(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[   5278987,      95404]
NotebookOptionsPosition[   5165900,      92984]
NotebookOutlinePosition[   5263114,      95026]
CellTagsIndexPosition[   5261996,      94984]
WindowTitle->Machine Learning: Elementary Introduction to the Wolfram \
Language
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[BoxData[
 InterpretationBox[Cell[
  "Machine Learning", "SectionInline",ExpressionUUID->
   "747f7954-9bd1-45dd-805e-484953bd1337"],
  $Line = 0; Null]], "SectionDoubleDigit",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CounterAssignments->{{"Section", 21}, {"Subsection", 0}, {
   "Subsubsection", 0}, {"Exercise", 0}},
 CellTags->"p:123",ExpressionUUID->"c97ab850-4a76-4666-aa61-74c4b348c44c"],

Cell[TextData[{
 "So far in this book, when we\[CloseCurlyQuote]ve wanted the Wolfram \
Language to do something, we\[CloseCurlyQuote]ve written code to tell it \
exactly what to do. But the Wolfram Language is also set up to be able to \
learn what to do just by looking at examples, using the idea of ",
 StyleBox["machine learning",
  FontSlant->"Italic"],
 ". "
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:1",ExpressionUUID->"915b6f3c-f225-4996-ac14-daa47344249a"],

Cell["\<\
We\[CloseCurlyQuote]ll talk about how to train the language yourself. But \
first let\[CloseCurlyQuote]s look at some built-in functions that have \
already been trained on huge numbers of examples.\
\>", "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"1c8c6f73-34ba-47a0-8790-89236c4827e3"],

Cell[TextData[{
 ButtonBox["LanguageIdentify",
  BaseStyle->"Link"],
 " takes pieces of text, and identifies what human language ",
 "they\[CloseCurlyQuote]re",
 " in."
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:2",ExpressionUUID->"f11b647e-7bf2-4c4c-9d41-fc529403a277"],

Cell["Identify the language each phrase is in:", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:3",ExpressionUUID->"d29a7c56-1ab8-4e56-86fc-93b883bc0ae3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LanguageIdentify", "[", 
  RowBox[{"{", " ", 
   RowBox[{
   "\"\<thank you\>\"", ",", "\"\<merci\>\"", ",", "\"\<dar las gracias\>\"", 
    ",", "\"\<\:611f\:8b1d\>\"", ",", 
    "\"\<\:0431\:043b\:0430\:0433\:043e\:0434\:0430\:0440\:0438\:0442\:044c\>\
\""}], "}"}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[1]:=",ExpressionUUID->"e273792f-fb5a-4243-b881-59f2864cdd57"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TemplateBox[{"\"English\"",RowBox[{"Entity", "[", 
       RowBox[{"\"Language\"", ",", "\"English\""}], "]"}],
     "\"Entity[\\\"Language\\\", \\\"English\\\"]\"","\"language\""},
    "Entity"], ",", 
   TemplateBox[{"\"French\"",RowBox[{"Entity", "[", 
       RowBox[{"\"Language\"", ",", "\"French\""}], "]"}],
     "\"Entity[\\\"Language\\\", \\\"French\\\"]\"","\"language\""},
    "Entity"], ",", 
   TemplateBox[{"\"Spanish\"",RowBox[{"Entity", "[", 
       RowBox[{"\"Language\"", ",", "\"Spanish\""}], "]"}],
     "\"Entity[\\\"Language\\\", \\\"Spanish\\\"]\"","\"language\""},
    "Entity"], ",", 
   TemplateBox[{"\"Chinese\"",RowBox[{"Entity", "[", 
       RowBox[{"\"Language\"", ",", "\"Chinese\""}], "]"}],
     "\"Entity[\\\"Language\\\", \\\"Chinese\\\"]\"","\"language\""},
    "Entity"], ",", 
   TemplateBox[{"\"Russian\"",RowBox[{"Entity", "[", 
       RowBox[{"\"Language\"", ",", "\"Russian\""}], "]"}],
     "\"Entity[\\\"Language\\\", \\\"Russian\\\"]\"","\"language\""},
    "Entity"]}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[1]=",ExpressionUUID->"35103a01-9f72-47a4-9864-79e103fb298b"]
}, Open  ]],

Cell["\<\
The Wolfram Language can also do the considerably more difficult \
\[OpenCurlyDoubleQuote]artificial intelligence\[CloseCurlyDoubleQuote] task \
of identifying what an image is of.\
\>", "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:4",ExpressionUUID->"cbc9e568-f31c-4611-a1e5-2ef6b6b65ba1"],

Cell["Identify what an image is of:", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:5",ExpressionUUID->"4ea5e5fb-0ba2-4f16-a1ff-8b390713de44"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ImageIdentify", "[", 
  GraphicsBox[
   TagBox[RasterBox[CompressedData["
1:eJxMu1eQLGd6pkdJN7rUjYKxHHLIGQyA49u78t57X5Xlvcny3nvvvetqb47p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     "], {{0, 213}, {320, 0}}, {0, 255},
     ColorFunction->RGBColor],
    BoxForm`ImageTag[
    "Byte", ColorSpace -> "RGB", Interleaving -> True, 
     MetaInformation -> {
      "Exif" -> {
        "Make" -> "Canon", "Model" -> "Canon EOS 700D", "ExposureTime" -> 
         Rational[1, 320], "FNumber" -> Rational[28, 5], "ISOSpeedRatings" -> 
         2000, "DateTimeOriginal" -> "2014:08:18 16:34:53", "Flash" -> 16, 
         "FocalLength" -> 250, 
         System`Convert`ExifDump`ReadFIDData[
          InputStream[String, 4], {136, 0, 0, 0, 0}, True], "GPSLatitudeRef" -> 
         "N", "GPSLatitude" -> {51, 54, 
           Rational[147, 100]}, "GPSLongitudeRef" -> "W", 
         "GPSLongitude" -> {8, 17, 
           Rational[667, 20]}}}],
    Selectable->False],
   BaseStyle->"ImageGraphics",
   ImageSize->{159.62890625, Automatic},
   ImageSizeRaw->{320, 213},
   PlotRange->{{0, 320}, {0, 213}}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[2]:=",ExpressionUUID->"24ab5800-def3-4052-8c1c-3bc8bcc7dac2"],

Cell[BoxData[
 TemplateBox[{"\"cheetah\"",RowBox[{"Entity", "[", 
     RowBox[{"\"Concept\"", ",", "\"AcinonyxJubatus::3g535\""}], "]"}],
   "\"Entity[\\\"Concept\\\", \\\"AcinonyxJubatus::3g535\\\"]\"",
   "\"concept\""},
  "Entity"]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[2]=",ExpressionUUID->"06029f14-f918-45b7-8bf9-298727e46c30"]
}, Open  ]],

Cell[TextData[{
 "There\[CloseCurlyQuote]s a general function ",
 ButtonBox["Classify",
  BaseStyle->"Link"],
 ", ",
 "which has been taught",
 " various kinds of classification. One example is classifying the \
\[OpenCurlyDoubleQuote]sentiment\[CloseCurlyDoubleQuote] of text."
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:6",ExpressionUUID->"bdcb1c61-b798-43ee-9c38-3a85263af201"],

Cell["Upbeat text is classified as having positive sentiment:", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:7",ExpressionUUID->"a1c49e7b-dd7e-4a7f-9291-5eb7080b915f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Classify", "[", 
  RowBox[{
  "\"\<Sentiment\>\"", ",", "\"\<I'm so excited to be programming\>\""}], 
  "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[3]:=",ExpressionUUID->"5e38586c-b936-4af6-951d-ab4fc0ae1309"],

Cell[BoxData["\<\"Positive\"\>"], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[3]=",ExpressionUUID->"97dc60b0-458e-4dcb-a566-8b9366dc9cdf"]
}, Open  ]],

Cell["Downbeat text is classified as having negative sentiment:", \
"CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"f2ed0dda-c079-4adc-8030-5cae3908c3f0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Classify", "[", 
  RowBox[{"\"\<Sentiment\>\"", ",", "\"\<math can be really hard\>\""}], 
  "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[4]:=",ExpressionUUID->"3c1aad97-5044-43ac-8f17-3155ed368974"],

Cell[BoxData["\<\"Negative\"\>"], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellTags->"LastCellOfAPage",
 CellLabel->"Out[4]=",ExpressionUUID->"a705f288-6ff9-4ed3-a28f-0b426ef098b3"]
}, Open  ]],

Cell[TextData[{
 "You can also train ",
 ButtonBox["Classify",
  BaseStyle->"Link"],
 " yourself. Here\[CloseCurlyQuote]s a simple example of classifying \
handwritten digits as 0 or 1. You give ",
 ButtonBox["Classify",
  BaseStyle->"Link"],
 " a collection of training examples, followed by a particular handwritten \
digit. Then it\[CloseCurlyQuote]ll tell you whether the digit you give is a 0 \
or 1. "
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->{
  "p:124", "i:8"},ExpressionUUID->"aa4f2372-7772-46fc-8d47-2372e74b70b5"],

Cell[TextData[{
 "With training examples, ",
 ButtonBox["Classify",
  BaseStyle->"Link"],
 " correctly identifies a handwritten 0:"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"29152688-d53f-4c73-a850-72a03d821a94"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Classify", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      GraphicsBox[
       TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRJI
mQgQCwLxfyg4NdWR1xjG+X9muSUbAyMjZ+9rCH8+F6Nc+qzjDeGM5SDu39WM
rPmfQazfGQKngFQXI+NMmF7FoP//bzEy7oUbttX8//9iRlE4//82yVePhVkm
IwS+yPaeYBT5jwTcLU8whiILCKudYFyBLCCkeoKxFIm/m9nyAnsSksA2xob/
qsiGrmdc/l+V9ylCIEbzy/+djIpw/hGFwP///2Qwpj+H8NeogT33SJJRrPj4
rVvLJnPyHQFLvO6TYmEEAfNDcM1bYmwYzTrfg5gAPlYFyw==
         "], {{0, 20}, {17, 
         0}}, {0, 255},
         ColorFunction->GrayLevel],
        BoxForm`ImageTag[
        "Byte", ColorSpace -> Automatic, Interleaving -> None],
        Selectable->False],
       BaseStyle->"ImageGraphics",
       ImageSizeRaw->{17, 20},
       PlotRange->{{0, 17}, {0, 20}}], "\[Rule]", "0"}], ",", 
     RowBox[{
      GraphicsBox[
       TagBox[
        RasterBox[{{255, 255, 255, 255, 219, 87, 139, 253}, {255, 255, 255, 
         255, 119, 1, 1, 212}, {255, 255, 255, 255, 62, 1, 46, 236}, {255, 
         255, 255, 218, 26, 1, 94, 255}, {255, 255, 255, 177, 1, 1, 206, 
         255}, {255, 255, 255, 68, 1, 1, 206, 255}, {255, 255, 255, 68, 1, 1, 
         206, 255}, {255, 255, 255, 68, 1, 15, 215, 255}, {255, 255, 255, 68, 
         1, 103, 255, 255}, {255, 255, 213, 18, 1, 138, 255, 255}, {255, 255, 
         165, 1, 1, 200, 255, 255}, {255, 255, 74, 1, 1, 200, 255, 255}, {255,
          239, 51, 1, 56, 244, 255, 255}, {255, 205, 1, 1, 69, 255, 255, 
         255}, {255, 205, 1, 1, 69, 255, 255, 255}, {255, 155, 1, 1, 118, 255,
          255, 255}, {255, 80, 0, 0, 193, 255, 255, 255}, {235, 45, 1, 1, 193,
          255, 255, 255}, {211, 1, 1, 60, 252, 255, 255, 255}, {232, 40, 89, 
         218, 255, 255, 255, 255}}, {{0, 20}, {8, 0}}, {0, 255},
         ColorFunction->GrayLevel],
        BoxForm`ImageTag[
        "Byte", ColorSpace -> Automatic, Interleaving -> None],
        Selectable->False],
       BaseStyle->"ImageGraphics",
       ImageSizeRaw->{8, 20},
       PlotRange->{{0, 8}, {0, 20}}], "\[Rule]", "1"}], ",", 
     RowBox[{
      GraphicsBox[
       TagBox[
        RasterBox[{{255, 255, 229, 134, 121, 2, 2, 0, 58, 242, 255, 255, 255, 
         255}, {255, 226, 47, 3, 3, 3, 3, 2, 3, 14, 218, 255, 255, 255}, {133,
          22, 3, 3, 3, 3, 3, 96, 57, 3, 67, 235, 255, 255}, {42, 3, 3, 3, 68, 
         216, 145, 255, 182, 54, 3, 69, 234, 255}, {63, 52, 3, 3, 162, 255, 
         255, 255, 255, 186, 13, 3, 189, 255}, {220, 188, 3, 33, 231, 255, 
         255, 255, 255, 255, 70, 3, 91, 255}, {255, 188, 3, 43, 255, 255, 255,
          255, 255, 255, 187, 11, 48, 242}, {255, 174, 3, 43, 255, 255, 255, 
         255, 255, 255, 255, 55, 3, 176}, {255, 55, 3, 43, 255, 255, 255, 255,
          255, 255, 255, 55, 3, 176}, {255, 55, 3, 43, 255, 255, 255, 255, 
         255, 255, 255, 55, 3, 176}, {255, 54, 2, 42, 255, 255, 255, 255, 255,
          255, 255, 54, 2, 175}, {255, 55, 3, 43, 255, 255, 255, 255, 255, 
         255, 255, 55, 3, 120}, {255, 55, 3, 43, 255, 255, 255, 255, 255, 255,
          255, 55, 3, 162}, {255, 98, 3, 9, 134, 255, 255, 255, 255, 255, 229,
          39, 3, 176}, {255, 188, 3, 3, 30, 255, 255, 255, 255, 255, 139, 3, 
         3, 176}, {255, 237, 52, 3, 24, 232, 255, 255, 255, 235, 34, 3, 14, 
         192}, {255, 255, 90, 3, 3, 128, 255, 255, 238, 136, 3, 3, 147, 
         255}, {255, 255, 235, 67, 3, 8, 95, 164, 56, 3, 3, 60, 231, 255}, {
         255, 255, 255, 217, 15, 3, 3, 2, 3, 3, 57, 233, 255, 255}, {255, 255,
          255, 255, 242, 59, 3, 2, 60, 136, 236, 255, 255, 255}}, {{0, 20}, {
         14, 0}}, {0, 255},
         ColorFunction->GrayLevel],
        BoxForm`ImageTag[
        "Byte", ColorSpace -> Automatic, Interleaving -> None],
        Selectable->False],
       BaseStyle->"ImageGraphics",
       ImageSizeRaw->{14, 20},
       PlotRange->{{0, 14}, {0, 20}}], "\[Rule]", "0"}], ",", 
     RowBox[{
      GraphicsBox[
       TagBox[
        RasterBox[{{255, 255, 255, 255, 157, 22, 154}, {255, 255, 255, 255, 1,
          2, 39}, {255, 255, 255, 223, 0, 67, 205}, {255, 255, 221, 36, 1, 
         163, 255}, {255, 255, 162, 2, 1, 163, 255}, {255, 255, 151, 1, 23, 
         255, 255}, {255, 255, 47, 2, 98, 255, 255}, {255, 255, 47, 2, 139, 
         255, 255}, {255, 255, 47, 2, 234, 255, 255}, {255, 191, 6, 2, 255, 
         255, 255}, {255, 69, 1, 1, 255, 255, 255}, {255, 70, 2, 76, 255, 255,
          255}, {242, 51, 2, 118, 255, 255, 255}, {208, 2, 2, 212, 255, 255, 
         255}, {103, 2, 2, 232, 255, 255, 255}, {92, 1, 94, 255, 255, 255, 
         255}, {93, 2, 94, 255, 255, 255, 255}, {93, 2, 94, 255, 255, 255, 
         255}, {187, 2, 94, 255, 255, 255, 255}, {229, 33, 146, 255, 255, 255,
          255}}, {{0, 20}, {7, 0}}, {0, 255},
         ColorFunction->GrayLevel],
        BoxForm`ImageTag[
        "Byte", ColorSpace -> Automatic, Interleaving -> None],
        Selectable->False],
       BaseStyle->"ImageGraphics",
       ImageSizeRaw->{7, 20},
       PlotRange->{{0, 7}, {0, 20}}], "\[Rule]", "1"}], ",", 
     RowBox[{
      GraphicsBox[
       TagBox[
        RasterBox[{{38, 78, 255, 255, 255, 255, 255, 255}, {39, 2, 143, 255, 
         255, 255, 255, 255}, {39, 1, 41, 229, 255, 255, 255, 255}, {39, 1, 1,
          142, 255, 255, 255, 255}, {189, 18, 1, 41, 230, 255, 255, 255}, {
         255, 159, 1, 1, 190, 255, 255, 255}, {255, 176, 1, 1, 146, 255, 255, 
         255}, {255, 176, 1, 1, 60, 255, 255, 255}, {255, 198, 15, 1, 60, 255,
          255, 255}, {255, 255, 52, 0, 14, 200, 255, 255}, {255, 255, 149, 1, 
         1, 153, 255, 255}, {255, 255, 197, 12, 1, 53, 255, 255}, {255, 255, 
         255, 58, 1, 53, 255, 255}, {255, 255, 255, 58, 1, 18, 203, 255}, {
         255, 255, 255, 58, 1, 1, 160, 255}, {255, 255, 255, 72, 1, 1, 18, 
         202}, {255, 255, 255, 228, 39, 1, 0, 160}, {255, 255, 255, 255, 72, 
         1, 1, 40}, {255, 255, 255, 255, 195, 1, 0, 43}, {255, 255, 255, 255, 
         195, 1, 92, 214}}, {{0, 20}, {8, 0}}, {0, 255},
         ColorFunction->GrayLevel],
        BoxForm`ImageTag[
        "Byte", ColorSpace -> Automatic, Interleaving -> None],
        Selectable->False],
       BaseStyle->"ImageGraphics",
       ImageSizeRaw->{8, 20},
       PlotRange->{{0, 8}, {0, 20}}], "\[Rule]", "1"}], ",", 
     RowBox[{
      GraphicsBox[
       TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRJI
mQgQCwHxfwj4yLj///98xtr/cFDExLYrVy2QxQQuksPEOO/F2x+20negAt+8
mBg/AWkXJkOoSBUTk8I3IL2WSewRRIk3E9NUEOMkE9MUsMhBJiZxMOOdBUTk
jjwTM0TqfyBTG4g6xMTE/x8mIgYkbysyMYXBRUCKTRkZpWHuCmAAitxRYGKa
AxWYzMZ78P8dDSamiK8QgWfaTLL//y9kYtL/BFUykUkF6AtzJiYLqMB+Xia/
//9fiDExzYIInHNmcnv1/389E5PBKxD/2lwuJlcQi4+JSaq6PS4ujoGJyfn1
f4gIBDDwt78Da+4Ngwh4tv2Emg8AlT70Eg==
         "], {{0, 20}, {18, 0}}, {0, 255},
         ColorFunction->GrayLevel],
        BoxForm`ImageTag[
        "Byte", ColorSpace -> Automatic, Interleaving -> None],
        Selectable->False],
       BaseStyle->"ImageGraphics",
       ImageSizeRaw->{18, 20},
       PlotRange->{{0, 18}, {0, 20}}], "\[Rule]", "0"}], ",", 
     RowBox[{
      GraphicsBox[
       TagBox[
        RasterBox[{{255, 255, 255, 255, 160, 1, 57, 88, 189, 255, 255, 255}, {
         255, 255, 255, 250, 52, 1, 0, 1, 90, 246, 255, 255}, {255, 255, 255, 
         237, 1, 23, 180, 6, 238, 255, 255, 255}, {255, 255, 255, 140, 3, 184,
          255, 205, 90, 255, 255, 255}, {255, 255, 232, 10, 56, 255, 255, 255,
          42, 217, 255, 255}, {255, 255, 143, 10, 204, 255, 255, 255, 148, 92,
          250, 255}, {255, 239, 30, 19, 255, 255, 255, 255, 221, 13, 220, 
         255}, {255, 183, 1, 92, 255, 255, 255, 255, 255, 33, 184, 255}, {255,
          131, 2, 196, 255, 255, 255, 255, 255, 118, 68, 253}, {255, 72, 28, 
         255, 255, 255, 255, 255, 255, 220, 13, 211}, {226, 15, 54, 255, 255, 
         255, 255, 255, 255, 255, 35, 211}, {211, 1, 116, 255, 255, 255, 255, 
         255, 255, 255, 36, 211}, {211, 1, 116, 255, 255, 255, 255, 255, 255, 
         255, 36, 211}, {211, 1, 116, 255, 255, 255, 255, 255, 255, 244, 29, 
         211}, {211, 1, 145, 255, 255, 255, 255, 255, 255, 141, 9, 219}, {211,
          1, 104, 255, 255, 255, 255, 255, 213, 15, 100, 255}, {246, 45, 28, 
         255, 255, 255, 255, 238, 34, 34, 236, 255}, {255, 198, 8, 196, 255, 
         255, 209, 27, 39, 219, 255, 255}, {255, 245, 76, 6, 71, 71, 1, 34, 
         244, 255, 255, 255}, {255, 255, 237, 83, 1, 62, 116, 252, 255, 255, 
         255, 255}}, {{0, 20}, {12, 0}}, {0, 255},
         ColorFunction->GrayLevel],
        BoxForm`ImageTag[
        "Byte", ColorSpace -> Automatic, Interleaving -> None],
        Selectable->False],
       BaseStyle->"ImageGraphics",
       ImageSizeRaw->{12, 20},
       PlotRange->{{0, 12}, {0, 20}}], "\[Rule]", "0"}], ",", 
     RowBox[{
      GraphicsBox[
       TagBox[
        RasterBox[{{255, 255, 255, 255, 255, 255, 229, 39, 20, 210}, {255, 
         255, 255, 255, 255, 255, 202, 1, 1, 164}, {255, 255, 255, 255, 255, 
         255, 202, 1, 1, 164}, {255, 255, 255, 255, 255, 255, 81, 1, 37, 
         248}, {255, 255, 255, 255, 255, 201, 7, 1, 158, 255}, {255, 255, 255,
          255, 255, 81, 1, 1, 170, 255}, {255, 255, 255, 255, 255, 65, 1, 1, 
         170, 255}, {255, 255, 255, 255, 255, 65, 1, 38, 240, 255}, {255, 255,
          255, 255, 202, 13, 1, 47, 255, 255}, {255, 255, 255, 255, 189, 1, 1,
          147, 255, 255}, {255, 255, 255, 200, 48, 1, 40, 235, 255, 255}, {
         255, 255, 255, 155, 1, 1, 80, 255, 255, 255}, {255, 255, 240, 43, 0, 
         11, 196, 255, 255, 255}, {255, 255, 155, 1, 1, 80, 255, 255, 255, 
         255}, {255, 255, 45, 1, 1, 190, 255, 255, 255, 255}, {255, 202, 18, 
         1, 41, 230, 255, 255, 255, 255}, {255, 159, 1, 6, 148, 255, 255, 255,
          255, 255}, {250, 37, 1, 80, 255, 255, 255, 255, 255, 255}, {162, 1, 
         3, 205, 255, 255, 255, 255, 255, 255}, {162, 1, 146, 255, 255, 255, 
         255, 255, 255, 255}}, {{0, 20}, {10, 0}}, {0, 255},
         ColorFunction->GrayLevel],
        BoxForm`ImageTag[
        "Byte", ColorSpace -> Automatic, Interleaving -> None],
        Selectable->False],
       BaseStyle->"ImageGraphics",
       ImageSizeRaw->{10, 20},
       PlotRange->{{0, 10}, {0, 20}}], "\[Rule]", "1"}], ",", 
     RowBox[{
      GraphicsBox[
       TagBox[
        RasterBox[{{255, 255, 255, 255, 255, 255, 255, 255, 255, 47, 2, 
         191}, {255, 255, 255, 255, 255, 255, 255, 255, 210, 19, 3, 160}, {
         255, 255, 255, 255, 255, 255, 255, 255, 102, 3, 34, 255}, {160, 255, 
         255, 255, 255, 255, 255, 217, 15, 3, 118, 255}, {244, 255, 255, 255, 
         255, 255, 255, 208, 3, 3, 118, 255}, {255, 255, 255, 255, 255, 255, 
         252, 85, 2, 2, 180, 255}, {255, 255, 255, 255, 255, 255, 210, 3, 3, 
         62, 247, 255}, {255, 255, 255, 255, 255, 255, 117, 3, 3, 178, 255, 
         255}, {255, 255, 255, 255, 255, 255, 117, 3, 3, 210, 255, 255}, {255,
          255, 255, 255, 255, 255, 64, 3, 3, 210, 255, 255}, {255, 255, 255, 
         255, 255, 244, 0, 2, 71, 255, 255, 255}, {255, 255, 255, 255, 255, 
         139, 2, 3, 72, 255, 255, 255}, {255, 255, 255, 255, 255, 139, 2, 3, 
         155, 255, 255, 255}, {255, 255, 255, 255, 255, 45, 2, 3, 186, 255, 
         255, 255}, {255, 255, 255, 255, 255, 25, 2, 45, 249, 255, 255, 
         255}, {255, 255, 255, 255, 255, 24, 0, 48, 255, 255, 255, 255}, {255,
          255, 255, 255, 195, 11, 2, 70, 255, 255, 255, 255}, {255, 255, 255, 
         255, 131, 3, 19, 230, 255, 255, 255, 255}, {255, 255, 255, 229, 31, 
         3, 120, 255, 255, 255, 255, 255}, {255, 255, 255, 185, 3, 3, 192, 
         255, 255, 255, 255, 255}}, {{0, 20}, {12, 0}}, {0, 255},
         ColorFunction->GrayLevel],
        BoxForm`ImageTag[
        "Byte", ColorSpace -> Automatic, Interleaving -> None],
        Selectable->False],
       BaseStyle->"ImageGraphics",
       ImageSizeRaw->{12, 20},
       PlotRange->{{0, 12}, {0, 20}}], "\[Rule]", "1"}], ",", 
     RowBox[{
      GraphicsBox[
       TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRJI
mSAQiwDxfzhYefPm4/P/kUHXMyYlpXIZyxq4yLEw+XomZiBgki/7ChWLAXGZ
IUQcRKg3gYmJiSG9uLi4yJeJqR8kdB6s5MkfEHsVM7MQkKqWYWIW8D4B0QIU
Y/7/9bA8M5PPPphts0BiIIn+z3AXyIHEcpiYHBHOZGAC2SHHLAtTtWdVDBOz
WMbndk7mXqi7p/MD3ed65f//BGbmGZ/ePz0cFgZ20OrjQNk+IMPJhB/iBeF+
iBeYQF5gYvItNi4uvgAx5bMXUEl4RPm3/x8Qtr9ZMfPEf1QAAMkk12Y=
         "], {{0, 
         17}, {20, 0}}, {0, 255},
         ColorFunction->GrayLevel],
        BoxForm`ImageTag[
        "Byte", ColorSpace -> Automatic, Interleaving -> None],
        Selectable->False],
       BaseStyle->"ImageGraphics",
       ImageSizeRaw->{20, 17},
       PlotRange->{{0, 20}, {0, 17}}], "\[Rule]", "0"}], ",", 
     RowBox[{
      GraphicsBox[
       TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRJI
mQgU/0eAw3vsGRkZtt9BElrNzwQGtnehAj8fWIoB+dw8rExM+yBCT71AKhT9
Pv9vZGVqAwt98QHrygKxuZiYQPre+IFE+PY+AXI+cjIJAKnNIBGe8IMgVTeM
web9BJvVBzG4F8jc971eFUh53/4JFroGtFzgaDlIEedUqJPOMzFJrP3PABIT
hbk7gonJ+v//J0/uysLE3t8UZGJ6DGZuholNB2rx+YUi9hToDv9n/5HFsoAa
g77+h4nxbv7/qdcMqAomBPKHtI8LyKxn8IA7Ig0JONNupNDcVgISCvj4Hxn8
2ucvse85nAsAzOUDGw==
         "], {{0, 20}, {20, 0}}, {0, 255},
         ColorFunction->GrayLevel],
        BoxForm`ImageTag[
        "Byte", ColorSpace -> Automatic, Interleaving -> None],
        Selectable->False],
       BaseStyle->"ImageGraphics",
       ImageSizeRaw->{20, 20},
       PlotRange->{{0, 20}, {0, 20}}], "\[Rule]", "0"}], ",", 
     RowBox[{
      GraphicsBox[
       TagBox[
        RasterBox[{{254, 146, 22, 2, 2, 145, 240, 176, 146, 192, 255, 255, 
         255, 255, 255}, {130, 3, 3, 3, 3, 2, 33, 13, 3, 111, 255, 255, 255, 
         255, 255}, {34, 3, 3, 3, 3, 2, 3, 3, 3, 95, 250, 255, 255, 255, 
         255}, {65, 3, 87, 3, 3, 2, 3, 3, 3, 2, 96, 214, 255, 255, 255}, {172,
          112, 203, 44, 3, 2, 3, 3, 3, 2, 3, 122, 255, 255, 255}, {255, 255, 
         58, 3, 3, 33, 76, 24, 3, 2, 3, 8, 121, 255, 255}, {254, 156, 13, 3, 
         3, 130, 255, 177, 3, 2, 3, 3, 3, 255, 255}, {254, 3, 3, 3, 87, 255, 
         255, 239, 147, 2, 3, 3, 3, 171, 255}, {254, 2, 2, 18, 193, 255, 255, 
         255, 255, 145, 2, 2, 2, 110, 255}, {213, 3, 3, 40, 255, 255, 255, 
         255, 255, 146, 3, 3, 3, 17, 225}, {111, 3, 3, 143, 255, 255, 255, 
         255, 255, 224, 28, 3, 3, 2, 220}, {111, 3, 3, 101, 255, 255, 255, 
         255, 255, 255, 38, 3, 3, 2, 220}, {110, 2, 2, 23, 208, 255, 255, 255,
          255, 255, 37, 2, 2, 110, 255}, {111, 3, 3, 3, 147, 255, 255, 255, 
         255, 161, 8, 3, 3, 111, 255}, {130, 3, 3, 3, 44, 234, 255, 255, 255, 
         146, 3, 3, 3, 214, 255}, {254, 3, 3, 3, 3, 48, 235, 255, 255, 64, 3, 
         3, 3, 255, 255}, {254, 64, 2, 2, 2, 0, 2, 85, 2, 0, 2, 2, 64, 255, 
         255}, {255, 240, 75, 3, 3, 2, 3, 3, 3, 2, 3, 14, 178, 255, 255}, {
         255, 255, 234, 75, 3, 2, 3, 3, 3, 2, 14, 153, 255, 255, 255}, {255, 
         255, 255, 239, 65, 2, 3, 3, 3, 64, 178, 255, 255, 255, 255}}, {{0, 
         20}, {15, 0}}, {0, 255},
         ColorFunction->GrayLevel],
        BoxForm`ImageTag[
        "Byte", ColorSpace -> Automatic, Interleaving -> None],
        Selectable->False],
       BaseStyle->"ImageGraphics",
       ImageSizeRaw->{15, 20},
       PlotRange->{{0, 15}, {0, 20}}], "\[Rule]", "0"}], ",", 
     RowBox[{
      GraphicsBox[
       TagBox[
        RasterBox[{{255, 115, 1, 0, 54, 167, 255, 255, 255}, {255, 116, 2, 2, 
         2, 4, 144, 255, 255}, {255, 116, 2, 2, 2, 2, 101, 255, 255}, {255, 
         116, 2, 2, 2, 2, 101, 255, 255}, {255, 116, 2, 2, 2, 2, 101, 255, 
         255}, {213, 20, 2, 2, 2, 2, 101, 255, 255}, {205, 2, 2, 2, 2, 2, 101,
          255, 255}, {205, 2, 2, 2, 2, 2, 101, 255, 255}, {205, 2, 2, 2, 2, 2,
          101, 255, 255}, {205, 2, 2, 2, 2, 2, 101, 255, 255}, {205, 2, 2, 2, 
         2, 2, 101, 255, 255}, {205, 2, 2, 2, 2, 2, 101, 255, 255}, {242, 87, 
         2, 2, 2, 2, 91, 248, 255}, {255, 116, 2, 2, 2, 2, 2, 190, 255}, {255,
          137, 6, 2, 2, 2, 2, 190, 255}, {255, 255, 25, 2, 2, 2, 2, 190, 
         255}, {255, 255, 63, 2, 2, 2, 2, 47, 255}, {255, 255, 189, 2, 2, 2, 
         2, 12, 174}, {255, 255, 251, 138, 4, 2, 2, 2, 43}, {255, 255, 255, 
         255, 116, 2, 2, 2, 117}}, {{0, 20}, {9, 0}}, {0, 255},
         ColorFunction->GrayLevel],
        BoxForm`ImageTag[
        "Byte", ColorSpace -> Automatic, Interleaving -> None],
        Selectable->False],
       BaseStyle->"ImageGraphics",
       ImageSizeRaw->{9, 20},
       PlotRange->{{0, 9}, {0, 20}}], "\[Rule]", "1"}], ",", 
     RowBox[{
      GraphicsBox[
       TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRJI
mQgU/0cFfy4pMs1HFbrSyczM7IskcGlnNCcTM7PMbITQGVugGqBYPEKXMg9Q
yLxMh3ky1OR5ikxMDExGr/7/z2Dq+gMSehkKVKJrUP0MyJ7DrPsZSB0zYmI2
LfoJ0bKRWeb9/3eL5Jm5Sj5Bjf1my9wBNACobxvcqs3MzHP/P2di4mqEC+03
BVm0l5m/Bi50s5iJe9L//4rMHnChN8rMTC1AWox5Gcz4XmVm3bnvgCwm5l0Q
oalezMxJL8FMUyaQcR9OlPIw63W/gkibMcu0X5ioAnSQHtxcR2ZIaMhsuA8X
++AHFOOK3/QIOWh/vewqe4Ua2gDMqh37
         "], {{0, 20}, {20, 0}}, {0, 255},
         ColorFunction->GrayLevel],
        BoxForm`ImageTag[
        "Byte", ColorSpace -> Automatic, Interleaving -> None],
        Selectable->False],
       BaseStyle->"ImageGraphics",
       ImageSizeRaw->{20, 20},
       PlotRange->{{0, 20}, {0, 20}}], "\[Rule]", "0"}], ",", 
     RowBox[{
      GraphicsBox[
       TagBox[
        RasterBox[{{255, 255, 255, 255, 255, 255, 255, 255, 255, 253, 103, 0, 
         221}, {255, 255, 255, 255, 255, 255, 255, 255, 255, 168, 2, 2, 
         107}, {255, 255, 255, 255, 255, 255, 255, 255, 249, 47, 2, 2, 155}, {
         255, 255, 255, 255, 255, 255, 255, 255, 108, 2, 2, 2, 173}, {255, 
         255, 255, 255, 255, 255, 255, 246, 50, 2, 2, 74, 243}, {255, 255, 
         255, 255, 255, 255, 255, 186, 2, 2, 2, 218, 255}, {255, 255, 255, 
         255, 255, 255, 244, 94, 2, 2, 59, 242, 255}, {255, 255, 255, 255, 
         255, 255, 192, 2, 2, 2, 113, 255, 255}, {255, 255, 255, 255, 255, 
         255, 105, 2, 2, 59, 242, 255, 255}, {255, 255, 255, 255, 255, 183, 
         20, 2, 2, 173, 255, 255, 255}, {255, 255, 255, 255, 255, 75, 2, 2, 
         92, 243, 255, 255, 255}, {255, 255, 255, 255, 215, 18, 2, 2, 200, 
         255, 255, 255, 255}, {255, 255, 255, 241, 80, 2, 2, 24, 217, 255, 
         255, 255, 255}, {255, 255, 255, 168, 2, 2, 23, 194, 255, 255, 255, 
         255, 255}, {255, 255, 177, 14, 2, 2, 110, 255, 255, 255, 255, 255, 
         255}, {255, 242, 58, 2, 2, 100, 247, 255, 255, 255, 255, 255, 255}, {
         244, 71, 2, 2, 22, 212, 255, 255, 255, 255, 255, 255, 255}, {230, 2, 
         2, 2, 51, 255, 255, 255, 255, 255, 255, 255, 255}, {230, 2, 2, 2, 
         109, 255, 255, 255, 255, 255, 255, 255, 255}, {242, 50, 20, 146, 253,
          255, 255, 255, 255, 255, 255, 255, 255}}, {{0, 20}, {13, 0}}, {0, 
         255},
         ColorFunction->GrayLevel],
        BoxForm`ImageTag[
        "Byte", ColorSpace -> Automatic, Interleaving -> None],
        Selectable->False],
       BaseStyle->"ImageGraphics",
       ImageSizeRaw->{13, 20},
       PlotRange->{{0, 13}, {0, 20}}], "\[Rule]", "1"}], ",", 
     RowBox[{
      GraphicsBox[
       TagBox[RasterBox[CompressedData["
1:eJxdUDEOwjAMtJgYEeID/ILRjKxFPKAVoWIJUoqEmPw0Py04cRvsWnKUO93F
OR+HV/fYAMC0laPrP+eU+u91J+AWp+cYw/0S32EM6TQU2UF6L52XYgDKtoTw
lEAkxJWAEBxRC7lZRFE0AOynkFJ2LNU7zdK/3BAFUEbzb3W5n86MM6GwRsJr
E9VdYGMYNT3rO1wjaCzU1HY9S3K7Li7JG/oBdlL2Qg==
         "], {{0, 20}, {18, 
         0}}, {0, 255},
         ColorFunction->GrayLevel],
        BoxForm`ImageTag[
        "Byte", ColorSpace -> Automatic, Interleaving -> None],
        Selectable->False],
       BaseStyle->"ImageGraphics",
       ImageSizeRaw->{18, 20},
       PlotRange->{{0, 18}, {0, 20}}], "\[Rule]", "0"}], ",", 
     RowBox[{
      GraphicsBox[
       TagBox[
        RasterBox[{{61, 230, 255, 255, 255, 255}, {69, 52, 255, 255, 255, 
         255}, {197, 12, 255, 255, 255, 255}, {220, 43, 182, 255, 255, 255}, {
         93, 4, 156, 255, 255, 255}, {118, 0, 156, 255, 255, 255}, {247, 36, 
         62, 251, 255, 255}, {255, 67, 1, 178, 255, 255}, {255, 147, 1, 100, 
         255, 255}, {255, 249, 1, 100, 255, 255}, {255, 253, 79, 100, 255, 
         255}, {255, 255, 99, 2, 233, 255}, {255, 255, 99, 1, 146, 255}, {255,
          255, 99, 1, 133, 255}, {255, 255, 99, 1, 42, 255}, {255, 255, 192, 
         1, 42, 255}, {255, 255, 202, 1, 14, 213}, {255, 255, 247, 96, 1, 
         193}, {255, 255, 255, 232, 4, 127}, {255, 255, 255, 196, 2, 89}}, {{
         0, 20}, {6, 0}}, {0, 255},
         ColorFunction->GrayLevel],
        BoxForm`ImageTag[
        "Byte", ColorSpace -> Automatic, Interleaving -> None],
        Selectable->False],
       BaseStyle->"ImageGraphics",
       ImageSizeRaw->{6, 20},
       PlotRange->{{0, 6}, {0, 20}}], "\[Rule]", "1"}], ",", 
     RowBox[{
      GraphicsBox[
       TagBox[
        RasterBox[{{172, 62, 53, 226, 255, 255}, {24, 1, 1, 56, 255, 255}, {
         24, 1, 1, 9, 255, 255}, {45, 1, 1, 9, 255, 255}, {188, 1, 1, 9, 255, 
         255}, {188, 1, 1, 9, 255, 255}, {188, 1, 1, 9, 255, 255}, {188, 1, 1,
          9, 255, 255}, {188, 1, 1, 4, 158, 255}, {188, 1, 1, 1, 100, 255}, {
         233, 67, 1, 1, 100, 255}, {255, 98, 1, 1, 100, 255}, {255, 98, 1, 1, 
         100, 255}, {255, 98, 1, 1, 100, 255}, {255, 98, 1, 1, 100, 255}, {
         255, 98, 1, 1, 100, 255}, {255, 98, 1, 1, 100, 255}, {255, 189, 4, 1,
          100, 255}, {255, 255, 7, 1, 6, 145}, {255, 255, 7, 1, 1, 25}}, {{0, 
         20}, {6, 0}}, {0, 255},
         ColorFunction->GrayLevel],
        BoxForm`ImageTag[
        "Byte", ColorSpace -> Automatic, Interleaving -> None],
        Selectable->False],
       BaseStyle->"ImageGraphics",
       ImageSizeRaw->{6, 20},
       PlotRange->{{0, 6}, {0, 20}}], "\[Rule]", "1"}], ",", 
     RowBox[{
      GraphicsBox[
       TagBox[
        RasterBox[{{255, 255, 41, 83, 255}, {255, 255, 2, 3, 255}, {255, 255, 
         21, 2, 153}, {255, 255, 103, 3, 153}, {255, 255, 41, 2, 214}, {255, 
         255, 2, 3, 255}, {255, 214, 1, 2, 255}, {255, 173, 2, 3, 255}, {255, 
         153, 1, 2, 255}, {255, 153, 2, 43, 255}, {255, 153, 1, 104, 255}, {
         255, 153, 2, 104, 255}, {255, 52, 1, 205, 255}, {234, 32, 22, 225, 
         255}, {183, 2, 52, 255, 255}, {103, 3, 52, 255, 255}, {103, 2, 152, 
         255, 255}, {22, 3, 235, 255, 255}, {0, 63, 255, 255, 255}, {2, 144, 
         255, 255, 255}}, {{0, 20}, {5, 0}}, {0, 255},
         ColorFunction->GrayLevel],
        BoxForm`ImageTag[
        "Byte", ColorSpace -> Automatic, Interleaving -> None],
        Selectable->False],
       BaseStyle->"ImageGraphics",
       ImageSizeRaw->{5, 20},
       PlotRange->{{0, 5}, {0, 20}}], "\[Rule]", "1"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   GraphicsBox[
    TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRJI
mQgQCwHxfxh4sz/TkJHB/SVc4JoKExh0wQTexgB5bNJMTHwfoSIFQAH5yRuA
5CIw/1MsKxNT+I3/N/hgIvZMTALFf4EMaajIDqCKXLAUVOStDBOT939kkW6g
odfBAn+lmLg+/P9/mpOJaTlEyWwmJkUgFcnEZP4WLHBKl4mp5P//+cxMTPch
SmyYmHiBzGImJsvvYIE8VibODWAJ1q1ggcmsTNztQPoRB5MMiP++A6i7AMRa
yAQWOZDBxMQZ/R0ucriCn4lJYwPEfKAIqyob0M9G76DBcIcdHFBS1W/ggTdT
lokpdu0TOP8/ADHi5B0=
      "], {{0, 20}, {18, 0}}, {0, 255},
      ColorFunction->GrayLevel],
     BoxForm`ImageTag["Byte", ColorSpace -> Automatic, Interleaving -> None],
     Selectable->False],
    BaseStyle->"ImageGraphics",
    ImageSizeRaw->{18, 20},
    PlotRange->{{0, 18}, {0, 20}}]}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[5]:=",ExpressionUUID->"6f73d5c0-1e1b-4dfc-ba61-be627d15d13e"],

Cell[BoxData["0"], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[5]=",ExpressionUUID->"fff54c99-fc83-4da4-94da-21a073270bf0"]
}, Open  ]],

Cell[TextData[{
 "To get some sense of how this works\[LongDash]and because it\
\[CloseCurlyQuote]s useful in its own right\[LongDash]let\[CloseCurlyQuote]s \
talk about the function ",
 ButtonBox["Nearest",
  BaseStyle->"Link"],
 ", that",
 " finds what element in a list is nearest to what you supply."
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:9",ExpressionUUID->"7d7f33ff-a858-4678-ab3a-ca59f3367a45"],

Cell["Find what number in the list is nearest to 22:", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"6aba28a7-1c69-4008-9757-12c696aed462"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Nearest", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "10", ",", "20", ",", "30", ",", "40", ",", "50", ",", "60", ",", "70", 
     ",", "80"}], "}"}], ",", "22"}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[6]:=",ExpressionUUID->"254d4ec0-4be1-4fa1-a274-8c715cf5d97e"],

Cell[BoxData[
 RowBox[{"{", "20", "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[6]=",ExpressionUUID->"33400ac2-ba2e-4ee8-ad21-2fc8fb3297e2"]
}, Open  ]],

Cell["Find the nearest three numbers:", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"485d5a7e-1ea3-48bd-b462-795a02bda5a3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Nearest", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "10", ",", "20", ",", "30", ",", "40", ",", "50", ",", "60", ",", "70", 
     ",", "80"}], "}"}], ",", "22", ",", "3"}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[7]:=",ExpressionUUID->"db8d331e-b80d-4531-9c15-83bd0eca8c39"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"20", ",", "30", ",", "10"}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[7]=",ExpressionUUID->"91f1067c-eef6-4ffd-9fbc-1314bda4f949"]
}, Open  ]],

Cell[TextData[{
 ButtonBox["Nearest",
  BaseStyle->"Link"],
 " can find nearest colors as well."
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:10",ExpressionUUID->"3f1792fe-3c2a-40a6-b748-a23e7b3e5f55"],

Cell["\<\
Find the 3 colors in the list that are nearest to the color you give:\
\>", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"0f7209ec-c3dd-41de-8dde-6b67752f6ae2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Nearest", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {Hue[0.], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->Hue[0., 1., 0.6666666666666667],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "Hue[0.]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = Hue[0., 0.5, 0.5]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["HueColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      Hue[0.],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {Hue[0.05], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->Hue[0.05000000000000001, 1., 0.6666666666666667],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "Hue[0.05]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = Hue[0.05, 0.5, 0.5]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["HueColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      Hue[0.05],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {Hue[0.1], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->Hue[0.10000000000000002`, 1., 0.6666666666666667],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "Hue[0.1]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = Hue[0.1, 0.5, 0.5]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["HueColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      Hue[0.1],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {Hue[0.15000000000000002`], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->Hue[0.15, 1., 0.6666666666666667],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "Hue[0.15000000000000002]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           Hue[0.15000000000000002`, 0.5, 0.5]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["HueColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      Hue[0.15000000000000002`],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {Hue[0.2], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->Hue[0.20000000000000004`, 1., 0.6666666666666667],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "Hue[0.2]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = Hue[0.2, 0.5, 0.5]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["HueColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      Hue[0.2],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {Hue[0.25], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->Hue[0.25, 1., 0.6666666666666667],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "Hue[0.25]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = Hue[0.25, 0.5, 0.5]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["HueColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      Hue[0.25],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {Hue[0.30000000000000004`], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->Hue[0.30000000000000004`, 1., 0.6666666666666667],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "Hue[0.30000000000000004]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           Hue[0.30000000000000004`, 0.5, 0.5]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["HueColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      Hue[0.30000000000000004`],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {Hue[0.35000000000000003`], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->Hue[0.35000000000000003`, 1., 0.6666666666666667],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "Hue[0.35000000000000003]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           Hue[0.35000000000000003`, 0.5, 0.5]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["HueColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      Hue[0.35000000000000003`],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {Hue[0.4], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->Hue[0.4000000000000001, 1., 0.6666666666666667],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "Hue[0.4]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = Hue[0.4, 0.5, 0.5]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["HueColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      Hue[0.4],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {Hue[0.45], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->Hue[0.45, 1., 0.6666666666666667],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "Hue[0.45]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = Hue[0.45, 0.5, 0.5]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["HueColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      Hue[0.45],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {Hue[0.5], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->Hue[0.5, 1., 0.6666666666666667],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "Hue[0.5]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = Hue[0.5, 0.5, 0.5]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["HueColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      Hue[0.5],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {Hue[0.55], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->Hue[0.55, 1., 0.6666666666666667],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "Hue[0.55]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = Hue[0.55, 0.5, 0.5]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["HueColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      Hue[0.55],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {Hue[0.6000000000000001], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->Hue[0.6000000000000001, 1., 0.6666666666666667],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "Hue[0.6000000000000001]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           Hue[0.6000000000000001, 0.5, 0.5]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["HueColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      Hue[0.6000000000000001],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {Hue[0.65], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->Hue[0.65, 1., 0.6666666666666667],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "Hue[0.65]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = Hue[0.65, 0.5, 0.5]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["HueColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      Hue[0.65],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {Hue[0.7000000000000001], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->Hue[0.7000000000000001, 1., 0.6666666666666667],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "Hue[0.7000000000000001]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           Hue[0.7000000000000001, 0.5, 0.5]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["HueColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      Hue[0.7000000000000001],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {Hue[0.75], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->Hue[0.75, 1., 0.6666666666666667],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "Hue[0.75]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = Hue[0.75, 0.5, 0.5]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["HueColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      Hue[0.75],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {Hue[0.8], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->Hue[0.8000000000000002, 1., 0.6666666666666667],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "Hue[0.8]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = Hue[0.8, 0.5, 0.5]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["HueColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      Hue[0.8],
      Editable->False,
      Selectable->False]}], "}"}], ",", 
   InterpretationBox[
    ButtonBox[
     TooltipBox[
      GraphicsBox[{{{{
           {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
           {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
           {RGBColor[
            0.8727094319714808, 0.9066617343162084, 0.09569669807641734], 
            RectangleBox[{0, -1}, {2, 1}]}}}}},
       AspectRatio->1,
       Frame->True,
       FrameStyle->RGBColor[
        0.5818062879809872, 0.6044411562108056, 0.06379779871761157],
       FrameTicks->None,
       ImageSize->
        Dynamic[{
         Automatic, 
          1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
           Magnification])}],
       PlotRangePadding->None],
      "RGBColor[0.8727094319714808, 0.9066617343162084, 0.09569669807641734]"],
     Appearance->None,
     BaseStyle->{},
     BaselinePosition->Baseline,
     ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
       If[
        Not[
         AbsoluteCurrentValue["Deployed"]], 
        SelectionMove[Typeset`box$, All, Expression]; 
        FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
        FrontEnd`Private`$ColorSelectorInitialColor = 
         RGBColor[
          0.8727094319714808, 0.9066617343162084, 0.09569669807641734]; 
        FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
        MathLink`CallFrontEnd[
          FrontEnd`AttachCell[Typeset`box$, 
           FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
           Left, Top}, 
           "ClosingActions" -> {
            "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
     DefaultBaseStyle->{},
     Evaluator->Automatic,
     Method->"Preemptive"],
    RGBColor[0.8727094319714808, 0.9066617343162084, 0.09569669807641734],
    Editable->False,
    Selectable->False], ",", "3"}], "]"}]], "Input",
 Deletable->False,
 GraphicsBoxOptions->{BaselinePosition->Scaled[0.1]},
 CellLabel->"In[8]:=",ExpressionUUID->"b92b1b76-7c31-457f-96ed-919a5a319e33"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   InterpretationBox[
    ButtonBox[
     TooltipBox[
      GraphicsBox[{{{{
           {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
           {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
           {Hue[0.15000000000000002`], RectangleBox[{0, -1}, {2, 1}]}}}}},
       AspectRatio->1,
       Frame->True,
       FrameStyle->Hue[0.15, 1., 0.6666666666666667],
       FrameTicks->None,
       ImageSize->
        Dynamic[{
         Automatic, 
          1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
           Magnification])}],
       PlotRangePadding->None],
      "Hue[0.15000000000000002]"],
     Appearance->None,
     BaseStyle->{},
     BaselinePosition->Baseline,
     ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
       If[
        Not[
         AbsoluteCurrentValue["Deployed"]], 
        SelectionMove[Typeset`box$, All, Expression]; 
        FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
        FrontEnd`Private`$ColorSelectorInitialColor = 
         Hue[0.15000000000000002`, 0.5, 0.5]; 
        FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
        MathLink`CallFrontEnd[
          FrontEnd`AttachCell[Typeset`box$, 
           FrontEndResource["HueColorValueSelector"], {0, {Left, Bottom}}, {
           Left, Top}, 
           "ClosingActions" -> {
            "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
     DefaultBaseStyle->{},
     Evaluator->Automatic,
     Method->"Preemptive"],
    Hue[0.15000000000000002`],
    Editable->False,
    Selectable->False], ",", 
   InterpretationBox[
    ButtonBox[
     TooltipBox[
      GraphicsBox[{{{{
           {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
           {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
           {Hue[0.2], RectangleBox[{0, -1}, {2, 1}]}}}}},
       AspectRatio->1,
       Frame->True,
       FrameStyle->Hue[0.20000000000000004`, 1., 0.6666666666666667],
       FrameTicks->None,
       ImageSize->
        Dynamic[{
         Automatic, 
          1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
           Magnification])}],
       PlotRangePadding->None],
      "Hue[0.2]"],
     Appearance->None,
     BaseStyle->{},
     BaselinePosition->Baseline,
     ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
       If[
        Not[
         AbsoluteCurrentValue["Deployed"]], 
        SelectionMove[Typeset`box$, All, Expression]; 
        FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
        FrontEnd`Private`$ColorSelectorInitialColor = Hue[0.2, 0.5, 0.5]; 
        FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
        MathLink`CallFrontEnd[
          FrontEnd`AttachCell[Typeset`box$, 
           FrontEndResource["HueColorValueSelector"], {0, {Left, Bottom}}, {
           Left, Top}, 
           "ClosingActions" -> {
            "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
     DefaultBaseStyle->{},
     Evaluator->Automatic,
     Method->"Preemptive"],
    Hue[0.2],
    Editable->False,
    Selectable->False], ",", 
   InterpretationBox[
    ButtonBox[
     TooltipBox[
      GraphicsBox[{{{{
           {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
           {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
           {Hue[0.25], RectangleBox[{0, -1}, {2, 1}]}}}}},
       AspectRatio->1,
       Frame->True,
       FrameStyle->Hue[0.25, 1., 0.6666666666666667],
       FrameTicks->None,
       ImageSize->
        Dynamic[{
         Automatic, 
          1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
           Magnification])}],
       PlotRangePadding->None],
      "Hue[0.25]"],
     Appearance->None,
     BaseStyle->{},
     BaselinePosition->Baseline,
     ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
       If[
        Not[
         AbsoluteCurrentValue["Deployed"]], 
        SelectionMove[Typeset`box$, All, Expression]; 
        FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
        FrontEnd`Private`$ColorSelectorInitialColor = Hue[0.25, 0.5, 0.5]; 
        FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
        MathLink`CallFrontEnd[
          FrontEnd`AttachCell[Typeset`box$, 
           FrontEndResource["HueColorValueSelector"], {0, {Left, Bottom}}, {
           Left, Top}, 
           "ClosingActions" -> {
            "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
     DefaultBaseStyle->{},
     Evaluator->Automatic,
     Method->"Preemptive"],
    Hue[0.25],
    Editable->False,
    Selectable->False]}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 GraphicsBoxOptions->{BaselinePosition->Scaled[0.1]},
 CellLabel->"Out[8]=",ExpressionUUID->"74a9d9eb-c5d2-4aee-879d-631f7fabe6bc"]
}, Open  ]],

Cell["It also works on words.", "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:11",ExpressionUUID->"2aa7403f-57ce-4ce0-9ba2-a10485dd7cf0"],

Cell["Find the 10 words nearest to \[OpenCurlyDoubleQuote]good\
\[CloseCurlyDoubleQuote] in the list of words:", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:12",ExpressionUUID->"43586c80-36d2-41ca-aa07-74ed27a61f5e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Nearest", "[", 
  RowBox[{
   RowBox[{"WordList", "[", " ", "]"}], ",", "\"\<good\>\"", ",", "10"}], 
  "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[9]:=",ExpressionUUID->"724286fa-cd1e-455b-badd-3d3beffd66f0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"good\"\>", ",", "\<\"food\"\>", ",", "\<\"goad\"\>", 
   ",", "\<\"god\"\>", ",", "\<\"gold\"\>", ",", "\<\"goo\"\>", 
   ",", "\<\"goody\"\>", ",", "\<\"goof\"\>", ",", "\<\"goon\"\>", 
   ",", "\<\"goop\"\>"}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[9]=",ExpressionUUID->"6a25814f-16c2-4ebd-9269-a56388ae09c2"]
}, Open  ]],

Cell[TextData[{
 "There\[CloseCurlyQuote]s a notion of nearness for images too. ",
 "And though it\[CloseCurlyQuote]s far from the whole story, this is \
effectively part of what ",
 ButtonBox["ImageIdentify",
  BaseStyle->"Link"],
 " is using.",
 " "
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->{
  "LastCellOfAPage", 
   "i:13"},ExpressionUUID->"1f51a703-2c19-4149-abfa-2d40ba83fea6"],

Cell[TextData[{
 "Something that\[CloseCurlyQuote]s again related is recognizing text (",
 StyleBox["optical character recognition",
  FontSlant->"Italic"],
 " or OCR). Let\[CloseCurlyQuote]s make a piece of text \
that\[CloseCurlyQuote]s blurred."
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->{
  "p:125", "i:14"},ExpressionUUID->"9ad91d6e-8d51-44cd-ba69-db6ca5a530cc"],

Cell["Create an image of the word \[OpenCurlyDoubleQuote]hello\
\[CloseCurlyDoubleQuote], then blur it:", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:15",ExpressionUUID->"102a34da-ceb6-4b31-919c-86b4970f1a0d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Blur", "[", 
  RowBox[{
   RowBox[{"Rasterize", "[", 
    RowBox[{"Style", "[", 
     RowBox[{"\"\<hello\>\"", ",", "30"}], "]"}], "]"}], ",", "3"}], 
  "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[10]:=",ExpressionUUID->"b39028a3-fc19-46e6-9a1b-9ed3a6228475"],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJztmOlTWmm+x7vmvrkv779w39yXUzVTt2a6p6ump28qmSxtVMQdWWVxAfd9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    "], {{0, 38}, {63, 
    0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> False],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{63, 38},
  PlotRange->{{0, 63}, {0, 38}}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[10]=",ExpressionUUID->"46a1eb73-78cb-4857-a9c2-b6d00805f70b"]
}, Open  ]],

Cell[TextData[{
 ButtonBox["TextRecognize",
  BaseStyle->"Link"],
 " can recognize the original text string ",
 "in this",
 "."
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:16",ExpressionUUID->"0c6bc1f5-40e6-4b4d-908b-6aad4e5b2877"],

Cell["Recognize text in the image:", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"bef6ef40-20d4-4d35-8051-acae79162c41"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TextRecognize", "[", 
  GraphicsBox[
   TagBox[RasterBox[CompressedData["
1:eJztmOlTWmm+x7vmvrkv779w39yXUzVTt2a6p6ump28qmSxtVMQdWWVxAfd9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     "], {{0, 38}, {63, 
     0}}, {0, 255},
     ColorFunction->RGBColor],
    BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> False],
    Selectable->False],
   BaseStyle->"ImageGraphics",
   ImageSize->Automatic,
   ImageSizeRaw->{63, 38},
   PlotRange->{{0, 63}, {0, 38}}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[11]:=",ExpressionUUID->"b53292b5-3b15-45de-a4e7-2b261371b1f1"],

Cell[BoxData["\<\"hello\"\>"], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[11]=",ExpressionUUID->"9afcfcac-5a13-49e5-86dd-32a331fcf5ff"]
}, Open  ]],

Cell[TextData[{
 "One ",
 "more example",
 " involves taking a collection of things\[LongDash]say colors\[LongDash]and \
finding clusters of similar ones. This can be achieved using ",
 ButtonBox["FindClusters",
  BaseStyle->"Link"],
 "."
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:17",ExpressionUUID->"8c1d3d23-191b-494e-9685-f476279971e5"],

Cell["Collect \[OpenCurlyDoubleQuote]clusters\[CloseCurlyDoubleQuote] of \
similar colors into separate lists:", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"89eb4948-d7da-423f-925a-e044ed0edeaa"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FindClusters", "[", 
  RowBox[{"{", 
   RowBox[{
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{{{{
            {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
            {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
            {RGBColor[
             0.048175746346922704`, 0.8856231902848692, 0.002187262571789972],
              RectangleBox[{0, -1}, {2, 1}]}}}}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.0321171642312818, 0.5904154601899129, 0.0014581750478599813`],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.048175746346922704, 0.8856231902848692, \
0.002187262571789972}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.048175746346922704`, 0.8856231902848692, 0.002187262571789972]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.048175746346922704`, 0.8856231902848692, 
      0.002187262571789972}],
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{{{{
            {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
            {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
            {RGBColor[
             0.9543437880041175, 0.9364915417894851, 0.08314980598714755], 
             RectangleBox[{0, -1}, {2, 1}]}}}}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.636229192002745, 0.6243276945263234, 0.0554332039914317],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.9543437880041175, 0.9364915417894851, \
0.08314980598714755}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.9543437880041175, 0.9364915417894851, 0.08314980598714755]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.9543437880041175, 0.9364915417894851, 0.08314980598714755}],
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{{{{
            {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
            {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
            {RGBColor[
             0.8527294202095301, 0.15459949958575997`, 0.08139444813034824], 
             RectangleBox[{0, -1}, {2, 1}]}}}}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.5684862801396868, 0.10306633305717332`, 0.054262965420232165`],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.8527294202095301, 0.15459949958575997, \
0.08139444813034824}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.8527294202095301, 0.15459949958575997`, 0.08139444813034824]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.8527294202095301, 0.15459949958575997`, 0.08139444813034824}],
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{{{{
            {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
            {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
            {RGBColor[
             0.12965437429396431`, 0.8338364200576898, 0.16859742903104202`], 
             RectangleBox[{0, -1}, {2, 1}]}}}}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.08643624952930955, 0.5558909467051265, 0.11239828602069468`],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.12965437429396431, 0.8338364200576898, \
0.16859742903104202}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.12965437429396431`, 0.8338364200576898, 0.16859742903104202`]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.12965437429396431`, 0.8338364200576898, 
      0.16859742903104202`}],
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{{{{
            {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
            {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
            {RGBColor[
             0.14189318640501342`, 0.8685451286121387, 0.10426943556314977`], 
             RectangleBox[{0, -1}, {2, 1}]}}}}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.09459545760334229, 0.5790300857414259, 0.06951295704209985],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.14189318640501342, 0.8685451286121387, \
0.10426943556314977}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.14189318640501342`, 0.8685451286121387, 0.10426943556314977`]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.14189318640501342`, 0.8685451286121387, 
      0.10426943556314977`}],
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{{{{
            {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
            {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
            {RGBColor[
             0.9244703510275273, 0.001783470411052479, 0.14318146272477922`], 
             RectangleBox[{0, -1}, {2, 1}]}}}}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.6163135673516849, 0.0011889802740349862`, 0.09545430848318615],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.9244703510275273, 0.001783470411052479, \
0.14318146272477922}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.9244703510275273, 0.001783470411052479, 0.14318146272477922`]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.9244703510275273, 0.001783470411052479, 
      0.14318146272477922`}],
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{{{{
            {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
            {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
            {RGBColor[
             0.8340523614444824, 0.038129646837010533`, 0.09354464468116397], 
             RectangleBox[{0, -1}, {2, 1}]}}}}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.5560349076296549, 0.025419764558007023`, 0.06236309645410931],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.8340523614444824, 0.038129646837010533, \
0.09354464468116397}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.8340523614444824, 0.038129646837010533`, 0.09354464468116397]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.8340523614444824, 0.038129646837010533`, 
      0.09354464468116397}],
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{{{{
            {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
            {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
            {RGBColor[
             0.06423181065333894, 0.9361486399945784, 0.08411970647251821], 
             RectangleBox[{0, -1}, {2, 1}]}}}}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.042821207102225964`, 0.624099093329719, 0.05607980431501214],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.06423181065333894, 0.9361486399945784, \
0.08411970647251821}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.06423181065333894, 0.9361486399945784, 0.08411970647251821]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.06423181065333894, 0.9361486399945784, 0.08411970647251821}],
     
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{{{{
            {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
            {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
            {RGBColor[
             0.8676164929883508, 0.8866580065099905, 0.024086278089002183`], 
             RectangleBox[{0, -1}, {2, 1}]}}}}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.5784109953255672, 0.5911053376733271, 0.016057518726001457`],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.8676164929883508, 0.8866580065099905, \
0.024086278089002183}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.8676164929883508, 0.8866580065099905, 0.024086278089002183`]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.8676164929883508, 0.8866580065099905, 0.024086278089002183`}],
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{{{{
            {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
            {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
            {RGBColor[
             0.8577958146408966, 0.8374035340744639, 0.0071190816223388464`], 
             RectangleBox[{0, -1}, {2, 1}]}}}}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.5718638764272644, 0.5582690227163093, 0.004746054414892564],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.8577958146408966, 0.8374035340744639, \
0.0071190816223388464}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.8577958146408966, 0.8374035340744639, 0.0071190816223388464`]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.8577958146408966, 0.8374035340744639, 
      0.0071190816223388464`}],
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{{{{
            {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
            {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
            {RGBColor[
             0.9967431643372854, 0.969475575859666, 0.12251095291379577`], 
             RectangleBox[{0, -1}, {2, 1}]}}}}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.6644954428915236, 0.6463170505731107, 0.08167396860919718],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.9967431643372854, 0.969475575859666, \
0.12251095291379577}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.9967431643372854, 0.969475575859666, 0.12251095291379577`]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.9967431643372854, 0.969475575859666, 0.12251095291379577`}],
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{{{{
            {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
            {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
            {RGBColor[
             0.8543889209256321, 0.09697598692920356, 0.10750903324099509`], 
             RectangleBox[{0, -1}, {2, 1}]}}}}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.5695926139504215, 0.06465065795280238, 0.07167268882733006],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.8543889209256321, 0.09697598692920356, \
0.10750903324099509}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.8543889209256321, 0.09697598692920356, 0.10750903324099509`]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.8543889209256321, 0.09697598692920356, 0.10750903324099509`}],
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{{{{
            {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
            {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
            {RGBColor[
             0.8500363984900003, 0.9263311671408848, 0.13924242858059316`], 
             RectangleBox[{0, -1}, {2, 1}]}}}}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.5666909323266669, 0.6175541114272566, 0.09282828572039545],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.8500363984900003, 0.9263311671408848, \
0.13924242858059316}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.8500363984900003, 0.9263311671408848, 0.13924242858059316`]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.8500363984900003, 0.9263311671408848, 0.13924242858059316`}],
     
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{{{{
            {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
            {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
            {RGBColor[
             0.9879209034166253, 0.8377732017482453, 0.15613661869756118`], 
             RectangleBox[{0, -1}, {2, 1}]}}}}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.6586139356110836, 0.5585154678321635, 0.10409107913170745`],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.9879209034166253, 0.8377732017482453, \
0.15613661869756118}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.9879209034166253, 0.8377732017482453, 0.15613661869756118`]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.9879209034166253, 0.8377732017482453, 0.15613661869756118`}],
     
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{{{{
            {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
            {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
            {RGBColor[
             0.9573167308698426, 0.1507116093826361, 0.09832234398916928], 
             RectangleBox[{0, -1}, {2, 1}]}}}}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.6382111539132285, 0.10047440625509074`, 0.06554822932611286],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.9573167308698426, 0.1507116093826361, \
0.09832234398916928}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.9573167308698426, 0.1507116093826361, 0.09832234398916928]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.9573167308698426, 0.1507116093826361, 0.09832234398916928}],
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{{{{
            {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
            {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
            {RGBColor[
             0.04278634258158939, 0.9055378427790535, 0.0003309996431954121], 
             RectangleBox[{0, -1}, {2, 1}]}}}}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.028524228387726263`, 0.6036918951860357, 0.0002206664287969414],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.04278634258158939, 0.9055378427790535, \
0.0003309996431954121}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.04278634258158939, 0.9055378427790535, 0.0003309996431954121]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.04278634258158939, 0.9055378427790535, 
      0.0003309996431954121}],
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{{{{
            {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
            {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
            {RGBColor[
             0.8058039405531526, 0.8318774133774354, 0.10151558699591279`], 
             RectangleBox[{0, -1}, {2, 1}]}}}}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.5372026270354351, 0.5545849422516236, 0.06767705799727519],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.8058039405531526, 0.8318774133774354, \
0.10151558699591279}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.8058039405531526, 0.8318774133774354, 0.10151558699591279`]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.8058039405531526, 0.8318774133774354, 0.10151558699591279`}],
     
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{{{{
            {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
            {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
            {RGBColor[
             0.006814389873512461, 0.9336694049188562, 0.06907220235176909], 
             RectangleBox[{0, -1}, {2, 1}]}}}}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.004542926582341641, 0.6224462699459041, 0.04604813490117939],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.006814389873512461, 0.9336694049188562, \
0.06907220235176909}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.006814389873512461, 0.9336694049188562, 0.06907220235176909]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.006814389873512461, 0.9336694049188562, 0.06907220235176909}],
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{{{{
            {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
            {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
            {RGBColor[
             0.9450158125329948, 0.9670907305400336, 0.05040029871534907], 
             RectangleBox[{0, -1}, {2, 1}]}}}}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.6300105416886632, 0.6447271536933558, 0.033600199143566045`],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.9450158125329948, 0.9670907305400336, \
0.05040029871534907}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.9450158125329948, 0.9670907305400336, 0.05040029871534907]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.9450158125329948, 0.9670907305400336, 0.05040029871534907}],
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{{{{
            {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
            {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
            {RGBColor[
             0.9752641706478989, 0.8013981246170678, 0.10899973580393796`], 
             RectangleBox[{0, -1}, {2, 1}]}}}}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.650176113765266, 0.5342654164113786, 0.07266649053595864],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.9752641706478989, 0.8013981246170678, \
0.10899973580393796}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.9752641706478989, 0.8013981246170678, 0.10899973580393796`]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.9752641706478989, 0.8013981246170678, 0.10899973580393796`}],
     
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{{{{
            {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
            {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
            {RGBColor[
             0.16590548598015492`, 0.9015045495499641, 0.09828783196817376], 
             RectangleBox[{0, -1}, {2, 1}]}}}}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.11060365732010329`, 0.6010030330333094, 0.06552522131211584],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.16590548598015492, 0.9015045495499641, \
0.09828783196817376}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.16590548598015492`, 0.9015045495499641, 0.09828783196817376]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.16590548598015492`, 0.9015045495499641, 0.09828783196817376}],
     Editable->False,
     Selectable->False], ",", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{{{{
            {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
            {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
            {RGBColor[
             0.10048980936842117`, 0.9171495192304465, 0.16131399976146749`], 
             RectangleBox[{0, -1}, {2, 1}]}}}}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[
         0.06699320624561411, 0.6114330128202977, 0.10754266650764499`],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[{0.10048980936842117, 0.9171495192304465, \
0.16131399976146749}]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = 
          RGBColor[
           0.10048980936842117`, 0.9171495192304465, 0.16131399976146749`]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[{0.10048980936842117`, 0.9171495192304465, 
      0.16131399976146749`}],
     Editable->False,
     Selectable->False]}], "}"}], "]"}]], "Input",
 Deletable->False,
 GraphicsBoxOptions->{BaselinePosition->Scaled[0.1]},
 CellLabel->"In[12]:=",ExpressionUUID->"3ea70913-b20f-4a1e-a571-2fe3712fe551"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[
              0.048175746346922704`, 0.8856231902848692, 
               0.002187262571789972], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.0321171642312818, 0.5904154601899129, 0.0014581750478599813`],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.048175746346922704, 0.8856231902848692, \
0.002187262571789972}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.048175746346922704`, 0.8856231902848692, 0.002187262571789972]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.048175746346922704`, 0.8856231902848692, 
       0.002187262571789972}],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[
              0.12965437429396431`, 0.8338364200576898, 0.16859742903104202`],
               RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.08643624952930955, 0.5558909467051265, 0.11239828602069468`],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.12965437429396431, 0.8338364200576898, \
0.16859742903104202}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.12965437429396431`, 0.8338364200576898, 0.16859742903104202`]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.12965437429396431`, 0.8338364200576898, 
       0.16859742903104202`}],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[
              0.14189318640501342`, 0.8685451286121387, 0.10426943556314977`],
               RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.09459545760334229, 0.5790300857414259, 0.06951295704209985],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.14189318640501342, 0.8685451286121387, \
0.10426943556314977}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.14189318640501342`, 0.8685451286121387, 0.10426943556314977`]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.14189318640501342`, 0.8685451286121387, 
       0.10426943556314977`}],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[
              0.06423181065333894, 0.9361486399945784, 0.08411970647251821], 
              RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.042821207102225964`, 0.624099093329719, 0.05607980431501214],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.06423181065333894, 0.9361486399945784, \
0.08411970647251821}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.06423181065333894, 0.9361486399945784, 0.08411970647251821]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.06423181065333894, 0.9361486399945784, 0.08411970647251821}],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[
              0.04278634258158939, 0.9055378427790535, 0.0003309996431954121],
               RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.028524228387726263`, 0.6036918951860357, 0.0002206664287969414],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.04278634258158939, 0.9055378427790535, \
0.0003309996431954121}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.04278634258158939, 0.9055378427790535, 0.0003309996431954121]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.04278634258158939, 0.9055378427790535, 
       0.0003309996431954121}],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[
              0.006814389873512461, 0.9336694049188562, 0.06907220235176909], 
              RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.004542926582341641, 0.6224462699459041, 0.04604813490117939],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.006814389873512461, 0.9336694049188562, \
0.06907220235176909}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.006814389873512461, 0.9336694049188562, 0.06907220235176909]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.006814389873512461, 0.9336694049188562, 
       0.06907220235176909}],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[
              0.16590548598015492`, 0.9015045495499641, 0.09828783196817376], 
              RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.11060365732010329`, 0.6010030330333094, 0.06552522131211584],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.16590548598015492, 0.9015045495499641, \
0.09828783196817376}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.16590548598015492`, 0.9015045495499641, 0.09828783196817376]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.16590548598015492`, 0.9015045495499641, 
       0.09828783196817376}],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[
              0.10048980936842117`, 0.9171495192304465, 0.16131399976146749`],
               RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.06699320624561411, 0.6114330128202977, 0.10754266650764499`],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.10048980936842117, 0.9171495192304465, \
0.16131399976146749}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.10048980936842117`, 0.9171495192304465, 0.16131399976146749`]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.10048980936842117`, 0.9171495192304465, 
       0.16131399976146749`}],
      Editable->False,
      Selectable->False]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[
              0.9543437880041175, 0.9364915417894851, 0.08314980598714755], 
              RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.636229192002745, 0.6243276945263234, 0.0554332039914317],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.9543437880041175, 0.9364915417894851, \
0.08314980598714755}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.9543437880041175, 0.9364915417894851, 0.08314980598714755]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.9543437880041175, 0.9364915417894851, 0.08314980598714755}],
      
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[
              0.8676164929883508, 0.8866580065099905, 0.024086278089002183`], 
              RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.5784109953255672, 0.5911053376733271, 0.016057518726001457`],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.8676164929883508, 0.8866580065099905, \
0.024086278089002183}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.8676164929883508, 0.8866580065099905, 0.024086278089002183`]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.8676164929883508, 0.8866580065099905, 
       0.024086278089002183`}],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[
              0.8577958146408966, 0.8374035340744639, 0.0071190816223388464`],
               RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.5718638764272644, 0.5582690227163093, 0.004746054414892564],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.8577958146408966, 0.8374035340744639, \
0.0071190816223388464}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.8577958146408966, 0.8374035340744639, 0.0071190816223388464`]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.8577958146408966, 0.8374035340744639, 
       0.0071190816223388464`}],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[
              0.9967431643372854, 0.969475575859666, 0.12251095291379577`], 
              RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.6644954428915236, 0.6463170505731107, 0.08167396860919718],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.9967431643372854, 0.969475575859666, \
0.12251095291379577}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.9967431643372854, 0.969475575859666, 0.12251095291379577`]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.9967431643372854, 0.969475575859666, 0.12251095291379577`}],
      
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[
              0.8500363984900003, 0.9263311671408848, 0.13924242858059316`], 
              RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.5666909323266669, 0.6175541114272566, 0.09282828572039545],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.8500363984900003, 0.9263311671408848, \
0.13924242858059316}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.8500363984900003, 0.9263311671408848, 0.13924242858059316`]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.8500363984900003, 0.9263311671408848, 0.13924242858059316`}],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[
              0.9879209034166253, 0.8377732017482453, 0.15613661869756118`], 
              RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.6586139356110836, 0.5585154678321635, 0.10409107913170745`],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.9879209034166253, 0.8377732017482453, \
0.15613661869756118}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.9879209034166253, 0.8377732017482453, 0.15613661869756118`]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.9879209034166253, 0.8377732017482453, 0.15613661869756118`}],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[
              0.8058039405531526, 0.8318774133774354, 0.10151558699591279`], 
              RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.5372026270354351, 0.5545849422516236, 0.06767705799727519],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.8058039405531526, 0.8318774133774354, \
0.10151558699591279}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.8058039405531526, 0.8318774133774354, 0.10151558699591279`]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.8058039405531526, 0.8318774133774354, 0.10151558699591279`}],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[
              0.9450158125329948, 0.9670907305400336, 0.05040029871534907], 
              RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.6300105416886632, 0.6447271536933558, 0.033600199143566045`],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.9450158125329948, 0.9670907305400336, \
0.05040029871534907}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.9450158125329948, 0.9670907305400336, 0.05040029871534907]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.9450158125329948, 0.9670907305400336, 0.05040029871534907}],
      
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[
              0.9752641706478989, 0.8013981246170678, 0.10899973580393796`], 
              RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.650176113765266, 0.5342654164113786, 0.07266649053595864],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.9752641706478989, 0.8013981246170678, \
0.10899973580393796}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.9752641706478989, 0.8013981246170678, 0.10899973580393796`]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.9752641706478989, 0.8013981246170678, 0.10899973580393796`}],
      Editable->False,
      Selectable->False]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[
              0.8527294202095301, 0.15459949958575997`, 0.08139444813034824], 
              RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.5684862801396868, 0.10306633305717332`, 0.054262965420232165`],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.8527294202095301, 0.15459949958575997, \
0.08139444813034824}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.8527294202095301, 0.15459949958575997`, 0.08139444813034824]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.8527294202095301, 0.15459949958575997`, 
       0.08139444813034824}],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[
              0.9244703510275273, 0.001783470411052479, 0.14318146272477922`],
               RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.6163135673516849, 0.0011889802740349862`, 0.09545430848318615],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.9244703510275273, 0.001783470411052479, \
0.14318146272477922}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.9244703510275273, 0.001783470411052479, 0.14318146272477922`]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.9244703510275273, 0.001783470411052479, 
       0.14318146272477922`}],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[
              0.8340523614444824, 0.038129646837010533`, 0.09354464468116397],
               RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.5560349076296549, 0.025419764558007023`, 0.06236309645410931],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.8340523614444824, 0.038129646837010533, \
0.09354464468116397}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.8340523614444824, 0.038129646837010533`, 0.09354464468116397]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.8340523614444824, 0.038129646837010533`, 
       0.09354464468116397}],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[
              0.8543889209256321, 0.09697598692920356, 0.10750903324099509`], 
              RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.5695926139504215, 0.06465065795280238, 0.07167268882733006],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.8543889209256321, 0.09697598692920356, \
0.10750903324099509}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.8543889209256321, 0.09697598692920356, 0.10750903324099509`]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.8543889209256321, 0.09697598692920356, 
       0.10750903324099509`}],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[
              0.9573167308698426, 0.1507116093826361, 0.09832234398916928], 
              RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.6382111539132285, 0.10047440625509074`, 0.06554822932611286],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.9573167308698426, 0.1507116093826361, \
0.09832234398916928}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.9573167308698426, 0.1507116093826361, 0.09832234398916928]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.9573167308698426, 0.1507116093826361, 0.09832234398916928}],
      
      Editable->False,
      Selectable->False]}], "}"}]}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 GraphicsBoxOptions->{BaselinePosition->Scaled[0.1]},
 CellLabel->"Out[12]=",ExpressionUUID->"41495b31-bce5-44a3-a715-a1b82dae8aaa"]
}, Open  ]],

Cell["\<\
You can get a different view by connecting each color to the three most \
similar colors in the list, then making a graph out of the connections. In \
the particular example here, there end up being three disconnected subgraphs.\
\
\>", "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->
  "NearestNeighborGraph",ExpressionUUID->"c4ffd346-536d-41fe-9782-\
6c228e167a0b"],

Cell["\<\
Create a graph of connections based on nearness in \
\[OpenCurlyDoubleQuote]color space\[CloseCurlyDoubleQuote]:\
\>", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->{
  "graph-with-disconnected-parts", 
   "i:18"},ExpressionUUID->"7f061ea9-6eff-4ac7-9f94-19133ef933f2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"NearestNeighborGraph", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[
              0.048175746346922704`, 0.8856231902848692, 
               0.002187262571789972], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.0321171642312818, 0.5904154601899129, 0.0014581750478599813`],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.048175746346922704, 0.8856231902848692, \
0.002187262571789972}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.048175746346922704`, 0.8856231902848692, 0.002187262571789972]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.048175746346922704`, 0.8856231902848692, 
       0.002187262571789972}],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[
              0.9543437880041175, 0.9364915417894851, 0.08314980598714755], 
              RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.636229192002745, 0.6243276945263234, 0.0554332039914317],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.9543437880041175, 0.9364915417894851, \
0.08314980598714755}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.9543437880041175, 0.9364915417894851, 0.08314980598714755]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.9543437880041175, 0.9364915417894851, 0.08314980598714755}],
      
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[
              0.8527294202095301, 0.15459949958575997`, 0.08139444813034824], 
              RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.5684862801396868, 0.10306633305717332`, 0.054262965420232165`],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.8527294202095301, 0.15459949958575997, \
0.08139444813034824}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.8527294202095301, 0.15459949958575997`, 0.08139444813034824]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.8527294202095301, 0.15459949958575997`, 
       0.08139444813034824}],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[
              0.12965437429396431`, 0.8338364200576898, 0.16859742903104202`],
               RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.08643624952930955, 0.5558909467051265, 0.11239828602069468`],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.12965437429396431, 0.8338364200576898, \
0.16859742903104202}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.12965437429396431`, 0.8338364200576898, 0.16859742903104202`]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.12965437429396431`, 0.8338364200576898, 
       0.16859742903104202`}],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[
              0.14189318640501342`, 0.8685451286121387, 0.10426943556314977`],
               RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.09459545760334229, 0.5790300857414259, 0.06951295704209985],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.14189318640501342, 0.8685451286121387, \
0.10426943556314977}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.14189318640501342`, 0.8685451286121387, 0.10426943556314977`]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.14189318640501342`, 0.8685451286121387, 
       0.10426943556314977`}],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[
              0.9244703510275273, 0.001783470411052479, 0.14318146272477922`],
               RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.6163135673516849, 0.0011889802740349862`, 0.09545430848318615],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.9244703510275273, 0.001783470411052479, \
0.14318146272477922}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.9244703510275273, 0.001783470411052479, 0.14318146272477922`]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.9244703510275273, 0.001783470411052479, 
       0.14318146272477922`}],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[
              0.8340523614444824, 0.038129646837010533`, 0.09354464468116397],
               RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.5560349076296549, 0.025419764558007023`, 0.06236309645410931],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.8340523614444824, 0.038129646837010533, \
0.09354464468116397}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.8340523614444824, 0.038129646837010533`, 0.09354464468116397]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.8340523614444824, 0.038129646837010533`, 
       0.09354464468116397}],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[
              0.06423181065333894, 0.9361486399945784, 0.08411970647251821], 
              RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.042821207102225964`, 0.624099093329719, 0.05607980431501214],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.06423181065333894, 0.9361486399945784, \
0.08411970647251821}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.06423181065333894, 0.9361486399945784, 0.08411970647251821]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.06423181065333894, 0.9361486399945784, 0.08411970647251821}],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[
              0.8676164929883508, 0.8866580065099905, 0.024086278089002183`], 
              RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.5784109953255672, 0.5911053376733271, 0.016057518726001457`],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.8676164929883508, 0.8866580065099905, \
0.024086278089002183}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.8676164929883508, 0.8866580065099905, 0.024086278089002183`]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.8676164929883508, 0.8866580065099905, 
       0.024086278089002183`}],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[
              0.8577958146408966, 0.8374035340744639, 0.0071190816223388464`],
               RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.5718638764272644, 0.5582690227163093, 0.004746054414892564],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.8577958146408966, 0.8374035340744639, \
0.0071190816223388464}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.8577958146408966, 0.8374035340744639, 0.0071190816223388464`]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.8577958146408966, 0.8374035340744639, 
       0.0071190816223388464`}],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[
              0.9967431643372854, 0.969475575859666, 0.12251095291379577`], 
              RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.6644954428915236, 0.6463170505731107, 0.08167396860919718],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.9967431643372854, 0.969475575859666, \
0.12251095291379577}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.9967431643372854, 0.969475575859666, 0.12251095291379577`]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.9967431643372854, 0.969475575859666, 0.12251095291379577`}],
      
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[
              0.8543889209256321, 0.09697598692920356, 0.10750903324099509`], 
              RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.5695926139504215, 0.06465065795280238, 0.07167268882733006],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.8543889209256321, 0.09697598692920356, \
0.10750903324099509}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.8543889209256321, 0.09697598692920356, 0.10750903324099509`]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.8543889209256321, 0.09697598692920356, 
       0.10750903324099509`}],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[
              0.8500363984900003, 0.9263311671408848, 0.13924242858059316`], 
              RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.5666909323266669, 0.6175541114272566, 0.09282828572039545],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.8500363984900003, 0.9263311671408848, \
0.13924242858059316}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.8500363984900003, 0.9263311671408848, 0.13924242858059316`]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.8500363984900003, 0.9263311671408848, 0.13924242858059316`}],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[
              0.9879209034166253, 0.8377732017482453, 0.15613661869756118`], 
              RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.6586139356110836, 0.5585154678321635, 0.10409107913170745`],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.9879209034166253, 0.8377732017482453, \
0.15613661869756118}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.9879209034166253, 0.8377732017482453, 0.15613661869756118`]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.9879209034166253, 0.8377732017482453, 0.15613661869756118`}],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[
              0.9573167308698426, 0.1507116093826361, 0.09832234398916928], 
              RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.6382111539132285, 0.10047440625509074`, 0.06554822932611286],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.9573167308698426, 0.1507116093826361, \
0.09832234398916928}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.9573167308698426, 0.1507116093826361, 0.09832234398916928]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.9573167308698426, 0.1507116093826361, 0.09832234398916928}],
      
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[
              0.04278634258158939, 0.9055378427790535, 0.0003309996431954121],
               RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.028524228387726263`, 0.6036918951860357, 0.0002206664287969414],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.04278634258158939, 0.9055378427790535, \
0.0003309996431954121}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.04278634258158939, 0.9055378427790535, 0.0003309996431954121]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.04278634258158939, 0.9055378427790535, 
       0.0003309996431954121}],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[
              0.8058039405531526, 0.8318774133774354, 0.10151558699591279`], 
              RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.5372026270354351, 0.5545849422516236, 0.06767705799727519],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.8058039405531526, 0.8318774133774354, \
0.10151558699591279}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.8058039405531526, 0.8318774133774354, 0.10151558699591279`]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.8058039405531526, 0.8318774133774354, 0.10151558699591279`}],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[
              0.006814389873512461, 0.9336694049188562, 0.06907220235176909], 
              RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.004542926582341641, 0.6224462699459041, 0.04604813490117939],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.006814389873512461, 0.9336694049188562, \
0.06907220235176909}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.006814389873512461, 0.9336694049188562, 0.06907220235176909]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.006814389873512461, 0.9336694049188562, 
       0.06907220235176909}],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[
              0.9450158125329948, 0.9670907305400336, 0.05040029871534907], 
              RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.6300105416886632, 0.6447271536933558, 0.033600199143566045`],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.9450158125329948, 0.9670907305400336, \
0.05040029871534907}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.9450158125329948, 0.9670907305400336, 0.05040029871534907]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.9450158125329948, 0.9670907305400336, 0.05040029871534907}],
      
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[
              0.9752641706478989, 0.8013981246170678, 0.10899973580393796`], 
              RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.650176113765266, 0.5342654164113786, 0.07266649053595864],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.9752641706478989, 0.8013981246170678, \
0.10899973580393796}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.9752641706478989, 0.8013981246170678, 0.10899973580393796`]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.9752641706478989, 0.8013981246170678, 0.10899973580393796`}],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[
              0.16590548598015492`, 0.9015045495499641, 0.09828783196817376], 
              RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.11060365732010329`, 0.6010030330333094, 0.06552522131211584],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.16590548598015492, 0.9015045495499641, \
0.09828783196817376}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.16590548598015492`, 0.9015045495499641, 0.09828783196817376]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.16590548598015492`, 0.9015045495499641, 
       0.09828783196817376}],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[
              0.10048980936842117`, 0.9171495192304465, 0.16131399976146749`],
               RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[
          0.06699320624561411, 0.6114330128202977, 0.10754266650764499`],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[{0.10048980936842117, 0.9171495192304465, \
0.16131399976146749}]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = 
           RGBColor[
            0.10048980936842117`, 0.9171495192304465, 0.16131399976146749`]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[{0.10048980936842117`, 0.9171495192304465, 
       0.16131399976146749`}],
      Editable->False,
      Selectable->False]}], "}"}], ",", "3", ",", 
   RowBox[{"VertexLabels", "\[Rule]", "All"}]}], "]"}]], "Input",
 Deletable->False,
 GraphicsBoxOptions->{BaselinePosition->Scaled[0.1]},
 CellLabel->"In[13]:=",ExpressionUUID->"429adaa7-cf32-45a5-abcc-32f0fd8d5cef"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{
       RGBColor[{0.048175746346922704`, 0.8856231902848692, 
        0.002187262571789972}], 
       RGBColor[{0.9543437880041175, 0.9364915417894851, 
        0.08314980598714755}], 
       RGBColor[{0.8527294202095301, 0.15459949958575997`, 
        0.08139444813034824}], 
       RGBColor[{0.12965437429396431`, 0.8338364200576898, 
        0.16859742903104202`}], 
       RGBColor[{0.14189318640501342`, 0.8685451286121387, 
        0.10426943556314977`}], 
       RGBColor[{0.9244703510275273, 0.001783470411052479, 
        0.14318146272477922`}], 
       RGBColor[{0.8340523614444824, 0.038129646837010533`, 
        0.09354464468116397}], 
       RGBColor[{0.06423181065333894, 0.9361486399945784, 
        0.08411970647251821}], 
       RGBColor[{0.8676164929883508, 0.8866580065099905, 
        0.024086278089002183`}], 
       RGBColor[{0.8577958146408966, 0.8374035340744639, 
        0.0071190816223388464`}], 
       RGBColor[{0.9967431643372854, 0.969475575859666, 
        0.12251095291379577`}], 
       RGBColor[{0.8543889209256321, 0.09697598692920356, 
        0.10750903324099509`}], 
       RGBColor[{0.8500363984900003, 0.9263311671408848, 
        0.13924242858059316`}], 
       RGBColor[{0.9879209034166253, 0.8377732017482453, 
        0.15613661869756118`}], 
       RGBColor[{0.9573167308698426, 0.1507116093826361, 
        0.09832234398916928}], 
       RGBColor[{0.04278634258158939, 0.9055378427790535, 
        0.0003309996431954121}], 
       RGBColor[{0.8058039405531526, 0.8318774133774354, 
        0.10151558699591279`}], 
       RGBColor[{0.006814389873512461, 0.9336694049188562, 
        0.06907220235176909}], 
       RGBColor[{0.9450158125329948, 0.9670907305400336, 
        0.05040029871534907}], 
       RGBColor[{0.9752641706478989, 0.8013981246170678, 
        0.10899973580393796`}], 
       RGBColor[{0.16590548598015492`, 0.9015045495499641, 
        0.09828783196817376}], 
       RGBColor[{0.10048980936842117`, 0.9171495192304465, 
        0.16131399976146749`}]}, {Null, 
       SparseArray[
       Automatic, {22, 22}, 0, {
        1, {{0, 6, 12, 15, 18, 22, 25, 28, 31, 37, 42, 45, 49, 52, 55, 58, 63,
           66, 69, 73, 76, 81, 86}, {{5}, {8}, {16}, {18}, {21}, {22}, {9}, {
          10}, {11}, {14}, {19}, {20}, {7}, {12}, {15}, {5}, {21}, {22}, {
          1}, {4}, {21}, {22}, {7}, {12}, {15}, {3}, {6}, {12}, {1}, {16}, {
          18}, {2}, {10}, {11}, {13}, {17}, {19}, {2}, {9}, {14}, {17}, {
          20}, {2}, {9}, {19}, {3}, {6}, {7}, {15}, {9}, {17}, {19}, {2}, {
          10}, {20}, {3}, {6}, {12}, {1}, {8}, {18}, {21}, {22}, {9}, {10}, {
          13}, {1}, {8}, {16}, {2}, {9}, {11}, {13}, {2}, {10}, {14}, {1}, {
          4}, {5}, {16}, {22}, {1}, {4}, {5}, {16}, {21}}}, Pattern}]}, {
      VertexLabels -> {All}}]]}, 
    TagBox[GraphicsGroupBox[{{{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], {{{
              {Arrowheads[0.], 
               ArrowBox[{{1.6181134503584524`, -3.6792412719415104`}, {
                2.9049729069214085`, -3.427239245696992}}, 
                0.04390366136190131]}}}}, {{{
              {Arrowheads[0.], 
               ArrowBox[{{1.6181134503584524`, -3.6792412719415104`}, {
                0.4648511633541359, -4.2325440464552475`}}, 
                0.04390366136190131]}}}}, {{{
              {Arrowheads[0.], 
               ArrowBox[{{1.6181134503584524`, -3.6792412719415104`}, {
                1.3700266696218917`, -4.285764605039754}}, 
                0.04390366136190131]}}}}, {{{
              {Arrowheads[0.], 
               ArrowBox[{{1.6181134503584524`, -3.6792412719415104`}, {
                0.554186844464825, -3.5080754511825862`}}, 
                0.04390366136190131]}}}}, {{{
              {Arrowheads[0.], 
               ArrowBox[{{1.6181134503584524`, -3.6792412719415104`}, {
                2.5077218652244078`, -4.380316734568815}}, 
                0.04390366136190131]}}}}, {{{
              {Arrowheads[0.], 
               ArrowBox[{{1.6181134503584524`, -3.6792412719415104`}, {
                2.4353672087938216`, -3.839177553623694}}, 
                0.04390366136190131]}}}}, {{{
              {Arrowheads[0.], 
               ArrowBox[{{2.2253063918664857`, -1.1710411563987322`}, {
                1.3924101425548994`, -1.5665478470396907`}}, 
                0.04390366136190131]}}}}, {{{
              {Arrowheads[0.], 
               ArrowBox[{{2.2253063918664857`, -1.1710411563987322`}, {
                2.35378350863711, -1.995896708686483}}, 
                0.04390366136190131]}}}}, {{{
              {Arrowheads[0.], 
               ArrowBox[{{2.2253063918664857`, -1.1710411563987322`}, {
                1.5060840467800003`, -0.4648511633541359}}, 
                0.04390366136190131]}}}}, {{{
              {Arrowheads[0.], 
               ArrowBox[{{2.2253063918664857`, -1.1710411563987322`}, {
                3.2294827893937987`, -1.8961619949077049`}}, 
                0.04390366136190131]}}}}, {{{
              {Arrowheads[0.], 
               ArrowBox[{{2.2253063918664857`, -1.1710411563987322`}, {
                0.9602326263625951, -0.9849055396098816}}, 
                0.04390366136190131]}}}}, {{{
              {Arrowheads[0.], 
               ArrowBox[{{2.2253063918664857`, -1.1710411563987322`}, {
                3.223314906392934, -1.2651880018871549`}}, 
                0.04390366136190131]}}}}, {{{
              {Arrowheads[0.], 
               ArrowBox[{{5.583543421526646, -0.4648511633541359}, {
                5.615643053752226, -1.6184830560834866`}}, 
                0.04390366136190131]}}}}, {{{
              {Arrowheads[0.], 
               ArrowBox[{{5.583543421526646, -0.4648511633541359}, {
                5.022308187187053, -1.056787471678871}}, 
                0.04390366136190131]}}}}, {{{
              {Arrowheads[0.], 
               ArrowBox[{{5.583543421526646, -0.4648511633541359}, {
                4.4286179868869135`, -0.4947314325582979}}, 
                0.04390366136190131]}}}}, {{{
              {Arrowheads[0.], 
               ArrowBox[{{3.4989156601786418`, -4.095482422335041}, {
                2.9049729069214085`, -3.427239245696992}}, 
                0.04390366136190131]}}}}, {{{
              {Arrowheads[0.], 
               ArrowBox[{{3.4989156601786418`, -4.095482422335041}, {
                2.5077218652244078`, -4.380316734568815}}, 
                0.04390366136190131]}}}}, {{{
              {Arrowheads[0.], 
               ArrowBox[{{3.4989156601786418`, -4.095482422335041}, {
                2.4353672087938216`, -3.839177553623694}}, 
                0.04390366136190131]}}}}, {{{
              {Arrowheads[0.], 
               ArrowBox[{{2.9049729069214085`, -3.427239245696992}, {
                2.5077218652244078`, -4.380316734568815}}, 
                0.04390366136190131]}}}}, {{{
              {Arrowheads[0.], 
               ArrowBox[{{2.9049729069214085`, -3.427239245696992}, {
                2.4353672087938216`, -3.839177553623694}}, 
                0.04390366136190131]}}}}, {{{
              {Arrowheads[0.], 
               ArrowBox[{{4.461954271213614, -1.6495546496175093`}, {
                5.615643053752226, -1.6184830560834866`}}, 
                0.04390366136190131]}}}}, {{{
              {Arrowheads[0.], 
               ArrowBox[{{4.461954271213614, -1.6495546496175093`}, {
                5.022308187187053, -1.056787471678871}}, 
                0.04390366136190131]}}}}, {{{
              {Arrowheads[0.], 
               ArrowBox[{{4.461954271213614, -1.6495546496175093`}, {
                4.4286179868869135`, -0.4947314325582979}}, 
                0.04390366136190131]}}}}, {{{
              {Arrowheads[0.], 
               ArrowBox[{{5.615643053752226, -1.6184830560834866`}, {
                5.022308187187053, -1.056787471678871}}, 
                0.04390366136190131]}}}}, {{{
              {Arrowheads[0.], 
               ArrowBox[{{0.4648511633541359, -4.2325440464552475`}, {
                1.3700266696218917`, -4.285764605039754}}, 
                0.04390366136190131]}}}}, {{{
              {Arrowheads[0.], 
               ArrowBox[{{0.4648511633541359, -4.2325440464552475`}, {
                0.554186844464825, -3.5080754511825862`}}, 
                0.04390366136190131]}}}}, {{{
              {Arrowheads[0.], 
               ArrowBox[{{1.3924101425548994`, -1.5665478470396907`}, {
                2.35378350863711, -1.995896708686483}}, 
                0.04390366136190131]}}}}, {{{
              {Arrowheads[0.], 
               ArrowBox[{{1.3924101425548994`, -1.5665478470396907`}, {
                1.5060840467800003`, -0.4648511633541359}}, 
                0.04390366136190131]}}}}, {{{
              {Arrowheads[0.], 
               ArrowBox[{{1.3924101425548994`, -1.5665478470396907`}, {
                0.4648511633541359, -1.8964778601993966`}}, 
                0.04390366136190131]}}}}, {{{
              {Arrowheads[0.], 
               ArrowBox[{{1.3924101425548994`, -1.5665478470396907`}, {
                1.2626293529565484`, -2.49753691898872}}, 
                0.04390366136190131]}}}}, {{{
              {Arrowheads[0.], 
               ArrowBox[{{1.3924101425548994`, -1.5665478470396907`}, {
                0.9602326263625951, -0.9849055396098816}}, 
                0.04390366136190131]}}}}, {{{
              {Arrowheads[0.], 
               ArrowBox[{{2.35378350863711, -1.995896708686483}, {
                3.2294827893937987`, -1.8961619949077049`}}, 
                0.04390366136190131]}}}}, {{{
              {Arrowheads[0.], 
               ArrowBox[{{2.35378350863711, -1.995896708686483}, {
                1.2626293529565484`, -2.49753691898872}}, 
                0.04390366136190131]}}}}, {{{
              {Arrowheads[0.], 
               ArrowBox[{{2.35378350863711, -1.995896708686483}, {
                3.223314906392934, -1.2651880018871549`}}, 
                0.04390366136190131]}}}}, {{{
              {Arrowheads[0.], 
               ArrowBox[{{1.5060840467800003`, -0.4648511633541359}, {
                0.9602326263625951, -0.9849055396098816}}, 
                0.04390366136190131]}}}}, {{{
              {Arrowheads[0.], 
               ArrowBox[{{5.022308187187053, -1.056787471678871}, {
                4.4286179868869135`, -0.4947314325582979}}, 
                0.04390366136190131]}}}}, {{{
              {Arrowheads[0.], 
               ArrowBox[{{0.4648511633541359, -1.8964778601993966`}, {
                1.2626293529565484`, -2.49753691898872}}, 
                0.04390366136190131]}}}}, {{{
              {Arrowheads[0.], 
               ArrowBox[{{0.4648511633541359, -1.8964778601993966`}, {
                0.9602326263625951, -0.9849055396098816}}, 
                0.04390366136190131]}}}}, {{{
              {Arrowheads[0.], 
               ArrowBox[{{3.2294827893937987`, -1.8961619949077049`}, {
                3.223314906392934, -1.2651880018871549`}}, 
                0.04390366136190131]}}}}, {{{
              {Arrowheads[0.], 
               ArrowBox[{{1.3700266696218917`, -4.285764605039754}, {
                0.554186844464825, -3.5080754511825862`}}, 
                0.04390366136190131]}}}}, {{{
              {Arrowheads[0.], 
               ArrowBox[{{1.3700266696218917`, -4.285764605039754}, {
                2.5077218652244078`, -4.380316734568815}}, 
                0.04390366136190131]}}}}, {{{
              {Arrowheads[0.], 
               ArrowBox[{{1.3700266696218917`, -4.285764605039754}, {
                2.4353672087938216`, -3.839177553623694}}, 
                0.04390366136190131]}}}}, {{{
              {Arrowheads[0.], 
               ArrowBox[{{2.5077218652244078`, -4.380316734568815}, {
                2.4353672087938216`, -3.839177553623694}}, 
                0.04390366136190131]}}}}}}}}, {{{
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {
            DiskBox[{1.6181134503584524, -3.6792412719415104}, 
             0.04390366136190131], InsetBox[
             InterpretationBox[
              ButtonBox[
               TooltipBox[
                GraphicsBox[{{{{
                    {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                    {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                    {RGBColor[
                    0.048175746346922704`, 0.8856231902848692, 
                    0.002187262571789972], RectangleBox[{0, -1}, {2, 1}]}}}}},
                 
                 AspectRatio->1,
                 Frame->True,
                 
                 FrameStyle->RGBColor[
                  0.0321171642312818, 0.5904154601899129, 
                   0.0014581750478599813`],
                 FrameTicks->None,
                 
                 ImageSize->
                  Dynamic[{
                   Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}],
                 PlotRangePadding->None],
                
                "RGBColor[{0.048175746346922704, 0.8856231902848692, \
0.002187262571789972}]"],
               Appearance->None,
               BaseStyle->{},
               BaselinePosition->Baseline,
               ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
                 If[
                  Not[
                   AbsoluteCurrentValue["Deployed"]], 
                  SelectionMove[Typeset`box$, All, Expression]; 
                  FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                  FrontEnd`Private`$ColorSelectorInitialColor = 
                   RGBColor[
                    0.048175746346922704`, 0.8856231902848692, 
                    0.002187262571789972]; 
                  FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                  MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
               DefaultBaseStyle->{},
               Evaluator->Automatic,
               Method->"Preemptive"],
              
              RGBColor[{0.048175746346922704`, 0.8856231902848692, 
               0.002187262571789972}],
              Editable->False,
              Selectable->False], 
             Offset[{2, 2}, {1.6620171117203537, -3.635337610579609}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{2.2253063918664857, -1.1710411563987322}, 
             0.04390366136190131], InsetBox[
             InterpretationBox[
              ButtonBox[
               TooltipBox[
                GraphicsBox[{{{{
                    {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                    {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                    {RGBColor[
                    0.9543437880041175, 0.9364915417894851, 
                    0.08314980598714755], RectangleBox[{0, -1}, {2, 1}]}}}}},
                 AspectRatio->1,
                 Frame->True,
                 
                 FrameStyle->RGBColor[
                  0.636229192002745, 0.6243276945263234, 0.0554332039914317],
                 FrameTicks->None,
                 
                 ImageSize->
                  Dynamic[{
                   Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}],
                 PlotRangePadding->None],
                
                "RGBColor[{0.9543437880041175, 0.9364915417894851, \
0.08314980598714755}]"],
               Appearance->None,
               BaseStyle->{},
               BaselinePosition->Baseline,
               ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
                 If[
                  Not[
                   AbsoluteCurrentValue["Deployed"]], 
                  SelectionMove[Typeset`box$, All, Expression]; 
                  FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                  FrontEnd`Private`$ColorSelectorInitialColor = 
                   RGBColor[
                    0.9543437880041175, 0.9364915417894851, 
                    0.08314980598714755]; 
                  FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                  MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
               DefaultBaseStyle->{},
               Evaluator->Automatic,
               Method->"Preemptive"],
              
              RGBColor[{0.9543437880041175, 0.9364915417894851, 
               0.08314980598714755}],
              Editable->False,
              Selectable->False], 
             Offset[{2, 2}, {2.269210053228387, -1.127137495036831}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{5.583543421526646, -0.4648511633541359}, 
             0.04390366136190131], InsetBox[
             InterpretationBox[
              ButtonBox[
               TooltipBox[
                GraphicsBox[{{{{
                    {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                    {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                    {RGBColor[
                    0.8527294202095301, 0.15459949958575997`, 
                    0.08139444813034824], RectangleBox[{0, -1}, {2, 1}]}}}}},
                 AspectRatio->1,
                 Frame->True,
                 
                 FrameStyle->RGBColor[
                  0.5684862801396868, 0.10306633305717332`, 
                   0.054262965420232165`],
                 FrameTicks->None,
                 
                 ImageSize->
                  Dynamic[{
                   Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}],
                 PlotRangePadding->None],
                
                "RGBColor[{0.8527294202095301, 0.15459949958575997, \
0.08139444813034824}]"],
               Appearance->None,
               BaseStyle->{},
               BaselinePosition->Baseline,
               ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
                 If[
                  Not[
                   AbsoluteCurrentValue["Deployed"]], 
                  SelectionMove[Typeset`box$, All, Expression]; 
                  FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                  FrontEnd`Private`$ColorSelectorInitialColor = 
                   RGBColor[
                    0.8527294202095301, 0.15459949958575997`, 
                    0.08139444813034824]; 
                  FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                  MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
               DefaultBaseStyle->{},
               Evaluator->Automatic,
               Method->"Preemptive"],
              
              RGBColor[{0.8527294202095301, 0.15459949958575997`, 
               0.08139444813034824}],
              Editable->False,
              Selectable->False], 
             Offset[{2, 2}, {5.627447082888548, -0.4209475019922346}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{3.4989156601786418, -4.095482422335041}, 
             0.04390366136190131], InsetBox[
             InterpretationBox[
              ButtonBox[
               TooltipBox[
                GraphicsBox[{{{{
                    {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                    {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                    {RGBColor[
                    0.12965437429396431`, 0.8338364200576898, 
                    0.16859742903104202`], RectangleBox[{0, -1}, {2, 1}]}}}}},
                 
                 AspectRatio->1,
                 Frame->True,
                 
                 FrameStyle->RGBColor[
                  0.08643624952930955, 0.5558909467051265, 
                   0.11239828602069468`],
                 FrameTicks->None,
                 
                 ImageSize->
                  Dynamic[{
                   Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}],
                 PlotRangePadding->None],
                
                "RGBColor[{0.12965437429396431, 0.8338364200576898, \
0.16859742903104202}]"],
               Appearance->None,
               BaseStyle->{},
               BaselinePosition->Baseline,
               ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
                 If[
                  Not[
                   AbsoluteCurrentValue["Deployed"]], 
                  SelectionMove[Typeset`box$, All, Expression]; 
                  FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                  FrontEnd`Private`$ColorSelectorInitialColor = 
                   RGBColor[
                    0.12965437429396431`, 0.8338364200576898, 
                    0.16859742903104202`]; 
                  FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                  MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
               DefaultBaseStyle->{},
               Evaluator->Automatic,
               Method->"Preemptive"],
              
              RGBColor[{0.12965437429396431`, 0.8338364200576898, 
               0.16859742903104202`}],
              Editable->False,
              Selectable->False], 
             Offset[{2, 2}, {3.5428193215405432, -4.05157876097314}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{2.9049729069214085, -3.427239245696992}, 
             0.04390366136190131], InsetBox[
             InterpretationBox[
              ButtonBox[
               TooltipBox[
                GraphicsBox[{{{{
                    {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                    {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                    {RGBColor[
                    0.14189318640501342`, 0.8685451286121387, 
                    0.10426943556314977`], RectangleBox[{0, -1}, {2, 1}]}}}}},
                 
                 AspectRatio->1,
                 Frame->True,
                 
                 FrameStyle->RGBColor[
                  0.09459545760334229, 0.5790300857414259, 
                   0.06951295704209985],
                 FrameTicks->None,
                 ImageSize->
                  Dynamic[{
                   Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}],
                 PlotRangePadding->None],
                
                "RGBColor[{0.14189318640501342, 0.8685451286121387, \
0.10426943556314977}]"],
               Appearance->None,
               BaseStyle->{},
               BaselinePosition->Baseline,
               ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
                 If[
                  Not[
                   AbsoluteCurrentValue["Deployed"]], 
                  SelectionMove[Typeset`box$, All, Expression]; 
                  FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                  FrontEnd`Private`$ColorSelectorInitialColor = 
                   RGBColor[
                    0.14189318640501342`, 0.8685451286121387, 
                    0.10426943556314977`]; 
                  FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                  MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
               DefaultBaseStyle->{},
               Evaluator->Automatic,
               Method->"Preemptive"],
              
              RGBColor[{0.14189318640501342`, 0.8685451286121387, 
               0.10426943556314977`}],
              Editable->False,
              Selectable->False], 
             Offset[{2, 2}, {2.94887656828331, -3.3833355843350903}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{4.461954271213614, -1.6495546496175093}, 
             0.04390366136190131], InsetBox[
             InterpretationBox[
              ButtonBox[
               TooltipBox[
                GraphicsBox[{{{{
                    {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                    {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                    {RGBColor[
                    0.9244703510275273, 0.001783470411052479, 
                    0.14318146272477922`], RectangleBox[{0, -1}, {2, 1}]}}}}},
                 
                 AspectRatio->1,
                 Frame->True,
                 
                 FrameStyle->RGBColor[
                  0.6163135673516849, 0.0011889802740349862`, 
                   0.09545430848318615],
                 FrameTicks->None,
                 
                 ImageSize->
                  Dynamic[{
                   Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}],
                 PlotRangePadding->None],
                
                "RGBColor[{0.9244703510275273, 0.001783470411052479, \
0.14318146272477922}]"],
               Appearance->None,
               BaseStyle->{},
               BaselinePosition->Baseline,
               ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
                 If[
                  Not[
                   AbsoluteCurrentValue["Deployed"]], 
                  SelectionMove[Typeset`box$, All, Expression]; 
                  FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                  FrontEnd`Private`$ColorSelectorInitialColor = 
                   RGBColor[
                    0.9244703510275273, 0.001783470411052479, 
                    0.14318146272477922`]; 
                  FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                  MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
               DefaultBaseStyle->{},
               Evaluator->Automatic,
               Method->"Preemptive"],
              
              RGBColor[{0.9244703510275273, 0.001783470411052479, 
               0.14318146272477922`}],
              Editable->False,
              Selectable->False], 
             Offset[{2, 2}, {4.505857932575515, -1.605650988255608}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{5.615643053752226, -1.6184830560834866}, 
             0.04390366136190131], InsetBox[
             InterpretationBox[
              ButtonBox[
               TooltipBox[
                GraphicsBox[{{{{
                    {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                    {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                    {RGBColor[
                    0.8340523614444824, 0.038129646837010533`, 
                    0.09354464468116397], RectangleBox[{0, -1}, {2, 1}]}}}}},
                 AspectRatio->1,
                 Frame->True,
                 
                 FrameStyle->RGBColor[
                  0.5560349076296549, 0.025419764558007023`, 
                   0.06236309645410931],
                 FrameTicks->None,
                 
                 ImageSize->
                  Dynamic[{
                   Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}],
                 PlotRangePadding->None],
                
                "RGBColor[{0.8340523614444824, 0.038129646837010533, \
0.09354464468116397}]"],
               Appearance->None,
               BaseStyle->{},
               BaselinePosition->Baseline,
               ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
                 If[
                  Not[
                   AbsoluteCurrentValue["Deployed"]], 
                  SelectionMove[Typeset`box$, All, Expression]; 
                  FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                  FrontEnd`Private`$ColorSelectorInitialColor = 
                   RGBColor[
                    0.8340523614444824, 0.038129646837010533`, 
                    0.09354464468116397]; 
                  FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                  MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
               DefaultBaseStyle->{},
               Evaluator->Automatic,
               Method->"Preemptive"],
              
              RGBColor[{0.8340523614444824, 0.038129646837010533`, 
               0.09354464468116397}],
              Editable->False,
              Selectable->False], 
             Offset[{2, 2}, {5.659546715114128, -1.5745793947215854}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0.4648511633541359, -4.2325440464552475}, 
             0.04390366136190131], InsetBox[
             InterpretationBox[
              ButtonBox[
               TooltipBox[
                GraphicsBox[{{{{
                    {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                    {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                    {RGBColor[
                    0.06423181065333894, 0.9361486399945784, 
                    0.08411970647251821], RectangleBox[{0, -1}, {2, 1}]}}}}},
                 AspectRatio->1,
                 Frame->True,
                 
                 FrameStyle->RGBColor[
                  0.042821207102225964`, 0.624099093329719, 
                   0.05607980431501214],
                 FrameTicks->None,
                 
                 ImageSize->
                  Dynamic[{
                   Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}],
                 PlotRangePadding->None],
                
                "RGBColor[{0.06423181065333894, 0.9361486399945784, \
0.08411970647251821}]"],
               Appearance->None,
               BaseStyle->{},
               BaselinePosition->Baseline,
               ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
                 If[
                  Not[
                   AbsoluteCurrentValue["Deployed"]], 
                  SelectionMove[Typeset`box$, All, Expression]; 
                  FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                  FrontEnd`Private`$ColorSelectorInitialColor = 
                   RGBColor[
                    0.06423181065333894, 0.9361486399945784, 
                    0.08411970647251821]; 
                  FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                  MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
               DefaultBaseStyle->{},
               Evaluator->Automatic,
               Method->"Preemptive"],
              
              RGBColor[{0.06423181065333894, 0.9361486399945784, 
               0.08411970647251821}],
              Editable->False,
              Selectable->False], 
             Offset[{2, 2}, {0.5087548247160372, -4.188640385093346}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1.3924101425548994, -1.5665478470396907}, 
             0.04390366136190131], InsetBox[
             InterpretationBox[
              ButtonBox[
               TooltipBox[
                GraphicsBox[{{{{
                    {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                    {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                    {RGBColor[
                    0.8676164929883508, 0.8866580065099905, 
                    0.024086278089002183`], RectangleBox[{0, -1}, {2, 1}]}}}}},
                 AspectRatio->1,
                 Frame->True,
                 
                 FrameStyle->RGBColor[
                  0.5784109953255672, 0.5911053376733271, 
                   0.016057518726001457`],
                 FrameTicks->None,
                 
                 ImageSize->
                  Dynamic[{
                   Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}],
                 PlotRangePadding->None],
                
                "RGBColor[{0.8676164929883508, 0.8866580065099905, \
0.024086278089002183}]"],
               Appearance->None,
               BaseStyle->{},
               BaselinePosition->Baseline,
               ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
                 If[
                  Not[
                   AbsoluteCurrentValue["Deployed"]], 
                  SelectionMove[Typeset`box$, All, Expression]; 
                  FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                  FrontEnd`Private`$ColorSelectorInitialColor = 
                   RGBColor[
                    0.8676164929883508, 0.8866580065099905, 
                    0.024086278089002183`]; 
                  FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                  MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
               DefaultBaseStyle->{},
               Evaluator->Automatic,
               Method->"Preemptive"],
              
              RGBColor[{0.8676164929883508, 0.8866580065099905, 
               0.024086278089002183`}],
              Editable->False,
              Selectable->False], 
             Offset[{2, 2}, {1.4363138039168006, -1.5226441856777895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{2.35378350863711, -1.995896708686483}, 
             0.04390366136190131], InsetBox[
             InterpretationBox[
              ButtonBox[
               TooltipBox[
                GraphicsBox[{{{{
                    {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                    {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                    {RGBColor[
                    0.8577958146408966, 0.8374035340744639, 
                    0.0071190816223388464`], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}},
                 AspectRatio->1,
                 Frame->True,
                 
                 FrameStyle->RGBColor[
                  0.5718638764272644, 0.5582690227163093, 
                   0.004746054414892564],
                 FrameTicks->None,
                 
                 ImageSize->
                  Dynamic[{
                   Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}],
                 PlotRangePadding->None],
                
                "RGBColor[{0.8577958146408966, 0.8374035340744639, \
0.0071190816223388464}]"],
               Appearance->None,
               BaseStyle->{},
               BaselinePosition->Baseline,
               ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
                 If[
                  Not[
                   AbsoluteCurrentValue["Deployed"]], 
                  SelectionMove[Typeset`box$, All, Expression]; 
                  FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                  FrontEnd`Private`$ColorSelectorInitialColor = 
                   RGBColor[
                    0.8577958146408966, 0.8374035340744639, 
                    0.0071190816223388464`]; 
                  FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                  MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
               DefaultBaseStyle->{},
               Evaluator->Automatic,
               Method->"Preemptive"],
              
              RGBColor[{0.8577958146408966, 0.8374035340744639, 
               0.0071190816223388464`}],
              Editable->False,
              Selectable->False], 
             Offset[{2, 2}, {2.3976871699990117, -1.9519930473245817}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1.5060840467800003, -0.4648511633541359}, 
             0.04390366136190131], InsetBox[
             InterpretationBox[
              ButtonBox[
               TooltipBox[
                GraphicsBox[{{{{
                    {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                    {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                    {RGBColor[
                    0.9967431643372854, 0.969475575859666, 
                    0.12251095291379577`], RectangleBox[{0, -1}, {2, 1}]}}}}},
                 
                 AspectRatio->1,
                 Frame->True,
                 
                 FrameStyle->RGBColor[
                  0.6644954428915236, 0.6463170505731107, 0.08167396860919718],
                 FrameTicks->None,
                 
                 ImageSize->
                  Dynamic[{
                   Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}],
                 PlotRangePadding->None],
                
                "RGBColor[{0.9967431643372854, 0.969475575859666, \
0.12251095291379577}]"],
               Appearance->None,
               BaseStyle->{},
               BaselinePosition->Baseline,
               ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
                 If[
                  Not[
                   AbsoluteCurrentValue["Deployed"]], 
                  SelectionMove[Typeset`box$, All, Expression]; 
                  FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                  FrontEnd`Private`$ColorSelectorInitialColor = 
                   RGBColor[
                    0.9967431643372854, 0.969475575859666, 
                    0.12251095291379577`]; 
                  FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                  MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
               DefaultBaseStyle->{},
               Evaluator->Automatic,
               Method->"Preemptive"],
              
              RGBColor[{0.9967431643372854, 0.969475575859666, 
               0.12251095291379577`}],
              Editable->False,
              Selectable->False], 
             Offset[{2, 2}, {1.5499877081419016, -0.4209475019922346}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{5.022308187187053, -1.056787471678871}, 
             0.04390366136190131], InsetBox[
             InterpretationBox[
              ButtonBox[
               TooltipBox[
                GraphicsBox[{{{{
                    {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                    {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                    {RGBColor[
                    0.8543889209256321, 0.09697598692920356, 
                    0.10750903324099509`], RectangleBox[{0, -1}, {2, 1}]}}}}},
                 
                 AspectRatio->1,
                 Frame->True,
                 
                 FrameStyle->RGBColor[
                  0.5695926139504215, 0.06465065795280238, 
                   0.07167268882733006],
                 FrameTicks->None,
                 
                 ImageSize->
                  Dynamic[{
                   Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}],
                 PlotRangePadding->None],
                
                "RGBColor[{0.8543889209256321, 0.09697598692920356, \
0.10750903324099509}]"],
               Appearance->None,
               BaseStyle->{},
               BaselinePosition->Baseline,
               ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
                 If[
                  Not[
                   AbsoluteCurrentValue["Deployed"]], 
                  SelectionMove[Typeset`box$, All, Expression]; 
                  FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                  FrontEnd`Private`$ColorSelectorInitialColor = 
                   RGBColor[
                    0.8543889209256321, 0.09697598692920356, 
                    0.10750903324099509`]; 
                  FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                  MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
               DefaultBaseStyle->{},
               Evaluator->Automatic,
               Method->"Preemptive"],
              
              RGBColor[{0.8543889209256321, 0.09697598692920356, 
               0.10750903324099509`}],
              Editable->False,
              Selectable->False], 
             Offset[{2, 2}, {5.066211848548955, -1.0128838103169697}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0.4648511633541359, -1.8964778601993966}, 
             0.04390366136190131], InsetBox[
             InterpretationBox[
              ButtonBox[
               TooltipBox[
                GraphicsBox[{{{{
                    {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                    {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                    {RGBColor[
                    0.8500363984900003, 0.9263311671408848, 
                    0.13924242858059316`], RectangleBox[{0, -1}, {2, 1}]}}}}},
                 
                 AspectRatio->1,
                 Frame->True,
                 
                 FrameStyle->RGBColor[
                  0.5666909323266669, 0.6175541114272566, 0.09282828572039545],
                 FrameTicks->None,
                 
                 ImageSize->
                  Dynamic[{
                   Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}],
                 PlotRangePadding->None],
                
                "RGBColor[{0.8500363984900003, 0.9263311671408848, \
0.13924242858059316}]"],
               Appearance->None,
               BaseStyle->{},
               BaselinePosition->Baseline,
               ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
                 If[
                  Not[
                   AbsoluteCurrentValue["Deployed"]], 
                  SelectionMove[Typeset`box$, All, Expression]; 
                  FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                  FrontEnd`Private`$ColorSelectorInitialColor = 
                   RGBColor[
                    0.8500363984900003, 0.9263311671408848, 
                    0.13924242858059316`]; 
                  FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                  MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
               DefaultBaseStyle->{},
               Evaluator->Automatic,
               Method->"Preemptive"],
              
              RGBColor[{0.8500363984900003, 0.9263311671408848, 
               0.13924242858059316`}],
              Editable->False,
              Selectable->False], 
             Offset[{2, 2}, {0.5087548247160372, -1.8525741988374953}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{3.2294827893937987, -1.8961619949077049}, 
             0.04390366136190131], InsetBox[
             InterpretationBox[
              ButtonBox[
               TooltipBox[
                GraphicsBox[{{{{
                    {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                    {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                    {RGBColor[
                    0.9879209034166253, 0.8377732017482453, 
                    0.15613661869756118`], RectangleBox[{0, -1}, {2, 1}]}}}}},
                 
                 AspectRatio->1,
                 Frame->True,
                 
                 FrameStyle->RGBColor[
                  0.6586139356110836, 0.5585154678321635, 
                   0.10409107913170745`],
                 FrameTicks->None,
                 
                 ImageSize->
                  Dynamic[{
                   Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}],
                 PlotRangePadding->None],
                
                "RGBColor[{0.9879209034166253, 0.8377732017482453, \
0.15613661869756118}]"],
               Appearance->None,
               BaseStyle->{},
               BaselinePosition->Baseline,
               ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
                 If[
                  Not[
                   AbsoluteCurrentValue["Deployed"]], 
                  SelectionMove[Typeset`box$, All, Expression]; 
                  FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                  FrontEnd`Private`$ColorSelectorInitialColor = 
                   RGBColor[
                    0.9879209034166253, 0.8377732017482453, 
                    0.15613661869756118`]; 
                  FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                  MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
               DefaultBaseStyle->{},
               Evaluator->Automatic,
               Method->"Preemptive"],
              
              RGBColor[{0.9879209034166253, 0.8377732017482453, 
               0.15613661869756118`}],
              Editable->False,
              Selectable->False], 
             Offset[{2, 2}, {3.2733864507557002, -1.8522583335458036}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{4.4286179868869135, -0.4947314325582979}, 
             0.04390366136190131], InsetBox[
             InterpretationBox[
              ButtonBox[
               TooltipBox[
                GraphicsBox[{{{{
                    {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                    {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                    {RGBColor[
                    0.9573167308698426, 0.1507116093826361, 
                    0.09832234398916928], RectangleBox[{0, -1}, {2, 1}]}}}}},
                 AspectRatio->1,
                 Frame->True,
                 
                 FrameStyle->RGBColor[
                  0.6382111539132285, 0.10047440625509074`, 
                   0.06554822932611286],
                 FrameTicks->None,
                 
                 ImageSize->
                  Dynamic[{
                   Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}],
                 PlotRangePadding->None],
                
                "RGBColor[{0.9573167308698426, 0.1507116093826361, \
0.09832234398916928}]"],
               Appearance->None,
               BaseStyle->{},
               BaselinePosition->Baseline,
               ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
                 If[
                  Not[
                   AbsoluteCurrentValue["Deployed"]], 
                  SelectionMove[Typeset`box$, All, Expression]; 
                  FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                  FrontEnd`Private`$ColorSelectorInitialColor = 
                   RGBColor[
                    0.9573167308698426, 0.1507116093826361, 
                    0.09832234398916928]; 
                  FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                  MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
               DefaultBaseStyle->{},
               Evaluator->Automatic,
               Method->"Preemptive"],
              
              RGBColor[{0.9573167308698426, 0.1507116093826361, 
               0.09832234398916928}],
              Editable->False,
              Selectable->False], 
             Offset[{2, 2}, {4.472521648248815, -0.45082777119639655}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1.3700266696218917, -4.285764605039754}, 
             0.04390366136190131], InsetBox[
             InterpretationBox[
              ButtonBox[
               TooltipBox[
                GraphicsBox[{{{{
                    {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                    {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                    {RGBColor[
                    0.04278634258158939, 0.9055378427790535, 
                    0.0003309996431954121], RectangleBox[{0, -1}, {2, 1}]}}}}},
                 AspectRatio->1,
                 Frame->True,
                 
                 FrameStyle->RGBColor[
                  0.028524228387726263`, 0.6036918951860357, 
                   0.0002206664287969414],
                 FrameTicks->None,
                 
                 ImageSize->
                  Dynamic[{
                   Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}],
                 PlotRangePadding->None],
                
                "RGBColor[{0.04278634258158939, 0.9055378427790535, \
0.0003309996431954121}]"],
               Appearance->None,
               BaseStyle->{},
               BaselinePosition->Baseline,
               ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
                 If[
                  Not[
                   AbsoluteCurrentValue["Deployed"]], 
                  SelectionMove[Typeset`box$, All, Expression]; 
                  FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                  FrontEnd`Private`$ColorSelectorInitialColor = 
                   RGBColor[
                    0.04278634258158939, 0.9055378427790535, 
                    0.0003309996431954121]; 
                  FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                  MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
               DefaultBaseStyle->{},
               Evaluator->Automatic,
               Method->"Preemptive"],
              
              RGBColor[{0.04278634258158939, 0.9055378427790535, 
               0.0003309996431954121}],
              Editable->False,
              Selectable->False], Offset[{2, 2}, 
             {1.413930330983793, -4.241860943677852}], ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1.2626293529565484, -2.49753691898872}, 
             0.04390366136190131], InsetBox[
             InterpretationBox[
              ButtonBox[
               TooltipBox[
                GraphicsBox[{{{{
                    {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                    {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                    {RGBColor[
                    0.8058039405531526, 0.8318774133774354, 
                    0.10151558699591279`], RectangleBox[{0, -1}, {2, 1}]}}}}},
                 
                 AspectRatio->1,
                 Frame->True,
                 
                 FrameStyle->RGBColor[
                  0.5372026270354351, 0.5545849422516236, 0.06767705799727519],
                 FrameTicks->None,
                 
                 ImageSize->
                  Dynamic[{
                   Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}],
                 PlotRangePadding->None],
                
                "RGBColor[{0.8058039405531526, 0.8318774133774354, \
0.10151558699591279}]"],
               Appearance->None,
               BaseStyle->{},
               BaselinePosition->Baseline,
               ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
                 If[
                  Not[
                   AbsoluteCurrentValue["Deployed"]], 
                  SelectionMove[Typeset`box$, All, Expression]; 
                  FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                  FrontEnd`Private`$ColorSelectorInitialColor = 
                   RGBColor[
                    0.8058039405531526, 0.8318774133774354, 
                    0.10151558699591279`]; 
                  FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                  MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
               DefaultBaseStyle->{},
               Evaluator->Automatic,
               Method->"Preemptive"],
              
              RGBColor[{0.8058039405531526, 0.8318774133774354, 
               0.10151558699591279`}],
              Editable->False,
              Selectable->False], 
             Offset[{2, 2}, {1.3065330143184497, -2.4536332576268185}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0.554186844464825, -3.5080754511825862}, 
             0.04390366136190131], InsetBox[
             InterpretationBox[
              ButtonBox[
               TooltipBox[
                GraphicsBox[{{{{
                    {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                    {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                    {RGBColor[
                    0.006814389873512461, 0.9336694049188562, 
                    0.06907220235176909], RectangleBox[{0, -1}, {2, 1}]}}}}},
                 AspectRatio->1,
                 Frame->True,
                 
                 FrameStyle->RGBColor[
                  0.004542926582341641, 0.6224462699459041, 
                   0.04604813490117939],
                 FrameTicks->None,
                 
                 ImageSize->
                  Dynamic[{
                   Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}],
                 PlotRangePadding->None],
                
                "RGBColor[{0.006814389873512461, 0.9336694049188562, \
0.06907220235176909}]"],
               Appearance->None,
               BaseStyle->{},
               BaselinePosition->Baseline,
               ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
                 If[
                  Not[
                   AbsoluteCurrentValue["Deployed"]], 
                  SelectionMove[Typeset`box$, All, Expression]; 
                  FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                  FrontEnd`Private`$ColorSelectorInitialColor = 
                   RGBColor[
                    0.006814389873512461, 0.9336694049188562, 
                    0.06907220235176909]; 
                  FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                  MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
               DefaultBaseStyle->{},
               Evaluator->Automatic,
               Method->"Preemptive"],
              
              RGBColor[{0.006814389873512461, 0.9336694049188562, 
               0.06907220235176909}],
              Editable->False,
              Selectable->False], 
             Offset[{2, 2}, {0.5980905058267263, -3.4641717898206847}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0.9602326263625951, -0.9849055396098816}, 
             0.04390366136190131], InsetBox[
             InterpretationBox[
              ButtonBox[
               TooltipBox[
                GraphicsBox[{{{{
                    {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                    {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                    {RGBColor[
                    0.9450158125329948, 0.9670907305400336, 
                    0.05040029871534907], RectangleBox[{0, -1}, {2, 1}]}}}}},
                 AspectRatio->1,
                 Frame->True,
                 
                 FrameStyle->RGBColor[
                  0.6300105416886632, 0.6447271536933558, 
                   0.033600199143566045`],
                 FrameTicks->None,
                 
                 ImageSize->
                  Dynamic[{
                   Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}],
                 PlotRangePadding->None],
                
                "RGBColor[{0.9450158125329948, 0.9670907305400336, \
0.05040029871534907}]"],
               Appearance->None,
               BaseStyle->{},
               BaselinePosition->Baseline,
               ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
                 If[
                  Not[
                   AbsoluteCurrentValue["Deployed"]], 
                  SelectionMove[Typeset`box$, All, Expression]; 
                  FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                  FrontEnd`Private`$ColorSelectorInitialColor = 
                   RGBColor[
                    0.9450158125329948, 0.9670907305400336, 
                    0.05040029871534907]; 
                  FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                  MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
               DefaultBaseStyle->{},
               Evaluator->Automatic,
               Method->"Preemptive"],
              
              RGBColor[{0.9450158125329948, 0.9670907305400336, 
               0.05040029871534907}],
              Editable->False,
              Selectable->False], 
             Offset[{2, 2}, {1.0041362877244964, -0.9410018782479803}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{3.223314906392934, -1.2651880018871549}, 
             0.04390366136190131], InsetBox[
             InterpretationBox[
              ButtonBox[
               TooltipBox[
                GraphicsBox[{{{{
                    {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                    {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                    {RGBColor[
                    0.9752641706478989, 0.8013981246170678, 
                    0.10899973580393796`], RectangleBox[{0, -1}, {2, 1}]}}}}},
                 
                 AspectRatio->1,
                 Frame->True,
                 
                 FrameStyle->RGBColor[
                  0.650176113765266, 0.5342654164113786, 0.07266649053595864],
                 
                 FrameTicks->None,
                 
                 ImageSize->
                  Dynamic[{
                   Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}],
                 PlotRangePadding->None],
                
                "RGBColor[{0.9752641706478989, 0.8013981246170678, \
0.10899973580393796}]"],
               Appearance->None,
               BaseStyle->{},
               BaselinePosition->Baseline,
               ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
                 If[
                  Not[
                   AbsoluteCurrentValue["Deployed"]], 
                  SelectionMove[Typeset`box$, All, Expression]; 
                  FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                  FrontEnd`Private`$ColorSelectorInitialColor = 
                   RGBColor[
                    0.9752641706478989, 0.8013981246170678, 
                    0.10899973580393796`]; 
                  FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                  MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
               DefaultBaseStyle->{},
               Evaluator->Automatic,
               Method->"Preemptive"],
              
              RGBColor[{0.9752641706478989, 0.8013981246170678, 
               0.10899973580393796`}],
              Editable->False,
              Selectable->False], 
             Offset[{2, 2}, {3.2672185677548353, -1.2212843405252536}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{2.5077218652244078, -4.380316734568815}, 
             0.04390366136190131], InsetBox[
             InterpretationBox[
              ButtonBox[
               TooltipBox[
                GraphicsBox[{{{{
                    {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                    {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                    {RGBColor[
                    0.16590548598015492`, 0.9015045495499641, 
                    0.09828783196817376], RectangleBox[{0, -1}, {2, 1}]}}}}},
                 AspectRatio->1,
                 Frame->True,
                 
                 FrameStyle->RGBColor[
                  0.11060365732010329`, 0.6010030330333094, 
                   0.06552522131211584],
                 FrameTicks->None,
                 
                 ImageSize->
                  Dynamic[{
                   Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}],
                 PlotRangePadding->None],
                
                "RGBColor[{0.16590548598015492, 0.9015045495499641, \
0.09828783196817376}]"],
               Appearance->None,
               BaseStyle->{},
               BaselinePosition->Baseline,
               ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
                 If[
                  Not[
                   AbsoluteCurrentValue["Deployed"]], 
                  SelectionMove[Typeset`box$, All, Expression]; 
                  FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                  FrontEnd`Private`$ColorSelectorInitialColor = 
                   RGBColor[
                    0.16590548598015492`, 0.9015045495499641, 
                    0.09828783196817376]; 
                  FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                  MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
               DefaultBaseStyle->{},
               Evaluator->Automatic,
               Method->"Preemptive"],
              
              RGBColor[{0.16590548598015492`, 0.9015045495499641, 
               0.09828783196817376}],
              Editable->False,
              Selectable->False], 
             Offset[{2, 2}, {2.5516255265863093, -4.336413073206914}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{2.4353672087938216, -3.839177553623694}, 
             0.04390366136190131], InsetBox[
             InterpretationBox[
              ButtonBox[
               TooltipBox[
                GraphicsBox[{{{{
                    {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                    {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                    {RGBColor[
                    0.10048980936842117`, 0.9171495192304465, 
                    0.16131399976146749`], RectangleBox[{0, -1}, {2, 1}]}}}}},
                 
                 AspectRatio->1,
                 Frame->True,
                 
                 FrameStyle->RGBColor[
                  0.06699320624561411, 0.6114330128202977, 
                   0.10754266650764499`],
                 FrameTicks->None,
                 ImageSize->
                  Dynamic[{
                   Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}],
                 PlotRangePadding->None],
                
                "RGBColor[{0.10048980936842117, 0.9171495192304465, \
0.16131399976146749}]"],
               Appearance->None,
               BaseStyle->{},
               BaselinePosition->Baseline,
               ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
                 If[
                  Not[
                   AbsoluteCurrentValue["Deployed"]], 
                  SelectionMove[Typeset`box$, All, Expression]; 
                  FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                  FrontEnd`Private`$ColorSelectorInitialColor = 
                   RGBColor[
                    0.10048980936842117`, 0.9171495192304465, 
                    0.16131399976146749`]; 
                  FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                  MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
               DefaultBaseStyle->{},
               Evaluator->Automatic,
               Method->"Preemptive"],
              
              RGBColor[{0.10048980936842117`, 0.9171495192304465, 
               0.16131399976146749`}],
              Editable->False,
              Selectable->False], 
             Offset[{2, 2}, {2.479270870155723, -3.7952738922617923}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FormatType->TraditionalForm,
  FrameTicks->None,
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]]]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellTags->"LastCellOfAPage",
 CellLabel->"Out[13]=",ExpressionUUID->"7ac2c583-6f43-41ca-957c-f9c9482c147a"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Vocabulary", "VocabularySection",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"p:126",ExpressionUUID->"10430372-4a8f-4f0c-b981-c2e68639a8fc"],

Cell[BoxData[GridBox[{
   {
    RowBox[{
     ButtonBox["LanguageIdentify",
      BaseStyle->"CodeLink"], "[", 
     StyleBox["text", "CodeVariableLrg"], "]"}], " ", Cell[
    "identify what human language text is in ", "VocabularyText",
     ExpressionUUID->"6a809b68-8c9d-4561-b2ca-72420029b3ee"]},
   {
    RowBox[{
     ButtonBox["ImageIdentify",
      BaseStyle->"CodeLink"], "[", 
     StyleBox["image", "CodeVariableLrg"], "]"}], " ", Cell[
    "identify what an image is of ", "VocabularyText",ExpressionUUID->
     "53ca6b3a-665a-4d86-a46f-4e7d9d3d80ab"]},
   {
    RowBox[{
     ButtonBox["TextRecognize",
      BaseStyle->"CodeLink"], "[", 
     StyleBox["text", "CodeVariableLrg"], "]"}], " ", Cell[
    "recognize text from an image (OCR) ", "VocabularyText",ExpressionUUID->
     "1c0df709-5bdc-43a8-9891-c6868d201499"]},
   {
    RowBox[{
     ButtonBox["Classify",
      BaseStyle->"CodeLink"], "[", 
     RowBox[{
      StyleBox["training", "CodeVariableLrg"], ",", 
      StyleBox["data", "CodeVariableLrg"]}], "]"}], " ", Cell[
    "classify data on the basis of training examples ", "VocabularyText",
     ExpressionUUID->"2fd4779e-a588-4e4a-b139-72c391db15e9"]},
   {
    RowBox[{
     ButtonBox["Nearest",
      BaseStyle->"CodeLink"], "[", 
     RowBox[{
      StyleBox["list", "CodeVariableLrg"], ",", 
      StyleBox["item", "CodeVariableLrg"]}], "]"}], " ", Cell[TextData[{
     "find what element of ",
     Cell[BoxData[
      StyleBox["list", "CodeVariable"]], "InlineCode",ExpressionUUID->
      "314225cc-2834-4ba3-a2c1-adb5763ed8af"],
     " is nearest to ",
     Cell[BoxData[
      StyleBox["item", "CodeVariable"]], "InlineCode",ExpressionUUID->
      "19b0a8f4-f8fa-4bb5-8b28-87b788f2e951"],
     " "
    }], "VocabularyText",ExpressionUUID->
     "001c2750-0153-4d85-a3f0-7bdd4fcfb609"]},
   {
    RowBox[{
     ButtonBox["FindClusters",
      BaseStyle->"CodeLink"], "[", 
     StyleBox["list", "CodeVariableLrg"], "]"}], " ", Cell[
    "find clusters of similar items ", "VocabularyText",ExpressionUUID->
     "a1a3650c-3ac5-4076-8cd2-7fcae8b55dbe"]},
   {
    RowBox[{
     ButtonBox["NearestNeighborGraph",
      BaseStyle->"CodeLink"], "[", 
     RowBox[{
      StyleBox["list", "CodeVariableLrg"], ",", 
      StyleBox["n", "CodeVariableLrg"]}], "]"}], " ", Cell[TextData[{
     "connect elements of ",
     Cell[BoxData[
      StyleBox["list", "CodeVariable"]], "InlineCode",ExpressionUUID->
      "67e9f07a-681e-46f0-b883-102ca45de02a"],
     " to their ",
     Cell[BoxData[
      StyleBox["n", "CodeVariable"]], "InlineCode",ExpressionUUID->
      "0772c8c3-5c28-4033-8dab-c68e8876e0e3"],
     " nearest neighbors "
    }], "VocabularyText",ExpressionUUID->
     "9eb66968-ea0a-4332-b8f5-26ab0fa3280c"]}
  }]], "VocabularyTable",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 GridBoxOptions->{
 GridBoxDividers->{
  "Columns" -> {{False}}, "Rows" -> {False, {True, True, True, 
      Directive[
       Thickness[1.5], "VocabDivColor"], True, True, True, True}, 
     False}}},ExpressionUUID->"7191c57a-d61a-4f10-95e8-906039f3ca5c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 DynamicModuleBox[{$CellContext`open$$ = False}, 
  TagBox[GridBox[{
     {
      StyleBox["\<\"Exercises\"\>",
       StripOnInput->False,
       FontSlant->"Italic"], 
      PaneBox[
       TagBox[
        ButtonBox[
         DynamicBox[ToBoxes[
           If[$CellContext`open$$, 
            Row[{
              Style["-", "ExercisePreviewButtonTextHighlight"], 
              Style[" Preview Exercises", "ExercisePreviewButtonText"]}], 
            Row[{
              Style["+", "ExercisePreviewButtonTextHighlight"], 
              Style[" Preview Exercises", "ExercisePreviewButtonText"]}]], 
           StandardForm],
          ImageSizeCache->{115., {1., 10.}}],
         Appearance->None,
         ButtonFunction:>(
          If[$CellContext`open$$, $CellContext`open$$ = 
            False, $CellContext`open$$ = True]; NotebookFind[
            EvaluationNotebook[], "ExerciseSummaryCell", Next, CellStyle, 
            WrapAround -> True, AutoScroll -> False]; FrontEndTokenExecute[
            EvaluationNotebook[], "ExpandSelection"]; FrontEndExecute[
            FrontEndToken[
             EvaluationNotebook[], "OpenCloseGroup"]]),
         Evaluator->Automatic,
         Method->"Preemptive"],
        MouseAppearanceTag["LinkHand"]],
       Alignment->Right,
       ImageSize->Full]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {Left, Right}, "Rows" -> {{Center}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"],
  DynamicModuleValues:>{}]], "ExerciseSection",
 Editable->False,
 ShowCellBracket->False,
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{3.669991951589675*^9},
 ShowStringCharacters->
  False,ExpressionUUID->"51441cf8-4401-4b44-b0b8-203a6e0bcaac"],

Cell[CellGroupData[{

Cell[BoxData[
 TagBox[GridBox[{
    {
     TagBox[GridBox[{
        {
         PaneBox[
          
          StyleBox["\<\"14 Exercises Available\"\>", "ExerciseSummaryHeading",
           
           StripOnInput->False],
          ImageMargins->{{20, 0}, {0, 10}}]},
        {
         PaneBox[
          StyleBox["\<\"with 6 extras\"\>", "ExerciseSummarySubheading",
           StripOnInput->False],
          ImageMargins->{{20, 0}, {10, 0}}]}
       },
       DefaultBaseStyle->"Column",
       GridBoxAlignment->{"Columns" -> {{Left}}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
       
       GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{0}}}],
      "Column"], 
     PaneBox[
      ButtonBox[
       StyleBox["\<\"Get Started \[RightGuillemet]\"\>", 
        "ExerciseSummaryHeading",
        StripOnInput->False],
       Appearance->None,
       ButtonFunction:>
        NotebookLocate[{"EIWL1-22-machine-learning-exercises.nb", ""}],
       Evaluator->Automatic,
       Method->"Preemptive"],
      FrameMargins->{{10, 0}, {10, 10}},
      ImageSize->Full]}
   },
   AutoDelete->False,
   GridBoxAlignment->{"Columns" -> {{Left}}},
   GridBoxItemSize->{"Columns" -> {
       Scaled[0.7], 
       Scaled[0.3]}, "Rows" -> {{Automatic}}}],
  "Grid"]], "ExerciseSummaryCell",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"88971523-4291-4ee9-be1b-eda42bb0b0ce"],

Cell[CellGroupData[{

Cell[TextData[{
 "Identify what language the word \[OpenCurlyDoubleQuote]ajatella\
\[CloseCurlyDoubleQuote] comes from.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "22.1", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"24a3c41f-2ace-406b-9396-b2e81de5ce23"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       TemplateBox[{"\"Finnish\"",RowBox[{"Entity", "[", 
           RowBox[{"\"Language\"", ",", "\"Finnish\""}], "]"}],
         "\"Entity[\\\"Language\\\", \\\"Finnish\\\"]\"","\"language\""},
        "Entity"]], "ExerciseOutput",ExpressionUUID->
       "bc2e7b89-483c-4e32-854c-bd023fd474bb"],
      Apply[TextCell, 
       Cell[
        BoxData[
         TemplateBox[{"\"Finnish\"", 
           RowBox[{"Entity", "[", 
             RowBox[{"\"Language\"", ",", "\"Finnish\""}], "]"}], 
           "\"Entity[\\\"Language\\\", \\\"Finnish\\\"]\"", "\"language\""}, 
          "Entity"]], "ExerciseOutput", Selectable -> False, Copyable -> 
        False, Editable -> False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"6de3bb35-e2aa-405f-afb5-41a3687491b3"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Use ",
 Cell[TextData[Cell[BoxData[
  RowBox[{
  Cell["Ctrl", "KeyEvent",ExpressionUUID->
    "60fd230f-887e-4169-88b9-88f37cecabcf"], 
   StyleBox["+", "KeyEventDelimiter"], Cell[
   "=", "KeyEvent",ExpressionUUID->"8a1da34a-3ef5-4bef-bb53-e7f72ac6fb67"]}]],
   NotebookDefault,
  ShowStringCharacters->False,ExpressionUUID->
  "b4fbd69a-5c07-480c-8c59-2dc106062d2d"]], "MenuName",ExpressionUUID->
  "d5c825c6-142f-4d95-8a80-39f93ee1632e"],
 " to get an image of a tiger, then apply ",
 ButtonBox["ImageIdentify",
  BaseStyle->"Link"],
 ".",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "22.2", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"3455edf4-4bb2-4aeb-b5dd-4ce8fa464738"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       TemplateBox[{"\"tiger\"",RowBox[{"Entity", "[", 
           RowBox[{"\"Concept\"", ",", "\"PantheraTigris::2mpmq\""}], "]"}],
         "\"Entity[\\\"Concept\\\", \\\"PantheraTigris::2mpmq\\\"]\"",
         "\"concept\""},
        "Entity"]], "ExerciseOutput",ExpressionUUID->
       "e24bcf05-cb78-4a8e-a4d9-4f980308397b"],
      Apply[TextCell, 
       Cell[
        BoxData[
         TemplateBox[{"\"tiger\"", 
           RowBox[{"Entity", "[", 
             RowBox[{"\"Concept\"", ",", "\"PantheraTigris::2mpmq\""}], "]"}],
            "\"Entity[\\\"Concept\\\", \\\"PantheraTigris::2mpmq\\\"]\"", 
           "\"concept\""}, "Entity"]], "ExerciseOutput", Selectable -> False, 
        Copyable -> False, Editable -> False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"f4ba4a61-f611-41d1-971f-a4c63f8b40a4"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Make a table of image identifications for an image of a tiger, blurred by \
an amount from 1 to 5.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "22.3", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"ae142673-3369-4b07-95f4-8b7d9b496b2d"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       RowBox[{"{", 
        RowBox[{
         TemplateBox[{"\"tiger\"",RowBox[{"Entity", "[", 
             RowBox[{"\"Concept\"", ",", "\"PantheraTigris::2mpmq\""}], "]"}],
           "\"Entity[\\\"Concept\\\", \\\"PantheraTigris::2mpmq\\\"]\"",
           "\"concept\""},
          "Entity"], ",", 
         TemplateBox[{"\"tiger\"",RowBox[{"Entity", "[", 
             RowBox[{"\"Concept\"", ",", "\"PantheraTigris::2mpmq\""}], "]"}],
           "\"Entity[\\\"Concept\\\", \\\"PantheraTigris::2mpmq\\\"]\"",
           "\"concept\""},
          "Entity"], ",", 
         TemplateBox[{"\"domestic cat\"",RowBox[{"Entity", "[", 
             RowBox[{"\"Concept\"", ",", "\"DomesticCat::jpx55\""}], "]"}],
           "\"Entity[\\\"Concept\\\", \\\"DomesticCat::jpx55\\\"]\"",
           "\"concept\""},
          "Entity"], ",", 
         TemplateBox[{"\"domestic cat\"",RowBox[{"Entity", "[", 
             RowBox[{"\"Concept\"", ",", "\"DomesticCat::jpx55\""}], "]"}],
           "\"Entity[\\\"Concept\\\", \\\"DomesticCat::jpx55\\\"]\"",
           "\"concept\""},
          "Entity"], ",", 
         TemplateBox[{"\"person\"",RowBox[{"Entity", "[", 
             RowBox[{"\"Concept\"", ",", "\"Person::93r37\""}], "]"}],
           "\"Entity[\\\"Concept\\\", \\\"Person::93r37\\\"]\"","\"concept\""},
          "Entity"]}], "}"}]], "ExerciseOutput",ExpressionUUID->
       "d584b921-c9ef-4651-95e4-0b2f7dbc6873"],
      Apply[TextCell, 
       Cell[
        BoxData[
         RowBox[{"{", 
           RowBox[{
             TemplateBox[{"\"tiger\"", 
               RowBox[{"Entity", "[", 
                 RowBox[{"\"Concept\"", ",", "\"PantheraTigris::2mpmq\""}], 
                 "]"}], "\"Entity[\\\"Concept\\\", \
\\\"PantheraTigris::2mpmq\\\"]\"", "\"concept\""}, "Entity"], ",", 
             TemplateBox[{"\"tiger\"", 
               RowBox[{"Entity", "[", 
                 RowBox[{"\"Concept\"", ",", "\"PantheraTigris::2mpmq\""}], 
                 "]"}], "\"Entity[\\\"Concept\\\", \
\\\"PantheraTigris::2mpmq\\\"]\"", "\"concept\""}, "Entity"], ",", 
             TemplateBox[{"\"domestic cat\"", 
               RowBox[{"Entity", "[", 
                 RowBox[{"\"Concept\"", ",", "\"DomesticCat::jpx55\""}], 
                 "]"}], "\"Entity[\\\"Concept\\\", \
\\\"DomesticCat::jpx55\\\"]\"", "\"concept\""}, "Entity"], ",", 
             TemplateBox[{"\"domestic cat\"", 
               RowBox[{"Entity", "[", 
                 RowBox[{"\"Concept\"", ",", "\"DomesticCat::jpx55\""}], 
                 "]"}], "\"Entity[\\\"Concept\\\", \
\\\"DomesticCat::jpx55\\\"]\"", "\"concept\""}, "Entity"], ",", 
             TemplateBox[{"\"person\"", 
               RowBox[{"Entity", "[", 
                 RowBox[{"\"Concept\"", ",", "\"Person::93r37\""}], "]"}], 
               "\"Entity[\\\"Concept\\\", \\\"Person::93r37\\\"]\"", 
               "\"concept\""}, "Entity"]}], "}"}]], "ExerciseOutput", 
        Selectable -> False, Copyable -> False, Editable -> False, 
        ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"c0fe7a6c-f516-42b2-965e-44cbb09369b5"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Classify the sentiment of \[OpenCurlyDoubleQuote]I\[CloseCurlyQuote]m so \
happy to be here\[CloseCurlyDoubleQuote].",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "22.4", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"09a55fa3-4d76-453b-aef0-52cb41bfb28e"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[
      BoxData["\<\"Positive\"\>"], "ExerciseOutput",ExpressionUUID->
       "c353a576-6aef-47b4-830d-f6fcc47f67e1"],
      Apply[TextCell, 
       Cell[
        BoxData["\"Positive\""], "ExerciseOutput", Selectable -> False, 
        Copyable -> False, Editable -> False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"371f75d0-c745-4276-a9db-bec8ab7200e0"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Find the 10 words in ",
 Cell[BoxData[
  RowBox[{
   ButtonBox["WordList",
    BaseStyle->"CodeLink"], "[", " ", "]"}]], "InlineCode",ExpressionUUID->
  "ffb1bbbf-b74a-44d8-8fbc-2b87bef9d183"],
 " that are nearest to \
\[OpenCurlyDoubleQuote]happy\[CloseCurlyDoubleQuote].",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "22.5", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"7a90848f-6c49-4a1a-937f-da47fc2bdc55"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       RowBox[{"{", 
        RowBox[{"\<\"happy\"\>", ",", "\<\"haply\"\>", ",", "\<\"harpy\"\>", 
         ",", "\<\"nappy\"\>", ",", "\<\"sappy\"\>", ",", "\<\"apply\"\>", 
         ",", "\<\"campy\"\>", ",", "\<\"choppy\"\>", ",", "\<\"guppy\"\>", 
         ",", "\<\"hairy\"\>"}], "}"}]], "ExerciseOutput",ExpressionUUID->
       "2357e1e9-b0c2-4075-b16c-11deb18f7828"],
      Apply[TextCell, 
       Cell[
        BoxData[
         RowBox[{"{", 
           
           RowBox[{"\"happy\"", ",", "\"haply\"", ",", "\"harpy\"", ",", 
             "\"nappy\"", ",", "\"sappy\"", ",", "\"apply\"", ",", 
             "\"campy\"", ",", "\"choppy\"", ",", "\"guppy\"", ",", 
             "\"hairy\""}], "}"}]], "ExerciseOutput", Selectable -> False, 
        Copyable -> False, Editable -> False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"87b1a40f-a7e1-461f-a768-208d9df7c80a"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Generate 20 random numbers up to 1000 and find which 3 are nearest to \
100.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "22.6", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"cc688ba3-fc92-4419-bf66-45979f2047a5"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Sample", " ", "expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       RowBox[{"{", 
        RowBox[{"94", ",", "91", ",", "133"}], "}"}]], "ExerciseOutput",
       ExpressionUUID->"08d42e94-8d77-408a-9ce7-fb0bd33dac76"],
      Apply[TextCell, 
       Cell[
        BoxData[
         RowBox[{"{", 
           RowBox[{"94", ",", "91", ",", "133"}], "}"}]], "ExerciseOutput", 
        Selectable -> False, Copyable -> False, Editable -> False, 
        ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"a5c9f82b-468c-43bf-8d0f-348ae00d1c63"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Generate a list of 10 random colors, and find which 5 are closest to ",
 ButtonBox["Red",
  BaseStyle->"Link"],
 ".",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "22.7", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"257d98eb-a3f3-4e3c-8dca-511943539cc2"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Sample", " ", "expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       RowBox[{"{", 
        RowBox[{
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{{{{
                 {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                 {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                 {RGBColor[
                  0.9132382296127133, 0.1052875704634939, 0.1081561232856334],
                   RectangleBox[{0, -1}, {2, 1}]}}}}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.6088254864084756, 0.07019171364232928, 0.07210408219042228],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.9132382296127133, 0.1052875704634939, \
0.1081561232856334]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.9132382296127133, 0.1052875704634939, 0.1081561232856334]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[0.9132382296127133, 0.1052875704634939, 0.1081561232856334],
          Editable->False,
          Selectable->False], ",", 
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{{{{
                 {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                 {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                 {RGBColor[
                  0.9771026336083766, 0.363796063619348, 0.01077019070224905],
                   RectangleBox[{0, -1}, {2, 1}]}}}}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.6514017557389178, 0.24253070907956537`, 0.0071801271348327],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.9771026336083766, 0.363796063619348, \
0.01077019070224905]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.9771026336083766, 0.363796063619348, 0.01077019070224905]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[0.9771026336083766, 0.363796063619348, 0.01077019070224905],
          Editable->False,
          Selectable->False], ",", 
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{{{{
                 {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                 {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                 {RGBColor[
                  0.9549993293169798, 0.21676827484502326`, 
                   0.2513102591499172], RectangleBox[{0, -1}, {2, 1}]}}}}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.6366662195446533, 0.14451218323001552`, 0.16754017276661148`],
             
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.9549993293169798, 0.21676827484502326, \
0.2513102591499172]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.9549993293169798, 0.21676827484502326`, 0.2513102591499172]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.9549993293169798, 0.21676827484502326`, 0.2513102591499172],
          Editable->False,
          Selectable->False], ",", 
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{{{{
                 {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                 {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                 {RGBColor[
                  0.8483679553563124, 0.30385712208149696`, 
                   0.15484335046598763`], RectangleBox[{0, -1}, {2, 1}]}}}}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.5655786369042083, 0.202571414720998, 0.10322890031065843`],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.8483679553563124, 0.30385712208149696, \
0.15484335046598763]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.8483679553563124, 0.30385712208149696`, 
                 0.15484335046598763`]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.8483679553563124, 0.30385712208149696`, 0.15484335046598763`],
          Editable->False,
          Selectable->False], ",", 
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{{{{
                 {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                 {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                 {RGBColor[
                  0.9594790623807896, 0.5046051552943853, 
                   0.18946774256928367`], RectangleBox[{0, -1}, {2, 1}]}}}}},
             AspectRatio->1,
             Frame->True,
             
             FrameStyle->RGBColor[
              0.6396527082538598, 0.33640343686292357`, 0.12631182837952246`],
             
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            
            "RGBColor[0.9594790623807896, 0.5046051552943853, \
0.18946774256928367]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[
                0.9594790623807896, 0.5046051552943853, 0.18946774256928367`]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
          0.9594790623807896, 0.5046051552943853, 0.18946774256928367`],
          Editable->False,
          Selectable->False]}], "}"}]], "ExerciseOutput",ExpressionUUID->
       "08515927-b866-4ed3-90d8-391b99ba94c9"],
      Apply[TextCell, 
       Cell[
        BoxData[
         RowBox[{"{", 
           RowBox[{
             InterpretationBox[
              ButtonBox[
               TooltipBox[
                GraphicsBox[{{
                   GrayLevel[0], 
                   RectangleBox[{0, 0}]}, {
                   GrayLevel[0], 
                   RectangleBox[{1, -1}]}, {
                   RGBColor[
                   0.9132382296127133, 0.1052875704634939, 
                    0.1081561232856334], 
                   RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                 True, FrameStyle -> 
                 RGBColor[
                  0.6088254864084756, 0.07019171364232928, 
                   0.07210408219042228], FrameTicks -> None, ImageSize -> 
                 Dynamic[{
                   Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                "RGBColor[0.9132382296127133, 0.1052875704634939, \
0.1081561232856334]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
               Baseline, ButtonFunction :> 
               With[{Typeset`box$ = EvaluationBox[]}, 
                 If[
                  Not[
                   AbsoluteCurrentValue["Deployed"]], 
                  SelectionMove[Typeset`box$, All, Expression]; 
                  FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                  FrontEnd`Private`$ColorSelectorInitialColor = 
                   RGBColor[
                    0.9132382296127133, 0.1052875704634939, 
                    0.1081561232856334]; 
                  FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                  MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
               Automatic, Method -> "Preemptive"], 
              RGBColor[
              0.9132382296127133, 0.1052875704634939, 0.1081561232856334], 
              Editable -> False, Selectable -> False], ",", 
             InterpretationBox[
              ButtonBox[
               TooltipBox[
                GraphicsBox[{{
                   GrayLevel[0], 
                   RectangleBox[{0, 0}]}, {
                   GrayLevel[0], 
                   RectangleBox[{1, -1}]}, {
                   RGBColor[
                   0.9771026336083766, 0.363796063619348, 
                    0.01077019070224905], 
                   RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                 True, FrameStyle -> 
                 RGBColor[
                  0.6514017557389178, 0.24253070907956537`, 
                   0.0071801271348327], FrameTicks -> None, ImageSize -> 
                 Dynamic[{
                   Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                "RGBColor[0.9771026336083766, 0.363796063619348, \
0.01077019070224905]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
               Baseline, ButtonFunction :> 
               With[{Typeset`box$ = EvaluationBox[]}, 
                 If[
                  Not[
                   AbsoluteCurrentValue["Deployed"]], 
                  SelectionMove[Typeset`box$, All, Expression]; 
                  FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                  FrontEnd`Private`$ColorSelectorInitialColor = 
                   RGBColor[
                    0.9771026336083766, 0.363796063619348, 
                    0.01077019070224905]; 
                  FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                  MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
               Automatic, Method -> "Preemptive"], 
              RGBColor[
              0.9771026336083766, 0.363796063619348, 0.01077019070224905], 
              Editable -> False, Selectable -> False], ",", 
             InterpretationBox[
              ButtonBox[
               TooltipBox[
                GraphicsBox[{{
                   GrayLevel[0], 
                   RectangleBox[{0, 0}]}, {
                   GrayLevel[0], 
                   RectangleBox[{1, -1}]}, {
                   RGBColor[
                   0.9549993293169798, 0.21676827484502326`, 
                    0.2513102591499172], 
                   RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                 True, FrameStyle -> 
                 RGBColor[
                  0.6366662195446533, 0.14451218323001552`, 
                   0.16754017276661148`], FrameTicks -> None, ImageSize -> 
                 Dynamic[{
                   Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                "RGBColor[0.9549993293169798, 0.21676827484502326, \
0.2513102591499172]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
               Baseline, ButtonFunction :> 
               With[{Typeset`box$ = EvaluationBox[]}, 
                 If[
                  Not[
                   AbsoluteCurrentValue["Deployed"]], 
                  SelectionMove[Typeset`box$, All, Expression]; 
                  FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                  FrontEnd`Private`$ColorSelectorInitialColor = 
                   RGBColor[
                    0.9549993293169798, 0.21676827484502326`, 
                    0.2513102591499172]; 
                  FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                  MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
               Automatic, Method -> "Preemptive"], 
              RGBColor[
              0.9549993293169798, 0.21676827484502326`, 0.2513102591499172], 
              Editable -> False, Selectable -> False], ",", 
             InterpretationBox[
              ButtonBox[
               TooltipBox[
                GraphicsBox[{{
                   GrayLevel[0], 
                   RectangleBox[{0, 0}]}, {
                   GrayLevel[0], 
                   RectangleBox[{1, -1}]}, {
                   RGBColor[
                   0.8483679553563124, 0.30385712208149696`, 
                    0.15484335046598763`], 
                   RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                 True, FrameStyle -> 
                 RGBColor[
                  0.5655786369042083, 0.202571414720998, 
                   0.10322890031065843`], FrameTicks -> None, ImageSize -> 
                 Dynamic[{
                   Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                "RGBColor[0.8483679553563124, 0.30385712208149696, \
0.15484335046598763]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
               Baseline, ButtonFunction :> 
               With[{Typeset`box$ = EvaluationBox[]}, 
                 If[
                  Not[
                   AbsoluteCurrentValue["Deployed"]], 
                  SelectionMove[Typeset`box$, All, Expression]; 
                  FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                  FrontEnd`Private`$ColorSelectorInitialColor = 
                   RGBColor[
                    0.8483679553563124, 0.30385712208149696`, 
                    0.15484335046598763`]; 
                  FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                  MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
               Automatic, Method -> "Preemptive"], 
              RGBColor[
              0.8483679553563124, 0.30385712208149696`, 0.15484335046598763`],
               Editable -> False, Selectable -> False], ",", 
             InterpretationBox[
              ButtonBox[
               TooltipBox[
                GraphicsBox[{{
                   GrayLevel[0], 
                   RectangleBox[{0, 0}]}, {
                   GrayLevel[0], 
                   RectangleBox[{1, -1}]}, {
                   RGBColor[
                   0.9594790623807896, 0.5046051552943853, 
                    0.18946774256928367`], 
                   RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                 True, FrameStyle -> 
                 RGBColor[
                  0.6396527082538598, 0.33640343686292357`, 
                   0.12631182837952246`], FrameTicks -> None, ImageSize -> 
                 Dynamic[{
                   Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                "RGBColor[0.9594790623807896, 0.5046051552943853, \
0.18946774256928367]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
               Baseline, ButtonFunction :> 
               With[{Typeset`box$ = EvaluationBox[]}, 
                 If[
                  Not[
                   AbsoluteCurrentValue["Deployed"]], 
                  SelectionMove[Typeset`box$, All, Expression]; 
                  FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                  FrontEnd`Private`$ColorSelectorInitialColor = 
                   RGBColor[
                    0.9594790623807896, 0.5046051552943853, 
                    0.18946774256928367`]; 
                  FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                  MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
               Automatic, Method -> "Preemptive"], 
              RGBColor[
              0.9594790623807896, 0.5046051552943853, 0.18946774256928367`], 
              Editable -> False, Selectable -> False]}], "}"}]], 
        "ExerciseOutput", Selectable -> False, Copyable -> False, Editable -> 
        False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"415cb257-4004-46ea-ae02-c7725dc1cfbd"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Of the first 100 squares, find the one nearest to 2000.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "22.8", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"bca74320-1507-46d4-8c41-2e758aaec250"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
      "2025"], "ExerciseOutput",ExpressionUUID->
       "e72473b1-f353-4f04-bfd3-107a9eb4ae30"],
      Apply[TextCell, 
       Cell[
        BoxData["2025"], "ExerciseOutput", Selectable -> False, Copyable -> 
        False, Editable -> False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"a569f35b-4077-4bce-ab7d-f6e31149aa9e"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Find the 3 European flags nearest to the flag of Brazil.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "22.9", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"9bf7a3a1-8733-420d-b5a6-72e3f9918daa"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       RowBox[{"{", 
        RowBox[{
         GraphicsBox[{{{
             {Thickness[0.00078125], {{{
                 {FaceForm[{RGBColor[0., 0.321569, 0.5764710000000001], 
                  Opacity[1.]}], 
                  FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
                   0.}, {0., 800.}, {1280., 800.}, {1280., 0.}}}]}}}}, {{{
                 {FaceForm[{RGBColor[0.996078, 0.796078, 0.], Opacity[1.]}], 
                  FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{400.,
                    800.}, {560., 800.}, {560., 0.}, {400., 0.}}}], 
                  FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
                   480.}, {1280., 480.}, {1280., 320.}, {0., 320.}}}]}}}}}}}},
          
          AspectRatio->Automatic,
          ImageSize->{{128}, {85}},
          PlotRange->{{0., 1280.}, {0., 800.}}], ",", 
         GraphicsBox[{{{{
              {Thickness[0.000992063492063492], {{{
                  {FaceForm[{RGBColor[0.141176, 0.290196, 0.647059], Opacity[
                   1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{0., 0.}, {0., 720.}, {1008., 720.}, {1008., 
                    0.}}}]}}}}, {{{
                  {FaceForm[{RGBColor[0.815686, 0.65098, 0.313726], Opacity[
                   1.]}], FilledCurveBox[CompressedData["
1:eJxTTMoPSmJmYGBgBGJPJgYGMJuFmZGZmghoOnUNHBArqOXOoeLUYYBIDWpc
6kejjKaIkuCladQM13inir+IMQRNDS4uFcMZv1EAebsRkw==
                    
                    "], CompressedData["
1:eJyNXQm4jeX2V8mcqUEaFJcUlQpJlE8RoZIpB+fgDPucs8+4z57n+chViJt5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                    "]]}}}}}}}}, {{{
              {RGBColor[1., 1., 1.], 
               PolygonBox[{{{538.5090715034606, 568.7105746996907}, {528.809, 
                 538.8589999999999}, {554.2020729483969, 557.3083203441713}, {
                 554.2020729483969, 557.3083203441714}, {579.594, 
                 538.8589999999999}, {569.8952096853275, 568.7101584538358}, {
                 569.8952096853276, 568.7101584538358}, {595.2890000000001, 
                 587.16}, {563.9007641172633, 587.16}, {554.2030000000001, 
                 617.008}, {544.5040900715301, 587.16}, {513.117, 587.16}}, {{
                 637.3860620645678, 551.273238537617}, {627.6880000000001, 
                 521.4219999999999}, {653.0795450860053, 539.8713203441714}, {
                 678.4730000000001, 521.4219999999999}, {668.7728026714439, 
                 551.2739323339763}, {694.164, 569.7230000000001}, {
                 662.7778943725049, 569.7230000000001}, {653.0780000000001, 
                 599.5740000000001}, {643.380015431467, 569.7230000000001}, {
                 611.992, 569.7230000000001}}, {{731.7349490873759, 
                 516.9356405308232}, {722.035, 487.08599999999996`}, {
                 747.4284549139948, 505.5337924817798}, {772.8199999999999, 
                 487.08599999999996`}, {763.1221861348666, 
                 516.9349467480281}, {788.516, 535.383}, {757.1284809592055, 
                 535.383}, {747.43, 565.234}, {737.7296091390695, 535.383}, {
                 706.3439999999999, 535.383}}, {{438.10479031467247`, 
                 568.7101584538357}, {428.40599999999995`, 
                 538.8589999999999}, {453.7979270516031, 557.3083203441714}, {
                 479.191, 538.8589999999999}, {469.4909284965393, 
                 568.7105746996907}, {494.883, 587.16}, {463.4959099284699, 
                 587.16}, {453.79699999999997`, 617.008}, {
                 444.09923588273676`, 587.16}, {412.71099999999996`, 
                 587.16}}, {{339.2271973285562, 551.2739323339763}, {329.527, 
                 521.4219999999999}, {354.9204549139947, 539.8713203441714}, {
                 380.312, 521.4219999999999}, {370.61393793543226`, 
                 551.273238537617}, {396.008, 569.7230000000001}, {
                 364.6199845685331, 569.7230000000001}, {354.92199999999997`, 
                 599.5740000000001}, {345.2221056274951, 569.7230000000001}, {
                 313.83599999999996`, 569.7230000000001}}, {{
                 244.87781386513328`, 516.9349467480281}, {235.18, 
                 487.08599999999996`}, {260.57154508600524`, 
                 505.5337924817798}, {285.965, 487.08599999999996`}, {
                 276.265050912624, 516.9356405308232}, {301.656, 535.383}, {
                 270.27039086093055`, 535.383}, {260.57, 565.234}, {
                 250.8715190407944, 535.383}, {219.484, 535.383}}}]}}}}},
          AspectRatio->Automatic,
          ImageSize->{{128}, {85}},
          PlotRange->{{0., 1008.}, {0., 720.}}], ",", 
         GraphicsBox[{{{{
              {Thickness[0.0015625], {{{
                  {FaceForm[{RGBColor[
                   0., 0.13725500000000002`, 0.5843139999999999], Opacity[
                   1.]}], 
                   FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
                    341.99399999999997`}, {640., 341.99399999999997`}, {640., 
                    21.99399999999997}, {0., 21.99399999999997}}}]}}}}, {{{
                  {FaceForm[{RGBColor[0.996078, 0.796078, 0.], Opacity[1.]}], 
                   FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{169.602, 
                    341.99399999999997`}, {489.60200000000003`, 
                    341.99399999999997`}, {489.60200000000003`, 
                    21.994}}}]}}}}}}}}, {{{
              {RGBColor[1., 1., 1.], 
               PolygonBox[{{{100.95657021107493`, 342.00394621634484`}, {
                 94.133, 321.002}, {112., 333.98146020820417`}, {
                 129.86700000000002`, 321.002}, {123.04342978892507`, 
                 342.00394621634484`}, {140.914, 354.98599999999993`}, {
                 118.82553709630494`, 354.98599999999993`}, {112., 
                 375.99399999999997`}, {105.17446290369506`, 
                 354.98599999999993`}, {83.086, 354.98599999999993`}}, {{
                 140.95657021107493`, 302.00394621634484`}, {
                 134.13299999999998`, 281.002}, {152., 293.98146020820417`}, {
                 169.86700000000002`, 281.002}, {163.04342978892507`, 
                 302.00394621634484`}, {180.914, 314.98599999999993`}, {
                 158.82553709630494`, 314.98599999999993`}, {152., 
                 335.99399999999997`}, {145.17446290369506`, 
                 314.98599999999993`}, {123.086, 314.98599999999993`}}, {{
                 180.95657021107493`, 262.00394621634484`}, {
                 174.13299999999998`, 241.002}, {192., 253.98146020820417`}, {
                 209.86700000000002`, 241.002}, {203.04342978892507`, 
                 262.00394621634484`}, {220.914, 274.98599999999993`}, {
                 198.82553709630494`, 274.98599999999993`}, {192., 
                 295.99399999999997`}, {185.17446290369506`, 
                 274.98599999999993`}, {163.086, 274.98599999999993`}}, {{
                 220.95657021107493`, 222.0039462163449}, {
                 220.95657021107496`, 222.0039462163449}, {
                 214.13299999999998`, 201.002}, {232., 213.9814602082042}, {
                 232., 213.98146020820423`}, {249.86700000000002`, 201.002}, {
                 243.04342978892504`, 222.0039462163449}, {260.914, 
                 234.98600000000002`}, {238.8255370963049, 
                 234.98600000000002`}, {232., 255.994}, {225.1744629036951, 
                 234.98600000000002`}, {203.086, 234.98600000000002`}}, {{
                 260.95657021107496`, 182.0039462163449}, {
                 254.13299999999998`, 161.002}, {272., 173.9814602082042}, {
                 272., 173.98146020820423`}, {289.867, 161.002}, {
                 283.04342978892504`, 182.0039462163449}, {300.914, 
                 194.98600000000002`}, {278.8255370963049, 
                 194.98600000000002`}, {272., 215.994}, {265.1744629036951, 
                 194.98600000000002`}, {243.086, 194.98600000000002`}}, {{
                 300.95657021107496`, 142.00394621634487`}, {294.133, 
                 121.002}, {312., 133.9814602082042}, {329.867, 121.002}, {
                 323.04342978892504`, 142.00394621634487`}, {340.914, 
                 154.98600000000002`}, {318.8255370963049, 
                 154.98600000000002`}, {312., 175.994}, {305.1744629036951, 
                 154.98600000000002`}, {283.08599999999996`, 
                 154.98600000000002`}}, {{340.95657021107496`, 
                 102.00394621634486`}, {340.95657021107496`, 
                 102.00394621634484`}, {334.133, 81.002}, {352., 
                 93.98146020820418}, {352., 93.9814602082042}, {369.867, 
                 81.002}, {363.04342978892504`, 102.00394621634487`}, {
                 380.914, 114.986}, {358.8255370963049, 114.986}, {352., 
                 135.994}, {345.1744629036951, 114.986}, {323.08599999999996`,
                  114.986}}, {{380.95657021107496`, 62.00394621634486}, {
                 374.133, 41.002}, {392., 53.9814602082042}, {409.867, 
                 41.002}, {403.04342978892504`, 62.00394621634488}, {420.914, 
                 74.986}, {398.8255370963049, 74.986}, {392., 
                 95.99400000000001}, {385.1744629036951, 74.986}, {
                 363.08599999999996`, 74.986}}, {{420.95657021107496`, 
                 22.00394621634485}, {420.95657021107496`, 
                 22.003946216344847`}, {414.133, 1.002}, {432., 
                 13.981460208204187`}, {432., 13.981460208204194`}, {449.867, 
                 1.002}, {443.04342978892504`, 22.003946216344875`}, {
                 443.04342978892504`, 22.00394621634488}, {460.914, 34.986}, {
                 438.8255370963049, 34.986}, {432., 55.994}, {
                 425.1744629036951, 34.986}, {403.08599999999996`, 
                 34.986}}}]}}}}},
          AspectRatio->Automatic,
          ImageSize->{{128}, {85}},
          
          PlotRange->{{0., 640.}, {21.99399999999997, 
           341.99399999999997`}}]}], "}"}]], "ExerciseOutput",ExpressionUUID->
       "bee2aa7b-6c95-4310-acec-249cbcf756f5"],
      Apply[TextCell, 
       Cell[
        BoxData[
         RowBox[{"{", 
           RowBox[{
             GraphicsBox[{
               Thickness[0.00078125], {
                FaceForm[{
                  RGBColor[0., 0.321569, 0.5764710000000001], 
                  Opacity[1.]}], 
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
                 0.}, {0., 800.}, {1280., 800.}, {1280., 0.}}}]}, {
                FaceForm[{
                  RGBColor[0.996078, 0.796078, 0.], 
                  Opacity[1.]}], 
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{400., 
                 800.}, {560., 800.}, {560., 0.}, {400., 0.}}}], 
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
                 480.}, {1280., 480.}, {1280., 320.}, {0., 320.}}}]}}, 
              AspectRatio -> Automatic, ImageSize -> {{128}, {85}}, 
              PlotRange -> {{0., 1280.}, {0., 800.}}], ",", 
             GraphicsBox[{{
                Thickness[0.000992063492063492], {
                 FaceForm[{
                   RGBColor[0.141176, 0.290196, 0.647059], 
                   Opacity[1.]}], 
                 
                 FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
                  0.}, {0., 720.}, {1008., 720.}, {1008., 0.}}}]}, {
                 FaceForm[{
                   RGBColor[0.815686, 0.65098, 0.313726], 
                   Opacity[1.]}], 
                 FilledCurveBox[CompressedData["
1:eJxTTMoPSmJmYGBgBGJPJgYGMJuFmZGZmghoOnUNHBArqOXOoeLUYYBIDWpc
6kejjKaIkuCladQM13inir+IMQRNDS4uFcMZv1EAebsRkw==
                  
                  "], CompressedData["
1:eJyNXQm4jeX2V8mcqUEaFJcUlQpJlE8RoZIpB+fgDPucs8+4z57n+chViJt5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                  "]]}}, {
                RGBColor[1., 1., 1.], 
                
                PolygonBox[{{{538.5090715034606, 568.7105746996907}, {528.809,
                   538.8589999999999}, {554.2020729483969, 
                  557.3083203441713}, {554.2020729483969, 
                  557.3083203441714}, {579.594, 538.8589999999999}, {
                  569.8952096853275, 568.7101584538358}, {569.8952096853276, 
                  568.7101584538358}, {595.2890000000001, 587.16}, {
                  563.9007641172633, 587.16}, {554.2030000000001, 617.008}, {
                  544.5040900715301, 587.16}, {513.117, 587.16}}, {{
                  637.3860620645678, 551.273238537617}, {627.6880000000001, 
                  521.4219999999999}, {653.0795450860053, 
                  539.8713203441714}, {678.4730000000001, 
                  521.4219999999999}, {668.7728026714439, 
                  551.2739323339763}, {694.164, 569.7230000000001}, {
                  662.7778943725049, 569.7230000000001}, {653.0780000000001, 
                  599.5740000000001}, {643.380015431467, 569.7230000000001}, {
                  611.992, 569.7230000000001}}, {{731.7349490873759, 
                  516.9356405308232}, {722.035, 487.08599999999996`}, {
                  747.4284549139948, 505.5337924817798}, {772.8199999999999, 
                  487.08599999999996`}, {763.1221861348666, 
                  516.9349467480281}, {788.516, 535.383}, {757.1284809592055, 
                  535.383}, {747.43, 565.234}, {737.7296091390695, 535.383}, {
                  706.3439999999999, 535.383}}, {{438.10479031467247`, 
                  568.7101584538357}, {428.40599999999995`, 
                  538.8589999999999}, {453.7979270516031, 
                  557.3083203441714}, {479.191, 538.8589999999999}, {
                  469.4909284965393, 568.7105746996907}, {494.883, 587.16}, {
                  463.4959099284699, 587.16}, {453.79699999999997`, 
                  617.008}, {444.09923588273676`, 587.16}, {
                  412.71099999999996`, 587.16}}, {{339.2271973285562, 
                  551.2739323339763}, {329.527, 521.4219999999999}, {
                  354.9204549139947, 539.8713203441714}, {380.312, 
                  521.4219999999999}, {370.61393793543226`, 
                  551.273238537617}, {396.008, 569.7230000000001}, {
                  364.6199845685331, 569.7230000000001}, {354.92199999999997`,
                   599.5740000000001}, {345.2221056274951, 
                  569.7230000000001}, {313.83599999999996`, 
                  569.7230000000001}}, {{244.87781386513328`, 
                  516.9349467480281}, {235.18, 487.08599999999996`}, {
                  260.57154508600524`, 505.5337924817798}, {285.965, 
                  487.08599999999996`}, {276.265050912624, 
                  516.9356405308232}, {301.656, 535.383}, {
                  270.27039086093055`, 535.383}, {260.57, 565.234}, {
                  250.8715190407944, 535.383}, {219.484, 535.383}}}]}}, 
              AspectRatio -> Automatic, ImageSize -> {{128}, {85}}, 
              PlotRange -> {{0., 1008.}, {0., 720.}}], ",", 
             GraphicsBox[{{
                Thickness[0.0015625], {
                 FaceForm[{
                   RGBColor[0., 0.13725500000000002`, 0.5843139999999999], 
                   Opacity[1.]}], 
                 
                 FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
                  341.99399999999997`}, {640., 341.99399999999997`}, {640., 
                  21.99399999999997}, {0., 21.99399999999997}}}]}, {
                 FaceForm[{
                   RGBColor[0.996078, 0.796078, 0.], 
                   Opacity[1.]}], 
                 
                 FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{169.602, 
                  341.99399999999997`}, {489.60200000000003`, 
                  341.99399999999997`}, {489.60200000000003`, 21.994}}}]}}, {
                RGBColor[1., 1., 1.], 
                
                PolygonBox[{{{100.95657021107493`, 342.00394621634484`}, {
                  94.133, 321.002}, {112., 333.98146020820417`}, {
                  129.86700000000002`, 321.002}, {123.04342978892507`, 
                  342.00394621634484`}, {140.914, 354.98599999999993`}, {
                  118.82553709630494`, 354.98599999999993`}, {112., 
                  375.99399999999997`}, {105.17446290369506`, 
                  354.98599999999993`}, {83.086, 354.98599999999993`}}, {{
                  140.95657021107493`, 302.00394621634484`}, {
                  134.13299999999998`, 281.002}, {152., 
                  293.98146020820417`}, {169.86700000000002`, 281.002}, {
                  163.04342978892507`, 302.00394621634484`}, {180.914, 
                  314.98599999999993`}, {158.82553709630494`, 
                  314.98599999999993`}, {152., 335.99399999999997`}, {
                  145.17446290369506`, 314.98599999999993`}, {123.086, 
                  314.98599999999993`}}, {{180.95657021107493`, 
                  262.00394621634484`}, {174.13299999999998`, 241.002}, {192.,
                   253.98146020820417`}, {209.86700000000002`, 241.002}, {
                  203.04342978892507`, 262.00394621634484`}, {220.914, 
                  274.98599999999993`}, {198.82553709630494`, 
                  274.98599999999993`}, {192., 295.99399999999997`}, {
                  185.17446290369506`, 274.98599999999993`}, {163.086, 
                  274.98599999999993`}}, {{220.95657021107493`, 
                  222.0039462163449}, {220.95657021107496`, 
                  222.0039462163449}, {214.13299999999998`, 201.002}, {232., 
                  213.9814602082042}, {232., 213.98146020820423`}, {
                  249.86700000000002`, 201.002}, {243.04342978892504`, 
                  222.0039462163449}, {260.914, 234.98600000000002`}, {
                  238.8255370963049, 234.98600000000002`}, {232., 255.994}, {
                  225.1744629036951, 234.98600000000002`}, {203.086, 
                  234.98600000000002`}}, {{260.95657021107496`, 
                  182.0039462163449}, {254.13299999999998`, 161.002}, {272., 
                  173.9814602082042}, {272., 173.98146020820423`}, {289.867, 
                  161.002}, {283.04342978892504`, 182.0039462163449}, {
                  300.914, 194.98600000000002`}, {278.8255370963049, 
                  194.98600000000002`}, {272., 215.994}, {265.1744629036951, 
                  194.98600000000002`}, {243.086, 194.98600000000002`}}, {{
                  300.95657021107496`, 142.00394621634487`}, {294.133, 
                  121.002}, {312., 133.9814602082042}, {329.867, 121.002}, {
                  323.04342978892504`, 142.00394621634487`}, {340.914, 
                  154.98600000000002`}, {318.8255370963049, 
                  154.98600000000002`}, {312., 175.994}, {305.1744629036951, 
                  154.98600000000002`}, {283.08599999999996`, 
                  154.98600000000002`}}, {{340.95657021107496`, 
                  102.00394621634486`}, {340.95657021107496`, 
                  102.00394621634484`}, {334.133, 81.002}, {352., 
                  93.98146020820418}, {352., 93.9814602082042}, {369.867, 
                  81.002}, {363.04342978892504`, 102.00394621634487`}, {
                  380.914, 114.986}, {358.8255370963049, 114.986}, {352., 
                  135.994}, {345.1744629036951, 114.986}, {
                  323.08599999999996`, 114.986}}, {{380.95657021107496`, 
                  62.00394621634486}, {374.133, 41.002}, {392., 
                  53.9814602082042}, {409.867, 41.002}, {403.04342978892504`, 
                  62.00394621634488}, {420.914, 74.986}, {398.8255370963049, 
                  74.986}, {392., 95.99400000000001}, {385.1744629036951, 
                  74.986}, {363.08599999999996`, 74.986}}, {{
                  420.95657021107496`, 22.00394621634485}, {
                  420.95657021107496`, 22.003946216344847`}, {414.133, 
                  1.002}, {432., 13.981460208204187`}, {432., 
                  13.981460208204194`}, {449.867, 1.002}, {
                  443.04342978892504`, 22.003946216344875`}, {
                  443.04342978892504`, 22.00394621634488}, {460.914, 
                  34.986}, {438.8255370963049, 34.986}, {432., 55.994}, {
                  425.1744629036951, 34.986}, {403.08599999999996`, 
                  34.986}}}]}}, AspectRatio -> Automatic, 
              ImageSize -> {{128}, {85}}, 
              PlotRange -> {{0., 640.}, {21.99399999999997, 
               341.99399999999997`}}]}], "}"}]], "ExerciseOutput", Selectable -> 
        False, Copyable -> False, Editable -> False, ShowCellBracket -> 
        False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"9b0c2fa3-9b43-473b-9312-a21bd1e2e0e1"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Make a graph of the 2 nearest neighbors of each color in ",
 Cell[BoxData[
  RowBox[{
   ButtonBox["Table",
    BaseStyle->"CodeLink"], "[", 
   RowBox[{
    RowBox[{
     ButtonBox["Hue",
      BaseStyle->"CodeLink"], "[", "h", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"h", ",", "0", ",", "1", ",", ".05"}], "}"}]}], "]"}]], 
  "InlineCode",ExpressionUUID->"7b2a1be5-0340-4c78-a73a-7fdd9479c8ff"],
 ".",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "22.10", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"2ea59eba-d241-4817-bbd1-9d5fe7decf5f"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       GraphicsBox[
        NamespaceBox["NetworkGraphics",
         DynamicModuleBox[{Typeset`graph = HoldComplete[
           Graph[{
             Hue[0.], 
             Hue[0.05], 
             Hue[0.1], 
             Hue[0.15000000000000002`], 
             Hue[0.2], 
             Hue[0.25], 
             Hue[0.30000000000000004`], 
             Hue[0.35000000000000003`], 
             Hue[0.4], 
             Hue[0.45], 
             Hue[0.5], 
             Hue[0.55], 
             Hue[0.6000000000000001], 
             Hue[0.65], 
             Hue[0.7000000000000001], 
             Hue[0.75], 
             Hue[0.8], 
             Hue[0.8500000000000001], 
             Hue[0.9], 
             Hue[0.9500000000000001], 
             Hue[1.]}, {
            Null, SparseArray[
             Automatic, {21, 21}, 0, {
              1, {{0, 3, 5, 6, 7, 8, 10, 12, 13, 14, 15, 16, 17, 19, 21, 22, 
                23, 24, 25, 26, 27, 28}, {{2}, {20}, {21}, {3}, {21}, {4}, {
                5}, {6}, {7}, {8}, {8}, {9}, {9}, {10}, {11}, {12}, {13}, {
                14}, {16}, {15}, {16}, {16}, {17}, {18}, {19}, {20}, {21}, {
                21}}}, {1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
               1, 1, 1, 1, 1, 1, 1, 1, 1, 1}}]}, {VertexLabels -> {All}}]]}, 
          TagBox[GraphicsGroupBox[{{{{
                {Hue[0.6, 0.7, 0.5], Opacity[0.7], {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{1.8420641773179816`, 0.32130855815221615`}, {
                    1.0665491794795048`, 0.6664282988476327}}, 
                    0.05313657305292026]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{1.8420641773179816`, 0.32130855815221615`}, {
                    2.676282077786261, 0.1403920737348341}}, 
                    0.05313657305292026]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{1.8420641773179816`, 0.32130855815221615`}, {
                    1.7338217213167764`, 0.}}, 0.05313657305292026]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{1.0665491794795048`, 0.6664282988476327}, {
                    0.3615364546912514, 1.6198742882711907`}}, 
                    0.05313657305292026]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{1.0665491794795048`, 0.6664282988476327}, {
                    1.7338217213167764`, 0.}}, 0.05313657305292026]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{0.3615364546912514, 1.6198742882711907`}, {0., 
                    2.7298745776939786`}}, 0.05313657305292026]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{0., 2.7298745776939786`}, {
                    0.008096224632337279, 3.8985025760512433`}}, 
                    0.05313657305292026]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{0.008096224632337279, 3.8985025760512433`}, {
                    0.38155111188984403`, 5.023510173106498}}, 
                    0.05313657305292026]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{0.38155111188984403`, 5.023510173106498}, {
                    1.0114596044540423`, 5.586558862825587}}, 
                    0.05313657305292026]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{0.38155111188984403`, 5.023510173106498}, {
                    0.8046472974003689, 5.858184517107867}}, 
                    0.05313657305292026]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{1.0114596044540423`, 5.586558862825587}, {
                    0.8046472974003689, 5.858184517107867}}, 
                    0.05313657305292026]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{1.0114596044540423`, 5.586558862825587}, {
                    1.7440609967717833`, 6.0094120741862245`}}, 
                    0.05313657305292026]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{0.8046472974003689, 5.858184517107867}, {
                    1.7440609967717833`, 6.0094120741862245`}}, 
                    0.05313657305292026]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{1.7440609967717833`, 6.0094120741862245`}, {
                    2.9402331599797185`, 6.0328115146098735`}}, 
                    0.05313657305292026]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{2.9402331599797185`, 6.0328115146098735`}, {
                    4.078457348971693, 5.70968647057631}}, 
                    0.05313657305292026]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{4.078457348971693, 5.70968647057631}, {
                    5.083763280895914, 5.07568280270236}}, 
                    0.05313657305292026]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{5.083763280895914, 5.07568280270236}, {
                    5.895165294053269, 4.167299935372059}}, 
                    0.05313657305292026]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{5.895165294053269, 4.167299935372059}, {
                    6.544562546983033, 3.722896998494484}}, 
                    0.05313657305292026]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{5.895165294053269, 4.167299935372059}, {
                    6.195587386399872, 3.1426908693667572`}}, 
                    0.05313657305292026]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{6.544562546983033, 3.722896998494484}, {
                    6.947627933840062, 3.2860017960095638`}}, 
                    0.05313657305292026]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{6.544562546983033, 3.722896998494484}, {
                    6.195587386399872, 3.1426908693667572`}}, 
                    0.05313657305292026]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{6.947627933840062, 3.2860017960095638`}, {
                    6.195587386399872, 3.1426908693667572`}}, 
                    0.05313657305292026]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{6.195587386399872, 3.1426908693667572`}, {
                    5.6415439480131315`, 2.0435185778788427`}}, 
                    0.05313657305292026]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{5.6415439480131315`, 2.0435185778788427`}, {
                    4.847828130982734, 1.13524507606749}}, 
                    0.05313657305292026]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{4.847828130982734, 1.13524507606749}, {
                    3.8373612505403942`, 0.4748705591256823}}, 
                    0.05313657305292026]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{3.8373612505403942`, 0.4748705591256823}, {
                    2.676282077786261, 0.1403920737348341}}, 
                    0.05313657305292026]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{2.676282077786261, 0.1403920737348341}, {
                    1.7338217213167764`, 0.}}, 0.05313657305292026]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[BezierCurveBox[{{1.7338217213167764`, 0.}, {
                    1.887311388804487, -0.1437631971404884}, {
                    1.878605419667176, -0.350299855128179}, {
                    1.7827966771059367`, -0.4526179362073518}, {
                    1.4252776229244422`, -0.3347567502208345}, {
                    1.4091005131900425`, -0.19552095745356066`}, {
                    1.5249281615125974`, -0.024298468056254574`}, {
                    1.7338217213167764`, 0.}},
                    SplineDegree->7], 0.05313657305292026]}}}}}}}}, {{{
                {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
                 0.7]}], {
                  DiskBox[{1.8420641773179816, 0.32130855815221615}, 
                   0.05313657305292026], InsetBox[
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{{{
                    {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                    {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                    {Hue[0.], RectangleBox[{0, -1}, {2, 1}]}}}}},
                    AspectRatio->1,
                    Frame->True,
                    FrameStyle->Hue[0., 1., 0.6666666666666667],
                    FrameTicks->None,
                    
                    ImageSize->
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}],
                    PlotRangePadding->None],
                    "Hue[0.]"],
                    Appearance->None,
                    BaseStyle->{},
                    BaselinePosition->Baseline,
                    ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0., 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
                    DefaultBaseStyle->{},
                    Evaluator->Automatic,
                    Method->"Preemptive"],
                    Hue[0.],
                    Editable->False,
                    Selectable->False], 
                   Offset[{2, 2}, {1.8952007503709019, 0.3744451312051364}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{1.0665491794795048, 0.6664282988476327}, 
                   0.05313657305292026], InsetBox[
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{{{
                    {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                    {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                    {Hue[0.05], RectangleBox[{0, -1}, {2, 1}]}}}}},
                    AspectRatio->1,
                    Frame->True,
                    
                    FrameStyle->Hue[
                    0.05000000000000001, 1., 0.6666666666666667],
                    FrameTicks->None,
                    
                    ImageSize->
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}],
                    PlotRangePadding->None],
                    "Hue[0.05]"],
                    Appearance->None,
                    BaseStyle->{},
                    BaselinePosition->Baseline,
                    ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.05, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
                    DefaultBaseStyle->{},
                    Evaluator->Automatic,
                    Method->"Preemptive"],
                    Hue[0.05],
                    Editable->False,
                    Selectable->False], 
                   Offset[{2, 2}, {1.119685752532425, 0.719564871900553}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{0.3615364546912514, 1.6198742882711907}, 
                   0.05313657305292026], InsetBox[
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{{{
                    {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                    {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                    {Hue[0.1], RectangleBox[{0, -1}, {2, 1}]}}}}},
                    AspectRatio->1,
                    Frame->True,
                    
                    FrameStyle->Hue[
                    0.10000000000000002`, 1., 0.6666666666666667],
                    FrameTicks->None,
                    
                    ImageSize->
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}],
                    PlotRangePadding->None],
                    "Hue[0.1]"],
                    Appearance->None,
                    BaseStyle->{},
                    BaselinePosition->Baseline,
                    ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.1, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
                    DefaultBaseStyle->{},
                    Evaluator->Automatic,
                    Method->"Preemptive"],
                    Hue[0.1],
                    Editable->False,
                    Selectable->False], 
                   Offset[{2, 2}, {0.41467302774417164, 1.673010861324111}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{0., 2.7298745776939786}, 0.05313657305292026], 
                  InsetBox[
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{{{
                    {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                    {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                    {Hue[0.15000000000000002`], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}},
                    AspectRatio->1,
                    Frame->True,
                    FrameStyle->Hue[0.15, 1., 0.6666666666666667],
                    FrameTicks->None,
                    
                    ImageSize->
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}],
                    PlotRangePadding->None],
                    "Hue[0.15000000000000002]"],
                    Appearance->None,
                    BaseStyle->{},
                    BaselinePosition->Baseline,
                    ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.15000000000000002`, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
                    DefaultBaseStyle->{},
                    Evaluator->Automatic,
                    Method->"Preemptive"],
                    Hue[0.15000000000000002`],
                    Editable->False,
                    Selectable->False], 
                   Offset[{2, 2}, {0.05313657305292026, 2.7830111507468986}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{0.008096224632337279, 3.8985025760512433}, 
                   0.05313657305292026], InsetBox[
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{{{
                    {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                    {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                    {Hue[0.2], RectangleBox[{0, -1}, {2, 1}]}}}}},
                    AspectRatio->1,
                    Frame->True,
                    
                    FrameStyle->Hue[
                    0.20000000000000004`, 1., 0.6666666666666667],
                    FrameTicks->None,
                    
                    ImageSize->
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}],
                    PlotRangePadding->None],
                    "Hue[0.2]"],
                    Appearance->None,
                    BaseStyle->{},
                    BaselinePosition->Baseline,
                    ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.2, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
                    DefaultBaseStyle->{},
                    Evaluator->Automatic,
                    Method->"Preemptive"],
                    Hue[0.2],
                    Editable->False,
                    Selectable->False], 
                   Offset[{2, 2}, {0.06123279768525754, 3.9516391491041634}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{0.38155111188984403, 5.023510173106498}, 
                   0.05313657305292026], InsetBox[
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{{{
                    {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                    {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                    {Hue[0.25], RectangleBox[{0, -1}, {2, 1}]}}}}},
                    AspectRatio->1,
                    Frame->True,
                    FrameStyle->Hue[0.25, 1., 0.6666666666666667],
                    FrameTicks->None,
                    
                    ImageSize->
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}],
                    PlotRangePadding->None],
                    "Hue[0.25]"],
                    Appearance->None,
                    BaseStyle->{},
                    BaselinePosition->Baseline,
                    ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.25, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
                    DefaultBaseStyle->{},
                    Evaluator->Automatic,
                    Method->"Preemptive"],
                    Hue[0.25],
                    Editable->False,
                    Selectable->False], 
                   Offset[{2, 2}, {0.4346876849427643, 5.076646746159418}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{1.0114596044540423, 5.586558862825587}, 
                   0.05313657305292026], InsetBox[
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{{{
                    {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                    {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                    {Hue[0.30000000000000004`], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}},
                    AspectRatio->1,
                    Frame->True,
                    
                    FrameStyle->Hue[
                    0.30000000000000004`, 1., 0.6666666666666667],
                    FrameTicks->None,
                    
                    ImageSize->
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}],
                    PlotRangePadding->None],
                    "Hue[0.30000000000000004]"],
                    Appearance->None,
                    BaseStyle->{},
                    BaselinePosition->Baseline,
                    ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.30000000000000004`, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
                    DefaultBaseStyle->{},
                    Evaluator->Automatic,
                    Method->"Preemptive"],
                    Hue[0.30000000000000004`],
                    Editable->False,
                    Selectable->False], 
                   Offset[{2, 2}, {1.0645961775069626, 5.639695435878507}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{0.8046472974003689, 5.858184517107867}, 
                   0.05313657305292026], InsetBox[
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{{{
                    {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                    {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                    {Hue[0.35000000000000003`], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}},
                    AspectRatio->1,
                    Frame->True,
                    FrameStyle->Hue[
                    0.35000000000000003`, 1., 0.6666666666666667],
                    FrameTicks->None,
                    
                    ImageSize->
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}],
                    PlotRangePadding->None],
                    "Hue[0.35000000000000003]"],
                    Appearance->None,
                    BaseStyle->{},
                    BaselinePosition->Baseline,
                    ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.35000000000000003`, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
                    DefaultBaseStyle->{},
                    Evaluator->Automatic,
                    Method->"Preemptive"],
                    Hue[0.35000000000000003`],
                    Editable->False,
                    Selectable->False], 
                   Offset[{2, 2}, {0.8577838704532892, 5.911321090160787}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{1.7440609967717833, 6.0094120741862245}, 
                   0.05313657305292026], InsetBox[
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{{{
                    {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                    {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                    {Hue[0.4], RectangleBox[{0, -1}, {2, 1}]}}}}},
                    AspectRatio->1,
                    Frame->True,
                    
                    FrameStyle->Hue[
                    0.4000000000000001, 1., 0.6666666666666667],
                    FrameTicks->None,
                    
                    ImageSize->
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}],
                    PlotRangePadding->None],
                    "Hue[0.4]"],
                    Appearance->None,
                    BaseStyle->{},
                    BaselinePosition->Baseline,
                    ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.4, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
                    DefaultBaseStyle->{},
                    Evaluator->Automatic,
                    Method->"Preemptive"],
                    Hue[0.4],
                    Editable->False,
                    Selectable->False], 
                   Offset[{2, 2}, {1.7971975698247036, 6.0625486472391446}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{2.9402331599797185, 6.0328115146098735}, 
                   0.05313657305292026], InsetBox[
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{{{
                    {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                    {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                    {Hue[0.45], RectangleBox[{0, -1}, {2, 1}]}}}}},
                    AspectRatio->1,
                    Frame->True,
                    FrameStyle->Hue[0.45, 1., 0.6666666666666667],
                    FrameTicks->None,
                    
                    ImageSize->
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}],
                    PlotRangePadding->None],
                    "Hue[0.45]"],
                    Appearance->None,
                    BaseStyle->{},
                    BaselinePosition->Baseline,
                    ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.45, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
                    DefaultBaseStyle->{},
                    Evaluator->Automatic,
                    Method->"Preemptive"],
                    Hue[0.45],
                    Editable->False,
                    Selectable->False], 
                   Offset[{2, 2}, {2.9933697330326385, 6.085948087662794}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{4.078457348971693, 5.70968647057631}, 
                   0.05313657305292026], InsetBox[
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{{{
                    {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                    {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                    {Hue[0.5], RectangleBox[{0, -1}, {2, 1}]}}}}},
                    AspectRatio->1,
                    Frame->True,
                    FrameStyle->Hue[0.5, 1., 0.6666666666666667],
                    FrameTicks->None,
                    
                    ImageSize->
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}],
                    PlotRangePadding->None],
                    "Hue[0.5]"],
                    Appearance->None,
                    BaseStyle->{},
                    BaselinePosition->Baseline,
                    ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.5, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
                    DefaultBaseStyle->{},
                    Evaluator->Automatic,
                    Method->"Preemptive"],
                    Hue[0.5],
                    Editable->False,
                    Selectable->False], 
                   Offset[{2, 2}, {4.131593922024613, 5.76282304362923}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{5.083763280895914, 5.07568280270236}, 
                   0.05313657305292026], InsetBox[
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{{{
                    {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                    {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                    {Hue[0.55], RectangleBox[{0, -1}, {2, 1}]}}}}},
                    AspectRatio->1,
                    Frame->True,
                    FrameStyle->Hue[0.55, 1., 0.6666666666666667],
                    FrameTicks->None,
                    
                    ImageSize->
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}],
                    PlotRangePadding->None],
                    "Hue[0.55]"],
                    Appearance->None,
                    BaseStyle->{},
                    BaselinePosition->Baseline,
                    ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.55, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
                    DefaultBaseStyle->{},
                    Evaluator->Automatic,
                    Method->"Preemptive"],
                    Hue[0.55],
                    Editable->False,
                    Selectable->False], 
                   Offset[{2, 2}, {5.136899853948834, 5.12881937575528}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{5.895165294053269, 4.167299935372059}, 
                   0.05313657305292026], InsetBox[
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{{{
                    {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                    {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                    {Hue[0.6000000000000001], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}},
                    AspectRatio->1,
                    Frame->True,
                    
                    FrameStyle->Hue[
                    0.6000000000000001, 1., 0.6666666666666667],
                    FrameTicks->None,
                    
                    ImageSize->
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}],
                    PlotRangePadding->None],
                    "Hue[0.6000000000000001]"],
                    Appearance->None,
                    BaseStyle->{},
                    BaselinePosition->Baseline,
                    ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.6000000000000001, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
                    DefaultBaseStyle->{},
                    Evaluator->Automatic,
                    Method->"Preemptive"],
                    Hue[0.6000000000000001],
                    Editable->False,
                    Selectable->False], 
                   Offset[{2, 2}, {5.948301867106189, 4.220436508424979}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{6.544562546983033, 3.722896998494484}, 
                   0.05313657305292026], InsetBox[
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{{{
                    {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                    {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                    {Hue[0.65], RectangleBox[{0, -1}, {2, 1}]}}}}},
                    AspectRatio->1,
                    Frame->True,
                    FrameStyle->Hue[0.65, 1., 0.6666666666666667],
                    FrameTicks->None,
                    
                    ImageSize->
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}],
                    PlotRangePadding->None],
                    "Hue[0.65]"],
                    Appearance->None,
                    BaseStyle->{},
                    BaselinePosition->Baseline,
                    ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.65, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
                    DefaultBaseStyle->{},
                    Evaluator->Automatic,
                    Method->"Preemptive"],
                    Hue[0.65],
                    Editable->False,
                    Selectable->False], 
                   Offset[{2, 2}, {6.597699120035953, 3.776033571547404}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{6.947627933840062, 3.2860017960095638}, 
                   0.05313657305292026], InsetBox[
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{{{
                    {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                    {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                    {Hue[0.7000000000000001], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}},
                    AspectRatio->1,
                    Frame->True,
                    
                    FrameStyle->Hue[
                    0.7000000000000001, 1., 0.6666666666666667],
                    FrameTicks->None,
                    
                    ImageSize->
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}],
                    PlotRangePadding->None],
                    "Hue[0.7000000000000001]"],
                    Appearance->None,
                    BaseStyle->{},
                    BaselinePosition->Baseline,
                    ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.7000000000000001, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
                    DefaultBaseStyle->{},
                    Evaluator->Automatic,
                    Method->"Preemptive"],
                    Hue[0.7000000000000001],
                    Editable->False,
                    Selectable->False], 
                   Offset[{2, 2}, {7.000764506892982, 3.339138369062484}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{6.195587386399872, 3.1426908693667572}, 
                   0.05313657305292026], InsetBox[
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{{{
                    {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                    {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                    {Hue[0.75], RectangleBox[{0, -1}, {2, 1}]}}}}},
                    AspectRatio->1,
                    Frame->True,
                    FrameStyle->Hue[0.75, 1., 0.6666666666666667],
                    FrameTicks->None,
                    
                    ImageSize->
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}],
                    PlotRangePadding->None],
                    "Hue[0.75]"],
                    Appearance->None,
                    BaseStyle->{},
                    BaselinePosition->Baseline,
                    ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.75, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
                    DefaultBaseStyle->{},
                    Evaluator->Automatic,
                    Method->"Preemptive"],
                    Hue[0.75],
                    Editable->False,
                    Selectable->False], 
                   Offset[{2, 2}, {6.248723959452792, 3.1958274424196773}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{5.6415439480131315, 2.0435185778788427}, 
                   0.05313657305292026], InsetBox[
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{{{
                    {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                    {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                    {Hue[0.8], RectangleBox[{0, -1}, {2, 1}]}}}}},
                    AspectRatio->1,
                    Frame->True,
                    
                    FrameStyle->Hue[
                    0.8000000000000002, 1., 0.6666666666666667],
                    FrameTicks->None,
                    
                    ImageSize->
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}],
                    PlotRangePadding->None],
                    "Hue[0.8]"],
                    Appearance->None,
                    BaseStyle->{},
                    BaselinePosition->Baseline,
                    ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.8, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
                    DefaultBaseStyle->{},
                    Evaluator->Automatic,
                    Method->"Preemptive"],
                    Hue[0.8],
                    Editable->False,
                    Selectable->False], 
                   Offset[{2, 2}, {5.694680521066052, 2.096655150931763}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{4.847828130982734, 1.13524507606749}, 
                   0.05313657305292026], InsetBox[
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{{{
                    {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                    {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                    {Hue[0.8500000000000001], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}},
                    AspectRatio->1,
                    Frame->True,
                    
                    FrameStyle->Hue[
                    0.8500000000000001, 1., 0.6666666666666667],
                    FrameTicks->None,
                    
                    ImageSize->
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}],
                    PlotRangePadding->None],
                    "Hue[0.8500000000000001]"],
                    Appearance->None,
                    BaseStyle->{},
                    BaselinePosition->Baseline,
                    ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.8500000000000001, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
                    DefaultBaseStyle->{},
                    Evaluator->Automatic,
                    Method->"Preemptive"],
                    Hue[0.8500000000000001],
                    Editable->False,
                    Selectable->False], 
                   Offset[{2, 2}, {4.900964704035654, 1.1883816491204102}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{3.8373612505403942, 0.4748705591256823}, 
                   0.05313657305292026], InsetBox[
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{{{
                    {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                    {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                    {Hue[0.9], RectangleBox[{0, -1}, {2, 1}]}}}}},
                    AspectRatio->1,
                    Frame->True,
                    FrameStyle->Hue[0.9, 1., 0.6666666666666667],
                    FrameTicks->None,
                    
                    ImageSize->
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}],
                    PlotRangePadding->None],
                    "Hue[0.9]"],
                    Appearance->None,
                    BaseStyle->{},
                    BaselinePosition->Baseline,
                    ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.9, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
                    DefaultBaseStyle->{},
                    Evaluator->Automatic,
                    Method->"Preemptive"],
                    Hue[0.9],
                    Editable->False,
                    Selectable->False], 
                   Offset[{2, 2}, {3.8904978235933143, 0.5280071321786026}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{2.676282077786261, 0.1403920737348341}, 
                   0.05313657305292026], InsetBox[
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{{{
                    {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                    {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                    {Hue[0.9500000000000001], 
                    RectangleBox[{0, -1}, {2, 1}]}}}}},
                    AspectRatio->1,
                    Frame->True,
                    
                    FrameStyle->Hue[
                    0.9500000000000001, 1., 0.6666666666666667],
                    FrameTicks->None,
                    
                    ImageSize->
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}],
                    PlotRangePadding->None],
                    "Hue[0.9500000000000001]"],
                    Appearance->None,
                    BaseStyle->{},
                    BaselinePosition->Baseline,
                    ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.9500000000000001, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
                    DefaultBaseStyle->{},
                    Evaluator->Automatic,
                    Method->"Preemptive"],
                    Hue[0.9500000000000001],
                    Editable->False,
                    Selectable->False], 
                   Offset[{2, 2}, {2.729418650839181, 0.19352864678775433}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{1.7338217213167764, 0.}, 0.05313657305292026], 
                  InsetBox[
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{{{
                    {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                    {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                    {Hue[1.], RectangleBox[{0, -1}, {2, 1}]}}}}},
                    AspectRatio->1,
                    Frame->True,
                    FrameStyle->Hue[0., 1., 0.6666666666666667],
                    FrameTicks->None,
                    
                    ImageSize->
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}],
                    PlotRangePadding->None],
                    "Hue[1.]"],
                    Appearance->None,
                    BaseStyle->{},
                    BaselinePosition->Baseline,
                    ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[1., 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
                    DefaultBaseStyle->{},
                    Evaluator->Automatic,
                    Method->"Preemptive"],
                    Hue[1.],
                    Editable->False,
                    Selectable->False], 
                   Offset[{2, 2}, {1.7869582943696967, 0.05313657305292026}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}}}}}}],
           MouseAppearanceTag["NetworkGraphics"]],
          AllowKernelInitialization->False]],
        DefaultBaseStyle->{
         "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
          Hue[0.8, 1., 0.6]},
        FrameTicks->None,
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]]]], "ExerciseOutput",ExpressionUUID->
       "afb99fb2-a613-495d-9072-c1018e1c0332"],
      Apply[TextCell, 
       Cell[
        BoxData[
         GraphicsBox[
          NamespaceBox["NetworkGraphics", 
           DynamicModuleBox[{Typeset`graph = HoldComplete[
               Graph[{
                 Hue[0.], 
                 Hue[0.05], 
                 Hue[0.1], 
                 Hue[0.15000000000000002`], 
                 Hue[0.2], 
                 Hue[0.25], 
                 Hue[0.30000000000000004`], 
                 Hue[0.35000000000000003`], 
                 Hue[0.4], 
                 Hue[0.45], 
                 Hue[0.5], 
                 Hue[0.55], 
                 Hue[0.6000000000000001], 
                 Hue[0.65], 
                 Hue[0.7000000000000001], 
                 Hue[0.75], 
                 Hue[0.8], 
                 Hue[0.8500000000000001], 
                 Hue[0.9], 
                 Hue[0.9500000000000001], 
                 Hue[1.]}, {
                Null, SparseArray[
                 Automatic, {21, 21}, 0, {
                  1, {{0, 3, 5, 6, 7, 8, 10, 12, 13, 14, 15, 16, 17, 19, 21, 
                    22, 23, 24, 25, 26, 27, 28}, {{2}, {20}, {21}, {3}, {
                    21}, {4}, {5}, {6}, {7}, {8}, {8}, {9}, {9}, {10}, {11}, {
                    12}, {13}, {14}, {16}, {15}, {16}, {16}, {17}, {18}, {
                    19}, {20}, {21}, {21}}}, {1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
                    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1}}]}, {
                VertexLabels -> {All}}]]}, 
            TagBox[
             GraphicsGroupBox[{{
                Hue[0.6, 0.7, 0.5], 
                Opacity[0.7], {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{1.8420641773179816`, 0.32130855815221615`}, {
                  1.0665491794795048`, 0.6664282988476327}}, 
                  0.05313657305292026]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{1.8420641773179816`, 0.32130855815221615`}, {
                  2.676282077786261, 0.1403920737348341}}, 
                  0.05313657305292026]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{1.8420641773179816`, 0.32130855815221615`}, {
                  1.7338217213167764`, 0.}}, 0.05313657305292026]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{1.0665491794795048`, 0.6664282988476327}, {
                  0.3615364546912514, 1.6198742882711907`}}, 
                  0.05313657305292026]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{1.0665491794795048`, 0.6664282988476327}, {
                  1.7338217213167764`, 0.}}, 0.05313657305292026]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{0.3615364546912514, 1.6198742882711907`}, {0., 
                  2.7298745776939786`}}, 0.05313657305292026]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{0., 2.7298745776939786`}, {0.008096224632337279, 
                  3.8985025760512433`}}, 0.05313657305292026]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{0.008096224632337279, 3.8985025760512433`}, {
                  0.38155111188984403`, 5.023510173106498}}, 
                  0.05313657305292026]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{0.38155111188984403`, 5.023510173106498}, {
                  1.0114596044540423`, 5.586558862825587}}, 
                  0.05313657305292026]}, {
                 Arrowheads[0.], 
                 ArrowBox[{{0.38155111188984403`, 5.023510173106498}, {
                  0.8046472974003689, 5.858184517107867}}, 
                  0.05313657305292026]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{1.0114596044540423`, 5.586558862825587}, {
                  0.8046472974003689, 5.858184517107867}}, 
                  0.05313657305292026]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{1.0114596044540423`, 5.586558862825587}, {
                  1.7440609967717833`, 6.0094120741862245`}}, 
                  0.05313657305292026]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{0.8046472974003689, 5.858184517107867}, {
                  1.7440609967717833`, 6.0094120741862245`}}, 
                  0.05313657305292026]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{1.7440609967717833`, 6.0094120741862245`}, {
                  2.9402331599797185`, 6.0328115146098735`}}, 
                  0.05313657305292026]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{2.9402331599797185`, 6.0328115146098735`}, {
                  4.078457348971693, 5.70968647057631}}, 
                  0.05313657305292026]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{4.078457348971693, 5.70968647057631}, {
                  5.083763280895914, 5.07568280270236}}, 
                  0.05313657305292026]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{5.083763280895914, 5.07568280270236}, {
                  5.895165294053269, 4.167299935372059}}, 
                  0.05313657305292026]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{5.895165294053269, 4.167299935372059}, {
                  6.544562546983033, 3.722896998494484}}, 
                  0.05313657305292026]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{5.895165294053269, 4.167299935372059}, {
                  6.195587386399872, 3.1426908693667572`}}, 
                  0.05313657305292026]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{6.544562546983033, 3.722896998494484}, {
                  6.947627933840062, 3.2860017960095638`}}, 
                  0.05313657305292026]}, {
                 Arrowheads[0.], 
                 ArrowBox[{{6.544562546983033, 3.722896998494484}, {
                  6.195587386399872, 3.1426908693667572`}}, 
                  0.05313657305292026]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{6.947627933840062, 3.2860017960095638`}, {
                  6.195587386399872, 3.1426908693667572`}}, 
                  0.05313657305292026]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{6.195587386399872, 3.1426908693667572`}, {
                  5.6415439480131315`, 2.0435185778788427`}}, 
                  0.05313657305292026]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{5.6415439480131315`, 2.0435185778788427`}, {
                  4.847828130982734, 1.13524507606749}}, 
                  0.05313657305292026]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{4.847828130982734, 1.13524507606749}, {
                  3.8373612505403942`, 0.4748705591256823}}, 
                  0.05313657305292026]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{3.8373612505403942`, 0.4748705591256823}, {
                  2.676282077786261, 0.1403920737348341}}, 
                  0.05313657305292026]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{2.676282077786261, 0.1403920737348341}, {
                  1.7338217213167764`, 0.}}, 0.05313657305292026]}, {
                 Arrowheads[0.], 
                 ArrowBox[
                  
                  BezierCurveBox[{{1.7338217213167764`, 0.}, {
                   1.887311388804487, -0.1437631971404884}, {
                   1.878605419667176, -0.350299855128179}, {
                   1.7827966771059367`, -0.4526179362073518}, {
                   1.4252776229244422`, -0.3347567502208345}, {
                   1.4091005131900425`, -0.19552095745356066`}, {
                   1.5249281615125974`, -0.024298468056254574`}, {
                   1.7338217213167764`, 0.}}, SplineDegree -> 7], 
                  0.05313657305292026]}}, {
                Hue[0.6, 0.2, 0.8], 
                EdgeForm[{
                  GrayLevel[0], 
                  Opacity[0.7]}], {
                 
                 DiskBox[{1.8420641773179816`, 0.32130855815221615`}, 
                  0.05313657305292026], 
                 InsetBox[
                  InterpretationBox[
                   ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    Hue[0.], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> Hue[0., 1., 0.6666666666666667], 
                    FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], "Hue[0.]"], 
                    Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0., 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                   Hue[0.], Editable -> False, Selectable -> False], 
                  Offset[{2, 2}, {1.8952007503709019`, 0.3744451312051364}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{1.0665491794795048`, 0.6664282988476327}, 
                  0.05313657305292026], 
                 InsetBox[
                  InterpretationBox[
                   ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    Hue[0.05], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    Hue[0.05000000000000001, 1., 0.6666666666666667], 
                    FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "Hue[0.05]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.05, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                   Hue[0.05], Editable -> False, Selectable -> False], 
                  Offset[{2, 2}, {1.119685752532425, 0.719564871900553}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{0.3615364546912514, 1.6198742882711907`}, 
                  0.05313657305292026], 
                 InsetBox[
                  InterpretationBox[
                   ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    Hue[0.1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    Hue[0.10000000000000002`, 1., 0.6666666666666667], 
                    FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], "Hue[0.1]"],
                     Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.1, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                   Hue[0.1], Editable -> False, Selectable -> False], 
                  Offset[{2, 2}, {0.41467302774417164`, 1.673010861324111}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 DiskBox[{0., 2.7298745776939786`}, 0.05313657305292026], 
                 InsetBox[
                  InterpretationBox[
                   ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    Hue[0.15000000000000002`], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> Hue[0.15, 1., 0.6666666666666667], 
                    FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "Hue[0.15000000000000002]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.15000000000000002`, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                   Hue[0.15000000000000002`], Editable -> False, Selectable -> 
                   False], 
                  Offset[{2, 2}, {0.05313657305292026, 2.7830111507468986`}], 
                  
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{0.008096224632337279, 3.8985025760512433`}, 
                  0.05313657305292026], 
                 InsetBox[
                  InterpretationBox[
                   ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    Hue[0.2], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    Hue[0.20000000000000004`, 1., 0.6666666666666667], 
                    FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], "Hue[0.2]"],
                     Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.2, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                   Hue[0.2], Editable -> False, Selectable -> False], 
                  Offset[{2, 2}, {0.06123279768525754, 3.9516391491041634`}], 
                  
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{0.38155111188984403`, 5.023510173106498}, 
                  0.05313657305292026], 
                 InsetBox[
                  InterpretationBox[
                   ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    Hue[0.25], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> Hue[0.25, 1., 0.6666666666666667], 
                    FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "Hue[0.25]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.25, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                   Hue[0.25], Editable -> False, Selectable -> False], 
                  Offset[{2, 2}, {0.4346876849427643, 5.076646746159418}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{1.0114596044540423`, 5.586558862825587}, 
                  0.05313657305292026], 
                 InsetBox[
                  InterpretationBox[
                   ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    Hue[0.30000000000000004`], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    Hue[0.30000000000000004`, 1., 0.6666666666666667], 
                    FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "Hue[0.30000000000000004]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.30000000000000004`, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                   Hue[0.30000000000000004`], Editable -> False, Selectable -> 
                   False], 
                  Offset[{2, 2}, {1.0645961775069626`, 5.639695435878507}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{0.8046472974003689, 5.858184517107867}, 
                  0.05313657305292026], 
                 InsetBox[
                  InterpretationBox[
                   ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    Hue[0.35000000000000003`], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    Hue[0.35000000000000003`, 1., 0.6666666666666667], 
                    FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "Hue[0.35000000000000003]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.35000000000000003`, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                   Hue[0.35000000000000003`], Editable -> False, Selectable -> 
                   False], 
                  Offset[{2, 2}, {0.8577838704532892, 5.911321090160787}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{1.7440609967717833`, 6.0094120741862245`}, 
                  0.05313657305292026], 
                 InsetBox[
                  InterpretationBox[
                   ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    Hue[0.4], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    Hue[0.4000000000000001, 1., 0.6666666666666667], 
                    FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], "Hue[0.4]"],
                     Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.4, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                   Hue[0.4], Editable -> False, Selectable -> False], 
                  Offset[{2, 2}, {1.7971975698247036`, 6.0625486472391446`}], 
                  
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{2.9402331599797185`, 6.0328115146098735`}, 
                  0.05313657305292026], 
                 InsetBox[
                  InterpretationBox[
                   ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    Hue[0.45], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> Hue[0.45, 1., 0.6666666666666667], 
                    FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "Hue[0.45]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.45, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                   Hue[0.45], Editable -> False, Selectable -> False], 
                  Offset[{2, 2}, {2.9933697330326385`, 6.085948087662794}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{4.078457348971693, 5.70968647057631}, 
                  0.05313657305292026], 
                 InsetBox[
                  InterpretationBox[
                   ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    Hue[0.5], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> Hue[0.5, 1., 0.6666666666666667], 
                    FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], "Hue[0.5]"],
                     Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.5, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                   Hue[0.5], Editable -> False, Selectable -> False], 
                  Offset[{2, 2}, {4.131593922024613, 5.76282304362923}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{5.083763280895914, 5.07568280270236}, 
                  0.05313657305292026], 
                 InsetBox[
                  InterpretationBox[
                   ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    Hue[0.55], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> Hue[0.55, 1., 0.6666666666666667], 
                    FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "Hue[0.55]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.55, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                   Hue[0.55], Editable -> False, Selectable -> False], 
                  Offset[{2, 2}, {5.136899853948834, 5.12881937575528}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{5.895165294053269, 4.167299935372059}, 
                  0.05313657305292026], 
                 InsetBox[
                  InterpretationBox[
                   ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    Hue[0.6000000000000001], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    Hue[0.6000000000000001, 1., 0.6666666666666667], 
                    FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "Hue[0.6000000000000001]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.6000000000000001, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                   Hue[0.6000000000000001], Editable -> False, Selectable -> 
                   False], 
                  Offset[{2, 2}, {5.948301867106189, 4.220436508424979}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{6.544562546983033, 3.722896998494484}, 
                  0.05313657305292026], 
                 InsetBox[
                  InterpretationBox[
                   ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    Hue[0.65], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> Hue[0.65, 1., 0.6666666666666667], 
                    FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "Hue[0.65]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.65, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                   Hue[0.65], Editable -> False, Selectable -> False], 
                  Offset[{2, 2}, {6.597699120035953, 3.776033571547404}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{6.947627933840062, 3.2860017960095638`}, 
                  0.05313657305292026], 
                 InsetBox[
                  InterpretationBox[
                   ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    Hue[0.7000000000000001], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    Hue[0.7000000000000001, 1., 0.6666666666666667], 
                    FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "Hue[0.7000000000000001]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.7000000000000001, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                   Hue[0.7000000000000001], Editable -> False, Selectable -> 
                   False], 
                  Offset[{2, 2}, {7.000764506892982, 3.339138369062484}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{6.195587386399872, 3.1426908693667572`}, 
                  0.05313657305292026], 
                 InsetBox[
                  InterpretationBox[
                   ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    Hue[0.75], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> Hue[0.75, 1., 0.6666666666666667], 
                    FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "Hue[0.75]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.75, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                   Hue[0.75], Editable -> False, Selectable -> False], 
                  Offset[{2, 2}, {6.248723959452792, 3.1958274424196773`}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 DiskBox[{5.6415439480131315`, 2.0435185778788427`}, 
                  0.05313657305292026], 
                 InsetBox[
                  InterpretationBox[
                   ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    Hue[0.8], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    Hue[0.8000000000000002, 1., 0.6666666666666667], 
                    FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], "Hue[0.8]"],
                     Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.8, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                   Hue[0.8], Editable -> False, Selectable -> False], 
                  Offset[{2, 2}, {5.694680521066052, 2.096655150931763}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{4.847828130982734, 1.13524507606749}, 
                  0.05313657305292026], 
                 InsetBox[
                  InterpretationBox[
                   ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    Hue[0.8500000000000001], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    Hue[0.8500000000000001, 1., 0.6666666666666667], 
                    FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "Hue[0.8500000000000001]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.8500000000000001, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                   Hue[0.8500000000000001], Editable -> False, Selectable -> 
                   False], 
                  Offset[{2, 2}, {4.900964704035654, 1.1883816491204102`}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{3.8373612505403942`, 0.4748705591256823}, 
                  0.05313657305292026], 
                 InsetBox[
                  InterpretationBox[
                   ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    Hue[0.9], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> Hue[0.9, 1., 0.6666666666666667], 
                    FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], "Hue[0.9]"],
                     Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.9, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                   Hue[0.9], Editable -> False, Selectable -> False], 
                  Offset[{2, 2}, {3.8904978235933143`, 0.5280071321786026}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{2.676282077786261, 0.1403920737348341}, 
                  0.05313657305292026], 
                 InsetBox[
                  InterpretationBox[
                   ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    Hue[0.9500000000000001], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    Hue[0.9500000000000001, 1., 0.6666666666666667], 
                    FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "Hue[0.9500000000000001]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.9500000000000001, 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                   Hue[0.9500000000000001], Editable -> False, Selectable -> 
                   False], 
                  Offset[{2, 2}, {2.729418650839181, 0.19352864678775433`}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 DiskBox[{1.7338217213167764`, 0.}, 0.05313657305292026], 
                 InsetBox[
                  InterpretationBox[
                   ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    Hue[1.], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> Hue[0., 1., 0.6666666666666667], 
                    FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], "Hue[1.]"], 
                    Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[1., 0.5, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                   Hue[1.], Editable -> False, Selectable -> False], 
                  Offset[{2, 2}, {1.7869582943696967`, 0.05313657305292026}], 
                  
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}}}], 
             MouseAppearanceTag["NetworkGraphics"]], 
            AllowKernelInitialization -> False]], 
          DefaultBaseStyle -> {
           "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
            Hue[0.8, 1., 0.6]}, FrameTicks -> None, GridLinesStyle -> 
          Directive[
            GrayLevel[0.5, 0.4]]]], "ExerciseOutput", Selectable -> False, 
        Copyable -> False, Editable -> False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"e1356f8f-f9a6-4551-ab7f-810a54ae1007"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Generate a list of 100 random numbers from 0 to 100, and make a graph of \
the 2 nearest neighbors of each one.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "22.11", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"afd20ffc-e506-48d6-a48c-66265b70cbe5"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Sample", " ", "expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       GraphicsBox[
        NamespaceBox["NetworkGraphics",
         DynamicModuleBox[{Typeset`graph = HoldComplete[
           
           Graph[{10, 69, 30, 19, 48, 99, 93, 75, 36, 5, 43, 79, 47, 82, 21, 
            68, 62, 88, 11, 26, 90, 100, 65, 35, 1, 13, 27, 24, 96, 95, 16, 
            29, 77}, {Null, 
             SparseArray[
             Automatic, {33, 33}, 0, {
              1, {{0, 4, 6, 10, 12, 14, 16, 19, 21, 23, 25, 27, 30, 32, 34, 
                36, 39, 41, 43, 45, 47, 49, 51, 54, 56, 58, 61, 64, 66, 69, 
                71, 73, 75, 78}, {{10}, {19}, {25}, {26}, {16}, {23}, {9}, {
                24}, {27}, {32}, {15}, {31}, {11}, {13}, {22}, {29}, {18}, {
                21}, {30}, {12}, {33}, {3}, {24}, {1}, {25}, {5}, {13}, {8}, {
                14}, {33}, {5}, {11}, {12}, {33}, {4}, {28}, {2}, {17}, {
                23}, {16}, {23}, {7}, {21}, {1}, {26}, {27}, {28}, {7}, {
                18}, {6}, {29}, {2}, {16}, {17}, {3}, {9}, {1}, {10}, {1}, {
                19}, {31}, {3}, {20}, {32}, {15}, {20}, {6}, {22}, {30}, {
                7}, {29}, {4}, {26}, {3}, {27}, {8}, {12}, {14}}}, 
               Pattern}]}, {VertexLabels -> {All}}]]}, 
          TagBox[GraphicsGroupBox[{{{{
                {Hue[0.6, 0.7, 0.5], Opacity[0.7], {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{1.4698040750396784`, -1.0073312235012324`}, {
                    0.623558208516048, -0.8270698415161517}}, 
                    0.07160324889883254]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{1.4698040750396784`, -1.0073312235012324`}, {
                    2.015707524455916, -0.7226833125475514}}, 
                    0.07160324889883254]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{1.4698040750396784`, -1.0073312235012324`}, {
                    0.6791981456723262, -1.3396955594051985`}}, 
                    0.07160324889883254]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{1.4698040750396784`, -1.0073312235012324`}, {
                    2.653820635964625, -0.9498121495677305}}, 
                    0.07160324889883254]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{8.524927318764899, -3.0222888665686773`}, {
                    7.590896303435223, -3.4563823756146217`}}, 
                    0.07160324889883254]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{8.524927318764899, -3.0222888665686773`}, {
                    7.59229833972008, -2.5868119764372937`}}, 
                    0.07160324889883254]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{11.589914111179747`, -0.9531546477444116}, {
                    12.382432199836519`, -0.6235582085160476}}, 
                    0.07160324889883254]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{11.589914111179747`, -0.9531546477444116}, {
                    12.434819477737406`, -1.1358513111828343`}}, 
                    0.07160324889883254]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{11.589914111179747`, -0.9531546477444116}, {
                    10.40614867754882, -1.007246725936377}}, 
                    0.07160324889883254]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{11.589914111179747`, -0.9531546477444116}, {
                    11.043565088476479`, -1.2354364283172665`}}, 
                    0.07160324889883254]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{5.2373001125987155`, -0.9688678620846822}, {
                    6.531320260404658, -0.9761739225168616}}, 
                    0.07160324889883254]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{5.2373001125987155`, -0.9688678620846822}, {
                    3.9456718437450693`, -0.9612421302664788}}, 
                    0.07160324889883254]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{1.120480423897308, -5.571293816276586}, {
                    1.6235518653185617`, -4.707048875930637}}, 
                    0.07160324889883254]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{1.120480423897308, -5.571293816276586}, {
                    0.6235582085160476, -4.703498792646718}}, 
                    0.07160324889883254]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{0.6241064896393222, -3.363097265353095}, {
                    0.6235582085160472, -2.6801962813960865`}}, 
                    0.07160324889883254]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{0.6241064896393222, -3.363097265353095}, {
                    1.5288506598086575`, -3.0214509266159544`}}, 
                    0.07160324889883254]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{4.1086213229066155`, -3.021537814968986}, {
                    5.012655262003232, -2.6798811194161076`}}, 
                    0.07160324889883254]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{4.1086213229066155`, -3.021537814968986}, {
                    5.012416985273892, -3.363313232635808}}, 
                    0.07160324889883254]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{4.1086213229066155`, -3.021537814968986}, {
                    2.8194457901038503`, -3.0214690769113344`}}, 
                    0.07160324889883254]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{12.037199375526567`, -3.0222888665686773`}, {
                    11.103168360196891`, -3.4563823756146217`}}, 
                    0.07160324889883254]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{12.037199375526567`, -3.0222888665686773`}, {
                    11.104570396481748`, -2.5868119764372937`}}, 
                    0.07160324889883254]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{12.382432199836519`, -0.6235582085160476}, {
                    12.434819477737406`, -1.1358513111828343`}}, 
                    0.07160324889883254]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{0.623558208516048, -0.8270698415161517}, {
                    0.6791981456723262, -1.3396955594051985`}}, 
                    0.07160324889883254]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{1.6235518653185617`, -4.707048875930637}, {
                    0.6235582085160476, -4.703498792646718}}, 
                    0.07160324889883254]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{11.103168360196891`, -3.4563823756146217`}, {
                    10.169663838007835`, -3.021635872839666}}, 
                    0.07160324889883254]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{11.103168360196891`, -3.4563823756146217`}, {
                    11.104570396481748`, -2.5868119764372937`}}, 
                    0.07160324889883254]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{10.169663838007835`, -3.021635872839666}, {
                    11.104570396481748`, -2.5868119764372937`}}, 
                    0.07160324889883254]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{6.531320260404658, -0.9761739225168616}, {
                    7.825205362065807, -0.9844603878267566}}, 
                    0.07160324889883254]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{7.590896303435223, -3.4563823756146217`}, {
                    6.657391781246168, -3.021635872839666}}, 
                    0.07160324889883254]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{7.590896303435223, -3.4563823756146217`}, {
                    7.59229833972008, -2.5868119764372937`}}, 
                    0.07160324889883254]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{6.657391781246168, -3.021635872839666}, {
                    7.59229833972008, -2.5868119764372937`}}, 
                    0.07160324889883254]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{5.012655262003232, -2.6798811194161076`}, {
                    5.012416985273892, -3.363313232635808}}, 
                    0.07160324889883254]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{2.015707524455916, -0.7226833125475514}, {
                    2.653820635964625, -0.9498121495677305}}, 
                    0.07160324889883254]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{9.11446929725064, -0.9936774985177124}, {
                    10.40614867754882, -1.007246725936377}}, 
                    0.07160324889883254]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{9.11446929725064, -0.9936774985177124}, {
                    7.825205362065807, -0.9844603878267566}}, 
                    0.07160324889883254]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{0.6235582085160472, -2.6801962813960865`}, {
                    1.5288506598086575`, -3.0214509266159544`}}, 
                    0.07160324889883254]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{2.653820635964625, -0.9498121495677305}, {
                    3.9456718437450693`, -0.9612421302664788}}, 
                    0.07160324889883254]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{10.40614867754882, -1.007246725936377}, {
                    11.043565088476479`, -1.2354364283172665`}}, 
                    0.07160324889883254]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{1.5288506598086575`, -3.0214509266159544`}, {
                    2.8194457901038503`, -3.0214690769113344`}}, 
                    0.07160324889883254]}}}}}}}}, {{{
                {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
                 0.7]}], {
                  DiskBox[{1.4698040750396784, -1.0073312235012324}, 
                   0.07160324889883254], 
                  InsetBox["10", 
                   Offset[{2, 2}, {1.5414073239385109, -0.9357279746023999}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{8.524927318764899, -3.0222888665686773}, 
                   0.07160324889883254], 
                  InsetBox["69", 
                   Offset[{2, 2}, {8.59653056766373, -2.9506856176698446}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{11.589914111179747, -0.9531546477444116}, 
                   0.07160324889883254], 
                  InsetBox["30", 
                   Offset[{2, 2}, {11.661517360078578, -0.8815513988455791}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{5.2373001125987155, -0.9688678620846822}, 
                   0.07160324889883254], 
                  InsetBox["19", 
                   Offset[{2, 2}, {5.308903361497548, -0.8972646131858497}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{1.120480423897308, -5.571293816276586}, 
                   0.07160324889883254], 
                  InsetBox["48", 
                   Offset[{2, 2}, {1.1920836727961406, -5.499690567377753}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{0.6241064896393222, -3.363097265353095}, 
                   0.07160324889883254], 
                  InsetBox["99", 
                   Offset[{2, 2}, {0.6957097385381548, -3.291494016454262}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{4.1086213229066155, -3.021537814968986}, 
                   0.07160324889883254], 
                  InsetBox["93", 
                   Offset[{2, 2}, {4.180224571805448, -2.9499345660701533}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{12.037199375526567, -3.0222888665686773}, 
                   0.07160324889883254], 
                  InsetBox["75", 
                   Offset[{2, 2}, {12.1088026244254, -2.9506856176698446}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{12.382432199836519, -0.6235582085160476}, 
                   0.07160324889883254], 
                  InsetBox["36", 
                   Offset[{2, 2}, {12.45403544873535, -0.5519549596172151}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{0.623558208516048, -0.8270698415161517}, 
                   0.07160324889883254], 
                  InsetBox["5", 
                   Offset[{2, 2}, {0.6951614574148806, -0.7554665926173192}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{1.6235518653185617, -4.707048875930637}, 
                   0.07160324889883254], 
                  InsetBox["43", 
                   Offset[{2, 2}, {1.6951551142173942, -4.635445627031804}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{11.103168360196891, -3.4563823756146217}, 
                   0.07160324889883254], 
                  InsetBox["79", 
                   Offset[{2, 2}, {11.174771609095723, -3.384779126715789}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{0.6235582085160476, -4.703498792646718}, 
                   0.07160324889883254], 
                  InsetBox["47", 
                   Offset[{2, 2}, {0.6951614574148801, -4.631895543747885}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{10.169663838007835, -3.021635872839666}, 
                   0.07160324889883254], 
                  InsetBox["82", 
                   Offset[{2, 2}, {10.241267086906667, -2.9500326239408334}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{6.531320260404658, -0.9761739225168616}, 
                   0.07160324889883254], 
                  InsetBox["21", 
                   Offset[{2, 2}, {6.602923509303491, -0.9045706736180291}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{7.590896303435223, -3.4563823756146217}, 
                   0.07160324889883254], 
                  InsetBox["68", 
                   Offset[{2, 2}, {7.662499552334055, -3.384779126715789}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{6.657391781246168, -3.021635872839666}, 
                   0.07160324889883254], 
                  InsetBox["62", 
                   Offset[{2, 2}, {6.7289950301450006, -2.9500326239408334}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{5.012655262003232, -2.6798811194161076}, 
                   0.07160324889883254], 
                  InsetBox["88", 
                   Offset[{2, 2}, {5.084258510902065, -2.608277870517275}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{2.015707524455916, -0.7226833125475514}, 
                   0.07160324889883254], 
                  InsetBox["11", 
                   Offset[{2, 2}, {2.0873107733547487, -0.6510800636487188}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{9.11446929725064, -0.9936774985177124}, 
                   0.07160324889883254], 
                  InsetBox["26", 
                   Offset[{2, 2}, {9.186072546149472, -0.9220742496188798}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{5.012416985273892, -3.363313232635808}, 
                   0.07160324889883254], 
                  InsetBox["90", 
                   Offset[{2, 2}, {5.0840202341727245, -3.2917099837369754}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{0.6235582085160472, -2.6801962813960865}, 
                   0.07160324889883254], 
                  InsetBox["100", 
                   Offset[{2, 2}, {0.6951614574148797, -2.6085930324972537}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{7.59229833972008, -2.5868119764372937}, 
                   0.07160324889883254], 
                  InsetBox["65", 
                   Offset[{2, 2}, {7.663901588618913, -2.515208727538461}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{12.434819477737406, -1.1358513111828343}, 
                   0.07160324889883254], 
                  InsetBox["35", 
                   Offset[{2, 2}, {12.506422726636238, -1.0642480622840018}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{0.6791981456723262, -1.3396955594051985}, 
                   0.07160324889883254], 
                  InsetBox["1", 
                   Offset[{2, 2}, {0.7508013945711587, -1.268092310506366}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{2.653820635964625, -0.9498121495677305}, 
                   0.07160324889883254], 
                  InsetBox["13", 
                   Offset[{2, 2}, {2.7254238848634578, -0.878208900668898}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{10.40614867754882, -1.007246725936377}, 
                   0.07160324889883254], 
                  InsetBox["27", 
                   Offset[{2, 2}, {10.477751926447652, -0.9356434770375446}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{7.825205362065807, -0.9844603878267566}, 
                   0.07160324889883254], 
                  InsetBox["24", 
                   Offset[{2, 2}, {7.89680861096464, -0.9128571389279241}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{1.5288506598086575, -3.0214509266159544}, 
                   0.07160324889883254], 
                  InsetBox["96", 
                   Offset[{2, 2}, {1.60045390870749, -2.9498476777171216}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{2.8194457901038503, -3.0214690769113344}, 
                   0.07160324889883254], 
                  InsetBox["95", 
                   Offset[{2, 2}, {2.891049039002683, -2.9498658280125016}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{3.9456718437450693, -0.9612421302664788}, 
                   0.07160324889883254], 
                  InsetBox["16", 
                   Offset[{2, 2}, {4.017275092643902, -0.8896388813676462}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{11.043565088476479, -1.2354364283172665}, 
                   0.07160324889883254], 
                  InsetBox["29", 
                   Offset[{2, 2}, {11.11516833737531, -1.163833179418434}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{11.104570396481748, -2.5868119764372937}, 
                   0.07160324889883254], 
                  InsetBox["77", 
                   Offset[{2, 2}, {11.17617364538058, -2.515208727538461}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}}}}}}],
           MouseAppearanceTag["NetworkGraphics"]],
          AllowKernelInitialization->False]],
        DefaultBaseStyle->{
         "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
          Hue[0.8, 1., 0.6]},
        FormatType->TraditionalForm,
        FrameTicks->None,
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        ImageMargins->{{24.23828125, 250.20703125}, {1.734375, 0.34765625}},
        ImageSize->{563.10546875, Automatic}]], "ExerciseOutput",
       ExpressionUUID->"37bbb659-3e69-4166-9c57-7b5cc5eef40b"],
      Apply[TextCell, 
       Cell[
        BoxData[
         GraphicsBox[
          NamespaceBox["NetworkGraphics", 
           DynamicModuleBox[{Typeset`graph = HoldComplete[
               
               Graph[{10, 69, 30, 19, 48, 99, 93, 75, 36, 5, 43, 79, 47, 82, 
                21, 68, 62, 88, 11, 26, 90, 100, 65, 35, 1, 13, 27, 24, 96, 
                95, 16, 29, 77}, {Null, 
                 SparseArray[
                 Automatic, {33, 33}, 0, {
                  1, {{0, 4, 6, 10, 12, 14, 16, 19, 21, 23, 25, 27, 30, 32, 
                    34, 36, 39, 41, 43, 45, 47, 49, 51, 54, 56, 58, 61, 64, 
                    66, 69, 71, 73, 75, 78}, {{10}, {19}, {25}, {26}, {16}, {
                    23}, {9}, {24}, {27}, {32}, {15}, {31}, {11}, {13}, {
                    22}, {29}, {18}, {21}, {30}, {12}, {33}, {3}, {24}, {1}, {
                    25}, {5}, {13}, {8}, {14}, {33}, {5}, {11}, {12}, {33}, {
                    4}, {28}, {2}, {17}, {23}, {16}, {23}, {7}, {21}, {1}, {
                    26}, {27}, {28}, {7}, {18}, {6}, {29}, {2}, {16}, {17}, {
                    3}, {9}, {1}, {10}, {1}, {19}, {31}, {3}, {20}, {32}, {
                    15}, {20}, {6}, {22}, {30}, {7}, {29}, {4}, {26}, {3}, {
                    27}, {8}, {12}, {14}}}, Pattern}]}, {
                VertexLabels -> {All}}]]}, 
            TagBox[
             GraphicsGroupBox[{{
                Hue[0.6, 0.7, 0.5], 
                Opacity[0.7], {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{1.4698040750396784`, -1.0073312235012324`}, {
                  0.623558208516048, -0.8270698415161517}}, 
                  0.07160324889883254]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{1.4698040750396784`, -1.0073312235012324`}, {
                  2.015707524455916, -0.7226833125475514}}, 
                  0.07160324889883254]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{1.4698040750396784`, -1.0073312235012324`}, {
                  0.6791981456723262, -1.3396955594051985`}}, 
                  0.07160324889883254]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{1.4698040750396784`, -1.0073312235012324`}, {
                  2.653820635964625, -0.9498121495677305}}, 
                  0.07160324889883254]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{8.524927318764899, -3.0222888665686773`}, {
                  7.590896303435223, -3.4563823756146217`}}, 
                  0.07160324889883254]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{8.524927318764899, -3.0222888665686773`}, {
                  7.59229833972008, -2.5868119764372937`}}, 
                  0.07160324889883254]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{11.589914111179747`, -0.9531546477444116}, {
                  12.382432199836519`, -0.6235582085160476}}, 
                  0.07160324889883254]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{11.589914111179747`, -0.9531546477444116}, {
                  12.434819477737406`, -1.1358513111828343`}}, 
                  0.07160324889883254]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{11.589914111179747`, -0.9531546477444116}, {
                  10.40614867754882, -1.007246725936377}}, 
                  0.07160324889883254]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{11.589914111179747`, -0.9531546477444116}, {
                  11.043565088476479`, -1.2354364283172665`}}, 
                  0.07160324889883254]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{5.2373001125987155`, -0.9688678620846822}, {
                  6.531320260404658, -0.9761739225168616}}, 
                  0.07160324889883254]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{5.2373001125987155`, -0.9688678620846822}, {
                  3.9456718437450693`, -0.9612421302664788}}, 
                  0.07160324889883254]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{1.120480423897308, -5.571293816276586}, {
                  1.6235518653185617`, -4.707048875930637}}, 
                  0.07160324889883254]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{1.120480423897308, -5.571293816276586}, {
                  0.6235582085160476, -4.703498792646718}}, 
                  0.07160324889883254]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{0.6241064896393222, -3.363097265353095}, {
                  0.6235582085160472, -2.6801962813960865`}}, 
                  0.07160324889883254]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{0.6241064896393222, -3.363097265353095}, {
                  1.5288506598086575`, -3.0214509266159544`}}, 
                  0.07160324889883254]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{4.1086213229066155`, -3.021537814968986}, {
                  5.012655262003232, -2.6798811194161076`}}, 
                  0.07160324889883254]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{4.1086213229066155`, -3.021537814968986}, {
                  5.012416985273892, -3.363313232635808}}, 
                  0.07160324889883254]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{4.1086213229066155`, -3.021537814968986}, {
                  2.8194457901038503`, -3.0214690769113344`}}, 
                  0.07160324889883254]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{12.037199375526567`, -3.0222888665686773`}, {
                  11.103168360196891`, -3.4563823756146217`}}, 
                  0.07160324889883254]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{12.037199375526567`, -3.0222888665686773`}, {
                  11.104570396481748`, -2.5868119764372937`}}, 
                  0.07160324889883254]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{12.382432199836519`, -0.6235582085160476}, {
                  12.434819477737406`, -1.1358513111828343`}}, 
                  0.07160324889883254]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{0.623558208516048, -0.8270698415161517}, {
                  0.6791981456723262, -1.3396955594051985`}}, 
                  0.07160324889883254]}, {
                 Arrowheads[0.], 
                 ArrowBox[{{1.6235518653185617`, -4.707048875930637}, {
                  0.6235582085160476, -4.703498792646718}}, 
                  0.07160324889883254]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{11.103168360196891`, -3.4563823756146217`}, {
                  10.169663838007835`, -3.021635872839666}}, 
                  0.07160324889883254]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{11.103168360196891`, -3.4563823756146217`}, {
                  11.104570396481748`, -2.5868119764372937`}}, 
                  0.07160324889883254]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{10.169663838007835`, -3.021635872839666}, {
                  11.104570396481748`, -2.5868119764372937`}}, 
                  0.07160324889883254]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{6.531320260404658, -0.9761739225168616}, {
                  7.825205362065807, -0.9844603878267566}}, 
                  0.07160324889883254]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{7.590896303435223, -3.4563823756146217`}, {
                  6.657391781246168, -3.021635872839666}}, 
                  0.07160324889883254]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{7.590896303435223, -3.4563823756146217`}, {
                  7.59229833972008, -2.5868119764372937`}}, 
                  0.07160324889883254]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{6.657391781246168, -3.021635872839666}, {
                  7.59229833972008, -2.5868119764372937`}}, 
                  0.07160324889883254]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{5.012655262003232, -2.6798811194161076`}, {
                  5.012416985273892, -3.363313232635808}}, 
                  0.07160324889883254]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{2.015707524455916, -0.7226833125475514}, {
                  2.653820635964625, -0.9498121495677305}}, 
                  0.07160324889883254]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{9.11446929725064, -0.9936774985177124}, {
                  10.40614867754882, -1.007246725936377}}, 
                  0.07160324889883254]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{9.11446929725064, -0.9936774985177124}, {
                  7.825205362065807, -0.9844603878267566}}, 
                  0.07160324889883254]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{0.6235582085160472, -2.6801962813960865`}, {
                  1.5288506598086575`, -3.0214509266159544`}}, 
                  0.07160324889883254]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{2.653820635964625, -0.9498121495677305}, {
                  3.9456718437450693`, -0.9612421302664788}}, 
                  0.07160324889883254]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{10.40614867754882, -1.007246725936377}, {
                  11.043565088476479`, -1.2354364283172665`}}, 
                  0.07160324889883254]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{1.5288506598086575`, -3.0214509266159544`}, {
                  2.8194457901038503`, -3.0214690769113344`}}, 
                  0.07160324889883254]}}, {
                Hue[0.6, 0.2, 0.8], 
                EdgeForm[{
                  GrayLevel[0], 
                  Opacity[0.7]}], {
                 
                 DiskBox[{1.4698040750396784`, -1.0073312235012324`}, 
                  0.07160324889883254], 
                 InsetBox["10", 
                  Offset[{2, 2}, {1.5414073239385109`, -0.9357279746023999}], 
                  
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{8.524927318764899, -3.0222888665686773`}, 
                  0.07160324889883254], 
                 InsetBox["69", 
                  Offset[{2, 2}, {8.59653056766373, -2.9506856176698446`}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{11.589914111179747`, -0.9531546477444116}, 
                  0.07160324889883254], 
                 InsetBox["30", 
                  Offset[{2, 2}, {11.661517360078578`, -0.8815513988455791}], 
                  
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{5.2373001125987155`, -0.9688678620846822}, 
                  0.07160324889883254], 
                 InsetBox["19", 
                  Offset[{2, 2}, {5.308903361497548, -0.8972646131858497}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{1.120480423897308, -5.571293816276586}, 
                  0.07160324889883254], 
                 InsetBox["48", 
                  Offset[{2, 2}, {1.1920836727961406`, -5.499690567377753}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{0.6241064896393222, -3.363097265353095}, 
                  0.07160324889883254], 
                 InsetBox["99", 
                  Offset[{2, 2}, {0.6957097385381548, -3.291494016454262}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{4.1086213229066155`, -3.021537814968986}, 
                  0.07160324889883254], 
                 InsetBox["93", 
                  Offset[{2, 2}, {4.180224571805448, -2.9499345660701533`}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{12.037199375526567`, -3.0222888665686773`}, 
                  0.07160324889883254], 
                 InsetBox["75", 
                  Offset[{2, 2}, {12.1088026244254, -2.9506856176698446`}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{12.382432199836519`, -0.6235582085160476}, 
                  0.07160324889883254], 
                 InsetBox["36", 
                  Offset[{2, 2}, {12.45403544873535, -0.5519549596172151}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{0.623558208516048, -0.8270698415161517}, 
                  0.07160324889883254], 
                 InsetBox["5", 
                  Offset[{2, 2}, {0.6951614574148806, -0.7554665926173192}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{1.6235518653185617`, -4.707048875930637}, 
                  0.07160324889883254], 
                 InsetBox["43", 
                  Offset[{2, 2}, {1.6951551142173942`, -4.635445627031804}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{11.103168360196891`, -3.4563823756146217`}, 
                  0.07160324889883254], 
                 InsetBox["79", 
                  Offset[{2, 2}, {11.174771609095723`, -3.384779126715789}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{0.6235582085160476, -4.703498792646718}, 
                  0.07160324889883254], 
                 InsetBox["47", 
                  Offset[{2, 2}, {0.6951614574148801, -4.631895543747885}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{10.169663838007835`, -3.021635872839666}, 
                  0.07160324889883254], 
                 InsetBox["82", 
                  Offset[{2, 2}, {10.241267086906667`, -2.9500326239408334`}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{6.531320260404658, -0.9761739225168616}, 
                  0.07160324889883254], 
                 InsetBox["21", 
                  Offset[{2, 2}, {6.602923509303491, -0.9045706736180291}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{7.590896303435223, -3.4563823756146217`}, 
                  0.07160324889883254], 
                 InsetBox["68", 
                  Offset[{2, 2}, {7.662499552334055, -3.384779126715789}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{6.657391781246168, -3.021635872839666}, 
                  0.07160324889883254], 
                 InsetBox["62", 
                  Offset[{2, 2}, {6.7289950301450006`, -2.9500326239408334`}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{5.012655262003232, -2.6798811194161076`}, 
                  0.07160324889883254], 
                 InsetBox["88", 
                  Offset[{2, 2}, {5.084258510902065, -2.608277870517275}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{2.015707524455916, -0.7226833125475514}, 
                  0.07160324889883254], 
                 InsetBox["11", 
                  Offset[{2, 2}, {2.0873107733547487`, -0.6510800636487188}], 
                  
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{9.11446929725064, -0.9936774985177124}, 
                  0.07160324889883254], 
                 InsetBox["26", 
                  Offset[{2, 2}, {9.186072546149472, -0.9220742496188798}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{5.012416985273892, -3.363313232635808}, 
                  0.07160324889883254], 
                 InsetBox["90", 
                  Offset[{2, 2}, {5.0840202341727245`, -3.2917099837369754`}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{0.6235582085160472, -2.6801962813960865`}, 
                  0.07160324889883254], 
                 InsetBox["100", 
                  Offset[{2, 2}, {0.6951614574148797, -2.6085930324972537`}], 
                  
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{7.59229833972008, -2.5868119764372937`}, 
                  0.07160324889883254], 
                 InsetBox["65", 
                  Offset[{2, 2}, {7.663901588618913, -2.515208727538461}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{12.434819477737406`, -1.1358513111828343`}, 
                  0.07160324889883254], 
                 InsetBox["35", 
                  Offset[{2, 2}, {12.506422726636238`, -1.0642480622840018`}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{0.6791981456723262, -1.3396955594051985`}, 
                  0.07160324889883254], 
                 InsetBox["1", 
                  Offset[{2, 2}, {0.7508013945711587, -1.268092310506366}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{2.653820635964625, -0.9498121495677305}, 
                  0.07160324889883254], 
                 InsetBox["13", 
                  Offset[{2, 2}, {2.7254238848634578`, -0.878208900668898}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{10.40614867754882, -1.007246725936377}, 
                  0.07160324889883254], 
                 InsetBox["27", 
                  Offset[{2, 2}, {10.477751926447652`, -0.9356434770375446}], 
                  
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{7.825205362065807, -0.9844603878267566}, 
                  0.07160324889883254], 
                 InsetBox["24", 
                  Offset[{2, 2}, {7.89680861096464, -0.9128571389279241}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{1.5288506598086575`, -3.0214509266159544`}, 
                  0.07160324889883254], 
                 InsetBox["96", 
                  Offset[{2, 2}, {1.60045390870749, -2.9498476777171216`}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{2.8194457901038503`, -3.0214690769113344`}, 
                  0.07160324889883254], 
                 InsetBox["95", 
                  Offset[{2, 2}, {2.891049039002683, -2.9498658280125016`}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{3.9456718437450693`, -0.9612421302664788}, 
                  0.07160324889883254], 
                 InsetBox["16", 
                  Offset[{2, 2}, {4.017275092643902, -0.8896388813676462}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{11.043565088476479`, -1.2354364283172665`}, 
                  0.07160324889883254], 
                 InsetBox["29", 
                  Offset[{2, 2}, {11.11516833737531, -1.163833179418434}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{11.104570396481748`, -2.5868119764372937`}, 
                  0.07160324889883254], 
                 InsetBox["77", 
                  Offset[{2, 2}, {11.17617364538058, -2.515208727538461}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}}}], 
             MouseAppearanceTag["NetworkGraphics"]], 
            AllowKernelInitialization -> False]], 
          DefaultBaseStyle -> {
           "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
            Hue[0.8, 1., 0.6]}, FormatType -> TraditionalForm, FrameTicks -> 
          None, GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], 
          ImageMargins -> {{24.23828125, 250.20703125}, {1.734375, 
           0.34765625}}, ImageSize -> {563.10546875, Automatic}]], 
        "ExerciseOutput", Selectable -> False, Copyable -> False, Editable -> 
        False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"24436223-a045-4762-bb17-0c1a6f3b6af6"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Collect the flags of Asia into clusters of similar flags.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "22.12", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"1bde4736-3d03-43ae-8fd9-495a7468f920"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           GraphicsBox[{{{
               {Thickness[0.0010416666666666667`], {{{
                   {Thickness[0.0010416666666666667`], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 480.}, {960., 480.}, {960., 0.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     320.}, {960., 320.}, {960., 160.}, {0., 
                    160.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[0., 0.478431, 0.23921600000000004`], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     160.}, {960., 160.}, {960., 0.}, {0., 0.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.8078430000000001, 0.06666670000000002, 0.14902], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{480., 240.}, {
                    0., 0.}, {0., 480.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    180.32800000000003`, 231.71099999999998`}, {159.875, 
                    229.80100000000002`}, {162.57, 209.36700000000002`}, {
                    148.32800000000003`, 224.22299999999998`}, {134.086, 
                    209.36700000000002`}, {136.781, 229.80100000000002`}, {
                    116.32799999999999`, 231.71099999999998`}, {133.93, 
                    242.33200000000002`}, {122.664, 259.57}, {
                    141.92200000000003`, 252.38700000000003`}, {
                    148.32800000000003`, 271.969}, {154.73399999999998`, 
                    252.38700000000003`}, {173.99200000000002`, 259.57}, {
                    162.727, 242.33200000000002`}}}]}}}}}}}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 960.}, {0., 480.}}], ",", 
           GraphicsBox[{{{
               {Thickness[0.0020833333333333333`], {{{
                   {FaceForm[{RGBColor[0., 0.6, 0.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 320.}, {480., 320.}, {480., 0.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[0.74902, 0., 0.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     320.}, {320., 320.}, {320., 0.}, {0., 0.}}}]}}}}, {{{
                   {Thickness[0.0020833333333333333`], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     320.}, {160., 320.}, {160., 0.}, {0., 0.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{255.602, 139.32800000000003`}, {
                    262.28099999999995`, 139.32800000000003`}, {262.309, 
                    136.80100000000002`}, {263.789, 134.09}, {265.867, 
                    132.531}, {253.062, 132.531}, {255.066, 
                    134.35200000000003`}, {255.61299999999997`, 136.504}, {
                    255.602, 139.32800000000003`}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{255.602, 139.328}, {262.28099999999995`, 
                    139.328}, {262.309, 136.80100000000002`}, {263.789, 
                    134.09}, {265.867, 132.531}, {253.062, 132.531}, {255.066,
                     134.352}, {255.61299999999997`, 136.504}, {255.602, 
                    139.328}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    213.36700000000002`, 177.176}, {217.02700000000002`, 
                    173.14499999999998`}, {262.574, 173.07}, {266.309, 
                    177.102}, {254.66, 177.25}, {248.984, 181.207}, {230.691, 
                    181.281}, {225.39100000000002`, 177.176}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4t7peULNDLkON899D368M83BcsuJsn3f8xze
1dibxu1Kc2AAAZt8h7cg/r00h4yJQFZgvoP+XRW2xsB0h/3zpfTvBuRD9E9M
d5CNSrG+758P0ReQ4VAtss794ak8BzW2xqnOqzMcfMw7HRNc8yDyGzIcvEF8
wzyHRa7bPv8F8rmvLy6wlcpzKLTlur74QAbEfJE8iDmXMiDuY89zeLx09hGF
PxkOTglPLyhx5zlcULr9s04s0+HOz7qsPX9yIeaJZELs+ZDr0Po6cIecaCZE
/+dciLlA/cdBDniR68AFsvdahoNLd87z3w9zIfYdynBY/fGSb9KZXLh7QcF1
YBtUfl0GxJ0CuRD7l2VAwmVpDiScdDMchJsPnFq4Msfhm0ZM/yFg+PSBDFiT
4xC3y5OHSTvdYRXI/B05EHVv0xzQ4wMAqua5vQ==
                    "]]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4t7peULNDLkON899D368M83BcsuJsn3f8xze
1dibxu1Kc2AAAZt8h7cg/r00h4yJQFZgvoP+XRW2xsB0h/3zpfTvBuRD9E9M
d5CNSrG+758P0ReQ4VAtss794ak8B1W2xqnOqzMcfMw7HRNc8yDyGzIcvEF8
wzyHRa7bPv8F8rmvLy6wlcpzKLDlur74QAbEfJE8hyqQOZcyIO5jz3N4snT2
EYU/GQ5OCU8vKHHnOVxQuv2zTizT4c7Puqw9f3Ih5olkQuz5kOvQ+jpwh5xo
JkT/51yHfSBzgfqPgxzwIteBC2TvtQwHl+6c578f5kLsO5ThsPrjJd+kM7lw
94KC68C2XIi/1mU4FILcKZALsX9ZBiRcluZAwkk3w0G4+cCphStzHL5pxPQf
AoZPH8iANTkOcbs8eZi00x1WgczfkQNR9zbNAT0+AKdmubk=
                    "],
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    206.129, 125.73400000000001`}, {273.703, 
                    125.73400000000001`}, {267.656, 130.664}, {212.176, 
                    130.664}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1,
                     0}, {0, 1, 0}}, {{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, {{{237.11299999999997`, 
                    144.24599999999998`}, {238.344, 140.55100000000002`}, {
                    241.14499999999998`, 140.55100000000002`}, {
                    238.90200000000002`, 144.25}, {237.11299999999997`, 
                    144.25}}, {{235.54299999999998`, 140.55100000000002`}, {
                    236.254, 136.895}, {239.539, 136.85500000000002`}, {
                    238.344, 140.555}}, {{241.105, 140.516}, {243.383, 
                    136.895}, {248.05100000000002`, 136.895}, {
                    244.39100000000002`, 140.555}}, CompressedData["
1:eJxTTMoPSmViYGAwB2IQ/U0jpv/QxiwHVbbGqc7tCQ6LXLd9/suQ7bB/vpT+
3QsJDkUZE9/WGGc7yEalWN/nT3RgAAGTbAfu64sLbLMSHfTvqrA1fkXwb577
HvwYyA/j09001zzR4bi3eacjR44DiEqQTHR4vHT2EQWVHIcJh75qxEhDzXuR
41Boy3V9sUyiQ5XIOveHz3IceqfnCTVPSHQoAIlH4OBzpEDcF5zjIANy3/MU
iH0ZuQ7qhhxrZLJSIfbezHXYB/JPRqrDrZ91WXsssuHyMP7bGnvTuLpUB6Hm
A6cWxhfA+VcrXqoZJhTA1XOB/CmWBzcP7O4HeRD3APmhIH8vzoeE44oUB5Dz
7JfmQ8KXHcEHh0NIskPcLk8epm4EHxwfnfmQ8GdJgfPB9NYUB6eEpxeUVudB
9EWnOqz6eMk36UcuRD40FRL+sbkQfwemQtydl+Owt2SyBMu+FIg7C6B8NgTf
EWTu+WSIO+/nOtwBhcuZZAerLSfK9t3OdfABmdebDHG/aB4kHjKSIe7uyIPE
o0uywwWl2z/r2vIcWl8H7pB7mgQJ3xt5EP+cSYKkl5t5EPvzkiD6bfIh4eaM
4IPd/zDRYQbQeQeq8h2qQeliVyIknsvzIe4NT4S6Mx81PbEg+GBzGvMdwkHm
9ydA0seJPFR+Th5cPTjeP+Wi6teEun9CAsTe5bkOLt05z39PTIDY14FQD/b3
S0T6fgcy71UOPH8BANfndxw=
                    "], {{231.289, 
                    144.21099999999998`}, {231.289, 140.555}, {235.547, 
                    140.555}, {234.684, 144.21099999999998`}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1,
                     0}, {0, 1, 0}}, {{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, {{{237.11299999999997`, 144.246}, {
                    238.344, 140.55100000000002`}, {241.14499999999998`, 
                    140.55100000000002`}, {238.90200000000002`, 144.25}, {
                    237.11299999999997`, 144.25}}, {{235.54299999999998`, 
                    140.55100000000002`}, {236.254, 136.895}, {239.539, 
                    136.85500000000002`}, {238.344, 140.555}}, {{241.105, 
                    140.516}, {243.383, 136.895}, {248.05100000000002`, 
                    136.895}, {244.39100000000002`, 140.555}}, CompressedData["
1:eJxTTMoPSmViYGAwB2IQ/U0jpv/QxiwHNbbGqc7tCQ6LXLd9/suQ7bB/vpT+
3QsJDkUZE9/WGGc7yEalWN/nT3RgAAGTbAeu64sLbLMSHfTvqrA1fkXwb577
HvwYyA/j09001zzR4bi3eacjR46DD5BKkEx0eLx09hEFlRyHCYe+asRIQ817
keNQaAs0QSbRoUpknfvDZzkOvdPzhJonJDoUgMQjMPl9ID5HCsR9wTkQ9z1P
gdiXkeugbsixRiYr1QHETbiZC/FPRqrDrZ91WXsssuHyMP7bGnvTuLpUB6Hm
A6cWxhfA+VcrXqoZJhTA1YP9KZYHNw/s7gd5EPcA+aEgfy/Od1gMCscVKQ4g
59kvzYeELzuCDw6HkGSHuF2ePEzdCD44PjrzHfaBzGdJgfO/guitKQ5OCU8v
KK3Og+iLTnVY9fGSb9KPXIh8aCok/GNzIf4OTIW4Oy/HYU/JZAmWfSmQcCyA
8tkQfEeQueeTHVRB7ryf63AbFC5nkh2stpwo23cbal5vMsT9onkQf2ckQ9zd
kQeJR5dkhwtKQJ1teQ6trwN3yD1NgoTvjTyIf84kQdLLzTyI/XlJEP02+ZBw
c0bwwfY9THSYAXTegap8h2pQutiV6CADiufyfEg4hCc63AG7Mx81PbEg+GBz
GvMh6bE/AZI+TuSh8nPy4OrB8f4pF1W/JjS+JyRAwml5roNzd87z3xMTIPZ1
INSD/f0Skb7fgcx7lQPPXwDcN3ca
                    "], {{231.289, 144.211}, {
                    231.289, 140.555}, {235.547, 140.555}, {234.684, 
                    144.211}}},
                    CurveClosed->{1, 1, 1, 1, 1}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    231.512, 150.67199999999997`}, {234.164, 
                    150.67199999999997`}, {234.164, 144.58599999999996`}, {
                    231.512, 144.58599999999996`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    227.76999999999998`, 144.16}, {230.35500000000002`, 
                    144.16}, {230.34, 148.637}, {230.305, 150.582}, {
                    232.05100000000002`, 152.547}, {232.89100000000002`, 
                    152.60899999999998`}, {233.816, 152.64499999999998`}, {
                    235.184, 150.773}, {235.227, 148.78900000000002`}, {
                    235.266, 144.14499999999998`}, {238.012, 144.152}, {
                    238.012, 155.67999999999998`}, {227.76999999999998`, 
                    155.625}}},
                    CurveClosed->{1}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    248.238, 141.488}, {251.449, 141.488}, {251.449, 
                    138.988}, {248.238, 138.988}}},
                    CurveClosed->{1}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    246.336, 145.78500000000003`}, {249.54700000000003`, 
                    145.78500000000003`}, {249.54700000000003`, 
                    143.28100000000003`}, {246.336, 143.28100000000003`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    243.238, 150.07799999999997`}, {246.449, 
                    150.07799999999997`}, {246.449, 147.57799999999997`}, {
                    243.238, 147.57799999999997`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    240.594, 153.695}, {243.805, 153.695}, {243.805, 
                    151.195}, {240.594, 151.195}}},
                    CurveClosed->{1}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, {{{238.465, 144.14499999999998`}, {
                    241.75, 144.031}, {247.60899999999998`, 138.844}, {
                    247.60899999999998`, 141.902}, {245.63299999999998`, 
                    143.32}, {245.63299999999998`, 145.75}, {242.758, 
                    147.39100000000002`}, {242.758, 150.004}, {
                    239.95700000000002`, 150.938}, {239.95700000000002`, 
                    154.484}, {238.539, 155.64499999999998`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    252.344, 151.71899999999997`}, {253.129, 
                    151.71899999999997`}, {253.129, 146.08199999999997`}, {
                    252.344, 146.08199999999997`}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    252.344, 151.719}, {253.129, 151.719}, {253.129, 
                    146.082}, {252.344, 146.082}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4gmHvmrE7M502DdfSv9uRKqD1ZYTZftmZzqE
8elumtud6rC3ZLIES1mmw0Wl2z/rhFIdGEDgS4bDcW/zTscdKQ5FGRPf1mzP
cHBMeHpBqT/FwQconNCb4aB/V4WtUTHFYZHrts9/ezIcQMrsbyY7xO3y5GHq
znCwBNmzPBli7qQMB67riwtsy5Lh6sF8t2SIOZ0ZEHs1kh1unvse/Dgzw6HA
FqjiSZJDMcjg+gyHfpA/LidBxHdkQPyzIslhRp5Q8wGmTIdVHy/5JnkkQcxX
yXSIBblDHSrvlAkR50ly6JsOFIjJhPhjLVS+KNOh9XXgDrmvSQ5bgc6e35Xp
oG7IsUbGKRniroZMSDjNS4aIH4Kqf5oMoT9C+aLQ8ErPcjgGCj+XFAdukD+j
shyEmw+cWhiZ4gAAUFevAg==
                    "]]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4gmHvmrE7M502D9fSv9uRKqD1ZYTZftmZzqE
8elumtud6rC3ZLIES1mmwwWl2z/rhFIdGEDgS4bDcW/zTscdKQ5FGRPf1mzP
cHBMeHpBqT/FwQconNCb4aB/V4WtUTHFYZHrts9/ezIcMoHK7G8mO8Tt8uRh
6s5wsATZszzZ4SLI3EkZDlzXFxfYliXD1YP5bskQczozIPZqJDvcPPc9+HFm
hkOBLVDFkySHYpD99RkO/SB/XE6CiO/IgPhnRZLDjDyh5gNMmQ6rPl7yTfJI
gpivkglxhzpU3ikTIs6T5NA3HSgQk+kA8l7CWqh8UaZD6+vAHXJfkxy2Ap09
vyvTQd2QY42MUzLEXQ2ZDntA4TQvGSJ+CKr+aTKE/gjli0LDKz3L4RjIApcU
B26QP6OyHISbD5xaGJniAABSL68D
                    "],
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[0.74902, 0., 0.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGI9IGYC4ts/67L2bMl0kI1Ksb5/PtmhWmSd+8NVmQ4X
lIAyz5IdjnubdzrOyXTYWzJZguVfssO7GnvTuK5MB67riwtshVIceqfnCTVX
QNWrpTiosjVOdU7OdAjj09001zwFYq431Hz7FAcfoHEJppkQcz1SHN6CzJPL
dHBKeHpBKRjK58t0cATx06F8tkyHRa7bPv8tSHGYcOirRsz/DAfh5gOnFtam
ODCAwJ8Mh0JboIt6UhxugfzzI8Nh64myffNnIfhg96xOgdjzOwNi/v4Uh1Uf
L/kmAeXB5u9JcagC+f9bhsMMoLcO7IKa/yXDoQBk/o4Uh6KMiW9rtmc4FIPo
/hSH1teBO+R6oe5RTHG4A7KvJ8NB/64KW+PNZIh+GP9oMiQcujMc1A051shs
SoarB4fnvGQHkLH2EzMcbp77Hvx4YjJE39QMh28aMf2HWqHmzYGqr0t2OAYK
xyUZkHgoSYaIr8uAxFdeMsT/O6D2ZyZDzD0LVZ+QDHHHM2h4xUHd8wdqfliy
w+Ols48oiEDj3w/K14HGl3WyAzj9OGRCwkclGRKeIZmQdMCfDAkvYHrYAjL/
W5KDAcgduZmQ+HqQBFGXnwkJ92dJEHcWZkLs+ZAEsac4EyL+NQninw6E/eB4
a4Gmpx6oe5DSMwC1Tkwb
                    "]]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGI9IGYC4ts/67L2bMl0kI1Ksb5/PtmhWmSd+8NVmQ4X
lYAyz5IdjnubdzrOyXTYUzJZguVfssO7GnvTuK5MB67riwtshVIceqfnCTVX
QNWrpTiosjVOdU7OdAjj09001zwFYq431Hz7FAcfoHEJppkQcz1SHN6CzJPL
dHBMeHpBKRjK58t0cALx06F8tkyHRa7bPv8tSHGYcOirRsz/DAfh5gOnFtam
ODCAwJ8Mh0JboIt6UhxugfzzI8Nhy4myffNnIfhg96xOgZj7OwNi3/4Uh1Uf
L/kmAeXB5u9JcagC+f9bhsMMoLcO7IKa/wVq/o4Uh6KMiW9rtmc4FIPo/hSH
1teBO+R6oe5RTHG4A7KvJ8PB4K4KW+PNZIh+IF8PxD+aDAmH7gwHdUOONTKb
kuHqweE5L9kBZKz9xAyHm+e+Bz+emOygD9I3NcMB6Ov+Q61Q8+ZA1dclOxwD
heOSDEg8lCRDxNdlQOIrLxni/x1Q92QmQ8w9C1WfkAxxx7MMh62g8IqDuucP
1PywZIfHS2cfURCBxr8flK8DjS/rZAdw+nHIdCgAhY9KMiQ8QzIh6YA/GRJe
wPQANv9bEsQduVD1D5Ig6vIzIenuWRLEv4WZEHs+JEHiqzgTEn5fkyD+6UDY
D463Fmh66oG6Byk9AwC1BkwY
                    "],
                    CurveClosed->{1}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    199.85500000000002`, 166.09}, {199.469, 163.402}, {
                    200.965, 162.51199999999997`}, {202.375, 161.988}, {
                    203.836, 161.47299999999998`}, {205.031, 159.906}, {
                    205.648, 158.488}}},
                    CurveClosed->{0}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{196.238, 
                    157.246}, {196.85500000000002`, 154.934}, {198.477, 
                    155.223}, {199.89100000000002`, 154.703}, {201.348, 
                    154.184}, {202.88700000000003`, 152.336}, {203.5, 
                    150.922}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    204.48800000000003`, 172.414}, {205.227, 
                    172.89100000000002`}, {219.43, 148.97299999999998`}, {
                    218.691, 148.496}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    204.48800000000003`, 172.414}, {205.227, 
                    172.89100000000002`}, {219.43, 148.97299999999998`}, {
                    218.691, 148.496}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{206.016, 173.36700000000002`}, {206.016, 
                    172.512}, {205.23399999999998`, 171.73}, {204.379, 
                    171.73}, {203.523, 171.73}, {202.742, 172.512}, {202.742, 
                    173.36700000000002`}, {202.742, 174.227}, {203.523, 
                    175.004}, {204.379, 175.004}, {205.23399999999998`, 
                    175.004}, {206.016, 174.227}, {206.016, 
                    173.36700000000002`}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{206.016, 173.36700000000002`}, {206.016, 
                    172.51199999999997`}, {205.23399999999998`, 
                    171.73000000000002`}, {204.379, 171.73000000000002`}, {
                    203.523, 171.73000000000002`}, {202.742, 
                    172.51199999999997`}, {202.742, 173.36700000000002`}, {
                    202.742, 174.22700000000003`}, {203.523, 175.004}, {
                    204.379, 175.004}, {205.23399999999998`, 175.004}, {
                    206.016, 174.22700000000003`}, {206.016, 
                    173.36700000000002`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    218.16, 192.586}, {223.914, 192.586}, {223.914, 
                    191.26600000000002`}, {218.16, 
                    191.26600000000002`}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    218.16, 192.58599999999998`}, {223.914, 
                    192.58599999999998`}, {223.914, 191.266}, {218.16, 
                    191.266}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    218.16, 190.078}, {223.914, 190.078}, {223.914, 
                    179.055}, {218.16, 179.055}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    218.16, 190.07799999999997`}, {223.914, 
                    190.07799999999997`}, {223.914, 179.05499999999998`}, {
                    218.16, 179.05499999999998`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    217.809, 194.09}, {224.191, 194.05100000000002`}, {
                    224.441, 196.21499999999997`}, {222.281, 198.555}, {
                    221.02, 198.531}, {219.77299999999997`, 198.469}, {
                    217.758, 196.164}, {217.809, 194.09}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    217.809, 194.08999999999997`}, {224.191, 194.051}, {
                    224.441, 196.215}, {222.281, 198.555}, {221.02, 
                    198.531}, {219.77299999999997`, 198.469}, {217.758, 
                    196.164}, {217.809, 194.08999999999997`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {CompressedData["
1:eJxTTMoPSmViYGBQBmIQ7ZTw9IKSc65D3/Q8oeacDIfHS2cfUZDJhdAxGQ5c
1xcX2P7LcQjn0900Vz/DQTYqxfr+6xyI+j/pDvp3Vdgab+Y4eJt3OiacTHe4
qHT7Z92lHAdVtsapzv3pDmDzb+c49ILUJyD4VltOlO2LT3d4W2NvGncPar5/
usMMoLIDj3IcGEDAJd1BBmTfc6h663SHRa7bPv99k+NQlDHxbY1xusNWoPD8
TzkQWg/qnp85Dj4g9+imOxwHOYwB6h+ddAeQMfPZciHm6ac7cIP8x5ULUW+a
7nDz3Pfgx7y5DnG7PHmYgPaB1fHnQtzplO7gCHI/P1TeO91hwqGvGjHcUH51
ukMYyB9A/iVQOKyCqheHmn8VGj5KuVB3ZUDCzRJqvloGJHySoepdMyD+ysp1
qBZZ5/7QKwNiT36uA8j79oHQ+ADyLUHuDM9wAJqetacgFxJvcRkQc3JzIeqS
MxyAnr2+OAOqPj0D4v74XIdikIH5GQ6FIPmAXAd1Q441MkVQ9yClDwAIJfB7

                    "], CompressedData["
1:eJxTTMoPSmViYGBQAmIQ7Zjw9IKSe66Dt3mnY0JihkPv9Dyh5oBch4yJb2vs
UzMcCm25ri+OyXWI2+XJw5Sc4aB/V4WtMRHKj89wkI1Ksb6fnOuwf76U/t2Y
DIfHS2cfUUjJdSgGGRCNkAebH5nhUAQSB/LB9oZnONw89z34MdC8/kNfNWKC
oeqjoeb7ZzgwgIBBrgPQNaZxehkOMiB58VyIO1ih6rlzIe6+kQ7h/89xCOPT
3TR3dTrEPQy5DtUi69wfVkHlmXMd1A051sh4pTus+njJN4klF+Iu53SHi0q3
f9Yx5UJou3SI/4H6rbacKNtnnQ4x51+OwyLXbZ//WqRD3P83B2KPBdT83zkQ
9wD53zRi+g/9zHHYBwofIB/s7q85kPCxhvI/5kDc45Tu4AMKp7c5Drd+1mXt
8UiHhNvLHEh4BKc7AF1TYPsMqj4Jyr+X47C3ZLIESx9U/9McB1W2xqnOx9Mh
4fwd6p4f6RB3cORC3K2ZAYln1VwHJ5A6YPijpwcAtQ3lmA==
                    "]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxlU1tIVFEUHcaSiLDQKInRJlHHnk6FWiPi1oqCsidUiNkk2j5G20or6Ali
ffjRU6IgJjFzwEl6SEUfZSJBESEmQUVIhPQVfURURESdc/eSggaGw71n77XX
XmvdWTV7NtYl+Xw+v/3PxPmofUb+yAmh0MIJPYGIoYf729LHVQt9y6s6MzDb
kHe/XOjswNe8qt9MOcnNF5YVCR2ZemPl+0FGndCno6UF1VeYNqfM742FhA67
+51Mo12XHwfDQqcuNqS2LGFyR3+haN10Jp/7rRKa+Kpzb0kyU5+bt1Vo6Z2n
B/uSmMw5i7wD+H6m/JHs5OZ68BvP9CLr7Y/jDUKnHfAkpkbX0CTKM43p5McN
9zMPCF3/PFxRE0B9I/BDmGew/1rMqxN6M/h90+gx8N8t+r6bdW/bb1F2PXiJ
e6tfkyv4yarXNeiTanRuj1DCnelG+24JXXI6ZBpKa+l/1nEb+DmG7lpa7b1C
GZW1xe/mGiqLfhjKugl9FhkadvwT4FtodL8O8C0xut95oYjbrxT+/eOvN68V
/BYYKnf4bXi2+Ooj/Aob1bET+s4zqnuXKI85Rv2Mi/KweRly7+PwP9fo3Dj0
yjaqu8XzeAXBJwb8gFF/D0EfP/ZnoSeri1rLXkPvKPgmmK6uuPfll81L2PVZ
v9bYsug28KlAXnlMXyYHE60HXuDvvcdzGvyrHfMPeakR2uLyOpn1O9iO+hRW
HSpRb5/3lVin1sPvKchTGfhkMOW6ecWoj7Dqvxh5ZeS7AH7GML8c+jxnzdk6
0T6bN09Py9+bG/zf3z+xPLCC
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    217.848, 170.09}, {224.27, 170.09}, {224.27, 161.203}, {
                    217.848, 161.203}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    217.848, 170.09}, {224.27, 170.09}, {224.27, 161.203}, {
                    217.848, 161.203}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    218.22299999999998`, 156.121}, {224.422, 156.121}, {
                    224.422, 154.25400000000002`}, {218.22299999999998`, 
                    154.25400000000002`}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    218.22299999999998`, 156.121}, {224.422, 156.121}, {
                    224.422, 154.25400000000002`}, {218.22299999999998`, 
                    154.25400000000002`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    218.07, 152.84}, {224.418, 152.84}, {224.418, 145.895}, {
                    218.07, 145.895}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    218.07, 152.84}, {224.418, 152.84}, {224.418, 145.895}, {
                    218.07, 145.895}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    217.625, 144.47299999999998`}, {224.566, 
                    144.47299999999998`}, {224.566, 140.58999999999997`}, {
                    217.625, 140.58999999999997`}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    217.625, 144.47299999999998`}, {224.566, 
                    144.47299999999998`}, {224.566, 140.58999999999997`}, {
                    217.625, 140.58999999999997`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    218.48000000000002`, 157.79299999999998`}, {
                    224.07399999999998`, 157.79299999999998`}, {225.184, 
                    159.641}, {217.477, 159.641}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    218.48000000000002`, 157.793}, {224.07399999999998`, 
                    157.793}, {225.184, 159.641}, {217.477, 159.641}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    226.023, 164.602}, {226.078, 169.45700000000002`}, {
                    229.93, 169.45700000000002`}, {228.418, 168.207}, {
                    227.008, 166.695}, {226.023, 164.602}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    226.023, 164.60199999999998`}, {226.078, 
                    169.45700000000002`}, {229.93, 169.45700000000002`}, {
                    228.418, 168.20700000000002`}, {227.008, 166.695}, {
                    226.023, 164.60199999999998`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYCYqeEpxeUorMdijImvq0JTnFY/fGSb1JMtgPX
9cUFtkYpDi7dOc9/N2Y7LHLd9vmvA4L/TSOm/1AgmnxLisPWE2X75jdlO/RN
zxNq3pPiUGgLNKkh2+H2z7qsPQ9SHFaBzAfyw/h0N839DeUfyHbYN19K/+6X
FAcGEADyweJPUhyOe5t3OgL5ba8Dd8jtTIGYcwBqf20KxF4gP26XJw+Td4pD
L8heIP9tjb1pHND970D0q2yIuEkKRN9LhHr9uypsjUB+KMg9zQj+zXPfgx9f
RagvBoXP/xQHdUOONTJA81pB7jFNhdgPDC+wu01SHWSjUqzvR0P9y4Dgg8Pl
WooDLLxV2RqnOncj+LDwBwDld7xQ
                    "],
                    CurveClosed->{1}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    218.85500000000002`, 152.016}, {223.41000000000003`, 
                    152.016}, {223.41000000000003`, 146.34}, {
                    218.85500000000002`, 146.34}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    221.76999999999998`, 149.664}, {223.37499999999997`, 
                    149.664}, {223.37499999999997`, 148.73}, {
                    221.76999999999998`, 148.73}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    221.76999999999998`, 149.664}, {223.37499999999997`, 
                    149.664}, {223.37499999999997`, 148.73}, {
                    221.76999999999998`, 148.73}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    218.969, 149.664}, {220.535, 149.664}, {220.535, 
                    148.73}, {218.969, 148.73}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    218.969, 149.664}, {220.535, 149.664}, {220.535, 
                    148.73}, {218.969, 148.73}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    220.535, 151.945}, {221.769, 151.945}, {221.769, 
                    149.629}, {220.535, 149.629}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    220.535, 151.945}, {221.769, 151.945}, {221.769, 
                    149.629}, {220.535, 149.629}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    220.535, 148.76999999999998`}, {221.769, 
                    148.76999999999998`}, {221.769, 146.30499999999998`}, {
                    220.535, 146.30499999999998`}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    220.535, 148.77}, {221.769, 148.77}, {221.769, 146.305}, {
                    220.535, 146.305}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{195.191, 
                    208.824}, {195.477, 204.371}, {194.094, 
                    201.92600000000002`}, {191.73399999999998`, 202.297}, {
                    191.086, 204.76999999999998`}, {192.566, 
                    206.42600000000002`}, {195.191, 208.824}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{195.191, 
                    208.824}, {195.477, 204.371}, {194.094, 201.926}, {
                    191.73399999999998`, 202.297}, {191.086, 
                    204.76999999999998`}, {192.566, 206.426}, {195.191, 
                    208.824}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{190.016, 
                    198.953}, {187.918, 200.02}, {189.434, 208.164}, {190.238,
                     211.57399999999998`}, {190.83200000000002`, 207.18}, {
                    191.82800000000003`, 200.93}, {190.016, 
                    198.953}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{190.016, 
                    198.95299999999997`}, {187.918, 200.01999999999998`}, {
                    189.434, 208.164}, {190.238, 211.574}, {
                    190.83200000000002`, 207.18}, {191.82800000000003`, 
                    200.93}, {190.016, 198.95299999999997`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{190.762, 
                    198.566}, {194.285, 197.344}, {197.07399999999998`, 
                    201.137}, {198.02, 205.535}, {195.10899999999998`, 
                    201.52}, {190.375, 201.516}, {190.762, 198.566}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{190.762, 
                    198.56599999999997`}, {194.285, 197.344}, {
                    197.07399999999998`, 201.137}, {198.02, 205.535}, {
                    195.10899999999998`, 201.51999999999998`}, {190.375, 
                    201.516}, {190.762, 198.56599999999997`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{188.09, 
                    194.45700000000002`}, {185.33200000000002`, 195.184}, {
                    186.99200000000002`, 203.824}, {187.49200000000002`, 
                    207.281}, {188.098, 203.71099999999998`}, {190., 
                    195.637}, {188.09, 194.45700000000002`}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{188.09, 
                    194.457}, {185.33200000000002`, 195.184}, {
                    186.99200000000002`, 203.824}, {187.49200000000002`, 
                    207.281}, {188.098, 203.711}, {190., 195.637}, {188.09, 
                    194.457}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{189.031, 
                    194.727}, {189.18800000000002`, 197.707}, {192.156, 
                    196.848}, {194.207, 198.43800000000002`}, {193.871, 
                    196.94899999999998`}, {192.60899999999998`, 194.309}, {
                    189.031, 194.727}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{189.031, 
                    194.727}, {189.18800000000002`, 197.707}, {192.156, 
                    196.848}, {194.207, 198.438}, {193.871, 196.949}, {
                    192.60899999999998`, 194.309}, {189.031, 194.727}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{185.656, 
                    190.73399999999998`}, {182.92600000000002`, 
                    191.47299999999998`}, {184.566, 200.76999999999998`}, {
                    184.41, 204.598}, {185.21099999999998`, 
                    201.29299999999998`}, {187.75, 191.63299999999998`}, {
                    185.656, 190.73399999999998`}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{185.656, 
                    190.734}, {182.92600000000002`, 191.47299999999998`}, {
                    184.566, 200.76999999999998`}, {184.41, 204.598}, {
                    185.21099999999998`, 201.293}, {187.75, 
                    191.63299999999998`}, {185.656, 190.734}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{186.93, 
                    191.137}, {189.164, 190.41}, {192.129, 191.863}, {192.363,
                     194.52700000000002`}, {190.434, 193.21899999999997`}, {
                    187.359, 194.21899999999997`}, {186.93, 
                    191.137}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{186.93, 
                    191.137}, {189.164, 190.41}, {192.129, 191.863}, {192.363,
                     194.527}, {190.434, 193.219}, {187.359, 194.219}, {
                    186.93, 191.137}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{183.617, 
                    186.63299999999998`}, {181.004, 186.42200000000003`}, {
                    182.172, 194.344}, {182.176, 201.71899999999997`}, {
                    183.13299999999998`, 194.824}, {185.75, 188.512}, {
                    183.617, 186.63299999999998`}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{183.617, 
                    186.63299999999998`}, {181.004, 186.422}, {182.172, 
                    194.344}, {182.176, 201.719}, {183.13299999999998`, 
                    194.824}, {185.75, 188.51199999999997`}, {183.617, 
                    186.63299999999998`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{184.52, 
                    186.99200000000002`}, {186.285, 186.105}, {189.445, 
                    187.52}, {190.348, 190.5}, {187.16, 189.117}, {
                    185.02700000000002`, 190.469}, {184.52, 
                    186.99200000000002`}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{184.52, 
                    186.992}, {186.285, 186.105}, {189.445, 
                    187.51999999999998`}, {190.348, 190.5}, {187.16, 
                    189.117}, {185.02700000000002`, 190.469}, {184.52, 
                    186.992}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{205.023, 
                    204.695}, {204.559, 200.83200000000002`}, {
                    202.98000000000002`, 198.586}, {200.621, 
                    198.95700000000002`}, {199.97299999999998`, 
                    201.42600000000002`}, {201.883, 203.008}, {205.023, 
                    204.695}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{205.023, 
                    204.695}, {204.559, 200.832}, {202.98000000000002`, 
                    198.58599999999998`}, {200.621, 198.957}, {
                    199.97299999999998`, 201.426}, {201.883, 
                    203.00799999999998`}, {205.023, 204.695}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{198.785, 
                    194.785}, {202.70299999999997`, 194.227}, {
                    204.11299999999997`, 197.23399999999998`}, {206.75, 
                    201.08200000000002`}, {203.055, 198.406}, {198.637, 
                    197.848}, {198.785, 194.785}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{198.785, 
                    194.785}, {202.70299999999997`, 194.227}, {
                    204.11299999999997`, 197.23399999999998`}, {206.75, 
                    201.082}, {203.055, 198.406}, {198.637, 197.848}, {
                    198.785, 194.785}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{197.672, 
                    195.22299999999998`}, {195.535, 197.789}, {197.602, 
                    201.008}, {199.23399999999998`, 203.75}, {198.883, 
                    199.668}, {200.27299999999997`, 197.39800000000002`}, {
                    197.672, 195.22299999999998`}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{197.672, 
                    195.223}, {195.535, 197.789}, {197.602, 
                    201.00799999999998`}, {199.23399999999998`, 203.75}, {
                    198.883, 199.668}, {200.27299999999997`, 
                    197.39800000000002`}, {197.672, 195.223}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{196.727, 
                    190.99200000000002`}, {196.48800000000003`, 193.5}, {
                    200.758, 194.055}, {202.691, 195.44899999999998`}, {
                    202.039, 194.}, {201.055, 190.102}, {196.727, 
                    190.99200000000002`}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{196.727, 
                    190.992}, {196.48800000000003`, 193.5}, {200.758, 
                    194.055}, {202.691, 195.449}, {202.039, 194.}, {201.055, 
                    190.10199999999998`}, {196.727, 190.992}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    195.83200000000002`, 190.93800000000002`}, {192.879, 
                    191.26999999999998`}, {194.105, 196.285}, {
                    196.22299999999998`, 199.07}, {195.33200000000002`, 
                    195.227}, {197.781, 192.55100000000002`}, {
                    195.83200000000002`, 190.93800000000002`}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    195.83200000000002`, 190.938}, {192.879, 191.27}, {
                    194.105, 196.285}, {196.22299999999998`, 199.07}, {
                    195.33200000000002`, 195.227}, {197.781, 192.551}, {
                    195.83200000000002`, 190.938}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    193.60899999999998`, 186.762}, {190.24599999999998`, 
                    188.24599999999998`}, {192.40200000000002`, 192.461}, {
                    193.664, 194.94899999999998`}, {193.125, 191.684}, {
                    195.82000000000002`, 189.191}, {193.60899999999998`, 
                    186.762}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    193.60899999999998`, 186.762}, {190.24599999999998`, 
                    188.246}, {192.40200000000002`, 192.461}, {193.664, 
                    194.949}, {193.125, 191.684}, {195.82000000000002`, 
                    189.191}, {193.60899999999998`, 186.762}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    194.27299999999997`, 187.15200000000002`}, {196.035, 
                    184.848}, {199.47299999999998`, 187.84}, {200.18, 
                    191.33200000000002`}, {197.18800000000002`, 188.84}, {
                    194.977, 189.25}, {194.27299999999997`, 
                    187.15200000000002`}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    194.27299999999997`, 187.152}, {196.035, 
                    184.84799999999998`}, {199.47299999999998`, 187.84}, {
                    200.18, 191.332}, {197.18800000000002`, 188.84}, {194.977,
                     189.25}, {194.27299999999997`, 187.152}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4rhdnjxMwekOXNcXF9jGpTrIRKVY33dPd2AA
gTOpDpeUbv+sm5XuUJQx8W3N5DQHWZB8fLrD3pLJEiz/0iDqw9MdCm2BJvCk
O3ibdzomFKY79B/6qhFjnO5w89z34MeN6RB90ukOYXy6m+bOhtr3Lc1B3ZBj
jcy2dAenhKcXlLrTHEDW2B9Md5iRJ9R8YFOawyLXbZ//nkl3+KYR03/obhpE
/ByUr5nusH++lP7dL+kOvdOBEhbpDq2vA3fI8WZAaMd0h2KQgfoZDlUi69wf
uqVD7FPLgLhXId3hzs+6rD0yGRD3/U6D+JsDqv9kmgM4fOQzIPYdTXPoA9mj
A1V/GCofnAEJh+9pkHAqhsrzQ93Zm+HgAwoX1XSH2yD7tmQ4WG45UbaPOd3h
Iih8+zIcQkHh8jjNwaU75/lvwQyH1R8v+SbVpDno31Vha5wJDUffNIdqkD+C
EPEFABcywTw=
                    "]]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4rhdnjxMwekOXNcXF9jGpTrIRKVY33dPd2AA
gTOpDpeUbv+sm5XuUJQx8W3N5DQHWZB8fLrDnpLJEiz/0iDqw9MdCm2BJvCk
O3ibdzomFKY79B/6qhFjnO5w89z34MeN6RB90ukOYXy6m+bOhtr3Lc1B3ZBj
jcy2dAfHhKcXlLrTHEDW2B9Md5iRJ9R8YFOawyLXbZ//nkl3+KYR03/obhpE
/ByUr5nusH++lP7dL+kOfdOBEhbpDq2vA3fI8WZAaMd0h2KQgfoZDtUi69wf
uqVD7FPLcCgAuVch3eHOz7qsPTIZEPf9ToP4myPDoQ2k/2SaAzh85DMcvoLs
O5oGsUcHqv4wVD4Yyv+eBgmnYiifH+rO3gxIuKimO9wG2bclw8Fyy4myfczp
DhdB4duX4RAKCpfHaQ4u3TnPfwtmOKz+eMk3qSbNQf+uClvjTGg4+qZB/BGE
iC8AFarBOw==
                    "],
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4qKMiW9ritMcRNa5P6y6Euuwf76U/t2UNAeX
7pznv29C+QFpDu1iN899fxzrELfLk4cpOc0BSGq3b4t1WPXxkm/SlzSH3ul5
Qs0BMQ4XlW7/rJNLd/imEdN/6G00hP8p3YEBBBRiHApsua4vPpEBUR8R4xDG
p7tp7u8MB78kgQjLMzEOws0HTi2cmAlxT0kshP8wE2LOpVgHkLYDYVkOxSB3
P4+F0OuzHDKBlP3aWId9IPfeyHIA2lJgOynWAejq4McfsyD2TYh1OOZt3ul4
Jcth09z3y4+djnXYcqJs3/xtWQ5PLwAtYItzCAW5Z3KWgyVIIjzOwTEBKJOf
5bBGJirFuj/OYcKhrxox8lkONfamcbs44x1AwvenZzo8A+m3i3cAGZ+gmQlx
l3i8Q+vrwB1yvRmQ8HoWBwkHngyIvHwcJJwK0yH+B4Z/ISh8FNIh9q2Phbjj
eJoD0PdZe7bEOqDHFwBlE80j
                    "]]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4qKMiW9ritMcRNa5P6y6Euuwf76U/t2UNAeX
7pznv29C+QFpDm1iN899fxzrELfLk4cpOc3Bi4dJu31brMOqj5d8k76kOfRN
zxNqDohxuKh0+2edXLrDN42Y/kNvoyH8T+kODCCgEONQYMt1ffGJDIj6iBiH
MD7dTXN/Zzj4JQlEWJ6JcRBuPnBq4cRMiHtKYiH8h5kOl0DmXIp1AGk7EJbl
AHb381iHYhC9PsshC0jZr4112Ady740sB57riwtsJ8U6AF0d/PhjFsS+CbEO
x7zNOx2vZDlsmvt++bHTsQ5bTpTtm78ty+HJBaAFbHEOoSD3TM5ysAJJhMc5
OCY8vaCUn+WwRiYqxbo/zmHCoa8aMfJZDjX2pnG7OOMdQML3p2c6PAPpt4t3
ABmfoJnpUAJyl3i8Q+vrwB1yvRkOHqDwehYHCQeeDIj75eMg4VSYDvE/MPwL
QeGjkA6xb32sgyXIHcfTHO78rMvasyXWAT2+AGtDzSk=
                    "],
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    217.84, 109.32}, {218.684, 109.215}, {219.21899999999997`,
                     107.57799999999999`}, {219.637, 108.68799999999999`}, {
                    220.34, 110.48}, {219.848, 111.906}, {219.055, 111.75}, {
                    218.117, 111.5}, {216.535, 109.402}, {217.84, 
                    109.32}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    217.84, 109.32}, {218.684, 109.215}, {219.21899999999997`,
                     107.57799999999997`}, {219.637, 108.68799999999999`}, {
                    220.34, 110.47999999999999`}, {219.848, 111.906}, {
                    219.055, 111.75}, {218.117, 111.5}, {216.535, 
                    109.40199999999999`}, {217.84, 109.32}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4gmHvmrE8Kc5ZEx8W2O/NdXhuLd5p+OHVIdv
GjH9h66mQsR/pjqoG3KskXmU6qDK1jjVWT3NYeuJsn3zgXyrLUCGd5rDItdt
n/8+SXVgAIEpaRBzzqQ6FIMMWA/lP0h1KLDlur74RJrDRaXbP+s+pULM2ZcG
0eeQBrH3ZJqDJcjcZKg959Icwvh0N80tT3MoBOm/k+ZQJbLO/eG0NAfZqBTr
+7/TIO5LS4OYH5HuoH9Xha3xYqpD3/Q8oeYz6Q6OCU8vKMmnOuwtmSzB8i/d
YdXHS75JBSkQd0tkOAB9aRrHlwJx73+o/tJkCL00HeIOvmSHWz/rsvasSHcA
2lJgm5bs8Hjp7CMKHemQcFqYDPFnQrrDJZD/XiVD7NVPd5gBdMYBrxSIvRVp
DuEg//inOqCHPwBV9Ldy
                    "]], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    188.42600000000002`, 149.24599999999998`}, {
                    191.60899999999998`, 149.23399999999998`}, {192.156, 
                    153.504}, {192.156, 154.69899999999998`}, {190.59, 
                    154.39800000000002`}, {187.82800000000003`, 151.785}, {
                    188.42600000000002`, 149.24599999999998`}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    188.42600000000002`, 149.246}, {191.60899999999998`, 
                    149.234}, {192.156, 153.504}, {192.156, 
                    154.69899999999998`}, {190.59, 154.398}, {
                    187.82800000000003`, 151.78500000000003`}, {
                    188.42600000000002`, 149.246}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{215.961, 
                    107.793}, {218.227, 107.277}, {218.195, 
                    112.73400000000001`}, {215.879, 115.04700000000001`}, {
                    216.89800000000002`, 111.543}, {214.176, 108.336}, {
                    215.961, 107.793}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{215.961, 
                    107.793}, {218.227, 107.27700000000002`}, {218.195, 
                    112.73400000000001`}, {215.879, 115.047}, {
                    216.89800000000002`, 111.54299999999998`}, {214.176, 
                    108.33600000000001`}, {215.961, 107.793}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{215.078, 
                    107.84}, {215.23, 105.24600000000001`}, {
                    208.71499999999997`, 108.17999999999999`}, {207.039, 
                    110.195}, {210.88700000000003`, 108.562}, {
                    214.89100000000002`, 109.91400000000002`}, {215.078, 
                    107.84}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{215.078, 
                    107.84}, {215.23, 105.24600000000001`}, {
                    208.71499999999997`, 108.17999999999998`}, {207.039, 
                    110.195}, {210.88700000000003`, 108.56199999999998`}, {
                    214.89100000000002`, 109.91399999999999`}, {215.078, 
                    107.84}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    212.22299999999998`, 111.543}, {212.45700000000002`, 
                    109.031}, {206.57399999999998`, 111.242}, {
                    204.83200000000002`, 113.203}, {208.69899999999998`, 
                    111.953}, {211.969, 113.613}, {212.22299999999998`, 
                    111.543}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    212.22299999999998`, 111.54299999999998`}, {
                    212.45700000000002`, 109.031}, {206.57399999999998`, 
                    111.24199999999999`}, {204.83200000000002`, 113.203}, {
                    208.69899999999998`, 111.953}, {211.969, 
                    113.61299999999997`}, {212.22299999999998`, 
                    111.54299999999998`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{213.305, 
                    111.191}, {215.57, 110.67599999999999`}, {
                    215.20299999999997`, 116.32}, {213., 118.262}, {214.059, 
                    114.49600000000001`}, {211.523, 111.738}, {213.305, 
                    111.191}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{213.305, 
                    111.191}, {215.57, 110.67599999999999`}, {
                    215.20299999999997`, 116.32}, {213., 118.262}, {214.059, 
                    114.49600000000001`}, {211.523, 111.738}, {213.305, 
                    111.191}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    210.92200000000003`, 114.62499999999999`}, {
                    213.18800000000002`, 114.109}, {211.88700000000003`, 
                    118.96900000000001`}, {210.207, 120.91000000000001`}, {
                    210.48000000000002`, 117.367}, {209.363, 
                    114.91000000000001`}, {210.92200000000003`, 
                    114.62499999999999`}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    210.92200000000003`, 114.625}, {213.18800000000002`, 
                    114.10899999999998`}, {211.88700000000003`, 118.969}, {
                    210.207, 120.91}, {210.48000000000002`, 
                    117.36700000000002`}, {209.363, 114.91}, {
                    210.92200000000003`, 114.625}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    209.71899999999997`, 114.641}, {209.953, 112.051}, {
                    205.375, 114.039}, {203.598, 116.488}, {
                    207.42600000000002`, 115.238}, {209.465, 
                    116.70700000000001`}, {209.71899999999997`, 
                    114.641}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    209.71899999999997`, 114.64099999999999`}, {209.953, 
                    112.05100000000002`}, {205.375, 114.03899999999999`}, {
                    203.598, 116.488}, {207.42600000000002`, 115.238}, {
                    209.465, 116.70700000000002`}, {209.71899999999997`, 
                    114.64099999999999`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    208.47299999999998`, 116.609}, {209.95700000000002`, 
                    117.67599999999999`}, {208.383, 120.5}, {205.555, 
                    120.324}, {205.83200000000002`, 118.617}, {206.809, 
                    115.621}, {208.47299999999998`, 116.609}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    208.47299999999998`, 116.60899999999998`}, {
                    209.95700000000002`, 117.67599999999999`}, {208.383, 
                    120.5}, {205.555, 120.32400000000001`}, {
                    205.83200000000002`, 118.61699999999999`}, {206.809, 
                    115.62100000000001`}, {208.47299999999998`, 
                    116.60899999999998`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    219.63299999999998`, 104.902}, {219.781, 102.309}, {
                    213.266, 103.60199999999999`}, {211.21899999999997`, 
                    106.363}, {215.32800000000003`, 105.586}, {219.441, 
                    106.98}, {219.63299999999998`, 104.902}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    219.63299999999998`, 104.90199999999999`}, {219.781, 
                    102.309}, {213.266, 103.60199999999998`}, {
                    211.21899999999997`, 106.363}, {215.32800000000003`, 
                    105.58600000000001`}, {219.441, 106.97999999999999`}, {
                    219.63299999999998`, 104.90199999999999`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{193.742, 
                    109.543}, {193.977, 106.95700000000001`}, {186.863, 
                    109.801}, {185.086, 112.25}, {188.91, 111.}, {
                    193.48800000000003`, 111.613}, {193.742, 
                    109.543}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{193.742, 
                    109.54299999999998`}, {193.977, 106.95700000000002`}, {
                    186.863, 109.80100000000002`}, {185.086, 112.25}, {188.91,
                     111.}, {193.48800000000003`, 111.61299999999997`}, {
                    193.742, 109.54299999999998`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{198.105, 
                    108.44100000000002`}, {199.59, 109.508}, {196.559, 
                    112.258}, {194.14499999999998`, 112.902}, {194.418, 
                    111.199}, {196.441, 107.453}, {198.105, 
                    108.44100000000002`}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{198.105, 
                    108.441}, {199.59, 109.50799999999998`}, {196.559, 
                    112.25800000000001`}, {194.14499999999998`, 
                    112.90199999999999`}, {194.418, 111.19899999999998`}, {
                    196.441, 107.453}, {198.105, 108.441}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{198.559, 
                    106.648}, {198.71899999999997`, 104.32}, {190.93, 
                    105.598}, {188.895, 107.74600000000001`}, {195.594, 
                    106.535}, {198.34, 108.641}, {198.559, 106.648}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{198.559, 
                    106.64799999999997`}, {198.71899999999997`, 104.32}, {
                    190.93, 105.59799999999998`}, {188.895, 
                    107.74600000000001`}, {195.594, 106.535}, {198.34, 
                    108.64099999999999`}, {198.559, 106.64799999999997`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{202.207, 
                    105.098}, {203.07399999999998`, 102.93400000000001`}, {
                    195.598, 103.46100000000001`}, {192.97299999999998`, 
                    104.71900000000001`}, {197.21499999999997`, 104.754}, {
                    201.61299999999997`, 106.60199999999999`}, {202.207, 
                    105.098}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{202.207, 
                    105.09799999999998`}, {203.07399999999998`, 102.934}, {
                    195.598, 103.46100000000001`}, {192.97299999999998`, 
                    104.719}, {197.21499999999997`, 104.75400000000002`}, {
                    201.61299999999997`, 106.60199999999998`}, {202.207, 
                    105.09799999999998`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    205.70299999999997`, 103.52}, {206.531, 101.582}, {
                    199.617, 101.62499999999999`}, {196.24599999999998`, 
                    102.695}, {200.71099999999998`, 102.73}, {
                    204.88700000000003`, 105.438}, {205.70299999999997`, 
                    103.52}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    205.70299999999997`, 103.51999999999998`}, {206.531, 
                    101.582}, {199.617, 101.625}, {196.24599999999998`, 
                    102.695}, {200.71099999999998`, 102.73000000000002`}, {
                    204.88700000000003`, 105.43799999999999`}, {
                    205.70299999999997`, 103.51999999999998`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    210.73399999999998`, 102.48}, {211.961, 
                    100.18799999999999`}, {204.664, 99.965}, {202.297, 
                    101.09400000000001`}, {206.516, 101.67199999999998`}, {
                    209.691, 104.285}, {210.73399999999998`, 
                    102.48}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    210.73399999999998`, 102.47999999999999`}, {211.961, 
                    100.18799999999999`}, {204.664, 99.965}, {202.297, 
                    101.094}, {206.516, 101.67199999999997`}, {209.691, 
                    104.28500000000003`}, {210.73399999999998`, 
                    102.47999999999999`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{202.191, 
                    106.398}, {199.871, 104.938}, {199.996, 109.25}, {198.148,
                     112.238}, {201.05100000000002`, 109.598}, {203.766, 
                    107.79700000000001`}, {202.191, 106.398}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{202.191, 
                    106.398}, {199.871, 104.93799999999999`}, {199.996, 
                    109.25}, {198.148, 112.238}, {201.05100000000002`, 
                    109.59799999999998`}, {203.766, 107.79700000000003`}, {
                    202.191, 106.398}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{206.305, 
                    104.848}, {204.35500000000002`, 103.12499999999999`}, {
                    202.80100000000002`, 109.043}, {201.02700000000002`, 
                    112.367}, {203.895, 109.203}, {208.102, 106.281}, {
                    206.305, 104.848}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{206.305, 
                    104.84799999999998`}, {204.35500000000002`, 103.125}, {
                    202.80100000000002`, 109.04299999999998`}, {
                    201.02700000000002`, 112.36700000000002`}, {203.895, 
                    109.203}, {208.102, 106.28100000000003`}, {206.305, 
                    104.84799999999998`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{211.742, 
                    103.199}, {210.094, 101.289}, {205.32800000000003`, 
                    108.816}, {203.594, 112.73400000000001`}, {
                    206.23399999999998`, 109.684}, {213.055, 104.82}, {
                    211.742, 103.199}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{211.742, 
                    103.19899999999998`}, {210.094, 101.28900000000002`}, {
                    205.32800000000003`, 108.816}, {203.594, 
                    112.73400000000001`}, {206.23399999999998`, 109.684}, {
                    213.055, 104.82}, {211.742, 103.19899999999998`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{207.105, 
                    97.45700000000001}, {206.281, 94.551}, {
                    194.15200000000002`, 100.195}, {192.797, 103.117}, {
                    199.738, 99.44100000000002}, {207.26999999999998`, 
                    100.21100000000001`}, {207.105, 
                    97.45700000000001}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{207.105, 
                    97.45700000000002}, {206.281, 94.55100000000002}, {
                    194.15200000000002`, 100.195}, {192.797, 
                    103.11699999999999`}, {199.738, 99.441}, {
                    207.26999999999998`, 100.21100000000001`}, {207.105, 
                    97.45700000000002}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYCYtmoFOv7zKkOYLo/2WFGnlDzgV8pDmF8upvm
zk52KLTlur74QYpDOIgPlHdMeHpB6XmKgxOILk52yJj4tsb+bYrDnZ91WXt8
kh1unvse/Fg1FaK/PclBla1xqnN7qoPllhNl+5yTIOadSXX4phHTf0gwyUH/
rgpbo2W6Q+vrwB1yBxMd4nZ58jDdT3eoFlnn/nBeooNLd87z35YZEH09iQ5A
ssC2LQPijnio/MEMh+kgd4slQtyzMgNibmmig495p2PC1AyIe3YnQsUzHISb
D5xaCLT/gtLtn3VhGQ6LXLd9/huT5LDq4yXfJJYMiH/XQ92/Pt2BAQS2JEHc
KZgOcf/OJIdekMUuaRB1x5Mg4bge6l/2ZEg4JUP56tDwMk2F+DM42QE9/AFt
n6we
                    "]]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYCYtmoFOv7zKkOYLo/2WFGnlDzgV8pDmF8upvm
zk52KLTlur74AZQPlHdMeHpB6XkKhC5OdsiY+LbG/m2Kw+2fdVl7fJIdbp77
HvxYNRWivj3JQZWtcapze6qD5ZYTZfuckyDmnUl1+KYR039IMMlB/64KW6Nl
ukPr68AdcgcTHeJ2efIw3U93qBZZ5/5wXqKDS3fO89+WGRB9PYkOQLLAti0D
Yn88VP5gBsTdYokQ96zMcNADmVua6OBj3umYMDUD4p7diRD7SjMchJsPnFoI
tP+CEtDlYRkOi1y3ff4bk+Sw6uMl3yQWqPr1UPevT3dgAIEtSRB3CqZD3L8z
yaF3OtBilzQHNZC640mQcFwP9S97soMTyJ3JUL46NLxMUyH+DE52QA9/AGl3
rBs=
                    "],
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{196.434, 
                    132.105}, {197.98800000000003`, 130.95700000000002`}, {
                    199.707, 135.066}, {197.73, 138.97299999999998`}, {
                    197.668, 135.21499999999997`}, {194.68, 
                    133.94899999999998`}, {196.434, 132.105}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{196.434, 
                    132.105}, {197.98800000000003`, 130.95700000000002`}, {
                    199.707, 135.066}, {197.73, 138.97299999999998`}, {
                    197.668, 135.215}, {194.68, 133.94899999999998`}, {
                    196.434, 132.105}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{197.93, 
                    128.336}, {200.08200000000002`, 127.67599999999999`}, {
                    200.758, 131.484}, {199.34, 134.535}, {
                    199.57399999999998`, 131.258}, {195.953, 129.285}, {
                    197.93, 128.336}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{197.93, 
                    128.336}, {200.08200000000002`, 127.67599999999999`}, {
                    200.758, 131.484}, {199.34, 134.535}, {
                    199.57399999999998`, 131.258}, {195.953, 
                    129.28500000000003`}, {197.93, 128.336}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{199.566, 
                    125.312}, {201.648, 124.277}, {202.43800000000002`, 
                    128.125}, {200.941, 130.984}, {201.105, 127.34}, {197.965,
                     126.262}, {199.566, 125.312}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{199.566, 
                    125.31199999999998`}, {201.648, 124.27700000000002`}, {
                    202.43800000000002`, 128.125}, {200.941, 130.984}, {
                    201.105, 127.34}, {197.965, 126.262}, {199.566, 
                    125.31199999999998`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    198.71099999999998`, 125.07799999999999`}, {
                    197.88700000000003`, 122.617}, {193.105, 127.203}, {
                    192.30100000000002`, 129.69899999999998`}, {
                    195.26999999999998`, 126.75}, {199.305, 
                    127.07799999999999`}, {198.71099999999998`, 
                    125.07799999999999`}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    198.71099999999998`, 125.07799999999997`}, {
                    197.88700000000003`, 122.61699999999999`}, {193.105, 
                    127.203}, {192.30100000000002`, 129.69899999999998`}, {
                    195.26999999999998`, 126.75}, {199.305, 
                    127.07799999999997`}, {198.71099999999998`, 
                    125.07799999999997`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    196.54299999999998`, 128.848}, {195.605, 126.383}, {
                    189.594, 132.727}, {188.266, 135.781}, {
                    191.23399999999998`, 132.836}, {197.21099999999998`, 
                    130.586}, {196.54299999999998`, 128.848}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    196.54299999999998`, 128.84799999999998`}, {195.605, 
                    126.38300000000001`}, {189.594, 132.72700000000003`}, {
                    188.266, 135.78100000000003`}, {191.23399999999998`, 
                    132.836}, {197.21099999999998`, 130.586}, {
                    196.54299999999998`, 128.84799999999998`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    195.35200000000003`, 132.54299999999998`}, {194.414, 
                    129.742}, {187.879, 137.207}, {186.02700000000002`, 
                    139.85200000000003`}, {189.14499999999998`, 136.941}, {
                    196.059, 134.578}, {195.35200000000003`, 
                    132.54299999999998`}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    195.35200000000003`, 132.54299999999998`}, {194.414, 
                    129.742}, {187.879, 137.20700000000002`}, {
                    186.02700000000002`, 139.852}, {189.14499999999998`, 
                    136.941}, {196.059, 134.57799999999997`}, {
                    195.35200000000003`, 132.54299999999998`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    195.14499999999998`, 135.312}, {197.445, 135.758}, {
                    195.012, 137.676}, {192.191, 140.79299999999998`}, {
                    192.062, 137.512}, {192.598, 135.21899999999997`}, {
                    195.14499999999998`, 135.312}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    195.14499999999998`, 135.31199999999998`}, {197.445, 
                    135.758}, {195.012, 137.676}, {192.191, 140.793}, {
                    192.062, 137.51199999999997`}, {192.598, 135.219}, {
                    195.14499999999998`, 135.31199999999998`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{191.266, 
                    137.176}, {192.258, 138.258}, {190.312, 
                    138.71899999999997`}, {187.90200000000002`, 
                    141.42200000000003`}, {187.547, 139.602}, {190.137, 
                    136.262}, {191.266, 137.176}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{191.266, 
                    137.176}, {192.258, 138.258}, {190.312, 138.719}, {
                    187.90200000000002`, 141.422}, {187.547, 
                    139.60199999999998`}, {190.137, 136.262}, {191.266, 
                    137.176}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    202.39800000000002`, 125.016}, {203.66, 124.277}, {204.52,
                     126.859}, {202.953, 129.195}, {202.594, 
                    126.66799999999999`}, {201.24599999999998`, 125.965}, {
                    202.39800000000002`, 125.016}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    202.39800000000002`, 125.01599999999999`}, {203.66, 
                    124.27700000000002`}, {204.52, 126.85900000000001`}, {
                    202.953, 129.195}, {202.594, 126.66799999999998`}, {
                    201.24599999999998`, 125.965}, {202.39800000000002`, 
                    125.01599999999999`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{175.047, 
                    141.297}, {172.375, 139.691}, {168.125, 146.09}, {
                    166.99200000000002`, 148.72299999999998`}, {169.34, 
                    145.69899999999998`}, {175.555, 142.941}, {175.047, 
                    141.297}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{175.047, 
                    141.29700000000003`}, {172.375, 139.691}, {168.125, 
                    146.09}, {166.99200000000002`, 148.723}, {169.34, 
                    145.69899999999998`}, {175.555, 142.941}, {175.047, 
                    141.29700000000003`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    177.32000000000002`, 137.566}, {175.84, 
                    135.92600000000002`}, {171.184, 140.383}, {169.566, 
                    142.641}, {172.062, 140.48000000000002`}, {
                    177.97299999999998`, 140.22299999999998`}, {
                    177.32000000000002`, 137.566}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    177.32000000000002`, 137.566}, {175.84, 
                    135.92600000000002`}, {171.184, 140.383}, {169.566, 
                    142.641}, {172.062, 140.48}, {177.97299999999998`, 
                    140.223}, {177.32000000000002`, 137.566}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    179.85500000000002`, 134.22299999999998`}, {
                    179.36700000000002`, 131.984}, {172.57, 137.02}, {
                    170.98000000000002`, 139.406}, {173.914, 
                    136.64499999999998`}, {180.30100000000002`, 136.895}, {
                    179.85500000000002`, 134.22299999999998`}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    179.85500000000002`, 134.223}, {179.36700000000002`, 
                    131.984}, {172.57, 137.01999999999998`}, {
                    170.98000000000002`, 139.406}, {173.914, 
                    136.64499999999998`}, {180.30100000000002`, 136.895}, {
                    179.85500000000002`, 134.223}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{178.816, 
                    131.80100000000002`}, {177.766, 129.781}, {172.238, 
                    134.781}, {170.914, 137.39100000000002`}, {174.289, 
                    134.441}, {179.672, 133.797}, {178.816, 
                    131.80100000000002`}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{178.816, 
                    131.80100000000002`}, {177.766, 129.78100000000003`}, {
                    172.238, 134.78100000000003`}, {170.914, 
                    137.39100000000002`}, {174.289, 134.441}, {179.672, 
                    133.79700000000003`}, {178.816, 131.80100000000002`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{175.977, 
                    141.625}, {177.71899999999997`, 143.465}, {176.977, 
                    144.324}, {175.707, 147.22299999999998`}, {175.012, 
                    144.24599999999998`}, {173.961, 143.059}, {175.977, 
                    141.625}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{175.977, 
                    141.625}, {177.71899999999997`, 143.465}, {176.977, 
                    144.324}, {175.707, 147.223}, {175.012, 144.246}, {
                    173.961, 143.059}, {175.977, 141.625}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{178.289, 
                    138.15200000000002`}, {181.453, 138.012}, {
                    178.32000000000002`, 141.863}, {177.57, 145.094}, {
                    177.844, 141.41}, {176.758, 138.504}, {178.289, 
                    138.15200000000002`}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{178.289, 
                    138.152}, {181.453, 138.01199999999997`}, {
                    178.32000000000002`, 141.863}, {177.57, 145.094}, {
                    177.844, 141.41}, {176.758, 138.504}, {178.289, 138.152}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{180.305, 
                    135.098}, {182.496, 135.59}, {181.863, 138.695}, {180.184,
                     142.44899999999998`}, {180.531, 138.39100000000002`}, {
                    178.32800000000003`, 136.047}, {180.305, 
                    135.098}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{180.305, 
                    135.09799999999998`}, {182.496, 135.59}, {181.863, 
                    138.695}, {180.184, 142.44899999999998`}, {180.531, 
                    138.39100000000002`}, {178.32800000000003`, 136.047}, {
                    180.305, 135.09799999999998`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{179.559, 
                    128.961}, {178.73399999999998`, 126.49600000000001`}, {
                    172.5, 132.20299999999997`}, {171.508, 134.363}, {174.66, 
                    131.71499999999997`}, {180.117, 130.809}, {179.559, 
                    128.961}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{179.559, 
                    128.961}, {178.73399999999998`, 126.49600000000001`}, {
                    172.5, 132.203}, {171.508, 134.363}, {174.66, 131.715}, {
                    180.117, 130.809}, {179.559, 128.961}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{183.297, 
                    125.113}, {182.359, 122.648}, {175.824, 127.645}, {
                    173.824, 130.36700000000002`}, {177.762, 127.27}, {
                    183.777, 127.55499999999999`}, {183.297, 
                    125.113}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{183.297, 
                    125.11299999999997`}, {182.359, 122.64799999999997`}, {
                    175.824, 127.64499999999998`}, {173.824, 
                    130.36700000000002`}, {177.762, 127.27000000000001`}, {
                    183.777, 127.555}, {183.297, 125.11299999999997`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{187.105, 
                    121.23}, {186.055, 117.79700000000001`}, {
                    179.22299999999998`, 123.281}, {177.184, 125.965}, {
                    181.535, 122.645}, {187.66, 123.67599999999999`}, {
                    187.105, 121.23}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{187.105, 
                    121.23000000000002`}, {186.055, 117.79700000000003`}, {
                    179.22299999999998`, 123.28100000000003`}, {177.184, 
                    125.965}, {181.535, 122.64499999999998`}, {187.66, 
                    123.67599999999999`}, {187.105, 121.23000000000002`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{180.68, 
                    130.055}, {182.535, 129.094}, {183.285, 134.363}, {
                    182.238, 138.08200000000002`}, {182.254, 134.023}, {
                    178.516, 131.008}, {180.68, 130.055}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{180.68, 
                    130.055}, {182.535, 129.094}, {183.285, 134.363}, {
                    182.238, 138.082}, {182.254, 134.023}, {178.516, 
                    131.00799999999998`}, {180.68, 130.055}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{183.848, 
                    125.871}, {186.078, 125.21100000000001`}, {185.371, 
                    130.88700000000003`}, {183.465, 134.57}, {
                    183.21899999999997`, 130.92200000000003`}, {
                    181.57399999999998`, 127.45700000000001`}, {183.848, 
                    125.871}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{183.848, 
                    125.87100000000001`}, {186.078, 125.21100000000001`}, {
                    185.371, 130.88700000000003`}, {183.465, 134.57}, {
                    183.21899999999997`, 130.922}, {181.57399999999998`, 
                    127.45700000000002`}, {183.848, 125.87100000000001`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{187.809, 
                    121.953}, {190.30100000000002`, 121.812}, {188.586, 
                    126.82}, {186.531, 129.641}, {186.879, 
                    125.95700000000001`}, {185.71899999999997`, 
                    122.37899999999999`}, {187.809, 121.953}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{187.809, 
                    121.953}, {190.30100000000002`, 121.81199999999998`}, {
                    188.586, 126.82}, {186.531, 129.641}, {186.879, 
                    125.95700000000002`}, {185.71899999999997`, 
                    122.37899999999999`}, {187.809, 121.953}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{183.441, 
                    119.816}, {182.691, 118.54700000000001`}, {180.859, 
                    120.895}, {177.85200000000003`, 122.60499999999999`}, {
                    180.555, 121.898}, {183.77299999999997`, 120.992}, {
                    183.441, 119.816}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{183.441, 
                    119.816}, {182.691, 118.547}, {180.859, 
                    120.89500000000001`}, {177.85200000000003`, 
                    122.60499999999999`}, {180.555, 121.898}, {
                    183.77299999999997`, 120.99199999999999`}, {183.441, 
                    119.816}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{182.016, 
                    162.008}, {184.34, 163.727}, {182.566, 166.945}, {182.016,
                     170.008}, {181.26999999999998`, 167.105}, {179.297, 
                    163.297}, {182.016, 162.008}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{182.016, 
                    162.00799999999998`}, {184.34, 163.72700000000003`}, {
                    182.566, 166.945}, {182.016, 170.00799999999998`}, {
                    181.26999999999998`, 167.105}, {179.297, 
                    163.29700000000003`}, {182.016, 162.00799999999998`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    181.93800000000002`, 157.71899999999997`}, {178.441, 
                    158.141}, {178.969, 162.656}, {178.863, 165.52}, {179.914,
                     161.63299999999998`}, {182.777, 160.977}, {
                    181.93800000000002`, 157.71899999999997`}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    181.93800000000002`, 157.719}, {178.441, 158.141}, {
                    178.969, 162.656}, {178.863, 165.51999999999998`}, {
                    179.914, 161.63299999999998`}, {182.777, 160.977}, {
                    181.93800000000002`, 157.719}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    182.48800000000003`, 158.305}, {185.441, 158.477}, {
                    185.285, 161.836}, {185.445, 165.238}, {183.945, 
                    162.11299999999997`}, {182.172, 161.629}, {
                    182.48800000000003`, 158.305}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    182.48800000000003`, 158.305}, {185.441, 158.477}, {
                    185.285, 161.836}, {185.445, 165.238}, {183.945, 
                    162.11299999999997`}, {182.172, 161.629}, {
                    182.48800000000003`, 158.305}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    182.36700000000002`, 154.129}, {180.07, 153.945}, {
                    178.875, 156.20299999999997`}, {178.348, 
                    159.72299999999998`}, {180.52700000000002`, 
                    156.48000000000002`}, {182.512, 157.48800000000003`}, {
                    182.36700000000002`, 154.129}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    182.36700000000002`, 154.129}, {180.07, 153.945}, {
                    178.875, 156.203}, {178.348, 159.723}, {
                    180.52700000000002`, 156.48}, {182.512, 157.488}, {
                    182.36700000000002`, 154.129}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{183.191, 
                    154.406}, {186.148, 154.02700000000002`}, {185.676, 
                    157.469}, {185.555, 160.004}, {184.65200000000002`, 
                    157.586}, {182.24599999999998`, 156.824}, {183.191, 
                    154.406}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{183.191, 
                    154.406}, {186.148, 154.02700000000002`}, {185.676, 
                    157.469}, {185.555, 160.004}, {184.65200000000002`, 
                    157.586}, {182.24599999999998`, 156.824}, {183.191, 
                    154.406}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{178.586, 
                    155.863}, {178.82000000000002`, 153.617}, {180.238, 
                    149.758}, {182.523, 150.625}, {183.469, 153.383}, {
                    180.516, 153.934}, {178.586, 155.863}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{178.586, 
                    155.863}, {178.82000000000002`, 153.617}, {180.238, 
                    149.758}, {182.523, 150.625}, {183.469, 153.383}, {
                    180.516, 153.934}, {178.586, 155.863}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{183.23, 
                    150.383}, {182.207, 152.35500000000002`}, {185.555, 
                    153.34}, {186.266, 155.89800000000002`}, {186.672, 
                    152.23399999999998`}, {186.33200000000002`, 
                    149.83200000000002`}, {183.23, 150.383}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{183.23, 
                    150.383}, {182.207, 152.35500000000002`}, {185.555, 
                    153.34}, {186.266, 155.898}, {186.672, 152.234}, {
                    186.33200000000002`, 149.832}, {183.23, 150.383}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    173.70299999999997`, 173.727}, {175.54299999999998`, 
                    175.71099999999998`}, {173.918, 178.85200000000003`}, {
                    173.36700000000002`, 181.914}, {172.621, 179.012}, {
                    171.324, 175.164}, {173.70299999999997`, 
                    173.727}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    173.70299999999997`, 173.72700000000003`}, {
                    175.54299999999998`, 175.711}, {173.918, 178.852}, {
                    173.36700000000002`, 181.914}, {172.621, 
                    179.01199999999997`}, {171.324, 175.164}, {
                    173.70299999999997`, 173.72700000000003`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{173.648, 
                    170.039}, {170.418, 169.71099999999998`}, {169.637, 
                    176.285}, {169.305, 179.10899999999998`}, {
                    170.35500000000002`, 175.22299999999998`}, {174.078, 
                    173.445}, {173.648, 170.039}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{173.648, 
                    170.039}, {170.418, 169.711}, {169.637, 
                    176.28500000000003`}, {169.305, 179.10899999999998`}, {
                    170.35500000000002`, 175.223}, {174.078, 173.445}, {
                    173.648, 170.039}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{174.312, 
                    170.105}, {176.594, 171.285}, {176.066, 173.824}, {
                    176.781, 175.73}, {175.24599999999998`, 
                    173.39100000000002`}, {173.848, 173.055}, {174.312, 
                    170.105}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{174.312, 
                    170.105}, {176.594, 171.28500000000003`}, {176.066, 
                    173.824}, {176.781, 175.73000000000002`}, {
                    175.24599999999998`, 173.39100000000002`}, {173.848, 
                    173.055}, {174.312, 170.105}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{173.672, 
                    165.80100000000002`}, {170.29299999999998`, 165.512}, {
                    168.277, 172.789}, {168.172, 175.656}, {
                    169.22299999999998`, 171.766}, {174.066, 169.656}, {
                    173.672, 165.80100000000002`}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{173.672, 
                    165.80100000000002`}, {170.29299999999998`, 
                    165.51199999999997`}, {168.277, 172.78900000000002`}, {
                    168.172, 175.656}, {169.22299999999998`, 
                    171.76600000000002`}, {174.066, 169.656}, {173.672, 
                    165.80100000000002`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    174.32000000000002`, 165.91}, {177.5, 
                    166.64499999999998`}, {177.117, 168.69899999999998`}, {
                    176.641, 172.02700000000002`}, {175.629, 168.676}, {
                    173.85500000000002`, 169.38700000000003`}, {
                    174.32000000000002`, 165.91}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    174.32000000000002`, 165.91}, {177.5, 
                    166.64499999999998`}, {177.117, 168.69899999999998`}, {
                    176.641, 172.02700000000002`}, {175.629, 168.676}, {
                    173.85500000000002`, 169.38700000000003`}, {
                    174.32000000000002`, 165.91}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    173.63299999999998`, 161.602}, {169.914, 160.969}, {
                    170.176, 166.848}, {167.227, 171.11299999999997`}, {
                    169.777, 167.945}, {174.375, 163.953}, {
                    173.63299999999998`, 161.602}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    173.63299999999998`, 161.60199999999998`}, {169.914, 
                    160.969}, {170.176, 166.84799999999998`}, {167.227, 
                    171.11299999999997`}, {169.777, 167.945}, {174.375, 
                    163.953}, {173.63299999999998`, 161.60199999999998`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    174.47299999999998`, 161.80100000000002`}, {177.277, 
                    161.71899999999997`}, {177.55100000000002`, 165.941}, {
                    177.395, 167.656}, {176.75, 165.94899999999998`}, {
                    173.453, 164.32800000000003`}, {174.47299999999998`, 
                    161.80100000000002`}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    174.47299999999998`, 161.80100000000002`}, {177.277, 
                    161.719}, {177.55100000000002`, 165.941}, {177.395, 
                    167.656}, {176.75, 165.94899999999998`}, {173.453, 
                    164.328}, {174.47299999999998`, 161.80100000000002`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{167.824, 
                    166.129}, {169.21899999999997`, 161.605}, {171.195, 
                    157.07}, {173.63299999999998`, 157.414}, {
                    174.80100000000002`, 159.98800000000003`}, {
                    171.32000000000002`, 160.316}, {167.824, 
                    166.129}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{167.824, 
                    166.129}, {169.21899999999997`, 161.605}, {171.195, 
                    157.07}, {173.63299999999998`, 157.414}, {
                    174.80100000000002`, 159.988}, {171.32000000000002`, 
                    160.316}, {167.824, 166.129}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{174.512, 
                    158.078}, {173.48800000000003`, 160.05100000000002`}, {
                    176.836, 161.035}, {177.547, 163.598}, {177.953, 
                    159.934}, {177.61299999999997`, 157.52700000000002`}, {
                    174.512, 158.078}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{174.512, 
                    158.07799999999997`}, {173.48800000000003`, 
                    160.05100000000002`}, {176.836, 161.035}, {177.547, 
                    163.59799999999998`}, {177.953, 159.934}, {
                    177.61299999999997`, 157.52700000000002`}, {174.512, 
                    158.07799999999997`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{168.785, 
                    160.961}, {170.77299999999997`, 156.88700000000003`}, {
                    171.672, 152.20299999999997`}, {174.40200000000002`, 
                    152.883}, {175.42200000000003`, 156.05100000000002`}, {
                    171.38700000000003`, 156.71499999999997`}, {168.785, 
                    160.961}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{168.785, 
                    160.961}, {170.77299999999997`, 156.88700000000003`}, {
                    171.672, 152.203}, {174.40200000000002`, 152.883}, {
                    175.42200000000003`, 156.05100000000002`}, {
                    171.38700000000003`, 156.715}, {168.785, 160.961}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{174.969, 
                    153.656}, {173.79299999999998`, 155.812}, {
                    177.14499999999998`, 156.57399999999998`}, {177.965, 
                    159.547}, {178.41, 155.656}, {177.99200000000002`, 
                    152.883}, {174.969, 153.656}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{174.969, 
                    153.656}, {173.79299999999998`, 155.81199999999998`}, {
                    177.14499999999998`, 156.57399999999998`}, {177.965, 
                    159.547}, {178.41, 155.656}, {177.99200000000002`, 
                    152.883}, {174.969, 153.656}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{180.695, 
                    181.238}, {182.656, 180.71099999999998`}, {
                    184.71499999999997`, 182.91}, {184., 186.207}, {181.758, 
                    185.648}, {180.73, 183.61299999999997`}, {180.695, 
                    181.238}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{180.695, 
                    181.238}, {182.656, 180.711}, {184.71499999999997`, 
                    182.91}, {184., 186.20700000000002`}, {181.758, 
                    185.64799999999997`}, {180.73, 183.61299999999997`}, {
                    180.695, 181.238}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC0c0HTi08m+qw+uMl36Q7aQ5xuzx5mC6nOszI
E2o+sC/NwTHh6QWl76kODCCwJ82h0Jbr+uI3qQ57SyZLsDxLc5CNSrG+/xgq
z5Hu8LbG3jTuUaqD/l0VtkbFdLj61teBO+Rs0x22nijbN/9XKkRffDrEnG+p
DtUi69wfzkp3KM6Y+LbmdapDEYjenO5w+2dd1p4HqQ4+5p2OCWfTHQxA5u5N
dQCaWmC7Lx3i7jOpDjfPfQ9+vDLd4Q5I/R2o/CSo+rupDiDj7BOh7ruU6vAO
RHulO4Ty6W6aezjVoXc60MMa6Q5hIP7xVAj9O80BPXwAlGyLqw==
                    
                    "]]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC0c0HTi08m+qw+uMl36Q7aQ5xuzx5mC6nOszI
E2o+sC/NwTHh6QWl76kODCCwJ82h0Jbr+uI3qQ57SiZLsDxLc5CNSrG+/xgq
z5Hu8LbG3jTuUaqD/l0VtkbFdLj61teBO+Rs0x22nijbN/9XKkRffLrDXpA5
31IdqkXWuT+cle5QnDHxbc3rVIciEL053eH2z7qsPQ9SHbzNOx0TzqY7GIDM
3ZvqADS1wHZfOsTdZ1Idbp77Hvx4ZbrDHZD6O1D5SVD1d1MdQMbZJ0LddynV
4R2I9kp3COXT3TT3cKpD33SghzXSHcJA/OOpEPp3mgN6+AAAkxSLqg==
                    
                    "],
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4thdnjxM4hkO++dL6d91SXWYkSfUfOBfukPG
xLc19oqpEPpsugNYnXmqQxyI/pzuwAACGakON899D34smOEQzqe7aW5/qsPe
kskSLHYZEPkNUP2OGQ6LXLd9/nsj1cFyy4myfc5Q+3jSHLiuLy6wTcpwsAKJ
R6dB9NdlQMTL0hy2AoXnz8qA0JPSHMJA9uzOgLgzKw1i7pwMB5moFOv74VD1
VRkOws0HTi10THNY9fGSb1JKhsM3jZj+Q09THVpfB+6QS81wuKh0+2fdoVQH
WZC+5AwHVbbGqc5A94PdZZDhwA2yPyvVAT18ADOmhG0=
                    "]]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4thdnjxM4hkO++ZL6d91SXWYkSfUfOBfukPG
xLc19oqpEPpsukMcSJ15KoT+nO7AAAIZqQ43z30PfiyY4RDGp7tpbn+qw96S
yRIsdhkQ+Q1Q/Y4ZDotdt33+eyPVwXLLibJ9zlD7eNIcuK4vLrBNynCwAolH
p0H012VAxMvSHLYChefPynAASc+flAaxZ3cGxJ1ZaQ6LQObOyXCQjUqxvh8O
VV+V4SDcfODUQsc0h1UfL/kmpWQ4fNWI6T/0NNWh9XXgDrnUDIcLSrd/1h1K
hehLznBQZWuc6gx0/36Quwyg9melOqCHDwAx7oRo
                    "],
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4hl5Qs0HTqU7cF1fXGBbl+pwUen2z7pN6Q6X
QHRUqoNsVIr1/e50B1W2xqnO+akO3zRi+g8tTHfonQ7UuCLV4Zi3eafjlnSH
x0tnH1G4kAoxZ1u6Q8bEtzX2jGkO1SLr3B/CzJdLcwjj090093m6AzeI75Xm
sOrjJd8kiQyIurw0iDkmGQ4gYxM60xyArsjaE5ABsXdpGsTejAyHdzX2pnFd
aRBz/TIc1A051sgUpTm8BYnrZUDEg9IcrLacKNvHneGwFUjN10pzKLAFyvxI
d+gDmcMDNf9KOkT/pVSI+U/SHUJB7lyc6oAePgBisIf1
                    "]]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4hl5Qs0HTqU7cF1fXGBbl+pwUen2z7pN6RA6
KtVBNirF+n53uoMqW+NU5/xUh28aMf2HFqY79E0HalyR6nDM27zTcUu6w+Ol
s48oXEiFmLMt3SFj4tsae8Y0h2qRde4PYebLpTmE8elumvscyvdKc1j18ZJv
kkQGRF1eGsQckwwHH6CxCZ1pDkBXZO0JyHD4CrJ3aZpDL8jejAyHdzX2pnFd
aRBz/DIc1A051sgUpTm8BYnrZUDEg9IcrLacKNvHneEAouZrpTkU2AJlfkDd
zwM1/0o6RP+lVIj5T9IdQkHuXJzqgB4+AGGgh/M=
                    "],
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYCYsstJ8r2mac5TM8Taj5gluawf76U/l2TNIdV
Hy/5JrGkORjcVWFrjE1zOO5t3un4I9UhjE9309zoNIeMiW9r7B3THG6e+x78
OBKqrjfNQTYqxfq+cpqDKlvjVOfLaQ6LXLd9/usC5bunOwB1mcaFpTkwgEBD
ugPI+vlA/uOls48ovEiH0D5pDhMOfdWIkc9wqBZZ5/7QKc2B6/riAtuwDIj5
0mkQc4wyHLaC9GulQdzFnuEQt8uTh8k6zUHdkGONzLV0iLh6moNjwtMLSuXp
Dk4gGqi/H2Q+0D1AX59a+DUV4r89aQ4u3TnPf1umOfSCAqQizQE9fAAfS4EP

                    "]]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYCYsstJ8r2mac5zMgTaj5gluawf76U/l2TNIdV
Hy/5JrGkORjcVWFrjE1zOO5t3un4I9UhjE9309zoNIeMiW9r7B3THG6e+x78
ODLNQR+krjfNQTYqxfq+cpoDkDfV+XKawyLXbZ//uqQ5qIH47ukOQF2mcWFp
Dgwg0JDuALJ+PpD/ZOnsIwov0h0eg2ifNIcJh75qxMhnOFSLrHN/6JTmwHV9
cYFtWAbEfOk0h3cgc4wyHLaC9GulQdzFnuEQt8uTh8k6zUHdkGONzLV0iLh6
moNTwtMLSuXpEFoaaj7QPUBfn1r4NRXivz1pDi7dOc9/W6Y59E0HBkhFmgN6
+AAAITuBFQ==
                    "],
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4rc19qZxy9IcMiYCWb7pDr3T84SaF6Q5xO3y
5GGST4eIV6Y5zAAKH5BKdyiw5bq+uCXN4bi3eadjTLqDuiHHGpm+NAcQN2Fi
uoPVlhNl+/qh5u1EqAeb+yTdwQekrjTN4ZLS7Z91UhkQuirNASR9oCzD4ea5
78GPW9McWl8H7pCbm+Ggf1eFrXFimsM3jZj+Q0czHGSiUqzvb09z2FsyWYJl
XYaDJci+5WkOQFsKbPsyIOLToO7JzHBY5Lrt898paQ53ftZl7ZHJgLhrYRpE
/AfUfxvTHB4vnX1E4Ui6w/75Uvp310DNr0t3gIUP2N3A8AEAehyKbA==
                    
                    "]]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4rc19qZxy9IcMiYCWb7pDr3T84SaF6Q5xO3y
5GGST4eIV6Y5zAAKH5BKdyiw5bq+uCXN4bi3eadjTLqDuiHHGpm+NAcQN2Fi
uoPVlhNl+/rTHDJB+nYi1IPNfZLu4ANSV5rmcEnp9s86qQwIXQU1vyzD4ea5
78GPW9McWl8H7pCbm+Ggf1eFrXFimsM3jZj+Q0czHGSiUqzvb09z2FMyWYJl
XYaDJci+5WkOQFsKbPsyHPaCxKelQezJzHBY5Lrt898paQ53ftZl7ZHJgPhn
YZrDYpD4D6j/NqY5PF46+4jCkXSH/fOl9O+ugZpfl+4ACx+w/4DhAwB7lIpt

                    "],
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4sdLZx9RkEh1EG4+cGrhzGSH4oyJb2u0Ux0u
Kt3+WdeU7ACW90l1cOnOef57YrLD2xp70zi9VAeQMvuNyQ57SyZLsIilOlwC
qT8F5ctB9V9KdnBMeHpBiR+q/mOyQ+/0PKFmhlSHUD7dTXOFUyDijKkOW06U
7ZuvlgKx/30KRJ99ioMVSOJ+isMFkHlhKRD3nEhx2ApSb5fiwAACN1IcnEDq
tVMcZKNSrO+/htJA88HufZbiMANo7QGmFIi7PqU4rP54yTfpTbLDvvlS+nc5
Uh1unvse/PhoskMRyH7mVIdvGjH9hzZC/Y8UPgCcGY/J
                    "]]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4sdLZx9RkEh1EG4+cGrhzGSH4oyJb2u0Ux0u
KN3+WdeU7ACW90l1cO7Oef57YrLD2xp70zi9VAeQMvuNyQ57SyZLsIilOlwE
qT8F5ctB9V9KdnBMeHpBiR+q/mOyQ+/0PKFmhlSHUD7dTXOFUyDijKkOW0+U
7ZuvlgKx/30KRJ99ioPVFqDE/RSI+WEpEPecSIGot0txYACBG1D12ikOslEp
1vdfQ2mg+WD3PktxmAG09gAT1JxPKQ6rP17yTXqT7LBvvpT+XY5Uh5vnvgc/
PprsUASynznV4ZtGTP+hjVD/I4UPAJkBj8Y=
                    "],
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{185.07, 137.11299999999997`}, {187.023, 
                    136.15200000000002`}, {188.504, 133.754}, {188.602, 
                    131.805}, {188.76999999999998`, 129.555}, {189.09, 
                    127.66}, {190.102, 126.062}, {188.496, 126.508}, {187.727,
                     129.07}, {187.496, 131.523}, {187.266, 134.059}, {
                    185.89800000000002`, 135.16}, {185.07, 
                    137.11299999999997`}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{185.07, 137.11299999999997`}, {187.023, 
                    136.152}, {188.504, 133.75400000000002`}, {188.602, 
                    131.805}, {188.76999999999998`, 129.555}, {189.09, 
                    127.66}, {190.102, 126.06199999999998`}, {188.496, 
                    126.50799999999998`}, {187.727, 129.07}, {187.496, 
                    131.523}, {187.266, 134.059}, {185.89800000000002`, 
                    135.16}, {185.07, 137.11299999999997`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{189.137, 132.406}, {190.48800000000003`, 
                    129.914}, {192.375, 128.965}, {192.47299999999998`, 
                    127.113}, {192.637, 124.98400000000001`}, {192.797, 
                    124.87899999999999`}, {193.375, 122.785}, {191.785, 
                    123.20700000000001`}, {191.383, 123.348}, {190.953, 
                    126.531}, {190.691, 128.76999999999998`}, {
                    188.89800000000002`, 130.348}, {189.137, 
                    132.406}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{189.137, 132.406}, {190.48800000000003`, 
                    129.914}, {192.375, 128.965}, {192.47299999999998`, 
                    127.11299999999997`}, {192.637, 124.98400000000001`}, {
                    192.797, 124.87899999999999`}, {193.375, 
                    122.78500000000003`}, {191.785, 123.20700000000002`}, {
                    191.383, 123.34799999999998`}, {190.953, 126.531}, {
                    190.691, 128.77}, {188.89800000000002`, 
                    130.34799999999998`}, {189.137, 132.406}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{231.176, 
                    109.34400000000001`}, {231.934, 107.91400000000002`}, {
                    232.805, 105.73400000000001`}, {234.38700000000003`, 
                    106.133}, {234.41, 107.23}, {232.68, 107.988}, {231.176, 
                    109.34400000000001`}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    233.52700000000002`, 108.85499999999999`}, {236.598, 
                    107.598}, {239.24599999999998`, 107.91000000000001`}, {
                    239.57399999999998`, 105.98}, {236.69899999999998`, 
                    105.66799999999999`}, {235.64499999999998`, 
                    106.85199999999999`}, {233.52700000000002`, 
                    108.85499999999999`}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{220.68, 119.008}, {222.74599999999998`, 
                    117.316}, {224.086, 115.383}, {224.71099999999998`, 
                    112.887}, {225.363, 110.559}, {226.281, 108.703}, {
                    227.625, 106.613}, {225.434, 108.10499999999999`}, {
                    224.059, 110.141}, {223.36700000000002`, 112.586}, {
                    222.762, 114.992}, {222.05100000000002`, 116.793}, {
                    220.68, 119.008}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{223.22299999999998`, 119.016}, {
                    225.43800000000002`, 117.24600000000001`}, {
                    227.52700000000002`, 115.242}, {228.15200000000002`, 
                    112.742}, {228.805, 110.418}, {229.19899999999998`, 
                    108.637}, {230.691, 106.324}, {228.35200000000003`, 
                    107.816}, {227.42200000000003`, 110.074}, {
                    226.73399999999998`, 112.52}, {226.129, 114.926}, {
                    224.742, 116.727}, {223.22299999999998`, 119.016}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4tbXgTvkLuY4NB84tdDVL8ZBla1xqvP5HAeu
64sLbLNiHG79rMvacyPHYUaeUPOBphiHY97mnY5Pchycu3Oe/+6Mcdh6omzf
/F9Q+VkxDotct33+K5Dr0DsdKLAixsEx4ekFJfVch4Ug8S0xDqs+XvJNcsh1
kNa/q8J2MMbhotLtn3V+uRB9c6DmAfkZE9/W2LfGQMwF8r9pxPQfio1xCOfT
3TTXP9dBdJ37wyobhHovHibtdrkYiD7fXAegaVcqfkY7CIM85pnrIAfy6Ldo
h5vnvgc/toXa/zHaIW6XJ1BnrgPIuQdeRUPsE8p18EsSiLB8Eu1gtQVowf8c
h1iQutPRDrdB4fEhB+K/HdGQcHqU4wD05e2fx6D6b+U4FIMc8hxq39Uch+Og
cGOAhu/lHIj9hjEO6OEPAG3WvnI=
                    "]], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4oyJb2vsH+Y6NB84tdDVL8YhbpcnD9PjXAeu
64sLbLNiHML4dDfNvZ3rsNB12+e/LTEO3uadjgkXcx1E1rk/rOqJcfAB8ffm
OmSCzJkb46B/V4WtcWWuw8MqoIqFMQ690/OEmqfkOhSDLJof49D6OnCHXG2u
w3GQQQtiHFTZGqc6l+c6fNOI6T80NcbBMeHpBSUgf2/JZAmWuhiHWJB7gHw5
kMawGIi7ynIh5hog1M8Acg8IxTis+njJN6ki18EA5I630Q4MIADkg5QfeBXt
cFHp9s+6plwHsL+fRjv0H/qqETM510EeZP69aIi7NuQ6LAL59040xL0Hcx02
zX2//NjhaIetJ8r2zT8H9d/GaIg77+VC7DkAlb8Hdc+jaAegLaZx96Dm/YmG
hMP9XAdpUEAZxjighz8ADGG3Xg==
                    "]], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4p1yra8DlQod9s2X0r8bkerweOnsIwpGhQ5h
fLqb5nanOixy3fb5r0uhw0Wl2z/rhFIdGECgrdDhuLd5p+OOFIdjIHpJoYNj
wtMLSv0pDlEp1vf9dxY66N9VYWtUTIHQQH7GxLc19jeTIebsKnSw3HKibN/y
ZIfpeULNB7YVOnBdX1xgW5YMVw/muyVD9O0uhNirkewwWYIljO90oUOBLVDF
kySI/QcKHfoPfdWIuZzk4P6wSmTdYqh/ViQ5gKyZX1fosOrjJd8kjyQHA5D5
uYUOsbs8eZjUofJxhRB/8iQ5WIEEAgsdfIDGJqyFyrsVOgBDaYfc1ySHZcDg
2WBV6KBuyLFGxikZ4i6HQoe9JUCXzUt2yHn+e+VHOaj6p8kOIGcWsEP5otDw
OlMAoV1SHKpF1rk/vFTgINx84NTCyBQHAD+Yrl4=
                    "]]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4p1yra8DlQod9s+X0r8bkerweOnsIwpGhQ5h
fLqb5nanOixy3fb5r0uhwwWl2z/rhFIdGECgrdDhuLd5p+OOFIdjIHpJoYNj
wtMLSv0pDlEp1vf9dxY66N9VYWtUTIHQQH7mxLc19jeTHS6CzNlV6GC55UTZ
vuXJDtPzhJoPbCt04Lq+uMC2LBmuHsx3S3bIAOnbXQixVyPZYbIESxjf6UKH
AlugiidJEPsPFDr0H/qqEXM5ycH9YZXIusVQ/6xIcgBZM7+u0GHVx0u+SR5J
DgYg83MLHeJ2efIwqUPl4woh/uRJcrACCQQWOoCMTVgLlXcrdACG0g65r0kO
y4DBs8Gq0EHdkGONjFMyxF0OhQ57SoAum5fskPP898qPclD1T5MdQM4sYIfy
RaHhdaYAQrukOFSLrHN/eKnAQbj5wKmFkSkOAEFwrl8=
                    "],
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[0.74902, 0., 0.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGI9IGYCYuHmA6cWqhY6yEalWN8/n+xw+KtGTL9WocMF
pds/654lQ8QNCx32lkyWYPmX7NDpmPD0glWhA9f1xQW2QikOlltOlO1zhqpX
S3F4W2NvGudX6BDGp7tprnmKw6dLvkkCUVDz7VMcQJR/aqHDcW/zTkePFIh5
BYUOTkBKKRjKryh0AFFK6VB+TaHDItdtn/8WpDjskGt9HdhQ6AB2d22KAwMI
NBU6FNoCXdST4iAEEm8udNgKdNb8WQg+2D2rUxwe+PdOz2uCmr8/xUGrXezm
uWao+XtSHA6B/N9S6DAjD6hzF9T8tkKHApD5O1IcjoHcvaTQoThj4tua/hQH
kHDBTqh7FFMgNJCvf1eFrfFmMkT/Lij/aDIkPIB8dUOONTKbkuHqweE5L9kB
ZHzC9kKHm+e+Bz+emOwAssZ+a6HDN6CzDrVCzdsEVV8HjZ+1hQ5AXwk1lyQ7
VIusc3+4AhpfeckQ/y+G2p+Z7AAUDeObCVWfkOyQ+/z3yo890PCKg7qnEWp+
WLIDKNjel0LN84PyM6HxZQ01Px4aPirJDtqg8AwtdFBla5zqzJ8MCS9gegAl
k/nfkiD+8YTG14MkSHrxKHSoArn7GVTevdDh8dLZRxQ+JDncB8WXG9T9X5Mg
9lkj7DcAidtC01MP1P1I6RkA3wVEIA==
                    "]]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGI9IGYCYuHmA6cWqhY6yEalWN8/n+xw+KtGTL9WocNF
pds/654lQ8QNCx32lEyWYPmX7NDpmPD0glWhA9f1xQW2QikOlltOlO1zhqpX
S3F4W2NvGudX6BDGp7tprnmKw6dLvkkCUVDz7VMcQJR/aqHDcW/zTkePFIh5
BYUOIEopGMqvKHRwAvHTofyaQodFrts+/y1Icdgh1/o6sKHQAezu2hQHBhBo
KnQotAW6qCfFQQgk3lzoAHLW/FkIPtg9q1McHvj3Ts9rgtq3P8VBq13s5rlm
qPl7UhwOgfzfUugwIw+ocxfU/Dao+TtSHI6B3L2k0KE4Y+Lbmv4UB5BwwU6o
exRTIDSQb3BXha3xZjJE/65CBz0Q/2gyJDyAfHVDjjUym5Lh6sHhOS/ZAWR8
wvZCh5vnvgc/npjsALLGfmuhA8hZh1qh5m2Cqq+Dxs/aQgegr4SaS5IdqkXW
uT9cAY2vvGSI/xdD3ZOZ7AAUDeObCVWfkOyQ+/z3yo89hQ5bQeEVB3VPI9T8
sGQHULC9L4Wa5wflZ0LDzxpqfnyhQwEoIFSSHbRB4Rla6KDK1jjVmT8ZEl5+
UPO/JUH84wlV/yAJkl48CiHufgaVdy90eLx09hGFD0kO90Hx5QYNv69JEPus
EfaD/WULTU89UPcjpWcA3r1EHQ==
                    "],
                    CurveClosed->{1}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    280.14500000000004`, 166.09}, {280.53099999999995`, 
                    163.402}, {279.03499999999997`, 162.51199999999997`}, {
                    277.625, 161.988}, {276.16400000000004`, 
                    161.47299999999998`}, {274.969, 159.906}, {
                    274.35200000000003`, 158.488}}},
                    CurveClosed->{0}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{283.762, 
                    157.246}, {283.14500000000004`, 154.934}, {
                    281.52299999999997`, 155.223}, {280.10900000000004`, 
                    154.703}, {278.65200000000004`, 154.184}, {277.113, 
                    152.336}, {276.5, 150.922}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    275.512, 172.414}, {274.77299999999997`, 
                    172.89100000000002`}, {260.57, 148.97299999999998`}, {
                    261.309, 148.496}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    275.512, 172.414}, {274.77299999999997`, 
                    172.89100000000002`}, {260.57, 148.97299999999998`}, {
                    261.309, 148.496}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{273.984, 173.36700000000002`}, {273.984, 
                    172.512}, {274.76599999999996`, 171.73}, {275.621, 
                    171.73}, {276.477, 171.73}, {277.258, 172.512}, {277.258, 
                    173.36700000000002`}, {277.258, 174.227}, {276.477, 
                    175.004}, {275.621, 175.004}, {274.76599999999996`, 
                    175.004}, {273.984, 174.227}, {273.984, 
                    173.36700000000002`}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{273.984, 173.36700000000002`}, {273.984, 
                    172.51199999999997`}, {274.76599999999996`, 
                    171.73000000000002`}, {275.621, 171.73000000000002`}, {
                    276.477, 171.73000000000002`}, {277.258, 
                    172.51199999999997`}, {277.258, 173.36700000000002`}, {
                    277.258, 174.22700000000003`}, {276.477, 175.004}, {
                    275.621, 175.004}, {274.76599999999996`, 175.004}, {
                    273.984, 174.22700000000003`}, {273.984, 
                    173.36700000000002`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    256.08599999999996`, 192.586}, {261.84, 192.586}, {261.84,
                     191.26600000000002`}, {256.08599999999996`, 
                    191.26600000000002`}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    256.08599999999996`, 192.58599999999998`}, {261.84, 
                    192.58599999999998`}, {261.84, 191.266}, {
                    256.08599999999996`, 191.266}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    256.08599999999996`, 190.078}, {261.84, 190.078}, {261.84,
                     179.055}, {256.08599999999996`, 179.055}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    256.08599999999996`, 190.07799999999997`}, {261.84, 
                    190.07799999999997`}, {261.84, 179.05499999999998`}, {
                    256.08599999999996`, 179.05499999999998`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    262.191, 194.09}, {255.809, 194.05100000000002`}, {
                    255.559, 196.21499999999997`}, {257.719, 198.555}, {
                    258.97999999999996`, 198.531}, {260.227, 198.469}, {
                    262.242, 196.164}, {262.191, 194.09}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    262.191, 194.08999999999997`}, {255.809, 194.051}, {
                    255.559, 196.215}, {257.719, 198.555}, {
                    258.97999999999996`, 198.531}, {260.227, 198.469}, {
                    262.242, 196.164}, {262.191, 194.08999999999997`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {CompressedData["
1:eJxTTMoPSmViYGBQBmIQvX++lP7dPXkOfdPzhJpzMhxko1Ks7z/Oc3i8dPYR
hZgMh28aMf2HGPMdwvl0N83Vz4CIi+RD1P9Jd7igdPtnnVq+g7d5p2PCyXQH
g7sqbI26+Q6qbI1TnfvTHcDmq+Q79ILUJyD4VltOlO2LT3cQbj5waqEi1Hz/
dIeMiW9r7GXzHRhAwCUdYp8EVL11ukPcLk8eJuF8hyKQQuN0Bx+Qvbz5DluB
0vP1oO5hy4eI66ZD9P2H+kcnHeLOn3kQcf10iP++5kHUm6Y7qBtyrJH5lAex
B2jfcZCGD3kOQFeZxjlB3f8BKu+d7lBgy3V98RcovzrdYdXHS75JQP4lkDtW
pTvsA6l/ATX/KjR87uZBzGXIcAA5Y/4xqPlqGRDz50DVu2ZA6Kl5DtUi69wf
emU4LHLd9vnvhDxIOAVC4wPItwQZFJ4BDfc8B6CrCmzjMiDhMikPEq/JGQ5A
z2rETIeqT89wKAS5f0GeQzHIwPwMhwkg+fV5kHAogroHKX0AAM/u82U=
                    
                    "], CompressedData["
1:eJxTTMoPSmViYGBQAmIQvW++lP7dHXkO3uadjgmJGQ7FGRPf1qzPcwBR9qkZ
Dv2HvmrELM5ziNvlycOUnOFwUen2z7p5UH58hsPjpbOPKMzJc9gPMicmw0E2
KsX6/uw8iDnRCHmw+ZEZDn3T84SagXzHhKcXlMIzHNQNOdbIAM0D2xMMVb8E
ar5/hgMDCFzIcwC6xjRODyr/Is9B/64KWyMrlP8lz6EXZO6NdAifId8hjE93
09zV6RD3/M9zqBZZ5/6wCir/Jw9ir1c6RN3vPIcikHud0x0MQOb+zYP40y7d
YQLIXUD9VltOlO2zTndofR24Q44x32GR67bPfy3SIeYw5UPMtYCaz5IPcQ+Q
z3V9cYEtW74DOJyB/Esgc7nyIeEDNA9sD18+xByndIetQGvmC+U73PpZl7XH
I90BZO18sXxIeASnO3zTiOk/JAlVnwTlK+Y77C2ZLMHSB9Uvle+gytY41fl4
OsReDqh7fqRDwv17nsPNc9+DH2tmOMwACh+4lefgBBIHhj96egAAMkbv9g==

                    "]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxlk1tIVFEUhoeRJEosNCpiNBNN7aYF3YzBZQURpV3EQpvEpFqbsFUR+JAl
iBR0sZJIh2KcLCLSqIgC6TKJBJmIiURZJhERPUQPPVSID7X3Wb8UNHA4HPba
//rW/6+ZU3Vg6544n8/nt89svFdXfh5IrxXKWjzxViDf0NrT1V/G2oR+ZofO
decY8s4fCZ3v/pEd+s30brRu3+Meodppt9d97Gea9ObaweBroW9HC5ZWtDK1
fx8sqhoSOuLO9zKllO9e9eGlUGOLJDWsYDJNtvKF0LbEhfciM5h87tcpqhPP
VOj63RBaeb+nJhbHFLbXulqh72caSB8erWsG3wSm3JGM+PomobNOP4H1fUYo
M77+4ppkVs5TQh2OK8CU5+oboZ+Ffi2Yvxj9Lgm97f9V8ukY+C+Ict9kOv51
S2eqvT/sfHiFc+vfYVcwxurXDviTZKjUzVki6stMo1ybRPukGp2rGPqZhjYu
P1lYWSSqO9/Q0+is3JHN8GeJ0XlLwbvMaJ8K8AaNzrdfKN/NV4D8/snX61cD
vkXQr8a31U9u6Opt24W88gy9d3OG4O8CQ5MdR7nQoMthnlHuMlFfcsBXhvzn
GuUqg18Zhp5vsANaPa9vGniqoB8wmu8J+OM3FHN1YdF7Q/A7Ct52pp0P1yf4
7b54c9u8Htixo1fBU4R9DY/7y+RsiTZDL/D33PNnOvK7PJ4f9iUitN3lOIXp
UNAmcQX1idi/66i3397/5A7ynop9ioEnhdWHZ6jPZ/WhD/vKrL72Is8I+j+B
P32sudwV5bT75s1h+T2utP/z/QOeprBY
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    255.73, 170.09}, {262.152, 170.09}, {262.152, 161.203}, {
                    255.73, 161.203}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    255.73, 170.09}, {262.152, 170.09}, {262.152, 161.203}, {
                    255.73, 161.203}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    255.578, 156.121}, {261.777, 156.121}, {261.777, 
                    154.25400000000002`}, {255.57799999999997`, 
                    154.25400000000002`}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    255.578, 156.121}, {261.777, 156.121}, {261.777, 
                    154.25400000000002`}, {255.57799999999997`, 
                    154.25400000000002`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    255.58200000000002`, 152.84}, {261.93, 152.84}, {261.93, 
                    145.895}, {255.582, 145.895}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    255.58200000000002`, 152.84}, {261.93, 152.84}, {261.93, 
                    145.895}, {255.582, 145.895}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    255.434, 144.47299999999998`}, {262.375, 
                    144.47299999999998`}, {262.375, 140.58999999999997`}, {
                    255.434, 140.58999999999997`}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    255.434, 144.47299999999998`}, {262.375, 
                    144.47299999999998`}, {262.375, 140.58999999999997`}, {
                    255.434, 140.58999999999997`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    261.52, 157.79299999999998`}, {255.92600000000002`, 
                    157.79299999999998`}, {254.816, 159.641}, {
                    262.52299999999997`, 159.641}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    261.52, 157.793}, {255.92600000000002`, 157.793}, {
                    254.816, 159.641}, {262.52299999999997`, 159.641}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    253.977, 164.602}, {253.92200000000003`, 
                    169.45700000000002`}, {250.07, 169.45700000000002`}, {
                    251.58200000000002`, 168.207}, {252.99200000000002`, 
                    166.695}, {253.977, 164.602}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    253.977, 164.60199999999998`}, {253.92200000000003`, 
                    169.45700000000002`}, {250.07, 169.45700000000002`}, {
                    251.58200000000002`, 168.20700000000002`}, {
                    252.99200000000002`, 166.695}, {253.977, 
                    164.60199999999998`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4gf+vdPzggocijImvq0JTnHQbhe7eS6wwIHr
+uICW6MUh9hdnjxM9gUOi1y3ff7rgOB/04jpPxSIJt+S4rB09hGFDXYFDn3T
84Sa96Q4uD+sElkHlL/9sy5rz4MUBy2Q+UB+GJ/uprm/oXz5Aod986X0735J
cWAAAYUCh1UfL/kmPUlxkIlKsb4PlG97HbhDbmeKg1DzgVML5aH216Y46N9V
YWsE8uNA7vBOcbDccqJsH5D/tsbeNA7o/k7HhKcXuAocekHuMUlxaAWZw41Q
D/K2PZAfCnJPM4J/89z34MdXEeqLQRL/Uxxyn/9e+RFoHljcNBViPzC8wO42
SXX4BHS2QBDUvwwI/lags+ZfS3GAhbcqW+NU524EHxb+ACCvraM=
                    "],
                    CurveClosed->{1}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    256.59, 152.016}, {261.145, 152.016}, {261.145, 146.34}, {
                    256.59, 146.34}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    256.625, 149.664}, {258.23, 149.664}, {258.23, 148.73}, {
                    256.625, 148.73}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    256.625, 149.664}, {258.23, 149.664}, {258.23, 148.73}, {
                    256.625, 148.73}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    259.465, 149.664}, {261.03099999999995`, 149.664}, {
                    261.03099999999995`, 148.73}, {259.465, 148.73}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    259.465, 149.664}, {261.03099999999995`, 149.664}, {
                    261.03099999999995`, 148.73}, {259.465, 148.73}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    258.22999999999996`, 151.945}, {259.46399999999994`, 
                    151.945}, {259.46399999999994`, 149.629}, {
                    258.22999999999996`, 149.629}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    258.22999999999996`, 151.945}, {259.46399999999994`, 
                    151.945}, {259.46399999999994`, 149.629}, {
                    258.22999999999996`, 149.629}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    258.22999999999996`, 148.76999999999998`}, {
                    259.46399999999994`, 148.76999999999998`}, {
                    259.46399999999994`, 146.30499999999998`}, {
                    258.22999999999996`, 146.30499999999998`}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    258.22999999999996`, 148.77}, {259.46399999999994`, 
                    148.77}, {259.46399999999994`, 146.305}, {
                    258.22999999999996`, 146.305}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{284.809, 
                    208.824}, {284.52299999999997`, 204.371}, {
                    285.90599999999995`, 201.92600000000002`}, {
                    288.26599999999996`, 202.297}, {288.914, 
                    204.76999999999998`}, {287.43399999999997`, 
                    206.42600000000002`}, {284.809, 208.824}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{284.809, 
                    208.824}, {284.52299999999997`, 204.371}, {
                    285.90599999999995`, 201.926}, {288.26599999999996`, 
                    202.297}, {288.914, 204.76999999999998`}, {
                    287.43399999999997`, 206.426}, {284.809, 208.824}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{289.984, 
                    198.953}, {292.082, 200.02}, {290.566, 208.164}, {289.762,
                     211.57399999999998`}, {289.168, 207.18}, {288.172, 
                    200.93}, {289.984, 198.953}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{289.984, 
                    198.95299999999997`}, {292.082, 200.01999999999998`}, {
                    290.566, 208.164}, {289.762, 211.574}, {289.168, 
                    207.18}, {288.172, 200.93}, {289.984, 
                    198.95299999999997`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    289.23799999999994`, 198.566}, {285.715, 197.344}, {
                    282.92599999999993`, 201.137}, {281.97999999999996`, 
                    205.535}, {284.89099999999996`, 201.52}, {289.625, 
                    201.516}, {289.23799999999994`, 198.566}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    289.23799999999994`, 198.56599999999997`}, {285.715, 
                    197.344}, {282.92599999999993`, 201.137}, {
                    281.97999999999996`, 205.535}, {284.89099999999996`, 
                    201.51999999999998`}, {289.625, 201.516}, {
                    289.23799999999994`, 198.56599999999997`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    291.90999999999997`, 194.45700000000002`}, {294.668, 
                    195.184}, {293.008, 203.824}, {292.508, 207.281}, {
                    291.902, 203.71099999999998`}, {290., 195.637}, {
                    291.90999999999997`, 194.45700000000002`}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    291.90999999999997`, 194.457}, {294.668, 195.184}, {
                    293.008, 203.824}, {292.508, 207.281}, {291.902, 
                    203.711}, {290., 195.637}, {291.90999999999997`, 
                    194.457}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{290.969, 
                    194.727}, {290.812, 197.707}, {287.84400000000005`, 
                    196.848}, {285.79299999999995`, 198.43800000000002`}, {
                    286.129, 196.94899999999998`}, {287.39099999999996`, 
                    194.309}, {290.969, 194.727}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{290.969, 
                    194.727}, {290.812, 197.707}, {287.84400000000005`, 
                    196.848}, {285.79299999999995`, 198.438}, {286.129, 
                    196.949}, {287.39099999999996`, 194.309}, {290.969, 
                    194.727}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    294.34400000000005`, 190.73399999999998`}, {297.074, 
                    191.47299999999998`}, {295.43399999999997`, 
                    200.76999999999998`}, {295.59, 204.598}, {294.789, 
                    201.29299999999998`}, {292.25, 191.63299999999998`}, {
                    294.34400000000005`, 190.73399999999998`}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    294.34400000000005`, 190.734}, {297.074, 
                    191.47299999999998`}, {295.43399999999997`, 
                    200.76999999999998`}, {295.59, 204.598}, {294.789, 
                    201.293}, {292.25, 191.63299999999998`}, {
                    294.34400000000005`, 190.734}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{293.07, 
                    191.137}, {290.83599999999996`, 190.41}, {287.871, 
                    191.863}, {287.637, 194.52700000000002`}, {289.566, 
                    193.21899999999997`}, {292.641, 194.21899999999997`}, {
                    293.07, 191.137}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{293.07, 
                    191.137}, {290.83599999999996`, 190.41}, {287.871, 
                    191.863}, {287.637, 194.527}, {289.566, 193.219}, {
                    292.641, 194.219}, {293.07, 191.137}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{296.383, 
                    186.63299999999998`}, {298.9959999999999, 
                    186.42200000000003`}, {297.828, 194.344}, {297.824, 
                    201.71899999999997`}, {296.867, 194.824}, {294.25, 
                    188.512}, {296.383, 186.63299999999998`}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{296.383, 
                    186.63299999999998`}, {298.9959999999999, 186.422}, {
                    297.828, 194.344}, {297.824, 201.719}, {296.867, 
                    194.824}, {294.25, 188.51199999999997`}, {296.383, 
                    186.63299999999998`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    295.47999999999996`, 186.99200000000002`}, {293.715, 
                    186.105}, {290.555, 187.52}, {289.65200000000004`, 
                    190.5}, {292.84000000000003`, 189.117}, {
                    294.97299999999996`, 190.469}, {295.47999999999996`, 
                    186.99200000000002`}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    295.47999999999996`, 186.992}, {293.715, 186.105}, {
                    290.555, 187.51999999999998`}, {289.65200000000004`, 
                    190.5}, {292.84000000000003`, 189.117}, {
                    294.97299999999996`, 190.469}, {295.47999999999996`, 
                    186.992}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{274.977, 
                    204.695}, {275.441, 200.83200000000002`}, {277.02, 
                    198.586}, {279.379, 198.95700000000002`}, {280.027, 
                    201.42600000000002`}, {278.117, 203.008}, {274.977, 
                    204.695}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{274.977, 
                    204.695}, {275.441, 200.832}, {277.02, 
                    198.58599999999998`}, {279.379, 198.957}, {280.027, 
                    201.426}, {278.117, 203.00799999999998`}, {274.977, 
                    204.695}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{281.215, 
                    194.785}, {277.29699999999997`, 194.227}, {275.887, 
                    197.23399999999998`}, {273.25, 201.08200000000002`}, {
                    276.945, 198.406}, {281.363, 197.848}, {281.215, 
                    194.785}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{281.215, 
                    194.785}, {277.29699999999997`, 194.227}, {275.887, 
                    197.23399999999998`}, {273.25, 201.082}, {276.945, 
                    198.406}, {281.363, 197.848}, {281.215, 194.785}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{282.328, 
                    195.22299999999998`}, {284.465, 197.789}, {
                    282.39799999999997`, 201.008}, {280.76599999999996`, 
                    203.75}, {281.117, 199.668}, {279.727, 
                    197.39800000000002`}, {282.328, 
                    195.22299999999998`}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{282.328, 
                    195.223}, {284.465, 197.789}, {282.39799999999997`, 
                    201.00799999999998`}, {280.76599999999996`, 203.75}, {
                    281.117, 199.668}, {279.727, 197.39800000000002`}, {
                    282.328, 195.223}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    283.27299999999997`, 190.99200000000002`}, {283.512, 
                    193.5}, {279.242, 194.055}, {277.309, 
                    195.44899999999998`}, {277.96099999999996`, 194.}, {
                    278.945, 190.102}, {283.27299999999997`, 
                    190.99200000000002`}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    283.27299999999997`, 190.992}, {283.512, 193.5}, {279.242,
                     194.055}, {277.309, 195.449}, {277.96099999999996`, 
                    194.}, {278.945, 190.10199999999998`}, {
                    283.27299999999997`, 190.992}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{284.168, 
                    190.93800000000002`}, {287.121, 191.26999999999998`}, {
                    285.895, 196.285}, {283.777, 199.07}, {284.668, 
                    195.227}, {282.219, 192.55100000000002`}, {284.168, 
                    190.93800000000002`}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{284.168, 
                    190.938}, {287.121, 191.27}, {285.895, 196.285}, {283.777,
                     199.07}, {284.668, 195.227}, {282.219, 192.551}, {
                    284.168, 190.938}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    286.39099999999996`, 186.762}, {289.754, 
                    188.24599999999998`}, {287.59799999999996`, 192.461}, {
                    286.33599999999996`, 194.94899999999998`}, {286.875, 
                    191.684}, {284.18, 189.191}, {286.39099999999996`, 
                    186.762}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    286.39099999999996`, 186.762}, {289.754, 188.246}, {
                    287.59799999999996`, 192.461}, {286.33599999999996`, 
                    194.949}, {286.875, 191.684}, {284.18, 189.191}, {
                    286.39099999999996`, 186.762}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{285.727, 
                    187.15200000000002`}, {283.965, 184.848}, {280.527, 
                    187.84}, {279.82, 191.33200000000002`}, {282.812, 
                    188.84}, {285.02299999999997`, 189.25}, {285.727, 
                    187.15200000000002`}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{285.727, 
                    187.152}, {283.965, 184.84799999999998`}, {280.527, 
                    187.84}, {279.82, 191.332}, {282.812, 188.84}, {
                    285.02299999999997`, 189.25}, {285.727, 187.152}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4gtKt3/WhRU5cF1fXGAbl+rw6ZJvkkBMkQMD
CJxJdZiRJ9R8wKjIoShj4tuayWkQ+YAih70lkyVY/kH5IUUOhbZAE3jSHaJS
rO/7uxc59B/6qhFjnO4AVBXGZ1/kIAuSkE53uFrxUs3QCGrftzSH3Oe/V35U
KXJwSnh6Qak7zcHbvNMxQb4IYu+mNAf9uypsjZJFDt80YvoP3U1z2HKibN98
CShfM91BcQPQZaxFDr3TgRos0h1Azij4WejQ+jpwh5xjusMxkIEvCh2qRNa5
P3RLh9j3phDiXoV0B+HmA6cWfiyEuO93GsTff6D6T6Y5gMPnQyHEvqNpDlYg
B7yEqj8Mlb9W6CAD4n9Pg9h3DCrPnw4xZ2ehgw/IX6pQ+5YWOliCzGFOh/hz
R6FDKJ/uprmP0xxid3nyMH0vdFj9ERiwNWkOoGC3Ny5yuHnue/Bj3zQHULD2
I8UXAIuTyOo=
                    "]]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4gtKt3/WhRU5cF1fXGAbl+rw6ZJvkkBMkQMD
CJxJdZiRJ9R8wKjIoShj4tuayWkQ+YAihz0lkyVY/kH5IUUOhbZAE3jSHaJS
rO/7uxc59B/6qhFjnO4AVBXGZ1/kIAuSkE53uFrxUs3QCGrftzSH3Oe/V35U
KXJwTHh6Qak7zcHbvNMxQb4IYu+mNAf9uypsjZJFDt80YvoP3U1z2HKibN98
CShfM91BcQPQZaxFDn3TgRos0h1Azij4WejQ+jpwh5xjusMxkIEvCh2qRda5
P3RLh9j3ptChAKRQId1BuPnAqYUfCyHu+50G8fefQoc2kP6TaQ7g8PlQ6PAV
ZN/RNAcrkANeQtUfhspfg/K/p0HsOwbl86dD3LGzEOIvVah9SwsdLEHmMKdD
/Lmj0CGUT3fT3MdpDrG7PHmYvhc6rP4IDNiaNAdQsNsbFzncPPc9+LFvmgMo
WPuR4gsAigvI6Q==
                    "],
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4mPe5p2Ox4ocRNa5P6y6EuuguKEoY+LZIgeX
7pznv2/GOiiA+NeLHNrFbp77/jjW4YLS7Z9154ocPHmYtNu3xTpogyRaixx6
p+cJNQfEOMwAUgcKihy+acT0H3ob7QASPsBW5MAAAgoxDkBbRNbNLoSoj4hx
uFrxUs2wqdDBL0kgwvJMjEP5vvlS+uaFEPeUxEL4/IUOF0H2Xop12HKibN/8
KwUOxRkT39Y8j3UAu39FgUMmkGu/FureyQUOXNcXF9hOinWYLMESxtdeALFv
QqyDbFSK9f2pBQ6b5r5ffux0rMPS2UcUNiwpcHgK8hhbHMQ92wocLEEWhcc5
3PcH6jxR4LBGBqixP85hh1zr68APBQ419qZxuzjjHT5d8k0SMCl0eAbSbxfv
ADLeP7sQ4j7xeAdbkEN2FkLC61kcJBx+QeXl4xyApu2Qcy+C+B8Y/uDwyS+C
2Lc+1uExyIFzihyAvs/aswXqX6T4AgDJDcnj
                    "]]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4mPe5p2Ox4ocRNa5P6y6EuuguKEoY+LZIgeX
7pznv2/GOiiA+NeLHNrEbp77/jjW4YLS7Z9154ocvHiYtNu3xTpotwMlWosc
+qbnCTUHxDjMAFIHCoocvmnE9B96G+0AEj7AVuTAAAIKMQ5AW0TWzS6EqI+I
cbha8VLNsKnQwS9JIMLyTIxD+b75UvrmhRD3lMRC+PyFDpdA9l6Kddhyomzf
/CsFDkBXva15HusAdv+KAocsINd+LdS9kwsceK4vLrCdFOswWYIljK+9AGLf
hFgH2agU6/tTCxw2zX2//NjpWIels48obFhS4PAE5DG2OIh7thU4WIEsCo9z
uO/fOz3vRIHDGhmgxv44hx1yra8DPxQ41Nibxu3ijHf4dMk3ScCk0OEZSL9d
vAPIeP/sQocSkPvE4x1suYAO2Vno4AEKr2dxkHD4VQhxv3ycA9C0HXLuRRD/
A8MfHD75RRD71sc6PAY5cE6Rw52fdVl7tkD9ixRfAM89yek=
                    "],
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    262.16, 109.32}, {261.316, 109.215}, {260.78099999999995`,
                     107.57799999999999`}, {260.363, 108.68799999999999`}, {
                    259.66, 110.48}, {260.15200000000004`, 111.906}, {260.945,
                     111.75}, {261.883, 111.5}, {263.465, 109.402}, {262.16, 
                    109.32}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    262.16, 109.32}, {261.316, 109.215}, {260.78099999999995`,
                     107.57799999999997`}, {260.363, 108.68799999999999`}, {
                    259.66, 110.47999999999999`}, {260.15200000000004`, 
                    111.906}, {260.945, 111.75}, {261.883, 111.5}, {263.465, 
                    109.40199999999999`}, {262.16, 109.32}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4h1yra8DfxQ5ZEx8W2O/NdVBJirF+j57scM3
jZj+Q1dTHbzNOx0TmIsd1A051sg8SnUAqjKNe1PksPVE2b75QP7jpbOPKNwq
cljkuu3z3yepDgwgsK3I4ThI45lUh2MgegWU/yDVwf1hlci62UUOF5Vu/6z7
lOqwDKh9w4IiiD6HNAega3bIAeUttwAtSE6DyM8ocgjj0900tzzNwQOkf2KR
A5B0fzgtzeHTJd8kgaYiiPvS0iDmBxc56N9VYWu8mOpgBTJHssjBMeHpBSX5
VIg7GYocVn0EaixIgaj7XAjxF18KxL0MUP2lyZBw0YX6ly/ZQaj5wKmF2kUO
XNcXF9imJTuAnPXeGhp+C5Mh4edf5HAJ5L9XyQ73/Xun52UUOczIA+r0SnHQ
ahe7ee5wkUM4SKN/qgN6+AMAUBKzZA==
                    "]], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{291.574, 
                    149.24599999999998`}, {288.39099999999996`, 
                    149.23399999999998`}, {287.84400000000005`, 153.504}, {
                    287.84400000000005`, 154.69899999999998`}, {
                    289.40999999999997`, 154.39800000000002`}, {292.172, 
                    151.785}, {291.574, 149.24599999999998`}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{291.574, 
                    149.246}, {288.39099999999996`, 149.234}, {
                    287.84400000000005`, 153.504}, {287.84400000000005`, 
                    154.69899999999998`}, {289.40999999999997`, 154.398}, {
                    292.172, 151.78500000000003`}, {291.574, 149.246}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{264.039, 
                    107.793}, {261.77299999999997`, 107.277}, {261.805, 
                    112.73400000000001`}, {264.121, 115.04700000000001`}, {
                    263.10200000000003`, 111.543}, {265.824, 108.336}, {
                    264.039, 107.793}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{264.039, 
                    107.793}, {261.77299999999997`, 107.27700000000002`}, {
                    261.805, 112.73400000000001`}, {264.121, 115.047}, {
                    263.10200000000003`, 111.54299999999998`}, {265.824, 
                    108.33600000000001`}, {264.039, 107.793}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    264.92199999999997`, 107.84}, {264.77, 
                    105.24600000000001`}, {271.28499999999997`, 
                    108.17999999999999`}, {272.96099999999996`, 110.195}, {
                    269.113, 108.562}, {265.10900000000004`, 
                    109.91400000000002`}, {264.92199999999997`, 
                    107.84}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    264.92199999999997`, 107.84}, {264.77, 
                    105.24600000000001`}, {271.28499999999997`, 
                    108.17999999999998`}, {272.96099999999996`, 110.195}, {
                    269.113, 108.56199999999998`}, {265.10900000000004`, 
                    109.91399999999999`}, {264.92199999999997`, 107.84}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{267.777, 
                    111.543}, {267.543, 109.031}, {273.42599999999993`, 
                    111.242}, {275.168, 113.203}, {271.301, 111.953}, {
                    268.03099999999995`, 113.613}, {267.777, 
                    111.543}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{267.777, 
                    111.54299999999998`}, {267.543, 109.031}, {
                    273.42599999999993`, 111.24199999999999`}, {275.168, 
                    113.203}, {271.301, 111.953}, {268.03099999999995`, 
                    113.61299999999997`}, {267.777, 111.54299999999998`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{266.695, 
                    111.191}, {264.42999999999995`, 110.67599999999999`}, {
                    264.79699999999997`, 116.32}, {267., 118.262}, {265.941, 
                    114.49600000000001`}, {268.477, 111.738}, {266.695, 
                    111.191}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{266.695, 
                    111.191}, {264.42999999999995`, 110.67599999999999`}, {
                    264.79699999999997`, 116.32}, {267., 118.262}, {265.941, 
                    114.49600000000001`}, {268.477, 111.738}, {266.695, 
                    111.191}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{269.078, 
                    114.62499999999999`}, {266.812, 114.109}, {268.113, 
                    118.96900000000001`}, {269.79299999999995`, 
                    120.91000000000001`}, {269.52, 117.367}, {270.637, 
                    114.91000000000001`}, {269.078, 
                    114.62499999999999`}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{269.078, 
                    114.625}, {266.812, 114.10899999999998`}, {268.113, 
                    118.969}, {269.79299999999995`, 120.91}, {269.52, 
                    117.36700000000002`}, {270.637, 114.91}, {269.078, 
                    114.625}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    270.28099999999995`, 114.641}, {270.047, 112.051}, {
                    274.625, 114.039}, {276.402, 116.488}, {272.574, 
                    115.238}, {270.53499999999997`, 116.70700000000001`}, {
                    270.28099999999995`, 114.641}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    270.28099999999995`, 114.64099999999999`}, {270.047, 
                    112.05100000000002`}, {274.625, 114.03899999999999`}, {
                    276.402, 116.488}, {272.574, 115.238}, {
                    270.53499999999997`, 116.70700000000002`}, {
                    270.28099999999995`, 114.64099999999999`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{271.527, 
                    116.609}, {270.043, 117.67599999999999`}, {271.617, 
                    120.5}, {274.445, 120.324}, {274.168, 118.617}, {273.191, 
                    115.621}, {271.527, 116.609}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{271.527, 
                    116.60899999999998`}, {270.043, 117.67599999999999`}, {
                    271.617, 120.5}, {274.445, 120.32400000000001`}, {274.168,
                     118.61699999999999`}, {273.191, 115.62100000000001`}, {
                    271.527, 116.60899999999998`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{260.367, 
                    104.902}, {260.219, 102.309}, {266.734, 
                    103.60199999999999`}, {268.78099999999995`, 106.363}, {
                    264.672, 105.586}, {260.559, 106.98}, {260.367, 
                    104.902}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{260.367, 
                    104.90199999999999`}, {260.219, 102.309}, {266.734, 
                    103.60199999999998`}, {268.78099999999995`, 106.363}, {
                    264.672, 105.58600000000001`}, {260.559, 
                    106.97999999999999`}, {260.367, 104.90199999999999`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{286.258, 
                    109.543}, {286.02299999999997`, 106.95700000000001`}, {
                    293.137, 109.801}, {294.914, 112.25}, {291.09, 111.}, {
                    286.512, 111.613}, {286.258, 109.543}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{286.258, 
                    109.54299999999998`}, {286.02299999999997`, 
                    106.95700000000002`}, {293.137, 109.80100000000002`}, {
                    294.914, 112.25}, {291.09, 111.}, {286.512, 
                    111.61299999999997`}, {286.258, 109.54299999999998`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{281.895, 
                    108.44100000000002`}, {280.40999999999997`, 109.508}, {
                    283.441, 112.258}, {285.855, 112.902}, {285.582, 
                    111.199}, {283.559, 107.453}, {281.895, 
                    108.44100000000002`}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{281.895, 
                    108.441}, {280.40999999999997`, 109.50799999999998`}, {
                    283.441, 112.25800000000001`}, {285.855, 
                    112.90199999999999`}, {285.582, 111.19899999999998`}, {
                    283.559, 107.453}, {281.895, 108.441}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{281.441, 
                    106.648}, {281.28099999999995`, 104.32}, {289.07, 
                    105.598}, {291.105, 107.74600000000001`}, {
                    284.40599999999995`, 106.535}, {281.66, 108.641}, {
                    281.441, 106.648}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{281.441, 
                    106.64799999999997`}, {281.28099999999995`, 104.32}, {
                    289.07, 105.59799999999998`}, {291.105, 
                    107.74600000000001`}, {284.40599999999995`, 106.535}, {
                    281.66, 108.64099999999999`}, {281.441, 
                    106.64799999999997`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    277.79299999999995`, 105.098}, {276.92599999999993`, 
                    102.93400000000001`}, {284.402, 103.46100000000001`}, {
                    287.027, 104.71900000000001`}, {282.78499999999997`, 
                    104.754}, {278.387, 106.60199999999999`}, {
                    277.79299999999995`, 105.098}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    277.79299999999995`, 105.09799999999998`}, {
                    276.92599999999993`, 102.934}, {284.402, 
                    103.46100000000001`}, {287.027, 104.719}, {
                    282.78499999999997`, 104.75400000000002`}, {278.387, 
                    106.60199999999998`}, {277.79299999999995`, 
                    105.09799999999998`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    274.29699999999997`, 103.52}, {273.469, 101.582}, {
                    280.383, 101.62499999999999`}, {283.754, 102.695}, {
                    279.289, 102.73}, {275.113, 105.438}, {
                    274.29699999999997`, 103.52}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    274.29699999999997`, 103.51999999999998`}, {273.469, 
                    101.582}, {280.383, 101.625}, {283.754, 102.695}, {
                    279.289, 102.73000000000002`}, {275.113, 
                    105.43799999999999`}, {274.29699999999997`, 
                    103.51999999999998`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    269.26599999999996`, 102.48}, {268.039, 
                    100.18799999999999`}, {275.33599999999996`, 99.965}, {
                    277.703, 101.09400000000001`}, {273.484, 
                    101.67199999999998`}, {270.309, 104.285}, {
                    269.26599999999996`, 102.48}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    269.26599999999996`, 102.47999999999999`}, {268.039, 
                    100.18799999999999`}, {275.33599999999996`, 99.965}, {
                    277.703, 101.094}, {273.484, 101.67199999999997`}, {
                    270.309, 104.28500000000003`}, {269.26599999999996`, 
                    102.47999999999999`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{277.809, 
                    106.398}, {280.129, 104.938}, {280.004, 109.25}, {
                    281.85200000000003`, 112.238}, {278.949, 109.598}, {
                    276.234, 107.79700000000001`}, {277.809, 
                    106.398}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{277.809, 
                    106.398}, {280.129, 104.93799999999999`}, {280.004, 
                    109.25}, {281.85200000000003`, 112.238}, {278.949, 
                    109.59799999999998`}, {276.234, 107.79700000000003`}, {
                    277.809, 106.398}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{273.695, 
                    104.848}, {275.64500000000004`, 103.12499999999999`}, {
                    277.199, 109.043}, {278.97299999999996`, 112.367}, {
                    276.105, 109.203}, {271.89799999999997`, 106.281}, {
                    273.695, 104.848}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{273.695, 
                    104.84799999999998`}, {275.64500000000004`, 103.125}, {
                    277.199, 109.04299999999998`}, {278.97299999999996`, 
                    112.36700000000002`}, {276.105, 109.203}, {
                    271.89799999999997`, 106.28100000000003`}, {273.695, 
                    104.84799999999998`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{268.258, 
                    103.199}, {269.90599999999995`, 101.289}, {274.672, 
                    108.816}, {276.40599999999995`, 112.73400000000001`}, {
                    273.76599999999996`, 109.684}, {266.945, 104.82}, {
                    268.258, 103.199}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{268.258, 
                    103.19899999999998`}, {269.90599999999995`, 
                    101.28900000000002`}, {274.672, 108.816}, {
                    276.40599999999995`, 112.73400000000001`}, {
                    273.76599999999996`, 109.684}, {266.945, 104.82}, {
                    268.258, 103.19899999999998`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{272.895, 
                    97.45700000000001}, {273.719, 94.551}, {285.848, 
                    100.195}, {287.203, 103.117}, {280.262, 
                    99.44100000000002}, {272.72999999999996`, 
                    100.21100000000001`}, {272.895, 
                    97.45700000000001}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{272.895, 
                    97.45700000000002}, {273.719, 94.55100000000002}, {
                    285.848, 100.195}, {287.203, 103.11699999999999`}, {
                    280.262, 99.441}, {272.72999999999996`, 
                    100.21100000000001`}, {272.895, 97.45700000000002}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4k+XfJME6oodZKNSrO/3JztsPVG2b35TsUMY
n+6mubOTHdwfVoms6y92CAfxgfL3/Xun5/UUOzglPL2gVJzs4G3e6ZjQWexw
52dd1h6fZIfJEixhfLlQ/e1JDm9r7E3jbIodLLcADXZOcvAAmSdZ7PBNI6b/
kGCSQ8ZEoIrkIofW14E75A4mOlxQuv2zTqDIoVpknfvDeYkOcbs8eZgeFzoU
2nJdX9yTCBHfU+jgCLI/PtEhFiQ/v9Bhep5Q8wGxRIh7Vhc66N9VYWssTXQA
ect/ayHEPbsTIfYdLXQQbj5waiHQfrC+K4UOi1y3ff4bk+Sg3S5289zfQoh/
10Pdr1HkwAACW5IcQM4oKC+CuH9nkoMVyF93ixxU2RqnOh9PcgCHpwbUv+zQ
8PKD8tWh4ZVaDPFXcLIDevgDAJdbrTE=
                    "]]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4k+XfJME6oodZKNSrO/3JztsPVG2b35TsUMY
n+6mubOTHdwfVoms64fygfL3/Xun5/UUOzgmPL2gVJzs4G3e6ZjQWexw+2dd
1h6fZIfJEixhfLlQ9e1JDm9r7E3jbIodLLcADXZOcvAAmSdZ7PBNI6b/kGCS
Q8ZEoIrkIofW14E75A4mOlxQApokUORQLbLO/eG8RIe4XZ48TI8LHQptua4v
7kmEiO8phNgfn+gQC5KfX+gwI0+o+YBYIsQ9qwsd9O6qsDWWJjqAvOW/tRDi
nt2JEPuOFjoINx84tRBo/3SQviuFDotct33+G5PkoN0udvPcX6j69VD3axQ5
MIDAliQHkDMKyosg7t+Z5GAF8tfdIgc1tsapzseTHMDhqQH1Lzs0vPygfHVo
eKUWQ/wVnOyAHv4AkzOtLg==
                    "],
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{283.566, 
                    132.105}, {282.012, 130.95700000000002`}, {
                    280.29299999999995`, 135.066}, {282.27, 
                    138.97299999999998`}, {282.332, 135.21499999999997`}, {
                    285.32, 133.94899999999998`}, {283.566, 
                    132.105}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{283.566, 
                    132.105}, {282.012, 130.95700000000002`}, {
                    280.29299999999995`, 135.066}, {282.27, 
                    138.97299999999998`}, {282.332, 135.215}, {285.32, 
                    133.94899999999998`}, {283.566, 132.105}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{282.07, 
                    128.336}, {279.91799999999995`, 127.67599999999999`}, {
                    279.242, 131.484}, {280.66, 134.535}, {
                    280.42599999999993`, 131.258}, {284.047, 129.285}, {
                    282.07, 128.336}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{282.07, 
                    128.336}, {279.91799999999995`, 127.67599999999999`}, {
                    279.242, 131.484}, {280.66, 134.535}, {
                    280.42599999999993`, 131.258}, {284.047, 
                    129.28500000000003`}, {282.07, 128.336}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    280.43399999999997`, 125.312}, {278.35200000000003`, 
                    124.277}, {277.562, 128.125}, {279.059, 130.984}, {
                    278.895, 127.34}, {282.03499999999997`, 126.262}, {
                    280.43399999999997`, 125.312}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    280.43399999999997`, 125.31199999999998`}, {
                    278.35200000000003`, 124.27700000000002`}, {277.562, 
                    128.125}, {279.059, 130.984}, {278.895, 127.34}, {
                    282.03499999999997`, 126.262}, {280.43399999999997`, 
                    125.31199999999998`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{281.289, 
                    125.07799999999999`}, {282.113, 122.617}, {286.895, 
                    127.203}, {287.699, 129.69899999999998`}, {
                    284.72999999999996`, 126.75}, {280.695, 
                    127.07799999999999`}, {281.289, 
                    125.07799999999999`}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{281.289, 
                    125.07799999999997`}, {282.113, 122.61699999999999`}, {
                    286.895, 127.203}, {287.699, 129.69899999999998`}, {
                    284.72999999999996`, 126.75}, {280.695, 
                    127.07799999999997`}, {281.289, 125.07799999999997`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{283.457, 
                    128.848}, {284.395, 126.383}, {290.40599999999995`, 
                    132.727}, {291.734, 135.781}, {288.76599999999996`, 
                    132.836}, {282.789, 130.586}, {283.457, 
                    128.848}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{283.457, 
                    128.84799999999998`}, {284.395, 126.38300000000001`}, {
                    290.40599999999995`, 132.72700000000003`}, {291.734, 
                    135.78100000000003`}, {288.76599999999996`, 132.836}, {
                    282.789, 130.586}, {283.457, 128.84799999999998`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{284.648, 
                    132.54299999999998`}, {285.58599999999996`, 129.742}, {
                    292.121, 137.207}, {293.97299999999996`, 
                    139.85200000000003`}, {290.855, 136.941}, {283.941, 
                    134.578}, {284.648, 132.54299999999998`}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{284.648, 
                    132.54299999999998`}, {285.58599999999996`, 129.742}, {
                    292.121, 137.20700000000002`}, {293.97299999999996`, 
                    139.852}, {290.855, 136.941}, {283.941, 
                    134.57799999999997`}, {284.648, 132.54299999999998`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{284.855, 
                    135.312}, {282.555, 135.758}, {284.98799999999994`, 
                    137.676}, {287.809, 140.79299999999998`}, {
                    287.93799999999993`, 137.512}, {287.402, 
                    135.21899999999997`}, {284.855, 135.312}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{284.855, 
                    135.31199999999998`}, {282.555, 135.758}, {
                    284.98799999999994`, 137.676}, {287.809, 140.793}, {
                    287.93799999999993`, 137.51199999999997`}, {287.402, 
                    135.219}, {284.855, 135.31199999999998`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{288.734, 
                    137.176}, {287.742, 138.258}, {289.688, 
                    138.71899999999997`}, {292.09799999999996`, 
                    141.42200000000003`}, {292.453, 139.602}, {289.863, 
                    136.262}, {288.734, 137.176}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{288.734, 
                    137.176}, {287.742, 138.258}, {289.688, 138.719}, {
                    292.09799999999996`, 141.422}, {292.453, 
                    139.60199999999998`}, {289.863, 136.262}, {288.734, 
                    137.176}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    277.60200000000003`, 125.016}, {276.34000000000003`, 
                    124.277}, {275.47999999999996`, 126.859}, {277.047, 
                    129.195}, {277.40599999999995`, 126.66799999999999`}, {
                    278.754, 125.965}, {277.60200000000003`, 
                    125.016}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    277.60200000000003`, 125.01599999999999`}, {
                    276.34000000000003`, 124.27700000000002`}, {
                    275.47999999999996`, 126.85900000000001`}, {277.047, 
                    129.195}, {277.40599999999995`, 126.66799999999998`}, {
                    278.754, 125.965}, {277.60200000000003`, 
                    125.01599999999999`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{304.953, 
                    141.297}, {307.625, 139.691}, {311.875, 146.09}, {313.008,
                     148.72299999999998`}, {310.66, 145.69899999999998`}, {
                    304.445, 142.941}, {304.953, 141.297}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{304.953, 
                    141.29700000000003`}, {307.625, 139.691}, {311.875, 
                    146.09}, {313.008, 148.723}, {310.66, 
                    145.69899999999998`}, {304.445, 142.941}, {304.953, 
                    141.29700000000003`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{302.68, 
                    137.566}, {304.16, 135.92600000000002`}, {308.816, 
                    140.383}, {310.43399999999997`, 142.641}, {
                    307.93799999999993`, 140.48000000000002`}, {302.027, 
                    140.22299999999998`}, {302.68, 137.566}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{302.68, 
                    137.566}, {304.16, 135.92600000000002`}, {308.816, 
                    140.383}, {310.43399999999997`, 142.641}, {
                    307.93799999999993`, 140.48}, {302.027, 140.223}, {302.68,
                     137.566}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    300.14500000000004`, 134.22299999999998`}, {300.633, 
                    131.984}, {307.42999999999995`, 137.02}, {309.02, 
                    139.406}, {306.08599999999996`, 136.64499999999998`}, {
                    299.699, 136.895}, {300.14500000000004`, 
                    134.22299999999998`}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    300.14500000000004`, 134.223}, {300.633, 131.984}, {
                    307.42999999999995`, 137.01999999999998`}, {309.02, 
                    139.406}, {306.08599999999996`, 136.64499999999998`}, {
                    299.699, 136.895}, {300.14500000000004`, 134.223}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{301.184, 
                    131.80100000000002`}, {302.234, 129.781}, {307.762, 
                    134.781}, {309.08599999999996`, 137.39100000000002`}, {
                    305.71099999999996`, 134.441}, {300.328, 133.797}, {
                    301.184, 131.80100000000002`}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{301.184, 
                    131.80100000000002`}, {302.234, 129.78100000000003`}, {
                    307.762, 134.78100000000003`}, {309.08599999999996`, 
                    137.39100000000002`}, {305.71099999999996`, 134.441}, {
                    300.328, 133.79700000000003`}, {301.184, 
                    131.80100000000002`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    304.02299999999997`, 141.625}, {302.28099999999995`, 
                    143.465}, {303.02299999999997`, 144.324}, {
                    304.29299999999995`, 147.22299999999998`}, {
                    304.98799999999994`, 144.24599999999998`}, {306.039, 
                    143.059}, {304.02299999999997`, 141.625}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    304.02299999999997`, 141.625}, {302.28099999999995`, 
                    143.465}, {303.02299999999997`, 144.324}, {
                    304.29299999999995`, 147.223}, {304.98799999999994`, 
                    144.246}, {306.039, 143.059}, {304.02299999999997`, 
                    141.625}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    301.71099999999996`, 138.15200000000002`}, {298.547, 
                    138.012}, {301.68, 141.863}, {302.42999999999995`, 
                    145.094}, {302.156, 141.41}, {303.242, 138.504}, {
                    301.71099999999996`, 138.15200000000002`}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    301.71099999999996`, 138.152}, {298.547, 
                    138.01199999999997`}, {301.68, 141.863}, {
                    302.42999999999995`, 145.094}, {302.156, 141.41}, {
                    303.242, 138.504}, {301.71099999999996`, 138.152}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{299.695, 
                    135.098}, {297.504, 135.59}, {298.137, 138.695}, {299.816,
                     142.44899999999998`}, {299.469, 138.39100000000002`}, {
                    301.672, 136.047}, {299.695, 135.098}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{299.695, 
                    135.09799999999998`}, {297.504, 135.59}, {298.137, 
                    138.695}, {299.816, 142.44899999999998`}, {299.469, 
                    138.39100000000002`}, {301.672, 136.047}, {299.695, 
                    135.09799999999998`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{300.441, 
                    128.961}, {301.26599999999996`, 126.49600000000001`}, {
                    307.5, 132.20299999999997`}, {308.49199999999996`, 
                    134.363}, {305.34000000000003`, 131.71499999999997`}, {
                    299.883, 130.809}, {300.441, 128.961}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{300.441, 
                    128.961}, {301.26599999999996`, 126.49600000000001`}, {
                    307.5, 132.203}, {308.49199999999996`, 134.363}, {
                    305.34000000000003`, 131.715}, {299.883, 130.809}, {
                    300.441, 128.961}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{296.703, 
                    125.113}, {297.641, 122.648}, {304.176, 127.645}, {
                    306.176, 130.36700000000002`}, {302.23799999999994`, 
                    127.27}, {296.22299999999996`, 127.55499999999999`}, {
                    296.703, 125.113}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{296.703, 
                    125.11299999999997`}, {297.641, 122.64799999999997`}, {
                    304.176, 127.64499999999998`}, {306.176, 
                    130.36700000000002`}, {302.23799999999994`, 
                    127.27000000000001`}, {296.22299999999996`, 127.555}, {
                    296.703, 125.11299999999997`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{292.895, 
                    121.23}, {293.945, 117.79700000000001`}, {300.777, 
                    123.281}, {302.816, 125.965}, {298.465, 122.645}, {
                    292.34000000000003`, 123.67599999999999`}, {292.895, 
                    121.23}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{292.895, 
                    121.23000000000002`}, {293.945, 117.79700000000003`}, {
                    300.777, 123.28100000000003`}, {302.816, 125.965}, {
                    298.465, 122.64499999999998`}, {292.34000000000003`, 
                    123.67599999999999`}, {292.895, 121.23000000000002`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{299.32, 
                    130.055}, {297.465, 129.094}, {296.715, 134.363}, {
                    297.762, 138.08200000000002`}, {297.746, 134.023}, {
                    301.484, 131.008}, {299.32, 130.055}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{299.32, 
                    130.055}, {297.465, 129.094}, {296.715, 134.363}, {
                    297.762, 138.082}, {297.746, 134.023}, {301.484, 
                    131.00799999999998`}, {299.32, 130.055}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    296.15200000000004`, 125.871}, {293.92199999999997`, 
                    125.21100000000001`}, {294.629, 130.88700000000003`}, {
                    296.53499999999997`, 134.57}, {296.78099999999995`, 
                    130.92200000000003`}, {298.42599999999993`, 
                    127.45700000000001`}, {296.15200000000004`, 
                    125.871}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    296.15200000000004`, 125.87100000000001`}, {
                    293.92199999999997`, 125.21100000000001`}, {294.629, 
                    130.88700000000003`}, {296.53499999999997`, 134.57}, {
                    296.78099999999995`, 130.922}, {298.42599999999993`, 
                    127.45700000000002`}, {296.15200000000004`, 
                    125.87100000000001`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{292.191, 
                    121.953}, {289.699, 121.812}, {291.414, 126.82}, {293.469,
                     129.641}, {293.121, 125.95700000000001`}, {
                    294.28099999999995`, 122.37899999999999`}, {292.191, 
                    121.953}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{292.191, 
                    121.953}, {289.699, 121.81199999999998`}, {291.414, 
                    126.82}, {293.469, 129.641}, {293.121, 
                    125.95700000000002`}, {294.28099999999995`, 
                    122.37899999999999`}, {292.191, 121.953}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{296.559, 
                    119.816}, {297.309, 118.54700000000001`}, {299.141, 
                    120.895}, {302.148, 122.60499999999999`}, {299.445, 
                    121.898}, {296.227, 120.992}, {296.559, 
                    119.816}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{296.559, 
                    119.816}, {297.309, 118.547}, {299.141, 
                    120.89500000000001`}, {302.148, 122.60499999999999`}, {
                    299.445, 121.898}, {296.227, 120.99199999999999`}, {
                    296.559, 119.816}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{297.984, 
                    162.008}, {295.66, 163.727}, {297.43399999999997`, 
                    166.945}, {297.984, 170.008}, {298.72999999999996`, 
                    167.105}, {300.703, 163.297}, {297.984, 
                    162.008}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{297.984, 
                    162.00799999999998`}, {295.66, 163.72700000000003`}, {
                    297.43399999999997`, 166.945}, {297.984, 
                    170.00799999999998`}, {298.72999999999996`, 167.105}, {
                    300.703, 163.29700000000003`}, {297.984, 
                    162.00799999999998`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{298.062, 
                    157.71899999999997`}, {301.559, 158.141}, {
                    301.03099999999995`, 162.656}, {301.137, 165.52}, {
                    300.08599999999996`, 161.63299999999998`}, {
                    297.22299999999996`, 160.977}, {298.062, 
                    157.71899999999997`}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{298.062, 
                    157.719}, {301.559, 158.141}, {301.03099999999995`, 
                    162.656}, {301.137, 165.51999999999998`}, {
                    300.08599999999996`, 161.63299999999998`}, {
                    297.22299999999996`, 160.977}, {298.062, 157.719}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{297.512, 
                    158.305}, {294.559, 158.477}, {294.715, 161.836}, {
                    294.555, 165.238}, {296.055, 162.11299999999997`}, {
                    297.828, 161.629}, {297.512, 158.305}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{297.512, 
                    158.305}, {294.559, 158.477}, {294.715, 161.836}, {
                    294.555, 165.238}, {296.055, 162.11299999999997`}, {
                    297.828, 161.629}, {297.512, 158.305}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{297.633, 
                    154.129}, {299.92999999999995`, 153.945}, {301.125, 
                    156.20299999999997`}, {301.65200000000004`, 
                    159.72299999999998`}, {299.47299999999996`, 
                    156.48000000000002`}, {297.48799999999994`, 
                    157.48800000000003`}, {297.633, 154.129}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{297.633, 
                    154.129}, {299.92999999999995`, 153.945}, {301.125, 
                    156.203}, {301.65200000000004`, 159.723}, {
                    299.47299999999996`, 156.48}, {297.48799999999994`, 
                    157.488}, {297.633, 154.129}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{296.809, 
                    154.406}, {293.85200000000003`, 154.02700000000002`}, {
                    294.324, 157.469}, {294.445, 160.004}, {295.348, 
                    157.586}, {297.754, 156.824}, {296.809, 
                    154.406}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{296.809, 
                    154.406}, {293.85200000000003`, 154.02700000000002`}, {
                    294.324, 157.469}, {294.445, 160.004}, {295.348, 
                    157.586}, {297.754, 156.824}, {296.809, 154.406}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{301.414, 
                    155.863}, {301.18, 153.617}, {299.762, 149.758}, {297.477,
                     150.625}, {296.53099999999995`, 153.383}, {299.484, 
                    153.934}, {301.414, 155.863}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{301.414, 
                    155.863}, {301.18, 153.617}, {299.762, 149.758}, {297.477,
                     150.625}, {296.53099999999995`, 153.383}, {299.484, 
                    153.934}, {301.414, 155.863}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{296.77, 
                    150.383}, {297.79299999999995`, 152.35500000000002`}, {
                    294.445, 153.34}, {293.734, 155.89800000000002`}, {
                    293.328, 152.23399999999998`}, {293.668, 
                    149.83200000000002`}, {296.77, 150.383}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{296.77, 
                    150.383}, {297.79299999999995`, 152.35500000000002`}, {
                    294.445, 153.34}, {293.734, 155.898}, {293.328, 
                    152.234}, {293.668, 149.832}, {296.77, 150.383}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    306.29699999999997`, 173.727}, {304.457, 
                    175.71099999999998`}, {306.082, 178.85200000000003`}, {
                    306.633, 181.914}, {307.379, 179.012}, {308.676, 
                    175.164}, {306.29699999999997`, 173.727}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    306.29699999999997`, 173.72700000000003`}, {304.457, 
                    175.711}, {306.082, 178.852}, {306.633, 181.914}, {
                    307.379, 179.01199999999997`}, {308.676, 175.164}, {
                    306.29699999999997`, 173.72700000000003`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    306.35200000000003`, 170.039}, {309.582, 
                    169.71099999999998`}, {310.363, 176.285}, {310.695, 
                    179.10899999999998`}, {309.64500000000004`, 
                    175.22299999999998`}, {305.92199999999997`, 173.445}, {
                    306.35200000000003`, 170.039}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    306.35200000000003`, 170.039}, {309.582, 169.711}, {
                    310.363, 176.28500000000003`}, {310.695, 
                    179.10899999999998`}, {309.64500000000004`, 175.223}, {
                    305.92199999999997`, 173.445}, {306.35200000000003`, 
                    170.039}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{305.688, 
                    170.105}, {303.40599999999995`, 171.285}, {
                    303.93399999999997`, 173.824}, {303.219, 175.73}, {
                    304.754, 173.39100000000002`}, {306.15200000000004`, 
                    173.055}, {305.688, 170.105}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{305.688, 
                    170.105}, {303.40599999999995`, 171.28500000000003`}, {
                    303.93399999999997`, 173.824}, {303.219, 
                    175.73000000000002`}, {304.754, 173.39100000000002`}, {
                    306.15200000000004`, 173.055}, {305.688, 170.105}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{306.328, 
                    165.80100000000002`}, {309.707, 165.512}, {
                    311.72299999999996`, 172.789}, {311.828, 175.656}, {
                    310.777, 171.766}, {305.93399999999997`, 169.656}, {
                    306.328, 165.80100000000002`}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{306.328, 
                    165.80100000000002`}, {309.707, 165.51199999999997`}, {
                    311.72299999999996`, 172.78900000000002`}, {311.828, 
                    175.656}, {310.777, 171.76600000000002`}, {
                    305.93399999999997`, 169.656}, {306.328, 
                    165.80100000000002`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{305.68, 
                    165.91}, {302.5, 166.64499999999998`}, {302.883, 
                    168.69899999999998`}, {303.35900000000004`, 
                    172.02700000000002`}, {304.371, 168.676}, {
                    306.14500000000004`, 169.38700000000003`}, {305.68, 
                    165.91}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{305.68, 
                    165.91}, {302.5, 166.64499999999998`}, {302.883, 
                    168.69899999999998`}, {303.35900000000004`, 
                    172.02700000000002`}, {304.371, 168.676}, {
                    306.14500000000004`, 169.38700000000003`}, {305.68, 
                    165.91}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{306.367, 
                    161.602}, {310.08599999999996`, 160.969}, {309.824, 
                    166.848}, {312.77299999999997`, 171.11299999999997`}, {
                    310.22299999999996`, 167.945}, {305.625, 163.953}, {
                    306.367, 161.602}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{306.367, 
                    161.60199999999998`}, {310.08599999999996`, 160.969}, {
                    309.824, 166.84799999999998`}, {312.77299999999997`, 
                    171.11299999999997`}, {310.22299999999996`, 167.945}, {
                    305.625, 163.953}, {306.367, 161.60199999999998`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{305.527, 
                    161.80100000000002`}, {302.72299999999996`, 
                    161.71899999999997`}, {302.449, 165.941}, {302.605, 
                    167.656}, {303.25, 165.94899999999998`}, {306.547, 
                    164.32800000000003`}, {305.527, 
                    161.80100000000002`}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{305.527, 
                    161.80100000000002`}, {302.72299999999996`, 161.719}, {
                    302.449, 165.941}, {302.605, 167.656}, {303.25, 
                    165.94899999999998`}, {306.547, 164.328}, {305.527, 
                    161.80100000000002`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{312.176, 
                    166.129}, {310.78099999999995`, 161.605}, {308.805, 
                    157.07}, {306.367, 157.414}, {305.199, 
                    159.98800000000003`}, {308.68, 160.316}, {312.176, 
                    166.129}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{312.176, 
                    166.129}, {310.78099999999995`, 161.605}, {308.805, 
                    157.07}, {306.367, 157.414}, {305.199, 159.988}, {308.68, 
                    160.316}, {312.176, 166.129}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    305.48799999999994`, 158.078}, {306.512, 
                    160.05100000000002`}, {303.16400000000004`, 161.035}, {
                    302.453, 163.598}, {302.047, 159.934}, {302.387, 
                    157.52700000000002`}, {305.48799999999994`, 
                    158.078}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    305.48799999999994`, 158.07799999999997`}, {306.512, 
                    160.05100000000002`}, {303.16400000000004`, 161.035}, {
                    302.453, 163.59799999999998`}, {302.047, 159.934}, {
                    302.387, 157.52700000000002`}, {305.48799999999994`, 
                    158.07799999999997`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{311.215, 
                    160.961}, {309.227, 156.88700000000003`}, {308.328, 
                    152.20299999999997`}, {305.59799999999996`, 152.883}, {
                    304.578, 156.05100000000002`}, {308.613, 
                    156.71499999999997`}, {311.215, 160.961}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{311.215, 
                    160.961}, {309.227, 156.88700000000003`}, {308.328, 
                    152.203}, {305.59799999999996`, 152.883}, {304.578, 
                    156.05100000000002`}, {308.613, 156.715}, {311.215, 
                    160.961}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    305.03099999999995`, 153.656}, {306.207, 155.812}, {
                    302.855, 156.57399999999998`}, {302.03499999999997`, 
                    159.547}, {301.59, 155.656}, {302.008, 152.883}, {
                    305.03099999999995`, 153.656}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    305.03099999999995`, 153.656}, {306.207, 
                    155.81199999999998`}, {302.855, 156.57399999999998`}, {
                    302.03499999999997`, 159.547}, {301.59, 155.656}, {
                    302.008, 152.883}, {305.03099999999995`, 153.656}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{299.305, 
                    181.238}, {297.34400000000005`, 180.71099999999998`}, {
                    295.28499999999997`, 182.91}, {296., 186.207}, {298.242, 
                    185.648}, {299.27, 183.61299999999997`}, {299.305, 
                    181.238}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{299.305, 
                    181.238}, {297.34400000000005`, 180.711}, {
                    295.28499999999997`, 182.91}, {296., 
                    186.20700000000002`}, {298.242, 185.64799999999997`}, {
                    299.27, 183.61299999999997`}, {299.305, 181.238}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4vJ986X0JYsdVn+85Jt0J83hgtLtn3VixQ4z
8oSaD+xLc7jv3zs9j6XYgQEE9qQ5eDysElnHWeywt2SyBMuzNIdPQG0CfFB5
jnSHDseEpxeAfP27KmyNiulw9a2vA3fI2aY7LJt9RGEDU7GDbFSK9f34dIdF
rts+/wWaXy2yzv3hrHSH497mnY5cxQ5FGRPf1mxOdwC64tRC/mIHH6Bwwtl0
B5CwvWKxA9f1xQW2+9IdtNvFbp4Duv/mue/Bj1emOwiD1AtC5SdB1QP5YDoR
6j6g/97V2JvGeaU7XK14qWYoV+wA9KVQswaUL1PsEManu2nu7zQH9PABACpY
gi4=
                    "]]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4vJ986X0JYsdVn+85Jt0J83hgtLtn3VixQ4z
8oSaD+xLc7jv3zs9j6XYgQEE9qQ5eDysElnHWeywp2SyBMuzNIdPQG0CfFB5
jnSHDseEpxeAfP27KmyNiulw9a2vA3fI2aY7LJt9RGEDU7GDbFSK9f34dIdF
rts+/wWaXy2yzv3hrHSH497mnY5cxQ5FGRPf1mxOdwC64tRC/mIHkHDC2XQH
kLC9YrED1/XFBbb70h2028VungO6/+a578GPV6Y7CIPUC0LlJ0HVA/lgOhHq
PqD/3tXYm8Z5pTtcrXipZihX7NA3HehhDShfptghjE9309zfaQ7o4QMAKQCC
LQ==
                    "],
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4gtKt3/WfSl02D9fSv+uS6rDlhNl++YzFDlk
THxbY6+Y6uBt3umYIFnkELvLk4fJPNUBrJ6tyIEBBDJSHSZLsITxfS90COfT
3TS3P9Vhkeu2z38fFELkN0D13y+EiN9IdXi8dPYRhXtQ+3jSHKpE1rk/PFfo
YAWyODoNou5AoQPX9cUFtmVpDsuAyjdsKnTYCnLXpDSHqxUv1QwXFTrMyBNq
PpCV5qB/V4WtcWOhg0xUivX9cKj6Q4UOws0HTi10THPQbhe7ee5socM3jZj+
Q09THexABgP5F0H+OJTq8OmSb5IA0H5VtsapzkD3K2woypj4vNCBG2R/FtS/
SOEDAIZxjIA=
                    "]]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4gtKt3/WfSl02DdfSv+uS6rDlhNl++YzFDlk
THxbY6+Y6uBt3umYIFnkELfLk4fJPNUBrJ6tyIEBBDJSHSZLsITxfS90COPT
3TS3P9Vhkeu2z38fFELkN0D13y90WAwSv5Hq8Hjp7CMK96D28aQ5VImsc394
rtDBCmRxdBpE/4FCB67riwtsy9IclgGVb9hUCHHXpDSHqxUv1QwXFTrMyBNq
PpCV5qB/V4WtcWOhg2xUivX9cKj6Q4UOws0HTi10THPQbhe7ee5socNXjZj+
Q09THexABgP5YH8cSnX4dMk3SQBovypb41RnoPsVNhRlTHwOtT8L6l+k8AEA
hLmMew==
                    "],
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4q0nyvbNlypy4Lq+uMC2LtVhep5Q8wG1IodL
Srd/1kWlOny65JskYFXkoMrWONU5P9Wh9XXgDjn9IodekMIVqQ6yUSnW91WL
HB4vnX1E4UKqQ7XIOveHKkUOGRPf1tgzpjkc/qoR0w8zXy7N4WrFSzVDniIH
bhDfK81Bq13s5rnPhRB9eWkOfLqb5r5/Wujgbd7pmNCZ5gB0zamF1wsdvgGN
ObQ0zcFyC9DBpwsd3tXYm8Z1pUH03Sh0UDfkWCNTlOYA1PX0wotCiH1BaRB3
/Sp0APtTK83B/WGVyDrmIoc+kPt50hyEQeaLFkH0X0p1sAKZz1vkEApyyOJU
B/TwAQAz4ogA
                    "]]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4q0nyvbNlypy4Lq+uMC2LtVhep5Q8wG1IoeL
Srd/1kWlOny65JskYFXkoMrWONU5P9Wh9XXgDjn9Ioc+kMIVqQ6yUSnW91WL
HB4vnX1E4UKqQ7XIOveHKkUOGRPf1tgzpjkc/qoR0w8zXy7N4WrFSzVDHijf
K81Bq13s5rnPhRB9eWkOfLqb5r5/WujgY97pmNCZ5gB0zamF1wsdQMYcWprm
YLkF6ODThQ7vauxN47rSIPpuFDqoG3KskSlKcwDqenrhRSHE/KA0iLt+FTqA
tM3XSnNwf1glso4Z6n6eNAdhkPmiRRD9l1IdrEAKeYscQkEOWZzqgB4+ADLS
h/4=
                    "],
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4sdLZx9ReFLkMD1PqPmAWZqD4oaijIlPixxW
fbzkm8SS5pAx8W2N/cUih+Pe5p2OP1Idrla8VDO8VAQRd0xzmCzBEsZ3ucjB
4K4KW2NvmsMnoDaBd0UOqmyNU50vp0HE70L57ukOnY4JTy9cKXJgAIGGdAeQ
9RuAfLA7XqQ78Olumvv+ZpHDhENfNWLkMxxAVP+9Igeu64sLbMMyIOZ/KnIA
2m4aZ5ThsAyk/1WRQxhII3uGw0Wl2z/rHhU5qBtyrJG5lg5x75siB5C1SuXp
Dg/8e6fnAfX3gwwGuqd833wpfdZiiP/2pDnE7fLkYXpc5NALCpCKNAf08AEA
G6SKkQ==
                    "]]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4sdLZx9ReFLkMCNPqPmAWZqD4oaijIlPixxW
fbzkm8SS5pAx8W2N/cUih+Pe5p2OP1Idrla8VDO8VAQRd0xzmCzBEsZ3uchB
/64KW2NvmsMnoDaBd0UOQN5U58tpDgYg8btFDmogvnu6Q6djwtMLV4ocGECg
Id0BZP0GIP8JiPEi3YFPd9Pc9zeLHCYc+qoRI5/hAKL67xU5cF1fXGAblgEx
/1ORw7sae9M4owyHZSD9r4ocwkAa2TMcLird/ln3qMhB3ZBjjcy1dIh73xQ5
OAGtVSpPd3jg3zs97xPUfKB7yvfNl9JnLYb4b0+aQ9wuTx6mx0UOfdOBAVKR
5oAePgAdlIqX
                    "],
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4k7HhKcX1hQ5ZEx8W2Pvm+5gueVE2b71RQ5x
uzx5mOTTHbzNgSoOFznMyBNqPiCV7uDxsEpk3d4ih+MgiZh0h9znv1d+3FEE
UTcx3eHx0tlHFHZAzduJUN87HWjAk3SHqBTr+/5HixwuKd3+WSeVATH3UJED
SPpAWYbDZAmWMD6g+tbXgTvk5mZAzNle5PBNI6b/0NEMh0+XfJMElhQ57C0B
qlyXAbEP6H6u64sLbPsyHBa5bvv8dwvUPZkZDgZ3VdgatxY53PlZl7VHJgMi
DvQfWN0PqP+WF0HMOZLuoLChKGPiSqj5dekOsPDxAakDhg8A6B2OBw==
                    
                    "]]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4k7HhKcX1hQ5ZEx8W2Pvm+5gueVE2b71RQ5x
uzx5mOTTHbzNgSoOFznMyBNqPiCV7uDxsEpk3d4ih+MgiZh0h9znv1d+3FEE
UTcx3eHx0tlHFID8TJB5OxHqe6cDDXiS7hCVYn3f/2iRwyWl2z/rpDIg5h6C
ml+W4TBZgiWMD6i+9XXgDrm5GRB3bS9y+KYR03/oaIbDp0u+SQJLihz2lABV
rsuA2Ad0P9f1xQW2fRkOi1y3ff67pcjBB+SezAwHg7sqbI1bixzu/KzL2iOT
AXEn0H+LQep+QP23vAhizpF0B4UNRRkTV0LNr0t3gIUPWB0wfADplY4I
                    
                    "],
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYCYj7dTXPfFxc7CDcfOLVwZrLDcW/zTsesYoeL
Srd/1jUlO4DlI4sdXLpznv+emOzQ6Zjw9EJGsUPGxLc19huTHRa5bvv8t6TY
4RJI/SkovwCq/1Kyw33/3ul5FVD1H5MdLLecKNtXX+wQCjJYOMUBZF0CkA8S
nq+W4nAMJNBR7ACyRsk+xeHx0tlHFCYUO1wAmReWAnHP7GKHrSD1dikODCAw
pdjBCaReO8Xh0yXfJIGuYgfZqBTr+0Dzwe7tKXaYkSfUfIApxWE6iG4rdlj9
EajwTbKDwoaijInVxQ43z30Pfnw0GWJ/XbHDN42Y/kMbof5HCh8A/bGSfA==

                    "]]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYCYj7dTXPfFxc7CDcfOLVwZrLDcW/zTsesYocL
Srd/1jUlO4DlI4sdnLtznv+emOzQ6Zjw9EJGsUPGxLc19huTHRa5bvv8t6TY
4SJI/SkovwCq/1Kyw33/3ul5FVD1H5MdLLecKNtXX+wQCjJYOMUBZF0CkL8V
KDxfLcXhGEigo9gBZI2SfYrD46WzjyhMgJoflgJxz2yoersUBwYQmAJVr53i
8OmSb5JAV7GDbFSK9X2g+WD39hQ7zMgTaj7AlOIwHUS3FTus/ghU+CbZQWFD
UcbE6mKHm+e+Bz8+mgyxv67Y4ZtGTP+hjVD/I4UPAPqZknk=
                    "],
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{294.92999999999995`, 137.11299999999997`}, {
                    292.977, 136.15200000000002`}, {291.4959999999999, 
                    133.754}, {291.39799999999997`, 131.805}, {
                    291.22999999999996`, 129.555}, {290.90999999999997`, 
                    127.66}, {289.89799999999997`, 126.062}, {291.504, 
                    126.508}, {292.27299999999997`, 129.07}, {292.504, 
                    131.523}, {292.734, 134.059}, {294.10200000000003`, 
                    135.16}, {294.92999999999995`, 
                    137.11299999999997`}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{294.92999999999995`, 137.11299999999997`}, {
                    292.977, 136.152}, {291.4959999999999, 
                    133.75400000000002`}, {291.39799999999997`, 131.805}, {
                    291.22999999999996`, 129.555}, {290.90999999999997`, 
                    127.66}, {289.89799999999997`, 126.06199999999998`}, {
                    291.504, 126.50799999999998`}, {292.27299999999997`, 
                    129.07}, {292.504, 131.523}, {292.734, 134.059}, {
                    294.10200000000003`, 135.16}, {294.92999999999995`, 
                    137.11299999999997`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{290.863, 132.406}, {289.512, 129.914}, {287.625, 
                    128.965}, {287.527, 127.113}, {287.363, 
                    124.98400000000001`}, {287.203, 124.87899999999999`}, {
                    286.625, 122.785}, {288.215, 123.20700000000001`}, {
                    288.617, 123.348}, {289.047, 126.531}, {289.309, 
                    128.76999999999998`}, {291.10200000000003`, 130.348}, {
                    290.863, 132.406}}}]}}}}, {{{
                   {RGBColor[0.741176, 0.41960800000000004`, 0.], Thickness[
                    0.0008333333333333334], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{290.863, 132.406}, {289.512, 129.914}, {287.625, 
                    128.965}, {287.527, 127.11299999999997`}, {287.363, 
                    124.98400000000001`}, {287.203, 124.87899999999999`}, {
                    286.625, 122.78500000000003`}, {288.215, 
                    123.20700000000002`}, {288.617, 123.34799999999998`}, {
                    289.047, 126.531}, {289.309, 128.77}, {
                    291.10200000000003`, 130.34799999999998`}, {290.863, 
                    132.406}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{248.824, 
                    109.34400000000001`}, {248.066, 107.91400000000002`}, {
                    247.195, 105.73400000000001`}, {245.61299999999997`, 
                    106.133}, {245.59, 107.23}, {247.32000000000002`, 
                    107.988}, {248.824, 109.34400000000001`}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    246.47299999999998`, 108.85499999999999`}, {
                    243.40200000000002`, 107.598}, {240.754, 
                    107.91000000000001`}, {240.42600000000002`, 105.98}, {
                    243.30100000000002`, 105.66799999999999`}, {
                    244.35500000000002`, 106.85199999999999`}, {
                    246.47299999999998`, 108.85499999999999`}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{259.32, 119.008}, {257.254, 117.316}, {255.914, 
                    115.383}, {255.289, 112.887}, {254.637, 110.559}, {
                    253.71899999999997`, 108.703}, {252.375, 106.613}, {
                    254.566, 108.10499999999999`}, {255.941, 110.141}, {
                    256.633, 112.586}, {257.23799999999994`, 114.992}, {
                    257.949, 116.793}, {259.32, 119.008}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{256.777, 119.016}, {254.562, 
                    117.24600000000001`}, {252.47299999999998`, 115.242}, {
                    251.848, 112.742}, {251.195, 110.418}, {
                    250.80100000000002`, 108.637}, {249.309, 106.324}, {
                    251.648, 107.816}, {252.578, 110.074}, {253.266, 
                    112.52}, {253.871, 114.926}, {255.258, 116.727}, {256.777,
                     119.016}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4mqRde4P9fIdmg+cWujqF+Nw+2dd1h6DfAeu
64sLbLNiHFTZGqc6q+c7zMgTaj7QFONgteVE2T7pfAfn7pznvztjHHzMOx0T
WKHys2Ic4nZ58jC9z3PonQ4UWBHjsG++lP7dG3kOC123ff67JcYhnE9309z9
eQ7S+ndV2A7GOICoxo15DotA8nNiHLxB5gH5GRPf1ti3xkBoIP+bRkz/odgY
h1UfL/kmbchzEAU6u8oGod6Lh0m7XS4G4o5NeQ5A065U/Ix2AOo2jduW5yDX
+jpwx7doB3VDjjUyh6D2f4yG2HslzwHk3AOvoiH2vc1z8EsSiLB8Eu1wHGQB
Q75DLMhfp6Mh4cGfD/HfjmiIu2TzHZ5eULr98xhUv2q+QzGI8Rxqn1Y+1JwY
hzug8NXJh9hvGOOAHv4AioCw8w==
                    "]], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4hl5Qs0H5PIcmg+cWujqF+OwyHXb578yeQ5c
1xcX2GbFOKz6eMk3SSXPYSFIvCXGYeuJsn3z9fIcRNa5P6zqgfKd8hwyJ76t
sZ8b43BB6fbPurA8h4dVQBULYxyKM4AS2XkQen6MQzVIY1Oew3Fv807HBTEO
t37WZe3pyHP4phHTf2hqjMO++VL6d4H8vSWTJVjqoO4B8uVaXwfuCIuBqOvM
c+idDnS4AUI92B9CMQ5hfLqb5rbnORjcVWFrfBvtwAACQHmQ8gOvoiHitXkO
IOfYP412KLQF+jQnz0EeZP69aAerLUAP+edB7L0TDXGvXZ7Dprnvlx87HO0A
cnaCIdR/G6MdXLpznv9WzIPYcwAqrwh1z6NoB2FQwCpCzfsTDXG3Qp6DtD7Q
IYYxDujhDwA/rLai
                    "]], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3},
                     {1, 3, 3}, {1, 3, 3}}}, {{{262.832, 90.67999999999999}, {
                    262.871, 89.73400000000001}, {262.97999999999996`, 
                    88.977}, {263.543, 88.215}, {260.28099999999995`, 
                    89.523}, {255.676, 88.824}, {252.52700000000002`, 
                    87.35499999999999}, {251.125, 86.68799999999999}, {
                    249.42600000000002`, 88.12499999999999}, {251.07, 
                    89.48400000000001}, {253.414, 91.383}, {
                    258.83599999999996`, 90.309}, {262.832, 
                    90.67999999999999}}, {{216.82800000000003`, 90.73}, {
                    216.875, 89.84}, {216.76999999999998`, 89.023}, {216.441, 
                    88.24600000000001}, {219.98800000000003`, 
                    89.71100000000001}, {223.79299999999998`, 88.492}, {
                    227.375, 87.051}, {229.836, 86.031}, {230.035, 87.793}, {
                    229.602, 88.402}, {228.85200000000003`, 
                    89.48400000000001}, {227.406, 90.67199999999998}, {
                    225.578, 90.699}, {224.359, 90.715}, {219.672, 90.758}, {
                    216.82800000000003`, 90.73}}, CompressedData["
1:eJxdVGtIFFEUls0sSiTLomSxB2ZGhPlDzEr8Qq2sSKzmrrurJmbQzr7uloSZ
Wr4ICdGyKBIxs7RILKRErFRE7AGFWRZiZiYqlSWRFiZh93oGAgdmds+c13fO
991ZneLcf0Tn5uYWKW75u/BdFQ/PsOKKY3Feq86MB09PNFeYrHicVrrc3c+M
npe/DwyGWFFfPlbTMceMlgrfoD4fK3Z76jacbTZhXfD8Wn21iqPnv2VGDBkx
eLOsfZW/iqyIkKQmbyMCPHIuRT60wCL99njyX7RgIMOnbud6zbZZUKs3pW69
a0BSU4ynbolWL8SAgq9xjX4rVByUgZsMOCXSBi6oiJH93zK4yeuj5u9kOC4T
p1W8WtM7md3FUNI2EZggbJmWkcYQ1OfvkTOpYq3EZWZ4sie0cPuoquFhNO+E
SvMvY4SnV7OHFbJbVPhJYA0Kvf+gouHn3zfpJxXCM67ikIyrUhB1zjYyFWdF
XuvzyugdDF0S1xcrfgUmFLf1Kdgr2idn2cifrdA+rtmQKPOtCgxeG+vL+20o
uiwI4lp/Yc/g7pzl36zNN9eOBZLXXAZXuPint6MyWiDMZxQXb6d8zojPMw7C
b2HU/70DW+4LIZxmkGHJ3k7CW8TAZT0fJ839XSF+gp0Y7hSD1SkQ06mPopzE
X4FCfUqcIJ1p87U7MS2vGoXilnLifx6DePbHHv5vz9TP49iXsig+rFZBd/rn
gOASTnzmK8TzVU59bygQqJhXKSe9vVBoH4VavDvDLkm0sEnfDPaRqds/8jky
pV5jGK7LPaVz2v8dRvVzOZ2PNkb1i7X4ZwxSXsV6F/kXG6h+jIvOy2sD+mPF
xv1cpC9XPMUPc03fRshn0i1O+/ljhNj2UOcxTudnwIRGKbRUbR8rzagW67tn
4giT/ISaqf42rvFuJv21Omn+RBPpq9tBc3wyEq9jduK7x0jn19dO/HYb0SH5
GrdiVKy9oMyE2d+Hf6Gf21o=
                    "]}]}}}}, {{{
                   {FaceForm[{RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {CompressedData["
1:eJxdUl1IVGEQXZbUKJOIHiTDVCoEsdUHkUV0j0WILSn9sH73Q9Iszd3b6nct
wmR7iIooaEUi+iMMonyRkAgpoU0k/CkoH5J+VGRZLSS1B6Mo0fpm50LRhcvc
YWbOnDnnZtY17693OhyOXP1SvN604Vz/QYWKuvXCPS0hjxZNVe5V6F1cftsa
lShZ8+6e2q0w6C28VPpeIqOnpbHDo3CisWM+9EbiBs3fasan0azxnzskIp2b
XJPDTdhy4cu+JxEDNF68EOT+5wbXU4MYIrx+AxRq3cfxPbu6faBAwiqmCZNx
P0rQmKfexMaHZdE2zS92//aLDGGipq882RmT2Fk7M5rlNVFJ/Ccknp28mrqq
xGS8MQmikZ5v8j0jEorws01E2zTiU8m8XgU4/jbwePhUpLMhgK2JZ6/t8hpY
S/x/+bneJfDh9Y8DsVk/9iQ7cy6GBfOd8/P9FQKlxCcpwPhugc0k6D95mASf
COAKxbtVcNDTbbL+532s14qtV7sP+hpfSo6ydfYhb5KYKdavpwpx/77ZfrgE
XFRfUjjjKTjUp/cthPSH00IaFcoFMsm/BIv5HBasT5IFP+kcFOyvzk/Pbs9f
HRKYp/lEi/dctvv1fFzPm4J5afwZuv+B3b+i2IdegZTcR3e+Lv/N43oMKaQT
UIPB94cVdFfX4KKBddR/TPG+lxJlRPSIwjbyQ/s91qqJVSt0E9Bnif//3z91
0Dt+
                    "], CompressedData["
1:eJxTTMoPSmViYGDQBmIQ3fo6cIdcaIHD3pLJEiznohyEmg+cWhhd4NA7PU+o
+UKUw6GvGjH9CQUOIuvcH1adiXIAq0+Gqt8X5fDpkm+SQFeBQ629adyuh5EO
S2cfUdhwpMBh09z3y48FRzrslAPq+FXg4JckEGG5JMLhasVLNcN/BQ5rZKJS
rKdHODCAQSFEfXeEwwygtQeAfDDdFOGgf1eFrZGxEGJ+ZYQDUNd9fyAf5IzW
4giHHSDzgerB5udEONz3B7ocaP43oLMPxUY4dDomPL3wA2qfP9T8T1D3u0VA
3DepwCFj4tsa+6PhEPdpFTg8rAL6eGOYA9f1xQW2/3Ih6peFOVxUuv2zbl02
xJxZUPlHWRB3bg13kAU5kDvLoRhkINA+cDj+yITw4yMcuEHqf2U6xO7y5GHq
hvkvC2L+tAgInZfl4NKd8/y3ZaTDY1CAXslyeHYBaPG7SIh6w2yI+1ZGOYC8
dd88G2p/lIO6IccaGadsh+Pe5p2OB6IcDEDivtkQc49FOdz6WZe1JyIbEt6n
oxz2z5fSv5uS7XAbJA6M30JboI9yEOqBoWIaZ5YDMU8hCiIulutwDMRfEQkx
/20uxH/LIyH2n8pzAAXrjmVQ/rx8iHqJKAeFDUUZEx2h4bszChLu7gUO2z7/
vVJxMMphy4myffP9ChyApk51Pg1Nb0jpEwCygSyW
                    "]}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4gJbruuLf2Q5qLE1TnXuznGoElnn/vBblsNF
pds/69blOBjcVWFr1M12yJj4tsZ+Y46DKkiderYDUDZrTwOUL5/tcMzbvNPR
JccBRCXMzHZwSnh6QWl1tkMRSOPibIc7IPU+2Q7vauxN41ZlQ8zlzXZ4C+LX
ZTuoG3KskbmW5TAjT6j5QFC2Qyif7qa5m7McfEDmyWY7cF9fXGDbBXXn6SwH
2agU6/v9WQ7750vp312S5RAGUr88y0G4+cCphb1ZEHt2ZTn0TgcaWAHl/8py
uHnue/DjziwHyy0nyvYJZzswgMCELIfjIIfLZEPMXZ3l8E0jpv/Q1iyH1teB
O+ReZkHcty3LoQ9knk22A0j7fCAfrL8hG+LOr9Bwa4KGFzDcwOHZlg0R74P6
E+iOVR8v+SZp5Dighz8AGsWr8g==
                    "]], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    223.39100000000002`, 220.84}, {223.824, 221.148}, {
                    224.512, 219.805}, {224.02700000000002`, 219.469}, {
                    223.621, 219.19899999999998`}, {222.83200000000002`, 
                    220.465}, {223.39100000000002`, 220.84}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{224.55100000000002`, 223.566}, {224.336, 
                    223.461}, {223.90200000000002`, 223.61299999999997`}, {
                    224.031, 223.797}, {224.641, 224.668}, {225.941, 
                    225.98000000000002`}, {226.883, 226.43800000000002`}, {
                    227.172, 226.578}, {227.68, 226.066}, {227.504, 
                    225.816}, {226.93800000000002`, 225.012}, {225.566, 
                    224.062}, {224.55100000000002`, 223.566}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{234.625, 231.559}, {234.86700000000002`, 
                    232.066}, {236.316, 232.637}, {236.68800000000002`, 
                    232.977}, {237.031, 233.32800000000003`}, {237.191, 
                    232.68}, {237.047, 232.375}, {236.805, 231.871}, {
                    235.55100000000002`, 231.02}, {235.004, 230.996}, {
                    234.707, 230.984}, {234.477, 231.254}, {234.625, 
                    231.559}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{238.07, 231.39800000000002`}, {
                    238.38700000000003`, 232.285}, {239.40200000000002`, 
                    233.629}, {240.098, 234.07}, {240.45700000000002`, 
                    234.297}, {241.102, 234.121}, {240.98000000000002`, 
                    233.781}, {240.71099999999998`, 233.02700000000002`}, {
                    239.47299999999998`, 231.71499999999997`}, {238.637, 
                    231.098}, {238.383, 230.871}, {238., 231.195}, {238.07, 
                    231.39800000000002`}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{235.121, 229.184}, {234.91, 229.078}, {235.023, 
                    228.63299999999998`}, {235.227, 228.562}, {235.656, 
                    228.418}, {236.441, 228.39100000000002`}, {236.797, 
                    228.586}, {237.312, 228.906}, {237.078, 230.863}, {
                    236.38700000000003`, 229.816}, {235.92200000000003`, 
                    229.172}, {235.586, 229.379}, {235.121, 229.184}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{229.289, 224.68800000000002`}, {
                    228.23399999999998`, 225.508}, {229.57, 226.66}, {230.672,
                     225.85500000000002`}, {232.82000000000002`, 224.238}, {
                    227.47299999999998`, 218.035}, {224.562, 
                    215.13299999999998`}, {224.02700000000002`, 214.566}, {
                    223.562, 215.996}, {224.242, 216.61299999999997`}, {
                    226.33200000000002`, 218.383}, {228.285, 220.496}, {
                    229.641, 222.68}, {229.90200000000002`, 223.102}, {
                    230.15200000000002`, 224.008}, {229.289, 
                    224.68800000000002`}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxNUl9I1EEQPq+4QqSgfBAzKbGSQlRQJEL87IiI6qHCAhERKYh2ZtSMHvII
vOgoMCSkf2QdFWdRcQ+hEVFymGD0EFIPJSVxiC+KhR0mQVG7N0v0g2V3fzP7
fTPfNxvb2g8eWxYIBHLs2mZX0K7pxM2xDZWCTz/PnniRIjxceLe/rVow+Xbp
0PQk4eTxy/ORFYLxvbUXG2x86PXpkXhIsPZc6s2dNCH3w72OOnvfFOq5Es4Q
Dq8qf3KrVnDE7X8IjxzePsFmF58jzWsXFDUd3fFlnHB+7sCz4kZBto5eQsvz
PXnBdaJ1XCAMO75ZVp4YaV03GI0OP0zYUrXycdEgY42rp4YUZ4j1fSnhR1lz
32iVYCReWDFVQLguNvOM/Itn67gvyrOVMB+pr2m5LcoX9Hgdgs9On18GfaOL
Zc1h0T6XDLrzk7vTxaJ92ni2n0XWPr8ZrHf4rxhOxvq0Ufwko6F1ZqIkbrDT
7f2MiRLrQMzg7q6nmd+9vt+oQWedPUVY6xjwfFFWHRJG311l9W/M6P9hVt6M
waVrtuGPDGdfa4736yurbrnenwFW3jwfj3r98gmVU6WhHmbVp9DPQ5fPryZ0
uXs3Y7sbDOvHy1P9BctjPr/J+/2eEXDfA6/vd4YrKzVIOierBRWOJ0GqU7ko
TtLr/998/gXD6ULx
                    "]], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{245.566, 229.816}, {246.023, 
                    230.21499999999997`}, {246.254, 230.88700000000003`}, {
                    246.73, 231.29299999999998`}, {246.99200000000002`, 
                    231.555}, {247.406, 231.242}, {247.34, 
                    230.61299999999997`}, {247.281, 230.11299999999997`}, {
                    246.61299999999997`, 229.68800000000002`}, {246.164, 
                    229.312}, {245.80100000000002`, 229.039}, {245.375, 
                    229.629}, {245.566, 229.816}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{250.742, 
                    231.656}, {251.418, 231.73}, {251.586, 
                    230.42600000000002`}, {250.848, 230.21499999999997`}, {
                    250.40200000000002`, 230.066}, {250.008, 231.578}, {
                    250.742, 231.656}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIxIGYC4oyJb2vsFfMdGECgJMdhkeu2z38VoPyAHIet
J8r2zTfKd+g/9FUjJjjHoXd6nlBzSL5DgS3X9cUhOQ4+5p2OCaX5Dt80YvoP
heY4AEULbCflO1huAWoEqlc35FgjA+Q/Xjr7iALQfJfunOe/J+Y73Dz3Pfjx
1ByHYpAD6vMdVNkapzpvhqqvyndY/fGSb9IchPlVIuvcH7blOOjfVWFrLMx3
COXT3TQ3GerelHyHuF2ePEzFOQ5g/0RC7WvIgdgTC5VvznEQbj5waqFnPsTc
3BwHoGrTOLt8iLmJOQ6trwN3yNlC3VMMlTfLh/irDqrfMN9h/3wp/bstUPuA
4Qd2RwWCDwtPADINlWE=
                    "]], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxNU2tIlEEU3d22LVqTLfwR0dOsllIkUiJDOrVFaRqk0A8zWaXt4f2Y2exB
UQgS/hARi5KCCCsr6EFhmJSamURFRIVE2yYisvQuwiJjiahv9l6rD4aPmbn3
3HPPuTO7QheFxjgcDqe9cuzlstf2I58PLs9W2Jk7IdLSRaj9uOHmjAzF/wZC
2JxnKfSl9ser8wl3mqdmDhQojPhLG3vzCGUdeUkuUngVr67sWktI4F2U+1bC
cTX5UM99hQfrltSteEe4NNxXWPFSoe3h3u5mj8X3IwrTS7YsG/RamL9o/JVp
HxRi50/em/WJsNngRxTmeWqaAp3Cx86/YfKLCJkDaZ6a95K/mPj8q0Jj73d/
6RxCgV02mK2xMvj6WWqAmAc0x5UQ5xVrxqmVfUBzneeEE4Zfvua+3cJvvUaD
IZ5mMS4J/kKLcXZo7n+ixX1u1axLlPi8XKPb4O0TfiHNehcSNiZnXD+1TcNh
vizCLpN4TeNAytU1Q8mid6fm/ybx667s6wnRJz+KY1ENb6QlnNsh+1sah40e
Xwi3dx+d4r4g/H2W6Ktx2fiSZDHPYcEbFD2cYfajR/gP6b/zkYiLadgqPToT
Evw30p9f/G/XMFNW5iGue0zixwq/PRpnV7d/++WWfbn4s4Bkrkb1lflLl/h0
8dOnmefvSuYfVzDHQSexjqcVqszFOMJcM0dPFVbVW29/1hH31aZY51H9mhT7
YveX8LtKIccY6f03/4k59kl9v0K/4Zki8S7B3y/zOUnuz0n9mfLeHhPzXKpY
txfyfv57j38AmbmZ6A==
                    "]], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJVIGYCYh/zTseEp/kO3NcXF9h25TjcPPc9+PHOfIfb
P+uy9izJcXi8dPYRhRf5EPGXOQ5g9X/zHYSbD5xaeDHHIWPi2xp74QKHVR8v
+SYtyHFgAAGNAodikIR2jsN9/97peWYFEP2KOQ5CIH32BQ5WW06U7ZPOcSjf
N19KH8g/7g00uCLHweNhlcg61wIHLpB7FuU4yEalWN/3LHAASScczHEAaZsf
U+CgytY41Xl7jsNkCZYwvsgChwmHvmrE9Oc4aLWL3TwXXuCgbsixRqYpx+GC
EtAnDgUOcbs8eZheZzvslGt9HehU4AAkd8g9zXZ4AHJfUIEDkBRqXgLlJ0HV
J2dD9OcUOHwDmn5INtthGTA4NhQUQNz1P8sBpO1AXAHE3yLZcPeB7ZfKhvgv
sMBhNSh8bLIh9tpC3bsfwQf7b2c2xFzjAki4xmZDwsmwwMGlO+f5b8dsB17d
TXPfqxc4WILEP2c55D7/vfKjSoHDDJA7bmU5XAS5VwgaPvezHEDRt0EMah83
1P1S0PDXz4aEnyk0vB9lOyhsKMqYCLS/COSA59kOHcDUcUGuAJIeDKDxwV3g
sBXkzyxoekBKPwAl7Amg
                    "]], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIxIGZigAKpAoeMiW9r7B9mOfDpbpr7XrjAYeuJsn3z
H2U5XFS6/bOOq8CB6/riAttjWQ4z8oSaD2gUODglPL2gtDvLofV14A65wAKH
vulAiTVZDt7mnY4JtQUOlluABhzPcqgWWef+sKvAIXaXJw+TeLbDA//e6Xmz
oPaVZjssnX1EYcMSqH3nsh1AxhxYU+Cw6uMl36QP2Q5VIP3bChzCQA4Tz3GQ
jUqxvn+4wKEXpFAkx2GnHNAFuwocbp77HvzYN8dBYUNRxsTNBQ6OIPeV5zjk
PP+98uMyqPlZOQ47QOqB9hXYAn0UkgNxx1yofRI5EPc1FTh804jpPxSa7fAJ
KCxQVeDg0g00yTAbYl9WgUMhSP8HaPh4FUDcfS3LAT08AU9cpAo=
                    "]], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{262.68, 224.742}, {
                    262.40999999999997`, 225.324}, {261.777, 224.875}, {
                    261.89099999999996`, 224.242}, {261.957, 223.668}, {
                    262.42599999999993`, 223.35500000000002`}, {
                    262.89099999999996`, 223.371}, {263.445, 
                    223.39100000000002`}, {264.617, 223.35200000000003`}, {
                    264.617, 224.27299999999997`}, {264.621, 224.918}, {
                    264.113, 225.45700000000002`}, {263.734, 224.742}, {
                    263.375, 224.098}, {262.914, 224.168}, {262.68, 
                    224.742}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{263.312, 227.176}, {263.117, 
                    227.04299999999998`}, {263.29299999999995`, 226.324}, {
                    263.52299999999997`, 226.33200000000002`}, {264.348, 
                    226.359}, {265.51599999999996`, 226.621}, {
                    266.14500000000004`, 227.059}, {266.328, 227.184}, {
                    266.25, 227.617}, {265.98799999999994`, 
                    227.60899999999998`}, {265.195, 227.58200000000002`}, {
                    263.92999999999995`, 227.605}, {263.312, 227.176}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{270.32, 225.36700000000002`}, {
                    270.91799999999995`, 226.30100000000002`}, {272.566, 
                    226.395}, {271.97299999999996`, 225.062}, {271.555, 
                    224.14499999999998`}, {267.449, 216.21899999999997`}, {
                    266.89099999999996`, 215.21099999999998`}, {
                    266.28099999999995`, 214.078}, {265.78099999999995`, 
                    214.641}, {266.215, 215.523}, {266.79699999999997`, 
                    216.656}, {270.133, 225.094}, {270.32, 
                    225.36700000000002`}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIlIGYC4p1yra8Dmwoc1A051shsynLQv6vC1lhf4PC2
xt407liWg0xUivX9/AKHY97mnY5PshyEmw+cWlhY4MB1fXGB7bosh+l5Qs0H
SgocjoPkfbIcPl3yTRLYUeDglPD0glJ2lsN9/97peWcKHPaWTJZg6ctyyHn+
e+XHewUO1SLr3B8C9VeB6HMFDhMOfdWIkYfa/7zAgQEEBLIcFrlu+/z3S4FD
P0iePcvhgtLtn3V8hRD7dLIcgKaG8UkXOuyfL6V/F2i/drvYzXO2hQ6OIPuX
Zznw6W6a+z640KEX5FCNbAeQtoTSQog9jdkQ9zYVOqz6CGQsyYaYn1fokDER
GAJ7sx1A1vanQdUvzIbQnoUQ9zlAzVMthLizAmrf3wKIftcsB6stJ8r23S1w
eLx09hEFmSwHUHD6A/3HDQq/qiyHqxUv1QyfFUDsnQYNzycFDmpsjVOdV2dB
9N0ocLh57nvw45NZEHOPFzh8Azrr0FpoeO2Ght/sLIfyfcCAWFngsBrkn54s
iPtnQOX7oeHfVwAJjwlZDh2ggGqDug/IR08PAAHY+B0=
                    "]], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    271.656, 219.258}, {271.68, 219.43}, {270.76599999999996`,
                     219.508}, {270.812, 218.621}, {270.84400000000005`, 
                    217.969}, {271.625, 217.789}, {271.762, 217.883}, {
                    272.99199999999996`, 218.781}, {271.5, 
                    218.33200000000002`}, {271.656, 219.258}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{269.863, 215.664}, {269.621, 215.605}, {
                    269.39799999999997`, 214.83200000000002`}, {269.969, 
                    214.789}, {270.49199999999996`, 214.75}, {272.539, 
                    214.97299999999998`}, {273.105, 214.93800000000002`}, {
                    273.47299999999996`, 214.953}, {273.613, 
                    215.65200000000002`}, {272.828, 215.61299999999997`}, {
                    271.875, 215.566}, {270.625, 215.805}, {269.863, 
                    215.664}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4,
                     3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, {{{220.297, 
                    228.99200000000002`}, {220.621, 228.977}, {221.512, 
                    227.824}, {221.453, 227.461}, {221.414, 
                    227.29299999999998`}, {220.5, 227.48800000000003`}, {
                    220.22299999999998`, 227.72299999999998`}, {220.016, 
                    227.89800000000002`}, {220.098, 229.}, {220.297, 
                    228.99200000000002`}}, CompressedData["
1:eJxNU1tIVFEUncSGEPGjhCIsSrL8CQsKiZCW9LCoPsrqIyYbpYF07+ldHzVI
JgZRqb3ohYjJQEgUlA7TMM6IFJaE6UQMZhIx2IMQiqiICLpnzqrpwuWwz95n
r7XXOmd+zf6tviyXy1Xq/Ga1nyAVvPlo3mVB75FLs7Lf1dn1NPezBaNDPypT
tYIdeYvvt80UfC/2tPQfFcTbZ5eMewVNn7aE5wYFJ/LvVrwdEuyKbMjNSrJu
QnBrbejr72Vq6yYFYz/r66LbFNf2TW/sy1GUjC9wNzQpjpvzCxVdXxKba1oV
a87q+1/lavveUGwsPVPurVW09n8r9uxWVBmcRkVOsvNAWbNi0dJpdwouqsW7
rZbHgOJgmVMRUKzofnIs9oJ9riuK3A1XVqcUaRmiijk796x8M8a+zxXNVx2C
rxUD5sBn4jr5tD5uv+U/yLpcxjHF3guTgVUfFefNfph4o+wfZ/4p54+o1bGP
84cUPQ7N9gjzXezTrdhu9O9Uq+tD9mljfYz7HeT7LKNHWp+EWj/P8dxLxUih
48Qp6pJkXT31GCZfUZR7J4YL7ylmONN2VJOP40+ByVcoWowuDzjHEvo5Qr+L
GE/1W1/zFQ768qoY8fLIJ0jcD7wfJ//2ycSbjI49mTite1T++ZDWoV5w2DSM
895UCV6Z+jD5VIvFCVAvn1gcH+fzi+W1TpEw+gyKvT8ete/gsVh91/MehMT6
O0VxyOBW8r30Eue/9/UH4cqIfA==
                    "]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    197.84, 210.062}, {197.71499999999997`, 209.691}, {
                    198.21099999999998`, 208.68800000000002`}, {
                    198.72299999999998`, 208.61299999999997`}, {
                    199.22299999999998`, 208.57399999999998`}, {
                    199.48000000000002`, 209.69899999999998`}, {199.316, 
                    210.062}, {199.19899999999998`, 210.33200000000002`}, {
                    197.93, 210.32800000000003`}, {197.84, 210.062}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxdU1tIVFEUnaaS6EFZfoSIlVgaRCokQ5m4zB6kVqQQUpNMNoJ7T6Q98KMk
GKwkpKzsScX0oB8NIUmT6CFSk0TEJESFDSZaQ4hCRElE1Dl37wq6cLicc9fZ
e621111QUV1SOdHlck0wy2OW26yhm5cez59FODKyuSv5CeHti/HSocmEp0We
Y/kRwt6qU6N1sSqM1uVll7cTXM5DKDaffVcI39K9TT0zCFNf36jJPU1o+dy3
oQKE1Y27Yj+ChLSsKbeSNhLm1Hc/u3aR8CiUmBH1EZK2+nMG7hJW3OmtfZij
uEUMh08xoSbXVFzGuL6m88vPMu0LxvHzu2fXnyGU31s/3T2ifW5r3WHCdns+
TjjZ8zXd20/C+yNhle9DJGUbCy6T8TKl//uhEhZ9O1l4FLH4QCz4Rpb6Oxgd
5nOondFq9XlZ+L1hHExoWzeYzNJvZkBwbhZ9aQFkRlPjglHCAYtbG5D+z9Xv
+ADC1udh5fuLxUdzv8nuY4x8y8PDsLK7Oxn7LN88hqUbOqf8C/TdwLhgcYkM
B0aqaxojw/LYo+efdE6H1d9ekvNXer+FsNzei6nfVwkP9jfPnTSmfBp0bgPK
s5kQsX6GtZ7BOzxbWfIR1fkHtf8gwaD5vl/rG/1jdk6Fqj9Mwjee/+buz/6E
xV/+t3f89Gv+tqgPpST+1Op8CjVfRxnvbN8lmi+j3+G1mLAwLni2oFrnmkqi
c5PyWar5MT46/0c2ic73msuVuu/SOc7THJp8//9//QaSPJEf
                    "]], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{197.24599999999998`, 213.016}, {
                    196.977, 212.71099999999998`}, {197.883, 
                    212.10899999999998`}, {198.062, 212.266}, {198.41, 
                    212.566}, {199.766, 214.10899999999998`}, {199.504, 
                    214.648}, {199.26999999999998`, 215.13299999999998`}, {
                    197.41, 216.184}, {197.105, 215.664}, {
                    196.54299999999998`, 214.762}, {198.859, 
                    214.35500000000002`}, {198.5, 214.09}, {
                    198.32000000000002`, 213.98800000000003`}, {197.684, 
                    213.547}, {197.24599999999998`, 213.016}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{200.586, 
                    219.785}, {200.586, 219.785}, {201.168, 
                    217.79299999999998`}, {201.641, 218.621}, {202.023, 
                    219.19899999999998`}, {200.586, 219.785}, {200.586, 
                    219.785}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4tbXgTvkDDMdLLecKNsnnO3wrsbeNE4r04EB
BASyHRwTnl5QEs90uP2zLmsPQ7ZDKJ/uprnKmQ4FtlzXF//Icug/9FUjxjzT
YZHrts9/32Q5ZEx8W2OfCzXvcZaDcPOBUwsTMx1cunOe/+bMdrikBDQpKtOh
d3qeULNCtsMMIHVgU6aDt3mnYwJQHqx/bqbDW5A73LIdwkD2Tc90UGVrnOoc
ng2xpybTIRwknp8NcWdBpoMTyJ3FUPXpmRBzSrMdJoDc553p8E0jpv9QarYD
2L+xUPnYbIi7MjMdQM6dH5btsH++lP7dCZkOViAB+2yHiyD3NkH9bwBVXwj1
L9D9YH1pUP+aZzuoG3KskQnKdHi8dPYRBZNsB5moFOv77pkQcaNsh60g9X6Z
EHtEsh1ugcz1gJrHk+2gf1eFrdEVGj4c2Q4g6oBZJoQWg7ofKb4A4TzGsw==

                    "]], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{205.92200000000003`, 224.184}, {205.57, 
                    224.012}, {204.94899999999998`, 223.066}, {
                    204.92600000000002`, 222.63299999999998`}, {204.914, 
                    222.39800000000002`}, {205.168, 222.078}, {
                    205.36700000000002`, 222.176}, {205.73399999999998`, 
                    222.359}, {206.297, 223.254}, {206.316, 223.664}, {
                    206.33200000000002`, 223.92200000000003`}, {206.137, 
                    224.29299999999998`}, {205.92200000000003`, 224.184}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{208.191, 224.434}, {207.52, 225.254}, {208.906, 
                    226.47299999999998`}, {209.52700000000002`, 
                    224.82800000000003`}, {209.906, 223.797}, {213.918, 
                    218.516}, {214.738, 216.72299999999998`}, {
                    215.32000000000002`, 215.512}, {214.71899999999997`, 
                    215.008}, {214., 215.879}, {211.969, 
                    218.47299999999998`}, {210.30100000000002`, 
                    221.70299999999997`}, {208.191, 224.434}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{212.312, 224.32000000000002`}, {
                    213.02700000000002`, 225.094}, {214.48800000000003`, 
                    226.68}, {214.094, 227.562}, {213.79299999999998`, 
                    228.324}, {212.906, 228.24599999999998`}, {212.754, 
                    228.07}, {211.88700000000003`, 227.035}, {213.371, 
                    227.29299999999998`}, {213.156, 226.941}, {
                    212.71499999999997`, 226.10899999999998`}, {
                    212.27299999999997`, 225.65200000000002`}, {212.047, 
                    224.85500000000002`}, {211.99200000000002`, 224.668}, {
                    212.184, 224.18}, {212.312, 224.32000000000002`}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{274.53499999999997`, 221.727}, {
                    274.02299999999997`, 222.14499999999998`}, {275.043, 
                    224.164}, {275.72999999999996`, 223.371}, {277.625, 
                    221.18}, {278.508, 214.062}, {279.055, 
                    208.73399999999998`}, {279.055, 208.73399999999998`}, {
                    278.203, 208.02700000000002`}, {278.195, 208.137}, {
                    278.195, 210.977}, {277.055, 219.656}, {
                    274.53499999999997`, 221.727}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJ5IGYC4m8aMf2HGHMdFrlu+/x3So4D1/XFBbbvchxc
unOe/z6Y46DK1jjVWT7XYUaeUPOBSzkOF5Ru/6xTy3XYeqJs3/xNOQ4FtkAd
HlC+XI6DuiHHGplZuQ4XQerWZTsc9zbvdLyR63Dz3Pfgx57ZDnG7PHmYXuc6
vKuxN43TynZgAIE7uQ5hfLqb5opnQ/XlQsw1garvz4WY65Xt4Jjw9IJSfq7D
vvlS+ndnZDuEg/TF5zrIRqVY35+d7RAK4jvnOrS+DtwhtzDboRBkDkOuw+Ol
s48oyGQ7FGVMfFtTDnWnE9T+kBwI7ZPt8BbkrrAcB/27KmyNW7MdgL4+tTA0
B6L/STaEBqoH++cn1H85OQ5WW4AB8D8bYm8uVP4h1Ly8HIdYkD+2Z0PCGage
HO6xUPuX5EDCNyrbAej7rD0XciDmRkDlTXIh7p4O1e8Bja8T2ZBwi86FqPuT
DbFHHOr/RKg9SPELAHwZ1xg=
                    "]], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{275.688, 209.297}, {276.03099999999995`, 
                    210.25}, {280.578, 217.883}, {281.176, 219.562}, {
                    281.47999999999996`, 220.375}, {282.789, 218.176}, {
                    281.512, 216.98800000000003`}, {280.395, 
                    215.98000000000002`}, {277.09, 210.562}, {
                    276.47299999999996`, 208.66}, {276.188, 207.805}, {
                    275.328, 208.21099999999998`}, {275.688, 209.297}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4g7HhKcXthU6vK2xN40TynY45m3e6Xik0AEk
rFSe7TA9T6j5wJNCh2qRde4PmbIdHi+dfUThRKGD/l0VtsaTWQ5a7WI3z82G
yhdlOVxQuv2zrq/QIWMi0MSzmRDzPAodVn285Ju0JdMhKsX6vr9pocNxkPia
TAcGEBApdPABchOOZkLM5yp0KAIZcDnTYYdc6+tAtkKHffOl9O/eyHTYcqJs
33yeQof9IP6fTIh9EoUOEw591Yh5nemgsAGoU7PQodCW6/riC5kOuc9/r/zo
U+iwFaTvFFQ+vtBhkeu2z39fZEL80V7ooMrWONXZPAvinhWFDnG7PHmY5mc5
wMLnIsgeYPgAAIpRiv0=
                    "]], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIxIGYCYnVDjjUyu3IdjnubdzqeyXSw3HKibN/mXIdF
rts+/z2S6bDq4yXfpAW5DlzXFxfYHst02AqUnj8v14EBBPZkOjgmPL2gND3X
AWzONIR8tcg694dNmQ5va+xN46blQug4KL8v16E4Y+LbGutMiL4yqH4rqP3l
uQ4gan5YpoNLd87z35VQ9dVQ98zIdQjn0900d30m1J5cB1W2xqnOmzMdCmyB
Li2B6t+W6aB/V4WtMTPX4ZtGTP+hk1D9FVD1lzMdjoH8PQWq/lkmRHxxrkMo
yPzHmQ4XlG7/rNsG1X830wHkDPu9uQ5WIA23ofbvy3W4ee578OOLUP8ghScA
Tmyjwg==
                    "]], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxdUksohFEUHo8skIUUeYW8IsZGEsYnC4kUitJ4JMr5uxflsfCYmkhZCHlN
iVlo2MjCa6EwSZEibCw0IRsbrChN5L/OXbl1Fvc793zn+865ye09dZ1BFosl
wIwUMwLNeB0pzW9Zl/jMtE+ffBOqCibL2pwSXbNmxkdoOagMD2yVsKhzTTh2
x1p9xRLNCt8gDEdtVTzlSoTerfWWLBLSQpwL5VbJuIP4XYaE1Zca4iTC3vng
kTtRwtUdOeatIxTumkCQrq8h9KnGfsF96wl5qu5V4NmzfJpkJzRG5GyvvAt+
P0Gs61Ew3qP13ArmbyK8KX8XAof9czHBNsKQyu/revP+59MjWJdN843r+nbt
d15gaskEOgg3KfdfjivBvAbx3C513kWYPvnItD8L9rFMaFC6/JpvVff7FqhW
cx4g9hWu5z9KiG/qKHqIljyXMe0/QSJB4TuEMKU7S7Iur+arlThS9xfCmVpg
r2S/P5rfJZGu9hJncH5TYkbpzDbY94HE3z+IMPD/P/wCd4HqJA==
                    "]], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJVIGYCYuHmA6cW6uY56N9VYWtszHSQjUqxvs+f51Cc
MfFtTXWmwyLXbZ//iuQ5+Jh3OiaEZjqA1cvmORTacl1fHJDpwAACOnkOLt05
z397ZjoARQtsnfIcHBOeXlByz3TYeqJs33yvPIe4XZ48TMWZDheVbv+s88uD
mNuSCdEXCLVfMhNCV+Y5VIusc3/olOlw3Bto8YQ8iD0xmQ690/OEmk/kObyt
sTeNs8t0eLx09hGFB3kON899D34cC3XvB4R96oYca2S+5UHc3QiVf5HnAHRF
1p4FmQ6trwN3yD3Ng6hbBVV/DuqepZkOEw591Yg5nwfxRx/U/gt5DmpsjVOd
q6HhcTDPoR+kLjkT4q51eQ5FoPBLh9q3JM8BxLXPzHQI5dPdNHdzngPImAPT
Mh24QeG1Ks/BCRReixHqwf5ZCXXf3DwIvRIa3jOg7l2UCfEHMHzA4TQj00EV
5K750PjJyYS4qz3PoQoUnmmZDiBlCZl5kHiOh5oPDG9wOALjY/XHS75JOVD/
dmVC/OGcBwmH+ZmQdGEPTQ+tUP8jpR8ATgcJtg==
                    "]], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIxIGYC4oyJb2vsRfMdZuQJNR84lekQt8uTh0k732H/
fCn9uxcyHY55m3c6qiD4QNWmcW5Q/ptMB8stJ8r2Bec7xIL0fYfKh+U76N9V
YWu8memwyHXb578h+Q7fNGL6D53NdLiodPtnXVC+w81z34Mf78x0qBZZ5/7Q
Kt+BAQROZDqE8ulummuc73ABpG5bpsM+kD0a+Q5WIHvmZzqA3aubD3FndqaD
MNDVCzWh9oVmOqiyNU51Vs93uATS75UJEQf6b8Khrxox3pkOslEp1veF8x0e
L519RCEkE+JvvnyIu/MyHfpB6sSh7unIdABbK5bvcOtnXdaeFVD/AflgczZD
+Wz5Dj7AYEo4CnUfUngCADiJmEQ=
                    "]], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{244.664, 208.434}, {244.5, 207.691}, {244.512, 
                    207.08200000000002`}, {244.512, 206.57}, {
                    244.55100000000002`, 206.16}, {245.30100000000002`, 
                    206.42600000000002`}, {245.297, 206.477}, {245.262, 
                    207.129}, {245.41, 208.02700000000002`}, {
                    245.21499999999997`, 208.281}, {245.11299999999997`, 
                    208.414}, {244.70299999999997`, 208.57}, {244.664, 
                    208.434}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJlIGYC4mPe5p2OX3IdnBKeXlD6neVQLbLO/eG5XAfZ
qBTr+9lZDnG7PHmYZkP5pxF8/bsqbI2ZUL52rsPbGnvTuHdZDjfPfQ9+HAhV
H5/lkDERKPM2B6J+K9R8pVyH2z/rsvaEZDkcB9lfkOMgA1J/HKr/YQ7EPc5Q
84Oh+juzHEDKE3ZC5Y2zHML5dDfNPZ8N4XdD7duYA7FfOsvBcsuJsn3MuQ4F
tlzXF7tkQewtyXUwAJkXm+WwFSg9/xOCD9aXnwfng+19mOew6uMl3ySgfgYQ
MMmHmw8OPyDfCmSPNNR+03yHx0tnH1GQyXIQaj5waqEpQj3Q9U8vcBXA3Qvi
KunnQ8LPCOreyflw/15QArqYDarfGcovy4eHF9g9R/Lg4QnW9zMPHt7750vp
352SB48PML07Dx5fYL53nsMtkP6MLIi/ffPg8Q02RzIPnh4ACz7tng==
                    
                    "]], FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1,
                     3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3,
                     3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGI5IGYC4q0nyvbN18t1EFnn/rBqTawDjN984NRC175Y
h+Pe5p2OOrkOXNcXF9gmxTpYbgEqUM91kNa/q8KmGevQ+jpwh5wsJp8BBAKg
+mVyHfaWTJZgyYt1eFdjbxonlesQv8uTh6k51qHAFmiyRK7DfxCYHuuQMfFt
jb0o1LyNsQ6Pl84+oiAA1X8u1kE2KsX6PneuA1C3dvuzWAdVtsapzuy5EPp3
LMSdTFD/8MRBzPub4/BNI6b/kGwcxH1fcxxu/6zL2mMS56BuyLFG5lWOw7bP
f69UBMY5TDj0VSPmf44DN8icXVD1nLkOD6uAJi6MQ3VPX5zDMZD/RHIdeqfn
CTU3xDnsmy+lf1cC6v5CqP3A8DAAchtj4xxAyhMUofrd4hyEQAGtmuvgBfKP
HlS/Ri7EvaJxDk4JTy8oaec6VL5UM+T4EwsxRxcaH48Q8QWOl+MIPiw+ATDa
x/g=
                    "]], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxlk19IVFEQxjcLoaiXjAhLrTDwbV8KqQi/xSSieiihKJqTWEJBo5FStJRh
i2wRaiZa0B81NSMlyHQrJZOltD8QGQsVISJSPURIRElE1Mw9xy7lhcPwu3fu
OfN9M2dZYcm2opmBQGCGrJWykmRdy4t9/ZVgdC7ZtW/tUYN/eIfB+rMHP/4c
dpxjkCZh9DmjdH/t5+NBg7cvJvPHHzvOMDb2MaIL5UuKwcPG1OBIJ+OAvM6Z
Z1D5aeu99Nsuf4IQ0KebMbgp+0zoDWGzhIIexuruJ0f6hwgXiudHBmKM9y+X
v/sRIxzW/+4yFtzaMBZu9XmN5tf4PCzp5acIoQL5cyq/jCBVrDKyX3AkM7mi
iCC7P2uW8zTkbSfc/PJqS6HU4+kOufwuRpUWkkXoVz03prP1hzCkOoT39G6c
m5RPII3tjBXJFfW5ewnfs3bXxNucP6VOfyuj68pE+2CEkKKFNDPmvG45tO48
2X40MR6U1S2a1UA2XnV8nWwdF53eONlz6lw9o2T7U+V40uWfZuSqvtnG5kdc
f9IMesTGxrDrT7bjYsZYWBzcaWBUz0nGHa23z9g+RZ3eFoNz8W+ikHFCbOut
dfNRz/itT9SgQ/29zMjQQSg3f/V7fh/z52WKvX4M+OzFp4wPOg/VPi/Wht53
+yWmc6bq7DAYb7v0aKmw977JWD+E07WeBnd+wvlb7d8HHdvKyH/3Q+7LH2aC
gDg=
                    "]], 
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {CompressedData["
1:eJxTTMoPSmViYGDQBGIQffPc9+DHuXkOVltOlO3rj3XQv6vC1piY5/CwSmSd
u2aswzeNmP5DkXkOBiBx3ViH/kNfNWKC8xxq7U3jdlnGOlxUuv2zzi8Pos43
1uFdDVDCK8/Bi4dJuz0Oqt49z+F14A651uJYB6HmA6cWuuY5ZE58W2PfG+sg
G5Vifd85z0GuFahiWaxD3C5PHiZnqP0HEXzRde4Pq+7EOhTYcl1fbJHn8PQC
0OJrsQ6rPl7yTTLIc/BLEoiwvAK1XwvBfwviyyH4vdPzhJpF8hxmAKkDt2Id
CkHm8eQ5rJEBOuR5rMP++VL6d1nyHNrFgCHzOdZhkeu2z38ZoHzmODi/OAPo
AXEEH+xexzgHoGkFtmxQ/6RB5QXyHP6DQHscxL/SeQ4gZ+1aGefweOnsIwoa
eQ6XQOG4Kw4SPqYIPljeAcEvAtkLDE8RUHhsiXMI49PdNNc7zyEEpHAFVH1A
nsMbUHjPjoOEHzC+gLqz9vTEOTCAQEieQ+VLNUOOGqj7QqDxkx0Hif/QPAcg
OdXZG8EHmyeN4EuDGB9jHVRB6sKh4Xkp1mErMBnNj0LEn495p2NCLNT8zbEO
lqB0lpznEA9y1+JYB/T0BwCaCyN9
                    "], {{241.98800000000003`, 
                    120.91400000000002`}, {241.92200000000003`, 121.32}, {
                    241.71099999999998`, 121.523}, {241.344, 121.523}, {
                    241.18800000000002`, 121.523}, {241.04299999999998`, 
                    121.48}, {240.914, 121.395}, {240.781, 121.309}, {
                    240.71499999999997`, 121.23400000000001`}, {
                    240.71499999999997`, 121.16799999999999`}, {
                    240.71499999999997`, 120.953}, {240.97299999999998`, 
                    120.848}, {241.484, 120.848}, {241.648, 120.848}, {
                    241.816, 120.871}, {241.98800000000003`, 
                    120.91400000000002`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJVIGYC4nA+3U1z+fMdtn3+e6ViZayD/l0VtkbOfIfb
P+uy9ujEOmRMfFtj/zfPYW/JZAkWu1gHl+6c578/5jkscgXqiIl1KAIpeJ7n
UGNvGrerM9bhDkjfnTyH3ul5Qs07Yh2+acT0H7qY5zADyD3wK9Zhy4myffOP
QeUD4iDm74Wa/y/Wwce80zFha57DwyqRde4HYx1U2RqnOq+H6p8V69D6OnCH
3Mo8B6Dsw6oSqPxiqPpIqHvnQvmeUP7MPAcvHibtdqD7q0EaJ+U5bJr7fvkx
41gHdUOONTJdeQ4hj5fOPqIR61AM0tCd58AAAgtiHUDOPDAtz0EeZPG+WIet
IPfPy3NoPnBqoes1hP2eIPOfQcNnJdS+f1DzgO7nvr64wFYqzkE2KsX6/mYo
3yrO4bg30MM78hwuKQFDPArK35MHiYdWqPr9eQ5vgN5u3R3n4JTw9ILSaQQf
7P5LeRB/AtXvmy+lf/cG1HygeRMOfdWIuY+wDxy+T/Mc/JMEIixl4hz6QB58
kweJf8Y4hwJbruuLv+Q5XAS551UsRN8vqP5bUP8yQ9PHkVgH9PQDAPNPDX8=

                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[0.74902, 0., 0.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}}, {{0, 2, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 
                    0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}}, {{0, 2, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}}, {{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{1, 4,
                     3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}}}, {CompressedData["
1:eJxTTMoPSmViYGBQAWIQnfv898qPRQUOLt05z38LRjq0vg7cIVde4ODFw6Td
/i/CgQEEqgocVNgapzq/jnBwf1glsq66wKF3ep5Q840IB2/zTseE2gKHvSWT
JViORTgc+qoR019X4AAypnV1hEPGxLc19vUFDtL6d1XYOqHmlUHVt0H5QPsX
um77/HdJhMPVipdqhnkFDpkgfXsjHB74A23KKnCQBznsXISDwoaijInpBQ6V
QGUcdyIc4nZ58jAlFzg8u6B0++e7CIctJ8r2zY8pcLAEMdgjHY6BHBgGda9C
JETcH8q3gPrXs8DBCiweCbHPqcChGOTw9EgHPt1Nc99bFjjMACo/0BQJsV+/
wAHo2isVC6Hy2gUOIuuAIbMm0kG4+cCphZoFDn5JAhGWWyIh7tEocAh5vHT2
kR2RDuX75kvpq0PN3x/p8OmSb5KAWoHDIpD/z0DlVaHh9TDSARiKrwNVoOHz
Bep+5QIHkDWufFEQ9yhD7dOJgrjHGereQ5GQ8AwocLgEDJ66WZEOO0HmRRU4
PAWFVxmUn1Tg8B8EwiMdQMJ1GQUOx0Hh5gB1Xx7UPZqRDujpBQAOoQIS
                    
                    "], {{256., 104.609}, {255.879, 103.121}, {
                    253.49200000000002`, 103.184}, {253.672, 104.703}, {256., 
                    104.609}}, CompressedData["
1:eJxTTMoPSmViYGBQBmIQ/bbG3jQupcDBP0kgwrImwsGW6/riAs4CB4O7KmyN
vBEO3uadjgkf8x2cu3Oe/86McIhKsb7v717gANK262SEg+WWE2X7nKHq70Y4
LHLd9vmvQ4EDkDfV+XWEw2QJljA++wKH+F2ePEyfIxwYQMCmwGGNDNCk/xEO
h75qxPRbFDiEPF46+whHpAPIuPkmBQ7FGRPf1vBHOoDdB+TvLQGa9C/C4TBI
vVGBg3zr68Ad7yIcyvfNl9LXL3AA2nql4mGEg1a72M1z2gUOfiD/XIlw0Ae5
S73AAeQt21MRDlcrXqoZKhU4bJr7fvmxw1D90gUOqiD37obKixQ4cIPU74LK
8xY4HAcFxIEIh2Mgmq3AAegb7fZjEQ4gZ8gxFjjMyBNqPnApwiGMT3fT3N/5
Drd/1mXteRLh4AIKN2D4gf0D9O8dkPibfEh4KEdCwuMNVN4/0kENHG75EPsa
Ih1unvse/BioHxyucyIdPl3yTRJgKID4a2kkxH2c0PDbEOkg3Hzg1EJRqPuW
RTqAjLVXLXB4ekHp9s+2SIdqkXXuD2Hhmw7lA+OrdzrQAw5Q9Z7Q8BKChj9S
+gAAf3fwHg==
                    "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQfeirRky/XIGDFw+TdrtdpMNxb/NOR6kCh+YDpxa6
ukU6dDgmPL0gVuAQu8uTh8k70uEYSF6kwGGR67bPf30iHay2nCjbJ1jg8OyC
0u2ffpEOtlzXFxfwI/hRKdb3/XkLHPySBCIsgeqXzT6isIGrwOFhlcg6d89I
h2og9ZCjwEGVrXGqs3OkgwxIA3uBwyWg9jqrSIec579XfmQrcKi1N43bZRjp
0Po6cIccUB5o+5UKzUgHkPXzOaDmKUY6KGwoypjIWeBQ+VLNkEMm0qF833wp
fe4Ch97peULNEpEOIOcnAN3zFOQ+sUgHd5BGoHv176qwNYpGOny65JskIAT1
vxjUfBGofZJQvhjC/Lc1QIdJFEDCQT7SQbtd7OY5yQKHjIlAGVWofdLQ8NOO
dMgF+UcG6l/jSAf08AcA2MWlpw==
                    "], {{251.82000000000002`, 
                    102.141}, {251.47299999999998`, 100.664}, {249.105, 
                    100.883}, {249.465, 102.371}, {251.82000000000002`, 
                    102.141}}, CompressedData["
1:eJxNU2tIFGEUXZaQkojQCiGzEsP+SPkjw0Q7VtLDXqY4N5PNVrMU624WJibC
IhISIZFREGIW0o8syuxJxaJhEVH2kLRVwiRDJUIqRULsuzMXbGCYGe537zn3
nDPLvbznoNvlcqWYW54Xj4ZVBxb5cFZeIggdf1bm1rl9eHrifMSsEIJdH2e0
ROYUJE1bqBnNeBg1zCg696Ny/ZSFwebLz5f1Mda1vSx7Zuqped+6ot8y3kUH
J6vcBM/jrXPdHfodSsieF9fa8IDRmb62NtXgXU27/2vq9kz/YZnbzBCYmlHL
4VXPzpyg1msZLrm6LNwYe7/DW6n8XlgIrw68ajrCTl/AcubvZqwI8V/YeNdy
9knQ+eGEunazcCYjy16EHJ5eRqLwiSX0TVYVPylhrO6PCfHHEUI/XfMllzI2
nSn5/jeeILBfTjLM1sHJBMKpBbc2D1QxjttEdf5pRozgpxNi42e3RJp6lAiZ
TRCYxjLGUvn2qB4+xn7ZN58cnCLGtFyHCEsEL58xUGGAigj3pN+j+IWEY8mG
YS47/hWq/vsYO73zKbGAMG7sbd/LMCgfyw+QoxMxhqTf4JcKb4txSXTKUX7Z
jCbhlaX8t2l/BsEsucaTwtgl8yvJ8TFJ89Gg5zcwgqJjm+JtUT6vyfHR4Nu8
+pW/2X/xKiP4MKH3zUTmYK32/yZH10b1e4Igx/x39PyY8jd5s30e0fMmjwuN
LRV9hDDJRzdDHmmdqneP+vlI+X5WPjcJEtO8Xs3HFeXfo/zrCdul3q39ft2n
i52cFJOTow8z/tgx61E9jR92TPoZEpuKAtXzK6O14ef1TuO/2DwwNFO38zWi
/M08O+9zfA6/cv1f//uf/wFpEcg1
                    "], CompressedData["
1:eJxTTMoPSmViYGCQB2IQvfrjJd+knHwHLx4m7fZ94Q6LXLd9/uuS78B1fXGB
7aZwh7hdnjxM+vkOKmyNU51XQ+Vl8h1cunOe/94Y7lAtss79IV++gydI/7Fw
B1WQuv95Dnd+1mXtuRPuINx84NTCj3kQebYIiLnP8hw2zX2//JhzBET/JSh/
dYTDRaXbP+vO5UHMORzh0Ds9T6j5RJ7DQpC9VyIg9h/Ig4g/iHDwMe90TNib
57C3ZLIEy7MIB3VDjjUy2/IcDO4CXfw2AuL+1VD7v0U4rAL5d0eew5vAHXKt
0ZEOsSD543kOr0F870iIfqB7LoHcYRUJ8efNPAdpfaCBmpEOTglPLyg9znPw
SxKIsBSJhJj/Os8h5PHS2Ud+RDh4g9wD8++1CIcZQGce+JcHCd++CIfjIAUc
+Q6bQf6NjnAAGdsomO/wsAoYEJYRDu9q7E3jpPId1shEpVirQ+UV8yH+lYDy
NfMh5gpBw8soHyIuGuFw89z34MeR0PhRjHBAj18A0DPWew==
                    "], {{
                    246.125, 100.62899999999999`}, {245.33200000000002`, 
                    99.23}, {243.08200000000002`, 99.75}, {243.883, 101.16}, {
                    246.125, 100.62899999999999`}}, {{247.434, 94.293}, {
                    241.824, 93.785}, {241.484, 95.367}, {246.19899999999998`,
                     95.793}, {246.07399999999998`, 96.051}, {245.906, 
                    96.262}, {245.695, 96.43}, {245.586, 96.523}, {245.336, 
                    96.67999999999999}, {244.95700000000002`, 96.895}, {
                    245.375, 98.34400000000001}, {245.895, 
                    98.05499999999999}, {246.27299999999997`, 97.738}, {
                    246.512, 97.395}, {246.758, 97.04700000000001}, {
                    246.95700000000002`, 96.52}, {247.10899999999998`, 
                    95.812}, {247.434, 94.293}}, CompressedData["
1:eJxFVAlIlUEQFotXeUTlI8yreiVaURqaoqKOmpSGRmXsEmpeRZa7XlHiBVES
YgcRURQiFhGUCEmFSIdE2AGFVGgm9hLNihC7y8xsd2d878HjZ5jZmW++b2aW
5hVv3eXq4uKSq/76+zM48+T9LAn947V7bxcwGLp84cGSjRIOdz5pTt7NYLQ6
fl12hIRb3yZfVhQyeLgpsj4hWEKqh+uqo5JB0NrZLX4+EgIth84klZPfQ8I5
ueBwZyXD7z8B6XnzeNQRBok577pt34TDf7fJJ2Tgg8D6+xn47yiIsdsFrG8o
ej9RyiBBx/cKKN9zarS6mEHfs1/bhh4LWFz3aUu7qn/1y/O0vHYB0TceHbir
/Dosvl7Azo4UD1eF55r2Vwtoaxy70qVst95LJbFlAjJ0oxWEZx/VO0T18wUs
1/00MEB+BLjrd+cZlMSqDFzASLetf7yVgYYRkEb9KL/pAwRYWzcMVh5jyEuY
s/8ojTNIQKHGWcMwrw/lV3zcVO4mN4HvqqifwSK4s/+098xast8VYb5hip8r
UJ9BBlW6sE2Ai/69ZfgNF6jnCOmVSHi+E38Z5Ldw1Dub+FvGkY+dAnlL5Zhf
8WdwJHPMV0b9xHLQ8ueUUv5wDqWarxIBSZrfFZx0Ir0Wc9S3mOKtHPuRAnma
RfmVna3xTBDfKr+Zs88MyjSQgwJa/BTQ9zQfNdTPGwYhA0rJOuKnj/o/IcBX
O/pI3+sCUvQ89xC/ar6ak/ULin8toEvXe8Xg+Fkl9LCTX4PnC+X/yEDDsP8S
sFn385fBRZ3nN7335ph/nPAFEJ9/BOg0dYpvo7Palyn9CyL+pwTosp0rOWyf
u7qtcQbt3xqO9edInO8wjvNppf2N43BP75eV9jfKaRt9VbyZV2VP559+b+bZ
xrFfZYdqHv05zouyjR6+hM9Lov6eHLx04fnSoZexPSXuwzBz5DP7bKf99KP4
fuIzUKKevaTnarovL+geRErUv5thPyBRx6ekXwL130P7Fy8d+2HqxFD+MQZ6
zJoiCP8k7Xe4xHmwEF/KNvfAnfheJ6FGrUnHfNJLvQ/QjoUcTt7/EZyp8Jl7
sojjPEQSfl+a52iJ90Ppb/YqTiLuQOKbS7xv6VQvi2ylp+k7R+L8hXLkJ1c6
9tXMR75EXAqPuecFZFsIXz7p+3X6vjnv/391iJxl
                    "], {{234.414, 
                    100.12899999999999`}, {232.996, 99.12499999999999}, {
                    231.93, 99.785}, {230.879, 99.}, {229.47299999999998`, 
                    99.848}, {230.812, 100.80499999999999`}, {
                    231.94899999999998`, 100.16799999999999`}, {
                    233.04299999999998`, 100.96900000000001`}, {234.414, 
                    100.12899999999999`}}, {{232.18800000000002`, 94.02}, {
                    226.695, 94.918}, {227.297, 96.46900000000001}, {231.914, 
                    95.71100000000001}, {231.94899999999998`, 95.98}, {
                    231.918, 96.21900000000001}, {231.816, 96.426}, {231.766, 
                    96.535}, {231.629, 96.742}, {231.40200000000002`, 
                    97.035}, {232.629, 98.277}, {232.945, 97.883}, {
                    233.10899999999998`, 97.49600000000001}, {
                    233.13299999999998`, 97.117}, {233.156, 96.738}, {233.035,
                     96.199}, {232.766, 95.504}, {232.18800000000002`, 
                    94.02}}, CompressedData["
1:eJxTTMoPSmViYGCQB2IQ7dKd8/x3YY7DGpmoFOv14Q4MIOCT47Dt898rFQfD
HapE1rk/NMtxeB24Q671dLjDjDyh5gNaOQ7NB04tdL0X7gDSdl89x+EhSOHP
cIdVHy/5JqlAzROPcHBKeHpBSTvHYdPc98uPOUdAzLfJcZBvBZpYF+Fw62dd
1p6IHIf4XZ48TI8jHFTZGqc6x+c41Nqbxu36GeFw89z34MeJOQ63Qep4Ih0K
bbmuL07IcdgMMk86EmJeAlS/cqTDIlegy2NyHLx4mLTb9SIh7gvPcdhbMlmC
xS7S4W0N0OC+HIf/INAe6VCUMfFtzeQch+Pe5p2OBZEO+ndVgC7IcQCHS2Qk
xD9Tchy+acT0H3KNhPhnMtQ8oPlg9/VC3SsIVd+S49A7HRhQHyIgdEGOQyzI
fasjHC4qAX2SBDW/MsJhwqGvGjHROQ5yoPAIi3CIA6mLhoanY4TD1hNl++ZH
5UD8aRABCf+4HIg7VSMc+kH606HqFSMcfIDeSAC659kFoEV8EQ7o8QsA9SzW
8A==
                    "], {{224.75, 100.67999999999999`}, {222.824, 
                    99.867}, {221.5, 101.15599999999999`}, {223.445, 
                    101.977}, {224.75, 100.67999999999999`}}, CompressedData["

1:eJxNUwtIk1EUHiOiZIXUEKtl7wfUUpMQNdtXJLWeVMa9SRlISe38lD3psYyI
MMseEpgRMpYEEiL0spBaElJRITmCitAaChllKFJS4ere/54eg3E599xzzvc4
/6SinWu3Oh0OR7b66/PbzI3nHg4S3n4vDdz7LHAlr7F/sJewzOWcVdYqcK0v
urKoi5B168n+yB0Bh/69JuR3Xr3cUieQre+fEY745hU2XRK4v/dC8pAI4fHy
zPKF5wWqd4w63txAcDcsiR2qEBAjvTdqQlx/UmBXbsKr2gpC22SF4JRAavvU
ocf2cb9KYe4L+X21MH2XEsqS3rQO1AoUNvldzgzCZn3eFFC36zqHE85cVINf
CKjuJblfAqa+l+vfB7CqKFFmuaXJRwPYs62yJ5gpDV4V22eBxOLT1oefsQAm
nPi05m6pxGFNRPXbrp77arg+HoBf69UojT6JBD2++anEes13CmGcJhaTmJE+
rN6ziBDVvH5Iox8RUnT/pA3QR4rib+sYlyjR+uQTwtqXLp63gAyuNmn4pnO+
RcL2c9ofvxiPh/Wok8ZPN8+rkritnoUSyPA/KqFlmuji+cUSkdDY1PZkQlD7
4ed5qr89xysxvmBLzrsc9tfN+hXw/sQFdFvfQfavWxj+Vdy/g/PXCUqscJ6K
z2qcz8no3cH708HzPwqDr5uMbr/Y7x5Cmt6bEcy/j7Ba++th/fvJ+D2b8185
P19ik96bAUK9RxERErs1IBXb30GQ4wzL4H30L7b3M8z6zbWgXr88UC7xQOuV
Zv2tt/F5LcOvmP2fbhk8KyRG68QYy/Cdw/j++x5/A+LsplY=
                    
                    "]}]}}}}}}}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 480.}, {0., 320.}}], ",", 
           GraphicsBox[{{{
               {Thickness[0.0010416666666666667`], {{{
                   {FaceForm[{RGBColor[0., 0.596078, 0.764706], Opacity[1.]}],
                     FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    0., 0.}, {0., 480.}, {960., 480.}, {960., 0.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.8784310000000001, 0., 0.20392200000000002`], Opacity[
                    1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{0., 320.}, {960., 320.}, {960., 160.}, {0., 
                    160.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0., 0.6823529999999999, 0.39607800000000004`], Opacity[
                    1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{0., 160.}, {960., 160.}, {960., 0.}, {0., 
                    0.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{536.8009999999999, 240.}, {536.8009999999999, 
                    200.23399999999998`}, {504.566, 168.}, {464.801, 168.}, {
                    425.03499999999997`, 168.}, {392.801, 
                    200.23399999999998`}, {392.801, 240.}, {392.801, 
                    279.76599999999996`}, {425.03499999999997`, 312.}, {
                    464.801, 312.}, {504.566, 312.}, {536.8009999999999, 
                    279.76599999999996`}, {536.8009999999999, 240.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.8784310000000001, 0., 0.20392200000000002`], Opacity[
                    1.]}], FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {
                    1, 3, 3}}}, {{{540., 240.}, {540., 206.863}, {513.137, 
                    180.}, {480., 180.}, {446.863, 180.}, {420., 206.863}, {
                    420., 240.}, {420., 273.137}, {446.863, 300.}, {480., 
                    300.}, {513.137, 300.}, {540., 273.137}, {540., 
                    240.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, {{{573.105, 211.73399999999998`}, {
                    552.4649999999999, 221.52700000000002`}, {544.828, 
                    200.}, {537.16, 221.516}, {516.535, 211.695}, {526.328, 
                    232.33200000000002`}, {504.801, 239.97299999999998`}, {
                    526.3159999999999, 247.641}, {516.496, 
                    268.26599999999996`}, {537.133, 258.47299999999996`}, {
                    544.7730000000001, 280.}, {552.4409999999999, 258.484}, {
                    573.0619999999999, 268.305}, {563.2730000000001, 
                    247.668}, {584.8009999999999, 240.02700000000002`}, {
                    563.2810000000001, 232.359}}}]}}}}}}}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 960.}, {0., 480.}}], ",", 
           GraphicsBox[{{{
               {Thickness[0.0025], {{{
                   {FaceForm[{RGBColor[
                    0., 0.41568600000000006`, 0.30588200000000004`], Opacity[
                    1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{0., 0.}, {0., 240.}, {400., 240.}, {400., 
                    0.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.956863, 0.16470600000000002`, 0.254902], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{260., 120.}, {260., 75.816}, {224.184, 40.}, {
                    180., 40.}, {135.816, 40.}, {100., 75.816}, {100., 
                    120.}, {100., 164.184}, {135.816, 200.}, {180., 200.}, {
                    224.184, 200.}, {260., 164.184}, {260., 120.}}}]}}}}}}}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 400.}, {0., 240.}}], ",", 
           GraphicsBox[{{{
               {Thickness[0.00125], {{{
                   {FaceForm[{RGBColor[
                    0., 0.12941200000000003`, 0.6784309999999999], Opacity[
                    1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     1.}, {0., 400.999847}, {799.999634, 400.999847}, {
                    799.999634, 1.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.109804, 0.541176, 0.25882400000000005`], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{0., 401.}, {
                    800., 1.}, {799.543, 400.703}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 0.776471, 0.223529], Opacity[1.]}],
                     FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4mqRde4PJ9Q6xO7y5GFSz3SA8YWbD5xaeDLN
YYdc6+tAkVoHBhAoSHE45m3e6WhXA+EfSYLwM6ohfIlEB1uu64sLrKscZuQJ
NR+QS3CYDqJ5KuH8T5d8kwTulcP5GRPf1thvLIPrB/Nvl8LNB/NZS+H2bzlR
tm9+RwncfTA+zP0w/qqPQItasuH6Xbpznv++mws3H8zvzIfbv8h12+e/swrg
7gvl0900V7wQ7n4YH+Y/GB/mf5h+WPjAzIeFH8x+WPjC3Ice/gBATahi
                    
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.109804, 0.541176, 0.25882400000000005`], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJyFVWtsFFUUXleigIKI1lhSNisSpdiKqGiEVE6NxhLU+qIxtUC72e2dzu5M
iTiPvTMpj1IJNg2oKEZEYgkxPNT1UVtIrYVUKGh00ZiKpWmhaSoxBYFo0xSD
c+e7LSb7w00m2TP33nO+7zvfuXNHpPr52LWBQOAa73G9JxiQv0dNelefXtt+
r0Z1fzzXEmowaV7P7OvWLUuQc+snT56eYFHFQHpW91mVSqOLeotjFv02UqO2
FsWpt7hhm56y6OjShzcVerG/3mXRLbXtxz8siCPPaRmfVEkbHN1z4U0bdXao
ZLXtnDHv6yTq3B+nw3/NKdtscnq8PjE4mqVlxEdEnddkfLNGmwrLB9JrOfIf
0+iejbed/GEdp7+9Y4ezddRvluuTdOxv4bTwy06z7bxGLSEPSTsnX4dOjRIC
Xxunu+dP3J+zV6PGJ7669E8nB949Gk3J/3zH+V5OAi5v0YD/Cgf+kA7+2Q7N
FH9W6uSpNlITdihL7Hd18MlxoPd7OviEZNymA0eejIPV0PcZme+SDtzLHNp7
4aenI2l5vswBzwM6DbmLF6zw4kfEvo904Io49I0Hs2eLDn3qHOyL6OhHhwO9
GnTUOXY1vuiVmZZ2aJvAc0Snc+LcGYdE2fJDmbGv84hDJVM9ob6TfP906BXl
jSH3qE5zRf0rMm7W6YDQ/6IDHhs08A+5JODvNDXqE/xnuCRk7vk1gfUcF32Z
kxjPt/zgkhuDw/Hx2Of/RRw6TnTh34o4nRD9eN2lFWL/yjj8UOYCd3acdm/v
CKcedHHunEpv3T6hZOpyF3p9oIJP2KUt4s8a6edVUt/vq0jQWlws+/XA/8e+
r+505Nwp434Yi30cAYfKBf6ZChVM7tq1qpvjfaki+8Lhh9kK/NLKMY99DPtS
HP1Zwug+4ZNvOfiPVkKvHzkJGWZtrqRf7LN3ze+Q+V6sBN5m6fffYzRd6LSP
o3/Xx6DPGk5PifwDUfBKchIwC96JYj5icl4Lo+BXI+ezKUJNos/q1djHM5ik
4Rf6d29PReDr2iTliLyDcr04iXm6HAHP9Unw+TSK/ulJ6JdfOR6P8fHnpyJJ
H4uE9QxxnU2rfaIM/KM2/KYw4C2yqVvcd68y5HvIBr9GhvnKs9GfJob5mmLT
PlGvlVG/OBC00YfjDHr1W9D1BKNwylPyZwv8DzH46ZS8Lz9jmI+DFvK9z6BX
xKL9Av9GBj0WyXwLlIzYr08W+lKtyLkysZ6rQKdJJvaVKeB/ykC/cuX+Thm/
LevtMqDnBumvRgP3XAnD/ccMeX8y+O5lA3i7GObtJQM8SmX+rQb03ZoZ+/Pe
YcBvXRJfn4E5PqNAz2ED/pxWhfdBE31ZX4X5uDx2Xs5blok5yFfR/1wT/q9W
kb/IhK+eVeX9YKI/mrwPVpv0mNhfr+JecE34Z2kc3wcmz6/NjP15uMkE3nAC
7yebdIPw09wE9BoywDst77s8+X1eKO/H/3yv/wVdD4SX
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[1., 0.776471, 0.223529], Opacity[1.]}],
                     FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxlVGtsFFUUrrUxvkB5GSoqj/BDwKYmapDK40PFitCoJQXUQkptl7Ld7kx3
trsNVmpn7s6gRolp2hqNJVYRIaQBbCuJBRvF1pBo5OGDYIMIBglQsNWA6BLv
2W9oE3eTuzNn7r3nfI9z79RSo7D8+oyMjOv0WK1Hph4t4bFOz2ACz5c9cvzp
3Ci+/Ove4k0/JfCFPK9GsWqTfhtQaFvUNZTsjiFDfvMVGidmLR99NI7mx14P
nR6nMFC34KHVY2vx3bRjf2+47ODmHz8w512Mw7vj6LeXkg7ztY6sXzL71YUl
RXEcLii9feV0hZ2RirfOZ8XxguDIU5jT8XVs32cx7J+iZ+DXf82vv1ThpfHt
+ScqYgh2RxsnFiqc3PLu/ikPp8epessU952qgc7+RssKBZne+XMN5gnQNxVG
5+x+78KLNXhb9GhSmCqAktG0+NOh5JHaToUi2eBEcX//9BsaDip0aribZ0bJ
98YEBP7mXgvFol++H9da+Er4ZCeIx41As65bMCmBlA9ZI3GK7+5qrruqON9d
TT1OKerZW828dyrE9X/uHAv3aRpbCx38ommG8yx0Cd42G0+eWD++fYuFucJ/
lY1/t/1xqKDDog/FNg6KbxELo0SHiE09CiwMHtIGDdis90SEeq5x2C+N1fTr
isM8SXPY31S9fpP65Pj67jXpS75if7Sa3FemuK7KpI4NPt+5JpokX6u//xaT
OH5V2K7hl1YYxPe7gshc3BcejkWO/j1h3C1AzyiskARGFfXcdy0OUbddComz
z+6556YQ97/j98uOIPukUsESY4z0OOX3oE0fYgH6m2Njx126sFHO/E31WPOb
PhnbAuxbux5LhffeAGZJglH1OC/npzkwvF67Eex+MEA8gVeQK/qUl1OHkw3s
k+wy5ily2C9HAuz/dgclUu+btZgvQp9x0CdC163FR4J/hs93TAXrNSrmmbCO
/s1IsN5zQfq8KIHH9ed/Xg6SZ0sC45yeA+/nVBLfBhePSsGhStb/xOW5afP1
vOjS764QLmztXTI712P8Q4j9+YBHvT+uwuJbM2d5+R6WC9FjVRizUt8EZR75
dPrz6z1cWqY7qSSMjQv1zHY/nx2mP20e5Dqp60uPU/dTs1/vGYO813nsy40G
8S/2588ZeErqZXvIE+IT/P687PLemGziQ1O/fe/y+xUDYvvxAy4E1rTTBvX8
3OV9cdigfx0u6/Wkx5PFmAaXuPpH4mt4Uutvc3leM01+n+SS558R/P8+/w+D
e6zi
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.109804, 0.541176, 0.25882400000000005`], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{735.695, 245.79299999999998`}, {735.309, 
                    244.707}, {733.3549999999999, 244.21899999999997`}, {
                    731.602, 244.76899999999998`}, {729.8439999999999, 
                    245.324}, {728.602, 246.812}, {728.992, 247.894}, {
                    729.379, 248.98000000000002`}, {731.3319999999999, 
                    249.469}, {733.09, 248.914}, {734.8439999999999, 
                    248.363}, {736.086, 246.875}, {735.695, 
                    245.79299999999998`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    150.523, 248.25}, {140.324, 257.79699999999997`}, {130., 
                    248.379}, {131.105, 262.308}, {117.309, 264.508}, {
                    128.88700000000003`, 272.328}, {122.004, 
                    284.48799999999994`}, {135.336, 280.312}, {
                    140.55100000000002`, 293.277}, {145.598, 280.246}, {
                    158.98800000000003`, 284.25}, {151.945, 272.18}, {
                    163.42600000000002`, 264.21099999999996`}, {149.598, 
                    262.191}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{186.71099999999998`, 132.57}, {
                    175.71099999999998`, 139.91}, {164.996, 132.172}, {
                    168.766, 144.63299999999998`}, {157.90200000000002`, 
                    152.16}, {171.23, 152.523}, {175.227, 164.914}, {
                    179.69899999999998`, 152.676}, {193.035, 152.805}, {
                    182.469, 144.883}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    237.266, 180.226}, {227.066, 189.777}, {216.742, 
                    180.359}, {217.848, 194.289}, {204.05100000000002`, 
                    196.48800000000003`}, {215.629, 204.30800000000002`}, {
                    208.74599999999998`, 216.469}, {222.078, 212.289}, {
                    227.29299999999998`, 225.254}, {232.34, 
                    212.22299999999998`}, {245.727, 216.23}, {
                    238.68800000000002`, 204.16}, {250.168, 196.191}, {236.34,
                     194.168}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    60.870999999999995`, 149.672}, {50.672000000000004`, 
                    159.21899999999997`}, {40.348, 149.80100000000002`}, {
                    41.452999999999996`, 163.73}, {27.656000000000002`, 
                    165.93}, {39.234, 173.75}, {32.352, 185.91}, {45.684, 
                    181.73399999999998`}, {50.898, 194.695}, {55.945, 
                    181.668}, {69.332, 185.672}, {62.293000000000006`, 
                    173.601}, {73.773, 165.63299999999998`}, {59.945, 
                    163.61299999999997`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    152.54299999999998`, 33.}, {142.34, 
                    42.550999999999995`}, {132.02, 33.133}, {133.125, 
                    47.062000000000005`}, {119.324, 49.26200000000001}, {
                    130.906, 57.082}, {124.02, 69.242}, {137.35500000000002`, 
                    65.062}, {142.57, 78.027}, {147.617, 64.99600000000001}, {
                    161.004, 69.004}, {153.965, 56.933}, {165.441, 48.965}, {
                    151.617, 46.940999999999995`}}}]}}}}}}}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 800.}, {0., 401.}}], ",", 
           GraphicsBox[{{{
               {Thickness[0.0020833333333333333`], {{{
                   {FaceForm[{RGBColor[0., 0.686275, 0.7921569999999999], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 240.}, {480., 240.}, {480., 0.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.996078, 0.772549, 0.047058800000000005`], Opacity[1.]}],
                     FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}}}, CompressedData["
1:eJxlVg1MlVUYvhKhY8hMjQiwAcMRukZazhrce9/vfB8jVNJqIRTdEd3vrxUI
knPK2hwRmiEaNnNUpMYKctaaojMiBmIg2SxLc8kcMn+WWYmTZobrnPO+9zsz
2O7Ys3Pu+z7neZ73nJtWXvm0eZfP55vCP1v5J4p/HtuklV1YkQufXfuxsDzX
hAj+9ebrL3d9FIZwzrnljSsB8YowFD++f2BNPPNwicAhw8MHr0/8tHZnHtRf
eerQA+0K787rvD6RYnr4wMCa7taQCZ0Cu3mQ8hzv1GBC446KmXV/GbBfrB+d
jH3iL1WD2NN7Vvl7bYh/6MsP/swPwol0zuBNB7JKm3pvXA5A6HBBXFSrg/+H
ArB+9r78kcMKC9rdo/9bT3fB2PzKpVslgPWKXFx/XsO+xS6ew2CQPZwRs6HE
hYaEM9//reuI0xSeVddzbNeI4+HRtpYjqdsdePXSrfZruxmuVzlwbJcoqHm4
78aDpU0LFW4/unTxphHwzhfBmQum7U3pUFjy7HPgU4Hv0WCcl+k97sCSuKj5
DUUKS/7RzMOS30kNWNmFE+nNk/EPou88hv7scGCRaFTN4Oua5sTofaT3E3Se
QQfeP5L6RfVGhv5H6vcxWLaYB+tnOt8Yg/e4rT3nHfiHx6amj+r94cCQ0KOR
gbC9Z1zVl3xvqv6rnW1Xa5Nd+J23qc9hMEfwm++iD/0a+rnQhYAIyrAGnMUz
o3NdrM+x9Pl+F/ue0pBPvAtTN7yrb07RsB6vL333AawT9WIUlvw6HQ9rQi/b
ge2J0UXxw4B+ZzjIbz2Db1qTsocfJX0SSZ8sBwqEPxc19GWGg/3Pashr3Mb5
yyT9Jmyv3tXa4KLQ7clY5mApw3qX6ftTGc7PKRv9jGVQ5efC7KX1lVT/gI3z
/CGDmcLPfhuShaBTdNjay437yka+FkNcacO9XJZ1GTrqERPpl0d+WpQ/A/VP
s0kvA/0sUVj6tk1huT+P9BowQMRaCyscma8IlvOQQP6VGuj/ky6IayK2Qcfz
vabw3Bi+cTXN6ywDzor7q9bF+62C6m1xaV6Jbxv5X6bj/i4X9XxLg28Fvy7K
VyNAtcjnHhfE8RPOBHCeWlzgaW9ONPy4/pKLeTmei3zyKY9Fubif51nIO7si
B/PS73j7xdeDLuHCAN6/0Q7W/Zz8z7Dwfh3U6Twm6nw3na/CxDnIMpD/MoVl
nUyFJZ+hMOp3mqG+HYTvUzhJNFig3bmeD5Q/hSX/6aaH5bxlm3g/vEPvjWHC
RXHx3VZY+hHF7sRjGjwszjWd9nfTPP8Wxvy+SPP3b5jWKe9zTNTpY7pPgvTe
+HT8PjNhjD+LM4p1rF9o4nvziU55NPF+cnTUb62J85hM+WpQ9SPv2zyx/xfi
02VifpYwaBLzdFLxl3qcM0HYXn9Fg26x/5CJeZ/GMIdvK30i2C8fRoV14V9B
EJ4VxOtMzOPOgMdf5mtLwMvHILcpqTKA+x+xJmHUI4DzUGXh/L9B/VZZyCdE
frxg4TzGaZjfNgv9Kie/hyz0/6Af+/daqFdNAOt9Z+F/COL9dl5h9Nv2sHzP
822aEz90iN8zG21vXqS/LTb2Xa5+7/wH58Ld4w==
                    "]], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{266.469, 175.172}, {268.355, 174.824}, {
                    269.29699999999997`, 175.859}, {269.578, 
                    177.26999999999998`}, {269.949, 179.15200000000002`}, {
                    269.14500000000004`, 188.63299999999998`}, {
                    269.14500000000004`, 188.63299999999998`}, {
                    269.14500000000004`, 188.63299999999998`}, {
                    264.77299999999997`, 180.184}, {264.39799999999997`, 
                    178.30100000000002`}, {264.121, 176.88700000000003`}, {
                    264.58599999999996`, 175.547}, {266.469, 175.172}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{273.348, 173.086}, {275.133, 172.375}, {276.254, 
                    173.207}, {276.805, 174.535}, {277.539, 176.309}, {
                    278.60200000000003`, 185.762}, {278.60200000000003`, 
                    185.762}, {278.60200000000003`, 185.762}, {
                    272.66400000000004`, 178.32800000000003`}, {
                    271.92999999999995`, 176.555}, {271.379, 175.227}, {
                    271.578, 173.82000000000002`}, {273.348, 173.086}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{279.691, 169.695}, {281.301, 
                    168.65200000000002`}, {282.562, 169.25}, {283.363, 
                    170.445}, {284.42999999999995`, 172.039}, {287.312, 
                    181.105}, {287.312, 181.105}, {287.312, 181.105}, {
                    280.043, 174.97299999999998`}, {278.977, 173.379}, {
                    278.176, 172.18}, {278.094, 170.762}, {279.691, 
                    169.695}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{285.25, 165.137}, {286.621, 163.797}, {
                    287.97999999999996`, 164.137}, {288.9959999999999, 
                    165.15200000000002`}, {290.355, 166.508}, {294.953, 
                    174.84}, {294.953, 174.84}, {294.953, 174.84}, {286.621, 
                    170.242}, {285.26599999999996`, 168.883}, {284.246, 
                    167.86700000000002`}, {283.89099999999996`, 
                    166.49200000000002`}, {285.25, 165.137}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{289.809, 159.578}, {290.895, 157.996}, {
                    292.29299999999995`, 158.062}, {293.49199999999996`, 
                    158.863}, {295.08599999999996`, 159.93}, {301.219, 
                    167.19899999999998`}, {301.219, 167.19899999999998`}, {
                    301.219, 167.19899999999998`}, {292.15200000000004`, 
                    164.316}, {290.559, 163.25}, {289.363, 162.453}, {288.742,
                     161.172}, {289.809, 159.578}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{293.199, 153.23399999999998`}, {293.957, 
                    151.47299999999998`}, {295.34000000000003`, 151.266}, {
                    296.668, 151.816}, {298.441, 152.55100000000002`}, {
                    305.875, 158.48800000000003`}, {305.875, 
                    158.48800000000003`}, {305.875, 158.48800000000003`}, {
                    296.42199999999997`, 157.42600000000002`}, {294.648, 
                    156.691}, {293.32, 156.141}, {292.465, 155.008}, {293.199,
                     153.23399999999998`}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{295.28499999999997`, 146.35500000000002`}, {
                    295.684, 144.477}, {297., 144.008}, {298.414, 144.285}, {
                    300.29699999999997`, 144.66}, {308.746, 149.031}, {
                    308.746, 149.031}, {308.746, 149.031}, {
                    299.26599999999996`, 149.836}, {297.383, 149.465}, {
                    295.97299999999996`, 149.184}, {294.914, 148.238}, {
                    295.28499999999997`, 146.35500000000002`}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{295.99199999999996`, 139.19899999999998`}, {
                    296.01599999999996`, 137.281}, {297.215, 136.562}, {
                    298.656, 136.562}, {300.574, 136.562}, {309.715, 
                    139.19899999999998`}, {309.715, 139.19899999999998`}, {
                    309.715, 139.19899999999998`}, {300.574, 141.84}, {
                    298.656, 141.84}, {297.215, 141.84}, {295.99199999999996`,
                     141.117}, {295.99199999999996`, 139.19899999999998`}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{295.28499999999997`, 132.04299999999998`}, {
                    294.93799999999993`, 130.156}, {295.97299999999996`, 
                    129.21899999999997`}, {297.383, 128.93800000000002`}, {
                    299.26599999999996`, 128.562}, {308.746, 
                    129.36700000000002`}, {308.746, 129.36700000000002`}, {
                    308.746, 129.36700000000002`}, {300.29699999999997`, 
                    133.738}, {298.414, 134.11299999999997`}, {297., 
                    134.395}, {295.66, 133.92600000000002`}, {
                    295.28499999999997`, 132.04299999999998`}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{293.199, 125.164}, {292.48799999999994`, 
                    123.383}, {293.32, 122.258}, {294.648, 
                    121.70700000000001`}, {296.42199999999997`, 120.973}, {
                    305.875, 119.91400000000002`}, {305.875, 
                    119.91400000000002`}, {305.875, 119.91400000000002`}, {
                    298.441, 125.848}, {296.668, 126.582}, {
                    295.34000000000003`, 127.133}, {293.93399999999997`, 
                    126.938}, {293.199, 125.164}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{289.809, 118.824}, {288.76599999999996`, 
                    117.215}, {289.363, 115.94900000000001`}, {290.559, 
                    115.148}, {292.15200000000004`, 114.082}, {301.219, 
                    111.199}, {301.219, 111.199}, {301.219, 111.199}, {
                    295.08599999999996`, 118.473}, {293.49199999999996`, 
                    119.539}, {292.29299999999995`, 120.336}, {290.875, 
                    120.418}, {289.809, 118.824}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{285.25, 113.266}, {283.90999999999997`, 
                    111.891}, {284.246, 110.535}, {285.26599999999996`, 
                    109.516}, {286.621, 108.16}, {294.953, 103.562}, {294.953,
                     103.562}, {294.953, 103.562}, {290.355, 111.891}, {
                    288.9959999999999, 113.24600000000001`}, {
                    287.97999999999996`, 114.266}, {286.605, 114.621}, {
                    285.25, 113.266}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{279.691, 108.703}, {278.10900000000004`, 
                    107.617}, {278.176, 106.21900000000001`}, {278.977, 
                    105.023}, {280.043, 103.426}, {287.312, 97.293}, {287.312,
                     97.293}, {287.312, 97.293}, {284.42999999999995`, 
                    106.359}, {283.363, 107.953}, {282.562, 
                    109.15199999999999`}, {281.28499999999997`, 109.77}, {
                    279.691, 108.703}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{273.348, 105.312}, {271.58599999999996`, 
                    104.559}, {271.379, 103.17199999999998`}, {
                    271.92999999999995`, 101.84400000000001`}, {
                    272.66400000000004`, 100.07}, {278.60200000000003`, 
                    92.637}, {278.60200000000003`, 92.637}, {
                    278.60200000000003`, 92.637}, {277.539, 102.09}, {276.805,
                     103.863}, {276.254, 105.191}, {275.121, 
                    106.04700000000001`}, {273.348, 105.312}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{238.93800000000002`, 108.703}, {
                    237.32800000000003`, 109.75}, {236.062, 
                    109.15199999999999`}, {235.262, 107.953}, {234.195, 
                    106.359}, {231.312, 97.293}, {231.312, 97.293}, {231.312, 
                    97.293}, {238.586, 103.426}, {239.648, 105.023}, {
                    240.44899999999998`, 106.21900000000001`}, {240.531, 
                    107.637}, {238.93800000000002`, 108.703}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{233.379, 113.266}, {232.004, 
                    114.60499999999999`}, {230.648, 114.266}, {229.629, 
                    113.24600000000001`}, {228.27299999999997`, 111.891}, {
                    223.676, 103.562}, {223.676, 103.562}, {223.676, 
                    103.562}, {232.004, 108.16}, {233.359, 109.516}, {234.379,
                     110.535}, {234.73399999999998`, 111.906}, {233.379, 
                    113.266}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{228.816, 118.824}, {227.73, 120.406}, {
                    226.33200000000002`, 120.336}, {225.137, 119.539}, {
                    223.539, 118.473}, {217.406, 111.199}, {217.406, 
                    111.199}, {217.406, 111.199}, {226.47299999999998`, 
                    114.082}, {228.066, 115.148}, {229.266, 
                    115.94900000000001`}, {229.883, 117.227}, {228.816, 
                    118.824}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{225.42600000000002`, 125.164}, {224.672, 
                    126.926}, {223.285, 127.133}, {221.95700000000002`, 
                    126.582}, {220.184, 125.848}, {212.75, 
                    119.91400000000002`}, {212.75, 119.91400000000002`}, {
                    212.75, 119.91400000000002`}, {222.20299999999997`, 
                    120.973}, {223.977, 121.70700000000001`}, {225.305, 
                    122.258}, {226.16, 123.391}, {225.42600000000002`, 
                    125.164}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{223.34, 132.04299999999998`}, {222.941, 
                    133.92200000000003`}, {221.625, 134.395}, {
                    220.21499999999997`, 134.11299999999997`}, {
                    218.33200000000002`, 133.738}, {209.883, 
                    129.36700000000002`}, {209.883, 129.36700000000002`}, {
                    209.883, 129.36700000000002`}, {219.359, 128.562}, {
                    221.242, 128.93800000000002`}, {222.656, 
                    129.21899999999997`}, {223.71499999999997`, 130.164}, {
                    223.34, 132.04299999999998`}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{222.63299999999998`, 139.19899999999998`}, {
                    222.60899999999998`, 141.117}, {221.41, 141.84}, {
                    219.97299999999998`, 141.84}, {218.055, 141.84}, {208.914,
                     139.19899999999998`}, {208.914, 139.19899999999998`}, {
                    208.914, 139.19899999999998`}, {218.055, 136.562}, {
                    219.97299999999998`, 136.562}, {221.41, 136.562}, {
                    222.63299999999998`, 137.281}, {222.63299999999998`, 
                    139.19899999999998`}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{223.34, 146.35500000000002`}, {223.691, 
                    148.242}, {222.656, 149.184}, {221.242, 149.465}, {
                    219.359, 149.836}, {209.883, 149.031}, {209.883, 
                    149.031}, {209.883, 149.031}, {218.33200000000002`, 
                    144.66}, {220.21499999999997`, 144.285}, {221.625, 
                    144.008}, {222.965, 144.47299999999998`}, {223.34, 
                    146.35500000000002`}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{225.42600000000002`, 153.23399999999998`}, {
                    226.141, 155.02}, {225.305, 156.141}, {223.977, 
                    156.691}, {222.20299999999997`, 157.42600000000002`}, {
                    212.75, 158.48800000000003`}, {212.75, 
                    158.48800000000003`}, {212.75, 158.48800000000003`}, {
                    220.184, 152.55100000000002`}, {221.95700000000002`, 
                    151.816}, {223.285, 151.266}, {224.691, 151.465}, {
                    225.42600000000002`, 153.23399999999998`}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{228.816, 159.578}, {229.863, 
                    161.18800000000002`}, {229.266, 162.453}, {228.066, 
                    163.25}, {226.47299999999998`, 164.316}, {217.406, 
                    167.19899999999998`}, {217.406, 167.19899999999998`}, {
                    217.406, 167.19899999999998`}, {223.539, 159.93}, {
                    225.137, 158.863}, {226.33200000000002`, 158.062}, {
                    227.75, 157.98000000000002`}, {228.816, 159.578}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{233.379, 165.137}, {234.71899999999997`, 
                    166.508}, {234.379, 167.86700000000002`}, {233.359, 
                    168.883}, {232.004, 170.242}, {223.676, 174.84}, {223.676,
                     174.84}, {223.676, 174.84}, {228.27299999999997`, 
                    166.508}, {229.629, 165.15200000000002`}, {230.648, 
                    164.137}, {232.02, 163.777}, {233.379, 165.137}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{291.562, 139.16}, {291.562, 121.324}, {277.105, 
                    106.867}, {259.27299999999997`, 106.867}, {
                    241.43800000000002`, 106.867}, {226.98000000000002`, 
                    121.324}, {226.98000000000002`, 139.16}, {
                    226.98000000000002`, 156.99200000000002`}, {
                    241.43800000000002`, 171.44899999999998`}, {
                    259.27299999999997`, 171.44899999999998`}, {277.105, 
                    171.44899999999998`}, {291.562, 156.99200000000002`}, {
                    291.562, 139.16}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{259.312, 175.879}, {261.22999999999996`, 
                    175.90200000000002`}, {261.953, 177.102}, {261.953, 
                    178.54299999999998`}, {261.953, 180.461}, {259.312, 
                    189.602}, {259.312, 189.602}, {259.312, 189.602}, {
                    256.676, 180.461}, {256.676, 178.54299999999998`}, {
                    256.676, 177.102}, {257.395, 175.879}, {259.312, 
                    175.879}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{266.469, 103.227}, {264.59, 
                    102.82799999999999`}, {264.121, 101.512}, {
                    264.39799999999997`, 100.10199999999999`}, {
                    264.77299999999997`, 98.21900000000001}, {
                    269.14500000000004`, 89.77}, {269.14500000000004`, 
                    89.77}, {269.14500000000004`, 89.77}, {269.949, 
                    99.24600000000001}, {269.578, 101.12899999999999`}, {
                    269.29699999999997`, 102.543}, {268.35200000000003`, 
                    103.60199999999999`}, {266.469, 103.227}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{259.312, 102.52}, {257.395, 
                    102.49600000000001`}, {256.676, 101.29700000000001`}, {
                    256.676, 99.859}, {256.676, 97.94100000000002}, {259.312, 
                    88.801}, {259.312, 88.801}, {259.312, 88.801}, {261.953, 
                    97.94100000000002}, {261.953, 99.859}, {261.953, 
                    101.29700000000001`}, {261.22999999999996`, 102.52}, {
                    259.312, 102.52}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{252.156, 103.227}, {250.26999999999998`, 
                    103.57799999999999`}, {249.33200000000002`, 102.543}, {
                    249.05100000000002`, 101.12899999999999`}, {248.676, 
                    99.24600000000001}, {249.48000000000002`, 89.77}, {
                    249.48000000000002`, 89.77}, {249.48000000000002`, 
                    89.77}, {253.85200000000003`, 98.21900000000001}, {
                    254.227, 100.10199999999999`}, {254.508, 101.512}, {
                    254.039, 102.85199999999999`}, {252.156, 103.227}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{245.277, 105.312}, {243.496, 106.027}, {242.371, 
                    105.191}, {241.82000000000002`, 103.863}, {241.086, 
                    102.09}, {240.02700000000002`, 92.637}, {
                    240.02700000000002`, 92.637}, {240.02700000000002`, 
                    92.637}, {245.961, 100.07}, {246.695, 
                    101.84400000000001`}, {247.24599999999998`, 
                    103.17199999999998`}, {247.05100000000002`, 
                    104.57799999999999`}, {245.277, 105.312}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{238.93800000000002`, 169.695}, {240.52, 
                    170.785}, {240.44899999999998`, 172.18}, {239.648, 
                    173.379}, {238.586, 174.97299999999998`}, {231.312, 
                    181.105}, {231.312, 181.105}, {231.312, 181.105}, {
                    234.195, 172.039}, {235.262, 170.445}, {236.062, 
                    169.25}, {237.34, 168.63299999999998`}, {
                    238.93800000000002`, 169.695}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{245.277, 173.086}, {247.039, 173.844}, {
                    247.24599999999998`, 175.227}, {246.695, 176.555}, {
                    245.961, 178.32800000000003`}, {240.02700000000002`, 
                    185.762}, {240.02700000000002`, 185.762}, {
                    240.02700000000002`, 185.762}, {241.086, 176.309}, {
                    241.82000000000002`, 174.535}, {242.371, 173.207}, {
                    243.504, 172.35200000000003`}, {245.277, 173.086}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{252.156, 175.172}, {254.035, 175.57}, {254.508, 
                    176.88700000000003`}, {254.227, 178.30100000000002`}, {
                    253.85200000000003`, 180.184}, {249.48000000000002`, 
                    188.63299999999998`}, {249.48000000000002`, 
                    188.63299999999998`}, {249.48000000000002`, 
                    188.63299999999998`}, {248.676, 179.15200000000002`}, {
                    249.05100000000002`, 177.26999999999998`}, {
                    249.33200000000002`, 175.859}, {250.27299999999997`, 
                    174.80100000000002`}, {252.156, 175.172}}}], 
                    FilledCurveBox[CompressedData["
1:eJxTTMoPSmJmYGBgBOLNQALEZmAC80fRKBpFo2gUwRAApg0EFg==
                    
                    "], CompressedData["
1:eJxdWQu0TdUaPkjJKyLlVZFHhuqEqy6SWZJBNLL3Wmu/914ka8211z77HHSS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                    
                    "]], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                     1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, CompressedData["
1:eJxdVGlIFlEU/dSw1bTsh6SmZi4hYUqrIV1LKSudNyUmaSZiENK892GSoiWJ
aURotpnRahJW2GKERYtaiGaQmllmamWSBqZg0oYZvTf3OQN9MMx3uMs5794z
zyuZbd5pZ7FYbPgTzx9b/mxLWfVB2W+F/tb5Xb//KtB35Wy9Z5EVPgs8rMC3
tqhkpxIriLTCDolLrbBn17GhfS0m1uON/+U3yn4nZX6tAg0blx8OOyjjFQoI
mJRh4pC7z/bWRJn54rXa1ewX2LPAPreJGfzW0Gkd5XHMiK9J4sq9mVHvnFf3
vGyIQprAtxTwC5pS6VZDwSJ+lxQoPE1n5xVTEDOxFCuQPefmut5UiufIlPyR
FM7Ve95Oi5M4VOL1Un8QhYUJR59+X6Egj5/E/gpsnbnoznkPCq5C+CwZ96bI
m6SgzgBTn67X3dSnz8PR1OcuFmZn6tPzfmlGv8fpJ1wmDWuGPv28/Zqhp1EI
/qjBVbEIGwX49Kyh7zW4NzrentkZjfG3mqFX31e77A8K8NMvTWzTDP7rI/xP
q2bsbyI+sZ+J+gl/6XxvNPCxzz211pkgX7eGfvMlhj4dLyPony8aCPq6DcQ4
70sezkkl8MOfH8yBghhbRAFBf/hQCD+ye2CsjKCeYIq8xwmIqkdAsT/PDxN+
UWR9DoFYsa94CokPImfYZhMYFvXcD7p+Hn8n6jNNvtqLcwN7uH++qvfn5ccT
9EcVhRghPIngPhoovouk3iZZXyL1NVPYIfjKCe63hWLeDYJ+fkVRdz3Bc7dR
fH8y8y9HVI+O/5H6B6TfbFQQW0+wY4inqpA/yIV6MdTnoqJ+YLhff1X6iIH4
DLKWqDi3HAbRyU5xK8NVnOsZiTepqLOK4d6ICm5CT4XsByrur5hBt9DvpqJf
0hn0ZnGGEWLw6Xt7TWC64MtiUC382ESMeh0/kf44wHCeF8x6Pr2AQ7EE74MY
ZvhHj6cw2C7mG0AMfn3e3gS/jwKGfnQl0Nn8c0vfNRPr83xo5i8WOl+Y/YrF
fLsYlAp/hhDwFXWDZlz30RiDSjEYD4L3hYMVsSOBjBq+AA+JJ0t/B5v38f/3
8z9bA3i2
                    "]], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, {{{244.824, 67.52}, {245.008, 
                    67.45700000000001}, {245.195, 67.395}, {245.258, 
                    67.21100000000001}, {245.32000000000002`, 67.023}, {
                    245.258, 66.84}, {245.195, 66.65199999999999}, {245.008, 
                    66.527}, {244.578, 66.527}, {244.453, 
                    66.65199999999999}, {244.32800000000003`, 66.84}, {
                    244.266, 67.023}, {244.32800000000003`, 
                    67.21100000000001}, {244.453, 67.395}, {244.578, 
                    67.45700000000001}, {244.824, 67.52}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    244.754, 67.273}, {244.875, 67.21100000000001}, {
                    244.93800000000002`, 67.086}, {244.875, 
                    66.96100000000001}, {244.754, 66.902}, {244.629, 
                    66.96100000000001}, {244.566, 67.086}, {244.629, 
                    67.21100000000001}, {244.754, 67.273}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{244.80100000000002`, 66.422}, {
                    244.48800000000003`, 66.418}, {244.23, 
                    66.67599999999999}, {244.23, 66.988}, {244.23, 67.301}, {
                    244.48800000000003`, 67.55499999999999}, {
                    244.80100000000002`, 67.55499999999999}, {
                    245.11299999999997`, 67.55499999999999}, {
                    245.36700000000002`, 67.301}, {245.36700000000002`, 
                    66.988}, {245.36700000000002`, 66.67599999999999}, {
                    245.11299999999997`, 66.418}, {244.80100000000002`, 
                    66.422}}}], FilledCurveBox[{CompressedData["
1:eJxTTMoPSmJiYGA4A8TMQMwA5DCOolFEQwQA/LgDRQ==
                    
                    "], CompressedData["
1:eJxTTMoPSmJiYGC4yMjAwAykGYAcxlE0ikbRKBpF9EAArgAEUA==
                    
                    "]}, {CompressedData["
1:eJxdVwlQVlUUJjSHUXIpMhMkXFLCMbGSKNJOYwbyv+23VVzGjCZ1lHfvjSnE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                    "], CompressedData["
1:eJxVWXmcFNURXhFWEhZEUOKxbEARZD04FBFY8bEgiAfszHTPTM/OxYIRAs70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                    "]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{244.754, 66.848}, {244.625, 66.848}, {244.52, 
                    66.94900000000001}, {244.52, 67.07799999999999}, {244.52, 
                    67.20700000000001}, {244.625, 67.309}, {244.754, 
                    67.309}, {244.879, 67.309}, {244.984, 
                    67.20700000000001}, {244.984, 67.07799999999999}, {
                    244.984, 66.94900000000001}, {244.879, 66.848}, {244.754, 
                    66.848}}}]}}}}, {{{
                   {RGBColor[0., 0.686275, 0.7921569999999999], Thickness[
                    0.00019063687500000002`], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{244.754, 66.84799999999998}, {244.625, 
                    66.84799999999998}, {244.52, 66.94899999999998}, {244.52, 
                    67.07799999999997}, {244.52, 67.20700000000002}, {244.625,
                     67.309}, {244.754, 67.309}, {244.879, 67.309}, {244.984, 
                    67.20700000000002}, {244.984, 67.07799999999997}, {
                    244.984, 66.94899999999998}, {244.879, 
                    66.84799999999998}, {244.754, 66.84799999999998}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.996078, 0.772549, 0.047058800000000005`], Opacity[1.]}],
                     FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxllHlIFFEcxzevxEw7bDOvDsKORXbXmTezMzuz+9sOSkQsJf/QCLMEISux
EDGKCsRERESxP8xAIygqKRErKYkOiC7KBLtLZCsRSa2IEKF97/d8YrswzHx2
3vv+ru+b1UWHc4pDLRbLvMBVELhCAldzfFhezHMDLPR30gn/85P2rT0/j+ug
dz+u6Ftph7tHm+LDejTYsLvh/u8zDij9NnV5otwF0SG2GuuKdKDLp5tN2FF/
9tCSYU1wov3j2oh2Yy43AtRY377406SDGTV4oSzNB19frnn/95PC4/uA7OnN
iC6SIfDWjLrpw/W5DoxfEsxs3XInOALyp/wAd2i+LU7U7QPU/ZIOcZ3bhqq6
AdRaX6G/jK/fBWBjgnagr+NivIJpGiF1xly+4uL5OyHnVkr16GJVcAetsztd
8Hqa33YHDF9sfbjKYQea9XDxxiBe54y8mpQg8bsNJvuziha9kflcHPj/O4mv
l3jdMlSxgiTMa1SGY5TzJX4nWOd4OtwoL2kcO0dw3yUJ85QJ+Gl/TsiwpY5O
VMa4LsLzIFjHEQKVI6nOyFICyfn73Z+zCTyjA01WMK6N8L4pqP+dQMvmgGAr
gYPUJ10KVI/uDHRK5n1Xsa5rKs7nvIJ6bRr285VLMHuf4hZ8ndbxweB9cGGc
RA+vRxXM4vYrgpmfNino20kT+z9OuK9N7jMCLpqfw4N1vyaoO+CBJFp3rMLr
9/L58f4s9YJC9TtkXNfggV/TA5UjEYTPx8Q8CmTs1wGT5yfxeCb6tUKCbHp+
Hhg8vgR021SGgedqn4x9DDeEPtNbYOD8amXsf6Qb9awEJug8K3U8d0MEdUKD
mZ2Pwlk99IkimH0PTFUwy+ORyn3pFsx0LLPM4vh07he+Xtf4PHm8TA39mTTj
Xw33+/k5ytUFs/29hmCcowf91ynDMvoQBhCb1tX2Y74KT2mchYD9StVw3lb+
Pbino4/CvYKZDwYNwU3Up2Ma+rWe9yNTEoz+dghmPjudhpzlwjnk2USfZ5j5
wW0IZnUneGAvPZC37UH8D1c2WwE=
                    "]], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}}}, CompressedData["
1:eJxlVg1MlVUYvhKhY4RlZkytWbFMqhWupg7u5T3nO5d7L5ef77s2EmXMiArL
oIgxMOfGyIgcZGoLphZZRrqy32U1Yy5+lFjNrGWsqJH86MylOKNy/XznPOee
b467fffu2Tnnfd/zPM/7fvem8urYQ1f4fL4Z7rPVfRLcZ3kLWztmZ9PbC1dX
ZDU7FMd5KQm3N3fHqCLrl6LW+wm4bCWtWvHR0bpUbnCJxGXC4IMX/vmuviNI
f9xW+sIX78QM/rx2e1piv2Nwe9WcpsPcoY8lXhekI9FlLeycTa0vuwvnBNZr
pmOf/CxidOL1J/zJU2FKvfOD3b+HchB/PEhL3LQXTwWoed7Q11NNQSr7LJKS
MBig6w6ERjbM9fD8u4bTk54UBs+V67UWiS3rJy6VEOK9ybG+hiFvJ6c9Qbdi
wbGvgyOPZZElcYNlsLpXgzC4pvLFsxvfDdLjE5f2nd/Dsb4il758TQZkBvdc
dIlb6uF9/S4xI2TuF8fQxcMqzwVBb0l8DQMPR7UuxR5W9Sdyg9W5bxn9venR
Q7UfBqfhb27+8a9NGRw6dAbpXklIDafZinfNd5hD1yFBu3oXvVfzHKffnE9u
3Dyo4/dwxNkvcL9JTuratQJ5euLxBA3KhVbNc7ow8TPkb5ow+dXvNgt5sji1
yfpsi6SsjX0Met5jUSDZdcowo52yrkoL8V08ebyg/Op2C7x+z5Cv16KZjS9Z
WxYyxNtqQXcfwT+jHkZ9QYPVPR7MpR1picWpwwS9q0Oo72lOSTLuHSHwk6b5
WROiiNRnnFHD6VszZx0KIf9PDL5eHIbOizV/yWETT51Lmo6VX6Mc8Ur1+Zmc
7pa87A3rOBy8FES0j3T8jAj6+RXtz9NhWiAJnWFBtzkR5HmYA/M88JJugY/R
qM4X1Hrma/8J8F8f1XwJ6NmeZ7Dqn08jBqv9p3LBl+vTsWNugVUejvdXHKu8
XVq/UoG6ejnmRLNlfBzHqg+X6v69VkC3qzjmW5WOd4TpftU+rNRzYK2l9zPE
fZ6hvlSm/Uvap4zk9ecNBeCP7Yzkd5rwGx+rOF9lI8+vHH4szsb+lRapsVWV
RWekzmeE2Y+5pP1WECB5KvVsSM8ZTvVS//VF4GnAIleNrv6TNvrjSgF8i4M5
tkTQU/LcIx5Wur/v4Y05bsXrYuDvBCdpH/9+ja/3sJqrmezy9RBhfsc8rOoY
cwxW87/Tga+2EXxW59C45PVfDyueEvjleJJhnozq/d1al4wY7vEAp6bD7qRN
iul1TvK6OX0OfPsGx75GB3POZ9FxeX6DgzmxykL8Cgd96fpM8bXM0b7QeLaD
flyg5/9528SPv9+U73/Q9Txro848Tq7KB0Iltqlf7Sdb686wv82G32dx+k9+
JmzDTxz7FfEeVn0VyaH7Tu7d2funDT92BEz9yl9tAeOPgbruV+dXB6hLvkcy
i6Zh8BHAvZcXos+eIfQFFaKeMgbftBSiH1MY7vFYAfQqJ8zXY/nQ/6Af/TaV
D75qAyT/o/jcdcTNwRyp87CKPxA1WOk3kkebZaI+P+bYzxHTL3hfROiG1TKT
93/nfzxF5I4=
                    "]], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxlVg1sU1UUHnNOssxNCS7LIIsKisKW9efdvv4wOO17Xdv99b3OYMYI0Ylh
AgLWptmAkCzLnETH0KFMCXFIcJEgoJCJOgnK3EBQcRoVVBS3MZdBBCdOXRa9
957b25g1eWm/3PvO/c53vnNu76ndEHn8lpSUlBn0aaNPKn0eWNH28c1gMRyc
u3yVp8WEBC7NTF3UciICK98PZaaOORGvrIKXtOfWjWwmEh+J1r1w7QeLxO/s
+a2r72wB/MkCvRWR+MNYe25anylxx/pZTSd9JoxMvnljoLUQ+svUbd7rBuSm
LcsqjBbhenQ6ZsfkVKvw7b6NxRkTQYgcz28eM90Y/4ofBvfv7r37iBtaci58
PtHkhzPxE6/lfeGGuw4FLm+ancR5RT/OT39Kl3g2W49pQIMdzx92Yrw3fLC2
h/4YckAK+3T6gMn0UzYBncow+YoPz7/TDkyWyQZN4u7xqa/rG3SJmUxbDvuR
V5WC664SOLfX3z2+h0jM1+2qxJzHN6rML4Epi3Drw0nM3xvXgdFNi6vwIKvj
aR3qR++3zrzqkJjzbyMSU9UfGb5O4J+ta3piR/3T8BoWUCfQuosWoFOc161A
diGtZMAPf1Cao+kE3mV8L+gY91kFrlIZm88m8lfgy3u//3vrAR1ep+lOHbMD
S3sqllzHeDoc5kIpuG++LuMvZHFzdXk+YcZ8UQOTEZtHYDvjZ2hYz2wH1lPR
4Mp5evAlAswV0TpN+JXA7wMVtXd0aNDODHaN4Hm9GsxhvnhUxXg7NFhgnXlw
7qsu9M9QEiM/v8Rcr8dK0Cc/q1jvDQHkt0+B9EbaOQUByGJ5riaoT00AGlh9
zhH87gng+ZcJ7lsQRF+FCOqXEZTxQqwR0qdj7tc0EW9FEH26jYCFhm3cH0R/
NxNYkkE7qCIk+lvUZ2EIXmYH1gh/jgaxz3bZ4dRN2tCzQrCT6fWZgthXCk7m
F8OOegyVof9yikQ9y4X/LKh/fZnQy4r17CiVmOf5Xkhivv/XEoxzmwWGWR3X
J3GivxKY90OXJvS3YL16fajD8zaRXxI/yQaPzYd+32jFvG73Yf4fiHj9XtGv
FvR1nRf5XbSJ/V6hpwP5ZXmFf53oz6gX6/mRG/3R7kX/Llss1n1Cz8XI5xef
6Ldi3F+lId+CJcCPGdPlfl63mhLEFR7h4wBsZsZ3K6j7ujAw9oO32nDuDhrY
H21WxPNMXPdb4WlGe3USc95vJ/GWpZTxE4n7wA7MPsUHIuIcIjH3i6pKzPln
unB+R5KYhW8cNiXm87/TRB/FnOjnuIn12K1KzOvRTv6PjxKcJ0Mm5p/nEPWO
YJ9/p0DTyU/3+tMjGG+OAizdpZ+YqEdYwXwbTTEX7DDA3t9kYv+M2jD+qsT9
aEO9VBP7tF/gbBPrWivm/w1Dxk/cb3z/iB35PGPIfqWX06FAtSH58/1gQJj1
9ymC+7cbYr4S+Jd9RgypTwLzeZfvkhjPd8ND7GL8y8A8Z3gkf9TfI/3B67vI
A119lIA1PA3z970e5OGsxP7Z4cS+g0rkf9Eh5k6l0FVF/66tQJ8POHG+ni8H
g+U36MF+myjHfrrPA+w/Sgpd5/223I3/L+JJzOOfKZMY52Yp+uErD1S7jp2O
XwrJfsH7IgT/ATGx0GU=
                    "]], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}}}, CompressedData["
1:eJxllHlIVEEcx9ejkrIoNbvtILpEXHfddHff2/ed2ZWMiC6yA42sBCk7KAs7
ycBMJKS7KAKLLoqIEK1I/0iR6CJDEMuQMrssSKWixOjN+42zlAvD8Hkz+5vf
7/v7zkxes3lxTpjNZgsxR6Y5Qs1xfHR4xrCnGmzitz8J//PumJtz3ow14Kl4
uKNmYiI23M8/NvqdgZmZZQ++H7Jj44eea51HgcjQ+OLYMQ5aD9ew8PCpTVFt
bsXjEl9PHViu/ctHgKKORXfiBhjQBzdd3JLA4BNzFpPnM+z8NC0p4hyH+VUf
XMXovAsBOj+3P1txWQB2cypsB67Wz0spCQng/fMpr37VgOrL8kOUtasCKI5t
fvYzWu5fCrSLfc8CEMsxwwzFq+7NjQwt1f7l66mo/T4jsyw0gMV34oo6RqQo
vpBW2d1b4VA8Q+SXbqf8QtJgnrqkLWdWP96We+TrHsOP6UkRN8aPjaf1bC77
Yqf1Vi73O9H1Yv6a4ac5dlkFOUmnZZz6ttJJ+ydypJSw1e3fHFjuNhv5h5Fe
V52Un4NTXfuSKV4BpznVRX0AJ522uSj+KI4JK9d5Wxe4qG/VjPSId8Fqb72M
/9FFuv+Rfbo9G4HSvA89JTKfLSmoFvt/gPadn011/DZIz4ZUxdZ6nFfxra1m
YS0aqrp7GwvOACf9ZuBxPrhEIg6m+Pe+9ffz1wa5QPjpBkOeyKdLx0ghWyOj
PCp1XBF+6WRIFfnZfaTPW0b9bPTRXMdk/Qb5KFnqE23gi2nnot0c48V6mY90
SO/rjy7r5KTXBp3ya+PyPJ3yj/Jjgbg/tZo8n0Ok3zNXo/hnubw3mopvxRui
QWR1uJjT9wgvxeMcnVZfPRhUeMJf2sLofob1Z8tnE4LxyA9M8aNyU4CEIDcI
23wG+fWlV7HlG1uQ6V56yC86o/0eN8XrlfHmSa7u86+b/LLCT/ou8Si2/n9P
U9x26WzdpG8+iGMKt3PqazikPgyPRdyhgOhigRvU71j5bjX76D6Z71AfWz5v
0hQfE7p8dUO4vPhgX75OxeRvu2JL9wMJxJdB9yIjnuaThmIrryxdsVX/Xi+y
xYW8m9iPrffwSfB9/gsDg2Cj
                    "]], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}}}, CompressedData["
1:eJxllg1MVlUYx18JlRGxFBRCBGM2P5oxm2QF78tzz70M8WNmH3wU3nvfe8lp
KzAi14yxGBCUwyxt4SwJq4HN1FqJKyILJdRVhpWhEjHmx1KnwsgRmd1z/+e9
Zwy2d/DjnPuc5/yf//Pc926r5NGnb/P5fBOczxbnE+Z8HnxNMc89kkHLFjt/
rLMpxLuyDgzdDC+iovS+lfV5RDWXVh1MeqKI8h/6vGtDNPO4gLOuedw6dPOX
l7Zn0fP+yFMf/Gt7fHqk4pm2OsnOKSdSsm06wHldFn1dtjU+PMmm+neKp1Zd
07DeZ41jH/+ZpVDp2jevlA+YFL3gs/euZmfSPZMq31aTTZpX+MZ3wxcDxB87
NMkk/cucqLDjAfp7rrPwq+Fx7fSeH29UGWPXJxqkbXr2wmgBUTK/0E4d608p
dNm5Xs0OHbpoDHk16IijquAIw+NOLmid5JiqQ8eappj03IXR3dd3MawvMulY
Ew+oeNwx7CRyv+Td/I9+8u4X4j2JTxal3zA8Tu2dPanyiEEtnKco0Gm/QUuj
wu6tzZWMujKP3fxOKvRF14b2xqnmOP455cxIxXxGzn8fG7jDpDQuSCmjh52y
t181oPcSocdBg949PGt/aR2j/o2xe7M/FfE7GD0+8NGOw+8buN8gIy5H1qsG
/ePYosxZf4HXs8Sg41yPegY/6DL+Lf6TZ3jnn+F+ijVQl3RGjguaO4d0oYOC
ep7TKeDYcH2vgnxv6YjvMLdte5yBc35TkM99Bk12ZN6UqCBejAGdfIR4fsnu
c39IdvUKmLQtPjw3ulfsrzSR38sMuq83oU88o7M8/3KTcnh9ziv0TWNCau82
E+efFfnuM9F/c4S+LTKeo8rcwubx7Pp1mYjfJp6fzNA/P4l6Ror+HRHreYw+
vt69wrpmop93Mvqe++9Pk2ZwQSeo1M2f+0vku4bRCc4PBGna3uz+jbNVnNsY
FOdlQd/WoPCfBp2qg0Ivwcslu+fHSp7p2LvPEHp1aairIjnUXyF2+yFZ1K9Q
g/6f6ORU3x9Zq8J/pmS37YpE/8Zo6PtVOuZbsYiXqot+Ffn6dPw2VeK28nev
hp6vK2Tw+59cLfxLFMt1CdeJX396TwD5T9PJcfvWeM2P9WodfvlBzNs2Hb7K
zcD+YZ34ttjidMzJbw1v/2buhwzhtxUB1LPJxFzcx+CnVyw8d1SlXD4o42zE
naiBF9u49zwN86lA8pXyzDS9QnIDn6enbeh3iqHeo4LjJCfwAxYqY9ezSfhP
MuanZHe+vGhjPrxF0MO06Tw32n+S3XqEsbE8qMCvDWJ/u0KMn/eVDf8GGbVz
PVpC66KfnPeRG+dDhnquEe8fn4rnbZsGHVvema8ifr6N902zmOeKjfm0VvAC
G/04Q4UvkmT80PttPt//u8jnooV9Sxn07ra8/N39nRbxstZcEvPhsgW/RzD4
+y6pT4j97kUkq7x+OZk0Z2HEnsQUG37cHvDyd/21OeD546gzxhJKAthfao1j
6BFAHyyy0P/V4rw0kb8u6rHEQj9GKfg+4LNQL0vUuyeI+rf6MS8GgtCrTLyP
e8Q8oEzMtw7JqLdkvC+C6IMjflrOv8/MDHr9crt7UBBzZaX8vvM/dq7buw==

                    "]], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxlVg1QVFUUXmklhkhSCQ0VirJslJZl39u37IIdUkaddBQrStP37r5Hf2ZJ
ZA4pw8QgiWNGDZpMjBExjdZYUpkxSaZZ2I+loWXgL7MRkTBqZg5DjL1zz937
xuHNvNn99t53zne+85379jZzxcLHrnO5XCPsu8a+Y+x7ypKary7PzoX7tfV5
7CkLovid/N2XhtxFoH8+JyHmXACqzhW0pD5UBJtnbFjes0aVuLnkydf7T2ZK
/PHW89vafpgGz+XGH2/6z5K4c6B8WWu1g/NY95H0WRb0DL53sX1jBnyxsna8
O9WC8e7CURklHlo/Yw7DCTFT1yUv0gDTlkUYLGxJtVMHYXJsxeYZaQwi79Z/
fWtzELY8O6ZyXyyD71btbUg5HIR/sbBfDInXJXf8dKXSuHZ9pEF1dAcgDb+8
pcPTrTax3/3QZ/9cVa/DxMVFoTOJKmzEBHU65R/tIxxnSNyGglY7eGzlvu8b
RzPK+4BC6wqDQ4220FtVifm6T5OY6/KrJuuL4h1I5IohsefUHbEV3xiAdN2r
NHDh1WxAae+d3rg+v8Scf40qMba9+4IKn35rCzGGDcPLMOBMFZB15EaRf7cC
wV32hvMG/DN0rLQ3VujRYsDd6J9qBbpWJ30466No/Qo8iI152yBf7fIBypH/
srP+PPZzhQE7eWMVyqM78a/i9bAh859APyUZUICJb1fJV5d06mein/rZrcMf
R9JPDJxWie9VXfhVhWzE4wyoRYP1q8TnHgMmoJBhjeKNNeAub9yOiW9mU7xc
B3Mepx3M9ZrOSNezGu2vYMSvSaG6ixmMyrAjP6HCSeRfxuBF7M8hFb5sSPGc
2sQof5fgu5MBjtvgHKHvdieerfKUJduGY+5Xt4jfymAmPr9epfk5zMjfVWJ+
B5iYbwXev9g+z7zA4A1M+KgCB9F/ZxkcbyrOjd/ig3ZbxvK/GGxCvX5UAGUt
94chgH5Z4KM4DWHyX7KH9P0sLPyXSbqsDQu9vITnOpjnT3LwJPSpwSAR9bo+
k/yd5+DofEUxn4c0Q+ifSfp/oJO+r2SR/5iDceyGinTye7GXdCrQqf49Ip5H
F/Mq+Lt04teZBfEoTPtSoacfDKz/6FLh3wDY7u9a7dapn/uDxP9mnXxTmEPr
a3WhZw75o1UX85ZL+y8LvtOmg716rHS/Ife/in7IEf2YFyIejQzWYOCgQn56
yaS5HZkFhWi8cRbNR42XsGbRer6XzqdFDu4vu1fVyx1ch+dppyX8Ivo9aFF/
l6sSc79omsScf0K28J+D6fx0MM/zgkU6rAzQJ7OoH/WaxLwfteq1+BOV/GrH
4/Wn+OE+zLfHgr9tW930mwJ7UY/tIt4EhfJXCz3mK9TPx8X+Oh89b1nki94s
iv9I9P2YRXrlWTTPBwXOsEDFwk0f/IzzkerEj77f+P4eH/H505TzyvVuNyV/
vr/NhPlI9IA4H/pMcb6q5O9bHH2imJ93qdkSU/4g+TbdIj+OCEn+pH9I+oP3
bWqI9peYwzB/Pi9E86CYND+vBSifKvh3+kmv2WJ/hUb/B1wmPMNf+AHqd0cY
FmB9kRCdF5Ew+XhyiOJ1iPNgcZDOtwMOpn47mN4XYfLD0RDMRWKTwnJebuDG
DMP/+LzHsw==
                    "]], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxlVg9MVVUYR6KXcwRmjRkgC4LUIeP9O+8+3oP4UBy5JNEWCzNm9O6795op
qDlK1sYYoUtDh4qLOTLGmuTMlTKmZIaJGVBOy8o0QyIio7KS5ojWPed33r0r
3nb39nvnu9/3O7/v953zUivWr1DviIqKmmY+jeYTbT7zVjX23Hokj96+eaG4
IlelCP7m9strut8IUfnxJbHRN/zAJSHas+jVtSNbmIWPbNB3jV1xWvjd/b++
1du3gOpvLO9KOWjjNxd3/jGZrFr42MebT7aWqzQycfDmhR1ZlLwyFLzWoNLs
mNK4rA3ZdJSv907FsdGZDQllCs34sq0yr0ejFV0pZqkAnU8zGbyi01B7y0cP
HAmAd6tO58zXEj8L0Jb7DhcNHrdxDk849L/1NAO8h/3IV2rQc92bmmZ/76Mo
/nnSAM94RtlX0x21ZQbq3+MBTrXxvXWnPjkwqFtY8NqtU0PC15/+9bgX61U6
9R8whdnPLCzWPYqF3zfLx1xSrP1F8FzX9EPJHTYW+z2tE6cbs1mhcd7IAZ2q
Rx9yTf/ZZ2HBv5FZWNlWsHr4N0YLVw+fT2uaitfwhIUM7zXLep1efB/W6c/J
z6tHHZL/OZ3mc/9s9ULHgcj+vbSUJ/5Chw+Oemjfull1p67b6yLfLzq9w/1U
46Vmvj5u5xd8b9v1N/KwJIOW7zAjH2Q0h/PLNNDPeB/66TboBy7ct4y46kMZ
hvQro0LTxhP3G9TEDTbGwCfOoCTeyGcU5DPzC51fz6GXeD6HjQW/Tt3CBVwv
TYdPvlPQ73Qd/Nq89EFrYvZVr05xWeYEaAz6zNfpRd6ffgZdZuqoP8iwz3GN
+LhNLGHQb1Kz8o3V5LPyf6Zi4dcYme9HDfvcxjA/lzTUrWdUlWdO0CFNzrfs
zzGN9vKCT3lpFu/nGY34mM1o9tDOnlvzVp3QaDfXa8ALvF4jP/dLiQd6ODT4
LyFb9jMs/eeE/qma1MuFfpbZWMzPLhuL+MU6xXO97nJS76MmwZCNI/MVweK9
BEPq70T/HzOg73Y39veCjTMctXsWbTTg90oXXeHnV42B/Z+Q+V4z5Lw6wbdd
9v+yG/Hd8ryo99FZzs/E8K+fxFeb9NOHAcxTiwFdSnOx/qwh9cwFnyJDzlse
4jMl3wUPo84Z3Yrnr+cbEhcHcf7G6Nh3wIv+p4eh451uuR8V89HoAl6nSp1d
4L/UxoLfXBsLPn2R+8CDOh0h9Hcts7Dwi6JYWPCPzZH+s7Hgf7dqYTFv2Sp4
b5L3TaGKfrQoFhb9aGL/xe8xcnL/mPlE3UQf5vmnEP1uXmszv5Lz93cI+ZKk
3+dIPZbJ8yRfRfw+eT4tVDE/o27kL47cj27pRxXzfNYN/apVYlygCg/62WDn
j9xvIn7EAz7dqjWvjXyeLtr8hR7XVFrG5/s0o5M8vkuV5yuDz7fb+kSwOO9S
ciyM+gF6gheuU+HHaUGLP/QPWv4Q/c0MIt4TnoLF+wVBzENVGPOz0496lWHw
v+yDXk/L+FoF/m0P0/Piwvdjf31hKuH7G5L1e8KIywgiX38Yv68M4Hy7bmP0
W7OwuM+LNPjhYpA6+P+ZrZo1L6K/LRr9C1IyyJU=
                    "]], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxlVQ1MlWUUviLdiEiwGXPgMEvNghv35/vud38EDkNmGArC/S73fj/XYDbK
LE0didzczKmxcuDQcDFnZM25ObR0zPk3kdJ+yB9qWkglQyIC+tGSGWl973ve
+35r3O2OPbzvPec5z3nOeWdVrSp7frLFYplkfBuMb5zxnac1nP3rmRx4ccdo
NM8mQwyfWtc0Pf52OUSOFyXFDXvgNjmQy2FXwVsrB+tEjg+veWHHaK+d44/3
/Lb/3JdZkLFleOkxa4DjRUlxmdt+NfHreWLk+KsyDI4f+KN7uw22pX53YaxT
hunxwSm2Ndl4nh+cgEmY1LAE6dnfz7Z6FSg7RjL5oP3W3W/Wd6jQ/2HLJ48e
9sHlx67d2XhThc9rTu9Nu+iDxKv7Vuc8pXFcOzTXkRA18YPk/G8NCO2MAQ/0
bZjWtrBSh5dOGkLccIOB+jYs12GGstz/Y7IIa42yo9U65p/qQjymcew9+lnN
6ddM3Htn44qTvSrWWS7g/WYVuloL22/tETmm5y6JY9qHKxKvL4YDpNAEjeNu
Uq9PA0I3vkYCC/mUarCe1Dni5pjybxA5lurznxv4XYTdrzy8+UyPOgGvIAEX
iLCkKiXkvcHytwtw/lnjZooGfxq0hqyM/0INniT+eVOAmUTIJbH6BThIEi/T
4H2j3LtHXdjPWvN8e7ORsFGDQ8RPUQEWGDYbbzXj/0s++zWef7Z1066CYQ2W
kh8+zvgl6djPZDf2M02Hny4ZwvwgIl+LzvwqwjmCf9agiRhsVEQ+lzX0VaWE
8UY0eMKRcHDGu170z1kTU36zTEz1ekNFXa9L8Ajxyz8K8tsnIO8MFabYjAmo
FqGIGNmqog+7RNh85ovWwisK5u8TUY/3FCDjNl4kYh1tZjzqz48mYurXeBZ/
q4I861l9lQr6ewub34cUNt+sPzMVeIckVJk/8xQgZSc2u0An9zIV2En0+kqA
ZQQ3hcFD/FLqwjwdIfRfajbrZ4j5z479GwsxvRyIq8Mc0/xXTUz7BSokE73u
t6NvoiaOzVcM03m4rjH97divMh31fduJ8feamNbdoqPfVzuwP2061n+Cxbuk
s3m1Y1xLBPn1OFE/W4Tp6UZ+WRHmXw+MkH+P69jPDraPftExT3A+ntfpTM/5
qGeBzuYtB+8nMr5Zubg/czV+f4D4YauKeLEf+ZxSoI4sKp+AfroXBMK+/z4n
q0fG+WhwIG6U8bzQAdfIfio28RwyX5NNTPksCjC/uNCXDwSwvytFjqlfJIlj
yj/Jy/xnYurnCyam8zZNRh3XeVCnXBn70SJxTPvRJP4fH2H752IA609zQ5Tk
qw/Aze7FVSnfMj3aAhgvXcD8xntE9SgRgLbRJeP93Ww/eWX09ZAT45fE3kcn
7vOojPN83on6fSCDSASqcmE/O2UeP/a+0fuDLuTzdJDPK9VbDXL+9P7aIJSQ
Qepk+2FukO1XEd+jLlOfGKZ1ZXg5xvw+OELe3RMy+nGSn/NH/f3cH7S/mX68
n14xAdPf5/txfpsrcH4aPZhvZwXy73GjXqvY/U0Svgf3KuBl+uB7sN/FISgl
9fX7cV94QjhPc/wYr5jtC8WH+63WxNhvE1O9CsL492s/0PX1aZjPC+3vcBj+
A+kU0+0=
                    "]], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}}}, CompressedData["
1:eJxllg1MlWUUx69ISETMioyBoTayxKhZc0lw33veD0Yoft/3frwfV2GU2goM
mYXd3MyUyGEUNnJWptnMrdHn0lkyFTHNMrUmmbBi5VfYF02ZUtTzPOfc95nj
bu/ufjzvPc95/v9zzsOEypp5j4z0+Xwj2NPMniT2TGtUF56ZUwxLXv4tHigw
IcF76lqyki/Ph6qiH2c3hQEu3+28tN+cD5HCTw4tz9A8jnKOGR7v/Pvf757e
WAK5a/rm7koJejw9PWlyw++Snw1Mje1+0oRPOS8pgYYxp44OdJjQ1Fp98+o/
DVxXQ8PYxz/jVci5rycvpdCCjIKP3vijNIBx9tkwiaVx6bwCx+84fWVlvw2x
3WXpSUcUSOt6e6k/3/G4/sLEKalxyTfw9asOGOsePzcYBehdkdlWWuHiuq0C
o94VVS5sLWE7GRosW8wEW+Ri3rqOPOB4zGVpf0py95WVj33ebcMT5wZ3/LWV
ft9qw5dbeEDV445LTMj7Je84OOPBxl7wzpfg4M/vbDqQ6nh8gp/3IQfe5XyT
ijrNcVD3kGSRf7LmscjvWxVeYzLv/cEexkLHfA1mVY6OFP5iw1QuSK0GX7Bt
1NEO6v0wnafUgdcPjP+g9gUNxnH/Z1H8Dg3eG2tVFS1w8Hz9GvpZ78BVJksd
Wxc+NztwhOvRpKEPW2T8//hnu+Ptn5ey6lW9z4GLc3flrimi/NJd4GWxqlNF
P7NdULjxPSrm63MxPmMuk3rewTo/qWI+xx0YxcKuG6tivIsO6uQDrJ/9kkV+
EyQLvZ6zYUNWciijB+BWXi//WJjfMxruk2ujPlkalHFfUmz8PqvC6r2sEk5a
uH+3inq8ZWH/3aXB2WPMiDYZT9Tnh8NZ1OsMir+Wfj+K9K6w0M806t8baT1M
/oyzsJ/fJD8DFvbZCB1cHneyhXEf1WAB55YonjNPRz32RWi/EvIzQvVnoH8D
EdKLeFHUY7F/l2ThF5Behwys27jkRH8lWPTDT+SfY6Bf81zgX2kNOsbfLFno
tIn69xYD/Wlzcb5VU7xjLvWrQXnF8HuhjvoVxFDPF1XM754Y1S+gL4Mu8OOP
OUXz6FcXWLW3ZBl+8s3Fevm6GPXUXcwjVEw+ucDlzawuQh0Vx3v/DK+HtVRv
MxXMZ48Ftdy39zWsp6EQzo3DOp3HxP64js7XbKJvkww4zedTueQ7eX+NlCzy
mR5E/bo00Pnfrye+TXI232CKeu16KVD9SRb1fFSy6LdME+fDK4A6KCa+NyRZ
+JGkXcv9NC+/CeL77SrE+X6NQazfCtKjLbFO/cTuI+HbNg36uB8P0P3j0zHf
QhP6T8xkmdF8n23ifbOd5nncxPm0WEf9tpnoa46OfrL7LBE/cb/l8/e/p3zu
DZGuGupth7z8xfvLQphXH82HiSGs91QN76OvpD4J9ovClyx8KAvAxyzrg5+Z
WI8bFS9/UV/rFa8+Di9v35xdo+D7OeFhjHoo2L+tYez/52m/DWHMJ0Z+1ISx
H9NVvA+GwuhXJfldHkH/d/pR92kR1KtOwXjlNC8ggPOtXjL6LRnv2SjwbXI7
/SDGV2fU6xfUMQq3W3xCyf93/gcwRuih
                    "]], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}}}, CompressedData["
1:eJxllAlIVUEUhtVsIURK27Bso03aIwlLe/+d96Rs18gyUlrJO/MyowWzMqJM
SiorsyJbLKyMiIg2QkssLNowkfaIMpVsAZOMLKOZe6Z7IR/cd993Z945//nn
nNtv8cq4ZW18fHx85bVAXn7yyu3hHx/4KBI+6lMh8D9v6HJh0rsQF0rW7O/h
H+iFKJY/Prjo+VeBFXW/ihr2AbeOh4x8Uyxo3T8ScwKHXzp6m9scOn/phLfC
4fGX7627+cpE5qfY673bupAa1fHZqcsmJspbaqJB+U+YWP9x0OgO+QzqcdQ+
k/Kd9KBpyII9ZYWtuefINwPaGR6o8MfLTZwtnzpuh68Hd+XNqDCpvkQ36a80
kdXtxeMfwR5cUfvrTdRU9H/187GH8vXmNlvrKf9xPcft7zKxn84fKmxW6RYW
OZyu8jUJ0ucbjeCtpfcLEryteHXy3i8bXW7Ir/CkGXp9ESOuFbT+lmFguy0H
3PsFvlVOX9zpEMMq5V+OgJLdcS4jP3P1/j4MssrZ1QUC8yKkM38Mqn+n1jeG
obrwyJ2+qTpeGsPJ6KuNLfMEnQMYlIwtsTp+d0b9EC+g0qSWGOTHfAHreMt1
fCZQq/yS+az6wgQ82d66Xzu0ns6C4jSB8g8T5FOzi/ys4TZb6/kOn2uQQpdy
XGtsqUo7DOw+mBK0NZIjPOlGTMAYw+bmDF68ZonDaaqfzms9BkdXGS69yoBl
ewzHGdUvDQbpi9Dn+97ANHWeAzn5cscg3d04lJz0sQyjlD+hHJ9lO2du0P6M
4AiTZXyfrM9nFic/jjHyK07rq9Z+JGj9QW7Eq/lZ/i8/g5Jfuk7HP8KQUyYX
NjvxrXgZHHLKZu7KYuT/MR2P6fO8yNFetk32awNzVfxbrdmaj1AnHvWDYfP9
AhlouMNPZDkZ9YD85sXbHKb5dbiXmv9rnPolysBLtf+5jtdi0Lw+1Vyi+7eK
U78kuKn/rjhs/T/ZYevej9O+tbr+P6b2R5//bxNXVb9EAJVKV7OJAL+h8hUw
keapD7fZei8tc9iavzKOGPVgu9abJ2y2+umjw1a9g73Ep0F+TfHSfOS5bH6g
6k2Mstmqf9ME6m//1my9Dx867+e/8LeRNg==
                    "]], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxllHlIFFEcx63EImI7sTDXMjKVjt11Z2bdza1fWYRdlJGViYgpOe9ttklI
dBhiERadmv1RVhpBRkmFR4Sl2ElUyCZlipWIhoqVnXTSvPd7zkC7MOx85r35
Hd/f9014+tbEzGEBAQFDtGujdg3VruJJgUmmp3EQwH5NFP7nx2WLaz7vccHt
7UWTAk0e/K9xwq4JlUs63lPwvPtVMZATC/XnQiztdRTY9j/Fblhrmn2j9C7R
2ZycMfcNNdhV9Sj3TpsKB4JfPfte5AKve+TLC1UqdDdNa/vxWsH851WQU28l
jEqXQFv1uk+I/Wus8C0q5WjjRX9m20ZOtAELf+6BCnWs3hIbPFzmKFzQpGLc
tzFYv08F7Wlal9cG1Wx/rwozeUAL5gsjOvP17P+4l4j6bZjfTHVm6dIqDN7J
8n2j0Hnx9L2pVguML2h4XLbB48eRthFXQkPs0L97vpy60gOffCvSx7RIyN0U
11vtEBGUfzK+iEK0lvZrlgTbmH7HKDC5hvZJqGcxxT6TZWAqdZZRuJ6Tdbz/
jIzPD1IoZ/OQZKzDS2HRITZRCZ+vF/lCZLC0Tw/KX01hR88M2wiPjD5IovCE
DdSsoB7JFLSoOyeYFIy/kEJJvBbwtIz9RVPY37f6Zth+CesZK/x21YH5Z4l4
pU7Us4vozNfPGHx5QBMmg2CczFg4cip7XEEcEf04dN7C/OlTdOZ+WqhgPQsI
xv0og6bK7vkJBP1TK/Ryivk+l2E5m2cEgVDm49EK9h8s3rfKYGX6mAkoLH65
hOtzCHz507yjJ0jG+awiqMdGCfVKHKzPjvk2EPRrrh2S2PnZPJjfDqz8hlwC
qw5rd5skONb4NSplrxGfx8sjOL9CCfU/K+IFy6jLNQKT2SA7ZFjH4tf7Mz8f
aUY87q9Lis78e+B26Mzned8BbT/ySN0+g/H8Gsx1qxXzMzugle1vGZynjOf1
BUF/hgr/Nov3u2LQf9UG8/ezDOZ9hxP0X6Xo/68Ko7W2PgwXfvitol4znODT
PjN5P8X3oMGF52kK0ZnHzTSYn79Ggn49rGC9JVRn7qceg3m/kR7kFbGo11IP
zm+YS2fuh7lxOvO6Q+ahvwP9+R9CWIsK
                    "]]}}}}}}}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 480.}, {0., 240.}}], ",", 
           GraphicsBox[{{{
               {Thickness[0.0010416666666666667`], {{{
                   {FaceForm[{RGBColor[0., 0.478431, 0.23921600000000004`], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     480.}, {960., 480.}, {960., 320.}, {0., 
                    320.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     320.}, {960., 320.}, {960., 160.}, {0., 
                    160.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.8078430000000001, 0.06666670000000002, 0.14902], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     160.}, {960., 160.}, {960., 0.}, {0., 0.}}}]}}}}, {{{
                   {Thickness[0.0010416666666666667`], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     480.}, {240., 320.}, {240., 160.}, {0., 0.}}}]}}}}}}}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 960.}, {0., 480.}}], ",", 
           GraphicsBox[{{{
               {Thickness[0.0016666666666666668`], {{{
                   {FaceForm[{RGBColor[
                    0., 0.42352900000000004`, 0.20784300000000003`], Opacity[
                    1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{0., 0.}, {0., 400.}, {600., 400.}, {600., 
                    0.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}, CompressedData["
1:eJxTTMoPSmJiYGBIB2JmIGZkYWZkHkqIgRHoaIaBdQMAS8ME2Q==
                    
                    "], {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, {CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQZaBQ73/Xun50kUOyxy3fb5r0qBw5YTZfvmA/nC
zQdOLZQtcNBuF7t5TrTYoXzffCl94QIHIZA4f7FDUcbEtzXf8x14dTfNff+/
yGFGHlBmVj5E/nyRA9j8GfkOny75JgnMKHJofR24Q25qvsOy2UcUNlQUOYC0
23fmO3Q6Jjy9AOQDeaZxm/IdqkXWuT9Mgeq/kO9gy3V9cYF/EcQ9b/MdFDYA
bQ4sgugTKYCYkwhVr1bgwAdyT26RgxbI3doFEPGyIog+Q6j67iKIOywKHKpA
9q0rgriTp8DhHcgdVVD3sBVAxBcVOYC8f/dHPkT9sSKIOyWg5l+D2m9SAHHn
zyJIOAL5D0Dhy1UMUQ/kP14KtBgYvujhDwBPyaXl
                    
                    "], CompressedData["
1:eJxlVQ1MlmUUZeSquWJEX2gNSawcEwtdmSWVV4uwOURpc9mIGeVGJd/33PuU
ljU2p4lm5oiVzp80FQdlStaatUnUyhqlox/GrBVJs2ZkgJmFrex93nPQLdnY
y/2477nnnnvu/fKqUuUL0tPS0hZHv+EZ/3yvcuLL0qrMbC+XL2trf7VTpebn
v5sHEl5mTl41bf5nKp1PHhs7cbiXxa1brircr9JdtmZdst+k8r17Lkl/S2XC
d9deuLTTpGHksLkZdSpvf7qodcsuk3XJrGVtO5l/n8nOjR+NbmlT5F1jcv/D
Rd1lEf6+3Gd753yuMrrFquvfV8kKPB5T8HmD9WerFIY6zSqNAedulZj/iyrV
9cefmVqg8nRid8kRp1JyZEli90WsU6qyPvDIJP5E9purkhMIjFD0Wcj3LlA5
ED64hfh/OeCnVH4MhU87WRj0OaDQ44yT6L+TKuca4j4HHo8b6nU54Oww6NLi
JOp2X26D4fOtzF/OeLaTW0NikUnHmG8Ha/Md9Il0i+tkOvCvVHltIPrjZAp5
2Qrcj1PgUUD+O1LIn6Eyff7RjjH3piTj+r2b+2o4t1LGL7H+r0n0u8BkSuBR
lsTnKziX4hTmUM+++lPIb3Zyx/Cu7W6Sk3F12YcPrXWYe4WDD4ap5AU9nhjq
V2XltIjQCierwrNJwaPBwX+7FO9tcvJDwNmg8kXoc4PDHPqdbCt+5/d/mhi3
s87XrPsynzdTl5mcYx198rwDnzX0T1Q3ntdhxt0O9X6hjwbIO81Q74SDr0Ya
+PVQjwn09UHyG2/op4n8Kg06RvrEflhpsiTg1nKuPfTNauafYv4eh/3J8tA/
4nd70PtKL5cG3frow7EeOOkq7wbfTPHy4R/5FWtz6J8KD70zz8WxThfTz/O8
zAh7MOgQF3v038t+y5nfwbk86rGPrezf+bPziONa8jlEffd4+Oro0Lw89J6j
58UPhPvSxTv0FO9Am8c+LOI+v0n8pKLPVzx4VXGvN3vsR7Qvv4V+n/OYYzn3
2VivjP3fyXgq92c844d4FxLEe4HvJ6hnO/PTqc+pc3F8xwZVPgnv9/BOFnHO
Z4z1DPPIIP5thn5vYL838b7c6OGXWbyn0z3mUm2Y22Ue7+0lXj/xuwx++cqg
658GH71u0OM07/Vy+vkb4j3CvA8Y1/DZSPxq4q9m3oP0+0KDLlWGOZSw36XM
v5r3cJPJqLAwx1QKwt04aLgjjbwX+8nvrvPjeL+2cn+y6Z8k/59DvHnsO09x
Vycb9noc8a4zzKtl6PuAfK4w4Ocb7tJ23sd/+X32k8EPJ/XsHOO8XsU+jvDy
/+/X/wAwLEGX
                    "], {{277.25, 304.707}, {276.43799999999993`,
                     304.637}, {275.53499999999997`, 303.688}, {274.801, 
                    301.855}, {274.168, 300.465}, {273.39799999999997`, 
                    293.18}, {273.52299999999997`, 293.18}, {273.02, 
                    291.012}, {275.789, 290.094}, {277.051, 292.879}, {
                    278.93799999999993`, 297.98799999999994`}, {278.949, 
                    300.16400000000004`}, {279.074, 302.332}, {
                    278.78099999999995`, 303.97999999999996`}, {278.062, 
                    304.777}, {277.25, 304.707}}, CompressedData["
1:eJxNU2tIk1EYHlNMIv1hEVZqU8JuhA21ixE9SmGxItT0RxcZo8twbvt2zvnm
yCjKZNmPTAoqRIbGgkpUokQq1ggpkRCVQuwmIpISEcOkpKK+s/cE/Rjfzjnv
+1zeS7bDW37CbDKZYPzk19LDnC1lHFPh1n6LmeNNYDbXupujfllX6aSJI/6+
neNaemJV6gJDtjwXchw+vmPi4DTDC9vWpuLNHJeK7dPDvQzVj/ctMedzimtj
aJL3RRynJZ6f4aYnrSEKjsbPZX1Zxxj6sox/JzlSNz1o+2pV8QHFn86Id4Tj
peTp8EnZJlOuoPuN6hwQKJ00GLo1yrsoyM8hjfCvCHTs6Z37/c2LL2d2FVZf
F3g04I+ESrzYK/PaBa4+n1939IkbRQ+Nh7AgX69dWNoQHWy/JYh/Ww3dRwSc
LRKphnB/KLyuGopP0Ynf7qJ6rNIxPvS9Yqqylvwl6ygxPjk2D9Jk/CIV/96D
G7I+STruxUYPONK95CdRJ367l/LNOum976V+OXRUygJylR/RSd96N/VvhZ/0
RVy4Y9D0FPmx1prcmfHRhThsvp90VripnhY/miV+0E04Y0pP1EP8TMd+mTev
9JQr/Vs0ii/VidemIUMOymodOxeP3daCGuoioZV5MYHhnHcLZ19pkOUOzah+
5vkof0JgRL5f8FH8uOpvq4/8DgpkStwERnqN+qTI+WlW8/DrH77CmxWQdpoL
GDYEl48Pdav+1av8WsX3lpGPKoG8D2uSzhvzHs8zzvG8P2o+CwTcn37ejY0y
0m8RNM9hRv2yKD/nGO2FMa/xfTnCaM4zBflwMsJJU3x1jPwmKD2XFf4Ap74+
ZTRv/ZzinzE1z5z8zqh9aeTU1zlG9T+l9juR03z+t+9/AejMx9k=
                    
                    "], CompressedData["
1:eJxlVg9MV1UUJixiVIzA1NV0/lg6I5uQ/UOETsMCV44shWSJzdH88d7v3304
3ruP5mbk0loTEkoxQnRkDCnHJMWKSJwabmSSERhDRoRgfwQV54rVu+87Qpts
7O7ee9453/nOd8/5edYHX3o9PCwsrNL5V6v795SkH+LP39g0ZtCi3gcjNidJ
rFcM+vONpx/PS5B0ZM6WSysv8z5e0hll/6tBzumROXESa5dBn+w+PvdguCR7
+mcZ/S0GmS3V9y+aJimj3zmpNnAeIWnbM68NnvGyfYykY9cWvLo90aA/lP/p
kjKV/Q2B9T6JuGOCdsy6PTt6psR6ScB+FvsfEMgjViKuc5+bn9KXdQ/bjwr4
iZI0dnbF+pirgp5/0kFSbSGffIPmHjS8ZSmS+rLe+zAQYZDLz7gFP2s53y8t
mq0OqgyKfqSx6q86iy4o+0b+3mT7bgO85VkUV9LaXjNsAEeWhfwjC2mrWp+z
gL+T+U+3YFdrACdZtPbo8rvDg8xnOttnGJSnzp39w2/P6O5IMhBnjQVeI9ne
z/ldFuD5EMffKShRxZuwKDWqa18oRTAe5qcnROes4flJ2ayHuBA1q3xyJRWr
Oh4NgB9N0t5nv7gysdBPyYdOFbVskLQzEFvS+qYPeFZIcqJrX+3REfcxSaUK
yLu37l19REvwu04nj+LzmkUnVaFKdeQzYCHvah1877Jo3Enr2BbfLXu3PoUW
8Lb7EC/XIrXEH/YBP03Zu3mPm+D7uk4qneofTcpWji5p0M9ek7YrvIs1SlO8
VZh0l7OkRmnkH/q7bjRk0ryIzRXpQwXQZ6YJP09o0Ft/EQ3UOgV6UQc/s03w
c4HxxZjAI33QQVMR8q3X8R56i+iEcrSK8YwVUZPy78R34zjfu/UqK4BeHzKR
57ICrPkm4kcWIP4uk7xlDtJmL/C1mXRW6WXEC/89jMfD+cSwnh3/Lr57LcpR
/HzOeBIs+L+oQT9Lrcl8XV16LVK0pabp8LeJ72N06HCHRauVv04NeR7g+h/Q
UP/TFutFm9Svm/+jGuqfzP0sXgOfGyXqVaghz6qbetTA02FJSxRx59n/93IS
r8vnRd7/rEMfv0gSCuieAPD/xP1wRgj7fyR1d1x/eeDbIPTnscnpDrElq4Lw
n2GDz8EA8ObYsN/mh+7W2dDPYtbzGhv5jWjAudpGHnWc72kb9Wjg99Ru4z0u
8IE3Z/+NE7a33MfvwCYFp3XcN2nv4lnpB95pxTRfxd/tQx9LKYb/fn5vwWLY
z9Ohp9Ji8JOpw/9bxZPvy+UjxPbD3A+S2V+Nn+eMje+9AfDzNeO5Lch91UZf
aQtSgupz+2zWfwj2VTZwmiHk876NPBpC6ONbbdQtTODesoGTBOq20QZPuQJ4
Nth4N/UC+eps3yiQr8H8HhfA/Y6Nvnjz/gPGc1IA734buu8RmAev2OjDn/J8
SWT7Ae7/Hq7nhIE632kD51UD/fk3no/f8fw8JdEnGwyeIxLf+bn/97F+E3n+
TPA8Lxewn2lzn2X+FjKenBD0dgfvy0Lw4+jd5aWL+d8vcf+AAO+1EvPII3Bf
w+8reWrv+lkytXf5XSowNyrZfzPfV7D/LoF+Ui7RpwZ4vpdJ5oX5/5jtB3m+
10uc97C/Bok+0y2QdxPzeU6g7m38+6FTkE/18w7GO8Lz8QT7/1eg33/E7/8F
5reQ52cl87+c7YcM+Fkmod/fDXyXxvN1lPXwv99j/wFFn1ST
                    
                    "], CompressedData["
1:eJxTTMoPSmViYGAQBmIQDQZ/kh0uKN3+WfeuyEG4+cCphWeTHcr3zZfSf1/k
8K7G3jRuVrLDjDyh5gMPihzegvjrkh2qRda5PzxSBBFflOzg8bBKZN3WIoeM
iUAVnCkOO+VaXwc2FTmosTVOdZZOcXi8dPYRhbQihwmHvmrEaKc4gO0Ngspz
p0D0CRY53PlZl7VHJ8UhKsX6vj93kYPVlhNl+7xTHEDUfJYiB67riwtsy6Dm
WUDd05bi4A6yPx1qfn8KRF9jkUOBLVBHR4pD3C5PHqbbRQ6qIPv4oea/LXJY
5Lrt818OqHuA/t8KsocpxeG+f+/0PCAfPXwAlnOEaw==
                    
                    "], CompressedData["
1:eJxdUmtIlEEU/ZSQkJCw6EXJKmEPERWKwKiOhZRFhAX+kCxZE74HbvtNUPFd
EexB7I/KJWiLCKulHwtSIhK9WCJ6SIEsRciiZraJhGxRSesSQjN7pz8NDMMw
Z84599xb6j9+sD3fMIwKudU5ceBiJNBEMNT6JnAq3ruqqpGwvXAkGkwLXAsU
n322l9Ax/Sf244sALb23exIanxA4P9P4sGQD8RkTjPMRqsbXFnS3CXxS/Bs1
vlxAsr253UbYtyVU1xoN4ue7/f7Flwjrahb2rW4OwFP8Vwlj2S77aZ+DosqB
m9/DhNrBoZNxx0GibDTb1aP1GhyY4XTnjm5CXetUoixjs+5RgrtNFnDLxqMS
iawlvFKCm2zGL9d+DBsfTn8tr5n1mP+thSXKX8xDcjhzKHXdYnzYw07Ff8LC
muZjWyd2efi9/vDl5yst1pP3XC4DJtdzxmM/901UXFiWHE57eK30h0yuu4OY
P2ky/0ti/pSFiMp7jFCteCtt5PozR2h53LAoX9aX85clyF+bjwiH/eR1so/6
AO7UP/g1P6vrPRfkPOMEX78wwyGX9Z8QrqxY0FQUdZG6e+OFr59Qqt7HXdYb
JJ6DKRcqxuA/fMZFDv5R9y/lsv8Zneeciz2TUnGeEFIBFArOo0fzRQT7t/T9
veB/fuJ8PgvmayGodvTKefx/Pv8COAIxWg==
                    "], CompressedData["
1:eJxTTMoPSmViYGCQAWIQ/emSb5LAmzIHBhB4UeQg1Hzg1MLnZQ7l++ZL6T8v
cpgswRLG97DM4b5/7/S8B0UO1SLr3B9eKXN4W2NvGnehyGF6HlDHtjIHPt1N
c9/nFjlcrXipZrimzMHgrgpbo2yRg/vDKpF126HqHxQ6LHLd9vkvSzlEn0+B
wzFv807HkHIHl+6c57935kLUu5c7CIPcsTPLYYdc6+vAnHIHILlDDsgH65tW
7gDSlpCYDXHPinKI+zlyHGaA5DeVO/iA5N/mOBwHKVwE1V+Z65AxEeiS+VD1
DHkQ8+eUO4BsfdiW55D7/PfKj0HlDoe+asT0pxU6gMPHpdxBYUNRxsSZhQ6P
l84+omBUDhH/VQhxR3c5xB/LCh08QO5vLIf4916hA1D26YUkqP2qRQ5WW06U
7RMth5jTUwRR/7cMYv7JIgeQ9PwvZRDzbxU56IPC8XMZxN0vixzQ4wsA2srK
og==
                    "], CompressedData["
1:eJxNU39ojWEUvi1JaAl/rDvmGtlKmisSWp5pmoWWH1k0WrfpfVsMZzKNbiFl
dNu0NCVuiHIzrm22tc3aLzYLXdev7q7PbEtICKFLyvt+79Hnq6+v533Pec5z
nnO+2b49G3cmuVyuxerV3+qe75lFhRIfD69csuM1IfQlut6XK1FXNvVY1ytC
7qldb397JSqn38gbeU6o0fHzJVz6GSTkFL+JpGdIZFlzxx/pJtweONAZXCSR
PfHF5b2NBJt/jkRFZ9CddZMQTY8n/G6Js5o/RDj+YUNrWkJgeZNKrOf7X8LE
33Wwvg4+IBQmL2g4/1lguCBQV/aUcGl187c/7zg+RtBls0cF1i6tyimOE35k
FlX3WMLofcn4sYNXaf29AnkjqsM46+1lPTHut13AEyZ5+glhmT5vEdhWsmK4
4CHnN3L9fgfb/F1kdNwSUN0OXmxhf0ICVdq4JjK+X+B75dc+bVyNg2fqQrUC
h7T/DYShhL+044Qwec2EDO+E6zOOcr02wid9XimM/+0Onqb5uh1sxw8Qtrfl
T06qEHh28P08b5T1lzO/mvc6rX+3QL9uZIgwduVcn6dE4J7Gyj977luZ3yLD
6xFYqM8t1p/K8+rgfZnF9cNk+nJzfj33lyJQmzJuS3I5xwv2y0cI6MWMCKzR
88onxB793DR2RqI1TW3SZjJ1A7xv1xx8VckOq3qT9H6clLDX6P4/P6XhjxDu
7FeV/dLM12J/SyW+qt9iyijr+e9/+QtnxnWn
                    "], CompressedData["
1:eJx9lG1IVEEUhi8S/giL2CIiQsxMtmDbXe2DCvGEFoZIn0SISEiBcO+M3jEs
yiJZQiNiMxGtCOmL6E9IlEmQiUVGP8RWIpbaNCQkosSiIiTozJlZZjLowmV4
7jl75j3vmdnlNXW7D2U4jlOCr1wnbl5+mvOWQU6PqG0bE7Dx3vPG/gcM5NL9
TsC++aG7VzoZFM19fb0+KYDymxh8aSpeV50Q8Fmu6xmwyZnb0z0CHh1uXzIn
n0H5hjNbDhwXcG1r77ffVQwc+VQKeJn75tfJCzpeIWBZ5cHNY0MMxnec6+QF
uv4NrWeFgMfdS8OpLAaY/WEk4cPKzOaOkpgLq1sWJ4fLfTg/+D1YVefCkX5M
LNRx5OqH27MykO/LPrgLTzAtXmCY9COTHuRXRz/mR634JmlA1DDpsTicysts
jprf17ahE1ac9CB38UBsAJl8iPgg28hFfVJ2PGL0k4/IDbIQcl/26U+7kMm3
ehe+JipqFiCTP8j0HXlIGok8D8c0FfaVX1ac9rUYq/Zl+yZ/YWzgxVXkgFyR
f6CsQV/3i1x61pucsZh0CpNP/QoTn800jwbtB3Jc9jubW1wYkT4G9f4nPHX+
glp/lwet0rg1Wv9Fw6Qfmb6n9SOn6yeHf+6ZsDgh97lkmPT+h9P5f/VnMfU3
pfOLtd5TXJ3XPPEP0/w8DmXvjy26E9Lx/RyeyTmu1fFSruoVCaU/xFW/23Q8
wtX52Gny0/eL7ustDp68j4063sqVn72a93Klf1Qo31ZxdX5TAvAWBmIOV/MY
1/nW/8MfLAnpTQ==
                    "], CompressedData["
1:eJxTTMoPSmViYGDQAGIQfUHp9s86lTKHDseEpxfuFTmU75svpS9f5nDM27zT
EcifkSfUfECizOHx0tlHFK4VOVSJrHN/yFcGUXewyKH1deAOue+lDjvlgKxZ
RQ6xuzx5mJ6XOhz6qhHTH1bkUA1S/6IUol68yGEHSJ0MVP/mAodPl3yTBHTK
HFTZGqc6f89z8HgItMG3zAHkHCX9HIf7/r3T8wLKHLivLy6wfZXtAHJWgneZ
AxeI35btAHa/SZnD2xp707i4bAetdrGb5+6XOgg3Hzi1cG2Wg9WWE2X7Uksd
ijImvq25nAlxz4MSiPn5mQ6HQe68VOIQB3K3fybEPpZSiPnHMiDqXUoh5gP5
y4DBsGFDqcMEkAfvZzjYghTylzms+gj0SESmQ1SK9X3/dKj7p2dBwrWuzEH/
rgpb48MsiH9XlDkUgjQ2ZEPUryxzYACBP9kQdRuh+s/nOUyWYAnjm14Gsbeh
AOKeBKj6tkIHO5D9sWUQd8wvdLAE+Te+zEFxA9DHewsh9qVAw/toIcS87DIH
A5A9Zwsh8dtU5rDIddvnv0cKIe7pL3NQAOm/WQiJj4XQ8H0DNS8Oyu8ocnAH
yZtD+UeKIO4ygLrnchHEPG0o/36RA3p6AwBMEhxV
                    
                    "], CompressedData["
1:eJxlVQtsFFUUXZCUAoIoTQOKda0KbdS0BcFPU7gtEILSIFaCkM3abmfezEDp
vvf8QNKKIKAhKIWA36INlhrExhDSVjBa15ZYYwguJYRUfiFVS+XTIn6iSOK8
OTctSTfZ7N6Z++6ce865d+6NxZ+xh4dCodX+1/x2N9QeDvfbdPdyK//ccU2X
q2fPiHbadGJN75S8To5bbPq9szg2/jtNrXV35pzZy/nNmkLms8emzYWlvySr
NT2Qsv7tOfU2Pd70/cutczQF9ffbtOni4oMZt3H8M+cfUPTWu5V3bPjDpgkb
Ej/sLlP0V1akpm2sQP4tik79s3bFV2mCkpn+v42SXnC3X66usulghp9xRNIx
c/01rj9GUdfRv0u6G2wyj6+LKPrsqg98l02req5/evW0om8M/mqbcs/cn7L+
hgJ+y8ZvhiYDK3M+9ztFU6epP9qmT0wbYU1XDB8/WeAnU9PUvNTGyVGLzi3y
OzmraFvbn1mRfAv4KofGAZ8ZFpm2E49wv7dblGPwDON+QxaF92t3e4cErqZy
MmVqPuJ+15Yjf5Sijqce3Vz4dDmtNsIsVdBlejkFtKdr8PZrDNd7Fe0zfCRj
wPGsoq9f3DFxREuMzO1FxRL6+M87ZPBOk6QN3z2M7z4JnQos8DOT+Wy0aLIp
4Ciau6Wi5/q3Fp67TsEvFyzw78dB/UsW8JQNxgG/aySZdkp7LapK+3z++Yck
dC22gTddQo8PbPSXIqnI6HXRpgffSO86OkrCT2GBeqncDwmKfrng1uHtcTpt
+F0ooFtLJfyyTJAsGH2yfu8q4BaCnjAGqq0YEgf9hh3ys2WBqIB+2Q5wl1VS
s/HdNAe4tsSB+4qgdqNfkUS9dAd8Ps/6TnRo3MMHPuyrkqhfyvVekVRjhN/B
+XFJS0xitwO9SyTmbaQLf+Vyvxs5niXRZ5EHfz7H/DR58NPrXP8LD/V/lPBT
o4f5TGN/7fLg9+WsVynn1/H8uh6uNyrwlO9BvyOcP5fzuxTz5sH/rTyv73v0
8byWazcSPA8Ng/kLDQ+bOH+cho4lHvQu1Mgf5sF/SzXmo9XFfL/E+ybikrHx
7DjHj7mon6fR/1QXc/0b41/pQpd3FO4fd+HDxYr96YKPmdxfqofr/jwG/vyX
888zv+0u7h+T8N+bLo01ep/keY6yXv1D4+B8hwM+s9RAHPQ3Q2Ef9rF/mnmf
JR3Mx2Hm85CDehcUjTH872M/TdK8Tx3gzWY+lziYnyc15jTHAf9RTcrMyX9i
IMY+FwP5Ac+7Bb1n7o/n/ISA/3byvugXwBfhfTWB8WQrnF/gDOy3oH7uYBzs
07sc+PcS+92vF+yvazw/Sa6fxvtuD8/vMj5fy3gTg3HQfx/vw60C748s9tur
As+vZ79M5/Nt/L64h/tL8vtvpEAfJ5ifm96v/wMD2V+O
                    
                    "], CompressedData["
1:eJxlVg1MlWUUvrNmLRXLLK9JKMyAVg6wksKxDimZYSbaLubMGNzLvd/7/d5P
+zGbm5FL1wTEkjYypiYk/ZnDFvmTkANMggvOOQtGzLVshc4xs9bPet/3OYOt
2Nh3z/ee95zzPOd5z/emlrkrIxMCgUCd/FfP6vZrmWszBG39pfiLlLM+XTxQ
f2pOUODZ79M9E7e8vegmQfe9ceeFnm990v6jBmUNzp245YxPi9+0fvrzMwP7
23z6quGurMENBm2a/smS4fc53jaD7l4TXjhk+7Qsd3tB6TmDYjtHXn20Mk6P
tHS9eELGP/fyz+k5CQ/7nxG07sulkyeccen7PzaLY6WCAurvLZfecaZVnpwv
KJQ07/CeIhf1XDfgv8olGfWhdbUG3te5yLOR67mV43fHSG2/MsVDfSti9NIJ
uSDtCz3XV11si1Jfmsxc62L9UJTyVJ1TXapRceujlKzwNDnAtSsKnnKdMf94
/i3n9w/YjC9Gj5X+mEhbbyO/F0Odm+2xeqS3l7/bJk/tCxrg6YhNzylcJQbw
Bxz6LXNtdXvcgP9le8zOyLn5o2Rp67r98fX/2kdkOQ3+//2zVT9Hxm2dX9qa
10qDdtRJ4hM27Sv8fPRvz6APr/Y/VTZgIf+UGHiYbYH3B6J4f9wk2a1v9m6t
AN5GE/xkVgDnaovriABfl4W491dQZ5EswGO8eyKoP8mB3+/lVKD47DXQL9lf
8M/PGYLU9tJhGzpNFeD/Bgd9IQHe5zqUUHhDAu+TuX9Sbxpv0AHemKD1SkiT
eN1ifY7a0EORQJ2tBvLeWwG9uAbevxABP1/zOVvKeKeb8FsYQR0dJvjLjSBO
jgWcWRHw5FvQcUqE9W2hnsnMT6MFvQ+HwXeHhXPSxLbcD/2GgfcHE/xsD1O6
4s000f+qMPgqGrcnqfjfCeixM0wdqsDXo8wT8zsaA95rAv1tMdGPchN1pdrk
qx+jgppVnx9kPoMm6g85eC9t9MUBDzNNUmlOhlgP0sa5cDB/ZnIeaeu+zDKB
W9oal7T1OZS25lvamv/VDlWpwMkmcEhb60La0KcD3lNMUuNhUNpal3NM1PUs
15M6bmu/Dzhfpw0cFRa9ovr2OOOtseC/0YF+91o4l7UO+O7hPu/j+CMW+HnN
gR5KbPRzAc+fqVznGtbzAsY55NCAmp/LOG6ZSyWKl+dZ15d4voUdak2Ryszz
oI/ZDs5tlgeeLtmwMzzU02cj7ywP57Wb50LQA49dNvLf4aEvkgcdf5oH3G02
Hd+wK3jjPy76dNSG33kX8eXc0/o85CJui4159LGLeqR9WeFvdoHrMM/ZJsb3
Kc+t/fy9aOa59x7HP8D11buIu4PnXpULHZfb4HO3Cz2U2qi71UX/ySapuoNX
05mPVotUuIZs/p7ELOTf5OK8y3Os4y/neN0m9hVy/e2st20ueO3lc3mbR7cr
3neaY3zr/XJu6PhXXPT3V0FDT0vmazzwdUogbloc/u8KxDvKdkLg/B6Lg+cA
6/dgHPVnmyS7E0rq5PW/BOwZPuqo5vtAq488K3n9NN8HigW+p9LWcYt5Hp/m
+8EKrkfamuflPBflfULr/klB+jPazfeHJwTyyvuHPvdLBPTf42OuFHL+XvZf
zPGlrXlaJPC97mX/At6fYH/5PWhU+aSt+c7nevt86lf48jh/H/s/LKCDfsY/
n/PL+5PGMU+Qos07y/enjPH1fwEq9CVv
                    "], CompressedData["
1:eJxTTMoPSmViYGAQBmIQXb5vvpS+d6mDbFSK9f2LRQ7HvM07HQ1KHZbNPqKw
4VKRw7sae9M4oVIHj4dVIusOFjkwgIBcqYMMSP38IoeMiW9r7MVLHQzuqrA1
9kLlI0odcp7/XvnRr8jhgX/v9LykUoelIPN0ihzA9pWWOjwGCfwodPh0yTdJ
IKTUgU9309z3RwsdhJoPnFqYDlW/r9BBGMSvLHU49FUjpn9bocPWE2X75k8q
dVjkuu3z3y+FEPvmQNXrFTkAXen+cFmpA8gbCbFFDoobijImtpY65ILcs6fI
4T7IPWFQ/10ocgCqenohqNRBAaQO6P/JEixhfP6lDtrtYjfPXYS6Fyl8AH3A
iKY=
                    "], {{238.277, 297.52}, {239.04299999999998`, 
                    297.59799999999996`}, {239.97299999999998`, 
                    296.89099999999996`}, {240.42600000000002`, 295.895}, {
                    240.91, 294.828}, {240.668, 293.812}, {239.875, 
                    293.617}, {239.086, 293.42599999999993`}, {238.062, 
                    294.129}, {237.578, 295.195}, {237.094, 296.258}, {
                    237.336, 297.301}, {238.125, 297.49199999999996`}, {
                    238.176, 297.508}, {238.227, 297.51599999999996`}, {
                    238.277, 297.52}}, CompressedData["
1:eJxTTMoPSmViYGAQBmIQfd+/d3rekSoH/bsqbI2eRQ5a7WI3z62ucnhXY28a
51XksMh12+e/E6oc3B9WiawzL3IQaj5wauHsKofW14E75ISLHOy4ri8umArl
/y90eLx09hGFC1UO3uadjgm7Cx2EQepvVjnskAOqmFbocLXipZrhoyoHPt1N
c99XFzpsOVG2b/6ZKoec579XflQrdAC75x7UPPlChw7HhKcX3kH1ixU6yEal
WN9nrXbQBrkzEqqerxoiP6PQoXzffCl94WqHi0q3f9btKoSo+1nlcPirRky/
URHEvHNVDrwg+92LHBQ2FGVMPF3l0AkS9yiCiB+Huh8YHujhAwAjvJH8
                    
                    "], {{323.22999999999996`, 289.99199999999996`}, {323.371,
                     289.367}, {323.512, 288.734}, {323.605, 288.094}, {
                    323.91799999999995`, 286.707}, {324.191, 285.332}, {
                    324.47999999999996`, 283.969}, {323.26599999999996`, 
                    285.641}, {322.262, 286.98799999999994`}, {321.828, 
                    287.469}, {319.082, 290.72999999999996`}, {
                    321.89099999999996`, 289.613}, {323.22999999999996`, 
                    289.99199999999996`}}, CompressedData["
1:eJxTTMoPSmViYGAwAWIQXSWyzv3htlIH/bsqbI2JhQ7e5p2OCWtLHWSiUqzv
xxc6XK14qWa4pNRBqPnAqYXhhQ7VIPULSh2WzT6isMGr0GF6HlBmXqnDcZBG
p0KH3Oe/V34Eqj/0VSOm36TQIWPi2xr7uaUOO+RaXwcaQPXPKHWQBZmvXehg
ueVE2b72Uof7/r3T8/QKIXQHVN4VwQe7y7fQIW6XJw9Tc6mD4oaijImhhQ7u
D4E+qC912AkyP6oQYk9NqcMFpds/62IKHT5d8k0SqCp1AIrukIuF8ksQfLD7
c0odgKY/vRADdR+QD6ajoPyMUoelIP+GFDqU75svpZ8Oda8fVD6l1OEYyIEe
CD7YfMdCBz7dTXPfJ5c6zADZY1HosMh12+e/CaUQcVOo+iio+cDwYgCBEAQf
HH6hUPXGUP/6Q+PLvNABKGsa5wO1zxoaXh7Q8LdB8MHx5YTgT5ZgCePzLHTo
APnbrdQBFNz+wVD3uEDND4e63xEa/tGFEHW2pZB4hoWvBTR+46Dy0qWQdAPk
C4PSjSQ0vmyh/pGGutewEEID5cHxAIx/cDoTL3XQahe7ee5zgQM4fdpB3fO4
AEIXlzq8A/n7VIEDKPnMv1bqYMd1fXHB1QKHByD/XYKmB61COF8bZJ4hNLwu
lELSkTc0PM9DwzewEKLvFDR+46DqD0Ddm1zogJ5fAElDb5M=
                    
                    "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQffPc9+DHc3MdZKJSrO/7Fzrsny+lf3dCrsOhrxox
/QGFDrIg8fpch6sVL9UM/Qodjnubdzrm5DrskGt9HehR6OCY8PSCEn+uA5C3
Q06/0MEJxH+d43Dfv3d63pMCh0Wu2z7/Vcl1WDb7iMKGHQUOamyNU52joeZN
KoDYtwFq3oICiPl7EPyijIlva8TzHLaeKNs3f1aBA9i9vnkQd30lzC+05bq+
OCDPQWED0CT+QodjIPOfQN17v8BhC8jcbbkOnSCP3CpwALpaqBnonskSLGF8
j6HuXwINn/cFDsUg98zOdRBqPnBqIXuhgzCIBoafJcgg+UKIezfnOujfVWFr
NC90MADRe3MdrEDyrgj5DpB9wPBED38AsCXAaA==
                    
                    "], CompressedData["
1:eJxTTMoPSmViYGBQBWIQ/Xjp7CMKkyocdsi1vg50KXQ45m3e6VhR4aC4oShj
omuhw/Q8oeYDMRUOnY4JTy+YFDpYbTlRti+0wkH/rgpbo2Chg3a72M1zQD7I
mA1/ChyApuyQi69wKN83X0r/Y4FDVIr1ff9YqPn3Chy2ArXPj4Lqv1wAof0r
HN7W2JvGnSlwyH3+e+VHkwqIOTcLHCZLsITxWVZAxO8UOFiC7FeGyv/G5Mfu
8uRh4q+AiLMXQuz/XO7wwL93et4vqHselkPc+67AwZbr+uKC61A+0PxPl3yT
BC6UQ/y1F6r+djnE/fOg7vlZ7gAKpoR0KB/oXwVQeHFC3dNf4bAMZB5HgQOI
O39ChcNxkAarAgc7kH1TKxzA4V5TAKFnQN2/tMAhYyIwJGZWOBz6qhHTv6XA
oVpknfvDORUOws0HTi08CjV/NTT8ThY4HAap21UBcc/ZAkj8XamAhPOuAocL
Srd/1l2BuudUAcRfF6HueQUN/9MVDjNA8SwBjd+d0PjUK4S4f0OFw9WKl2qG
NoUQdyyE+te50AE9/QAAyMoYyQ==
                    "], CompressedData["
1:eJx9mHuMVcUdx1ckykNZhK1aRWVXKgTqk5eCawfEAraGWKM0Pimi3fs458w9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                    "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQHbfLk4fJuMih9XXgDrngAgf9uypsjZpFDrZc1xcX
BBY47JADyigUOQg3Hzi10LPAYZHrts9/ZYocls4+orDBpsChWmSd+0OpIodj
3uadjiYFDpMlWML4FIscrla8VDNUK3AACSdIFjnIRqVY31eE6hcpcrADmS9b
ABFnLnL4dMk3SUChwGHLibJ981mKIO4wR/BjQe60L4C483+hQ/m++VL67gUO
Wu1iN8/9LoSY413gcN+/d3rej0KIeX5Q/d8KIe6F8T8g+BkT39bYvyx0AJKm
cX5Q970ohJjjA+U/KYSEg1uBA8ga/8eFDgwg4ACVf1DooA1yhyWCvwxkvlEB
xB1A/juQ+VpQ998thPhPvQDir+tQ84Hh9RjksAsIvhXIwRcLHRQ3FGVMVC2A
hOuZQog5mtDwPwH1jw7Uf0cKIeboIfhg80wQfLD7rKD+OVwIMccFGl8HoeYD
4/uC0u2fdfsKHXKf/1750QeaPnYWOhz6qhHT7wd1z5ZCBxmwQQWQdDO9EBIv
/lD3T4Wapw81fzrUfiVo+E+Fhj8w/i1B6icXOszIEwKmuHwHcPrcXejADTTW
dlW+A0h04Xto+FfkQ8zNhaaXqflQd0HTm3QBnA92lzKU71MECQcbaPrxhup3
hqYftyKI+QFQ/9sUOUwHuSekwAE9vwAAcUN0QQ==
                    "], {{401.562, 
                    256.668}, {401.47999999999996`, 256.684}, {401.387, 
                    256.68}, {401.289, 256.64500000000004`}, {401.289, 
                    256.64500000000004`}, {386.039, 245.797}, {
                    385.66400000000004`, 245.418}, {384.15200000000004`, 
                    244.07399999999998`}, {384.90599999999995`, 239.348}, {
                    385.66400000000004`, 239.895}, {386.758, 
                    239.47299999999998`}, {402.105, 249.875}, {401.812, 
                    251.094}, {402.484, 251.055}, {402.805, 256.445}, {
                    401.562, 256.668}}, CompressedData["
1:eJxNkl9IVGEQxReJ0r2uyNZDhoqaUC9hPoRkiJPUQ2QspXlTQmQxkCgn9hP7
t22a9BAhi/RgIiEaBUmQRIWGilioRSy79tdELFR8CBOTCpGgmd0D64XLx497
vrlzzky2l0+cSXA4HPny6pk3k7u5Oc3QodvnFte/M0V5pyGHPvNMo793nw7u
NVTXtuQvnmG6+eN4f2aRobv17paREFNV7YFZj8fQ1paRt90DTK9UX2VoKvS3
bK4D+krobzDd2b6pIkV4V37i43Thi8NdO/KEew6/WP3XFNf3rkwe8zbF9YXP
JhqHrzPNelrb608ZiuRMrwUCTP2ZckN4qEGUwmNHC24dFC6Vo+Ya0y8pkyo8
96DzdZafybXn6b1l25BRQ1eZ0tWAcEnNQjhH2K0+hH/6i/dVX0EeNvK5zFTk
/Hz/gg2/wtFchL+uBc4OXkL/NvoXDmufFYaWtF4jU3afr67tJL43MLVrLuXI
x8ex3Euh9zLtV98Fhqa1fi30udBLfw/FVp/bkJ0ixoLodwvyesIxXaKJ3RuL
c1AHO458kwy1qmAC/QtHzzfwm4R9eIf+nIaeS/muEOo5oY8wVb88kpxgIa8I
5ivs06Deoz8L/j8wZWkeFv4vnKHzsLAPwmpr2UL9j5h/MvL5hPxdmO8X6F3Q
TzHJFiyEUw39kbUclf09v7j+aGUb6n9DPxv2/z+FclwC
                    "], {{
                    172.066, 252.312}, {164.168, 252.168}, {152.598, 
                    241.953}, {152.29299999999998`, 236.285}, {160.629, 
                    240.289}, {168.816, 244.14499999999998`}, {
                    177.29299999999998`, 248.285}, {175.92600000000002`, 
                    250.32800000000003`}, {177.21099999999998`, 252.168}, {
                    172.066, 252.312}}, CompressedData["
1:eJxTTMoPSmViYGBQAmIQ7WPe6ZiwNcNh1cdLvkkS+Q7qhhxrZM5lODxeOvuI
ApB/3Buo4EWGg2xUivV9bqj8twyH1teBO+Re5jlsPVG2bz5TpgNIWcLJPIfp
eULNB4DyDCCwIs/BcgtQwfMMh6KMiW9rpuc5hPHpbpoL5Pcf+qoRA+TLgMwF
8qtE1rk/nIZQDzYHyAfrA/Lf1tibxgH5qmyNU52BfP27KkBWnkPsLk8epudQ
9wD5q0H+uAO1rz3PwTHh6QWl7VD53jyHPpDBc9D4NRkQf/TlORTacl1fnAP1
7+Q8iL8iMxz2lkyWYFmXBwmXgAyHOJC9p/Mg4ZMDte95nkMvyLwKqPl/8xwK
QOYB+eBwBvJByuwrMxy+acT0H/oLNb8Sav6/PIcZIH9XQcOPId9h/3wp/bs1
UP8z5UPsrYfGF0s+xL4OqH28+RB6JtQ+Uaj61VD3iedDzFkHNR8Yv2B3bETE
P3p6AAAFaeu5
                    "], CompressedData["
1:eJxTTMoPSmViYGAQBmIQrX9Xha3xZYWD5ZYTZfs25zlMlmAJ47tc4cB1fXGB
7bo8B4+HVSLr9kLlm/McwOqPVzhYgfj2eQ7e5p2OCQcrHGSiUqzvi+c5MIDA
swqH4yCJnlyI+vcVDuqGHGtknHIdPl3yTRL4UeHgA9LHm+twQen2z7onUPUV
OQ475FpfB36rcOidnifUnJHjAKIOsFU6xO7y5GEKz3GQBdljWOkAVLVD7iBU
vUElxHy3XIj7TSsdLoHM7cp1eLx09hEFlUoHkHPnt+VB9P2sgLh7Y57D1YqX
aoZfKiDqtuQ5gKgN7yocFrlu+/x3C9S/SOEDAHzMhuo=
                    
                    "], CompressedData["
1:eJxTTMoPSmViYGAQBmIQzXV9cYFtXY6Dj3mnY8LeXIctJ8r2zQ/LcdgKonfl
OjglPL2gZAyVXwrlO0P5ubkOt3/WZe1xyIHQLrkO/Ye+asRszoHQwrkO3CDz
d0HVb81xmJEn1HzgFNT8vhyHbxox/YcW5jhcVAKaIJTjIBuVYn3/cI5D7C5P
Hib2HAdVtsapzo9zHFy6c57//pkN0c+X63AHZF9MjoMjyD3yuQ6904ESO3Ic
jnsDLdLIdagWWef+8FWOgyXIQ9+h9s7KddC/q8LWuDTHQd2QY40M0H/75kvp
352R47AfRO/JdSjOmPi2pjvHARwu+3Id0MMHADisi5I=
                    
                    "], CompressedData["
1:eJxdk11IVFEQxy8iIn1IlA8RGq709RJmJJFhjVFYZIgGFhGySIGeezDnVhYq
QlRQhKj0YD2EmC/Rh4RERIQbPlSEhAUhYpssabqu7rZKbEsEzZwzsuKFy+F3
55w5//n/ub7aC1Xn0xzH2U0vr/OtB4tqGhG2F2Y+zfmuIffMuf0TiGC+E18Z
7NlUcDFV725Yf/3tpRQ/PPJy8d8y5uMVl1Pse+7VdS3jkfzxZNsjhM+8DmnI
4/oiwqmsnQMPAtJ/j2f3D4ieeg86h37vOPtEw8KXE7Xrbnjw/vje26WnNURZ
Z5UH5YT+Irnf58G+Fx+aBjdo+Ho1vK1wAaEguCXjWtIFviYWRyjmuuvCREV7
d8MfqW914e7G9OqsBAKWrBrtc1yrb2l/TMHNSOWrzXHRH1X2/C+Eb8k29WZO
wVruH5P9EQU5LIi4mi8mpuk+9hIf8k+N5BOb/sQ1r4+tSSM2OojvsQ+zCuq6
KAni1aN9jSXEJo+Y+Els9BIfvqOn/4YV3CqlxlGZh9j4Scx2+YlNrsTtXJhR
8I4LxI/jZCzx0VBzdv88Wt3TyuZHbPwkbsnuLwvNITTz+lNZPyMIY58SJ39M
iT5ikwex8WkWIUCfg5MyXxhhnP0iNnPOiJ5J8TeIdg0pm98wQgfnnxC/ArI/
3bV59yI4/OySPMvl/H3Xzgvib4sGHqPngOh9pu28lcJjGlb+D/8B1W5zlw==

                    "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQXWDLdX2xR7JD7/Q8oWaDHAcgr8DWKdlh1cdLvklA
vv5dFbZG02QHH/NOxwTZHAewepVkB8stJ8r2sUPV9yU5PF46+4iCRLbD/vlS
+ncbkhwuKt3+Wbcp00E2KsX6/uUkiHr3TAcGMICaJ5rpALPfMeHpBaX/GRDz
6pId4nZ58jDxZzrc+VmXtedOsoMMyBzzTIg8W4qDKlvjVOfvUPPfQ82zzYK4
+0Kyw1agdfPzshz6D33ViNme7HAB5J6yLIg505Md+kD+9cmC6AtNhvjzaKaD
cPOBUwstkx1unvse/FgxC2K+MdT83CyIvGayw2qQPX+yHIoyJr6tMU+G+L8h
2yEW5G53aHi+yHaYALLfP9lhb8lkCRa5HIi/gPzbIH8Z5Dighz8Az4+pxg==

                    "], CompressedData["
1:eJxTTMoPSmViYGDQAGIQ/bbG3jRuWbHDzXPfgx9/zXLodEx4emFBscMFpds/
675B+bOKHYC8rD1fshym5wk1H5hS7DADRL/LclDYUJQxcTKCn/P898qPccUO
QNG3NcuzHBhAwA9qfmmWA1DVqYXOxQ7qhhxrZNKg5rsUO/SCDI6Aqvcodmh9
HbhDzjbL4dMl3ySBgGKIuESWwzFv805HoPmhfLqb5ipnOYDdnwdVb5rlYLnl
RNm+5mKHuF2ePEzWWQ6Pl84+otBX7FAtss79oRxUfU+xQzHIfa8zHS6C/NlU
7DDh0FeNmNWZEH9MgLp/MoIPVt+Pxu/OdAA5J2FpMcSejEwHRVB47C2GuLMl
0wHknPkfih3U2BqnOgPNv+8P9KlAiQNIu/3FTIi/IkocVn0EevQD1PysEodF
rts+/wXyPR5WiazLLHHQv6vC1hgKDR+fEoh/I7Mg5qhCzQPKg9UxQvmBWRDz
bhVDzBfJcsgFxc+hYog8Z5ZDFShc9hU7cF1fXGCrBo3PnVD1DlDzNhc77J8v
pX+3IcuhfB+QcbwYEo7roPzD0Pi/B42fI8UOhbZAE+9kQdy5HRo+X6Dhj5Te
ANdEJCY=
                    "], CompressedData["
1:eJxTTMoPSmViYGDQAGIQ3eGY8PQCX5VDccbEtzXVWQ5RKdb3/VmrHKpF1rk/
rILyf1c6HPc273SsyHLoBKl/U+lw89z34MelWQ6trwN3yN2tdFBla5zqnJ/l
ANQksu56pYP+XRW2xkSo+iuVEPOtsxz4dDfNfX8Vqp8xy0FhQ1HGxOeVDrd/
1mXtYclyEG4+cGrhT6j820yHT5d8kwRYqhz6D33ViLmcCXEXV5WDGsi+3ZkQ
839Aze/PhNgPNO/x0tlHFAoyIe64XQnRF5fp8MC/d3reKah6+0yHdzX2pnGH
Kh0YQEAlE+LfvZVQd2RAxK9VOqz+CHTImwwHIZA4c5XD1hNl++ZfynAo3zdf
Sj+3ykEWpDE6E86fkQdUCbRvhxwwhOqqHFaB9FdkOmwB6auogoTbSqj6cgQf
7CyYefszHaaDzAmrcuC6vrjAdlMmxH73Kkj4bM10uA/yjwOCD7ZXo8phP9DY
u3syIe43qYKY8yzTARSNCbZVkPBmyIKEC1A/OH4FsiDucYe61yAL4n6/Kodw
UMT5Z0HiwwOqPyULYr9eFTw9gM1XhIZPFVS/RBUkPmqyHNDTGwAQLip9
                    
                    "], CompressedData["
1:eJxllAtIVFEQhkVKJKKiN2WWUiZZWVGEWTmZ4tpLjLLLtvfutlu4mZn5OnvN
AguREIklQilEyh5GtmpaqZhE9CIiTAqJjIoyizJ7h0jUnDNndy+2oOvnec38
88+E2fdt3hUYEBCwA3/4d/SL2UHFOxhM538kW2HVqO6abOQtb86dum2yAuuo
nhaNHNN8v6AjyQolH1NbQpHrQsw7Y5Gd7v6iuEkMrn3/88Q1qMH4IzcfnJ7C
YN3owKjSDhVaQvGEicEm+zglZqlK5+fm+Tje1tsZ3pQFj8OfDx7KUGEGXvuy
JtPHPfi7vWiPj4/d+hlp6U6neBtV2LD86BrbHT9P4O+XOyGXB5a+HbaNWXCl
qn433FuPG7+YQWtLxsj20PtvzVCZhRF/2+tjsS8jH35FWvApMwh94piPuSyz
QqU+wWaKK54BT6ukTAG+3GCR+xMV0keV+ScodF5jkFCW2Te0Ru7XpP7ISa8L
J3qsDN514sWrFdjbN3Txq43BmURUeKVC+qD+Kfw+5KeuDxGL7QyaqgYu3I1V
ANXo7bT7149PHZE2xjFs/2EGM0UhFJhXOvnZo2MyH5cCrbxeJxl08bzaZHwP
5XqtQvV874K7XKdKuT9Qp/vbFfhcFLdMM/BVtE018iKu4w0FzvP7kIU+yOKe
iTrwsiWmKWDi+c/RgVe7/cc2ij9J7h+pwKyGHKe7WIe//LNcIb/V68CPJaXK
fBt10nu++T8WaV/SqS5bpT8jdKpjuAr8mtdBOvlnrEr5e1zAZQv+ZPmPeVtU
m1zk0xAVoriefxgcRBnawlR6v4zR/UtUyu8Eo7ydKvRzvWq9ftDIb27pB7dk
PC/0OKuRnli/Ffzheo3iL2AUT51G9TVwAP8YWPgn388innzpT2Shi2FdxG9g
4cM8//4K3j/Ior6XNdInT/ofWeSHLOrr0chvuXI+eGR+uXKeYD4HuP45Mv9G
Db51bbSPQ+b/LmyW+/fL/dc14DLakIUfkIX/s6X+rRr5LdvrZ3l/huyHHo3m
Wrrst4VW0gf7hYf5e62V4nV4+9dK/kMWcSRa6dvh7Xc5Pw0s/Obwz0tvP3pZ
9LfdP19fpZRXZNn981f0l90/n8V8MjAfbwOG+e2dD14WfjTMcxG/YX34/P8H
0Cyccg==
                    "], CompressedData["
1:eJxNkm9IU2EUxseIiEiRkogyqYi4m4T4QSIjfEaIRtSoD9F7iRGjICNKCLrH
NCFsmURE+MFBiJRUSCVREWIy15SVBaajFEvR/tiaOgb9ZUTQeXcPbBcul4d7
3nN+53mfjf7TB445HQ5HGb/6m7f1UUeq3cI+f8Gh7UMmvsf2+guCFgp7qj+e
Y/2OElvKWLesnhz5M2iitziwsD+YrbdCnWtL8wi115ONlQ9M+Pp2r3A2ECqe
vDwbGjCR6Z8irCud3ry028Ss92r7KWc9dl05Gf9bK+fThPOV5b6+SQXu3luc
JNwvMo/uGFCI/DIOX1skNIdf3awKKTBVYc8CYSrddKK/X+pZezUP6zs3hjY8
nCc87kjdjT5TyNfzE9n/GuNCjm5bs+Rgfo7mLcp937LnM/zx7P/1jDXznODQ
T1j63yNojMCg6IDwv5B61l9HN31Ijyis0ouwntN6XPhZ/+Y1I9MKn2/zAo0E
dmllc42JBn0RFYSnP/69JY9p85dIfVJBt/eyztzXorLr3YTlE111O+fFD7f4
n1C2/27hi8s81pn7/CL8LsIY4zV9UqjRfruEZ1bmucT/KeFnHdP172W+QThz
nAMxodDqOTI3yjrIx8Mx4TFk/hsFHZNOQ/x7rRDds63Vw5pTVNISVXbeDOGJ
KNyqYid+WnZ+uhUu6/5RCxqzeljut82y9x1TmNH7XrRQzzFeViR5vmTZ87ok
nzn5/w8WOWkh
                    "]}]}}}}}}}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 600.}, {0., 400.}}], ",", 
           GraphicsBox[{{{
               {Thickness[0.002352941176470588], {{{
                   {FaceForm[{RGBColor[0.662745, 0., 0.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}}, {{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 
                    0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}}, {{1, 4, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{146.555, 24.364}, {
                    148.90200000000002`, 24.364}, {150.805, 
                    22.461999999999996`}, {150.805, 20.114000000000004`}, {
                    150.805, 15.868}, {150.805, 13.524}, {148.90200000000002`,
                     11.622}, {146.555, 11.622}, {142.309, 11.622}, {142.309, 
                    24.364}}, {{146.555, 7.372}, {151.24599999999998`, 
                    7.372}, {155.05100000000002`, 11.177}, {
                    155.05100000000002`, 15.868}, {155.05100000000002`, 
                    20.114000000000004`}, {155.05100000000002`, 24.805}, {
                    151.24599999999998`, 28.610000000000003`}, {146.555, 
                    28.610000000000003`}, {138.059, 28.610000000000003`}, {
                    138.059, 7.372}}, {{129.562, 28.610000000000003`}, {
                    133.812, 28.610000000000003`}, {133.812, 7.372}, {129.562,
                     7.372}}, {{121.066, 28.610000000000003`}, {125.316, 
                    28.610000000000003`}, {125.316, 7.372}, {121.066, 
                    7.372}, {112.57, 20.708}, {112.57, 7.372}, {108.324, 
                    7.372}, {108.324, 28.610000000000003`}, {112.57, 
                    28.610000000000003`}, {121.066, 15.277999999999999`}}, {{
                    57.348, 28.610000000000003`}, {70.09, 
                    28.610000000000003`}, {70.09, 24.364}, {61.594, 24.364}, {
                    61.594, 20.114000000000004`}, {70.09, 
                    20.114000000000004`}, {70.09, 15.868}, {61.594, 15.868}, {
                    61.594, 11.622}, {70.09, 11.622}, {70.09, 7.372}, {57.348,
                     7.372}}, {{40.355, 28.610000000000003`}, {
                    44.602000000000004`, 28.610000000000003`}, {
                    44.602000000000004`, 11.622}, {53.098000000000006`, 
                    11.622}, {53.098000000000006`, 7.372}, {40.355, 
                    7.372}}, {{84.96100000000001, 11.622}, {89.20700000000001,
                     11.622}, {92.727, 11.622}, {95.57799999999999, 14.473}, {
                    95.57799999999999, 17.993}, {95.57799999999999, 21.509}, {
                    92.67199999999998, 24.352}, {89.20700000000001, 24.364}, {
                    84.96100000000001, 24.364}, {84.96100000000001, 
                    20.114000000000004`}, {89.20700000000001, 
                    20.114000000000004`}, {90.37899999999999, 
                    20.114000000000004`}, {91.332, 19.165}, {91.332, 
                    17.993}, {91.332, 16.820999999999998`}, {
                    90.37899999999999, 15.868}, {89.20700000000001, 15.868}, {
                    84.96100000000001, 15.868}}, {{89.20700000000001, 
                    32.86}, {97.418, 32.86}, {104.074, 26.204}, {104.074, 
                    17.993}, {104.074, 9.782}, {97.418, 3.126}, {
                    89.20700000000001, 3.126}, {80.99600000000001, 3.126}, {
                    74.34, 9.782}, {74.34, 17.993}, {74.34, 26.204}, {
                    80.99600000000001, 32.86}, {89.20700000000001, 32.86}}, {{
                    89.20700000000001, 28.610000000000003`}, {95.07, 
                    28.610000000000003`}, {99.82799999999999, 23.856}, {
                    99.82799999999999, 17.993}, {99.82799999999999, 
                    12.129999999999999`}, {95.07, 7.372}, {89.20700000000001, 
                    7.372}, {83.34400000000001, 7.372}, {78.586, 
                    12.129999999999999`}, {78.586, 17.993}, {78.586, 
                    23.856}, {83.34400000000001, 28.610000000000003`}, {
                    89.20700000000001, 28.610000000000003`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[
                    1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{0., 284.2}, {424.801, 284.2}, {424.801, 
                    1.0009999999999764`}, {0., 1.0009999999999764`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    50.977, 284.2}, {127.43800000000002`, 284.2}, {
                    127.43800000000002`, 1.0009999999999764`}, {
                    50.977000000000004`, 1.0009999999999764`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4js/67L2xGQ5HFHYUJQxM9/hotLtn3Xvsh3M
Ox0Tnr7Jc2AAAY5ch56c579XxubC+SGPl84+0pMN5y+Q0r+rIpfpANR1QYk/
2+HflYqXaqrpDr3T84SaF2TA+d80YvoPdabD+VtPlO2b35XmkJ4GBF1Q+aOp
EPOMMhyKMya+rbFPc7h57nvw47/pDgW2XNcXH4Gqv5fucBvk/oB0B3vTuF2e
N9IdZgCtO7Av00EaqJ1tb7oDWPvZbIc3gTvkWudnQtzzItthxTFv807eHIfj
QMrxR7aDQITllhNluQ4gbynEZDucB1q3dH+eA3r4AADYT4vw
                    "]], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{183.75, 249.708}, {179.758, 
                    252.60999999999999`}, {181.281, 257.302}, {177.289, 
                    254.399}, {173.297, 257.302}, {174.824, 
                    252.60999999999999`}, {170.83200000000002`, 249.708}, {
                    175.766, 249.708}, {177.289, 245.012}, {178.816, 
                    249.708}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{183.75, 231.583}, {179.758, 234.485}, {181.281, 
                    239.177}, {177.289, 236.278}, {173.297, 239.177}, {
                    174.824, 234.485}, {170.83200000000002`, 231.583}, {
                    175.766, 231.583}, {177.289, 226.89100000000002`}, {
                    178.816, 231.583}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{183.75, 213.45800000000003`}, {179.758, 
                    216.36}, {181.281, 221.05200000000002`}, {177.289, 
                    218.153}, {173.297, 221.05200000000002`}, {174.824, 
                    216.36}, {170.83200000000002`, 213.45800000000003`}, {
                    175.766, 213.45800000000003`}, {177.289, 208.766}, {
                    178.816, 213.45800000000003`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{165.844, 222.74699999999999`}, {
                    161.85200000000003`, 225.64499999999998`}, {163.379, 
                    230.341}, {159.383, 227.43800000000002`}, {
                    155.39100000000002`, 230.341}, {156.918, 
                    225.64499999999998`}, {152.92600000000002`, 
                    222.74699999999999`}, {157.859, 222.74699999999999`}, {
                    159.383, 218.05200000000002`}, {160.91, 
                    222.74699999999999`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{188.738, 240.41899999999998`}, {192.73, 
                    243.32100000000003`}, {191.20299999999997`, 248.012}, {
                    195.195, 245.11399999999998`}, {199.18800000000002`, 
                    248.012}, {197.664, 243.32100000000003`}, {201.656, 
                    240.41899999999998`}, {196.72299999999998`, 
                    240.41899999999998`}, {195.195, 235.727}, {193.672, 
                    240.41899999999998`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIJIGYC4t7peULNH4IdpPXvqrDtzHXInPi2xn5voMPr
wB1yreF5Dhkg/tQAOB+krNHVz+H64gJbruMIfuVLNUOOhHyHha7bPv818Xaw
N43b5XkDwQeqvr64pgCuPuTx0tlHdiD4xiDAWgi3D6ibh8m2EO4eGB/m3qsV
QAt7Ch2cu3Oe/14ZAeeD1d+NgqsHm8caA+dbbjlRtq88Fm4fjA9zDwMYxMPd
C+PD/ANTD/MvjA8LD5h9sPCCuQfGh7kXFt4ATMyf3A==
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[
                    1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {
                    0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
                    1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIJIGYCYk8eJu32ZREObwJ3yLXuz3WotTeN23UzyuHm
ue/Bj2PzIHzGGDh/ep5Q84GsWAfBCMstJ04h+CDppcn5DvG7gCZ+jnPYPPf9
8mO3EXy3bZ//XqkqgKvPef575cdtCD7HGpmoFOZCuH3fNGL6D1kWwt0D48Pc
mwvS31Ho0C4GdNnnYDg/5PHS2UcOBMLVg/kzAuD8ZxeUbv+M84PbB+PD3PMU
xPfzhrsXxof5B6Ye5l8YHxYeMPtg4QVzD4wPcy8svAEeRcV0
                    
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIJIGYCYr8kgQhLkRCHBVL6d1V+5TpIAym2h4EOvdPz
hJpn5DnE7fLkYdodAOeD9DIE+DuosTVOdX6N4E9z7s553pzvAOIyOPg4xPYf
+qrxB8EvtOW6vjirAK4++PHS2UeWIfgBIAs+F8Dtm31EYUORTCHcPTA+zL3M
YXy6m7ILHZoPnFro2hYB52/7/PdKxc4ouPo1MlEp1vej4XygKwpsP8XA7YPx
Ye65pHT7Z11VHNy9MD7MPzD1MP/C+LDwgNkHCy+Ye2B8mHth4Q0AqVub2A==

                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    111.43400000000001`, 244.97}, {115.586, 247.47}, {115.586,
                     252.23499999999999`}, {121.71100000000001`, 255.993}, {
                    121.71100000000001`, 259.173}, {89.309, 259.173}, {89.309,
                     240.016}, {98.043, 240.016}, {106.84400000000001`, 
                    244.97}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    62.828, 271.079}, {62.828, 266.309}, {56.703, 262.552}, {
                    56.703, 259.376}, {89.10499999999999, 259.376}, {
                    89.10499999999999, 278.52799999999996`}, {80.371, 
                    278.52799999999996`}, {71.57, 273.579}, {66.98, 
                    273.579}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    62.828, 247.47}, {66.98, 244.97}, {71.57, 244.97}, {
                    80.371, 240.016}, {89.10499999999999, 240.016}, {
                    89.10499999999999, 259.173}, {56.703, 259.173}, {56.703, 
                    255.993}, {62.828, 252.23499999999999`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    115.586, 266.309}, {115.586, 271.079}, {
                    111.43400000000001`, 273.579}, {106.84400000000001`, 
                    273.579}, {98.043, 278.52799999999996`}, {89.309, 
                    278.52799999999996`}, {89.309, 259.376}, {
                    121.71100000000001`, 259.376}, {121.71100000000001`, 
                    262.552}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{103.895, 266.227}, {102.727, 267.462}, {106.273, 
                    270.805}, {106.273, 273.079}, {108.34400000000001`, 
                    271.794}, {109.85199999999999`, 273.2}, {111.348, 
                    272.27799999999996`}, {109.836, 270.872}, {111.777, 
                    269.66900000000004`}, {107.543, 
                    269.66900000000004`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    109.87899999999999`, 272.95}, {108.523, 271.684}, {109.66,
                     270.98099999999994`}, {111.016, 272.247}}, {{106.477, 
                    272.71599999999995`}, {106.477, 270.71999999999997`}, {
                    103.016, 267.454}, {103.902, 266.512}, {
                    107.46100000000001`, 269.872}, {111.066, 
                    269.872}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{96.758, 266.845}, {95.59, 268.079}, {99.137, 
                    271.42299999999994`}, {99.137, 273.69599999999997`}, {
                    101.20700000000001`, 272.41499999999996`}, {102.715, 
                    273.817}, {104.20700000000001`, 272.899}, {102.699, 
                    271.489}, {104.637, 270.28599999999994`}, {100.402, 
                    270.28599999999994`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    102.738, 273.567}, {101.383, 272.302}, {102.52, 
                    271.59799999999996`}, {103.87499999999999`, 
                    272.86400000000003`}}, {{99.34, 273.33299999999997`}, {
                    99.34, 271.337}, {95.87499999999999, 
                    268.07099999999997`}, {96.766, 267.13}, {100.324, 
                    270.489}, {103.93, 270.489}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{104.418, 262.188}, {103.25, 
                    263.42299999999994`}, {106.79700000000001`, 266.77}, {
                    106.79700000000001`, 269.04}, {108.867, 267.759}, {
                    110.37499999999999`, 269.165}, {111.871, 268.243}, {
                    110.359, 266.83299999999997`}, {112.301, 265.63}, {
                    108.066, 265.63}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    110.402, 268.91099999999994`}, {109.04700000000001`, 
                    267.64500000000004`}, {110.184, 266.942}, {111.539, 
                    268.20799999999997`}}, {{107., 268.677}, {107., 266.68}, {
                    103.539, 263.41499999999996`}, {104.426, 262.477}, {
                    107.98400000000001`, 265.83299999999997`}, {111.59, 
                    265.83299999999997`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{103.895, 252.317}, {102.727, 
                    251.08700000000002`}, {106.273, 247.73899999999998`}, {
                    106.273, 245.47}, {108.34400000000001`, 246.751}, {
                    109.85199999999999`, 245.345}, {111.348, 246.266}, {
                    109.836, 247.677}, {111.777, 248.876}, {107.543, 
                    248.876}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    109.87899999999999`, 245.598}, {108.523, 246.86}, {109.66,
                     247.563}, {111.016, 246.298}}, {{106.477, 245.833}, {
                    106.477, 247.82500000000002`}, {103.016, 251.095}, {
                    103.902, 252.032}, {107.46100000000001`, 248.677}, {
                    111.066, 248.677}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{96.758, 251.7}, {95.59, 250.47}, {99.137, 
                    247.122}, {99.137, 244.85200000000003`}, {
                    101.20700000000001`, 246.134}, {102.715, 244.727}, {
                    104.20700000000001`, 245.64899999999997`}, {102.699, 
                    247.055}, {104.637, 248.259}, {100.402, 
                    248.259}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    102.738, 244.98100000000002`}, {101.383, 
                    246.24299999999997`}, {102.52, 246.946}, {
                    103.87499999999999`, 245.68}}, {{99.34, 245.212}, {99.34, 
                    247.208}, {95.87499999999999, 250.477}, {96.766, 
                    251.415}, {100.324, 248.055}, {103.93, 248.055}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{104.418, 256.356}, {103.25, 255.122}, {
                    106.79700000000001`, 251.778}, {106.79700000000001`, 
                    249.505}, {108.867, 250.79}, {110.37499999999999`, 
                    249.38400000000001`}, {111.871, 250.305}, {110.359, 
                    251.712}, {112.301, 252.915}, {108.066, 
                    252.915}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    110.402, 249.637}, {109.04700000000001`, 250.899}, {
                    110.184, 251.602}, {111.539, 250.33700000000002`}}, {{
                    107., 249.86800000000002`}, {107., 251.864}, {103.539, 
                    255.13}, {104.426, 256.071}, {107.98400000000001`, 
                    252.712}, {111.59, 252.712}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{74.516, 252.317}, {75.684, 
                    251.08700000000002`}, {72.137, 247.73899999999998`}, {
                    72.137, 245.47}, {70.066, 246.751}, {68.559, 245.345}, {
                    67.066, 246.266}, {68.574, 247.677}, {66.637, 248.876}, {
                    70.871, 248.876}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    68.535, 245.598}, {69.891, 246.86}, {68.754, 247.563}, {
                    67.398, 246.298}}, {{71.93400000000001, 245.833}, {
                    71.93400000000001, 247.82500000000002`}, {75.398, 
                    251.095}, {74.508, 252.032}, {70.94900000000001, 
                    248.677}, {67.34400000000001, 248.677}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{81.65599999999999, 251.7}, {82.824, 250.47}, {
                    79.277, 247.122}, {79.277, 244.85200000000003`}, {
                    77.20700000000001, 246.134}, {75.699, 244.727}, {74.203, 
                    245.64899999999997`}, {75.715, 247.055}, {73.773, 
                    248.259}, {78.008, 248.259}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    75.67199999999998, 244.98100000000002`}, {77.027, 
                    246.24299999999997`}, {75.895, 246.946}, {74.535, 
                    245.68}}, {{79.074, 245.212}, {79.074, 247.208}, {82.539, 
                    250.477}, {81.648, 251.415}, {78.09, 248.055}, {
                    74.48400000000001, 248.055}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{73.992, 256.356}, {75.16, 255.122}, {71.613, 
                    251.778}, {71.613, 249.505}, {69.543, 250.79}, {68.035, 
                    249.38400000000001`}, {66.543, 250.305}, {68.051, 
                    251.712}, {66.113, 252.915}, {70.348, 
                    252.915}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    68.012, 249.637}, {69.367, 250.899}, {68.23, 251.602}, {
                    66.87499999999999, 250.33700000000002`}}, {{
                    71.41000000000001, 249.86800000000002`}, {
                    71.41000000000001, 251.864}, {74.87499999999999, 
                    255.13}, {73.98400000000001, 256.071}, {70.426, 
                    252.712}, {66.82, 252.712}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{74.516, 266.227}, {75.684, 267.462}, {72.137, 
                    270.805}, {72.137, 273.079}, {70.066, 271.794}, {68.559, 
                    273.2}, {67.066, 272.27799999999996`}, {68.574, 
                    270.872}, {66.637, 269.66900000000004`}, {70.867, 
                    269.66900000000004`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    68.535, 272.95}, {69.891, 271.684}, {68.754, 
                    270.98099999999994`}, {67.398, 272.247}}, {{
                    71.93400000000001, 272.71599999999995`}, {
                    71.93400000000001, 270.71999999999997`}, {75.398, 
                    267.454}, {74.508, 266.512}, {70.94900000000001, 
                    269.872}, {67.34400000000001, 269.872}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{81.65599999999999, 266.845}, {82.824, 268.079}, {
                    79.277, 271.42299999999994`}, {79.277, 
                    273.69599999999997`}, {77.20700000000001, 
                    272.41499999999996`}, {75.699, 273.817}, {74.203, 
                    272.899}, {75.715, 271.489}, {73.773, 
                    270.28599999999994`}, {78.008, 
                    270.28599999999994`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    75.67199999999998, 273.567}, {77.027, 272.302}, {75.895, 
                    271.59799999999996`}, {74.535, 272.86400000000003`}}, {{
                    79.074, 273.33299999999997`}, {79.074, 271.337}, {82.539, 
                    268.07099999999997`}, {81.648, 267.13}, {78.09, 
                    270.489}, {74.48400000000001, 270.489}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{73.992, 262.188}, {75.16, 263.42299999999994`}, {
                    71.613, 266.77}, {71.613, 269.04}, {69.543, 267.759}, {
                    68.035, 269.165}, {66.543, 268.243}, {68.051, 
                    266.83299999999997`}, {66.113, 265.63}, {70.348, 
                    265.63}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    68.012, 268.91099999999994`}, {69.367, 
                    267.64500000000004`}, {68.23, 266.942}, {
                    66.87499999999999, 268.20799999999997`}}, {{
                    71.41000000000001, 268.677}, {71.41000000000001, 
                    266.68}, {74.87499999999999, 263.41499999999996`}, {
                    73.98400000000001, 262.477}, {70.426, 
                    265.83299999999997`}, {66.82, 
                    265.83299999999997`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{101.12899999999999`, 
                    273.673}, {101.801, 275.309}, {98.922, 276.805}, {95.023, 
                    276.805}, {93.027, 278.73099999999994`}, {85.387, 
                    278.73099999999994`}, {83.387, 276.805}, {79.492, 
                    276.805}, {76.613, 275.309}, {77.285, 273.673}, {
                    79.85199999999999, 275.02}, {80.977, 275.02}, {
                    84.91400000000002, 270.46999999999997`}, {
                    89.20700000000001, 273.08299999999997`}, {93.5, 
                    270.46999999999997`}, {97.438, 275.02}, {98.562, 
                    275.02}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{101.12899999999999`, 
                    244.872}, {101.801, 243.23499999999999`}, {98.922, 
                    241.74299999999997`}, {95.023, 241.74299999999997`}, {
                    93.027, 239.817}, {85.387, 239.817}, {83.387, 
                    241.74299999999997`}, {79.492, 241.74299999999997`}, {
                    76.613, 243.23499999999999`}, {77.285, 244.872}, {
                    79.85199999999999, 243.524}, {80.977, 243.524}, {
                    84.91400000000002, 248.07899999999998`}, {
                    89.20700000000001, 245.46200000000002`}, {93.5, 
                    248.07899999999998`}, {97.438, 243.524}, {98.562, 
                    243.524}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{68.824, 
                    262.78999999999996`}, {66.85199999999999, 
                    262.78999999999996`}, {66.41000000000001, 
                    263.32099999999997`}, {66.41000000000001, 
                    264.71999999999997`}, {67.52, 265.45799999999997`}, {
                    65.699, 266.137}, {65.65599999999999, 266.106}, {63.305, 
                    264.47299999999996`}, {63.305, 264.03599999999994`}, {
                    59.539, 259.274}, {63.305, 254.509}, {63.305, 254.071}, {
                    65.699, 252.411}, {67.52, 253.091}, {66.41000000000001, 
                    253.82500000000002`}, {66.41000000000001, 255.227}, {
                    66.85199999999999, 255.755}, {68.824, 
                    255.755}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{63.508, 254.177}, {63.508, 
                    254.57899999999998`}, {59.797000000000004`, 259.274}, {
                    63.508, 263.96599999999995`}, {63.508, 264.368}, {65.727, 
                    265.91099999999994`}, {67.07799999999999, 265.407}, {
                    66.20700000000001, 264.829}, {66.20700000000001, 
                    263.247}, {66.758, 262.59099999999995`}, {68.621, 
                    262.59099999999995`}, {68.621, 255.95800000000003`}, {
                    66.758, 255.95800000000003`}, {66.20700000000001, 
                    255.298}, {66.20700000000001, 253.71599999999998`}, {
                    67.07799999999999, 253.141}, {65.727, 
                    252.634}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{109.586, 
                    262.78999999999996`}, {111.562, 262.78999999999996`}, {
                    112.004, 263.32099999999997`}, {112.004, 
                    264.71999999999997`}, {110.891, 265.45799999999997`}, {
                    112.71100000000001`, 266.137}, {112.758, 266.106}, {
                    115.109, 264.47299999999996`}, {115.109, 
                    264.03599999999994`}, {118.87499999999999`, 259.274}, {
                    115.109, 254.509}, {115.109, 254.071}, {
                    112.71100000000001`, 252.411}, {110.891, 253.091}, {
                    112.004, 253.82500000000002`}, {112.004, 255.227}, {
                    111.562, 255.755}, {109.586, 255.755}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{114.906, 254.177}, {
                    114.906, 254.57899999999998`}, {118.617, 259.274}, {
                    114.906, 263.96599999999995`}, {114.906, 264.368}, {
                    112.684, 265.91099999999994`}, {111.332, 265.407}, {
                    112.203, 264.829}, {112.203, 263.247}, {
                    111.65599999999999`, 262.59099999999995`}, {109.789, 
                    262.59099999999995`}, {109.789, 255.95800000000003`}, {
                    111.65599999999999`, 255.95800000000003`}, {112.203, 
                    255.298}, {112.203, 253.71599999999998`}, {111.332, 
                    253.141}, {112.684, 252.634}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{89.10499999999999, 278.52799999999996`}, {
                    89.10499999999999, 273.259}, {84.953, 
                    270.73099999999994`}, {81.066, 275.22299999999996`}, {
                    79.801, 275.22299999999996`}, {77.387, 273.954}, {76.867, 
                    275.21599999999995`}, {79.539, 276.60200000000003`}, {
                    83.46900000000001, 276.60200000000003`}, {
                    85.46900000000001, 278.52799999999996`}}, {{89.309, 
                    277.954}, {89.309, 273.259}, {93.46100000000001, 
                    270.73099999999994`}, {97.34400000000001, 
                    275.22299999999996`}, {98.613, 275.22299999999996`}, {
                    101.027, 273.954}, {101.543, 275.21599999999995`}, {
                    98.871, 276.60200000000003`}, {94.94500000000001, 
                    276.60200000000003`}, {92.94500000000001, 
                    278.52799999999996`}, {89.309, 278.52799999999996`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{89.10499999999999, 240.016}, {89.10499999999999, 
                    245.29}, {84.953, 247.817}, {81.066, 
                    243.32100000000003`}, {79.801, 243.32100000000003`}, {
                    77.387, 244.591}, {76.867, 243.329}, {79.539, 241.946}, {
                    83.46900000000001, 241.946}, {85.46900000000001, 
                    240.016}}, {{89.309, 240.591}, {89.309, 245.29}, {
                    93.46100000000001, 247.817}, {97.34400000000001, 
                    243.32100000000003`}, {98.613, 243.32100000000003`}, {
                    101.027, 244.591}, {101.543, 243.329}, {98.871, 
                    241.946}, {94.94500000000001, 241.946}, {
                    92.94500000000001, 240.016}, {89.309, 
                    240.016}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxlk21IFFEUhtcRFqqlD41+lERF9kFICFJIRDfWJTSy2dWZFZs+WEzsw9mZ
kvBHKCK2RVSEhMUWtITkSj9CQiRCJMW+IEqsCOmXiIVELUKhUnbvHd5z0Rbm
xzN75573vOc9G2PxyMlsn8+XxZ8IfzT+lAW0HYnrYfZrm3Xjeb7DKsc7k0Nd
OnF5bGVVcYnOPjR+21IYcNjwwd1X9l/WWXdm5FCM8/tNYzNNOTqrEN99jbO0
OJA6zJpPP2to1xzi2Sb+YonDVhT03PuRKPe+L1L/r/n89nfFccX31+78srlW
3d+3vm0q3LCovqX0Xeuwc1otpf/Y09KAFnQY+gPn+1tuBYMR775axTNC36DD
Jt7xgv5K4oQQlmuyN6lQ73SuS6yLgttdNhXmNw0aLDm04fG5XS5b+umBs7db
8W0uayBisMm5dGZkq8vqbn6/uC9ksHrxIs9l63ib/izD66vI9XxvMzy/ddfT
nVQszxeaLNtcXtBzxmW9039GG08pPi8KzJt0fkw0sjpKLM/fiVI9qceIkp7i
Jy8v9B+Ikt4X4txPk/oRtvV9VFwq/L2k/ADDL+lvexX5+SivumZPtPo/xjx4
Oh4OLztC85J6M4pbB16nQqZF8y65enZybpVFeZgXv4RFeZHfv7IoT2DkTeo1
j1Ie8T/yCkaecT/yvqB+QOnDvkA/9gn9gdH/XeGnpljmtixO/oHhb5cYYNom
lueabZqP9KfGpvmBMV9Zv8Wm+XM3xjs7bMoH/+rERJ1N+fk7KhqyKV9g5E/6
O1tP+QQjvziPfIPlvvoMqof9gB7sD/Riv9AP9g+M/YQfYPiF/V7gL9//xYx5
/AN4GlC2
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 
                    1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, {{{89.309, 242.985}, {90.20700000000001, 
                    242.298}, {89.309, 241.61399999999998`}}, CompressedData["

1:eJxTTMoPSmViYGBQBmIQvch12+e/c0Idzn0PfrzUPM9hjUxUivV8BD9j4tsa
e9Mwh97peULNDHkOcq2vA3e4YfLfBO6Qa9XOc/gPAt9DHVYc8zbv9ETIg81L
R/DtTeN2ee6Ami8aAjEvJd9hb8lkCZayIAy+G9CZVzgKHKy2nCjbNz/QIeTx
0tlHjAocRNe5P6yKCYDzVdgapzpzBzh81YjpPyRd4NAudvPc92J/uDyYv9kP
zge7e7e/Q33WnpLJXAg+yFgRlgIHl+6c578FAyD++Zjv8A1kbmqAQwDIgZwF
DiIghSYBDkBVKz9yIPhA3/Ew8UL1LwxwyAXJaxQ4xIPEJwfC+ceBxjoGBDns
AfmTBcGX1r+rwhaY7wAKhgNcIXA+2N0KYQ7/rlS8VFubB+dPcwZaVJ3nUAwK
0OOhDgukgBri8hyaD5xa6LoMwbcEhZ97qEMPyMG1eZBwdgh1OKKwoSijM8/h
otLtn3VCoRD3ZEH5XYj0AADYPwDm
                    "], {{64.17599999999999, 
                    260.505}, {65.17599999999999, 259.376}, {63.176, 
                    259.376}}, {{89.10499999999999, 276.93399999999997`}, {
                    88.20700000000001, 276.247}, {89.10499999999999, 
                    275.559}}, {{113.238, 259.173}, {114.238, 
                    258.04400000000004`}, {115.238, 259.173}}, CompressedData["
1:eJxTTMoPSmViYGBQAmIQrcrWONX5d5hD7vPfKz/6FDpkTHxbY58a5jD7iMKG
ooxCh01z3y8/FozJj9vlycMUXOhwUen2z7pFYQ6nF7pu++yMkK8WWef+0ATB
r8vaUzKZB2p+awTEvG0FDn5JAhGWKlEY/Bvnvgc/ji9wmJEn1HzgVxTEfNMC
h70lkyVY7GLg/DUyUSnW/TFQ9xc49E4HangQ47AHpM4MyneIhfPv/AS6ZE+M
wwIp/bsqcQh+gS3X9cUpUPUdUP0FBQ63QfImMQ7MYXy6m+Kh9qfFOHzViOk/
hMQHy0cXOBzzNu90/BENkbcvcCgGeZgdwQfaUmDrFeUQ/Hjp7CMpCD5Y34EC
B6stJ8r29UfA+ds+/71SURkGca9QIZzvBmJoFTrEg+LhcpgDC8h+y0JI+H1B
8MHhFxTucBMUnpqFDi7dOc9/R4ZD/KdS6PAfBNrDIe4zLnRgAAGBcHh6AAB7
afdG
                    "]}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1,
                     0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 
                    0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 
                    0}, {0, 1, 0}}}, {{{89.10499999999999, 
                    241.61399999999998`}, {88.20700000000001, 242.298}, {
                    89.10499999999999, 242.985}}, {{65.17599999999999, 
                    259.173}, {64.17599999999999, 258.04400000000004`}, {
                    63.176, 259.173}}, CompressedData["
1:eJxTTMoPSmViYGBQBmIQnTnxbY393zCHc9+DHy81z3NQZWuc6vwbwc8AyaeG
OfROzxNqZshz2DT3/fJjwZj8N4E75Fq18xwuKt3+WbcozGHFMW/zTk+EPNi8
dATf3jRul+cOqPmtERDzUvId/JIEIixVojD4bts+/73CUeAwAyh84FeUQ8jj
pbOPGBU47C2ZLMFiFwPnr5GJSrHuj3H4qhHTf0i6AGLOA4Q8mO8QC+ff+VmX
tWdPjEN91p6SyVwI/jr3h1UiLFD1HTEQ/3zMd7gNkjeJcQgASXBC7U+Lcch5
/nvlRw4EH+g7HibeAgeQNscf0Q65IHmNAodikIfZEXyu64sLbL2iHPaA9LEg
+NL6d1XYAvMdrLacKNvXHwHng4KhojLM4d+Vipdqa/Pg/GnO3TnPq/Mc4kH2
Xg5zWCAF1BCXBwm/Lwg+OPyCwh16QA6uzXNwAWr7HRnucERhQ1FGZ57DfxBo
D4e4JyvPgQEEBMLh6QEAP70BUg==
                    "], {{114.238, 260.505}, {
                    113.238, 259.376}, {115.238, 259.376}}, CompressedData["
1:eJxTTMoPSmViYGBQAmIQvUYmKsV6fqhD7vPfKz/6FDpkTHxbY28a5jD7iMKG
ooxCB7nW14E73DD5cbs8eZiCCx3+g8D3UIfTC123fXZGyFeLrHN/aILg12Xt
KZnMAzVfNARi3rYCh70lkyVYyoIw+DfOfQ9+HF/gYLXlRNm++YEQ800LHESB
xlbFBMD5KmyNU525A6DuL3BoF7t57nuxv8MekDlmUP5mPzj/TeAOudbd/g4L
pPTvqsQh+AW2XNcXpxQ4uHTnPP8tGABRX1Dg8E0jpv9QaoADcxif7iage0De
qjIJcPgKEkfig+WjCxyAphTYLoLK2xc4xIPCaXIgnH/c27zTMSDIIfjx0tlH
UhD8YyD6QIHD9Dyh5gNcIXB+CEidQhjEvUKFcL7bts9/r2gVOhSDAvR4qAML
yH7LQofmA6cWui5D8C1B4ece6nATFJ6ahQ69IAscQiH+Uyl0uKh0+2edUCjE
fcZQfhciPQAALpL1Zg==
                    "], {{89.309, 275.559}, {
                    90.20700000000001, 276.247}, {89.309, 
                    276.93399999999997`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[
                    1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {
                    0, 1, 0}, {0, 1, 0}}}, {{{89.10499999999999, 272.552}, {
                    80.387, 267.2}, {74.04700000000001, 267.2}, {
                    74.04700000000001, 261.895}, {70.824, 259.376}, {
                    89.10499999999999, 259.376}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, {{{89.309, 245.997}, {98.023, 251.345}, {
                    104.367, 251.345}, {104.367, 256.653}, {107.59, 
                    259.173}, {89.309, 259.173}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, {{{107.59, 259.376}, {104.367, 
                    261.895}, {104.367, 267.2}, {98.023, 267.2}, {89.309, 
                    272.552}, {89.309, 259.376}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, {{{70.824, 259.173}, {74.04700000000001, 
                    256.653}, {74.04700000000001, 251.345}, {80.387, 
                    251.345}, {89.10499999999999, 245.997}, {
                    89.10499999999999, 259.173}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{84.273, 260.19599999999997`}, {85.44100000000002,
                     261.42699999999996`}, {81.895, 264.774}, {81.895, 
                    267.04400000000004`}, {79.824, 265.762}, {78.316, 
                    267.16900000000004`}, {76.82, 266.247}, {78.332, 
                    264.837}, {76.391, 263.637}, {80.62499999999999, 
                    263.637}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    78.289, 266.91499999999996`}, {79.645, 265.653}, {78.512, 
                    264.94599999999997`}, {77.15199999999999, 266.212}}, {{
                    81.691, 266.68}, {81.691, 264.688}, {85.15599999999999, 
                    261.419}, {84.266, 260.48099999999994`}, {
                    80.70700000000001, 263.837}, {77.10199999999999, 
                    263.837}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{94.137, 258.35200000000003`}, {92.973, 
                    257.118}, {96.52, 253.77399999999997`}, {96.52, 
                    251.501}, {98.59, 252.786}, {100.098, 
                    251.38000000000002`}, {101.59, 252.30200000000002`}, {
                    100.07799999999999`, 253.708}, {102.02, 254.911}, {97.785,
                     254.911}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    100.121, 251.63}, {98.766, 252.895}, {99.902, 253.598}, {
                    101.258, 252.333}}, {{96.723, 251.864}, {96.723, 
                    253.86}, {93.258, 257.126}, {94.148, 258.067}, {
                    97.70700000000001, 254.708}, {101.309, 254.708}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{84.273, 258.35200000000003`}, {85.44100000000002,
                     257.118}, {81.895, 253.77399999999997`}, {81.895, 
                    251.501}, {79.824, 252.786}, {78.316, 
                    251.38000000000002`}, {76.82, 252.30200000000002`}, {
                    78.332, 253.708}, {76.391, 254.911}, {80.62499999999999, 
                    254.911}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[
                    1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{78.289, 251.63}, {79.645, 252.895}, {78.512, 
                    253.598}, {77.15199999999999, 252.333}}, {{81.691, 
                    251.864}, {81.691, 253.86}, {85.15599999999999, 
                    257.126}, {84.266, 258.067}, {80.70700000000001, 
                    254.708}, {77.10199999999999, 254.708}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{94.137, 260.19599999999997`}, {92.973, 
                    261.42699999999996`}, {96.52, 264.774}, {96.52, 
                    267.04400000000004`}, {98.59, 265.762}, {100.098, 
                    267.16900000000004`}, {101.59, 266.247}, {
                    100.07799999999999`, 264.837}, {102.02, 263.637}, {97.785,
                     263.637}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[
                    1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{100.121, 266.91499999999996`}, {98.766, 
                    265.653}, {99.902, 264.94599999999997`}, {101.258, 
                    266.212}}, {{96.723, 266.68}, {96.723, 264.688}, {93.258, 
                    261.419}, {94.148, 260.48099999999994`}, {
                    97.70700000000001, 263.837}, {101.309, 263.837}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    98.57799999999999, 259.274}, {89.20700000000001, 
                    253.024}, {79.832, 259.274}, {89.20700000000001, 
                    265.52}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1,
                     0}}, {{0, 2, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}}}, {{{
                    89.10499999999999, 265.212}, {80.348, 259.376}, {
                    89.10499999999999, 259.376}}, {{89.309, 259.376}, {98.062,
                     259.376}, {89.309, 265.212}}, {{80.348, 259.173}, {
                    89.10499999999999, 253.33700000000002`}, {
                    89.10499999999999, 259.173}}, {{89.309, 
                    253.33700000000002`}, {98.066, 259.173}, {89.309, 
                    259.173}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{91.715, 263.137}, {91.715, 
                    261.42299999999994`}, {94.95700000000001, 
                    261.42299999999994`}, {94.95700000000001, 257.126}, {
                    91.715, 257.126}, {91.715, 255.407}, {86.699, 255.407}, {
                    86.699, 257.126}, {83.45700000000001, 257.126}, {
                    83.45700000000001, 261.42299999999994`}, {86.699, 
                    261.42299999999994`}, {86.699, 263.137}}}]}}}}, {{{
                   {Thickness[0.00006663529411764707], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{91.715, 
                    263.13698200000005`}, {91.715, 261.42298200000005`}, {
                    94.95700000000001, 261.42298200000005`}, {
                    94.95700000000001, 257.125982}, {91.715, 257.125982}, {
                    91.715, 255.40698200000003`}, {86.699, 
                    255.40698200000003`}, {86.699, 257.125982}, {
                    83.45700000000001, 257.125982}, {83.45700000000001, 
                    261.42298200000005`}, {86.699, 261.42298200000005`}, {
                    86.699, 263.13698200000005`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgAWI2IGYC4lp707hdO0MdYnd58jDlFzjA+K8Dd8i1Bhc4
cF1fXGD7KgSDv6dksgSLWYGDXCtQxi0Mgw8zb9Pc98uPBSPkj3ubdzpuCMfg
w8wPebx09pEHYRh8dPNgfJh7wOqMEHxjEBBF+AedDzb/cz7cveh8mHkw+2Dy
KO5D4sPMh/kHnY9uHowPAG5CqjE=
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4pDHS2cfMQhxuL64wJarOd0Bha+d7lBjbxq3
KzMCOx+o/vbPuqw9PlEYfKeEpxeUbqc7WG05UbZPPwY73zjD4aISUIdQHAb/
y98rFS/9suHq0fmfQfxl2XD70Plg9/zPRnUvOj88B9W/6Hyg+m8aMf2HfIMw
+DD7pucJNR/ICsDgw9xbnDHxbQ2/LwYf5l+Yeqx8YHjB7EPnw8IbAN9z2dI=

                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4js/67L2xEQ4rDjmbd7Zme6AwjdMd/imEdN/
yDYEOx+ofkaeUPOBqCAMfk/O898rH6Y7WG45UbavPAA73zLDYdvnv1cqNH0x
+Ks+XvJN8siGq0fn904HWrQgG24fVv6PbLh70fmFtlzXFwfkwP2LzoeptwLZ
Zx+FnQ+zTykGgw9zL9g+1jgMPsy/MPVY+cDwgtmHzoeFNwBep9jy
                    
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4m8aMf2H9oY4rDjmbd55Mt0Bxj+isKEoozDd
4c7Puqw9d8Ix+DD1VltOlO3bH4mdr5jhMCNPqPnAomgMfk/O898rKzMg9rXG
YvB7pwMVcmTD1WPlJ2TD7UPnF9hyXV+8IxvuXnR+IYgvkAP3Lzofph5s360g
DD7MPkuQfd8DsPOB7t32+e+VCk0/DD7MvzD16HyU8ALah5UPDG8AAlTaAA==

                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGZigIIL4Q7TnLtznp9Pd4Dxp4L45ekOF5Vu/6w7
FYLBh6kvzpj4tuZ5EAa/8qWaIYdGhoPIOveHVSyB2PkNGQ6/6rL2lDj7YfD3
lEyWYGHKhqvHyo/KhtuHzl8gpX9XZVM23L1Y+Vw5cP9i5QPVx+/y5GHaHInB
h9n3TSOm/9DUaOx8oHtDHi+dfaQiFoMP8y9MPVY+MLxg9qHzYeENAGuWuLI=

                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], FilledCurveBox[CompressedData["
1:eJxTTMoPSmJmYGBgBOJMIAaxGZjA/FFEOgIA9vgCgQ==
                    
                    "], CompressedData["
1:eJxtVFtIVFEUnSxEwyyloKSsRETpo/oQLYo5aUNYmY+xZpyHyJDNnblS9iA0
xBAZTFIiogdIYEoUEiYWEaE5lFj0ITkMSKkfIhYRIREmZq9ztrP2VfDC+Vh3
n/04a6+9t3vOFFesNJlMK+TxyxMlz67x1Oj6/BKR3XSgfKpKF77r32rNEnd+
D+V7unUxnDI6VxeyioeDR7KaanTxT302K9v3PH178aXE8A+p+x+LhTmz7EVe
m4EHtnWf0yy6uHM6sSHoKRaxjzY7Tm6NxJfYde3VTLpdF3tVvOkiUbV/9UhH
qi7G5ur8vbVFbN/QdWjiksTwp/yzhQv15RmY8s34xXp1v7lQHI6L2tE45BfV
X9J2x0jclrRzPDVKF6MqflyhqFH/w/6FepIK2H7wauXn+U0F7P/sx59wdcYx
0XvhxsZVvww80iErnveJ85okcG3+8rjRt/T+Ikz5r2ic72vR8+TAE43ruZUr
DZc1rpfq69L4PbDjvfAHHyWT91sHmg3ccls2IltjPhPs0uLRmO8PQ7PWyQyN
+0H8ujXuF+zoJ/zR77Oqf/sMTPcnvKyXv2FZeYLGevqZLjs87GW9UX0xGusR
dugV/vS/r0SsU/k/eRlTvoBXKPrNFcfFKfWFDEzxq72R+CdETvnU+5TXEXum
je3A8Cd+xmwcHxj52y2yo0ftXN9CfDvXT+99Y+f30XtzStlOfEoMf+K/v5T5
Awa/xGeWg/mn+BKjPypNsNPB/aM8W5xs71M6TnayP+Vvd7I+gKEfuh/vYn3R
XEgM/VH8Fhfrk96/xs126p/E8Kf7ATfrHxjzQfwkli2P5Xwtub8IYz6RD/OL
ejDfqBfz3xB8d88S72I73gt/8IH9Aoz9Az6xn8A39hf6gf2GfsGOfsIf/cb+
BMZ+hV6wf6En7GfoDfsbeoQdeoU/9Ez5Ww3sVvX91nkeeu5OPxh8bGCKH1vJ
80T96Nd53mAHhj/mFfGB06Lrb+bK/P8BIPUg9A==
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[
                    1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {
                    0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
                    1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4m2f/16p0PR1WHHM27yzN9MBxi+w5bq++Eum
w6+6rD0lzn4Y/CMKG4oy3mZB+Mb+DjfPfQ9+fDDLoV0MyALyl4PM+5rlcPsn
UAFPgEPlSzVDjjNZDr3T84SaBQIg+s9mOayRiUqxrg+Aqy/OmPi2BsiHmWe5
5UTZvu8BcPtg/ODHS2cfmZIBVx/Tf+irxoEMuHl9IHt6MuD27y2ZLMGyLQPu
Ppg8zP0w/TD/wcyH8WHhAwDBUpeK
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    70.145, 195.454}, {68.07, 194.134}, {68.07, 217.93}, {
                    70.145, 216.61399999999998`}, {70.148, 218.305}, {
                    71.74600000000001, 216.872}, {73.34, 218.305}, {
                    73.34400000000001, 216.61399999999998`}, {75.418, 
                    217.93}, {75.418, 194.134}, {73.34400000000001, 
                    195.454}, {73.34, 193.762}, {71.74600000000001, 
                    195.192}, {70.148, 193.762}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[
                    1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {
                    0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
                    1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    77.57, 192.942}, {75.617, 191.466}, {75.617, 220.598}, {
                    77.57, 219.122}, {77.574, 221.059}, {79.289, 
                    219.52800000000002`}, {81.004, 221.059}, {81.008, 
                    219.122}, {82.96100000000001, 220.598}, {
                    82.96100000000001, 191.466}, {81.008, 192.942}, {81.004, 
                    191.005}, {79.289, 192.54}, {77.574, 191.005}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    89.20700000000001, 221.727}, {85.785, 
                    223.92700000000002`}, {85.785, 221.032}, {83.164, 
                    223.423}, {83.164, 188.64499999999998`}, {85.785, 
                    191.032}, {85.785, 188.137}, {89.20700000000001, 
                    190.33700000000002`}, {92.62899999999999, 188.137}, {
                    92.62899999999999, 191.032}, {95.25, 
                    188.64499999999998`}, {95.25, 223.423}, {
                    92.62899999999999, 221.032}, {92.62899999999999, 
                    223.92700000000002`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[
                    1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {
                    0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
                    1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4m8aMf2HWOMcVhzzNu/szXSA8Qtsua4v/pLp
EPJ46ewjFbEY/CMKG4oy3mZB+AyxDjfPfQ9+fDDLoXd6nlAzkL8cZN7XLIh5
vTEOlS/VDDnOZDk4d+c8/90ZA9F/NstBla1xqrN0DFx93C5PHiYgH2beDKBx
BxZFw+2D8YNB9k7JgKsH2vJV40AG3Lw+kDt6MuD27y2ZLMGyLQPuPpg8zP0w
/TD/wcyH8WHhAwAmq49E
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    108.27, 195.454}, {110.34400000000001`, 194.134}, {
                    110.34400000000001`, 217.93}, {108.27, 
                    216.61399999999998`}, {108.266, 218.305}, {
                    106.66799999999999`, 216.872}, {105.074, 218.305}, {
                    105.07, 216.61399999999998`}, {102.99600000000001`, 
                    217.93}, {102.99600000000001`, 194.134}, {105.07, 
                    195.454}, {105.074, 193.762}, {106.66799999999999`, 
                    195.192}, {108.266, 193.762}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[
                    1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {
                    0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
                    1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    100.84400000000001`, 192.942}, {102.79700000000001`, 
                    191.466}, {102.79700000000001`, 220.598}, {
                    100.84400000000001`, 219.122}, {100.84, 221.059}, {
                    99.12499999999999, 219.52800000000002`}, {
                    97.41000000000001, 221.059}, {97.406, 219.122}, {95.453, 
                    220.598}, {95.453, 191.466}, {97.406, 192.942}, {
                    97.41000000000001, 191.005}, {99.12499999999999, 
                    192.54}, {100.84, 191.005}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{91.504, 216.466}, {90.691, 
                    215.76999999999998`}, {90.691, 217.82100000000003`}, {
                    92.523, 219.17299999999997`}, {89.20700000000001, 
                    221.618}, {85.891, 219.17299999999997`}, {87.723, 
                    217.82100000000003`}, {87.723, 215.76999999999998`}, {
                    86.91000000000001, 216.466}, {86.91000000000001, 
                    217.595}, {84.96900000000001, 216.001}, {87.051, 
                    214.07899999999998`}, {86.238, 212.95800000000003`}, {
                    92.17199999999998, 212.95800000000003`}, {91.363, 
                    214.07899999999998`}, {93.44500000000001, 216.001}, {
                    91.504, 217.595}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{86.70700000000001, 
                    217.16899999999998`}, {86.70700000000001, 216.372}, {
                    87.926, 215.333}, {87.926, 217.923}, {86.23, 
                    219.17299999999997`}, {89.20700000000001, 
                    221.36800000000002`}, {92.184, 219.17299999999997`}, {
                    90.488, 217.923}, {90.488, 215.333}, {91.703, 216.372}, {
                    91.703, 217.16899999999998`}, {93.137, 215.993}, {
                    91.09400000000001, 214.106}, {91.777, 213.161}, {86.637, 
                    213.161}, {87.32, 214.106}, {85.277, 215.993}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{89.20700000000001, 218.055}, {90.723, 
                    219.17299999999997`}, {89.20700000000001, 220.29}, {
                    89.148, 220.24699999999999`}, {87.691, 
                    219.17299999999997`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[
                    1.]}], FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {
                    1, 3, 3}}}, {{{89.20700000000001, 220.04}, {89.309, 
                    219.966}, {90.203, 219.305}, {90.383, 
                    219.17299999999997`}, {90.203, 219.04399999999998`}, {
                    89.309, 218.38000000000002`}, {89.20700000000001, 
                    218.305}, {89.10499999999999, 218.38000000000002`}, {
                    88.20700000000001, 219.04399999999998`}, {88.031, 
                    219.17299999999997`}, {88.20700000000001, 219.305}, {
                    89.10499999999999, 219.966}, {89.20700000000001, 
                    220.04}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIRIGYC4m8aMf2HlkY6rDjmbd5ZmOlQnDHxbY1+DAZ/
mnN3zvPZmQ5+SQIRliyxGPwFUvp3VZ4h1KPze6fnCTULZDnA7IPxt33+e6Xi
YbjDvysVL9WWZjlIA7Wx7QyB82//rMva8yUIrh5EHcgKwODD7GNrnOrcreOP
wYe5F6YenQ/zL8w+GB/mHjB9NwPuXhgfAAZzj3w=
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIRIGYCYsstJ8r2lQc4VL5UM+SoyHSA8dNAYFGmgycP
k3a7mz8G//z34MdL7yPUo/P3lEyWYOHKcuidnifU/CMIzr/zsy5rz54QB71N
c98vn5flYHBXha3xbjic79Kd8/z3wki4+hlA7QeUYjD4MPvWyESlWH/H5MPc
C1OPzof5F2YfjA9zDwfIoMcZcPfC+DD/wNQDADpbjso=
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, {{{109.004, 204.68}, {109.004, 
                    207.38700000000003`}, {101.766, 207.38700000000003`}, {
                    101.766, 208.02800000000002`}, {95.309, 212.266}, {
                    83.10499999999999, 212.266}, {76.648, 
                    208.02800000000002`}, {76.648, 207.38700000000003`}, {
                    69.41000000000001, 207.38700000000003`}, {
                    69.41000000000001, 204.68}, {76.648, 204.68}, {76.648, 
                    204.036}, {83.10499999999999, 199.798}, {95.309, 
                    199.798}, {101.766, 204.036}, {101.766, 204.68}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, {{{69.613, 207.184}, {76.848, 207.184}, {
                    76.848, 207.91899999999998`}, {83.164, 212.067}, {95.25, 
                    212.067}, {101.562, 207.91899999999998`}, {101.562, 
                    207.184}, {108.801, 207.184}, {108.801, 
                    204.88000000000002`}, {101.562, 204.88000000000002`}, {
                    101.562, 204.14499999999998`}, {95.25, 200.001}, {83.164, 
                    200.001}, {76.848, 204.14499999999998`}, {76.848, 
                    204.88000000000002`}, {69.613, 
                    204.88000000000002`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {CompressedData["
1:eJxTTMoPSmViYGDQAWIQfftnXdaeKWEO0vp3VdhysxwyJ76tsfcNc1ggBRQI
ynL4phHTf4gVIW+15UTZvvpQOJ/r+uICWy6ovGWWgwGQauQNhei/lelgCVLf
HuKw+uMl3ySeLIeQx0tnH9kQ4jDNuTvnuXQWRN/DEIg9nFkO7WI3z31XDnX4
8vdKxUslhPq9JZMlWPyyHGrtTeN2MSLMu6gE9MGpEIg5BzPh8kDTf68szYTr
r3ypZshhkgk3X5WtcapzfCbc/lUg8yoQ6psPnFromoZwP8w8mP+mgty/PBPV
/56ZqOEjmokafkA+LHzB/tfPdEAJf6D8jDyh5gNS4XD+cW/zTscJCPMXuW77
/LcnHG4/WL1QBNx9NSD/vwyHux+o+krFznC4/zx5mLTby8Lh/oeph4UP2P8z
EOYxgMCFcHj4wuRh4Q/TD4sfmPmw+IPZD4tfmHpY/MPcDzMP5j9Y+kHxv2UW
avgA0x8AwN0vbA==
                    "], {{89.20700000000001, 208.997}, {
                    93.15599999999999, 206.032}, {89.20700000000001, 
                    203.067}, {85.258, 206.032}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {CompressedData["
1:eJxTTMoPSmViYGDQAWIQvWnu++XHPoc56IIYaVkOl5Ru/6yrCnOQ1r+rwmaZ
5bDIddvnvz3hDntKJkuwXMp0OOZt3umoEeGw+uMl3ySeLIcae9O4XS/DHaY5
d+c8V85yAKq+UrEz3OHmue/BjwWzHCpeqhlyAPV/AQq/VEKo3wsyzy3LIX6X
Jw9TM8I87uuLC2x3hUPsP5gJlwea/ntlaSZcf2z/oa8aNplw81XZGqc6x2fC
7Qcp8yxAqF8gBTQwDuF+mHkw/1WCzNmQiep/z0wHWPi8Cdwh1yqd6fCwSmSd
+0wEP3Pi2xp73zCIfguoPCNCHuh67fZloXC+1ZYTZfvkEeYbAKlG3lC4/S4g
hxWGwN0X8njp7CMbQuDuB+t7GAL3X/OBUwtd+ULh/oeph4VPcQbQgeII8xhA
4EEIPHxh8rDwh+mHxQ/MfFj8weyHxS9MPSz+Ye6HmQfzHyz9oPgfmL5g4QNL
f7Dwg/Fh4Qv2v1cWPPxh8gBYbjeA
                    "], {{89.145, 209.208}, {
                    84.918, 206.032}, {89.20700000000001, 202.813}, {
                    93.49600000000001, 206.032}, {89.20700000000001, 
                    209.251}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    77.95700000000001, 206.032}, {79.79700000000001, 
                    204.813}, {81.633, 206.032}, {79.79700000000001, 
                    207.255}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[
                    1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{79.79700000000001, 207.009}, {81.266, 206.032}, {
                    79.79700000000001, 205.055}, {78.324, 
                    206.032}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    87.371, 206.032}, {89.20700000000001, 204.813}, {91.043, 
                    206.032}, {89.20700000000001, 207.255}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[
                    1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{89.20700000000001, 207.009}, {90.67999999999999, 
                    206.032}, {89.20700000000001, 205.055}, {
                    87.73400000000001, 206.032}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    100.45700000000001`, 206.032}, {98.617, 204.813}, {96.781,
                     206.032}, {98.617, 207.255}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[
                    1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{98.617, 207.009}, {97.148, 206.032}, {98.617, 
                    205.055}, {100.09, 206.032}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYCYin9uypsG/0d0tOAQC/LIcJyy4myc/4O1xcX
2HKpZzksP+Zt3vnR30GVrXGqs3KWw+2fdVl7eALg/N7peULNCgi+S3fO89+G
AXD9IY+Xzj7iEAA334uHSbs9LwBirmuWw3Eg5VgQ4MC5RiYqJT/LwQpo/b78
AIcjChuKMnox+TOA1h2wgvILsxykQe4H2rf64yXfpJwsh4tKQBdqBTgsAHms
COHezXPfLz/WTZh/eqHrts93/eH6+0D+u+APN3+yBEsY315/uP25z3+v/Bjk
D3cfOv/wV42YfiAf5j8DoHMbQ/3h/kcPfwC3UK7R
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4ts/67L28AQ4fPl7peJlXZaDyDr3h1UiAQ6V
L9UMOSqyHLx4mLTb9QIcenKe/16ZSJivytY41Tk4wEFa/64KW2mWA9f1xQW2
SQEO5p2OCU9rshx6p+cJNSdA7YvKctj2GcgIhNrnkOVQnDHxbY15gANIG5dx
lsPrwB1yrdpQ/TpZDotcgTpkAhy+acT0H9LMcoC5H8affURhQ9EPfzgfbO4d
f7j+X0DlJYf94eaD7ev3h9tvGrfLk6fIH+6+UwuBFub6w90PVtfjD/efAZBq
vOoP9z86vwKk/o2/A+camaiU7CwHYOCuc2cMcPgHNF6tFOF+WPgDADdUstg=

                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    73.301, 214.52}, {71.74600000000001, 215.86}, {
                    70.18799999999999, 214.52}, {71.258, 213.602}, {71.258, 
                    211.47299999999998`}, {70.65199999999999, 
                    212.07899999999998`}, {70.65199999999999, 213.278}, {
                    69.266, 211.993}, {71.74600000000001, 209.516}, {74.223, 
                    211.993}, {72.836, 213.278}, {72.836, 
                    212.07899999999998`}, {72.23400000000001, 
                    211.47299999999998`}, {72.23400000000001, 
                    213.602}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    71.45700000000001, 213.696}, {70.49600000000001, 214.52}, 
                    {71.74600000000001, 215.591}, {72.992, 214.52}, {72.031, 
                    213.696}, {72.031, 210.985}, {73.039, 211.993}, {73.039, 
                    212.817}, {73.93, 211.989}, {71.74600000000001, 
                    209.80200000000002`}, {69.559, 211.989}, {
                    70.44900000000001, 212.817}, {70.44900000000001, 
                    211.993}, {71.45700000000001, 210.985}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    80.848, 216.911}, {79.289, 218.24699999999999`}, {
                    77.73400000000001, 216.911}, {78.801, 215.993}, {78.801, 
                    213.864}, {78.199, 214.466}, {78.199, 
                    215.66899999999998`}, {76.812, 214.38400000000001`}, {
                    79.289, 211.903}, {81.77, 214.38400000000001`}, {80.383, 
                    215.66899999999998`}, {80.383, 214.466}, {79.777, 
                    213.864}, {79.777, 215.993}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    79.004, 216.083}, {78.043, 216.911}, {79.289, 
                    217.98100000000002`}, {80.539, 216.911}, {
                    79.57799999999999, 216.083}, {79.57799999999999, 
                    213.376}, {80.586, 214.38400000000001`}, {80.586, 
                    215.20399999999998`}, {81.477, 214.376}, {79.289, 
                    212.18800000000002`}, {77.10199999999999, 214.376}, {
                    77.99600000000001, 215.20399999999998`}, {
                    77.99600000000001, 214.38400000000001`}, {79.004, 
                    213.376}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    73.301, 197.54399999999998`}, {71.74600000000001, 
                    196.208}, {70.18799999999999, 197.54399999999998`}, {
                    71.258, 198.46200000000002`}, {71.258, 200.591}, {
                    70.65199999999999, 199.989}, {70.65199999999999, 
                    198.786}, {69.266, 200.071}, {71.74600000000001, 
                    202.55200000000002`}, {74.223, 200.071}, {72.836, 
                    198.786}, {72.836, 199.989}, {72.23400000000001, 
                    200.591}, {72.23400000000001, 
                    198.46200000000002`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    71.45700000000001, 198.36800000000002`}, {
                    70.49600000000001, 197.54399999999998`}, {
                    71.74600000000001, 196.47299999999998`}, {72.992, 
                    197.54399999999998`}, {72.031, 198.36800000000002`}, {
                    72.031, 201.07899999999998`}, {73.039, 200.071}, {73.039, 
                    199.251}, {73.93, 200.075}, {71.74600000000001, 
                    202.262}, {69.559, 200.075}, {70.44900000000001, 
                    199.251}, {70.44900000000001, 200.071}, {
                    71.45700000000001, 201.07899999999998`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    105.113, 214.52}, {106.66799999999999`, 215.86}, {108.227,
                     214.52}, {107.15599999999999`, 213.602}, {
                    107.15599999999999`, 211.47299999999998`}, {107.762, 
                    212.07899999999998`}, {107.762, 213.278}, {109.148, 
                    211.993}, {106.66799999999999`, 209.516}, {104.191, 
                    211.993}, {105.57799999999999`, 213.278}, {
                    105.57799999999999`, 212.07899999999998`}, {
                    106.17999999999999`, 211.47299999999998`}, {
                    106.17999999999999`, 213.602}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    106.95700000000001`, 213.696}, {107.918, 214.52}, {
                    106.66799999999999`, 215.591}, {105.422, 214.52}, {
                    106.383, 213.696}, {106.383, 210.985}, {
                    105.37499999999999`, 211.993}, {105.37499999999999`, 
                    212.817}, {104.48400000000001`, 211.989}, {
                    106.66799999999999`, 209.80200000000002`}, {
                    108.85499999999999`, 211.989}, {107.965, 212.817}, {
                    107.965, 211.993}, {106.95700000000001`, 
                    210.985}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    105.113, 197.54399999999998`}, {106.66799999999999`, 
                    196.208}, {108.227, 197.54399999999998`}, {
                    107.15599999999999`, 198.46200000000002`}, {
                    107.15599999999999`, 200.591}, {107.762, 199.989}, {
                    107.762, 198.786}, {109.148, 200.071}, {
                    106.66799999999999`, 202.55200000000002`}, {104.191, 
                    200.071}, {105.57799999999999`, 198.786}, {
                    105.57799999999999`, 199.989}, {106.17999999999999`, 
                    200.591}, {106.17999999999999`, 
                    198.46200000000002`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    106.95700000000001`, 198.36800000000002`}, {107.918, 
                    197.54399999999998`}, {106.66799999999999`, 
                    196.47299999999998`}, {105.422, 197.54399999999998`}, {
                    106.383, 198.36800000000002`}, {106.383, 
                    201.07899999999998`}, {105.37499999999999`, 200.071}, {
                    105.37499999999999`, 199.251}, {104.48400000000001`, 
                    200.075}, {106.66799999999999`, 202.262}, {
                    108.85499999999999`, 200.075}, {107.965, 199.251}, {
                    107.965, 200.071}, {106.95700000000001`, 
                    201.07899999999998`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    80.848, 195.157}, {79.289, 193.817}, {77.73400000000001, 
                    195.157}, {78.801, 196.075}, {78.801, 
                    198.20399999999998`}, {78.199, 197.598}, {78.199, 
                    196.399}, {76.812, 197.684}, {79.289, 200.161}, {81.77, 
                    197.684}, {80.383, 196.399}, {80.383, 197.598}, {79.777, 
                    198.20399999999998`}, {79.777, 196.075}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    79.004, 195.98100000000002`}, {78.043, 195.157}, {79.289, 
                    194.08700000000002`}, {80.539, 195.157}, {
                    79.57799999999999, 195.98100000000002`}, {
                    79.57799999999999, 198.692}, {80.586, 197.684}, {80.586, 
                    196.86}, {81.477, 197.68800000000002`}, {79.289, 
                    199.876}, {77.10199999999999, 197.68800000000002`}, {
                    77.99600000000001, 196.86}, {77.99600000000001, 
                    197.684}, {79.004, 198.692}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    97.566, 216.911}, {99.12499999999999, 
                    218.24699999999999`}, {100.67999999999999`, 216.911}, {
                    99.613, 215.993}, {99.613, 213.864}, {100.215, 214.466}, {
                    100.215, 215.66899999999998`}, {101.60199999999999`, 
                    214.38400000000001`}, {99.12499999999999, 211.903}, {
                    96.645, 214.38400000000001`}, {98.031, 
                    215.66899999999998`}, {98.031, 214.466}, {98.637, 
                    213.864}, {98.637, 215.993}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    99.41000000000001, 216.083}, {100.371, 216.911}, {
                    99.12499999999999, 217.98100000000002`}, {
                    97.87499999999999, 216.911}, {98.836, 216.083}, {98.836, 
                    213.376}, {97.82799999999999, 214.38400000000001`}, {
                    97.82799999999999, 215.20399999999998`}, {96.938, 
                    214.376}, {99.12499999999999, 212.18800000000002`}, {
                    101.309, 214.376}, {100.418, 215.20399999999998`}, {
                    100.418, 214.38400000000001`}, {99.41000000000001, 
                    213.376}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    97.566, 195.157}, {99.12499999999999, 193.817}, {
                    100.67999999999999`, 195.157}, {99.613, 196.075}, {99.613,
                     198.20399999999998`}, {100.215, 197.598}, {100.215, 
                    196.399}, {101.60199999999999`, 197.684}, {
                    99.12499999999999, 200.161}, {96.645, 197.684}, {98.031, 
                    196.399}, {98.031, 197.598}, {98.637, 
                    198.20399999999998`}, {98.637, 196.075}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    99.41000000000001, 195.98100000000002`}, {100.371, 
                    195.157}, {99.12499999999999, 194.08700000000002`}, {
                    97.87499999999999, 195.157}, {98.836, 
                    195.98100000000002`}, {98.836, 198.692}, {
                    97.82799999999999, 197.684}, {97.82799999999999, 
                    196.86}, {96.938, 197.68800000000002`}, {
                    99.12499999999999, 199.876}, {101.309, 
                    197.68800000000002`}, {100.418, 196.86}, {100.418, 
                    197.684}, {99.41000000000001, 198.692}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYCYin9uypsG/0dzn0Pfrw0ONMhwnLLibJz/g7X
FxfYckVnOiw/5m3e+dHfQRAkEZfpcPtnXdYengA4v3d6nlCzAoLv0p3z/Ldh
AFx/yOOls484BMDN9+Jh0m7PC3DoA+mzyXQ4DjTesQCqXyjTwQpo/b78AAeg
7uuLv2Rg8GcAtR2wCnAoBPEFMh2kQe4H2vdNI6b/kGimw0UloAu1AhwqX6oZ
cggg3Nt84NRC128ZBPmnF7pu+3zXH64f7M4L/nDzJ0uwhPHt9Yfbn/v898qP
Qf5w96HzD38Fagzyh/vPAOjcxlB/uP/Rwx8AxOmyuA==
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4ts/67L28AQ4OCU8vaDEnOkgss79YZVIgMOe
kskSLFyZDl48TNrtegEOvdPzhJoVCPNV2RqnOgcHOPy7UvFSjTfTgev64gLb
pAAHoKHr3FkzIeoSAhwcQfapZzps+/z3SkUg1D6nTIfijIlva8yh8v6ZDq8D
d8i1akP1h2Y6LHIF6pAJcLA3jdvlGZHpAHM/jD/7iMKGoh/+cH7lSzVDjjv+
cP2/gMpLDvvDzQfb1+8Ptx+kjafIH+6+UwuBFub6w90PNq/HH+4/g7sqbI1X
/eH+R+dXgNS/8XcQiLDcckIsE2IOY4CDeSfQBh6E+2HhDwCQuaLW
                    
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYCYpfunOe/D8Y4pKcBgV6Wgypb41TnzTEO1xcX
2HKpZznU2pvG7VoYAxFXznL4phHTf6gXwQfrr0Twe6fnCTVnoOmPRJhf8VLN
kEMnxmH5MW/zTtcsBy6QQq0YB841MlEp+VkOIO0HgPwjChuKMnox+VZbTpTt
i4fyC7McHlaJrHPPjHFY/fGSb1JOlgMDCBTEOCyQ0r+rUoRw7+a575cf6ybM
fx24Q651NUI/2H2bEOZXgty/B2G/NFAZ20eE+9D5YPd9RPgP7P73CP+jhz8A
6EisBw==
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4m8aMf2HemMcvvy9UvGyLsthb8lkCZa2GIfK
l2qGHBVZDhUgOifGoSfn+e+ViYT5a2SiUqzdYxyk9e+qsJVmORzzNu90tIhx
AJIJT2uyHFy6gQotofZFZUHUeULtc8hyiN/lycOUHONwfXGBLZdxlsOzC0q3
f+ZB9etkORgAlTfWxjiA3a2Z5QBzP4zffODUQtd5CL7IOveHVWsQ+kMeL519
ZAfC/Bl5Qs0HLiHs3/YZ6LCHCPe9Dtwh1/oY4X6weVcQ/rPacqJs33qE/9H5
YPVLYhw4QQGTneXwsAooMjPG4R/QeLVShPth4Q8Ax0u5yQ==
                    
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYCYpfunOe/D8Y4nPse/HhpcKaDKlvjVOfNMQ7X
FxfYckVnOtTam8btWhjjIBhhueVEXKbDN42Y/kO9CD5YfyWC3zs9T6g5A01/
JML8ipdqhhw6MQ59IHU2mQ5cIIVaUP1CmQ4g4QNAPlD39cVfMjD4VltOlO2L
j3EoBPEFMh0eVomsc8+MgbhLNNOBAQQKYhwqQfYIINzbfODUQtdvGQT5rwN3
yLWuRugHu28Twnyw+B6E/dL6d1XYPiLch84Hu+8jwn9g979H+B89/AH14a/u

                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4m8aMf2HemMcnBKeXlBiznTYWzJZgqUtxmEP
iObKdKh4qWbIkRPj0Ds9T6hZgTB/jUxUirV7jMO/K0AZ3kyHY97mnY4WMQ4P
q0TWubNmOrh05zz/bRnj4AiyTz3TQVr/rgqbJ9Q+p0yH+F2ePEzJUHn/TIdn
F5Ru/8yD6g/NdDAAKm+sjXGwN43b5RmR6QBzP4zffODUQtd5CD5Q18OqNQj9
IY+Xzj6yA2H+DKCzD1xC2L/t898rFQ8R7nsduEOu9THC/WDzriD8Z7XlRNm+
9Qj/o/PB6pfEOAhEWG45IZYJMWdmjAMwVBKe8iDcDwt/ACC/qcc=
                    
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{91.504, 195.598}, {90.691, 
                    196.29399999999998`}, {90.691, 194.24299999999997`}, {
                    92.523, 192.89100000000002`}, {89.20700000000001, 
                    190.446}, {85.891, 192.89100000000002`}, {87.723, 
                    194.24299999999997`}, {87.723, 196.29399999999998`}, {
                    86.91000000000001, 195.598}, {86.91000000000001, 
                    194.47}, {84.96900000000001, 196.063}, {87.051, 
                    197.985}, {86.238, 199.10999999999999`}, {
                    92.17199999999998, 199.10999999999999`}, {91.363, 
                    197.985}, {93.44500000000001, 196.063}, {91.504, 
                    194.47}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{86.70700000000001, 
                    194.895}, {86.70700000000001, 195.692}, {87.926, 
                    196.73499999999999`}, {87.926, 194.141}, {86.23, 
                    192.89100000000002`}, {89.20700000000001, 190.7}, {92.184,
                     192.89100000000002`}, {90.488, 194.141}, {90.488, 
                    196.73499999999999`}, {91.703, 195.692}, {91.703, 
                    194.895}, {93.137, 196.075}, {91.09400000000001, 
                    197.95800000000003`}, {91.777, 198.907}, {86.637, 
                    198.907}, {87.32, 197.95800000000003`}, {85.277, 
                    196.075}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{89.20700000000001, 194.009}, {90.723, 
                    192.89100000000002`}, {89.20700000000001, 
                    191.77399999999997`}, {89.148, 191.82100000000003`}, {
                    87.691, 192.89100000000002`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[
                    1.]}], FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {
                    1, 3, 3}}}, {{{89.20700000000001, 192.02800000000002`}, {
                    89.309, 192.098}, {90.203, 192.762}, {90.383, 
                    192.89100000000002`}, {90.203, 193.024}, {89.309, 
                    193.684}, {89.20700000000001, 193.759}, {
                    89.10499999999999, 193.684}, {88.20700000000001, 
                    193.024}, {88.031, 192.89100000000002`}, {
                    88.20700000000001, 192.762}, {89.10499999999999, 
                    192.098}, {89.20700000000001, 
                    192.02800000000002`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    63.465, 154.24299999999997`}, {63.465, 156.153}, {
                    59.839999999999996`, 153.85200000000003`}, {
                    58.382999999999996`, 154.97299999999998`}, {
                    56.882999999999996`, 154.80200000000002`}, {
                    56.160000000000004`, 153.782}, {57.452999999999996`, 
                    152.79399999999998`}, {56.160000000000004`, 151.805}, {
                    56.882999999999996`, 150.782}, {58.382999999999996`, 
                    150.60999999999999`}, {59.839999999999996`, 151.731}, {
                    63.465, 149.43}, {63.465, 151.345}, {61.184, 
                    152.79399999999998`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[
                    1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {
                    0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
                    1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    59.828, 153.602}, {63.26200000000001, 155.786}, {
                    63.26200000000001, 154.35200000000003`}, {60.805, 
                    152.79399999999998`}, {63.26200000000001, 151.231}, {
                    63.26200000000001, 149.798}, {59.828, 
                    151.98100000000002`}, {58.324, 150.82100000000003`}, {
                    56.996, 150.97299999999998`}, {56.438, 151.762}, {
                    57.785000000000004`, 152.79399999999998`}, {56.438, 
                    153.82100000000003`}, {56.996, 154.60999999999999`}, {
                    58.324, 154.762}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    63.465, 160.88700000000003`}, {63.465, 162.798}, {
                    59.839999999999996`, 160.497}, {58.382999999999996`, 
                    161.618}, {56.882999999999996`, 161.446}, {
                    56.160000000000004`, 160.42700000000002`}, {
                    57.452999999999996`, 159.43800000000002`}, {
                    56.160000000000004`, 158.45000000000002`}, {
                    56.882999999999996`, 157.43}, {58.382999999999996`, 
                    157.255}, {59.839999999999996`, 158.38000000000002`}, {
                    63.465, 156.075}, {63.465, 157.989}, {61.184, 
                    159.43800000000002`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[
                    1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {
                    0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
                    1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    59.828, 160.251}, {63.26200000000001, 162.43}, {
                    63.26200000000001, 160.997}, {60.805, 
                    159.43800000000002`}, {63.26200000000001, 157.876}, {
                    63.26200000000001, 156.442}, {59.828, 158.626}, {58.324, 
                    157.466}, {56.996, 157.618}, {56.438, 158.407}, {
                    57.785000000000004`, 159.43800000000002`}, {56.438, 
                    160.47}, {56.996, 161.255}, {58.324, 161.411}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    63.465, 144.696}, {63.465, 142.786}, {59.839999999999996`,
                     145.08700000000002`}, {58.382999999999996`, 143.966}, {
                    56.882999999999996`, 144.137}, {56.160000000000004`, 
                    145.157}, {57.452999999999996`, 146.14499999999998`}, {
                    56.160000000000004`, 147.137}, {56.882999999999996`, 
                    148.157}, {58.382999999999996`, 148.329}, {
                    59.839999999999996`, 147.208}, {63.465, 149.509}, {63.465,
                     147.598}, {61.184, 146.14499999999998`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[
                    1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {
                    0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
                    1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    59.828, 145.33700000000002`}, {63.26200000000001, 
                    143.153}, {63.26200000000001, 144.58700000000002`}, {
                    60.805, 146.14899999999997`}, {63.26200000000001, 
                    147.708}, {63.26200000000001, 149.141}, {59.828, 
                    146.95800000000003`}, {58.324, 148.118}, {56.996, 
                    147.966}, {56.438, 147.177}, {57.785000000000004`, 
                    146.14899999999997`}, {56.438, 145.118}, {56.996, 
                    144.329}, {58.324, 144.177}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    114.94900000000001`, 154.24299999999997`}, {
                    114.94900000000001`, 156.153}, {118.574, 
                    153.85200000000003`}, {120.031, 154.97299999999998`}, {
                    121.531, 154.80200000000002`}, {122.254, 153.782}, {
                    120.96100000000001`, 152.79399999999998`}, {122.254, 
                    151.805}, {121.531, 150.782}, {120.031, 
                    150.60999999999999`}, {118.574, 151.731}, {
                    114.94900000000001`, 149.43}, {114.94900000000001`, 
                    151.345}, {117.23, 152.79399999999998`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[
                    1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    118.586, 153.602}, {115.15199999999999`, 155.786}, {
                    115.15199999999999`, 154.35200000000003`}, {117.609, 
                    152.79399999999998`}, {115.15199999999999`, 151.231}, {
                    115.15199999999999`, 149.798}, {118.586, 
                    151.98100000000002`}, {120.09, 150.82100000000003`}, {
                    121.418, 150.97299999999998`}, {121.977, 151.762}, {
                    120.62499999999999`, 152.79399999999998`}, {121.977, 
                    153.82100000000003`}, {121.418, 154.60999999999999`}, {
                    120.09, 154.762}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    114.94900000000001`, 160.88700000000003`}, {
                    114.94900000000001`, 162.798}, {118.574, 160.497}, {
                    120.031, 161.618}, {121.531, 161.446}, {122.254, 
                    160.42700000000002`}, {120.96100000000001`, 
                    159.43800000000002`}, {122.254, 158.45000000000002`}, {
                    121.531, 157.43}, {120.031, 157.255}, {118.574, 
                    158.38000000000002`}, {114.94900000000001`, 156.075}, {
                    114.94900000000001`, 157.989}, {117.23, 
                    159.43800000000002`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[
                    1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {
                    0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
                    1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    118.586, 160.251}, {115.15199999999999`, 162.43}, {
                    115.15199999999999`, 160.997}, {117.609, 
                    159.43800000000002`}, {115.15199999999999`, 157.876}, {
                    115.15199999999999`, 156.442}, {118.586, 158.626}, {
                    120.09, 157.466}, {121.418, 157.618}, {121.977, 
                    158.407}, {120.62499999999999`, 159.43800000000002`}, {
                    121.977, 160.47}, {121.418, 161.255}, {120.09, 
                    161.411}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    114.94900000000001`, 144.696}, {114.94900000000001`, 
                    142.786}, {118.574, 145.08700000000002`}, {120.031, 
                    143.966}, {121.531, 144.137}, {122.254, 145.157}, {
                    120.96100000000001`, 146.14499999999998`}, {122.254, 
                    147.137}, {121.531, 148.157}, {120.031, 148.329}, {
                    118.574, 147.208}, {114.94900000000001`, 149.509}, {
                    114.94900000000001`, 147.598}, {117.23, 
                    146.14499999999998`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[
                    1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {
                    0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
                    1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    118.586, 145.33700000000002`}, {115.15199999999999`, 
                    143.153}, {115.15199999999999`, 144.58700000000002`}, {
                    117.609, 146.14899999999997`}, {115.15199999999999`, 
                    147.708}, {115.15199999999999`, 149.141}, {118.586, 
                    146.95800000000003`}, {120.09, 148.118}, {121.418, 
                    147.966}, {121.977, 147.177}, {120.62499999999999`, 
                    146.14899999999997`}, {121.977, 145.118}, {121.418, 
                    144.329}, {120.09, 144.177}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{107.016, 
                    172.934}, {107.016, 170.17299999999997`}, {109.027, 
                    170.17299999999997`}, {109.027, 168.95000000000002`}, {
                    111., 168.95000000000002`}, {111., 171.17299999999997`}, {
                    109.238, 171.17299999999997`}, {109.238, 
                    172.934}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[
                    1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {
                    0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{109.039, 
                    172.731}, {109.039, 170.97299999999998`}, {
                    110.79700000000001`, 170.97299999999998`}, {
                    110.79700000000001`, 169.153}, {109.227, 169.153}, {
                    109.227, 170.372}, {107.21900000000001`, 170.372}, {
                    107.21900000000001`, 172.731}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    112.94100000000002`, 168.575}, {112.94100000000002`, 
                    165.813}, {114.94900000000001`, 165.813}, {
                    114.94900000000001`, 164.591}, {116.926, 164.591}, {
                    116.926, 166.817}, {115.164, 166.817}, {115.164, 
                    168.575}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[
                    1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {
                    0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{114.965, 
                    168.376}, {114.965, 166.61399999999998`}, {116.723, 
                    166.61399999999998`}, {116.723, 164.79399999999998`}, {
                    115.15199999999999`, 164.79399999999998`}, {
                    115.15199999999999`, 166.016}, {113.145, 166.016}, {
                    113.145, 168.376}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{71.398, 
                    172.934}, {71.398, 170.17299999999997`}, {69.387, 
                    170.17299999999997`}, {69.387, 168.95000000000002`}, {
                    67.41400000000002, 168.95000000000002`}, {
                    67.41400000000002, 171.17299999999997`}, {
                    69.17599999999999, 171.17299999999997`}, {
                    69.17599999999999, 172.934}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[
                    1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    69.37499999999999, 172.731}, {69.37499999999999, 
                    170.97299999999998`}, {67.617, 170.97299999999998`}, {
                    67.617, 169.153}, {69.18799999999999, 169.153}, {
                    69.18799999999999, 170.372}, {71.195, 170.372}, {71.195, 
                    172.731}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{107.016, 
                    132.64899999999997`}, {107.016, 135.415}, {109.027, 
                    135.415}, {109.027, 136.634}, {111., 136.634}, {111., 
                    134.411}, {109.238, 134.411}, {109.238, 
                    132.64899999999997`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[
                    1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {
                    0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{109.039, 
                    132.85200000000003`}, {109.039, 134.61399999999998`}, {
                    110.79700000000001`, 134.61399999999998`}, {
                    110.79700000000001`, 136.43}, {109.227, 136.43}, {109.227,
                     135.212}, {107.21900000000001`, 135.212}, {
                    107.21900000000001`, 132.85200000000003`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{71.398, 
                    132.64899999999997`}, {71.398, 135.415}, {69.387, 
                    135.415}, {69.387, 136.634}, {67.41400000000002, 
                    136.634}, {67.41400000000002, 134.411}, {
                    69.17599999999999, 134.411}, {69.17599999999999, 
                    132.64899999999997`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[
                    1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {
                    0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    69.37899999999999, 132.85200000000003`}, {
                    69.37899999999999, 134.61399999999998`}, {67.617, 
                    134.61399999999998`}, {67.617, 136.43}, {
                    69.18799999999999, 136.43}, {69.18799999999999, 
                    135.212}, {71.195, 135.212}, {71.195, 
                    132.85200000000003`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    112.94100000000002`, 137.009}, {112.94100000000002`, 
                    139.76999999999998`}, {114.94900000000001`, 
                    139.76999999999998`}, {114.94900000000001`, 140.993}, {
                    116.926, 140.993}, {116.926, 138.76999999999998`}, {
                    115.164, 138.76999999999998`}, {115.164, 
                    137.009}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[
                    1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {
                    0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{114.965, 
                    137.212}, {114.965, 138.97}, {116.723, 138.97}, {116.723, 
                    140.79}, {115.15199999999999`, 140.79}, {
                    115.15199999999999`, 139.571}, {113.145, 139.571}, {
                    113.145, 137.212}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{65.473, 
                    168.575}, {65.473, 165.813}, {63.465, 165.813}, {63.465, 
                    164.591}, {61.488, 164.591}, {61.488, 166.817}, {63.25, 
                    166.817}, {63.25, 168.575}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[
                    1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {
                    0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{63.449, 
                    168.376}, {63.449, 166.61399999999998`}, {61.691, 
                    166.61399999999998`}, {61.691, 164.79399999999998`}, {
                    63.26200000000001, 164.79399999999998`}, {
                    63.26200000000001, 166.016}, {65.27, 166.016}, {65.27, 
                    168.376}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{65.473, 
                    137.009}, {65.473, 139.76999999999998`}, {63.465, 
                    139.76999999999998`}, {63.465, 140.993}, {61.488, 
                    140.993}, {61.488, 138.76999999999998`}, {63.25, 
                    138.76999999999998`}, {63.25, 137.009}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[
                    1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {
                    0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    63.452999999999996`, 137.212}, {63.452999999999996`, 
                    138.97}, {61.691, 138.97}, {61.691, 140.79}, {
                    63.26200000000001, 140.79}, {63.26200000000001, 
                    139.571}, {65.27, 139.571}, {65.27, 137.212}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4odVIuvcNSMcKl+qGXIsSHWQ1r+rwqYI5S9J
dXh6Qen2z2PhDue/Bz9eeh6T78nDpN2eFu5wfXGBLddiTL5Ld87z3xvDHZoP
nFroWpfqcAmovW5XuMMCKaBFVakOe0smS7D4hTssP+Zt3uma6rBGJirF+j2C
D3NfD9CYlYmpDqpsjVOdkyPg8n5JAhGWLJFwvuWWE2X7pkfAzT8OFHZcEAG3
f9Pc98uPvY6Auw+drwIyvzsC7r+LIPdmRUDU7U91cAb5xzPCYRqIsR7hPlj4
AQCthJsa
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[
                    1.]}], FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {
                    1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
                    1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["

1:eJxTTMoPSmVmYGBgBGJJIGYCYrnW14E7joU7CERYbjlxLNVBHsQ/F+4gCOIf
SnV4WCWyzl0zwuH64gJbrumE+UDdcq3NEXD9YH53BNx8VbbGqc6TIxycEp5e
UDqc6tA7PU+o+QJUflmqg7T+XRW2mxEOX/5eqXi5KNXhuLd5pyNQXm/T3PfL
56U6ZEx8W2PfGuGwQAqosAqT75cENOlJhMM05+6c595Q8zMQfJh7dUHmZaU6
gIR/vwyHy+8tmSzBkofgZ4LMPxsONx+d7wLS3xgOdx/Y/MpwuPtr7U3jdjWG
w/23RiYqxXp/ONz/6OEPAFeYtek=
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4syJb2vsfcMcKl+qGXIsSHVY6Lrt818XKH9J
qkPsLk8eptehDue/Bz9eeh6Tf1Hp9s+6rlCH64sLbLkWY/KbD5xa6HotFELX
pTrIt74O3HEv1GGBlP5dlapUBy6QwqJQh+XHvM07XVMdVNkapzoLh8H5MPf1
5Dz/vTIx1WGNTFSKdTtCHkQ5aoTD+Zvnvl9+bHcY3Hy/JIEIyyNhcPsZQEAg
HO4+dH5xBtDC9WFw/4Hd2xfmsAlk7v5Uh70lkyVY8sIcpjl35zxfj3AfLPwA
brqWLQ==
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[
                    1.]}], FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {
                    1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
                    1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["

1:eJxTTMoPSmVmYGBgBGJJIGYC4thdnjxMr0MdBCIst5w4luoQD+J/DnUQBPEP
pTpkTnxbY+8b5nB9cYEt13TC/OIMoMDyMLh+qy0nyvatD4Obv0YmKsV6e5iD
U8LTC0qHUx1u/6zL2vMFKr8s1WGR67bPf/+EOXz5e6Xi5aJUB5F17g+rgPJ6
m+a+Xz4v1eFhFVBkZZjDAin9uypVmPze6XlCzRzhDtOcu3Oee0P194TB+TD3
6oLMy0p12FsyWYKFDyHvAqR+TwyF88HmfwxFtQ+JD9a/LBTuPoO7KmyNc0Ph
7v+mEdN/aGko3H+qbI1TnR+Hwv2PHv4Az+G4JA==
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4odVIuvcC0McKl+qGXIsSHXY9vnvlYpKKH9J
qsPrwB1yrZdDHM5/D3689Dwmv13s5rnvxqEO1xcX2HItxuT3Ts8Tan4R4tB8
4NRC17pUBwYQeBDisEBK/65KVaoD0PaHVT6hDsuPeZt3uqY6qLA1TnVeHQLn
w9zXk/P898rEVIc1MlEp1uYIebC504Lh/BlA6w4wIcznBjnkVzDcfvlWoA/W
BcPdh84Hm8+P8B/YvQYhDpvmvl9+bH+qQ8jjpbOPBIQ4THPuznm+HuE+WPgB
AHmtmBI=
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[
                    1.]}], FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {
                    1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
                    1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["

1:eJxTTMoPSmVmYGBgBGJJIGYC4k1z3y8/djnEQSDCcsuJY6kOYP7pEAdBEP9Q
qsPDKpF17oUhDtcXF9hyTSfMf3pB6fZPMYT+ZyA+H8L8NTJRKdbsIQ5OCUCV
h1MdnLtznv8+GQyRX5bqsO3z3ysVB4MdvgCpl4tSHbhABp8KdtADOWxeqoP+
XRW2RtEQhwVSQFYVJr/5wKmFrtuCHaaBDPZOdXABmW8YAufD3KsLMi8r1aF3
ep5Q8waEPFD2YZVOKJyfOfFtjf1ZhPnofLB+iVC4+8DmK4bC3R/yeOnsI0B5
mP9U2RqnOt9G+B89/AH5hbwF
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4odVIuvcNSMcdDfNfb98UoKDtP5dFTbFCAfB
CMstJ/oSHJ5eULr981i4w/XFBbZcyZh8Tx4m7fa0cAeQ9mP9mHyX7pznvzeG
O6z6eMk3aUuCwyWg9rpd4Q690/OEmnckOOwtmSzB4hfuAHbH2wSHNTJRKdbv
EXyY+8DuupjgoMrWONU5OQIu75ckEGHJEgnnA11dtm96BNz8497mnY4LIuD2
g931OgLuPnS+Csj87gi4/y6C3JsV4fDl75WKl0UJDs4g/3hCw6cJ4T5Y+AEA
1rqfLA==
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[
                    1.]}], FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {
                    1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
                    1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["

1:eJxTTMoPSmVmYGBgBGJJIGYCYrnW14E7joU7VL5UM+TISXCQB/HPhTtMc+7O
eZ6f4PCwSmSdu2aEw+a575cfm02YD9Qt19ocAdcP5ndHwM1XZWuc6jw5wuEN
SBwo3zs9T6j5AlR9d4KDtP5dFbabEQ6bQOb1Jzgc9zbvdLwA1T8lwSFj4tsa
+9YIiL4dmHy/JIEIyycRDkByy4lnUPMzEHyYe8HmnUhwAFn7+2U4XH5vyWQJ
ljwEPxNk/tlwuPnofBeQ/sZwuPvA5leGw91fa28at6sxHO6/NTJRKdb7w+H+
Rw9/AICQthA=
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4syJb2vsfcMcdDfNfb98UoLDQtdtn/+6hDkI
RlhuOdGX4BC7y5OH6XWow/XFBbZcyZj8i0q3f9Z1hTqAtB/rx+Q3Hzi10PVa
qMOqj5d8k7YkOMi3vg7ccS/UoXd6nlDzjgQHLpBBRaEOD6tE1rm/TXBQZWuc
6iwcBufD3Cetf1eF7WKCwxqZqBTrdoT8MW/zTkeNcDh/M8je3WFw8/2SBCIs
j4TB7WcAAYFwuPvQ+cUZQAvXh8H9B3ZvX5jDl79XKl4WJTjsLZkswZIHDZ8m
hPtg4QcAl/CaPw==
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[
                    1.]}], FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {
                    1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
                    1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["

1:eJxTTMoPSmVmYGBgBGJJIGYC4thdnjxMr0MdKl+qGXLkJDjEg/ifQx2mOXfn
PM9PcMic+LbG3jfMYfPc98uPzSbML84ACiwPg+u32nKibN/6MLj5a2SiUqy3
hzm8Cdwh1wqUv/2zLmvPF6j67gSHRa7bPv/9E+awCWRef4KDyDr3h1VfoPqn
JDg8rAKKrAxz6J2eJ9S8A5MPpjnCHQQiLLeceAbV3xMG58PcCzbvRILD3pLJ
Eix8CHkXoDN+TwyF88HmfwxFtQ+JD9a/LBTuPoO7KmyNc0Ph7v+mEdN/aGko
3H+qbI1TnR+Hwv2PHv4A+Nm4Sw==
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4odVIuvcC0McdDfNfb98UoLDts9/r1RUhjgI
RlhuOdGX4PA6cIdc6+UQh+uLC2y5kjH57WI3z303DnUAaT/Wj8nvnZ4n1Pwi
xGHVx0u+SVsSHBhA4EEIRHxHggPQ9odVPqEOYHe8TXBQYWuc6rw6BM6HuU9a
/64K28UEhzUyUSnW5gj55gOnFrpOC4bzZwCNPcCEMJ8b5NBfwXD75VuBPlgX
DHcfOh9sPj/Cf2D3GoQ4fAEGy8uiBIeQx0tnHwmAhk8Twn2w8AMAouOcJA==

                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[
                    1.]}], FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {
                    1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
                    1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["

1:eJxTTMoPSmVmYGBgBGJJIGYC4k1z3y8/djnEofKlmiFHToIDmH86xGGac3fO
8/wEh4dVIuvcC0McNoPEZxPmP72gdPunGEL/MxCfD2H+GpmoFGv2EIc3gTvk
WoHyIGW/TwZD1HcnOGz7/PdKxcFgiDv6Exy4ri8usD0VDNE/JcFB/64KW6No
iEPv9Dyh5h2Y/OYDpxa6bgt2EIiw3HLiWYKDC8h8wxA4H+ZesHknEiD6NiDk
gbIPq3RC4fzMiW9r7M8izEfng2mJULj7wOYrhsLdH/J46ewjQHmY/1TZGqc6
30b4Hz38ASKMvCw=
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{69.18799999999999, 
                    170.372}, {69.18799999999999, 166.016}, {
                    63.26200000000001, 166.016}, {63.26200000000001, 
                    139.571}, {69.18799999999999, 139.571}, {
                    69.18799999999999, 135.212}, {109.227, 135.212}, {109.227,
                     139.571}, {115.15199999999999`, 139.571}, {
                    115.15199999999999`, 166.016}, {109.227, 166.016}, {
                    109.227, 170.372}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{109.027, 
                    170.17299999999997`}, {109.027, 165.813}, {
                    114.94900000000001`, 165.813}, {114.94900000000001`, 
                    139.76999999999998`}, {109.027, 139.76999999999998`}, {
                    109.027, 135.415}, {69.387, 135.415}, {69.387, 
                    139.76999999999998`}, {63.465, 139.76999999999998`}, {
                    63.465, 165.813}, {69.387, 165.813}, {69.387, 
                    170.17299999999997`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{106.46100000000001`, 
                    168.497}, {71.94900000000001, 168.497}, {
                    71.94900000000001, 163.251}, {65.137, 163.251}, {65.137, 
                    142.333}, {71.94900000000001, 142.333}, {
                    71.94900000000001, 137.08700000000002`}, {
                    106.46100000000001`, 137.08700000000002`}, {
                    106.46100000000001`, 142.333}, {113.277, 142.333}, {
                    113.277, 163.251}, {106.46100000000001`, 
                    163.251}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{106.262, 168.298}, {
                    106.262, 163.048}, {113.074, 163.048}, {113.074, 
                    142.536}, {106.262, 142.536}, {106.262, 137.29}, {
                    72.15199999999999, 137.29}, {72.15199999999999, 
                    142.536}, {65.34, 142.536}, {65.34, 163.048}, {
                    72.15199999999999, 163.048}, {72.15199999999999, 
                    168.298}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{65.137, 
                    146.317}, {77.633, 137.08700000000002`}, {100.781, 
                    137.08700000000002`}, {113.277, 146.317}, {113.277, 
                    159.26999999999998`}, {100.781, 168.497}, {77.633, 
                    168.497}, {65.137, 159.26999999999998`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[
                    1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{100.715, 
                    168.298}, {100.766, 168.259}, {112.992, 159.227}, {
                    113.074, 159.165}, {113.074, 146.41899999999998`}, {
                    112.992, 146.35600000000002`}, {100.766, 137.329}, {
                    100.715, 137.29}, {77.699, 137.29}, {77.648, 137.329}, {
                    65.422, 146.35600000000002`}, {65.34, 
                    146.41899999999998`}, {65.34, 159.165}, {65.422, 
                    159.227}, {77.648, 168.259}, {77.699, 
                    168.298}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{103.195, 
                    165.684}, {75.117, 165.684}, {75.117, 163.454}, {71.531, 
                    163.454}, {71.531, 142.13}, {75.117, 142.13}, {75.117, 
                    139.899}, {103.29700000000001`, 139.899}, {
                    103.29700000000001`, 142.13}, {106.883, 142.13}, {106.883,
                     163.454}, {103.29700000000001`, 163.454}, {
                    103.29700000000001`, 165.684}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{103.09400000000001`, 
                    165.48100000000002`}, {103.09400000000001`, 163.255}, {
                    106.67999999999999`, 163.255}, {106.67999999999999`, 
                    142.329}, {103.09400000000001`, 142.329}, {
                    103.09400000000001`, 140.102}, {75.32, 140.102}, {75.32, 
                    142.329}, {71.73400000000001, 142.329}, {
                    71.73400000000001, 163.255}, {75.32, 163.255}, {75.32, 
                    165.48100000000002`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{72.406, 
                    145.02800000000002`}, {78.516, 139.899}, {99.898, 
                    139.899}, {106.008, 145.02800000000002`}, {106.008, 
                    160.555}, {99.898, 165.684}, {78.516, 165.684}, {72.406, 
                    160.555}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[
                    1.]}], FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {
                    0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{99.824, 
                    165.48100000000002`}, {99.883, 165.43800000000002`}, {
                    105.73400000000001`, 160.52}, {105.80499999999999`, 
                    160.46200000000002`}, {105.80499999999999`, 145.122}, {
                    105.73400000000001`, 145.063}, {99.883, 
                    140.14899999999997`}, {99.824, 140.102}, {78.59, 
                    140.102}, {78.531, 140.14899999999997`}, {
                    72.67999999999999, 145.063}, {72.609, 145.122}, {72.609, 
                    160.46200000000002`}, {72.67999999999999, 160.52}, {
                    78.531, 165.43800000000002`}, {78.59, 
                    165.48100000000002`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{73.473, 
                    145.52800000000002`}, {78.902, 140.966}, {99.512, 
                    140.966}, {104.938, 145.52800000000002`}, {104.938, 
                    160.059}, {99.512, 164.618}, {78.902, 164.618}, {73.473, 
                    160.059}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{99.438, 
                    164.415}, {99.492, 164.36800000000002`}, {104.664, 
                    160.024}, {104.738, 159.96200000000002`}, {104.738, 
                    145.622}, {104.664, 145.559}, {99.492, 
                    141.21599999999998`}, {99.438, 141.16899999999998`}, {
                    78.977, 141.16899999999998`}, {78.922, 
                    141.21599999999998`}, {73.74600000000001, 145.559}, {
                    73.67599999999999, 145.622}, {73.67599999999999, 
                    159.96200000000002`}, {73.74600000000001, 160.024}, {
                    78.922, 164.36800000000002`}, {78.977, 164.415}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{81.363, 
                    165.48100000000002`}, {97.051, 165.48100000000002`}, {
                    97.051, 166.30200000000002`}, {95.398, 
                    167.72299999999998`}, {93.85199999999999, 
                    166.38700000000003`}, {92.30499999999999, 
                    167.72299999999998`}, {90.754, 166.38700000000003`}, {
                    89.20700000000001, 167.72299999999998`}, {87.66, 
                    166.38700000000003`}, {86.109, 167.72299999999998`}, {
                    84.562, 166.38700000000003`}, {83.016, 
                    167.72299999999998`}, {81.363, 
                    166.30200000000002`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{96.848, 165.684}, {93.953, 165.684}, {93.953, 
                    166.208}, {95.398, 167.454}, {96.848, 
                    166.208}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{93.75, 165.684}, {90.85499999999999, 165.684}, {
                    90.85499999999999, 166.208}, {92.30499999999999, 
                    167.454}, {93.75, 166.208}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{90.65199999999999, 165.684}, {87.758, 165.684}, {
                    87.758, 166.208}, {89.20700000000001, 167.454}, {
                    90.65199999999999, 166.208}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{87.559, 165.684}, {84.664, 165.684}, {84.664, 
                    166.208}, {86.109, 167.454}, {87.559, 
                    166.208}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{84.46100000000001, 165.684}, {81.566, 165.684}, {
                    81.566, 166.208}, {83.016, 167.454}, {84.46100000000001, 
                    166.208}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{66.863, 
                    149.696}, {68.195, 148.14899999999997`}, {66.863, 
                    146.598}, {68.281, 144.95000000000002`}, {
                    71.73400000000001, 144.95000000000002`}, {
                    71.73400000000001, 160.634}, {68.281, 160.634}, {66.863, 
                    158.985}, {68.195, 157.43800000000002`}, {66.863, 
                    155.88700000000003`}, {68.195, 154.341}, {66.863, 
                    152.79399999999998`}, {68.195, 
                    151.24299999999997`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{68.37499999999999, 145.153}, {67.12899999999999, 
                    146.598}, {68.37499999999999, 148.048}, {71.531, 
                    148.048}, {71.531, 145.153}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{68.37499999999999, 148.24699999999999`}, {
                    67.12899999999999, 149.696}, {68.37499999999999, 
                    151.141}, {71.531, 151.141}, {71.531, 
                    148.24699999999999`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{68.37499999999999, 151.345}, {67.12899999999999, 
                    152.79399999999998`}, {68.37499999999999, 
                    154.23899999999998`}, {71.531, 154.23899999999998`}, {
                    71.531, 151.345}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{68.37499999999999, 154.442}, {67.12899999999999, 
                    155.88700000000003`}, {68.37499999999999, 
                    157.33700000000002`}, {71.531, 157.33700000000002`}, {
                    71.531, 154.442}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{68.37499999999999, 157.54}, {67.12899999999999, 
                    158.985}, {68.37499999999999, 160.43}, {71.531, 160.43}, {
                    71.531, 157.54}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{81.363, 
                    140.102}, {97.051, 140.102}, {97.051, 139.282}, {95.398, 
                    137.86}, {93.85199999999999, 139.196}, {92.30499999999999,
                     137.86}, {90.754, 139.196}, {89.20700000000001, 
                    137.86}, {87.66, 139.196}, {86.109, 137.86}, {84.562, 
                    139.196}, {83.016, 137.86}, {81.363, 139.282}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{96.848, 139.899}, {93.953, 139.899}, {93.953, 
                    139.376}, {95.398, 138.13}, {96.848, 139.376}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{93.75, 139.899}, {90.85499999999999, 139.899}, {
                    90.85499999999999, 139.376}, {92.30499999999999, 
                    138.13}, {93.75, 139.376}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{90.65199999999999, 139.899}, {87.758, 139.899}, {
                    87.758, 139.376}, {89.20700000000001, 138.13}, {
                    90.65199999999999, 139.376}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{87.559, 139.899}, {84.664, 139.899}, {84.664, 
                    139.376}, {86.109, 138.13}, {87.559, 139.376}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{84.46100000000001, 139.899}, {81.566, 139.899}, {
                    81.566, 139.376}, {83.016, 138.13}, {84.46100000000001, 
                    139.376}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{111.551, 
                    149.696}, {110.21900000000001`, 148.14899999999997`}, {
                    111.551, 146.598}, {110.133, 144.95000000000002`}, {
                    106.67999999999999`, 144.95000000000002`}, {
                    106.67999999999999`, 160.634}, {110.133, 160.634}, {
                    111.551, 158.985}, {110.21900000000001`, 
                    157.43800000000002`}, {111.551, 155.88700000000003`}, {
                    110.21900000000001`, 154.341}, {111.551, 
                    152.79399999999998`}, {110.21900000000001`, 
                    151.24299999999997`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{110.039, 145.153}, {111.285, 146.598}, {110.039, 
                    148.048}, {106.883, 148.048}, {106.883, 
                    145.153}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{110.039, 148.24699999999999`}, {111.285, 
                    149.696}, {110.039, 151.141}, {106.883, 151.141}, {
                    106.883, 148.24699999999999`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{110.039, 151.345}, {111.285, 
                    152.79399999999998`}, {110.039, 154.23899999999998`}, {
                    106.883, 154.23899999999998`}, {106.883, 
                    151.345}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{110.039, 154.442}, {111.285, 
                    155.88700000000003`}, {110.039, 157.33700000000002`}, {
                    106.883, 157.33700000000002`}, {106.883, 
                    154.442}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{110.039, 157.54}, {111.285, 158.985}, {110.039, 
                    160.43}, {106.883, 160.43}, {106.883, 157.54}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{82.031, 
                    141.16899999999998`}, {83.191, 142.286}, {
                    84.35199999999999, 141.16899999999998`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    83.191, 144.622}, {82.05499999999999, 
                    145.52800000000002`}, {80.922, 145.04}, {80.715, 
                    143.74299999999997`}, {81.79700000000001, 142.79}, {80.02,
                     141.071}, {82.223, 141.071}, {83.191, 142.005}, {
                    84.15599999999999, 141.071}, {86.363, 141.071}, {84.586, 
                    142.79}, {85.664, 143.74299999999997`}, {
                    85.46100000000001, 145.04}, {84.324, 
                    145.52800000000002`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[
                    1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {
                    0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
                    1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{81.10199999999999, 144.895}, {82.023, 
                    145.29399999999998`}, {83.191, 144.364}, {83.254, 
                    144.415}, {84.35499999999999, 145.29399999999998`}, {
                    85.277, 144.895}, {85.44900000000001, 
                    143.82100000000003`}, {84.285, 142.798}, {85.973, 
                    141.16899999999998`}, {84.35199999999999, 
                    141.16899999999998`}, {83.191, 142.286}, {82.031, 
                    141.16899999999998`}, {80.406, 141.16899999999998`}, {
                    82.09400000000001, 142.798}, {80.93400000000001, 
                    143.82100000000003`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    88.04700000000001, 141.16899999999998`}, {
                    89.20700000000001, 142.286}, {90.367, 
                    141.16899999999998`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    89.20700000000001, 144.622}, {88.074, 
                    145.52800000000002`}, {86.938, 145.04}, {
                    86.73400000000001, 143.74299999999997`}, {87.812, 
                    142.79}, {86.035, 141.071}, {88.238, 141.071}, {
                    89.20700000000001, 142.005}, {90.17599999999999, 
                    141.071}, {92.37899999999999, 141.071}, {
                    90.60199999999999, 142.79}, {91.684, 
                    143.74299999999997`}, {91.477, 145.04}, {90.34, 
                    145.52800000000002`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[
                    1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {
                    0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
                    1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{87.121, 144.895}, {88.043, 
                    145.29399999999998`}, {89.20700000000001, 144.364}, {
                    89.27, 144.415}, {90.371, 145.29399999999998`}, {91.293, 
                    144.895}, {91.465, 143.82100000000003`}, {
                    90.30499999999999, 142.798}, {91.988, 
                    141.16899999999998`}, {90.367, 141.16899999999998`}, {
                    89.20700000000001, 142.286}, {88.04700000000001, 
                    141.16899999999998`}, {86.426, 141.16899999999998`}, {
                    88.109, 142.798}, {86.94900000000001, 
                    143.82100000000003`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{96.383, 
                    141.16899999999998`}, {95.223, 142.286}, {94.062, 
                    141.16899999999998`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    95.223, 144.622}, {96.359, 145.52800000000002`}, {
                    97.49600000000001, 145.04}, {97.699, 
                    143.74299999999997`}, {96.617, 142.79}, {98.398, 
                    141.071}, {96.191, 141.071}, {95.223, 142.005}, {94.258, 
                    141.071}, {92.051, 141.071}, {93.82799999999999, 
                    142.79}, {92.75, 143.74299999999997`}, {92.953, 145.04}, {
                    94.09, 145.52800000000002`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[
                    1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {
                    0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
                    1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{97.312, 144.895}, {96.391, 
                    145.29399999999998`}, {95.223, 144.364}, {95.16, 
                    144.415}, {94.059, 145.29399999999998`}, {93.137, 
                    144.895}, {92.96900000000001, 143.82100000000003`}, {
                    94.12899999999999, 142.798}, {92.44100000000002, 
                    141.16899999999998`}, {94.062, 141.16899999999998`}, {
                    95.223, 142.286}, {96.383, 141.16899999999998`}, {98.008, 
                    141.16899999999998`}, {96.32, 142.798}, {97.48, 
                    143.82100000000003`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{82.031, 
                    164.415}, {83.191, 163.298}, {84.35199999999999, 
                    164.415}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    83.191, 160.96200000000002`}, {82.05499999999999, 
                    160.055}, {80.922, 160.548}, {80.715, 161.841}, {
                    81.79700000000001, 162.79399999999998`}, {79.98, 
                    164.548}, {82.184, 164.548}, {83.191, 
                    163.57899999999998`}, {84.195, 164.548}, {86.402, 
                    164.548}, {84.586, 162.79399999999998`}, {85.664, 
                    161.841}, {85.46100000000001, 160.548}, {84.324, 
                    160.055}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[
                    1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {
                    0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
                    1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{81.10199999999999, 160.68800000000002`}, {82.023,
                     160.29}, {83.191, 161.22}, {83.254, 
                    161.16899999999998`}, {84.35499999999999, 160.29}, {
                    85.277, 160.68800000000002`}, {85.44900000000001, 
                    161.762}, {84.285, 162.786}, {85.973, 164.415}, {
                    84.35199999999999, 164.415}, {83.191, 163.298}, {82.031, 
                    164.415}, {80.406, 164.415}, {82.09400000000001, 
                    162.786}, {80.93400000000001, 161.762}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    88.04700000000001, 164.415}, {89.20700000000001, 
                    163.298}, {90.367, 164.415}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    89.20700000000001, 160.96200000000002`}, {88.074, 
                    160.055}, {86.938, 160.548}, {86.73400000000001, 
                    161.841}, {87.812, 162.79399999999998`}, {
                    85.99600000000001, 164.548}, {88.203, 164.548}, {
                    89.20700000000001, 163.57899999999998`}, {90.215, 
                    164.548}, {92.418, 164.548}, {90.60199999999999, 
                    162.79399999999998`}, {91.684, 161.841}, {91.477, 
                    160.548}, {90.34, 160.055}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[
                    1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {
                    0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
                    1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{87.121, 160.68800000000002`}, {88.043, 160.29}, {
                    89.20700000000001, 161.22}, {89.27, 
                    161.16899999999998`}, {90.371, 160.29}, {91.293, 
                    160.68800000000002`}, {91.465, 161.762}, {
                    90.30499999999999, 162.786}, {91.988, 164.415}, {90.367, 
                    164.415}, {89.20700000000001, 163.298}, {
                    88.04700000000001, 164.415}, {86.426, 164.415}, {88.109, 
                    162.786}, {86.94900000000001, 161.762}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{96.383, 
                    164.415}, {95.223, 163.298}, {94.062, 
                    164.415}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    95.223, 160.96200000000002`}, {96.359, 160.055}, {
                    97.49600000000001, 160.548}, {97.699, 161.841}, {96.617, 
                    162.79399999999998`}, {98.43400000000001, 164.548}, {
                    96.23, 164.548}, {95.223, 163.57899999999998`}, {
                    94.21900000000001, 164.548}, {92.016, 164.548}, {
                    93.82799999999999, 162.79399999999998`}, {92.75, 
                    161.841}, {92.953, 160.548}, {94.09, 160.055}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[
                    1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {
                    0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
                    1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{97.312, 160.68800000000002`}, {96.391, 160.29}, {
                    95.223, 161.22}, {95.16, 161.16899999999998`}, {94.059, 
                    160.29}, {93.137, 160.68800000000002`}, {
                    92.96900000000001, 161.762}, {94.12899999999999, 
                    162.786}, {92.44100000000002, 164.415}, {94.062, 
                    164.415}, {95.223, 163.298}, {96.383, 164.415}, {98.008, 
                    164.415}, {96.32, 162.786}, {97.48, 161.762}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    104.738, 158.567}, {104.738, 157.048}, {
                    104.73400000000001`, 157.048}, {103.816, 
                    157.805}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4oWu2z7/vRLpcPPc9+DHd5MdvmnE9B86G+nw
70rFS7WHyQ6WW06U7Zse6bDimLd5509MPli9a6TDqo+XfJO+JDtkTHxbY68a
6eDJw6Tdfg2Tv0YmKsU6PBKib2+yw7MLSrd/xkH5OxHyYPdsReiX1r+rwjYX
kw+zX5WtcapzPcJ9C6SACqow+TD/gd0zKdkB5n+w+FSovGkUxP5cBN8x4ekF
peXJDr3T84SaOaLg7oXJ94HEzyD454Hal/5PdvAC2aMX5SAYAXQJU4pDyOOl
s48IRDmkgcC3ZIcZQG0HPkHd9wrhHlh8AACwN8WQ
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[
                    1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {
                    0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 
                    1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4jUyUSnW+lEOC6T076pcSnbwSxKIsPwS6fBN
I6b/0M5kB5j8EYUNRRkLEXxpoHK2ymQHkXXuD6uuRDqkpwHBPEy+5ZYTZfum
RzoIRgBZTckOrwN3yLVOjnSw6HRMeNqQ7NB84NRC175Ih4dVQJ2NyQ6b5r5f
fiw40sEcJN+SDHGHL1S+NdlBha1xqrN3pMO578GPl7YnQ9xhGenQOz1PqHlG
skPGxLc19qaRDtOcu3Oez052UAWpt450+PL3SsVLoHvA5hQi/IfOh+nfCHLH
dYT5TglPLyjdRthf+VLNkOMNwn1g/75DuB/s33cI/4Gk0z4h/A+W/4QIH3B4
fECEH9hdVzH5sPDXBVn0K9kBAPEyyhI=
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    104.738, 153.555}, {104.738, 152.032}, {
                    104.73400000000001`, 152.032}, {103.816, 
                    152.79}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4oWu2z7/vRLpcERhQ1GGbbLDN42Y/kNnIx0K
bbmuL3ZIdrDccqJs3/RIB2n9uypskZh8sHrXSIdpzt05z4OTHTImvq2xV410
2FsyWYLFDJO/RiYqxTo80uFhlcg6d9lkh2cXlG7/jIPyJRHyYPeIIvSD3fMn
CYMPs18wAuiye0lw9/XkPP+98iYmH+a/PSD3fEpygPkfbP/XJIenIPeYRTmY
dzomPD2D4C+QAnk42aF3ep5QM0cU3L0w+T6QuA6CD7YnNdmh+cCpha5iUQ72
pnG7PCOg4fU10uHL3ysVL72SHdDDHwCGkrqO
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[
                    1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {
                    0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
                    3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGI5IGYC4jUyUSnW+lEO3zRi+g8ZJjv4JQlEWH6JdHhY
JbLOXTLZASYvrX9XhY0Rwe+dnifUfCPJAajqYdWVSIeb574HP/6LybfccqJs
3/RIh+YDpxa6PkpyeB24Q651cqTDqo+XfJMeJEHE+yIdQh4vnX0EyN809/3y
Y8FQ+SdJEHf5RjoEg+SBfBW2xqnO3pEOjglPLyg9T4K4yzLSofKlmiHHjySH
jIlva+xNIx04QQ79neSgClJvHengxcOk3f4vCeKvQoT/CPFh+u1N43Z5miTD
zQeLmyfD7dcFOdwqGe6+NyB/eifD3Q8OD99kuP/A/vZLhvsfLB+YDA8fsHhQ
Mjz8wOERkAwPX3B4mGDyYfGzQArosKhkBwC57tdw
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    104.738, 147.016}, {104.738, 148.536}, {
                    104.73400000000001`, 148.536}, {103.816, 
                    147.778}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4oWu2z7/vRLpEPx46ewjIUkO3zRi+g+djXRY
cczbvDMwycFyy4myfdMjHf5dqXipZonJB6t3jXRoPnBqoatdkkPGxLc19qqR
DrH9h75qxGDy18hEpViHRzpI699VYStNcnh2Qen2z7hIB/NOx4SnFQj5EJB7
ahD6u3Oe/145FZMPs58DpHEzwn0FtlzXF+/A5MP8FwNyz4IkB5j/wfbPSXJ4
CnKPWZTDwyqRde5HEXyw+3uSHHqn5wk1c0TB3QuTB7snFcG/vhhoozHUf3pR
Due/A0NYPwnib8Eoh8qXaoYcNkkO8bs8eZg+Rzqs+njJN8kD4R5YfAAAHKjI
7g==
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[
                    1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {
                    0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 
                    1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4jUyUSnW+lEOvdPzhJoTkhz8kgQiLL9EOph3
OiY8rUhygMk/rBJZ5z4Rwe/Jef575c4kB6Dow6orkQ6rPl7yTZqCybfccqJs
3/RIh2nO3TnP1yc5vA7cIdc6OdLhm0ZM/6GNSQ7NB04tdO2LdFhxzNu8E8jf
NPf98mPBUPm1SRDaN9LhiMKGogwgX4Wtcaqzd6TD9cUFtlyrkxyk9e+qsFlG
OiyQAjJmJTlkTHxbY28a6QD0xZYT05IcVEHqrSMh5k5OgvijEOE/dD5MP9j8
aIT5574HP14ajrBfF2SgG8J99qZxuzxdEO4H+9cZ4T+wvAPC/2B5e0T4gM1x
RIQf2L+xmHxY+Fe+VDPksEhyAAAQD8ZG
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    73.67999999999999, 158.567}, {73.67999999999999, 
                    157.048}, {74.598, 157.805}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYCYv27KmyNR4Mcbp77Hvz4brLD7Z91WXvOBDn8
u1LxUu1hssOMPKHmA0zBDiuOeZt3/sTkL3Td9vlvSLDDqo+XfJO+JDtkTHxb
Y18a7ODJw6Tdfg2T/zpwh1yrc7DDN42Y/kN7kx3egPjWUP5OhDzYPVsR+qVB
Dp2LyYfZr8rWONW5HuG+BVJABVWYfJj/wO6ZlOwA8z/Y/qlQ+RRoeOQi+I4J
Ty8oLU92cOnOef57YhDcvTD5vulAi84g+ODwYEhxUAG5KzvI4friAlsu5hQH
oGuvVHQGOehumvt++bdkh2KQh5YHObQcOLXQ9RXCPbD4AAA628bg
                    
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[
                    1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {
                    0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 
                    1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4teBO+Ras4McFkjp31W5lOzQfODUQtdlQQ7f
NGL6D+1MdoDJH1HYUJSxEMGXBipnq0x22FsyWYLlWJBDehoQzMPkx+/y5GFi
DnYQjLDccqIp2eHpBaXbP9mCHSw6HROeNiQ7+CUJRFjyBDs8rBJZ594IlXcL
djAHybckO9z+WZe1xwcq35rssEYmKsXaP9jh3Pfgx0vbkx22ff57pSIx2KF3
ep5Q84xkh4yJb2vsU4Mdpjl35zyfDVUfH+zwBajsJdA9YHM0g+H+Q+fD9G+c
+375sesI850SQC5D2F/5Us2Q4w3CfWD/vkO4H+zfdwj/gaTTPiH8D5b/hAgf
cHh8QIQf2F1XMfmw8NfdBHTgr2QHAFQuzOI=
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    73.67999999999999, 153.555}, {73.67999999999999, 
                    152.032}, {74.598, 152.79}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYCYv27KmyNR4McjihsKMqwTXa4/bMua8+ZIIdC
W67rix2SHWbkCTUfYAp2kAYpjMTkL3Td9vlvSLDDNOfunOfByQ4ZE9/W2JcG
O+wtmSzBYobJfx24Q67VOdjhYZXIOnfZZIc3IL41lC+JkAe7RxShH+yeP0kY
fJj9ghGWW07cS4K7ryfn+e+VNzH5MP/tAbnnU5IDzP9g+78mOQDJh1Up0PA4
i+B78jBpt7MlO7gAvfl7YhDcvTD52P5DXzV0klH1p0LDpyXIofKlmiFHBNQ/
S4McdDfNfb/cK9kBPfwBsn+wQQ==
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[
                    1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {
                    0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 
                    3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGI5IGYC4teBO+Ras4McvmnE9B8yTHZoPnBqoeuyIIeH
VSLr3CWTHWDy0vp3VdgYEfze6XlCzTeSHPaWTJZgORbkcPPc9+DHfzH58bs8
eZiYgyHmPkpyeHpB6fZPtmCHVR8v+SY9SHLwSxKIsOQJdgh5vHT2kQdQeTeo
/JMkh9s/67L2+AQ7BIPkgfw1MlEp1v7BDo4JQJXPkxy2ff57pSIx2KHypZoh
x48kh4yJb2vsU4MdOEEKf0PVxwc7ePEwabf/S4L4SzMY7j9CfJh+e9O4XZ4m
yXDzVdkapzqbJ8Pt19009/1yq2S4+96Awsk7Ge5+cHj4JsP9Bw4Pv2S4/8Hy
gcnw8AHLByXDww8cHgHJ8PAFh4cJJh8WPwukgBEWlewAAIKx2k0=
                    
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    73.67999999999999, 147.016}, {73.67999999999999, 
                    148.536}, {74.598, 147.778}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYCYv27KmyNR4Mcgh8vnX0kJMnh9s+6rD1nghxW
HPM27wxMcpiRJ9R8gCnY4d+Vipdqlpj8ha7bPv8NCXZoPnBqoatdkkPGxLc1
9qXBDrH9h75qxGDyXwfukGt1DnaQBllcmuTwBsS3DnYw73RMeFqBkA8BuacG
ob875/nvlVMx+TD7OdbIRKVsRrivwJbr+uIdmHyY/2JA7lmQ5ADzP9j+OUkO
IuvcH1alQPlHEPzz34Eh1J3k4AKyeGIQ3L0w+QVSQJPSEHzdTXPfLzdKcgBR
x7KDILR+kgPQtVcqOoMg4WGT5FAM8tDyIIfe6UCHeiDcA4sPAMpDxDI=
                    
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[
                    1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {
                    0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 
                    1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4teBO+Ras4MceqfnCTUnJDk0Hzi10HVZkIN5
p2PC04okB5j8wyqRde4TEfyenOe/V+5McthbMlmC5ViQw6qPl3yTpmDy43d5
8jAxBztMc+7Oeb4+yeHpBaXbP9mCHb5pxPQf2pjk4JckEGHJE+yw4pi3eedG
qLwbVH5tksPtn3VZe3yCHY4obCjKAPLXyESlWPsHO1xfXGDLtTrJYdvnv1cq
EoMdFkjp31WZleSQMfFtjX1qsAPQ1C0npkHVxwc7bJr7fvmxyUkQf2gGw/2H
zofpB5sfjTD/3Pfgx0vDEfbrggx0Q7jP3jRul6cLwv1g/zoj/AeWd0D4Hyxv
jwgfsH8dEeEH9m8sJh8W/pUv1Qw5LJIcAHL8yRY=
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIRIGYCYk8eJu32aeEOXiB6VZIDjL9p7vvlxx4nOci1
vg7cYRaBwf/y90rFS79kuHp0vr1p3C7PjmSHGXlCzQeUMPnXFxfYch1PdrDc
cqJsX3koBh+mvl3s5rnvzJh8mH1gdyWHYPBh7oWpR+fD/AuzD51//nvw46XZ
SXD3ovNh6gHRGpUg
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{84.262, 154.266}, {84.262, 156.055}, {86.074, 
                    156.055}, {86.074, 158.016}, {89.10499999999999, 
                    158.016}, {89.10499999999999, 155.993}, {86.238, 
                    154.364}, {86.238, 152.89100000000002`}, {81.762, 
                    152.89100000000002`}, {81.762, 154.266}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{94.15199999999999, 151.32100000000003`}, {
                    94.15199999999999, 149.52800000000002`}, {92.34, 
                    149.52800000000002`}, {92.34, 147.567}, {89.309, 
                    147.567}, {89.309, 149.591}, {92.17599999999999, 
                    151.22}, {92.17599999999999, 152.692}, {96.65199999999999,
                     152.692}, {96.65199999999999, 
                    151.32100000000003`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{94.15199999999999, 156.055}, {94.15199999999999, 
                    154.266}, {96.65199999999999, 154.266}, {
                    96.65199999999999, 152.89100000000002`}, {
                    92.17599999999999, 152.89100000000002`}, {
                    92.17599999999999, 154.364}, {89.309, 155.993}, {89.309, 
                    158.016}, {92.34, 158.016}, {92.34, 156.055}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{86.074, 149.52800000000002`}, {84.262, 
                    149.52800000000002`}, {84.262, 151.32100000000003`}, {
                    81.762, 151.32100000000003`}, {81.762, 152.692}, {86.238, 
                    152.692}, {86.238, 151.22}, {89.10499999999999, 
                    149.591}, {89.10499999999999, 147.567}, {86.074, 
                    147.567}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    86.44100000000002, 152.692}, {86.44100000000002, 
                    151.329}, {89.10499999999999, 149.813}, {
                    89.10499999999999, 152.692}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[
                    1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{89.10499999999999, 155.76999999999998`}, {
                    86.44100000000002, 154.259}, {86.44100000000002, 
                    152.895}, {89.10499999999999, 152.895}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    91.973, 152.895}, {91.973, 154.259}, {89.309, 
                    155.76999999999998`}, {89.309, 152.895}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[
                    1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{89.309, 149.813}, {91.973, 151.329}, {91.973, 
                    152.692}, {89.309, 152.692}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxlk1soRFEUhseMJCkltyRFiKR48CBhF5qkCXPmOIw5o8SDEh7klmia5EGS
JEoUkhSe5FYkJHmQpDRJroUkSUhM2WfrX2XOqf3wtfblX//6T1xNk7XOZDAY
/PjK5cvI12bLcJR/bimbfJnbLy5RGdhem31Z8lzFVt+8p+0ei47zMp0bRQt2
djhVuPKWVqxj7/zriSVaof2+fN0ZtmT2yPSeLws9bTY2MNoY6g6UiQ3adyWz
h29+4bv0V2+XmSZvYFViiQGukfxdiTj9IiHANSExTV7wjcS6NKEpMnFBf8P9
97qN7b4nOwattr/zbitxX4Tn6NMtsbOZ5pwgs8Sylg9at0Zl4vqh5648Sznr
eEzKCFyW2BiXs21UqF4UbEzti6gkXojhTkba6X6h/0ohtt3Oju81K6Rvmtvp
/akgFufPKqg/oT9OIT6JP//q3ignf0R9SCH/wpfM150Oh47h/weXsbOo6hjz
eypbi+01VesY88d+X0Z+8J4vI3//9HJGP8KXY5X6FX6GOMkPMPzSxth/p5Kf
YPgtDG1RaR5gzKtO87PHSfMEY95iXqFOygPqyAsYecL9yBsYeYQ+5BWMPKM/
5B2M/wH+/PtfuH+/A1q+Rg==
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGI7IGYC4pDHS2cfWRDrMO/98mPe86Mc5FpfB+74Foed
rx7ugKIeid984NRC12ehDsUZE9/W+Mdg8B1M43Z5toQ4ePEwabf3hcP5D6tE
1rkvDHN48Xvlx0tfgyHycuEOh75qxPSvCnbIBGq3vxsB59faAzVKRjpcX1xg
y/U+2MFqy4myff3hcP43oLJDT8MdFDcUZUx0DXGQ1r+rwvYzEpUvGOlQ+VLN
kCMk2METZB9bOJwPts83zEHs5rnvwYeDHdpBjMmhcPltn/9eqegMRuUvDIKb
f/tnXdaeLSFw/vQ8oeYDXKFw94HDqyEYzgfbtzcY7j+wuTWhcD44fH6GwsOn
AiTPEwoPv9hdQB94B2DwYeH/C+icks++GHxY/KVY3/fvdffGzgfGP4p6JP4O
UMJ4EA23D53/B+hcX6dYuHthfJh/wOFwIRbuXzAtEwcPDxgfFl5gd12PhYcn
jA8Lb3C8NsbC4wOFD4yvw6DwLIqDxyeMjxLfzHHw9ACTh6UXFD4wPcHMh6U3
GB+WHmHug6VXGB+WnmH+g6V3GB+WH2DhA8svsPCD5Sd0Piz8YfkRxgcAsCzF
DA==
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4syJb2vsfcMcdsi1vg7UCHFw6c55/ntnuMPr
QKAIc6jDcW/zTscL0Rj8qBTr+/6pYQ7bPv+9UqEYi8H35GHSbl8W7lCcAbSg
PA6DD7ZPIQquHp3/sEpknXtiNNw+dH5A7/Q8ocMxcPfC+DD/NB84tdB1XqwD
SLj5QQhcnuv64gLbUwEYfJj5pnG7PHk++WHwYe7bUzJZgsXNB4MP8x9MPTof
Fj4w+9D5sPCFuRfGBwBbbLNz
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYCYlW2xqnOh6Md/qz8eMm3KMwBxt8h1/o6UCDU
wZOHSbt9WzicnznxbY29b5jDvPfLj3mbhzi0i9089/1xCFz+6QWl2z+vBWDw
Yea/CQTKcPtj8EHGBG8Od2AAgQQf7HzhKFT1SHwH07hdniHRcPvQ+c0HTi10
3RYDdy+Mj+Kf/li4f2HysPBA58PMv/2zLmuPSCwGH+a+i0ogkTjsfKD/UNQj
8WHhAwAvx8Mv
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4syJb2vsfcMcdNrFbp7rD3HY9vnvlYqF4Q4O
pnG7PGNCHYozgArKozH469wfVonsC3MIebx09pETMRj8ee+XH/P+H+4g3/o6
cIdcHHb+8UhU9Uj8+qw9JZM5ouH2ofP/rPx4yTcrBu5eGB/mH4EIyy0nzGId
pPXvqrD9DIHLx+/y5GFSDsTgw8z/VQdkLPbH4MPcl2J937/3uw92PtB/KOqR
+LDwgdmHzoeFL8y9MD4Agr3JpQ==
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[
                    1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {
                    0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
                    1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4otKt3/WZUU7+PdOzxM6HeYA40vr31Vhywx1
2FsyWYJlXjicnznxbY29b5iDYITllhPzQhxE17k/rPoTApdnAAGDQAw+zHyg
aWF8e/0x+BUv1Qw5eCIcVhzzNu8U9MXgH/6qEdO/KxKuHp3/JnCHXOvvKLh9
6HzFDUUZE2Nj4O6F8WH+0WoXu3lOPRbuX5g8LDzQ+TDzK0Hu3BODwYe5r9be
NG6XYBwGH+Y/mHp0Pix8AIvmoTA=
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    70.738, 93.11}, {70.738, 87.759}, {79.09400000000001, 
                    87.759}, {70.738, 93.30199999999999}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    70.94100000000002, 92.923}, {78.422, 87.962}, {
                    70.94100000000002, 87.962}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4jUyUSnWy8MdpPXvqrAlhjvA+J8u+SYJCEQ4
vA7cIdeajeBnTnxbY+8b5hDQOz1P6HCEQ429adwuzzCHkMdLZx85EOHw7ILS
7Z96oXD1qmyNU50/h2DwYfZt+/z3SoUnJh/oivv+S8Pg6tH5zQdOLXT9Fgq3
D8aHuU/s5rnvwc6hcPfD5GH+Q+fDzAe7IzACgw9zHwAveoMP
                    
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1,
                     0}}}, {{{89.20700000000001, 98.809}, {93.29700000000001, 
                    96.251}, {85.117, 96.251}}, {{93.29700000000001, 
                    87.848}, {89.20700000000001, 85.29}, {85.117, 
                    87.848}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    94.41000000000001, 90.583}, {94.41000000000001, 
                    88.05199999999999}, {89.309, 88.05199999999999}, {89.309, 
                    90.583}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    89.10499999999999, 90.583}, {89.10499999999999, 
                    88.05199999999999}, {84.004, 88.05199999999999}, {84.004, 
                    90.583}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    97.062, 93.31700000000001}, {97.062, 90.786}, {
                    91.96100000000001, 90.786}, {91.96100000000001, 
                    93.31700000000001}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    91.758, 93.31700000000001}, {91.758, 90.786}, {
                    86.65599999999999, 90.786}, {86.65599999999999, 
                    93.31700000000001}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    86.453, 93.31700000000001}, {86.453, 90.786}, {
                    81.35199999999999, 90.786}, {81.35199999999999, 
                    93.31700000000001}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    94.41000000000001, 96.048}, {94.41000000000001, 93.516}, {
                    89.309, 93.516}, {89.309, 96.048}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    89.10499999999999, 96.048}, {89.10499999999999, 93.516}, {
                    84.004, 93.516}, {84.004, 96.048}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4odVIuvcI0McwLRjpAOMv0Ou9XXgh0gHg7sq
bI2yCP4amagU6/9BDgG90/OEFkc5VL5UM+T4E+QgrQ9UuDAKQj8MhKsHcRuX
YvJh9skDhXfIYfKBttz3b42Aq0fne/IwabdfC4fbB+PD3AcypVU5HO5+mDzM
f+h8mPl7SyZLsKiFYvBh7gMAHJ14OA==
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1,
                     0}}}, {{{75.988, 106.309}, {80.082, 103.755}, {71.898, 
                    103.755}}, {{80.07799999999999, 95.35199999999999}, {
                    75.988, 92.79400000000001}, {71.898, 
                    95.35199999999999}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    81.191, 98.083}, {81.191, 95.55199999999999}, {76.09, 
                    95.55199999999999}, {76.09, 98.083}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    75.887, 98.083}, {75.887, 95.55199999999999}, {70.785, 
                    95.55199999999999}, {70.785, 98.083}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    84.395, 100.81700000000001`}, {84.395, 98.286}, {79.293, 
                    98.286}, {79.293, 100.81700000000001`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    79.09, 100.81700000000001`}, {79.09, 98.286}, {73.988, 
                    98.286}, {73.988, 100.81700000000001`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    73.785, 100.81700000000001`}, {73.785, 98.286}, {68.684, 
                    98.286}, {68.684, 100.81700000000001`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    81.191, 103.55199999999999`}, {81.191, 101.02}, {76.09, 
                    101.02}, {76.09, 103.55199999999999`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    75.887, 103.55199999999999`}, {75.887, 101.02}, {70.785, 
                    101.02}, {70.785, 103.55199999999999`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4odVIuvcHSMcIHSkA4y/Q671deCHSIdFrts+
/61B8FXZGqc6z450COidnie0OMrBi4dJu31epIO0/l0VtoVRDkDVVyp2RsHV
LwTp/4LJh9m3ee775ceqozH4USnW9/1bI+Dq0fmeIHuvhcPtg/Fh7nsdCLRR
ORzufpg8zH/ofJj5QN7DqpJwDD7MfQD7y4xs
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1,
                     0}}}, {{{102.426, 106.309}, {98.332, 103.755}, {106.516, 
                    103.755}}, {{98.336, 95.35199999999999}, {102.426, 
                    92.79400000000001}, {106.516, 
                    95.35199999999999}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    97.223, 98.083}, {97.223, 95.55199999999999}, {102.324, 
                    95.55199999999999}, {102.324, 98.083}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    102.527, 98.083}, {102.527, 95.55199999999999}, {
                    107.62899999999999`, 95.55199999999999}, {
                    107.62899999999999`, 98.083}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    94.02, 100.81700000000001`}, {94.02, 98.286}, {99.121, 
                    98.286}, {99.121, 100.81700000000001`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    99.324, 100.81700000000001`}, {99.324, 98.286}, {104.426, 
                    98.286}, {104.426, 100.81700000000001`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    104.62899999999999`, 100.81700000000001`}, {
                    104.62899999999999`, 98.286}, {109.73, 98.286}, {109.73, 
                    100.81700000000001`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    97.223, 103.55199999999999`}, {97.223, 101.02}, {102.324, 
                    101.02}, {102.324, 103.55199999999999`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    102.527, 103.55199999999999`}, {102.527, 101.02}, {
                    107.62899999999999`, 101.02}, {107.62899999999999`, 
                    103.55199999999999`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4jUyUSnWy8MdFDcUZUxMjXKA8T15mLTbt0U6
vA7cIdeajeBnTnxbY+8bBhFnjnSosTeN2+UZ5vDi98qPl1gjHZ5dULr9Uy8U
rl6VrXGq8+cQDD7Mvm2f/16p8MTkP6wSWeeuGA1Xj84H2v468EI03D4YH+Y+
sZvnvgc3x8DdD5OH+Q+dDzNfWv+uCltgBAYf5j4Ayk2BGA==
                    
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1,
                     0}}}, {{{89.20700000000001, 100.29400000000001`}, {
                    93.29700000000001, 102.85199999999999`}, {85.117, 
                    102.85199999999999`}}, {{93.29700000000001, 111.255}, {
                    89.20700000000001, 113.813}, {85.117, 
                    111.255}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    94.41000000000001, 108.52}, {94.41000000000001, 
                    111.05199999999999`}, {89.309, 111.05199999999999`}, {
                    89.309, 108.52}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    89.10499999999999, 108.52}, {89.10499999999999, 
                    111.05199999999999`}, {84.004, 111.05199999999999`}, {
                    84.004, 108.52}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    97.062, 105.79}, {97.062, 108.321}, {91.96100000000001, 
                    108.321}, {91.96100000000001, 105.79}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    91.758, 105.79}, {91.758, 108.321}, {86.65599999999999, 
                    108.321}, {86.65599999999999, 105.79}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    86.453, 105.79}, {86.453, 108.321}, {81.35199999999999, 
                    108.321}, {81.35199999999999, 105.79}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    94.41000000000001, 103.05499999999999`}, {
                    94.41000000000001, 105.587}, {89.309, 105.587}, {89.309, 
                    103.05499999999999`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    89.10499999999999, 103.05499999999999`}, {
                    89.10499999999999, 105.587}, {84.004, 105.587}, {84.004, 
                    103.05499999999999`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    70.738, 105.99300000000001`}, {70.738, 111.345}, {
                    79.09400000000001, 111.345}, {70.738, 
                    105.80499999999999`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}}}, {{{
                    70.94100000000002, 106.17999999999999`}, {71.23, 
                    106.37599999999999`}, {77.91000000000001, 
                    110.80499999999999`}, {78.422, 111.141}, {
                    70.94100000000002, 111.141}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    107.67599999999999`, 93.11}, {107.67599999999999`, 
                    87.759}, {99.32, 87.759}, {107.67599999999999`, 
                    93.30199999999999}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}}}, {{{107.473, 
                    92.923}, {107.184, 92.73100000000001}, {100.504, 
                    88.298}, {99.992, 87.962}, {107.473, 87.962}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    107.67599999999999`, 105.99300000000001`}, {
                    107.67599999999999`, 111.345}, {99.32, 111.345}, {
                    107.67599999999999`, 105.80499999999999`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}}}, {{{107.473, 
                    106.17999999999999`}, {107.184, 106.37599999999999`}, {
                    100.504, 110.80499999999999`}, {99.992, 111.141}, {
                    107.473, 111.141}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    72.37899999999999, 100.255}, {72.37899999999999, 
                    98.848}, {70.09, 98.848}, {70.09, 100.255}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    70.30499999999999, 100.04}, {72.16399999999999, 100.04}, {
                    72.16399999999999, 99.063}, {70.30499999999999, 
                    99.063}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    74.48400000000001, 102.989}, {74.48400000000001, 
                    101.583}, {72.191, 101.583}, {72.191, 
                    102.989}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    72.406, 102.774}, {74.265, 102.774}, {74.265, 101.797}, {
                    72.406, 101.797}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    79.785, 102.989}, {79.785, 101.583}, {77.49600000000001, 
                    101.583}, {77.49600000000001, 102.989}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    77.71100000000001, 102.774}, {79.57000000000001, 
                    102.774}, {79.57000000000001, 101.797}, {
                    77.71100000000001, 101.797}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    77.684, 100.255}, {77.684, 98.848}, {75.395, 98.848}, {
                    75.395, 100.255}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    75.609, 100.04}, {77.46799999999999, 100.04}, {
                    77.46799999999999, 99.063}, {75.609, 99.063}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    82.988, 100.255}, {82.988, 98.848}, {80.695, 98.848}, {
                    80.695, 100.255}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    80.91400000000002, 100.04}, {82.77300000000001, 100.04}, {
                    82.77300000000001, 99.063}, {80.91400000000002, 
                    99.063}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    79.785, 97.52}, {79.785, 96.114}, {77.49600000000001, 
                    96.114}, {77.49600000000001, 97.52}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    77.71100000000001, 97.30499999999999}, {79.57000000000001,
                     97.30499999999999}, {79.57000000000001, 96.332}, {
                    77.71100000000001, 96.332}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    74.48400000000001, 97.52}, {74.48400000000001, 96.114}, {
                    72.191, 96.114}, {72.191, 97.52}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    72.406, 97.30499999999999}, {74.265, 97.30499999999999}, {
                    74.265, 96.332}, {72.406, 96.332}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    87.699, 110.489}, {87.699, 109.083}, {85.41000000000001, 
                    109.083}, {85.41000000000001, 110.489}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    85.62499999999999, 110.274}, {87.48399999999998, 
                    110.274}, {87.48399999999998, 109.301}, {
                    85.62499999999999, 109.301}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    93.004, 110.489}, {93.004, 109.083}, {90.715, 109.083}, {
                    90.715, 110.489}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    90.93, 110.274}, {92.789, 110.274}, {92.789, 109.301}, {
                    90.93, 109.301}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    85.051, 107.759}, {85.051, 106.35199999999999`}, {82.758, 
                    106.35199999999999`}, {82.758, 107.759}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    82.973, 107.54}, {84.832, 107.54}, {84.832, 
                    106.56700000000001`}, {82.973, 
                    106.56700000000001`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    90.35199999999999, 107.759}, {90.35199999999999, 
                    106.35199999999999`}, {88.062, 106.35199999999999`}, {
                    88.062, 107.759}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    88.277, 107.54}, {90.136, 107.54}, {90.136, 
                    106.56700000000001`}, {88.277, 
                    106.56700000000001`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    95.65599999999999, 107.759}, {95.65599999999999, 
                    106.35199999999999`}, {93.363, 106.35199999999999`}, {
                    93.363, 107.759}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    93.582, 107.54}, {95.44099999999999, 107.54}, {
                    95.44099999999999, 106.56700000000001`}, {93.582, 
                    106.56700000000001`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    87.699, 105.024}, {87.699, 103.618}, {85.41000000000001, 
                    103.618}, {85.41000000000001, 105.024}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    85.62499999999999, 104.809}, {87.48399999999998, 
                    104.809}, {87.48399999999998, 103.832}, {
                    85.62499999999999, 103.832}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    93.004, 105.024}, {93.004, 103.618}, {90.715, 103.618}, {
                    90.715, 105.024}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    90.93, 104.809}, {92.789, 104.809}, {92.789, 103.832}, {
                    90.93, 103.832}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    100.918, 102.989}, {100.918, 101.583}, {98.62899999999999,
                     101.583}, {98.62899999999999, 102.989}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    98.84400000000001, 102.774}, {100.703, 102.774}, {100.703,
                     101.797}, {98.84400000000001, 101.797}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    106.223, 102.989}, {106.223, 101.583}, {103.93, 
                    101.583}, {103.93, 102.989}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    104.148, 102.774}, {106.00699999999999`, 102.774}, {
                    106.00699999999999`, 101.797}, {104.148, 
                    101.797}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    97.71900000000001, 100.255}, {97.71900000000001, 
                    98.848}, {95.426, 98.848}, {95.426, 100.255}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    95.641, 100.04}, {97.5, 100.04}, {97.5, 99.063}, {95.641, 
                    99.063}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    103.02, 100.255}, {103.02, 98.848}, {100.73, 98.848}, {
                    100.73, 100.255}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    100.94500000000001`, 100.04}, {102.804, 100.04}, {102.804,
                     99.063}, {100.94500000000001`, 99.063}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    108.324, 100.255}, {108.324, 98.848}, {106.035, 98.848}, {
                    106.035, 100.255}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    106.25, 100.04}, {108.109, 100.04}, {108.109, 99.063}, {
                    106.25, 99.063}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    100.918, 97.52}, {100.918, 96.114}, {98.62899999999999, 
                    96.114}, {98.62899999999999, 97.52}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    98.84400000000001, 97.30499999999999}, {100.703, 
                    97.30499999999999}, {100.703, 96.332}, {98.84400000000001,
                     96.332}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    106.223, 97.52}, {106.223, 96.114}, {103.93, 96.114}, {
                    103.93, 97.52}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    104.148, 97.30499999999999}, {106.00699999999999`, 
                    97.30499999999999}, {106.00699999999999`, 96.332}, {
                    104.148, 96.332}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    87.699, 95.485}, {87.699, 94.079}, {85.41000000000001, 
                    94.079}, {85.41000000000001, 95.485}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    85.62499999999999, 95.27}, {87.48399999999998, 95.27}, {
                    87.48399999999998, 94.297}, {85.62499999999999, 
                    94.297}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    93.004, 95.485}, {93.004, 94.079}, {90.715, 94.079}, {
                    90.715, 95.485}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    90.93, 95.27}, {92.789, 95.27}, {92.789, 94.297}, {90.93, 
                    94.297}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    85.051, 92.755}, {85.051, 91.348}, {82.758, 91.348}, {
                    82.758, 92.755}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    82.973, 92.536}, {84.832, 92.536}, {84.832, 91.563}, {
                    82.973, 91.563}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    90.35199999999999, 92.755}, {90.35199999999999, 91.348}, {
                    88.062, 91.348}, {88.062, 92.755}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    88.277, 92.536}, {90.136, 92.536}, {90.136, 91.563}, {
                    88.277, 91.563}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    95.65599999999999, 92.755}, {95.65599999999999, 91.348}, {
                    93.363, 91.348}, {93.363, 92.755}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    93.582, 92.536}, {95.44099999999999, 92.536}, {
                    95.44099999999999, 91.563}, {93.582, 91.563}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    87.699, 90.02}, {87.699, 88.614}, {85.41000000000001, 
                    88.614}, {85.41000000000001, 90.02}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    85.62499999999999, 89.80499999999999}, {87.48399999999998,
                     89.80499999999999}, {87.48399999999998, 
                    88.82799999999999}, {85.62499999999999, 
                    88.82799999999999}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    93.004, 90.02}, {93.004, 88.614}, {90.715, 88.614}, {
                    90.715, 90.02}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    90.93, 89.80499999999999}, {92.789, 89.80499999999999}, {
                    92.789, 88.82799999999999}, {90.93, 
                    88.82799999999999}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    118.15199999999999`, 40.345}, {98.301, 29.661}, {80.113, 
                    29.661}, {60.26200000000001, 40.345}, {60.26200000000001, 
                    57.946}, {80.113, 68.62599999999999}, {98.301, 
                    68.62599999999999}, {118.15199999999999`, 
                    57.946}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.15686300000000003`, 0.6823529999999999, 0.4], Opacity[
                    1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {
                    0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{98.25, 
                    29.864}, {117.94900000000001`, 40.466}, {
                    117.94900000000001`, 57.825}, {98.25, 68.423}, {80.164, 
                    68.423}, {60.465, 57.825}, {60.465, 40.466}, {80.164, 
                    29.864}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    116.54700000000001`, 41.312999999999995`}, {97.898, 
                    31.278}, {80.516, 31.278}, {61.867, 
                    41.312999999999995`}, {61.867, 56.977}, {80.516, 
                    67.012}, {97.898, 67.012}, {116.54700000000001`, 
                    56.977}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{116.34400000000001`, 41.434}, {
                    116.34400000000001`, 49.044}, {89.309, 49.044}, {89.309, 
                    31.480999999999998`}, {97.848, 31.480999999999998`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{62.07, 49.247}, {89.10499999999999, 49.247}, {
                    89.10499999999999, 66.809}, {80.566, 66.809}, {62.07, 
                    56.855999999999995`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{80.566, 31.480999999999998`}, {89.10499999999999,
                     31.480999999999998`}, {89.10499999999999, 49.044}, {
                    62.07, 49.044}, {62.07, 41.434}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{116.34400000000001`, 56.855999999999995`}, {
                    97.848, 66.809}, {89.309, 66.809}, {89.309, 49.247}, {
                    116.34400000000001`, 49.247}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGI5IGYC4qcXlG7/LItwWCClf1eFzdUhfpcnD5NyuIPu
prnvl4c5w/n3VNgapzY7Orh05zz/zRjhAOQ5d9s4OBRnTHxbsz0Mg7/O/WGV
yDknh0wg1943zOH64gJbLncniHmPQ+HyMD5Mf+/0PKHmGSGo5pWHwu2H8WHu
UwUpVA6Bu/+bRkz/IdNgDP7Jsn3zpeR94OphfJh51vf9e6ef84Xz/12peKm2
0B/unsqXaoYcJQFw96Lzwf4L94P7V3FDUcbEu37w8IDJw/gw/bDwRDEPGN4w
+2F8mPtg8QVz/+2fdVl7UiIx+DD/AwAX3Mlr
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{97.801, 56.04}, {92.34400000000001, 59.501}, {
                    92.34400000000001, 63.36}, {95.41400000000002, 65.61}, {
                    91.07, 65.61}, {91.07, 60.309}, {89.309, 61.427}, {89.309,
                     49.247}, {101.371, 49.247}, {101.371, 56.04}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{80.609, 42.251}, {86.07, 38.786}, {86.07, 
                    34.927}, {83., 32.67700000000001}, {87.34400000000001, 
                    32.67700000000001}, {87.34400000000001, 37.977}, {
                    89.10499999999999, 36.86}, {89.10499999999999, 49.044}, {
                    77.039, 49.044}, {77.039, 42.251}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{91.07, 32.67700000000001}, {95.41400000000002, 
                    32.67700000000001}, {92.34400000000001, 34.927}, {
                    92.34400000000001, 38.786}, {97.801, 42.251}, {101.371, 
                    42.251}, {101.371, 49.044}, {89.309, 49.044}, {89.309, 
                    36.86}, {91.07, 37.977}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{86.07, 59.501}, {80.609, 56.04}, {77.039, 
                    56.04}, {77.039, 49.247}, {89.10499999999999, 49.247}, {
                    89.10499999999999, 61.43}, {87.34400000000001, 60.309}, {
                    87.34400000000001, 65.61}, {83., 65.61}, {86.07, 
                    63.36}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, {{{97.43400000000001, 54.755}, {100.098, 
                    54.755}, {100.098, 43.532000000000004`}, {
                    97.43400000000001, 43.532000000000004`}, {
                    89.20700000000001, 38.312999999999995`}, {80.98, 
                    43.532000000000004`}, {78.316, 43.532000000000004`}, {
                    78.316, 54.755}, {80.98, 54.755}, {89.20700000000001, 
                    59.973}, {89.262, 59.942}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, {{{97.37499999999999, 54.552}, {
                    89.20700000000001, 59.73500000000001}, {81.039, 54.552}, {
                    78.52, 54.552}, {78.52, 43.73500000000001}, {81.039, 
                    43.73500000000001}, {89.20700000000001, 38.552}, {
                    97.37499999999999, 43.73500000000001}, {99.895, 
                    43.73500000000001}, {99.895, 54.552}, {97.406, 
                    54.552}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIPIGYC4uKMiW9rroc5zJoJBJreDij8k14O7WI3z30X
DsfO5/Ry+A8C5WHY+S+9HbivLy6wvRWOwT//Pfjx0tleDs0HTi10bYvA4C8/
5m3eudHDYUaeUPOBS+HY+YWeDnKtrwN3qEVg8MHm3fZ0eHpB6fbPbeFw/sMq
kXXuK8McDn/ViOmf5AGXB7vP0x2uH50f0Ds9T2izO9x+rPxiD7j70flg8zrd
UMMDie+UAHSJtSs8/LDypd3h4Y+VH+0Gjz+s/N+uEPdWhWPwIf5xc8gEKrf3
DXMwi9vlyaPk4WC15UTZPvlQuDyMDw5PoP54oDKmw5h8mP1AnnZ7GyYfrB7o
/ovA4K9TCsPgw/x/HBitjgdCMPiw8PNLEoiwFMHkw8LfEuTe4zj4wPjbNPf9
8mPFmHxY/KuyNU51fozgg9PPx1B4+oHJw9IXTD86H5Y+YfZj5QPTN8z96HxY
/oD5H50Py1+w8MPKB+ZPWPhj5QPzNyz+sPKB5QMs/tH5pqD0UuQFTz/g8GHy
hKcvmDyMD9MPAIz0HZY=
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIPIGYCYrnW14E70kIcpkiwhPGddXeYkSfUfGAXJp+X
SbtdLNLD4WGVyDp3RUx+QO/0PKHFbg6ZE9/W2J/F5LcBrZELdXXQv6vC1iga
hsFfcczbvJPR3QEk3Do5FIMPcqZcqZuD1ZYTZfvOY/JXgtQ/dIW4VwiTDzbv
INQ9vmEOhbZc1xc7eDhYgvS3h8PlYXyY/otKt3/WnQrD4MPsf3oBKMAWjsGH
uX+h67bPf1vCMPgw/0PCJxyDDws/cPhWRmDwYeEP9v/9cAw+LP42zX2//Jhx
BAY/jE9301x9aPhuDofzjwOd6TghzOHwV42Y/kkecHmw/756wvWj8z9d8k0S
iPCE24/OP/89+PHS0x5w96PzweHT6AX3Pzo/HOS+897w8EPn3wMmo6nKXvDw
R+eD/bfeCx5/6HywemdvePxj5Sd7wdNP9p6SyRJPPODpCyaPwgfqh6VPdD7M
flj6RufD3A/LH+h8mP9h+QudDws/WP5E58PCH5a/0fmw+IOVD+h8WPyDw/cZ
gu/cnfP8Nyci/cDkYekLph/GBwDIKwPE
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{107.613, 48.255}, {107.613,
                     46.294000000000004`}, {109.992, 46.294000000000004`}, {
                    109.992, 48.255}, {112.35499999999999`, 48.255}, {
                    112.35499999999999`, 42.704}, {109.992, 42.704}, {109.992,
                     44.665000000000006`}, {107.613, 44.665000000000006`}, {
                    107.613, 42.704}, {105.25, 42.704}, {105.25, 48.255}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{99.16, 
                    40.88399999999999}, {99.16, 38.923}, {101.539, 38.923}, {
                    101.539, 40.88399999999999}, {103.902, 
                    40.88399999999999}, {103.902, 35.333}, {101.539, 
                    35.333}, {101.539, 37.294000000000004`}, {99.16, 
                    37.294000000000004`}, {99.16, 35.333}, {96.79700000000001,
                     35.333}, {96.79700000000001, 40.88399999999999}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{107.613, 50.036}, {107.613,
                     51.997}, {109.992, 51.997}, {109.992, 50.036}, {
                    112.35499999999999`, 50.036}, {112.35499999999999`, 
                    55.586999999999996`}, {109.992, 55.586999999999996`}, {
                    109.992, 53.626000000000005`}, {107.613, 
                    53.626000000000005`}, {107.613, 55.586999999999996`}, {
                    105.25, 55.586999999999996`}, {105.25, 50.036}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{70.801, 48.255}, {70.801, 
                    46.294000000000004`}, {68.422, 46.294000000000004`}, {
                    68.422, 48.255}, {66.059, 48.255}, {66.059, 42.704}, {
                    68.422, 42.704}, {68.422, 44.665000000000006`}, {70.801, 
                    44.665000000000006`}, {70.801, 42.704}, {73.164, 
                    42.704}, {73.164, 48.255}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{70.801, 50.036}, {70.801, 
                    51.997}, {68.422, 51.997}, {68.422, 50.036}, {66.059, 
                    50.036}, {66.059, 55.586999999999996`}, {68.422, 
                    55.586999999999996`}, {68.422, 53.626000000000005`}, {
                    70.801, 53.626000000000005`}, {70.801, 
                    55.586999999999996`}, {73.164, 55.586999999999996`}, {
                    73.164, 50.036}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{99.16, 57.403}, {99.16, 
                    59.364}, {101.539, 59.364}, {101.539, 57.403}, {103.902, 
                    57.403}, {103.902, 62.958}, {101.539, 62.958}, {101.539, 
                    60.997}, {99.16, 60.997}, {99.16, 62.958}, {
                    96.79700000000001, 62.958}, {96.79700000000001, 
                    57.403}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{79.254, 
                    40.88399999999999}, {79.254, 38.923}, {76.87499999999999, 
                    38.923}, {76.87499999999999, 40.88399999999999}, {74.512, 
                    40.88399999999999}, {74.512, 35.333}, {76.87499999999999, 
                    35.333}, {76.87499999999999, 37.294000000000004`}, {
                    79.254, 37.294000000000004`}, {79.254, 35.333}, {81.617, 
                    35.333}, {81.617, 40.88399999999999}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{79.254, 57.403}, {79.254, 
                    59.364}, {76.87499999999999, 59.364}, {76.87499999999999, 
                    57.403}, {74.512, 57.403}, {74.512, 62.958}, {
                    76.87499999999999, 62.958}, {76.87499999999999, 60.997}, {
                    79.254, 60.997}, {79.254, 62.958}, {81.617, 62.958}, {
                    81.617, 57.403}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{105.453, 48.052}, {105.453,
                     42.907}, {107.41000000000001`, 42.907}, {
                    107.41000000000001`, 44.864}, {110.195, 44.864}, {110.195,
                     42.907}, {112.15199999999999`, 42.907}, {
                    112.15199999999999`, 48.052}, {110.195, 48.052}, {110.195,
                     46.091}, {107.41000000000001`, 46.091}, {
                    107.41000000000001`, 48.052}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{97., 40.68}, {97., 
                    35.536}, {98.95700000000001, 35.536}, {98.95700000000001, 
                    37.497}, {101.742, 37.497}, {101.742, 35.536}, {103.699, 
                    35.536}, {103.699, 40.68}, {101.742, 40.68}, {101.742, 
                    38.720000000000006`}, {98.95700000000001, 
                    38.720000000000006`}, {98.95700000000001, 40.68}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{105.453, 
                    50.23500000000001}, {105.453, 55.38399999999999}, {
                    107.41000000000001`, 55.38399999999999}, {
                    107.41000000000001`, 53.423}, {110.195, 53.423}, {110.195,
                     55.38399999999999}, {112.15199999999999`, 
                    55.38399999999999}, {112.15199999999999`, 
                    50.23500000000001}, {110.195, 50.23500000000001}, {
                    110.195, 52.196000000000005`}, {107.41000000000001`, 
                    52.196000000000005`}, {107.41000000000001`, 
                    50.23500000000001}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{72.96100000000001, 
                    48.052}, {72.96100000000001, 42.907}, {71.004, 42.907}, {
                    71.004, 44.864}, {68.21900000000001, 44.864}, {
                    68.21900000000001, 42.907}, {66.262, 42.907}, {66.262, 
                    48.052}, {68.21900000000001, 48.052}, {68.21900000000001, 
                    46.091}, {71.004, 46.091}, {71.004, 48.052}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{72.96100000000001, 
                    50.23500000000001}, {72.96100000000001, 
                    55.38399999999999}, {71.004, 55.38399999999999}, {71.004, 
                    53.423}, {68.21900000000001, 53.423}, {68.21900000000001, 
                    55.38399999999999}, {66.262, 55.38399999999999}, {66.262, 
                    50.23500000000001}, {68.21900000000001, 
                    50.23500000000001}, {68.21900000000001, 
                    52.196000000000005`}, {71.004, 52.196000000000005`}, {
                    71.004, 50.23500000000001}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{97., 57.606}, {97., 
                    62.755}, {98.95700000000001, 62.755}, {98.95700000000001, 
                    60.794000000000004`}, {101.742, 60.794000000000004`}, {
                    101.742, 62.755}, {103.699, 62.755}, {103.699, 57.606}, {
                    101.742, 57.606}, {101.742, 59.567}, {98.95700000000001, 
                    59.567}, {98.95700000000001, 57.606}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{81.41400000000002, 
                    40.68}, {81.41400000000002, 35.536}, {79.45700000000001, 
                    35.536}, {79.45700000000001, 37.497}, {76.67199999999998, 
                    37.497}, {76.67199999999998, 35.536}, {74.715, 35.536}, {
                    74.715, 40.68}, {76.67199999999998, 40.68}, {
                    76.67199999999998, 38.720000000000006`}, {
                    79.45700000000001, 38.720000000000006`}, {
                    79.45700000000001, 40.68}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{81.41400000000002, 
                    57.606}, {81.41400000000002, 62.755}, {79.45700000000001, 
                    62.755}, {79.45700000000001, 60.794000000000004`}, {
                    76.67199999999998, 60.794000000000004`}, {
                    76.67199999999998, 62.755}, {74.715, 62.755}, {74.715, 
                    57.606}, {76.67199999999998, 57.606}, {76.67199999999998, 
                    59.567}, {79.45700000000001, 59.567}, {79.45700000000001, 
                    57.606}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{113.145, 
                    57.079}, {105.312, 61.294000000000004`}, {105.312, 
                    57.079}}}]}}}}, {{{
                   {Thickness[0.00006663529411764707], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{65.27, 
                    41.208000000000006`}, {73.10199999999999, 36.993}, {
                    73.10199999999999, 41.208000000000006`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{65.27, 
                    57.079}, {73.10199999999999, 61.294000000000004`}, {
                    73.10199999999999, 57.079}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{113.145, 
                    41.208000000000006`}, {105.312, 36.993}, {105.312, 
                    41.208000000000006`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{105.516, 
                    57.282000000000004`}, {105.516, 60.958}, {
                    112.34400000000001`, 57.282000000000004`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{72.898, 
                    41.009}, {72.898, 37.333}, {66.07, 41.009}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{72.898, 
                    57.282000000000004`}, {72.898, 60.958}, {66.07, 
                    57.282000000000004`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{105.516, 
                    41.009}, {105.516, 37.333}, {112.34400000000001`, 
                    41.009}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{57.18, 
                    33.649}, {57.555, 32.044}, {58.832, 30.829}, {59.137, 
                    29.161}, {59.75, 30.899}, {60.312, 32.356}, {59.891, 
                    34.259}, {59.59, 35.62200000000001}, {58.445, 36.591}, {
                    58.312, 37.989}, {57.066, 36.868}, {56.797000000000004`, 
                    35.278000000000006`}, {57.18, 33.649}}, CompressedData["
1:eJxTTMoPSmViYGCQBGIQHWG55URZno/Dh+XHvM1fWjnsLZkswfLNx6HpwKmF
rmWWDqZxuzx5Nvk68DBpt4tFWkD4TX4OTglPLyjNNnfQiuk/9DXCz+G4t3mn
4wMLiP5lfg6ZE9/W2F+1dHgTuEOu9befA5B8HXjDysEMpD/J3+Fk2b75Uvw2
Du1iN899n+wP0e9g69A7PU+o2cHfYYGU/l2VZXYO2z//vVIh6e9gD7L4ja3D
Itdtn/8+8XOQZAnj0w2ydUixvu/fuxzK32TjwN441bnbx89B3ZBjjcwua4c+
kHkCfg7lQOv071o5HP6qEdPP5OewRiYqxXq+JcT9M3wh/rG2cgA5jynb1yF7
D9AjKtYQ9Ua+DkDX75BjtXGYIgG06K6Pw5WKl2qGHrYQ+SAfhxZQeIXZOfyq
y9pTstnbAWSMNru9gx3X9cUFd70dYoHWaMyxdQCqAnrA26EC5B5ZGwf08AcA
SLunQg==
                    "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQvbdksgRLmr9D84FTC12nmTloxvQf+urh73Cl4qWa
4QlTh97peULNBv4OjglPLyj9NnEAqzfzdwgESSibOLA3TnXuvuPnkL0HKPHE
xMHgrgpbY6qfQ8bEtzX2paYObwJ3yLX+9nX4BzJQ0MwhbpcnD1O2r4O6Icca
mV9mDoe/agBt9HFYIxOVYj3fHGKej4/D++XHvM1PWjicXui67XOsj4MxCAib
Q8zb7eOwzv1hlcg6UwdbruuLC3J9Ie5ZbOKw7fPfKxWafg4gYdsuY4h5PP4Q
/Z+NHEDOZDnm76DKBpQ4bejg0p3z/PdKfwceJu12sUhjh1wg7+MnfwegLa8D
Z5g4hDxeOvuIRIDDAil9oM/MHGYAg+OAUQDEvynmEPskAxxA3tI+buEAMrZ7
j7+DJEsYn+4lS4cIyy0nyvb5Q9yzysKBERjmDBP8HaJTrO/7rzV3QA9/ADmb
pE4=
                    "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQ3Xzg1ELXtgCHzIlva+xDDR22ff57pWJmgMMuTx4m
bXUDB6stJ8r2nQ9w+LPy4yXfJD2H2z/rsvZ8CXCYL6V/V8VNx0EaSLFNDHCI
sAQqtNOF8C0DHGzu+/dOf6fnADR92+e9/hD9TgYOKdZAied+Dg6mcbs8dQwh
+v75OjysElnnftDQofKlmiGHja9DBsg9X40cpkiwhPHN9XXgur64wFbLwIG9
capzd4+fA8h57WK6DnEgh772dwAZOz1PG+KP3AAHe5D5PloQfZcCHGL6D33V
uKPlsGnu++XHkgMdFoDcz6bpEA/SHxzosBXozflSOg7fNIAqTQMd2ED25Og7
rJGJSrFmD3QAWydpCFH/OMBB3ZBjjYyUEcT+3QEO84DGeosbQ8JnSYCDJNDZ
ukYmDn5JAhGWLQEQd3gZO4CC429JgEM50Db9WCMH9PAHACGno/o=
                    
                    "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQfftnXdaeL4EOW0+U7ZsvpeXw9ILS7Z9iQQ7fgx8v
ne2i4SCyzv1hlUuQw0651teBO9QcREH8miCH3ul5Qs0Nqg7PQOrfBTrsAMlb
qDpkTnxbY18b6LBASv+uCpuGgypb41TnzwEOhhxrZKJUNByaD5xa6DovAKpe
A6LeFyqfou4wWYIljO+tP4S/RN3BAGhKYyxUfYWqw7bPf69UnAxwuO8PdMEk
ZYh73QIdVn285JskoOzAdX1xge2rQIc0MFCCujPIodAWKLNBGeIfk2AHa5AB
esoQ+QdBEH1cqg6ePEza7duCIO5vU3dw6c55/rsRqt9Ay+GbRkz/IVuYvC7E
/X8DHdJB1j3Th5hXAQsPA4j6tVD3TdBzAIf3mUCHCMstJ8rsdBzQwx8AQtmv
2g==
                    "], {{79.67599999999999, 9.384}, {75.781, 
                    8.722999999999999}, {72.051, 7.863999999999999}, {68.074, 
                    7.824999999999999}, {72.523, 6.274}, {76.71900000000001, 
                    5.993}, {81.133, 7.595}, {83.52, 8.462}, {85.348, 
                    8.927}, {87.15199999999999, 8.798}, {89.785, 8.606}, {
                    92.98400000000001, 7.566999999999999}, {96.527, 
                    3.8329999999999997`}, {97.918, 4.946}, {92.84400000000001,
                     9.47}, {86.199, 10.493}, {79.67599999999999, 9.384}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{121.254, 
                    33.649}, {120.87899999999999`, 32.044}, {
                    119.60199999999999`, 30.829}, {119.293, 29.161}, {118.684,
                     30.899}, {118.121, 32.356}, {118.543, 34.259}, {
                    118.84400000000001`, 35.62200000000001}, {119.988, 
                    36.591}, {120.121, 37.989}, {121.367, 36.868}, {121.637, 
                    35.278000000000006`}, {121.254, 33.649}}, CompressedData["

1:eJxTTMoPSmViYGCQBGIQLbLO/WFVSpzDh+XHvM1fWjmEPF46+4hCnEPTgVML
XcssHWbkCTUfOBTrwMOk3S4WaQHhR8U6OCU8vaA029xhjUxUinV+rMNxb/NO
xwcWEP0esQ6ZE9/W2F+1dNhbMlmCRS7WYYdc6+vAG1YO00H6X8U4nCzbN1+K
38ah1t40btfFGIh+B1uHN4FAlb9jHBZI6d9VWWbn8OyC0u2ffLEOIGWeb2wd
HlYBXawZ6yDJEsanG2Tr8B8E3KH8TTYOQF1sjaWxDuqGHGtkdlk7vAaZNznW
oRxonf5dK4dLQOPqZsVC3D3fEmL+Oah/rK0cmkH+fhbrkL0H6HAVa4eLIPVM
cQ6tIINYbSD+0o1zuFLxUs3QwxYiXxTn0ALSF2bn4NKd8/z3wTiHXZ7AEGO3
d1jkuu3z3zVxDrH9h75qzLF1uPOzLmvPnDiHCpB7ZG0c0MMfAB6Psig=
                    
                    "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQ3Ts9T6j5RYxD84FTC12nmTk8vaB0++e3GIcrFS/V
DE+YOrwO3CHXyhzr4JgAlPlt4hDyeOnsIwyxDoEgjcomDgZ3VdgadWMdsveU
TJZ4YuIgrQ8UyIx1yJj4tsa+1NRhL1CYZV6swz+QgYJmEHuexTqoG3Kskfll
5nAJaF2dVZzDGpmoFOv55g4g7Y2lcQ7vlx/zNj9p4QCUzdqTE+dgDALC5g7f
NGL6D9nGOaxzf1glss7UYaHrts9/n0Dds9jEQa4V6OK2WAeu64sLbLuMIeaJ
xkL0fzaCuH9HjIMqW+NU59OGEPXHYhx4mLTbxSKNHVy6c57/XhjjsAMkMcPE
IX6XJw9Tc4zDAimQSWZQ/8VA/JtiDlHfGOMAUqZ93AISHntjHCRZwvh0L1k6
iIIcuicG4p5VFg6b5gJ9djnGITrF+r7/WnMH9PAHAACeqxo=
                    
                    "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQrX9Xha1RNMYhc+LbGvtQQweX7pznvxljHHZ58jBp
qxs4VLxUM+Q4E+3wZ+XHS75Jeg5PLyjd/rks2mG+FFCnm47D9Dyh5gNcMQ4R
lltOlNnpOlwEStclxTjY3Pfvnf5Oz+HOz7qsPXtiIPqdDBz+g4B6rIODadwu
Tx1DB9F17g+r5sQ6PKwSWed+0NDhm0ZM/6G/sQ4ZIPd8NYK462ysA9f1xQW2
WgYOYPeGxjqAnNcupuvQfODUQtdlMQ7WIPvytCF8vRgHe5D5PloQc09GOwBN
/apxRwtiv3m0wwKQ+9k0HUIeL519xCPaYeuJsn3zpXQc9pZMlmBJi3Zga5zq
3J2j7yACct+UaAewdZKGEPU7oh3UDTnWyEgZQfgPoh3mvV9+zFvcGBI+36Id
JFnC+HSNTBzWyESlWIvHQNzvZewg1/o6cIdajEM50Db9WCMH9PAHAKgmrgU=

                    "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQ/fSC0u2fy6Ictp4o2zdfSstBZJ37w6qWKIfvwY+X
znbRcFgjE5ViHR7lsFOu9XXgDjUIXz7KoXd6nlBzgypE/Zoohx0geQtVBy8e
Ju12uWiHBVL6d1XYNByOeZt3Oq6IdjDkAOpU0XAwAIo2/o2GqteAqPeLgcin
qDtkTHxbY78Uyl+i7tB84NRCV7sYiPoKVQeu64sLbC9FO9z3B7pgkrLD7Z91
WXtCoh1WfbzkmySg7LDt898rFRujHNLAQMkhbpcnD5N0lEOhLVDnBmUHsH/T
Ih2sQQboKTuosjVOdd4dCTGXSxVi/9NIiPvb1B1q7U3jdklC9RtoOewtmSzB
EhcFldeFuH9elEM6yLpn+hDzlGH+M4CofxcFcd8EPYdnIPvPRTlEWG45UWan
44Ae/gAy+KYv
                    "], {{98.758, 9.384}, {102.65199999999999`, 
                    8.722999999999999}, {106.383, 7.863999999999999}, {
                    110.359, 7.824999999999999}, {105.91000000000001`, 
                    6.274}, {101.715, 5.993}, {97.301, 7.595}, {
                    94.91400000000002, 8.462}, {93.082, 8.927}, {91.281, 
                    8.798}, {88.648, 8.606}, {85.44900000000001, 
                    7.566999999999999}, {81.906, 3.8329999999999997`}, {
                    80.512, 4.946}, {85.59, 9.47}, {92.23400000000001, 
                    10.493}, {98.758, 9.384}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGItIGYC4r0lkyVY0nwcri8usOU6nO3AAAIKvg7nvgc/
Xjo92wEoG8ZX6+nw5e+Vipf7suB8jjUyUSni2Q6/6rL2lCz2hqvf9hmk0Atu
nmncLk+eIh+H5gOnFrrK5UDEj3s7gO11Q/Cl9e+qsPHmOCx0BZpQ4oXBf1gl
ss49MMfBlguoI9cXYh5TrsPrwB1yra/94PwU6/v+veL+Dpvmvl9+7HAOxD2W
fnC+S3fO89+a/g7nQe7thsofDHAw73RMeCqSC5dfIAV0wLxcuH5IOCHMh/Fh
9oNp9Vy4+2B8mPt7p+cJNd9A8EMeL519RCYP7n90Pti9j3Ph4fcGZB53Hjx8
BSIst5xIy4OHP9i9k/Lg8ZMGAkL5cD7Y3Ox8ePzC1MPiH2beKZAD3/rC7bMD
+Weuj8M/oK1qe3MdKl+qGXLU+ELiozPXYfYRhQ1FGv6Q+Hqb6wDy5oGsQHh4
wuTB/rPJgesHh8eCHLj5haCAy8mB2w9LLwCJMSw+
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGItIGYC4uuLC2y5vvs6nP8e/HhpfK6DS3fO89+a/g6O
CU8vKC3PdciY+LbG/mqAg3knUEQEIa+7ae775U05DjD9C6T076qcgvH94Px2
sZvnvl/2c5jmDNKY46AZ03/oa4UvnN83PU+oeYKXgx7IPD8E/3XgDrlW4RwI
vdobg7/8mLd5Z2iOgxbIvBk+Ds0HTi10lYPqF/CGuONwtsNFpds/6055O5wD
+W96tsNkCZYwvlpPiHo+BH8qyD3HsyDu++EDV//sAtAAOx+4eWD6uC/cPi8e
Ju32Mh+HQluu64tzchwqX6oZctT4OqwAuW9ljsPsIwobijT8Hb5pAA12zXF4
CjIvLBAenjB5sL4nuXD99qZxuzwbcuHm/7tS8VJtby7c/jegcODOg7tPIMJy
y4m0PLj7weE/KQ/uv5sgDyXmw/lg/dL58PCBqYeFH8w8WPjC7IOFP9h9V3Lh
fHB4iOXB4w+d7wRKT7dz4fEPdo9uLjx9wPiw9ANLjwD6gjUe
                    
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    64.93, 232.74299999999997`}, {63.379, 231.298}, {
                    63.12500000000001, 232.74299999999997`}, {63.379, 
                    234.18800000000002`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    63.523, 233.76999999999998`}, {63.343999999999994`, 
                    232.74299999999997`}, {63.523, 231.71599999999998`}, {
                    64.62499999999999, 232.74299999999997`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    54.473, 231.192}, {55.93, 232.64899999999997`}, {54.473, 
                    234.11399999999998`}, {52.684, 234.11399999999998`}, {
                    52.684, 236.165}, {50.977, 237.872}, {50.977, 227.43}, {
                    52.684, 229.141}, {52.684, 231.192}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    54.391, 233.911}, {55.645, 232.64899999999997`}, {54.391, 
                    231.39100000000002`}, {52.483999999999995`, 
                    231.39100000000002`}, {52.483999999999995`, 229.227}, {
                    50.977, 227.72}, {50.977, 237.58700000000002`}, {
                    52.483999999999995`, 236.07899999999998`}, {
                    52.483999999999995`, 233.911}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGItIGYC4r0lkyVY0nwc1NgapzpLpzowgICCr0PlSzVD
jg8pDkDZML5aTwfHhKcXlMQR/PPfgx8vzU9x+FWXtadksTdc/bbPf69UvPSC
m2cat8uTp8jHwZOHSbu9LNXh+uICW67j3g7paUAwD8E/orChKCM11WGhK9CE
Ei8M/opj3uadK1MdbLmAOnJ9HXQ3zX2/PCrN4XXgDrnW135wfor1ff9ecX+I
e2TSIO6x9IPzXbpznv/WhMo/SYXIHwxw+Ad0tVouQh7kvLRvCP1g9+5DmA/j
w+wHWX+sPg3uPhgf5n6LTmAIGqTD+dL6d1XYStPh/kfng91nkw4PP7B5yenw
8AXHx/50ePiD3fMqHR4/ghGWW05kZcD5qqD4OJwBj1+Yelj8w8w7BXLgW1+4
fXYg/8z1gcSHaDrEXTW+Dj3AYFr5MM1hNkhCwx8i75ruMD1PqPlAViA8PGHy
YP9NTYXrB6ae2Ud+pMLNNweFz5FUuP2w9AIALMwnGw==
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGItIGYC4uuLC2y5vvs6VL5UM+TYkebg0p3z/LemvwPn
GpmolP9pDhkT39bYXw1w+Hel4qVaLkIerO92qgNMfxoIKKVB+X5wfrvYzXPf
L/s52JvG7fIMSXPQjOk/9LXCF87vm54n1DzBy+HzX6AFy1Lh/M1z3y8/lp3q
8Dpwh1zram8MPtDU4MdrUx20QObN8HHw5GHSbi+D6hfwdlBja5zqLJ3qcFHp
9s+6U94Q/31IcZgswRLGV+vpoLsJaGAagg8yRkMhBeK+Hz5w9c8uAA2w84Gb
B/bfcV+4fV5g2sfBvNMx4emRVIi+Gl+I+xjTHGYfUdhQpOHvsLcEaNO8VIen
IPPCAuHhCZNf/fGSb5JNOlx/L8gfN9Lg5oOUZYimw+0HOf9YcjrcfUDbLyjt
T4e7Px0U/q/S4f5rOXBqoeuuDDgfrL84Ax4+MPWw8IOZBwtfmH2w8Aer00Hw
9UAK8tLh8YfOB6szTofH/wIp/bsqbYj0AePD0g8sPQIAa2kuwg==
                    
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    64.93, 179.501}, {63.379, 178.059}, {63.12500000000001, 
                    179.501}, {63.379, 180.946}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    63.523, 180.52800000000002`}, {63.343999999999994`, 
                    179.501}, {63.523, 178.477}, {64.62499999999999, 
                    179.501}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    54.473, 177.95000000000002`}, {55.93, 179.411}, {54.473, 
                    180.876}, {52.684, 180.876}, {52.684, 182.923}, {50.977, 
                    184.634}, {50.977, 174.192}, {52.684, 175.903}, {52.684, 
                    177.95000000000002`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    54.391, 180.67299999999997`}, {55.645, 179.411}, {54.391, 
                    178.153}, {52.483999999999995`, 178.153}, {
                    52.483999999999995`, 175.985}, {50.977, 174.477}, {50.977,
                     184.348}, {52.483999999999995`, 182.841}, {
                    52.483999999999995`, 180.67299999999997`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGItIGYC4r0lkyVY0nwc5r1ffsz7eYwDAwgo+DrUZ+0p
mTwhxgEoG8ZX6+lwfXGBLdf9KDj/0yXfJIEJ0Q6/6oAKF3vD1W/7/PdKxUsv
uHmmcbs8eYp8HF78Xvnx0txYiDnHvR2iUqzv+79F8MVvnvseXB3rsNAVaEKJ
FwZ/01yggcxxDrZcQB25vg7r3B9WiaTFO7wO3CHX+toPzgcZ2yvu7xDyeOns
Iy/iIO6x9IPzXbpznv/WhMpXQOUPBjj4907PE+qOh8sLRlhuOeGXANcvAOKL
JcDNh/Fh9oPIwA3xcPfB+DD3/wOGilpnApx/RGFDUcbZBLj/0fmrPgIDeEoC
PPxi+w991diTAA9fsL3iifDwB7vXKRE1vg4j+Oe/Bz9eKp0Ej1+Yelj8w8w7
BXLgW1+4fXYg/8z1cfimEdN/KDfBofKlmiFHja8DKHoeWyY4zAY5XMPfoQcY
bCvnJjgAQ7H5QFYgPDxh8l2OCU8v3IqF6/8DTA6+i+Lg5h/+CrTAKg5uPyy9
AAAMfju0
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGItIGYC4uuLC2y5vvs6OJjG7fIUSHBw6c55/lvT32Hj
3PfLj4UnOGRMfFtjfzXAwb93ep5Qdzxc3pOHSbs9Lc4Bpl9xQ1HGxK8wvh+c
3y5289z3y34O0vp3Vdgi4x00Y/oPfa3whfP7gMY2T/By8AKZ9y8Wzt8h1/o6
sCPW4XUgkLXaG4NvD3IvT5yDFsi8GT4OL36v/HhpLlS/gLfDPKDzvZ/HOFxU
uv2z7pS3Q33WnpLJE2IcJkuwhPHVekLU10bD+WD3fIyCuO+HD1z9swtAA+x8
4OaB/XfcF24f2N1lPg6Hv2rE9FvFOVS+VDPkqIGG55Y4h9lHFDYUafg7nD0D
BG9iHZ6CzAsLhIcnTB5o6vXFUxLg+i06HROeGiTAzf8GNP5QbgLc/ligMzX2
JMDdBw4X8US4+wUjLLeccEqE+w8cX0JJcD5Y/5lEePjA1MPCD2YeLHxh9sHC
3xzkvhYE//PfKxUvjyXA4w+dvxmUnroT4PE/BeSOvfHw9AHjw9IPLD0CAG7u
Lxc=
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    64.93, 126.262}, {63.379, 124.81700000000001`}, {
                    63.12500000000001, 126.262}, {63.379, 
                    127.708}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    63.523, 127.29}, {63.343999999999994`, 126.262}, {63.523, 
                    125.235}, {64.62499999999999, 126.262}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    54.473, 124.712}, {55.93, 126.17299999999999`}, {54.473, 
                    127.634}, {52.684, 127.634}, {52.684, 129.684}, {50.977, 
                    131.395}, {50.977, 120.95}, {52.684, 122.661}, {52.684, 
                    124.712}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    54.391, 127.43}, {55.645, 126.17299999999999`}, {54.391, 
                    124.915}, {52.483999999999995`, 124.915}, {
                    52.483999999999995`, 122.74700000000001`}, {50.977, 
                    121.239}, {50.977, 131.106}, {52.483999999999995`, 
                    129.598}, {52.483999999999995`, 127.43}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGItIGYC4r0lkyVY0nwcwvh0N83V93dgAAEFX4fDXzVi
+pv8HICyYXy1ng4ny/bNl5L3hvP/Xal4qdbo4/CrLmtPyWJvuPptn/8CZbzg
5pnG7fLkKfJx8OJh0m73C3C4vrjAluu4t8M694dVIvMQ/MqXaoYcOgEOC12B
JpR4YfDBBm0JcLDlAurI9XXwBJknFuTwOnCHXOtrPzg/xfq+f6+4vwPQ9HXu
MwMh7rH0g/NdunOe/9aEymtC5Q8GOGye+375MesguDzYfX7BcP1g/j2E+TA+
zP6Qx0tnH0kIgrsPxoe5P6B3ep7Q4WA4X+zmue/B3iFw/6Pzwe67GQwPP7B5
GiHw8E0FueN+CDz8we4xC4XHj0CE5ZYTZmFwvlY70IbnYfD4hamHxT/MvFMg
B771hdtnB/LPXB+HClB89ARD4qXG14Gtcapzt0qww+wjChuKNPwh8m+CHYC+
bD6QFQgPT5g82H/dAXD9XY4JTy8EBcLNB8u/DoDbD0svADOPI54=
                    
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGItIGYC4uuLC2y5vvs6PKwSWed+McjBpTvn+W9Nf4dP
l3yTBBKCHTImvq2xvxrgsHnu++XHrBHy84Bcb/FAB5j+de5AE5bB+H5wfrvY
zXPfL/s55Ak1HzjFGeSgGdN/6GuFL5zfNx3ImuAF0bc+AM4Pebx09hGLAIfX
gTvkWld7Y/CnSLCE8e0NcNACmTfDx8GLh0m73Q+qX8DbIYxPd9NcfX+Hi0q3
f9ad8nY4/FUjpr/Jz2EySF+tJ0R/rA+cH9AL1OjsDXHfDx+4+mcXgAbY+cDN
A7vzuC/cPjBd5uMA8mbw6wCHypdqhhw1vhBzUwMdZh9R2FCk4e8QlWJ9339u
gMNTkHlhgfDwhMmbxe3y5LkVDNf/Z+XHS75CwXDzK0DiPcFw+8HhoRECd18q
0Pje+yFw94PD3ywU7r8Xv4EGXg2D88H6PcLg4QNTDws/mHmw8IXZBwv/vyD3
7QqG88HutAuBxx86H6jqdeCJYHj8K24oypiYGwRPHzA+LP3A0iMAEvclyg==

                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    64.93, 73.02}, {63.379, 71.579}, {63.12500000000001, 
                    73.02}, {63.379, 74.46600000000001}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    63.523, 74.048}, {63.343999999999994`, 73.02}, {63.523, 
                    71.99700000000001}, {64.62499999999999, 
                    73.02}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    54.473, 71.47}, {55.93, 72.93}, {54.473, 74.395}, {52.684,
                     74.395}, {52.684, 76.44200000000001}, {50.977, 
                    78.15299999999999}, {50.977, 67.712}, {52.684, 69.423}, {
                    52.684, 71.47}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    54.391, 74.192}, {55.645, 72.93}, {54.391, 
                    71.67299999999999}, {52.483999999999995`, 
                    71.67299999999999}, {52.483999999999995`, 69.505}, {
                    50.977, 67.99700000000001}, {50.977, 77.868}, {
                    52.483999999999995`, 76.36}, {52.483999999999995`, 
                    74.192}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGItIGYC4uKMiW9r0uMcri8usOU6nO1wUen2zzquOIdz
34MfL52e7VD5Us2Q4068w5e/Vype7suC8znWyESliGc7hDxeOvvICYR6/bsq
bI2q8XDztn0GakyMc2g+cGqhq1yOw9MLQAu2xTnsLZksweKG4EuDNPLmODCA
QEI8Bv9hlcg698Ach01z3y8/9jgWYh5TrgPQtVl7VBB8+dbXgTv4YiHqDuc4
fNOI6T9Ui+CD3cca63Ae5N7uHIg9N6MdzDsdE56K5MLlF0gBWfNy4frB7k1D
mA/jw+wHisq1qufC3Qfjw9zfOz1PqPkGgg8ON5k8uP/R+RBzcuHh9wZkHnce
PHwFIiy3nEjLg4c/2L2T8uDxkwYCQvlwPjg+svPh8QtTD4t/mHlgdy+OhdsH
dod3nMM/YPSr7c11EF3n/rDqTiwkPjpzIeHOFgsJx7e5DlZbTpTt00eEJ0we
7E6bHLh+cHgsyIGbX2jLdX1xTg7cflh6AQANNjHl
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGItIGYC4mcXlG7/nBfrcP578OOl8bkO+ndV2BpZYx0c
E55eUFqe65Ax8W2N/dFoB/NOoIgIQl5309z3y5tyHGD6F0gBZU5B+XII/nFv
oE6DWIdpzt05z3/nOOwtmSzBcg/B57q+uMA2KN5BD2SeH4L/OnCHXKtwjsPt
n3VZe47EYfCXHwMaHAo1zy/OofnAqYWucjkOLiBjBeMdQMZwHc6GuH9rnMM5
kP+mZztUvlQz5LgTD1HPh+BPBbnneBbEPDmE+rhdnjxM1XFw856C/LctFm7f
GpmoFOv4OIdCW6DLc3IcRNe5P6y6E+uwAuS+lTkQdWyxDt80YvoPueZA/OGM
CE+YPNgdT3Lh+u1NgTY35MLN/3el4qXa3ly4/W9A5nDnwd0nEGG55URaHtz9
4PCflAf3302QhxLz4Xywful8ePjA1MPCD8U8YPjC7IOFP9h9V3LhfLA/xPLg
8YfOdwKlp9u58PgHu0c3F54+YHxY+oGlRwBWgTbg
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    113.48400000000001`, 232.74299999999997`}, {115.035, 
                    231.298}, {115.289, 232.74299999999997`}, {115.035, 
                    234.18800000000002`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    114.891, 233.76999999999998`}, {115.07, 
                    232.74299999999997`}, {114.891, 231.71599999999998`}, {
                    113.789, 232.74299999999997`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    123.94100000000002`, 231.192}, {122.48400000000001`, 
                    232.64899999999997`}, {123.94100000000002`, 
                    234.11399999999998`}, {125.73, 234.11399999999998`}, {
                    125.73, 236.165}, {127.438, 237.872}, {127.438, 227.43}, {
                    125.73, 229.141}, {125.73, 231.192}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    124.023, 233.911}, {122.77, 232.64899999999997`}, {
                    124.023, 231.39100000000002`}, {125.93, 
                    231.39100000000002`}, {125.93, 229.227}, {127.438, 
                    227.72}, {127.438, 237.58700000000002`}, {125.93, 
                    236.07899999999998`}, {125.93, 233.911}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGItIGYC4uKMiW9r0uMc1NgapzpLpzpcVLr9s44rzqHy
pZohx4cUCH0n3sEx4ekFJXEE//z34MdL81McQh4vnX3kBEK9/l0VtkbVeLh5
2z7/vVKRGOfgycOk3V6W6gA05fbPbXEO6WlAMA/BP6KwoSgjNdWBAQQS4jH4
K455m3euTHXYNPf98mOPYx10QYyoNAega7P2qCD48q2vA3fwxULcI5Pm8E0j
pv9QLYIPdh8rlP8k1UEaJHAz2uHflYqXarkIeZDz0r4h9IPduw9hPowPsx/s
rvo0uPtgfJj7LTqBIWiQDueD7S1Nh/sfnQ92n006PPzA5iWnw8MXHB/70+Hh
D3bPq3R4/AhGWG45kZUB56uC4uNwBjx+Yeph8Q8zD+g7udbFsXD7wLQ3NH5E
0x1E17k/rLoT69CT8/z3yodpDs0HTi10ZYuFyLumO1htOVG2Tx8RnjB5sP+m
psL1B4Pc/SMVbr45KHyOpMLth6UXALDCLMI=
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGItIGYC4mcXlG7/nBfrUPlSzZBjR5qD/l0VtkbWWAfO
NTJRKf/THDImvq2xPxrt8O9KxUu1XIT89cUFtly3Ux1g+tNAQCkNwpdD8I97
m3c6GsQ62JvG7fIMSXPYWzJZguUegs8FMigo3uHzX6AFy1Lh/M1z3y8/lp3q
cPtnXdaeI3EY/Jvnvgc/XpsKMc8vzsGTh0m7vSzVwaU75/lvwXgHNbbGqc7S
qRD3b42D+O9DCoS+E++guwloYBqCH9N/6KuGQgrEPDmEeqAreZiq4+DmPQX5
b1ss3D5QMFnHxzkAfZnw9Eiqg+g694dVd2Ih7mNMc2g+cGqhK1ssxNx5qQ6v
A3fItTojwhMmv/rjJd8km3S4/t7peULNN9Lg5h9R2FCUIZoOtx/k/GPJ6XD3
AW2/oLQ/He7+dFD4v0qH+68FZM+uDDgfrL84Ax4+MPWw8EMxDxi+MPtg4d8H
cp8Ogq8HUpCXDo8/dD7Y38bp8PhfIAVMSW2I9AHjw9IPLD0CAMdZMIQ=
                    
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    113.48400000000001`, 179.501}, {115.035, 178.059}, {
                    115.289, 179.501}, {115.035, 180.946}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    114.891, 180.52800000000002`}, {115.07, 179.501}, {
                    114.891, 178.477}, {113.789, 179.501}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    123.94100000000002`, 177.95000000000002`}, {
                    122.48400000000001`, 179.411}, {123.94100000000002`, 
                    180.876}, {125.73, 180.876}, {125.73, 182.923}, {127.438, 
                    184.634}, {127.438, 174.192}, {125.73, 175.903}, {125.73, 
                    177.95000000000002`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    124.023, 180.67299999999997`}, {122.77, 179.411}, {
                    124.023, 178.153}, {125.93, 178.153}, {125.93, 175.985}, {
                    127.438, 174.477}, {127.438, 184.348}, {125.93, 
                    182.841}, {125.93, 180.67299999999997`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGItIGYC4uKMiW9r0uMc5r1ffsz7eYzDRaXbP+u44hzq
s/aUTJ4Q41D5Us2Q4068w/XFBbZc96Pg/E+XfJMEJkQ7hDxeOvvICYR6/bsq
bI2q8XDztn3+e6UiMc7hxe+VHy/NjXV4egFowbY4h6gU6/v+bxF88ZvnvgdX
xzowgEBCPAZ/01yggcxxEPpxrMM694dVImnxDkDXZu1RQfDlW18H7uCLhbjr
RZzDN42Y/kO1CD7YfaxQfkWcgzRI4Ga0g3/v9Dyh7ni4vGCE5ZYTfglw/QIg
vlgC3HwYH2b/DjmgxIZ4uPtgfJj7/12peKnWmQDnH1HYUJRxNgHuf3T+qo/A
AJ6SAA+/2P5DXzX2JMDDF+gKuVbxRHj4g93rlIgaX4cR/PPfgx8vlU6Cxy9M
PSz+YeaB6cWxcPvA/vGGhmNugoMoKKDvxDqAouexZYJD84FTC13ZYh16cp7/
Xjk3wcFqy4myffqI8ITJdzkmPL1wKxau/w8wOfguioObf/gr0AKrOLj9sPQC
AJB0QVs=
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGItIGYC4mcXlG7/nBfr4GAat8tTIMFB/64KWyNrrMPG
ue+XHwtPcMiY+LbG/mi0g3/v9Dyh7ni4vCcPk3Z7WpwDTL/ihqKMiV+hfDkE
/7i3eaejQayDNEhjZLzD3pLJEiz3EHyu64sLbIPiHbxA5v2LhfN3yLW+DuyI
dbj9sy5rz5E4DL49yL08cRDz/OIcXvxe+fHS3FgHl+6c578F4x3mAZ3v/TwG
4v6tcQ71WXtKJk+Icah8qWbIcSceor42Gs4Hu+djFMQ8OYR6kC1M1XFw856C
/LctFm7fGpmoFOv4OIfDXzVi+q3iHETXuT+sugMNzy1xDs0HTi10ZYt1OHsG
CN7EOrwOBPrEGRGeMPkCW6DPpyTA9Vt0OiY8NUiAm/8NaPyh3AS4/bH9h75q
7EmAuw9srngi3P2CEZZbTjglwv0Hji+hJDgfrP9MIjx8YOph4YdiHjB8YfbB
wt8c5L4WBP/z3ysVL48lwOMPnb8ZlJ66E+DxP0WCJYxvbzw8fcD4sPQDS48A
yt4w2Q==
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    113.48400000000001`, 126.262}, {115.035, 
                    124.81700000000001`}, {115.289, 126.262}, {115.035, 
                    127.708}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    114.891, 127.29}, {115.07, 126.262}, {114.891, 125.235}, {
                    113.789, 126.262}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    123.94100000000002`, 124.712}, {122.48400000000001`, 
                    126.17299999999999`}, {123.94100000000002`, 127.634}, {
                    125.73, 127.634}, {125.73, 129.684}, {127.438, 131.395}, {
                    127.438, 120.95}, {125.73, 122.661}, {125.73, 
                    124.712}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    124.023, 127.43}, {122.77, 126.17299999999999`}, {124.023,
                     124.915}, {125.93, 124.915}, {125.93, 
                    122.74700000000001`}, {127.438, 121.239}, {127.438, 
                    131.106}, {125.93, 129.598}, {125.93, 127.43}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGItIGYC4uKMiW9r0uMcwvh0N83V93e4qHT7Zx1XnMPh
rxox/U1+DpUv1Qw57sQ7nCzbN19K3hvO/3el4qVao49DyOOls4+cQKjXv6vC
1qgaDzdv2+e/VyoS4xy8eJi02/0CHJ5eAFqwLc5hnfvDKpF5CD7YXJ0ABwYQ
SIjH4DuYxu3y3BLgsGnu++XHHsc6eILMEwtyALo2a48Kgi/f+jpwB1+sA9D0
de4zAx2+AZ11qBbBB7uPFcrXDHSQBgncjHbYDDLXOgguD3afXzBcP5h/D2E+
jA+zHxwOCUFw98H4MPcH9E7PEzocDOeL3Tz3Pdg7BO5/dD7YfTeD4eEHNk8j
BB6+qdb3/Xvvh8DDH+wes1B4/AhEWG45YRYG52u1A214HgaPX5h6WPzDzAP6
Tq51cSzcPrB/vOMcKkDm9AQ7iII03ol1YGuc6tytEuzQfODUQle2WIj8m2AH
qy0nyvbpI8ITJg/2X3cAXH+XY8LTC0GBcPPB8q8D4PbD0gsAt4UpRQ==
                    
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGItIGYC4mcXlG7/nBfr8LBKZJ37xSAH/bsqbI2ssQ6f
LvkmCSQEO2RMfFtjfzTaYfPc98uPWSPk5wG53uKBDjD969yBJiyD8uUQ/OPe
5p2OBrEOeULNB05xBjnsLZkswXIPwee6vrjANijeAURxrQ+A80MeL519xCLA
4fbPuqw9R+Iw+FMkWML49gZAzPOLc/DiYdJu9wtwcOnOef5bMN4hjE9301x9
f4j7t8Y5HP6qEdPf5OdQ+VLNkONOPER/rA+cH9A7PU/I2RtinhxCfdwuTx6m
6ji4eU9B/tsWC7dvjUxUinV8nIPYzXPfg18HOIiCPH4n1mEyyPzUQAegLxe6
ssU6AFXd958b4PA6cIdcqzMiPGHyZiCLbgXD9f9Z+fGSr1Aw3PwKkDt7guH2
g8NDIwTuvlSg8b33Q+DuB4e/WSjcfy9+Aw28Ggbng/V7hMHDB6YeFn4o5vnF
we2Dhf9fkPt2BcP54PCwC4HHHzof6OvXgSeC4fGvuKEoY2JuEDx9wPiw9ANL
jwBu5yeM
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    113.48400000000001`, 73.02}, {115.035, 71.579}, {115.289, 
                    73.02}, {115.035, 74.46600000000001}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    114.891, 74.048}, {115.07, 73.02}, {114.891, 
                    71.99700000000001}, {113.789, 73.02}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    123.94100000000002`, 71.47}, {122.48400000000001`, 
                    72.93}, {123.94100000000002`, 74.395}, {125.73, 74.395}, {
                    125.73, 76.44200000000001}, {127.438, 
                    78.15299999999999}, {127.438, 67.712}, {125.73, 69.423}, {
                    125.73, 71.47}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    124.023, 74.192}, {122.77, 72.93}, {124.023, 
                    71.67299999999999}, {125.93, 71.67299999999999}, {125.93, 
                    69.505}, {127.438, 67.99700000000001}, {127.438, 
                    77.868}, {125.93, 76.36}, {125.93, 74.192}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIxIGYC4uuLC2y5jns7fNWI6T8UXegA46uyNU51ti90
WOi67fPfEi8MPscamaiUxEIHWy6gjlxfh5vnvgc/3lno8Dpwh1zraz84P8X6
vn+vuL9DfdaeksmzCh2Auq9UWPrB+S7dOc9/a/o71IH4dVD5gwEOxiBwuNDh
otLtn3VZgXD+7CMKG4o0/B0CeqfnCYUXOlS+VDPkqPF1iNvlycPUWehgB3LP
XB+IfH6hwymQg9/6OtwAuce90GFvyWQJljQfh6sVQI1ShQ4MIKDgC7GfpdAB
KBvGV+vpsEBK/67KjAI4H2zvkQKHXyCFi73h6sHufekFN88U5JAiH7h9AIMo
ngA=
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIxIGYC4otKt3/WnfJ2qMvaUzKZpdBhsgRLGF+tp8ON
c9+DH+8vgPOTBCIst8wpcNCM6T/09YcPXP2zC0AD7Hwcrla8VDOUKnS4vrjA
luu4L0S/e6GDFw+TdnuZj0NA7/Q8ofxCh0qgMo4aX4c3gTvkWnsLHWYfUdhQ
pOHvINR84NTC6EKHpyDzwgIdjEHgcKFDxsS3NfZXA+B8l+6c5781/R3WuT+s
EqmC2vfd1+HF75UfL82F8f3g/Haxm+e+X/aDuH9bIcT9Fb5wfh/QWc0TvByA
vpFgSUDwwbRTocNrkDtXe2PwwXRyoYMWyLwZPnD/gtUJeMPDAwD7p6Dc
                    
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{64.832, 
                    284.2}, {63.379, 282.845}, {63.141, 284.2}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    63.358999999999995`, 284.2}, {63.523, 283.262}, {64.527, 
                    284.2}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{55.93, 284.2}, {50.977, 
                    284.2}, {50.977, 278.977}, {52.684, 280.688}, {52.684, 
                    282.739}, {54.473, 282.739}, {55.93, 
                    284.19599999999997`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{50.977, 279.262}, {50.977, 
                    284.2}, {55.645, 284.2}, {55.645, 284.19599999999997`}, {
                    54.391, 282.93799999999993`}, {52.483999999999995`, 
                    282.93799999999993`}, {52.483999999999995`, 
                    280.77}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIxIGYC4qcXlG7/3Bbn8FUjpv9QdKEDjK/K1jjV2b7Q
gQEEEuIx+BxrZKJSEgsdNs19v/zY41iHm+e+Bz/eWehw+2dd1h4VBF++9XXg
Dr5Yh/qsPSWTZxU6fAPZU4vg699VYWtkjXWoA/HrCh2kQQI3ox2MQeAw1D4D
BL/5wKmFrmyxDgG90/OEwgsdRNe5P6y6E+sQt8uTh6kT6h7vOIh8fqED0Ha5
1sWxDjdA7nEvdCjOmPi2Jj3O4WrFSzVDqUKHi0Dv1nHFQexnKXSoBApz3Il3
WCAFdMiMAjh/9hGFDUVHChxCHi+dfeQEQj3Y/arxcPO2ff57pSIxDm4fAAsQ
m/A=
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIxIGYC4oyJb2vst8Y51GXtKZnMUuhQ+VLNkONOvMON
c9+DH+8vgPOTBCIst8wpcNhbMlmCRQ6hPm6XJw9TdZzD1QqgQqlCh6cXlG7/
3BYL0e9e6LBGJirFOj7OIaB3ep5QfqGD6Dr3h1V3Yh3eBO6Qa+0tdGg+cGqh
K1usgxCIEV3o8Bok7hztYAwChwsdwO47iuDr31Vha2SNdQAZI1JV6PAMZN+8
WIcXv1d+vDQXypdD8I97m3c6GsRC3L+tEOL+ewg+1/XFBbZB8Q57QOIJCH4f
0LnNToUOt38CfXokDoMPdmcy1Dy/OLh/Xbpznv8WjIeHBwDCJaEs
                    
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{113.582, 
                    284.2}, {115.035, 282.845}, {115.273, 284.2}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    115.05499999999999`, 284.2}, {114.891, 283.262}, {113.887,
                     284.2}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{122.48400000000001`, 
                    284.2}, {127.438, 284.2}, {127.438, 278.977}, {125.73, 
                    280.688}, {125.73, 282.739}, {123.94100000000002`, 
                    282.739}, {122.48400000000001`, 
                    284.19599999999997`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{127.438, 279.262}, {
                    127.438, 284.2}, {122.77, 284.2}, {122.77, 
                    284.19599999999997`}, {124.023, 282.93799999999993`}, {
                    125.93, 282.93799999999993`}, {125.93, 280.77}}}]}}}}}}}},
            
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 425.}, {0., 285.}}], ",", 
           GraphicsBox[{{{
               {Thickness[0.0025], {{{
                   {FaceForm[{RGBColor[0., 0.6, 0.709804], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     200.}, {400., 200.}, {400., 136.}, {0., 
                    136.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.8078430000000001, 0.06666670000000002, 0.14902], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     136.}, {400., 136.}, {400., 64.}, {0., 64.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     132.}, {400., 132.}, {400., 68.}, {0., 68.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.117647, 0.709804, 0.22745100000000001`], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     64.}, {400., 64.}, {400., 0.}, {0., 0.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{80., 168.}, {80., 154.74599999999998`}, {69.254, 
                    144.}, {56., 144.}, {42.746, 144.}, {32., 
                    154.74599999999998`}, {32., 168.}, {32., 181.254}, {
                    42.746, 192.}, {56., 192.}, {69.254, 192.}, {80., 
                    181.254}, {80., 168.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[0., 0.6, 0.709804], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{88., 168.}, {88., 154.74599999999998`}, {77.254, 
                    144.}, {64., 144.}, {50.746, 144.}, {40., 
                    154.74599999999998`}, {40., 168.}, {40., 181.254}, {
                    50.746, 192.}, {64., 192.}, {77.254, 192.}, {88., 
                    181.254}, {88., 168.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{70.398, 
                    153.602}, {68.918, 149.035}, {71.199, 
                    148.29299999999998`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{70.398, 
                    153.602}, {71.883, 149.035}, {69.60199999999999, 
                    148.29299999999998`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{74.965, 
                    150.285}, {70.164, 150.285}, {70.164, 147.883}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{74.965, 
                    150.285}, {71.082, 147.461}, {69.67199999999998, 
                    149.40200000000002`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{73.223, 
                    144.918}, {71.738, 149.48000000000002`}, {
                    69.45700000000001, 148.738}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{73.223, 
                    144.918}, {69.34, 147.738}, {70.75, 149.68}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    67.57799999999999, 144.918}, {71.46100000000001, 
                    147.738}, {70.051, 149.68}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    67.57799999999999, 144.918}, {69.062, 
                    149.48000000000002`}, {71.34400000000001, 148.738}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{65.836, 
                    150.285}, {69.71900000000001, 147.461}, {
                    71.12899999999999, 149.40200000000002`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{65.836, 
                    150.285}, {70.637, 150.285}, {70.637, 147.883}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    89.60199999999999, 153.602}, {88.117, 149.035}, {90.398, 
                    148.29299999999998`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    89.60199999999999, 153.602}, {91.082, 149.035}, {88.801, 
                    148.29299999999998`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{94.164, 
                    150.285}, {89.363, 150.285}, {89.363, 147.883}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{94.164, 
                    150.285}, {90.281, 147.461}, {88.871, 
                    149.40200000000002`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{92.422, 
                    144.918}, {90.938, 149.48000000000002`}, {
                    88.65599999999999, 148.738}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{92.422, 
                    144.918}, {88.539, 147.738}, {89.94900000000001, 
                    149.68}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{86.777, 
                    144.918}, {90.66, 147.738}, {89.25, 149.68}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{86.777, 
                    144.918}, {88.262, 149.48000000000002`}, {90.543, 
                    148.738}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{85.035, 
                    150.285}, {88.918, 147.461}, {90.32799999999999, 
                    149.40200000000002`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{85.035, 
                    150.285}, {89.836, 150.285}, {89.836, 147.883}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{108.801, 
                    153.602}, {107.316, 149.035}, {109.598, 
                    148.29299999999998`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{108.801, 
                    153.602}, {110.285, 149.035}, {108., 
                    148.29299999999998`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{113.363, 
                    150.285}, {108.566, 150.285}, {108.566, 147.883}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{113.363, 
                    150.285}, {109.48, 147.461}, {108.07, 
                    149.40200000000002`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{111.621, 
                    144.918}, {110.137, 149.48000000000002`}, {
                    107.85499999999999`, 148.738}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{111.621, 
                    144.918}, {107.738, 147.738}, {109.148, 149.68}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{105.98, 
                    144.918}, {109.863, 147.738}, {108.453, 149.68}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{105.98, 
                    144.918}, {107.46100000000001`, 149.48000000000002`}, {
                    109.74600000000001`, 148.738}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    104.23400000000001`, 150.285}, {108.117, 147.461}, {
                    109.527, 149.40200000000002`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    104.23400000000001`, 150.285}, {109.035, 150.285}, {
                    109.035, 147.883}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{128., 
                    153.602}, {126.516, 149.035}, {128.80100000000002`, 
                    148.29299999999998`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{128., 
                    153.602}, {129.484, 149.035}, {127.199, 
                    148.29299999999998`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{132.566, 
                    150.285}, {127.766, 150.285}, {127.766, 147.883}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{132.566, 
                    150.285}, {128.684, 147.461}, {127.27, 
                    149.40200000000002`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    130.82000000000002`, 144.918}, {129.34, 
                    149.48000000000002`}, {127.05499999999999`, 148.738}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    130.82000000000002`, 144.918}, {126.938, 147.738}, {
                    128.348, 149.68}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    125.17999999999999`, 144.918}, {129.062, 147.738}, {
                    127.65199999999999`, 149.68}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    125.17999999999999`, 144.918}, {126.66, 
                    149.48000000000002`}, {128.945, 148.738}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    123.43400000000001`, 150.285}, {127.316, 147.461}, {
                    128.73, 149.40200000000002`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    123.43400000000001`, 150.285}, {128.23399999999998`, 
                    150.285}, {128.23399999999998`, 147.883}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    147.19899999999998`, 153.602}, {145.71499999999997`, 
                    149.035}, {148., 148.29299999999998`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    147.19899999999998`, 153.602}, {148.684, 149.035}, {
                    146.40200000000002`, 148.29299999999998`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{151.766, 
                    150.285}, {146.965, 150.285}, {146.965, 147.883}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{151.766, 
                    150.285}, {147.883, 147.461}, {146.47299999999998`, 
                    149.40200000000002`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{150.02, 
                    144.918}, {148.539, 149.48000000000002`}, {146.254, 
                    148.738}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{150.02, 
                    144.918}, {146.137, 147.738}, {147.547, 149.68}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{144.379, 
                    144.918}, {148.262, 147.738}, {146.85200000000003`, 
                    149.68}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{144.379, 
                    144.918}, {145.863, 149.48000000000002`}, {
                    148.14499999999998`, 148.738}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{142.637, 
                    150.285}, {146.52, 147.461}, {147.93, 
                    149.40200000000002`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{142.637, 
                    150.285}, {147.434, 150.285}, {147.434, 147.883}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    89.60199999999999, 172.80100000000002`}, {88.117, 
                    168.23399999999998`}, {90.398, 167.49200000000002`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    89.60199999999999, 172.80100000000002`}, {91.082, 
                    168.23399999999998`}, {88.801, 167.49200000000002`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{94.164, 
                    169.484}, {89.363, 169.484}, {89.363, 
                    167.08200000000002`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{94.164, 
                    169.484}, {90.281, 166.66}, {88.871, 168.605}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{92.422, 
                    164.117}, {90.938, 168.684}, {88.65599999999999, 
                    167.941}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{92.422, 
                    164.117}, {88.539, 166.93800000000002`}, {
                    89.94900000000001, 168.879}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{86.777, 
                    164.117}, {90.66, 166.93800000000002`}, {89.25, 
                    168.879}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{86.777, 
                    164.117}, {88.262, 168.684}, {90.543, 167.941}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{85.035, 
                    169.484}, {88.918, 166.66}, {90.32799999999999, 
                    168.605}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{85.035, 
                    169.484}, {89.836, 169.484}, {89.836, 
                    167.08200000000002`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{108.801, 
                    172.80100000000002`}, {107.316, 168.23399999999998`}, {
                    109.598, 167.49200000000002`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{108.801, 
                    172.80100000000002`}, {110.285, 168.23399999999998`}, {
                    108., 167.49200000000002`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{113.363, 
                    169.484}, {108.566, 169.484}, {108.566, 
                    167.08200000000002`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{113.363, 
                    169.484}, {109.48, 166.66}, {108.07, 168.605}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{111.621, 
                    164.117}, {110.137, 168.684}, {107.85499999999999`, 
                    167.941}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{111.621, 
                    164.117}, {107.738, 166.93800000000002`}, {109.148, 
                    168.879}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{105.98, 
                    164.117}, {109.863, 166.93800000000002`}, {108.453, 
                    168.879}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{105.98, 
                    164.117}, {107.46100000000001`, 168.684}, {
                    109.74600000000001`, 167.941}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    104.23400000000001`, 169.484}, {108.117, 166.66}, {
                    109.527, 168.605}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    104.23400000000001`, 169.484}, {109.035, 169.484}, {
                    109.035, 167.08200000000002`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{128., 
                    172.80100000000002`}, {126.516, 168.23399999999998`}, {
                    128.80100000000002`, 167.49200000000002`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{128., 
                    172.80100000000002`}, {129.484, 168.23399999999998`}, {
                    127.199, 167.49200000000002`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{132.566, 
                    169.484}, {127.766, 169.484}, {127.766, 
                    167.08200000000002`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{132.566, 
                    169.484}, {128.684, 166.66}, {127.27, 168.605}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    130.82000000000002`, 164.117}, {129.34, 168.684}, {
                    127.05499999999999`, 167.941}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    130.82000000000002`, 164.117}, {126.938, 
                    166.93800000000002`}, {128.348, 168.879}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    125.17999999999999`, 164.117}, {129.062, 
                    166.93800000000002`}, {127.65199999999999`, 168.879}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    125.17999999999999`, 164.117}, {126.66, 168.684}, {
                    128.945, 167.941}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    123.43400000000001`, 169.484}, {127.316, 166.66}, {128.73,
                     168.605}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    123.43400000000001`, 169.484}, {128.23399999999998`, 
                    169.484}, {128.23399999999998`, 167.08200000000002`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    147.19899999999998`, 172.80100000000002`}, {
                    145.71499999999997`, 168.23399999999998`}, {148., 
                    167.49200000000002`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    147.19899999999998`, 172.80100000000002`}, {148.684, 
                    168.23399999999998`}, {146.40200000000002`, 
                    167.49200000000002`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{151.766, 
                    169.484}, {146.965, 169.484}, {146.965, 
                    167.08200000000002`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{151.766, 
                    169.484}, {147.883, 166.66}, {146.47299999999998`, 
                    168.605}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{150.02, 
                    164.117}, {148.539, 168.684}, {146.254, 167.941}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{150.02, 
                    164.117}, {146.137, 166.93800000000002`}, {147.547, 
                    168.879}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{144.379, 
                    164.117}, {148.262, 166.93800000000002`}, {
                    146.85200000000003`, 168.879}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{144.379, 
                    164.117}, {145.863, 168.684}, {148.14499999999998`, 
                    167.941}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{142.637, 
                    169.484}, {146.52, 166.66}, {147.93, 168.605}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{142.637, 
                    169.484}, {147.434, 169.484}, {147.434, 
                    167.08200000000002`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{108.801, 
                    192.}, {107.316, 187.434}, {109.598, 186.691}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{108.801, 
                    192.}, {110.285, 187.434}, {108., 186.691}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{113.363, 
                    188.684}, {108.566, 188.684}, {108.566, 186.285}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{113.363, 
                    188.684}, {109.48, 185.863}, {108.07, 187.805}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{111.621, 
                    183.316}, {110.137, 187.883}, {107.85499999999999`, 
                    187.141}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{111.621, 
                    183.316}, {107.738, 186.137}, {109.148, 188.078}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{105.98, 
                    183.316}, {109.863, 186.137}, {108.453, 188.078}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{105.98, 
                    183.316}, {107.46100000000001`, 187.883}, {
                    109.74600000000001`, 187.141}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    104.23400000000001`, 188.684}, {108.117, 185.863}, {
                    109.527, 187.805}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    104.23400000000001`, 188.684}, {109.035, 188.684}, {
                    109.035, 186.285}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{128., 192.}, {
                    126.516, 187.434}, {128.80100000000002`, 186.691}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{128., 192.}, {
                    129.484, 187.434}, {127.199, 186.691}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{132.566, 
                    188.684}, {127.766, 188.684}, {127.766, 186.285}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{132.566, 
                    188.684}, {128.684, 185.863}, {127.27, 187.805}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    130.82000000000002`, 183.316}, {129.34, 187.883}, {
                    127.05499999999999`, 187.141}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    130.82000000000002`, 183.316}, {126.938, 186.137}, {
                    128.348, 188.078}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    125.17999999999999`, 183.316}, {129.062, 186.137}, {
                    127.65199999999999`, 188.078}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    125.17999999999999`, 183.316}, {126.66, 187.883}, {
                    128.945, 187.141}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    123.43400000000001`, 188.684}, {127.316, 185.863}, {
                    128.73, 187.805}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    123.43400000000001`, 188.684}, {128.23399999999998`, 
                    188.684}, {128.23399999999998`, 186.285}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    147.19899999999998`, 192.}, {145.71499999999997`, 
                    187.434}, {148., 186.691}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    147.19899999999998`, 192.}, {148.684, 187.434}, {
                    146.40200000000002`, 186.691}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{151.766, 
                    188.684}, {146.965, 188.684}, {146.965, 186.285}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{151.766, 
                    188.684}, {147.883, 185.863}, {146.47299999999998`, 
                    187.805}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{150.02, 
                    183.316}, {148.539, 187.883}, {146.254, 187.141}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{150.02, 
                    183.316}, {146.137, 186.137}, {147.547, 188.078}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{144.379, 
                    183.316}, {148.262, 186.137}, {146.85200000000003`, 
                    188.078}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{144.379, 
                    183.316}, {145.863, 187.883}, {148.14499999999998`, 
                    187.141}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{142.637, 
                    188.684}, {146.52, 185.863}, {147.93, 187.805}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{142.637, 
                    188.684}, {147.434, 188.684}, {147.434, 
                    186.285}}}]}}}}}}}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 400.}, {0., 200.}}], ",", 
           GraphicsBox[{{{
               {Thickness[0.001893939393939394], {{{
                   {FaceForm[{RGBColor[0., 0.47058800000000006`, 0.368627], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 352.}, {528., 352.}, {528., 0.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.9843139999999999, 0.8196080000000001, 
                    0.08627450000000002], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBWIuIGZigIKGAofHS2cfUbhV6LD1RNm++VYFDse8zTsd
WQod+g991YjZnAfnCzUfOLWQv8Dh0yXfJIEGqLop+Q4FtlzXF4fkO8DM2yHX
+jpQr8BBNirF+r5pIVz+bY29adwHhH6wumWFcPNBVMJRhP2LXLd9/iuQ5ZD7
/PfKj0lQd+ZkOaz+CDRgTr4DUPcOudxMB5funOe/X+ZB5JdkOfROzxNqfpLn
4Jjw9ILS/yyHapF17g935ULEU7Ih+h7mOYTx6W6aOzsH4s7beQ6qbI1TnRdn
O8Tu8uRhmp7vsApkD0eOwxZQuMQVQNzHmQ2hWQsc9O+qsDV+L4a7D2SMf3Ux
XF6rXezmud9FcP1g/+sVw82/WvFSzXBTEdx+K5BC32K4++77A13cUAx3P8i5
79cWw/0HCtYCzxK4/8HyJ4vh4VOUMfFtzeF0iP53OZDwcUh32D9fSv/ulWyH
CaD45U6DyP/KhqpLcwAZf0ANKp+d5lAIsogny6EYZF51OsTcxVkOcSB/xGdA
1J3PdLAEuV85w+H2z7qsPQzZDqEgBxlnQsJ5ejZE/f90Bx9Q+OzNhsSzXCnc
fReUgDoZSuHy4PBJK4HrB7v/XQncfLD6CyVw+4+DzHMqhbtvJyh9nSqFux+k
rL+jFO4/sPyvUrj/eUHhF18KDx8AMi5sNg==
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}}, {{1, 4, 3}, {0, 1, 0}, {1, 3, 3}}, {{1, 4,
                     3}, {0, 1, 0}, {1, 3, 3}}, {{1, 4, 3}, {0, 1, 0}, {1, 3, 
                    3}}, {{1, 4, 3}, {1, 3, 3}}}, {CompressedData["
1:eJxVVWtIFFEUFosSkwiLiLCyd9nD+hFSYp2KsKwoCxSiYhzc2XF3Z3RmZ5Me
SBGSPUlKKiKkRKEyidCealJSIZQmkmmGWUSSmElFVPSYe87M2RRk+Pbee+53
vvPdc6bKuVs8kREREbvtf/HFv/15EFSL+/f1aYA4kAvR7WV5KScCDtZhlMBH
fIxrnuyqL01TGc8ccaBk9UMF+vetWLLzrYMzPSDCrriWC3kpdsQ52fCu/Hxj
fLUOrdNe/SjweWBZtR1oig6zF0dVxv1RGD9an3R4ZbXKGOO151C8LB1WSe9b
pvX56NwLHTqefd/6rscPG+xjUqGzP8nhv1aHlWJ/aYDWZzr8YzXotFnUFmlQ
Z52aMPyPn84lavBc8Kv3McZ7fDmMz+qxBxseeGHswYami3c0yBi94MaFZAWW
Cr5lOpx88G3O9r9OvjEa3XdFIf5PfVDYl357co0Xjp+xA21WGaN+C8P4sdAh
RnX08MInsf7RS/FueEnHBBV23F0XE5nv7JdUuDLYulFe5IX60omJr4tURx+F
6hrph/vi9zcK5b1co3MvPVSnNp10W5RNv2/WKJ7lgaviu91PeSYpMEvokZzD
GPlEq4wxTq9Cev30UB26nTjHPKTngEJ1qZMp/4oc0rVOorzbAowvrbn55XeU
xhj1THF82yBRXnkanWuUYKfQZZhGOl+XSIfiANWzQqL7Jocxno/zMUbeaY5+
RhbF/apAl/BNrUz7K526XpRJJ0mhup+UwRB6jlHID0dl4q15Qbi/NiKL3p3f
0W+kRHqU+RmTDzXGia9njDhQnkv39Ergvl/0S7pMPBYYvI78400+T/4KMsb6
plmM84Vh1oWYX2rPnnFV30PMP+HQ+I5nzSHOL/66qRZfDnH+k7ZlJ3cXhlgf
9Gmnxfrh/sEg63tYGOKzydh2Y8boW2HcIvIvMLl+eD7V5Pqi3bNMrj/qs9dk
fyCfkjDG++ZbjFGPohD7r3uTfdOYXexPjHssxP6lr8X+xvcoh/E8oU96kHGc
uD/T5PezVuhZYvD7Qj9LJr8/ezW1pyDI7xPzvWfx+8V4zRa/b+Tz0eL3j/lF
h7g/YP4/LO4fuN5rcX9Bnu1hjHqeCzIWbW1gt8n9C+teZXB/Q79MN7n/oZ6q
yf3RxW7/dLHbX2NFHZJN7r+C7qZ+g/sz6tRlcP/G9TqD+7v24dflwdMG93/k
32zwfEC+nw2eHy5254uL3fmD+ZYbPJ8w3lyD51eRIHLC4PmG/JoMnn8uHjIf
bTxkfqYZQ+frf/P3HzZeSso=
                    "], CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQYNBQ6WW06U7WtOdOC+vrjAdlW+g8FdFbZG2wSH
CYe+asTcznXgAom/inO4ee578OO72XD+qo+XfJNE0uB8sHkOaQ419qZxuzLj
HL5pxPQfyk1zEFnn/rDqTayDcPOBUwvnpjnMyBNqPlAUCzHPNAfO3zdfSv8u
Rx6cX2ALNHlLvsOmue+XHzsMNR/o3oyJb2vsKxMcPB5WiaxTLYTLK2woypj4
uxCuf7IESxjf0yI4vxxkwcZSOL/1deAOuZOlcPeBzX9QCne/drvYzXNfS+H+
A5snWAzn75QDmiBUBOdXgwzSKoSHH3r4AgC2fJ4U
                    "], {{186.059, 
                    111.742}, {186.969, 110.74600000000001`}, {
                    187.90200000000002`, 109.77}, {188.85200000000003`, 
                    108.809}, {339.148, 108.809}, {340.09799999999996`, 
                    109.77}, {341.03099999999995`, 110.74600000000001`}, {
                    341.941, 111.742}}, {{195.336, 102.758}, {197.195, 
                    101.16799999999999`}, {199.105, 99.637}, {201.07, 
                    98.17599999999999}, {326.92999999999995`, 
                    98.17599999999999}, {328.895, 99.637}, {330.805, 
                    101.16799999999999`}, {332.66400000000004`, 102.758}}, {{
                    207.758, 93.59}, {211.164, 91.44100000000002}, {214.695, 
                    89.48}, {218.35200000000003`, 87.727}, {309.648, 
                    87.727}, {313.305, 89.48}, {316.83599999999996`, 
                    91.44100000000002}, {320.242, 93.59}}, {{225.055, 
                    84.793}, {237.105, 80.}, {250.24599999999998`, 77.367}, {
                    264., 77.367}, {277.754, 77.367}, {290.895, 80.}, {
                    302.945, 84.793}}}]}}}}}}}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 528.}, {0., 352.}}], ",", 
           GraphicsBox[{{{
               {Thickness[0.0020833333333333333`], {{{
                   {FaceForm[{RGBColor[0., 0.501961, 0.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     240.}, {480., 240.}, {480., 0.}, {0., 0.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 0.8784310000000001, 0.], Opacity[
                    1.]}], FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {
                    1, 3, 3}}}, {{{134.445, 170.}, {134.445, 141.16}, {
                    111.062, 117.777}, {82.223, 117.777}, {53.379, 117.777}, {
                    30., 141.16}, {30., 170.}, {30., 198.84}, {53.379, 
                    222.22299999999998`}, {82.223, 222.22299999999998`}, {
                    111.062, 222.22299999999998`}, {134.445, 198.84}, {
                    134.445, 170.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[0.501961, 0.12549000000000002`, 0.], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIVIGYCYmn9uypsG4MdHi+dfUQhIMGh+cCpha7fwnDy
K1+qGXLIhDtcULr9s64sweGbRkz/obdhDsIghZ0JDsUZE9/W7A9z2D9fSv/u
nASH14E75Fq5wxwWuW77/HcBVL8NVP5JggMDCCwIc1j18ZJvUkGiw96SyRIs
68IcfMw7HRNcEx2AtmTteRMGoSckQczTDoe4506yQ429adwuz3AHyy0nyvY9
TsXgg/13MQwn/5g30KIXYQ7qhhxrZJxSHS6C/LUozMEKJJ+f4nAHZG9MmAPI
W/ZzkyH63MMcZuQJNR/oSnYAWsbD9DvUoRXksJdJkPBaF+pQBNLgngRRtyjU
AWRto2USJBxiQh0mHPqqEXM70WGNTFSKtXgoxPzaRIfjIPcIhDr0TgdqrEh0
iAeZvzjEASScoJgIMcc0BOLeUwkOmSB9sSEQe14lOISAAybE4S0oILYlQPzD
FAIxdw5U/d1gB1W2xqnOixMg4XESGv8TEhxE1rk/rNoSDPFPLVQeKX2g8wEC
hwLd
                    "]]}}}}, {{{
                   {RGBColor[0.48235300000000003`, 0.192157, 0.], Thickness[
                    0.002314814583333333], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIVIGYCYmn9uypsG4MdipbOY1UMSHBoPnBqoeu3MJz8
ypdqhhwy4Q4JSves6ssSHL5pxPQfehvmsKjpMPeizgSH4oyJb2v2hzn4zZct
uDsnweF14A65Vu4wBwPXnSb/FkD120DlnyQ4MIDAgjAHy49X+5IKEh32lkyW
YFkX5nDbrKcpwTXR4fbPuqw9b8Icsn42rt4zIQlinnY4xD13kh1q7E3jdnmG
O5zYfHr7vsepGHyw/y6G4eQf8zbvdHwR5rDNgPutjFOqw0UloI2LoPL5KQ53
QPbHhDn8mPBhr/3cZAfLLSfK9rmHOajliR450JXsALSMh+l3qIPI65Cfci+T
IOG1LtSBKWOKXq17ksOMPKHmA4tCHfbdUXdvtExyWOS67fPfmFAHuUM/MmNu
JzqskYlKsRYPhZhfm+hwHOQegVAHmemFwc0ViQ7xIPMXhzjcAoWHYqIDyPmN
piEQ955KcMgEBrd9bAjEPa8SHEIeL519RCHEoabGqSxuWwLEP0whDmHeVqcc
50DV3w122MLacs15cQIkPE5C439CgoPIOveHVVuCIf6phcojpQ90PgBfPP92

                    "],
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 0.8784310000000001, 0.], Opacity[
                    1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {
                    0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
                    1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    360., 57.145}, {363.305, 46.863}, {373.402, 50.688}, {
                    367.42999999999995`, 41.69500000000001}, {376.715, 
                    36.184}, {365.957, 35.25}, {367.43799999999993`, 
                    24.555}, {360., 32.379}, {352.562, 24.555}, {354.043, 
                    35.25}, {343.28499999999997`, 36.184}, {352.57, 
                    41.69500000000001}, {346.59799999999996`, 50.688}, {
                    356.695, 46.863}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{360.,
                     217.14499999999998`}, {363.305, 206.863}, {373.402, 
                    210.68800000000002`}, {367.42999999999995`, 201.695}, {
                    376.715, 196.184}, {365.957, 195.25}, {
                    367.43799999999993`, 184.555}, {360., 192.379}, {352.562, 
                    184.555}, {354.043, 195.25}, {343.28499999999997`, 
                    196.184}, {352.57, 201.695}, {346.59799999999996`, 
                    210.68800000000002`}, {356.695, 206.863}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{300.,
                     152.14499999999998`}, {303.305, 141.863}, {313.402, 
                    145.68800000000002`}, {307.42999999999995`, 136.695}, {
                    316.715, 131.184}, {305.957, 130.25}, {
                    307.43799999999993`, 119.55499999999999`}, {300., 
                    127.37899999999999`}, {292.562, 119.55499999999999`}, {
                    294.043, 130.25}, {283.28499999999997`, 131.184}, {292.57,
                     136.695}, {286.59799999999996`, 145.68800000000002`}, {
                    296.695, 141.863}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    413.332, 168.14499999999998`}, {416.641, 157.863}, {
                    426.734, 161.68800000000002`}, {420.762, 152.695}, {
                    430.047, 147.184}, {419.29299999999995`, 146.25}, {
                    420.77299999999997`, 135.555}, {413.332, 143.379}, {
                    405.895, 135.555}, {407.375, 146.25}, {396.621, 
                    147.184}, {405.902, 152.695}, {399.92999999999995`, 
                    161.68800000000002`}, {410.027, 157.863}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{384., 120.}, {386.613, 113.59400000000001`}, {
                    393.512, 113.09}, {388.227, 108.62499999999999`}, {
                    389.879, 101.91000000000001`}, {384., 
                    105.55499999999999`}, {378.121, 101.91000000000001`}, {
                    379.77299999999997`, 108.62499999999999`}, {
                    374.48799999999994`, 113.09}, {381.387, 
                    113.59400000000001`}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJ/IGZigIE8BzDlkOpw52dd1p6eLDgfTB9Id1Bla5zq
XJwE50P0xcH52z7/vVIhGY6qvyHQAcV8IF/dkGONzLx8VPmuAoj5h4McHi+d
fURBotDhPwgcD3EQbj5waiFvocPrwB1yrZtDHIDk60CWQofijIlva6aHOChs
KMqY+LPAAcS1bw1xuFrxUs3wUoHDjDyh5gNOIQ6TJVjC+FYWODy7oHT7J1+I
wzFv807HugIHkDKON8EOIG5CcIGDtP5dFbaTwQ5VIuvcH6oVOICs2bEt2KEa
xP+UD+eD3TsDwY/b5cnDZJ8P1w8272Ue3PxQPt1Ncyfnwe0Hyzvmwd239UTZ
vvmfcuHul41Ksb6/OBfuf7D6yFyIPdKhDv2HvmrECOc61Nqbxu2qDIXoO5vj
0DsdaOCNUIcJIPnuHKj5YQ5WW4AW+OdA1O8Mg/hfJAfiXsNwh70lwBC6l+1w
GxRvW8Ih7lmXDZF3jICYV5/tsMgVGMNnIiDhE5bt4NKd8/x3YqQDSFmjaTYk
Pv5HQs2Hqp8T5fCuBmjxryxI+nCMdtg3X0r/7ossiPybaIh/rmdB9M2IceC6
vrjA9lwWhPaKhfNh6Q3G/6YR039oaxxcvyXIn+nxcPPB7uJMgNsPTl/xCXD3
geU3JsDdfxwkzpAI9x84vP0T4f4Hq5uZCA8fsH/vJ8LDTwiUTlWT4OFbBJJP
T4KHv1PC0wtKi5Pg8QM2514SPP7A7hdOhscvWL1zMjz+LwKTT11RMjx9gINj
TjI8/fiA1O1NhqcviPnJ8PQHTh8/kuHpcw/I3Vwp8PQL9o90Cjx9F9gCQ1ol
BZ7+YXxY/oDxYfkHph+Wv2Dmw/IfzH5Y/oS5D5Z/Ye6H5W+wOVuS4fkfHO/L
kuHlA8z/sPLjLSie56Wgli+w8gupfAMAErP+jA==
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[0., 0.501961, 0.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {CompressedData["

1:eJxdVwlsFGUUhspVJA1qQQUUVAS8KCagBSR9oFJ67uwxu7M7uwWZ+eeoFEtB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                    "], {{100., 176.39100000000002`}, {101.812, 176.695}, {
                    100.039, 173.637}, {99.16799999999999, 173.68}, {99.242, 
                    174.781}, {96.543, 174.676}, {98.21900000000001, 
                    175.63299999999998`}, {98.762, 175.984}, {99.367, 
                    176.25}, {100., 176.39100000000002`}}}]}}}}}}}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 480.}, {0., 241.}}], ",", 
           GraphicsBox[{{{
               {Thickness[0.0010416666666666667`], {{{
                   {Thickness[0.0010416666666666667`], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     480.}, {960., 480.}, {960., 320.}, {0., 
                    320.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     320.}, {960., 320.}, {960., 160.}, {0., 
                    160.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[0., 0.478431, 0.23921600000000004`], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     160.}, {960., 160.}, {960., 0.}, {0., 0.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.8078430000000001, 0.06666670000000002, 0.14902], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{0., 480.}, {
                    320., 240.}, {0., 0.}}}]}}}}}}}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 960.}, {0., 480.}}], ",", 
           GraphicsBox[{{{
               {Thickness[0.0010416666666666667`], {{{
                   {Thickness[0.0010416666666666667`], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     480.}, {960., 480.}, {960., 320.}, {0., 
                    320.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     320.}, {960., 320.}, {960., 160.}, {0., 
                    160.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[0., 0.478431, 0.23921600000000004`], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     160.}, {960., 160.}, {960., 0.}, {0., 0.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.8078430000000001, 0.06666670000000002, 0.14902], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{0., 480.}, {
                    320., 240.}, {0., 0.}}}]}}}}}}}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 960.}, {0., 480.}}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           GraphicsBox[{{{
               {Thickness[0.0010416666666666667`], {{{
                   {FaceForm[{RGBColor[0.8509800000000001, 0., 0.0705882], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 480.}, {960., 480.}, {960., 0.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[0., 0.2, 0.627451], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     320.}, {960., 320.}, {960., 160.}, {0., 
                    160.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.9490200000000001, 0.6588240000000001, 0.], Opacity[
                    1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{0., 160.}, {960., 160.}, {960., 0.}, {0., 
                    0.}}}]}}}}}}}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 960.}, {0., 480.}}], ",", 
           GraphicsBox[{{{{
                {Thickness[0.0008333333333333334], 
                 {FaceForm[{RGBColor[0.870588, 0.160784, 0.06274510000000001],
                   Opacity[1.]}], 
                  FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0., 
                   0.}, {0., 800.}, {1200., 800.}, {1200., 0.}}}]}}}}}, {{{
                {RGBColor[1., 0.870588, 0.], 
                 PolygonBox[{{{156.4073211147477, 585.837018249545}, {129.465,
                    502.91799999999995`}, {200., 554.1649280840463}, {
                   270.53499999999997`, 502.91799999999995`}, {
                   243.5926788852523, 585.837018249545}, {243.59267888525227`,
                    585.837018249545}, {314.125, 637.082}, {
                   226.94199026174442`, 637.082}, {226.9419902617444, 
                   637.082}, {200., 720.}, {173.0580097382556, 637.082}, {
                   85.87499999999999, 637.082}}, {{365.699, 
                   699.4219999999999}, {394.02059683525385`, 
                   705.9407992661736}, {408.97299999999996`, 681.02}, {
                   411.5242212411751, 709.96961920159}, {439.84400000000005`, 
                   716.488}, {413.10086862161455`, 727.8604005035999}, {
                   415.65200000000004`, 756.809}, {396.57181807195605`, 
                   734.8893074829407}, {369.828, 746.262}, {384.7797301874549,
                    721.3423223683757}}, {{440.402, 634.3439999999999}, {
                   469.0343335503074, 629.361789846223}, {473.14500000000004`,
                    600.594}, {486.7292087861558, 626.2827677708841}, {
                   486.7292087861558, 626.2827677708842}, {515.3589999999999, 
                   621.3009999999999}, {495.1246145642034, 
                   642.1591160197714}, {508.71099999999996`, 
                   667.8519999999999}, {482.6172094551196, 
                   655.0520653855589}, {462.383, 675.91}, {466.4935753121953, 
                   647.1428479638266}}, {{465.6480604418864, 
                   514.7602115466024}, {457.66400000000004`, 486.816}, {
                   480.5486352299245, 504.73064709811763`}, {504.656, 
                   488.504}, {494.6909275247808, 515.8015762641411}, {
                   517.5740000000001, 533.715}, {488.53181121238066`, 
                   532.6734000943798}, {478.566, 559.9730000000001}, {
                   470.58218157485607`, 532.0296355119963}, {441.539, 
                   530.988}}, {{366.582, 418.01599999999996`}, {
                   394.60952440391605`, 425.7048046163738}, {
                   394.60952440391605`, 425.70480461637374`}, {410.582, 
                   401.42599999999993`}, {411.9307747145386, 
                   430.4565517714337}, {411.9307747145386, 
                   430.45655177143374`}, {439.957, 438.14500000000004`}, {
                   412.7643509911082, 448.3981538726199}, {414.113, 
                   477.42599999999993`}, {395.95886570694836`, 
                   454.73476442005847`}, {368.76599999999996`, 
                   464.98799999999994`}, {384.7381266235573, 
                   440.70972583588684`}}}]}}}}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 1200.}, {0., 800.}}], ",", 
           GraphicsBox[{{{
               {Thickness[0.001388888888888889], {{{
                   {FaceForm[{RGBColor[
                    0.870588, 0.160784, 0.06274510000000001], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 480.}, {720., 480.}, {720., 0.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{359.97299999999996`, 240.07}, {275.762, 
                    275.66}, {313.09, 385.33599999999996`}, {393.625, 
                    379.82}, {377.33599999999996`, 371.449}, {
                    374.97299999999996`, 355.824}, {384.277, 
                    341.35200000000003`}, {394.695, 325.14500000000004`}, {
                    383.316, 299.07}, {369.234, 292.734}, {
                    346.08599999999996`, 282.316}, {341.449, 254.535}, {
                    359.97299999999996`, 240.07}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.870588, 0.160784, 0.06274510000000001], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{355.41799999999995`, 319.26599999999996`}, {
                    350.684, 311.828}, {348.965, 320.47999999999996`}, {
                    340.42199999999997`, 322.688}, {348.125, 327.}, {
                    347.58599999999996`, 335.801}, {354.055, 329.809}, {
                    362.258, 333.043}, {358.57, 325.03499999999997`}, {
                    364.172, 318.22999999999996`}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{360.449, 240.99200000000002`}, {
                    350.262, 246.21899999999997`}, {342.051, 257.117}, {
                    338.47299999999996`, 270.137}, {334.383, 285.074}, {
                    336.734, 301.133}, {344.941, 314.168}, {343.172, 
                    315.28099999999995`}, {334.66, 301.73799999999994`}, {
                    332.219, 285.09}, {336.465, 269.58599999999996`}, {
                    340.246, 255.809}, {348.637, 244.71099999999998`}, {
                    359.4959999999999, 239.137}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{360.059, 240.047}, {367.883, 331.137}, {483.727, 
                    329.52299999999997`}, {503.371, 251.227}, {490.371, 
                    264.133}, {474.78099999999995`, 261.551}, {
                    463.89099999999996`, 248.23}, {451.699, 233.312}, {
                    423.387, 236.078}, {413.008, 247.516}, {395.945, 
                    266.312}, {368.094, 262.133}, {360.059, 
                    240.047}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.870588, 0.160784, 0.06274510000000001], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{433.969, 268.85200000000003`}, {
                    425.43399999999997`, 271.059}, {433.133, 275.363}, {
                    432.59, 284.172}, {439.07, 278.18}, {447.27299999999997`, 
                    281.40999999999997`}, {443.574, 273.40599999999995`}, {
                    449.188, 266.60200000000003`}, {440.42999999999995`, 
                    267.637}, {435.691, 260.207}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{361.082, 239.879}, {
                    362.90599999999995`, 251.184}, {370.72999999999996`, 
                    262.35900000000004`}, {382.012, 269.78499999999997`}, {
                    394.949, 278.29299999999995`}, {410.949, 
                    281.01599999999996`}, {425.883, 277.242}, {
                    426.39799999999997`, 279.26599999999996`}, {410.887, 
                    283.176}, {394.29699999999997`, 280.355}, {380.867, 
                    271.527}, {368.93399999999997`, 263.672}, {360.969, 
                    252.262}, {359.02299999999997`, 
                    240.21499999999997`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{360.062, 239.961}, {449.10900000000004`, 
                    260.668}, {483.375, 149.996}, {414.97999999999996`, 
                    107.117}, {423.23799999999994`, 123.46900000000001`}, {
                    415.965, 137.496}, {399.92999999999995`, 143.738}, {
                    381.977, 150.72299999999998`}, {375.855, 178.504}, {
                    383.527, 191.91}, {396.129, 213.945}, {383.551, 
                    239.14499999999998`}, {360.062, 239.961}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.870588, 0.160784, 0.06274510000000001], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{410.29699999999997`, 178.566}, {409.758, 
                    187.36700000000002`}, {416.22999999999996`, 181.375}, {
                    424.441, 184.60899999999998`}, {420.746, 176.598}, {
                    426.35200000000003`, 169.79299999999998`}, {
                    417.59799999999996`, 170.84}, {412.85900000000004`, 
                    163.39800000000002`}, {411.137, 172.047}, {402.605, 
                    174.258}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{360.22299999999996`, 238.934}, {
                    371.53499999999997`, 240.691}, {384.582, 
                    236.70299999999997`}, {395.129, 228.26999999999998`}, {
                    407.219, 218.594}, {414.754, 204.21899999999997`}, {
                    415.777, 188.848}, {417.863, 188.984}, {416.789, 
                    204.945}, {408.977, 219.85200000000003`}, {
                    396.43399999999997`, 229.89800000000002`}, {
                    385.27299999999997`, 238.82000000000002`}, {
                    371.96099999999996`, 242.871}, {359.902, 
                    240.996}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{359.984, 239.92600000000002`}, {407.191, 
                    161.637}, {312.527, 94.848}, {250.60899999999998`, 
                    146.648}, {268.715, 143.844}, {279.809, 155.098}, {
                    280.789, 172.277}, {281.883, 191.512}, {306.414, 
                    205.918}, {321.53499999999997`, 202.762}, {346.387, 
                    197.586}, {366.465, 217.336}, {359.984, 
                    239.92600000000002`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.870588, 0.160784, 0.06274510000000001], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{317.117, 173.18}, {325.32, 176.41}, {321.621, 
                    168.40200000000002`}, {327.234, 161.598}, {
                    318.47299999999996`, 162.637}, {313.734, 
                    155.19899999999998`}, {312.02299999999997`, 163.848}, {
                    303.484, 166.055}, {311.176, 170.36700000000002`}, {
                    310.641, 179.164}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{359.055, 239.461}, {
                    364.22299999999996`, 229.24599999999998`}, {
                    364.46099999999996`, 215.602}, {359.699, 202.965}, {
                    354.22999999999996`, 188.477}, {342.89099999999996`, 
                    176.86700000000002`}, {328.59, 171.14499999999998`}, {
                    329.363, 169.20299999999997`}, {344.21099999999996`, 
                    175.156}, {355.97299999999996`, 187.191}, {361.648, 
                    202.23}, {366.688, 215.598}, {366.42599999999993`, 
                    229.512}, {360.91799999999995`, 
                    240.40200000000002`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{359.92599999999993`, 239.99200000000002`}, {
                    300.055, 170.90200000000002`}, {207.281, 240.297}, {
                    237.414, 315.188}, {240.34, 297.105}, {
                    254.47299999999998`, 290.03099999999995`}, {271.113, 
                    294.40599999999995`}, {289.746, 299.309}, {311.027, 
                    280.42999999999995`}, {312.699, 265.078}, {315.453, 
                    239.844}, {340.445, 226.85200000000003`}, {
                    359.92599999999993`, 239.99200000000002`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.870588, 0.160784, 0.06274510000000001], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{283.199, 260.137}, {288.809, 253.336}, {280.047, 
                    254.375}, {275.309, 246.934}, {273.59, 255.59}, {265.055, 
                    257.79699999999997`}, {272.75, 262.09799999999996`}, {
                    272.21099999999996`, 270.89799999999997`}, {278.688, 
                    264.91799999999995`}, {286.887, 268.141}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{359.195, 240.73399999999998`}, {
                    351.074, 232.66}, {338.176, 228.21899999999997`}, {
                    324.684, 228.84}, {309.215, 229.562}, {294.672, 
                    236.766}, {284.809, 248.598}, {283.203, 247.262}, {
                    293.453, 234.98000000000002`}, {308.53499999999997`, 
                    227.512}, {324.58599999999996`, 226.762}, {
                    338.85900000000004`, 226.098}, {352.008, 230.648}, {
                    360.66400000000004`, 239.254}}}]}}}}}}}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 720.}, {0., 480.}}], ",", 
           GraphicsBox[{{{
               {Thickness[0.001388888888888889], {{{
                   {FaceForm[{RGBColor[0.996078, 0., 0.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 480.}, {720., 480.}, {720., 0.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[0., 0., 0.5843139999999999], Opacity[
                    1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{0., 480.}, {360., 480.}, {360., 240.}, {0., 
                    240.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}}}, {{{204., 360.}, {180., 
                    270.}, {156., 360.}, {180., 450.}}, {{180., 336.}, {270., 
                    360.}, {180., 384.}, {90., 360.}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}}}, {{{200.785, 348.}, {135., 
                    282.059}, {159.21499999999997`, 372.}, {225., 
                    437.941}}, {{168., 339.215}, {257.941, 315.}, {192., 
                    380.78499999999997`}, {102.059, 405.}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}}}, {{{192., 339.215}, {102.059, 
                    315.}, {168., 380.78499999999997`}, {257.941, 405.}}, {{
                    159.21499999999997`, 348.}, {225., 282.059}, {200.785, 
                    372.}, {135., 437.941}}}]}}}}, {{{
                   {FaceForm[{RGBColor[0., 0., 0.5843139999999999], Opacity[
                    1.]}], FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {
                    1, 3, 3}}}, {{{231., 360.}, {231., 331.832}, {208.168, 
                    309.}, {180., 309.}, {151.83200000000002`, 309.}, {129., 
                    331.832}, {129., 360.}, {129., 388.168}, {
                    151.83200000000002`, 411.}, {180., 411.}, {208.168, 
                    411.}, {231., 388.168}, {231., 360.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{225., 360.}, {225., 335.148}, {
                    204.85200000000003`, 315.}, {180., 315.}, {155.148, 
                    315.}, {135., 335.148}, {135., 360.}, {135., 
                    384.85200000000003`}, {155.148, 405.}, {180., 405.}, {
                    204.85200000000003`, 405.}, {225., 384.85200000000003`}, {
                    225., 360.}}}]}}}}}}}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 720.}, {0., 480.}}], ",", 
           GraphicsBox[{{{
               {Thickness[0.001388888888888889], {{{
                   {FaceForm[{RGBColor[
                    0.9372550000000001, 0.698039, 0.17647100000000002`], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 480.}, {720., 480.}, {720., 0.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.886275, 0.23921600000000004`, 0.15686300000000003`], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{0., 0.}, {
                    720., 0.}, {720., 480.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{385.395, 
                    329.92999999999995`}, {381.402, 331.34400000000005`}, {
                    378.828, 329.28499999999997`}, {378.957, 324.133}, {
                    379.082, 318.97999999999996`}, {381.789, 316.02}, {
                    385.78099999999995`, 317.953}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{385.395, 
                    329.93}, {381.402, 331.344}, {378.828, 329.285}, {378.957,
                     324.133}, {379.082, 318.98}, {381.789, 316.02}, {
                    385.78099999999995`, 317.953}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    388.89799999999997`, 339.574}, {385.578, 342.199}, {
                    382.477, 341.074}, {380.941, 336.15200000000004`}, {
                    379.40999999999997`, 331.234}, {381.02, 327.562}, {
                    385.41799999999995`, 328.10900000000004`}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    388.89799999999997`, 339.57399999999996`}, {385.578, 
                    342.19899999999996`}, {382.477, 341.07399999999996`}, {
                    380.941, 336.152}, {379.40999999999997`, 
                    331.23400000000004`}, {381.02, 327.562}, {
                    385.41799999999995`, 328.109}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    394.42999999999995`, 348.914}, {391.566, 
                    352.03499999999997`}, {388.328, 351.42199999999997`}, {
                    386.02299999999997`, 346.812}, {383.72299999999996`, 
                    342.203}, {384.72299999999996`, 338.32}, {389.156, 
                    338.15200000000004`}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    394.42999999999995`, 348.914}, {391.566, 
                    352.03499999999997`}, {388.328, 351.422}, {
                    386.02299999999997`, 346.812}, {383.72299999999996`, 
                    342.203}, {384.72299999999996`, 338.32}, {389.156, 
                    338.152}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{390.805, 
                    303.527}, {385.90999999999997`, 301.727}, {385.395, 
                    295.027}, {388.48799999999994`, 290.90599999999995`}, {
                    391.578, 286.78499999999997`}, {397.242, 286.012}, {
                    400.332, 290.90599999999995`}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{390.805, 
                    303.52700000000004`}, {385.90999999999997`, 
                    301.72700000000003`}, {385.395, 295.02700000000004`}, {
                    388.48799999999994`, 290.906}, {391.578, 286.785}, {
                    397.242, 286.01199999999994`}, {400.332, 290.906}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{385.137, 317.695}, {380.5, 
                    319.23799999999994`}, {376.324, 313.012}, {375.605, 
                    307.39099999999996`}, {374.707, 300.309}, {364.66, 
                    297.99199999999996`}, {370.199, 287.301}, {371.355, 
                    294.125}, {375.867, 297.85900000000004`}, {379.469, 
                    298.117}, {383.078, 298.375}, {388.48799999999994`, 
                    299.148}, {390.805, 303.527}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{385.137, 317.695}, {380.5, 319.238}, {376.324, 
                    313.01199999999994`}, {375.605, 307.391}, {374.707, 
                    300.30899999999997`}, {364.66, 297.99199999999996`}, {
                    370.199, 287.30100000000004`}, {371.355, 294.125}, {
                    375.867, 297.85900000000004`}, {379.469, 
                    298.11699999999996`}, {383.078, 298.375}, {
                    388.48799999999994`, 299.14799999999997`}, {390.805, 
                    303.52700000000004`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{399.82, 
                    290.133}, {394.40999999999997`, 288.848}, {393.637, 
                    281.633}, {397.5, 276.484}, {400.805, 272.074}, {411.148, 
                    273.137}, {410.895, 277.512}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{399.82, 
                    290.133}, {394.40999999999997`, 288.84799999999996`}, {
                    393.637, 281.633}, {397.5, 276.48400000000004`}, {400.805,
                     272.07399999999996`}, {411.148, 273.137}, {410.895, 
                    277.51199999999994`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{415.14500000000004`, 
                    246.73399999999998`}, {415.39799999999997`, 251.371}, {
                    407.93399999999997`, 253.172}, {404.328, 
                    252.27299999999997`}, {400.719, 251.371}, {393.828, 
                    252.40200000000002`}, {392.219, 256.26599999999996`}, {
                    390.93399999999997`, 253.172}, {392.801, 249.824}, {
                    398.01599999999996`, 248.15200000000002`}, {401.965, 
                    246.883}, {401.879, 244.031}, {400.719, 242.742}, {
                    403.684, 242.227}, {412.441, 242.227}, {
                    415.14500000000004`, 246.73399999999998`}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{415.14500000000004`, 246.734}, {
                    415.39799999999997`, 251.371}, {407.93399999999997`, 
                    253.17199999999997`}, {404.328, 252.273}, {400.719, 
                    251.371}, {393.828, 252.402}, {392.219, 256.266}, {
                    390.93399999999997`, 253.17199999999997`}, {392.801, 
                    249.824}, {398.01599999999996`, 248.152}, {401.965, 
                    246.883}, {401.879, 244.031}, {400.719, 242.742}, {
                    403.684, 242.22700000000003`}, {412.441, 
                    242.22700000000003`}, {415.14500000000004`, 246.734}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{410.895, 276.355}, {405.613, 278.672}, {402.484, 
                    275.141}, {400.465, 271.719}, {397.5, 266.695}, {388.355, 
                    273.137}, {385.26599999999996`, 266.43799999999993`}, {
                    389.453, 268.242}, {393.715, 264.395}, {395.695, 
                    263.09}, {401.363, 259.355}, {412.309, 
                    260.51599999999996`}, {413.855, 
                    269.27299999999997`}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{410.895, 276.355}, {405.613, 
                    278.67199999999997`}, {402.484, 275.14099999999996`}, {
                    400.465, 271.719}, {397.5, 266.695}, {388.355, 273.137}, {
                    385.26599999999996`, 266.438}, {389.453, 
                    268.24199999999996`}, {393.715, 264.395}, {395.695, 
                    263.09000000000003`}, {401.363, 259.355}, {412.309, 
                    260.51599999999996`}, {413.855, 269.273}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    413.984, 270.172}, {408.703, 266.18}, {
                    406.64500000000004`, 261.414}, {406.77299999999997`, 
                    258.195}, {406.902, 254.977}, {411.40999999999997`, 
                    247.895}, {416.305, 247.508}, {419.137, 
                    253.30100000000002`}, {420.555, 265.53499999999997`}, {
                    413.984, 270.172}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    413.984, 270.17199999999997`}, {408.703, 
                    266.17999999999995`}, {406.64500000000004`, 261.414}, {
                    406.77299999999997`, 258.195}, {406.902, 254.977}, {
                    411.40999999999997`, 247.895}, {416.305, 
                    247.50799999999998`}, {419.137, 253.30100000000002`}, {
                    420.555, 265.53499999999997`}, {413.984, 
                    270.17199999999997`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{392.094, 
                    245.316}, {392.094, 247.25}, {394.92599999999993`, 
                    248.023}, {396.855, 247.379}, {398.789, 
                    246.73399999999998`}, {401.75, 244.805}, {400.719, 
                    242.742}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{392.094, 
                    245.316}, {392.094, 247.25}, {394.92599999999993`, 
                    248.023}, {396.855, 247.379}, {398.789, 246.734}, {401.75,
                     244.805}, {400.719, 242.742}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    362.98799999999994`, 255.879}, {362.47299999999996`, 
                    258.195}, {366.207, 262.188}, {371.22999999999996`, 
                    260.}, {376.25, 257.809}, {376.895, 253.559}, {374.832, 
                    251.88700000000003`}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    362.98799999999994`, 255.879}, {362.47299999999996`, 
                    258.195}, {366.207, 262.188}, {371.22999999999996`, 
                    260.}, {376.25, 257.80899999999997`}, {376.895, 
                    253.559}, {374.832, 251.88700000000003`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{375.219, 
                    251.629}, {374.832, 252.918}, {378.449, 
                    255.48800000000003`}, {384.621, 253.945}, {390.805, 
                    252.40200000000002`}, {392.32, 248.42200000000003`}, {
                    392.094, 245.316}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{375.219, 
                    251.629}, {374.832, 252.91799999999998`}, {378.449, 
                    255.488}, {384.621, 253.945}, {390.805, 252.402}, {392.32,
                     248.422}, {392.094, 245.316}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{362.34400000000005`, 255.879}, {
                    365.562, 258.324}, {364.34400000000005`, 
                    262.96099999999996`}, {361.441, 264.379}, {356.16, 
                    266.953}, {358.094, 273.648}, {354.742, 
                    274.93799999999993`}, {351.395, 276.227}, {348.176, 
                    278.543}, {348.047, 280.863}, {346.371, 
                    277.64500000000004`}, {347.402, 274.68}, {
                    349.72299999999996`, 272.621}, {352.039, 270.559}, {
                    347.91799999999995`, 262.188}, {350.879, 
                    260.}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{362.34400000000005`, 255.879}, {
                    365.562, 258.324}, {364.34400000000005`, 262.961}, {
                    361.441, 264.379}, {356.16, 266.953}, {358.094, 
                    273.64799999999997`}, {354.742, 274.938}, {351.395, 
                    276.22700000000003`}, {348.176, 278.543}, {348.047, 
                    280.863}, {346.371, 277.645}, {347.402, 
                    274.67999999999995`}, {349.72299999999996`, 272.621}, {
                    352.039, 270.55899999999997`}, {347.91799999999995`, 
                    262.188}, {350.879, 260.}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{293.316, 
                    257.68}, {290.60900000000004`, 261.92999999999995`}, {
                    284.172, 261.16}, {281.469, 258.195}, {278.762, 
                    255.23399999999998`}, {279.148, 250.85500000000002`}, {
                    281.72299999999996`, 248.92600000000002`}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{293.316, 
                    257.67999999999995`}, {290.60900000000004`, 261.93}, {
                    284.172, 261.15999999999997`}, {281.469, 258.195}, {
                    278.762, 255.234}, {279.148, 250.85500000000002`}, {
                    281.72299999999996`, 248.92600000000002`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{308.77, 
                    263.99199999999996`}, {307.73799999999994`, 269.656}, {
                    300.914, 270.301}, {297.18, 268.887}, {293.445, 
                    267.469}, {290.867, 261.801}, {293.316, 257.68}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{308.77, 
                    263.99199999999996`}, {307.73799999999994`, 269.656}, {
                    300.914, 270.30100000000004`}, {297.18, 
                    268.88700000000006`}, {293.445, 267.469}, {290.867, 
                    261.80100000000004`}, {293.316, 257.67999999999995`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{319.07, 264.76599999999996`}, {321.52, 
                    269.527}, {316.754, 276.613}, {311.34400000000005`, 
                    277.64500000000004`}, {306.828, 278.5}, {
                    301.49199999999996`, 278.47999999999996`}, {299.754, 
                    282.92199999999997`}, {298.66, 279.059}, {301.559, 
                    276.613}, {304.90599999999995`, 274.42199999999997`}, {
                    308.254, 272.234}, {304.262, 266.566}, {309.672, 
                    263.348}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{319.07, 264.766}, {321.52, 
                    269.52700000000004`}, {316.754, 276.61299999999994`}, {
                    311.34400000000005`, 277.645}, {306.828, 278.5}, {
                    301.49199999999996`, 278.48}, {299.754, 282.922}, {298.66,
                     279.05899999999997`}, {301.559, 276.61299999999994`}, {
                    304.90599999999995`, 274.422}, {308.254, 
                    272.23400000000004`}, {304.262, 266.56600000000003`}, {
                    309.672, 263.34799999999996`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{318.555, 
                    264.60200000000003`}, {317.42999999999995`, 268.012}, {
                    319.715, 272.555}, {324.34400000000005`, 
                    272.23799999999994`}, {328.969, 271.91799999999995`}, {
                    331.605, 268.555}, {329.566, 
                    264.35200000000003`}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{318.555, 
                    264.602}, {317.42999999999995`, 268.01199999999994`}, {
                    319.715, 272.555}, {324.34400000000005`, 272.238}, {
                    328.969, 271.918}, {331.605, 268.555}, {329.566, 
                    264.352}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    328.85900000000004`, 264.34400000000005`}, {
                    328.22299999999996`, 267.879}, {331.121, 272.055}, {
                    335.66, 271.09}, {340.195, 270.125}, {342.332, 
                    266.42599999999993`}, {339.727, 262.551}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    328.85900000000004`, 264.344}, {328.22299999999996`, 
                    267.879}, {331.121, 272.055}, {335.66, 
                    271.09000000000003`}, {340.195, 270.125}, {342.332, 
                    266.42600000000004`}, {339.727, 262.55100000000004`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    339.08599999999996`, 262.719}, {338.625, 
                    266.28099999999995`}, {341.734, 270.309}, {346.215, 
                    269.117}, {350.699, 267.92999999999995`}, {352.648, 
                    264.125}, {349.85200000000003`, 260.387}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    339.08599999999996`, 262.719}, {338.625, 
                    266.28100000000006`}, {341.734, 270.30899999999997`}, {
                    346.215, 269.11699999999996`}, {350.699, 267.93}, {
                    352.648, 264.125}, {349.85200000000003`, 
                    260.38700000000006`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{261.375, 
                    203.72299999999998`}, {252.75, 203.72299999999998`}, {
                    250.641, 201.668}, {249.39800000000002`, 
                    192.77299999999997`}, {247.85500000000002`, 
                    181.69899999999998`}, {262.92199999999997`, 180.41}, {
                    261.375, 203.72299999999998`}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{261.375, 
                    203.723}, {252.75, 203.723}, {250.641, 201.668}, {
                    249.39800000000002`, 192.77300000000002`}, {
                    247.85500000000002`, 181.699}, {262.92199999999997`, 
                    180.41000000000003`}, {261.375, 203.723}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    265.242, 215.312}, {251.977, 220.336}, {244.766, 
                    199.344}, {231.629, 203.078}, {236.32800000000003`, 
                    195.60899999999998`}, {247.72299999999998`, 203.062}, {
                    251.977, 202.305}, {259.188, 201.016}, {274.77, 
                    203.72299999999998`}, {265.242, 215.312}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    265.242, 215.312}, {251.977, 220.33599999999996`}, {
                    244.766, 199.344}, {231.629, 203.07800000000003`}, {
                    236.32800000000003`, 195.60900000000004`}, {
                    247.72299999999998`, 203.06200000000007`}, {251.977, 
                    202.305}, {259.188, 201.01600000000002`}, {274.77, 
                    203.723}, {265.242, 215.312}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{256.613, 
                    186.594}, {250.04299999999998`, 189.555}, {242.961, 
                    179.512}, {244.25, 175.13299999999998`}, {245.883, 
                    169.57}, {260.863, 174.102}, {256.613, 186.594}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{256.613, 
                    186.59400000000005`}, {250.04299999999998`, 189.555}, {
                    242.961, 179.51200000000006`}, {244.25, 
                    175.13299999999998`}, {245.883, 169.57000000000005`}, {
                    260.863, 174.10200000000003`}, {256.613, 
                    186.59400000000005`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxlVGlIVFEUniwqF2pS2y1arIwQkwhR0U5URGU12aAzzvbefbOmY2ISpmaI
rahZZAuUie2E9MNKSsxKBlFplUJFzGwTNQmVLIuod+cbJqiBx51z37nf+c73
nfsWst2JlvEKhWKc/GyXHx/5OZceWPgoPo382y5nxPWLtCxyclVIdRptiTq2
VmgWyY/vxzuptOFrmP6ISBFdoRMLljipvmJORNcNgR7yNcBJnWP5u+rKTFRy
Vga0p9K6orTen756SuA4gw7st+uAl2mnjy8WdY5d03nq2mgbU2qigzWUESdn
XLFSdfmX641BWpLZtVS+tiH/8N/484578w/F6pHvstP+NauNtdMMlGk/OZg3
004rOc8SA/jV2Ygf25CfQoN5cuIbqzeOudO0t/63xRu78cosVDPy61X2/WTE
B81kqN0U4DPgibMkmn5rY09OiIYU/KeRwL9YTSEp5tjuKJF6coJvbSxQUxXf
iDAh3qemuVzA5ToK5uerVPQg69SsCTVaUr+/et6lSqTRMH1pQ5ceeK5E6LDY
iLVQTW6/fATUzUiCX4dFrz5GzjNWgh+hGjrBfXsuoX5PCvLnS/BhWEu87AIV
o0/8fL72Pzx3v0cF6HFSS5Ub5H8fjOjLlASeVXr43ZyMfkYNtGRiwel1I8l4
/8STf0CD/SAB+X1azIVLgF8GHeo1iYidHr5nGHTr01HSlPDq8jaJWjndGCP8
GzBTdt/SyMkJevS9wIp5iDRhvlosdGRGx7NvhSa8V1roJT+/2UTR/LxkJj42
a04biYcVNRJwuw3Qp53BH6UJugUyb3233isY3Rxq3cqUAvr5LgHfz0SXuF6z
LMAPF+guxzda4WO/QMd5fpoNutwW0G+6HfsXBMzzJBvwLgrwM9cKnGER811s
pmSuS6mIOncl8DB77quvBH73GOqsYrSUr/4M9zyaoY8iRuu5L7MlrEMMeinM
uDd7GfTvNYP/DxF+rbeAzzsG3aba6NCAfEEfi7j/T20UxC/YJpFy+RgGOrz1
3fq8ddAeTrzI871pdJDs1s73HSLqq/7mu/1ptOOcgqHfeQ7Pd8vDb0sq8M4z
+vf79gfoVTIT
                    "]]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxlVGlIVGEUnSzalDKLsjJps4wQk4gyKU+kRWk1meiMs733vVnVMYmISrFC
s0JbJK2gjfZ+DP0wExNbGcSijSiyxbIFSs2ipJ2od98dRqiBx5v7vbuce869
3wSxOsPRV6fT9VGfFeoToj4HCiJKr87Px+BHJwrndcqYmjDQF1Wbj/TZOxZI
N2Q+n+/FnutfYs3bZMS3Te6/JcaLq0fHxLedlXCF3mFePPtRkttUbcPO/WpC
dx5Qkf/21yAz5+n2oJLOW02cb40b7+5NfPrjtAmhWl0X0kW4IXGEAYXzVI+T
TtQd/nimebgRKrqbxx662L+8136/siF6a5KZ/f1ubE6eZW0cZsEad1V38Sg3
ZhDOnRbG1+RCmRqWWpKD7mLV8bkzaM+ta1l3+Y8jaGv5qh2o6/n9YP3FbLbL
7JAal4SFdAXstQpGnFv8cmOUATr6GRTGX5mJqBx70ovZMt5sVD22ZMJHB/E2
tJO9IRNjicBpJo736XFp7d7IfvVGGF6fOujXZ+BrrHn39TYz9JTPn4Fa4mGS
lfkozYSmV4jEdQuzWK9yOciPlXAmKWgnPSYbWLe7CuN5mcP+0QrCiPfPRlDZ
8XrB8SXG//Jp/W6X0EB8VBlxLLW+5/cbK/dly8Jywukzs943srmfrxao7Ncs
7Mnm77cC/psMiKHz4RL7dxh5XvwS62Uxcb0WmW1vAO8+gUjircOErCFxtYcf
KXhAcOdaWb8uO9Z3TEkYmG7GU+p7vJPnIcHG83XTgcqRj+98K7Xx93AHxy+1
IZHiFTtobJJrVJ5V82i9gjn054WF+WkVrE+4jec3QgTra3xPF/B9ur9MhEvc
z/cAvsE2HCe+Ih3IpfxxEi5QfqsT+0jHTgm7yD/fhSnEy3mJ+y1w874cknie
B7igyXNEYj2LnKinPJ9lnu9KO/OyW+Y+Ligcbw/s6yCF8TUI5n+mYH1CBdJo
PxMF91EhkEK6jFawiN6fBPOls+MD7c06wXXe2hn/T5n1SnEwnleC9RjqQnmX
uqDXZN7/2y7e2yUyimgMIzzB+ho/7R7usyJw3zR78OTOt1WvH8tcX9/rr+nT
7OY4neB+x3kQq91bAXxpeZzvoMC/99tff9QyQQ==
                    "],
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    237.42200000000003`, 151.691}, {231.758, 156.07}, {
                    223.90200000000002`, 150.789}, {218.49200000000002`, 
                    152.85200000000003`}, {218.49200000000002`, 
                    149.24599999999998`}, {220.297, 143.836}, {
                    226.21899999999997`, 141.777}, {228.023, 143.062}, {
                    236.137, 150.148}, {237.42200000000003`, 
                    151.691}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    237.42200000000003`, 151.69099999999997`}, {231.758, 
                    156.07000000000005`}, {223.90200000000002`, 
                    150.78900000000004`}, {218.49200000000002`, 
                    152.85199999999998`}, {218.49200000000002`, 
                    149.24599999999998`}, {220.297, 143.83599999999996`}, {
                    226.21899999999997`, 141.77700000000004`}, {228.023, 
                    143.06200000000007`}, {236.137, 150.14799999999997`}, {
                    237.42200000000003`, 151.69099999999997`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{246.309, 
                    164.184}, {237.42200000000003`, 168.691}, {235.879, 
                    157.48800000000003`}, {228.92200000000003`, 159.805}, {
                    229.18, 156.586}, {231.758, 152.594}, {
                    237.42200000000003`, 151.691}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{246.309, 
                    164.18400000000003`}, {237.42200000000003`, 
                    168.69099999999997`}, {235.879, 157.488}, {
                    228.92200000000003`, 159.805}, {229.18, 156.586}, {
                    231.758, 152.59400000000005`}, {237.42200000000003`, 
                    151.69099999999997`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{251.59, 
                    174.359}, {238.453, 179.512}, {236.777, 
                    166.89100000000002`}, {229.05100000000002`, 169.336}, {
                    230.85500000000002`, 164.95700000000002`}, {241.93, 
                    162.641}, {247.598, 164.184}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{251.59, 
                    174.35899999999998`}, {238.453, 179.51200000000006`}, {
                    236.777, 166.89099999999996`}, {229.05100000000002`, 
                    169.33599999999996`}, {230.85500000000002`, 164.957}, {
                    241.93, 162.64099999999996`}, {247.598, 
                    164.18400000000003`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{269.617, 
                    229.605}, {266.141, 234.5}, {258.801, 230.508}, {257.641, 
                    224.71099999999998`}, {256.484, 218.918}, {259.316, 
                    210.805}, {264.21099999999996`, 212.605}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{269.617, 
                    229.605}, {266.141, 234.5}, {258.801, 
                    230.50799999999998`}, {257.641, 224.711}, {256.484, 
                    218.918}, {259.316, 210.805}, {264.21099999999996`, 
                    212.60500000000002`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{278.504, 
                    245.062}, {272.453, 246.477}, {265.4959999999999, 
                    245.83200000000002`}, {266.27, 239.91}, {263.953, 
                    238.879}, {263.309, 231.281}, {269.617, 
                    229.605}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{278.504, 
                    245.06199999999998`}, {272.453, 246.477}, {
                    265.4959999999999, 245.832}, {266.27, 239.91}, {263.953, 
                    238.879}, {263.309, 231.28100000000003`}, {269.617, 
                    229.605}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{282.4959999999999, 249.05100000000002`}, {
                    276.574, 256.008}, {269.965, 255.844}, {266.27, 
                    252.918}, {259.445, 247.508}, {252.812, 250.598}, {
                    252.621, 245.18800000000002`}, {256.742, 248.344}, {
                    260.348, 244.547}, {263.695, 245.70299999999997`}, {
                    267.043, 246.863}, {269.49199999999996`, 
                    240.42600000000002`}, {278.762, 243.129}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{282.4959999999999, 249.05100000000002`}, {
                    276.574, 256.008}, {269.965, 255.844}, {266.27, 
                    252.91799999999998`}, {259.445, 247.50799999999998`}, {
                    252.812, 250.59799999999998`}, {252.621, 245.188}, {
                    256.742, 248.344}, {260.348, 244.547}, {263.695, 
                    245.703}, {267.043, 246.863}, {269.49199999999996`, 
                    240.42600000000002`}, {278.762, 243.129}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    268.203, 145.125}, {269.105, 143.44899999999998`}, {
                    274.641, 142.676}, {277.348, 145.512}, {
                    280.92999999999995`, 149.266}, {276.96099999999996`, 
                    159.676}, {271.29299999999995`, 160.44899999999998`}, {
                    265.625, 161.22299999999998`}, {265.113, 148.73}, {
                    268.203, 145.125}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    268.203, 145.125}, {269.105, 143.449}, {274.641, 
                    142.676}, {277.348, 145.51200000000006`}, {
                    280.92999999999995`, 149.26600000000002`}, {
                    276.96099999999996`, 159.676}, {271.29299999999995`, 
                    160.449}, {265.625, 161.223}, {265.113, 
                    148.73000000000002`}, {268.203, 145.125}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{261.762, 
                    144.86700000000002`}, {269.875, 141.906}, {273.355, 
                    148.602}, {268.977, 152.85200000000003`}, {267.816, 
                    151.434}, {263.566, 146.285}, {261.762, 
                    144.86700000000002`}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{261.762, 
                    144.86700000000002`}, {269.875, 141.906}, {273.355, 
                    148.60200000000003`}, {268.977, 152.85199999999998`}, {
                    267.816, 151.43400000000003`}, {263.566, 
                    146.28500000000003`}, {261.762, 144.86700000000002`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYCYtmoFOv7r3McvM07HRN2Jji8q7E3jduV47DI
ddvnvyoJDtUi69wf7sp2OA5SwAOVn5XlYHBXha2xNsbBpTvn+e/KTAeu64sL
bB9FONw89z34cWqGwzeNmP5DqVEOVltOlO2Tz3CI3eXJw/Q6HK7+TeAOuVbp
KIi6ziyHNTJAhyyPcGAAgYhsh5DHS2cfuRDlkDHxbY39xBwHoGuuVEjGOTgl
PL2gNDkXIr8g1mH1x0u+STx5DkDTtduvxUP9kefgCFJXn+gAMvb+9QKHKpA/
yhId7vv3Ts97U+CgD3L/x2QHoCkKG3IKHOJA7lNOcRBuPnBq4cZcuHr08AEA
nyiJLw==
                    "]]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYCYtmoFOv7r3McfMw7HRN2Jji8q7E3jduV47DA
ddvnvyoJDtUi69wf7sp2OOYNVMADlZ+V5WBwV4WtsTbGwaU75/nvykwHnuuL
C2wfRTjcPPc9+HFqhsMPjZj+Q6lRDlZbTpTtk89wSNjlycP0Ohyu/k3gDrlW
6SiHbyB1nVkOa2SADlke4cAAAhHZDhGPl84+ciHKIWPi2xr7iTkOWz7/vVIh
GefglPD0gtLkXIj8gliH1R8v+Sbx5Dl48DBpt1+Ld/AG+yMPoq4+0QFk7P3r
BQ41IH+UJTrc9++dnvemAOL+j8kOQFMUNuQUQNynnOIg3Hzg1MKNuXD16OED
AKdgiUI=
                    "],
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{434.59, 328.512}, {444.895, 
                    325.16400000000004`}, {445.148, 311.77}, {
                    456.9959999999999, 307.39099999999996`}, {468.848, 
                    303.012}, {470.008, 292.453}, {479.66400000000004`, 
                    295.027}, {470.648, 297.477}, {471.29299999999995`, 
                    307.90599999999995`}, {461.895, 310.47999999999996`}, {
                    450.867, 313.504}, {446.695, 330.316}, {
                    437.93799999999993`, 332.89099999999996`}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{434.59, 328.51199999999994`}, {444.895, 
                    325.164}, {445.148, 311.77}, {456.9959999999999, 
                    307.391}, {468.848, 303.01199999999994`}, {470.008, 
                    292.453}, {479.66400000000004`, 295.02700000000004`}, {
                    470.648, 297.477}, {471.29299999999995`, 307.906}, {
                    461.895, 310.48}, {450.867, 313.504}, {446.695, 
                    330.31600000000003`}, {437.93799999999993`, 332.891}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC0c0HTi2UrXOISrG+769Z4HBR6fbPOqs6hxl5
Qs0HzuU7vK2xN40zq3OQBSl4nOfgbd7pmHC+1mFvyWQJlmV5DrG7PHmY2Osc
GEAgASofWefg0p3z/PfCPIels48obGirc3gHMscq32EZiO9U5wC2lzfP4dMl
3ySBAij/b45D+b75Uvq3oeadyHFwf1glsm55nYO6IccamVm5DkBbw/ik6x1a
XwfukPubC1H3rQ7Cb82D8K3qHSYc+qoR453nYLXlRNm+0nqHm+e+Bz+emAsx
r7ge4k+5XAegpteBZ+odVn0EOuRJLkS9Yb3DY5DD3+Q5gLjz/eod9O+qsDUu
zXcAAC1GhAA=
                    "]]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC0c0HTi2UrXOISrG+769Z4HBR6fbPOqs6hxl5
Qs0HzuU7vK2xN40zq3OQBSl4nOfgbd7pmHC+1mFPyWQJlmV5DrG7PHmY2Osc
GEAgASofWefg3J3z/PfCPIels48obGirc3gHMscq32EZiO9U5wC2lzfP4dMl
3ySBAij/b45D+b75Uvq3oeadyHFwf1glsm55nYO6IccamVm5DkBbw/ik6x1a
XwfukPubC1H3rQ7Cb82D8K3qHSYc+qoR453nYLXlRNm+0nqHm+e+Bz+emAsx
r7ge4k+5XAegpteBZ+odVn0EOuRJLkS9Yb3DY5DD3+Q5gLjz/eod9O6qsDUu
zXcAACtug/0=
                    "],
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIxIGYC4p1yra8DP1U6rP54yTeJJ8MhKsX6vn9vpYNw
84FTC/dmOBz3Nu90TKp0UDfkWCNzL93h0FeNmH6DSocJIIY2VJ6p0qEoY+Lb
muIMB6Dm6XlHKhy+AZUdqs1wmJ4n1HxgTYWDEMg8U6j5zJUOxSD1+hkOi1y3
ff57o8JB/64KW+PKdIfc579XfmyodOgFaexIh8vfPPc9+HFhugOv7qa5779X
OFSLrHN/+CsVYm57hYMP0BkJvGkOQN/skPtf4TADZK9WKsQ8m0qHfpB7r6c5
aLeL3Tw3t9IBZL39xDS4fbd/1mXtaYDqP13pcAvE/wE1fzrUf86pDpMlWML4
Xlc6hPEBHeIO5fNWOQBNM43TS3Ow5bq+uEC8CuLepWkOAJL2qh0=
                    
                    "]]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIxIGYC4p1yra8DP1U6rPp4yTeJJ8MhKsX6vn9vpYNQ
84FTC/dmOBz3Nu90TKp0UDPkWCNzL93h0FeNmH6DSoc+EEMbKs9U6VCSMfFt
TXGGA1Dz9LwjFQ7fgMoO1WY4TM8DmrSmAmKeKdR8Zqh6/QyHRa7bPv+9UeFg
cFeFrXFlukPu898rPzYAzQdp7EiHy9869z34cWG6A6/uprnvv1c4VImsc3/4
KxVibnuFgw/QGQm8aQ5A3+yQ+1/hMA1kr1YqxDybSocJIPdeT3PQbhe7eW5u
pUMW0Hr7iWlw++78rMva0wDVfxrK/wE1fzrUvc6pDpMlWML4Xlc6hPEBHeIO
5fNWObyrsTeN00tzsOW6vrhAvAri3qVpDgCTRqol
                    "],
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIlIGYC4rhdnjxMzoUOMlEp1vfbExxkQbRsoYNQ84FT
C48mOMzIA7I2FThsPVG2b/6jBAeFDUUZEzsLHFpfB+6Q25jgsEMOyEoocAjn
0900tz7BYTpIfV6Bgypb41Tn4gSHqxUv1QwXFDiA7clOcPB4WCWy7mIBxNyk
BAf9uypsjYKFELo13uFtjb1p3LICh01z3y8/VhzvkPv898qPJQUOIOtas+Md
7LiuLy5oLXAwAKnvjYWolytwEFnn/rAqJ9ZhC8idHgUOIOe7zotxKN83X0r/
YIED0HbtdrVYh/v+vdPz3hQ4SIMs5IyDuO9JgUNxxsS3Nf6xDgwgoFQIUb8s
xgEUHP6chQ7/QeB4tIMiyP+hhQ5PLyjd/rks2gGkzV6z0AHkLFujOAcrkAMW
FjqAvOkuGAcJn4JCh15QwPyIhfinpdDhDcg/1jEOtiCNtwsdnoHMWxfjwKsL
8nmhA8hZHD4xkHA6VOiwyHXb578x0RD3/4G6b1q0g7d5p2PC9UKIO1KjIeF8
utDBEuSO5VEOIGPr/hU6iILCxyYKYr5+ESS8fKIh7vtRCAkPyXgH9PQAANOF
8IM=
                    "]]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIlIGYC4rhdnjxMzoUOMlEp1vfbExxkQbRsoYNQ84FT
C48mOMzIA7I2FThsO1G2b/6jBAeFDUUZEzsLHNpeB+6Q25jgsEOu9XVgQoFD
GJ/uprn1CQ7TQerzChzU2BqnOhcnOFyteKlmuKDAAWxPdoKDx8MqkXUXCyDm
JiU46N9VYWsULHQwANGt8Q5va+xN45YVOGyZ+375seJ4h9znv1d+LClweAO0
rjU73sGO6/rigtYCiPreWIh6uQIHkXXuD6tyYh22gNzpUeDQAnS+67wYh/J9
86X0DxY4+PAwaberxTrc9++dnvemwEECZDFnHMR9TwocSjImvq3xj3VgAAGl
Qoj6ZTEOoODw5yyEiJ+IdlAE+T+00OHFBaXbP5dFO4C02WsWOvAAnWVrFOdg
BXLAwkKHJ0BvugvGQcKnoNChBxQwP2Ih/mkphPjHOsbBFuSf21Dz1sU48AKD
8f3yQgeQszh8YiDhdKjQYYHrts9/Y6Ih7v9T6OABct+0aAdv807HhOuFDjkg
d6RGQ8L5dKGDBcgdy6McQMbW/SuEhI9NFMR8/SII3yca4r4fhZDwkIx3QE8P
ACEa65k=
                    "],
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{556.676, 274.34400000000005`}, {566.535, 
                    274.34400000000005`}, {574.523, 282.33599999999996`}, {
                    574.523, 292.195}, {574.523, 302.051}, {566.535, 
                    310.043}, {556.676, 310.043}, {546.8159999999999, 
                    310.043}, {538.828, 302.051}, {538.828, 292.195}, {
                    538.828, 282.33599999999996`}, {546.8159999999999, 
                    274.34400000000005`}, {556.676, 
                    274.34400000000005`}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{556.676, 274.344}, {566.535, 274.344}, {574.523, 
                    282.336}, {574.523, 292.195}, {574.523, 
                    302.05100000000004`}, {566.535, 310.043}, {556.676, 
                    310.043}, {546.8159999999999, 310.043}, {538.828, 
                    302.05100000000004`}, {538.828, 292.195}, {538.828, 
                    282.336}, {546.8159999999999, 274.344}, {556.676, 
                    274.344}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxdVGtIVEEUXm2RMBULDZMwrYiebAUVKtrZLNRKtASTKBHJksX23rm+3Ycz
V9IkJETIIkwkM+yHbKYmUZuViPgj1AyJFN3ETMosIySix8w9lxVcGIbZmXPm
e82NypFO564yGAw+fCTz4cvH+SfJAb5Ldsirm7cfviVBlEvJq0txgPb/Jhni
/MfuysMO6D9xqMacJMPiSEpO8G4nTKXWNlj9Zbh3uy/SVeX01keK+kcV8Lwp
3DRhlKB6/bvXS1so2ELaEz0jEkyLAiuFoc3vfznTZChx84N1FPtWybjfQSHJ
Ux7SXibDxrMXYicHKZgmtvoxkww3resqez/p9QEytMgcYSCDnogrn0/56f02
MDiSPcOPSPCGt800M+Ao0qcfSlA2t23f6kwGglacWwKD+JUxOMnpZTdKWN/M
sH+/BJanhfVhLxgIGKk7ZHj5c/u564sM+YTLcCPhWv5spAr1YcaMoFxdr/0q
cDUOZI3KyP+iCq1CpyldP4sKb0s5kAyC/ZNVmBR6thAoFffvVIGjmRlyEexv
VuHy7O+271SBV+L+YQbRnQPF7jMK4vdRcY5Q8Pw4gy6+3fRA72/U8RURELIm
zjHvOjiTd+pniDeLAHd9V7WbIc4ggjgGGPpxjOA9zxj6YCE4dzHg6vdElBC4
Ks536/q1Evgg7lMZ4g9XsF8aQz2+EfSnkGF+PDq+bAZi8lgJ+lXOgN8y2JxA
oPvHn9HSSwxzZtb1SWeYVxNBfZKW8Wt+xjKI1wwnsFbwXbPcP3BPR+PCVwpZ
or5gea3lrZJgLuap1x+tfo4in079/nGK+n3U9R6hqEeUAgv3+csZo5jPfAV1
cVNoELod1P1qo5irLwSOC/0bKfJ5TKBPEC1esR9K8T3eIYhrqAL9qSEQI3JR
VOH1V9P7qNPrh/Ze/zq8+mtzjwPzHKPgeq8D85mnIE+XHfNfq6BPPnbk06tg
Dv/ZEActwHzE23DfWAhBQs9oG9aHFiCPFrv3+7Ly+/MfbnUMuQ==
                    
                    "]]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxdVGtIFFEUXksizMSemIRpRfRkK6iwSL+lIu1BVmASJRI9TGxn7mil7q7e
O1JmESFFD8JCMsN+hJmVRC32wMQfoZskYaEmZVJZGRERPebsGVZo4TLcvXPO
+V53EnZpW/aMdDgcYdZKtdYIa+28lxo54ocX+ys+eZMvaEioM7IrNvqQSf9P
07EyovOK3u5D8/pl5a4UHUOBjbui5xeje9PJc+4IHVcvPomvO1ocqo+n+lsl
8F+Odb4O11A2+eWzHzMkPBNvrO0NaOijArdE+/Sun8VpOg7TixWS+x7V+bxe
IqW3aOKNQh1Tt+9e0d0q4Xw9c5Ry6jjvHl/a9F4iQPWROqp1C+FYhca4Ix82
j7L7TVFwZb1tm96l4bnVNsOlYKHY2ndTQ+HArEWjMxSI1kq/Bgf9ChWIXlal
xvVVivE1a8i5n3865qECwdg0R8ej77N3nBpSKCI+sTrOrjqR2x9v4kxMeHrU
HluvxSYGvclLMjt05r/XRA3p1GPrl2PiRYEFJF1w/1QTPaRntUABzZ9r4jgR
qBPc32Uit/9X7Vdp4DHNb1dY3tByyL/NYPxhJj/jDH7/lQIdX75u9w+38R0U
IFnXDqjQPjojsaGlWTHeTAHL9XllfsU4owTKCUeLYj/WCJ7zQOEc+ZAj2I/b
Cpb6jXGHBY7R+3ds/WoE3tA8UzH+WIP7pSnW44tgf/IVsik/vTa+LMV5cQv2
q0hhQmlTa9UqgTvffncU7FOcM5etz1bFeXUK1idlGH/QzxUKSUHDBcYR3zHD
/ccuqK/8PCi5Pm94H8xbqcAGysUnGfInWD8gmU+DPf+VZP3e2XoHJOuRYODz
NevmdErOZ66BNtLFL1m3pbZftZJxfxRYR/pX2njuCjwhoof+O58k8ZQCe0nw
PWwrYX/KBefiYEnI36Deq4tDfgTv6x9fSP/gs9HHeV5u8H6hDx2Uz2wDB4hn
nZfzf9Jgn8K8zKfJQCLN++thfWQe5yPJw+fh+YgiPRM9XD8pj+9PtTf0ffn/
+/MPmF0Mzg==
                    "],
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{337.22999999999996`, 138.945}, {346.758, 
                    138.945}, {354.48799999999994`, 146.672}, {
                    354.48799999999994`, 156.19899999999998`}, {
                    354.48799999999994`, 165.73}, {346.758, 
                    173.45700000000002`}, {337.22999999999996`, 
                    173.45700000000002`}, {327.699, 173.45700000000002`}, {
                    319.97299999999996`, 165.73}, {319.97299999999996`, 
                    156.19899999999998`}, {319.97299999999996`, 146.672}, {
                    327.699, 138.945}, {337.22999999999996`, 
                    138.945}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{337.22999999999996`, 138.945}, {346.758, 
                    138.945}, {354.48799999999994`, 146.67200000000003`}, {
                    354.48799999999994`, 156.199}, {354.48799999999994`, 
                    165.73000000000002`}, {346.758, 173.457}, {
                    337.22999999999996`, 173.457}, {327.699, 173.457}, {
                    319.97299999999996`, 165.73000000000002`}, {
                    319.97299999999996`, 156.199}, {319.97299999999996`, 
                    146.67200000000003`}, {327.699, 138.945}, {
                    337.22999999999996`, 138.945}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxFUw1IFEEUvqykX4kKKSkpMZHLyIIQrcMvKiQsLAOJLGv3bnYv0bKdOY0K
SU6RECupSCiRCosiQsxMKs0yUgKlhAopM7Myy35UJESFdu4NtjAsb2bf976f
2eX64VQ21eFwTLGXy15B9qoPL/qx86SF2tbcxspgN+auqqn4fd/CzxOJ6zJy
dVw8NN/fFMpxT57n61i6x7O+28WR8WDrnKASHccW3knqyeBoEOcWTfugUX8L
x+aSrL6xHg3eMhtphGNFcMGFTX6NcCIESiVwpAZ7en14g8D70fzMRzEaPqbY
J98FzddV/xNBfZkaknrsiSUCDvlc1vD6aH/Umt3qfEij/TBB/NJ15DVWhq2O
E0iQAle66T1doLP9765enxunNh748tIpcGuwY7ve6sbVLXXDE7Gq3uFBudQf
rb4v8pC+FEF67nrInyyBbXE20oQHx6UfOQKvIt6N5kcwqmsF4TgZ+fxH4LFN
qyuHIVn2zfSR3usM3VJ/jI/88TDiU+gjPQ/Vea2PdCQzVF16tqy6UdXpBs3b
4CMfBgwE8v0qyMcyAzK+lGblb52BpyPRe88YAgv8TS+uVBjolYBpAi2SWJZB
ffGKb6HC/8ZJ31oDzuLQzvZmTufjiu8Ax+y313JcToP8H+aYJesag3z4xBEv
+fYak3kE9DpMwo8ROCuJ7Tcn8wj4W2XSXF3xOW+Sn7cF3cM3JuloU/qemxiy
Y5xXrvJI9cIliSQKusd+L+X3mSMtxA42z4t90udiTrqzvZP3O5BTv5qfyhEl
809XfMPU94tN8nsGJ50JBrL7xm4OLuE4LQcNMKrHLcL5xWD/NWkh3RaOSGLV
jPo6LNJRyojvDYv2axjtH7QQ2xUZXNDGKE/X//ofZNLBEA==
                    
                    "]]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxFUw1IFEEUvqykwiQqpMSkREQuIwtCsg6/iJKwsAwksqzdu929RE125jRK
pFCRMCvpR6FEKiwCETEzKRPLMAkUEyoqzMzKLDN/kBAV2udbbGFY3sy89/3t
rlNPJmnzHQ7HPGu5rOVnrcbQwl8HzppoaM9urvR3Y+mGuoo/j0wM58ZtSc1W
UZa5PL8lSKCezvNUrDns2dbrEkh9vCfAr1jF6ZU18X2pAk3yyqoFnxTufymw
uzh9YKpPgbf0d27chECE/7lrO/MVPKQ5YRIXaHC4Agu9MfSpxIfJvLSmKAWf
E0vKMn9KjBC+avc/k4yfpiC+z0IslnDQc1PBm1ODEZsOSeY/pvB+sGR+KSpy
miuDN8ZIxNKA9W5+L7TwOv8e7Pe5cX7H8W9dTonq0e59arsbt3c1jM9E2/V+
D8pJf6R9v9DD+hIl63ngYX/SJfbGWJNmPDhDfmRJdId9nMwL07iul7hO95wa
6xiRaLFo9WRpSKC+xT72+66GXtIf5WN/PBrzKfCxnif2eb2PdSRoqLrxYm1t
s12n6Iy33cc+DOmYzfe7RBr5WKqD4ktslYzXoOP5ROSRS7qExe7VrQod/TQw
WaKNiKXr7P9WCbKxp8Ce/0Owvs06nEVB7ztbBeuZtvkOCSx5dyfL5dTZ/3GB
AKrrdPbzi2C+/fpcHhdJr8Pg+VESl4nYMWMuj1l/qwy8JlzV5nPVYD+rJXKp
762BFaSjw9bXZmDMinFZuZ1HkhcuIhYnEUJG5Hs5v68CyYFWsDleHCWfiwT7
leGd+75n8Qdt/CSBcMo/xeYbbN9fbbDfiwTnHasjY2Dq/miI4DyHNK6nTXTR
nGEN1l+THNhrwiRitRr7021yHiUa871n8n6dxvpOmIjusRh0aJyn63/9D4+S
wSA=
                    "],
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    293.059, 181.441}, {291.89799999999997`, 184.789}, {
                    293.43399999999997`, 187.805}, {294.215, 
                    190.45700000000002`}, {296.21099999999996`, 
                    197.21899999999997`}, {294.98799999999994`, 
                    198.95700000000002`}, {288.93799999999993`, 198.055}, {
                    288.42199999999997`, 194.836}, {291.512, 
                    184.27299999999997`}, {293.059, 181.441}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    293.059, 181.44099999999997`}, {291.89799999999997`, 
                    184.78900000000004`}, {293.43399999999997`, 187.805}, {
                    294.215, 190.457}, {296.21099999999996`, 
                    197.21900000000005`}, {294.98799999999994`, 198.957}, {
                    288.93799999999993`, 198.055}, {288.42199999999997`, 
                    194.83599999999996`}, {291.512, 184.27300000000002`}, {
                    293.059, 181.44099999999997`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    288.613, 197.668}, {290.16, 196.121}, {295.633, 
                    195.414}, {296.21099999999996`, 200.309}, {296.879, 
                    205.92600000000002`}, {294.60200000000003`, 208.102}, {
                    289.707, 205.91}, {289.324, 204.621}, {288.871, 
                    199.344}, {288.613, 197.668}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    288.613, 197.668}, {290.16, 196.12099999999998`}, {
                    295.633, 195.41400000000004`}, {296.21099999999996`, 
                    200.30900000000003`}, {296.879, 205.926}, {
                    294.60200000000003`, 208.10200000000003`}, {289.707, 
                    205.91000000000003`}, {289.324, 204.62099999999998`}, {
                    288.871, 199.344}, {288.613, 197.668}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    289.77299999999997`, 206.102}, {291.832, 205.266}, {
                    296.277, 203.594}, {298.72299999999996`, 
                    208.35500000000002`}, {300.777, 212.35500000000002`}, {
                    298.078, 215.441}, {293.832, 215.184}, {292.801, 
                    214.023}, {290.73799999999994`, 209.90200000000002`}, {
                    289.77299999999997`, 206.102}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    289.77299999999997`, 206.10200000000003`}, {291.832, 
                    205.26600000000002`}, {296.277, 203.59400000000005`}, {
                    298.72299999999996`, 208.35499999999996`}, {300.777, 
                    212.35499999999996`}, {298.078, 215.44099999999997`}, {
                    293.832, 215.18400000000003`}, {292.801, 
                    214.02300000000002`}, {290.73799999999994`, 
                    209.90200000000004`}, {289.77299999999997`, 
                    206.10200000000003`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    293.574, 215.57}, {294.08599999999996`, 214.023}, {
                    299.367, 208.871}, {303.22999999999996`, 212.605}, {
                    307.094, 216.344}, {307.094, 221.879}, {301.301, 
                    223.941}, {299.754, 223.684}, {295.117, 
                    218.27299999999997`}, {293.574, 215.57}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    293.574, 215.57000000000005`}, {294.08599999999996`, 
                    214.02300000000002`}, {299.367, 208.87099999999998`}, {
                    303.22999999999996`, 212.60500000000002`}, {307.094, 
                    216.344}, {307.094, 221.87900000000002`}, {301.301, 
                    223.94099999999997`}, {299.754, 223.68400000000003`}, {
                    295.117, 218.27300000000002`}, {293.574, 
                    215.57000000000005`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    301.301, 223.941}, {302.457, 220.71899999999997`}, {
                    306.062, 215.184}, {312.762, 217.758}, {319.457, 
                    220.336}, {316.625, 228.70299999999997`}, {
                    313.53499999999997`, 230.379}, {311.72999999999996`, 
                    230.25}, {304.39099999999996`, 226.90200000000002`}, {
                    301.301, 223.941}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    301.301, 223.94099999999997`}, {302.457, 
                    220.71900000000005`}, {306.062, 215.18400000000003`}, {
                    312.762, 217.75799999999998`}, {319.457, 
                    220.33599999999996`}, {316.625, 228.703}, {
                    313.53499999999997`, 230.379}, {311.72999999999996`, 
                    230.25}, {304.39099999999996`, 226.902}, {301.301, 
                    223.94099999999997`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    313.53499999999997`, 230.379}, {313.02, 227.547}, {
                    313.53499999999997`, 219.82000000000002`}, {322.676, 
                    219.94899999999998`}, {331.82, 220.078}, {329.246, 
                    230.766}, {326.92599999999993`, 232.312}, {323.191, 
                    232.312}, {316.883, 232.184}, {313.53499999999997`, 
                    230.379}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    313.53499999999997`, 230.379}, {313.02, 227.547}, {
                    313.53499999999997`, 219.82}, {322.676, 219.949}, {331.82,
                     220.07800000000003`}, {329.246, 230.76600000000002`}, {
                    326.92599999999993`, 232.31199999999998`}, {323.191, 
                    232.31199999999998`}, {316.883, 232.184}, {
                    313.53499999999997`, 230.379}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{327.312, 
                    231.92600000000002`}, {326.28499999999997`, 
                    229.73399999999998`}, {323.96099999999996`, 215.324}, {
                    341.867, 219.305}, {344.184, 219.82000000000002`}, {
                    350.234, 233.08200000000002`}, {327.312, 
                    231.92600000000002`}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{327.312, 
                    231.92600000000002`}, {326.28499999999997`, 229.734}, {
                    323.96099999999996`, 215.324}, {341.867, 219.305}, {
                    344.184, 219.82}, {350.234, 233.082}, {327.312, 
                    231.92600000000002`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    337.10200000000003`, 230.637}, {335.301, 
                    228.83200000000002`}, {339.93399999999997`, 214.281}, {
                    352.039, 216.727}, {364.14500000000004`, 219.176}, {
                    353.97299999999996`, 232.953}, {337.10200000000003`, 
                    230.637}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    337.10200000000003`, 230.637}, {335.301, 228.832}, {
                    339.93399999999997`, 214.281}, {352.039, 
                    216.72700000000003`}, {364.14500000000004`, 219.176}, {
                    353.97299999999996`, 232.953}, {337.10200000000003`, 
                    230.637}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{347.402, 
                    228.44899999999998`}, {345.47299999999996`, 
                    224.45700000000002`}, {348.371, 212.605}, {363.309, 
                    212.605}, {376.848, 212.605}, {362.60200000000003`, 
                    228.191}, {347.402, 228.44899999999998`}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{347.402, 
                    228.44899999999998`}, {345.47299999999996`, 
                    224.45700000000002`}, {348.371, 212.60500000000002`}, {
                    363.309, 212.60500000000002`}, {376.848, 
                    212.60500000000002`}, {362.60200000000003`, 228.191}, {
                    347.402, 228.44899999999998`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{359.121, 
                    224.969}, {358.15200000000004`, 222.758}, {356.965, 
                    210.195}, {374.578, 209.129}, {387.328, 
                    208.35500000000002`}, {384.23799999999994`, 
                    226.38700000000003`}, {359.121, 224.969}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{359.121, 
                    224.969}, {358.15200000000004`, 222.75799999999998`}, {
                    356.965, 210.195}, {374.578, 209.12900000000002`}, {
                    387.328, 208.35499999999996`}, {384.23799999999994`, 
                    226.38700000000003`}, {359.121, 224.969}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{378.055, 
                    219.691}, {375.867, 215.82800000000003`}, {373.547, 
                    206.168}, {392.863, 205.395}, {405.23799999999994`, 
                    204.89800000000002`}, {397.629, 219.434}, {378.055, 
                    219.691}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{378.055, 
                    219.69099999999997`}, {375.867, 215.82799999999997`}, {
                    373.547, 206.168}, {392.863, 205.39499999999998`}, {
                    405.23799999999994`, 204.89799999999997`}, {397.629, 
                    219.43400000000003`}, {378.055, 219.69099999999997`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    394.15200000000004`, 216.727}, {391.32, 212.863}, {
                    393.40599999999995`, 205.285}, {400.59, 
                    203.85200000000003`}, {409.605, 202.047}, {410.895, 
                    210.547}, {404.715, 214.668}, {398.53099999999995`, 
                    218.789}, {394.15200000000004`, 216.727}, {
                    394.15200000000004`, 216.727}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    394.15200000000004`, 216.72700000000003`}, {391.32, 
                    212.863}, {393.40599999999995`, 205.28500000000003`}, {
                    400.59, 203.85199999999998`}, {409.605, 
                    202.04700000000003`}, {410.895, 210.54700000000003`}, {
                    404.715, 214.668}, {398.53099999999995`, 
                    218.78900000000004`}, {394.15200000000004`, 
                    216.72700000000003`}, {394.15200000000004`, 
                    216.72700000000003`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    402.90999999999997`, 214.92600000000002`}, {
                    400.85200000000003`, 211.32000000000002`}, {402.125, 
                    202.562}, {415.78499999999997`, 202.562}, {418.621, 
                    202.562}, {429.441, 213.637}, {402.90999999999997`, 
                    214.92600000000002`}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    402.90999999999997`, 214.926}, {400.85200000000003`, 
                    211.32}, {402.125, 202.56200000000007`}, {
                    415.78499999999997`, 202.56200000000007`}, {418.621, 
                    202.56200000000007`}, {429.441, 213.637}, {
                    402.90999999999997`, 214.926}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{297.184, 46.98}, {308.246, 46.98}, {317.219, 
                    55.949}, {317.219, 67.012}, {317.219, 
                    78.07799999999999}, {308.246, 87.051}, {297.184, 
                    87.051}, {286.117, 87.051}, {277.148, 
                    78.07799999999999}, {277.148, 67.012}, {277.148, 
                    55.949}, {286.117, 46.98}, {297.184, 46.98}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{297.184, 46.98000000000002}, {308.246, 
                    46.98000000000002}, {317.219, 55.94900000000001}, {
                    317.219, 67.01200000000006}, {317.219, 
                    78.07800000000003}, {308.246, 87.05099999999999}, {
                    297.184, 87.05099999999999}, {286.117, 
                    87.05099999999999}, {277.148, 78.07800000000003}, {
                    277.148, 67.01200000000006}, {277.148, 
                    55.94900000000001}, {286.117, 46.98000000000002}, {
                    297.184, 46.98000000000002}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxdVwtQVFUYRjGnFJ0syyegZNb4ptREI38lI80H8lriJexe7j4k3Lv3LrLs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                    
                    "]]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxdVwlsVFUULRSNYjGiKIiUTYIGRUBB22rlAiKLIKXb1G5MZ37/LNQ6f5nS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                    "],
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{515.8549999999999, 121.215}, {528.031, 
                    121.215}, {537.898, 131.08200000000002`}, {537.898, 
                    143.254}, {537.898, 155.42600000000002`}, {528.031, 
                    165.297}, {515.8549999999999, 165.297}, {503.684, 
                    165.297}, {493.812, 155.42600000000002`}, {493.812, 
                    143.254}, {493.812, 131.08200000000002`}, {503.684, 
                    121.215}, {515.8549999999999, 121.215}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{515.8549999999999, 121.21500000000003`}, {
                    528.031, 121.21500000000003`}, {537.898, 
                    131.08200000000005`}, {537.898, 143.25400000000002`}, {
                    537.898, 155.426}, {528.031, 165.29700000000003`}, {
                    515.8549999999999, 165.29700000000003`}, {503.684, 
                    165.29700000000003`}, {493.812, 155.426}, {493.812, 
                    143.25400000000002`}, {493.812, 131.08200000000005`}, {
                    503.684, 121.21500000000003`}, {515.8549999999999, 
                    121.21500000000003`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{431.758, 
                    337.27}, {426.863, 315.633}, {430.984, 
                    305.84799999999996`}, {438.195, 296.31600000000003`}, {
                    453.10200000000003`, 276.621}, {464.984, 
                    231.66799999999998`}, {447.984, 202.305}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{457.512, 227.676}, {
                    459.574, 228.44899999999998`}, {463.43799999999993`, 
                    230.895}, {464.34000000000003`, 235.14499999999998`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{459.059, 
                    237.07399999999998`}, {459.703, 240.81199999999998`}, {
                    465.4959999999999, 242.41799999999998`}, {465.625, 
                    246.414}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{459.188, 251.629}, {
                    458.801, 255.492}, {464.984, 258.969}, {464.078, 
                    262.832}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{455.84000000000003`, 
                    265.53499999999997`}, {455.324, 267.72700000000003`}, {
                    460.98799999999994`, 271.84799999999996`}, {459.445, 
                    275.324}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{451.59, 
                    279.05899999999997`}, {450.42999999999995`, 281.508}, {
                    454.29299999999995`, 284.34000000000003`}, {452.621, 
                    286.914}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{445.40599999999995`, 
                    289.875}, {445.02, 291.55100000000004`}, {447.402, 
                    295.223}, {446.117, 297.40999999999997`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{439.227, 302.625}, {
                    439.73799999999994`, 303.27}, {441.805, 
                    304.81600000000003`}, {440.965, 306.746}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{434.977, 311.961}, {
                    435.812, 312.414}, {438.324, 313.188}, {438.004, 
                    315.055}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{306.062, 
                    69.14499999999998}, {300.914, 70.945}, {
                    294.47299999999996`, 68.37099999999998}, {293.188, 
                    63.988}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{297.051, 
                    60.}, {297.695, 64.375}, {304.39099999999996`, 
                    66.30900000000003}, {306.449, 64.25}, {302.199, 
                    66.56600000000003}, {300.141, 58.327999999999975`}, {
                    303.875, 58.06600000000003}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{338.51599999999996`, 
                    161.86700000000002`}, {335.42599999999993`, 160.32}, {
                    334.527, 154.65599999999995`}, {338.51599999999996`, 
                    150.40200000000004`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    343.15200000000004`, 160.57800000000003`}, {340.965, 
                    158.77700000000004`}, {341.094, 153.36700000000002`}, {
                    344.312, 152.07800000000003`}, {341.60900000000004`, 
                    154.01200000000006`}, {344.312, 157.35899999999998`}, {
                    346.246, 157.488}, {348.176, 157.61700000000002`}, {
                    349.465, 155.29700000000003`}, {347.14500000000004`, 
                    152.98000000000002`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{524.094, 
                    147.832}, {516.883, 149.76200000000006`}, {
                    511.08599999999996`, 141.39099999999996`}, {
                    517.6519999999999, 133.92200000000003`}, {
                    517.5269999999999, 141.13299999999998`}, {522.676, 
                    145.89799999999997`}, {528.988, 144.60900000000004`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    526.09, 139.62099999999998`}, {524.3159999999999, 
                    139.62099999999998`}, {523.3199999999999, 
                    138.23400000000004`}, {523.3199999999999, 
                    136.88299999999998`}, {523.3199999999999, 
                    135.46500000000003`}, {524.543, 134.113}, {526.539, 
                    134.113}, {527.828, 134.113}, {528.8589999999999, 
                    135.59400000000005`}, {528.8589999999999, 
                    136.75400000000002`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{551.523, 
                    297.73400000000004`}, {552.6840000000001, 293.355}, {
                    558.738, 291.55100000000004`}, {563.5, 292.582}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{563.5, 
                    295.414}, {559.766, 295.285}, {556.676, 298.762}, {
                    556.934, 301.72700000000003`}, {556.934, 
                    299.53499999999997`}, {561.9569999999999, 298.504}, {
                    563.5, 299.922}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{307.867, 
                    148.344}, {306.83599999999996`, 150.92200000000003`}, {
                    310.957, 153.49599999999998`}, {311.08599999999996`, 
                    155.94099999999997`}, {311.215, 158.39099999999996`}, {
                    315.72299999999996`, 160.32}, {320.35900000000004`, 
                    155.68400000000003`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{318.172, 
                    183.11700000000002`}, {317.27, 182.73000000000002`}, {
                    316.4959999999999, 182.21500000000003`}, {
                    315.72299999999996`, 181.957}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{327.055, 
                    169.07800000000003`}, {325.96099999999996`, 
                    169.01200000000006`}, {323.707, 169.14099999999996`}, {
                    322.484, 169.98000000000002`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{322.547, 
                    164.18400000000003`}, {321.648, 163.73400000000004`}, {
                    319.648, 162.961}, {318.49199999999996`, 
                    162.70300000000003`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{278.375, 
                    86.39799999999997}, {278.246, 84.07800000000003}, {
                    280.566, 80.73400000000004}, {281.85200000000003`, 
                    79.70300000000003}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{288.42199999999997`, 
                    91.93799999999999}, {287.133, 90.00800000000004}, {
                    286.35900000000004`, 86.65599999999995}, {287.133, 
                    84.33999999999997}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    307.60900000000004`, 84.21100000000001}, {
                    305.29299999999995`, 85.75799999999998}, {
                    306.83599999999996`, 89.75}, {306.578, 
                    92.32400000000001}, {306.32, 94.89799999999997}, {
                    309.28499999999997`, 99.02000000000004}, {315.078, 
                    95.543}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{285.97299999999996`, 
                    98.89099999999996}, {288.29299999999995`, 
                    99.27700000000004}, {290.73799999999994`, 
                    99.14799999999997}, {292.28499999999997`, 
                    98.50800000000004}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{315.33599999999996`, 
                    106.23400000000004`}, {314.305, 104.81599999999997`}, {
                    314.051, 103.27000000000004`}, {313.92199999999997`, 
                    102.238}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{326.156, 106.488}, {
                    324.35200000000003`, 106.488}, {322.805, 
                    105.20300000000003`}, {322.03499999999997`, 
                    103.91400000000004`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{301.172, 172.426}, {
                    303.22999999999996`, 171.71900000000005`}, {308.574, 
                    168.43400000000003`}, {308.77, 165.02000000000004`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{323.062, 189.168}, {
                    316.754, 189.29700000000003`}, {314.305, 195.738}, {
                    319.07, 195.738}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{334.395, 
                    180.53900000000004`}, {331.949, 179.51200000000006`}, {
                    333.10900000000004`, 175.26200000000006`}, {
                    336.58599999999996`, 173.199}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{319.328, 
                    140.10200000000003`}, {318.105, 141.64799999999997`}, {
                    319.715, 146.152}, {323.707, 144.805}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{328.72999999999996`, 
                    93.09800000000001}, {328.984, 97.02300000000002}, {
                    333.945, 99.344}, {335.941, 94.89799999999997}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{310.441, 
                    81.89499999999998}, {310.121, 86.20700000000005}, {
                    312.309, 87.625}, {314.242, 87.87900000000002}, {316.172, 
                    88.137}, {318.941, 86.531}, {320.22999999999996`, 
                    83.695}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{272.066, 
                    78.67200000000003}, {272.324, 81.25}, {274.512, 
                    83.95299999999997}, {276.832, 83.56600000000003}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{507.73799999999994`, 
                    193.031}, {506.062, 191.80900000000003`}, {504.969, 
                    186.33599999999996`}, {511.34400000000005`, 185.82}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{497.949, 
                    184.01600000000002`}, {497.949, 183.375}, {
                    498.78499999999997`, 182.473}, {499.305, 182.086}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{528.3439999999999, 
                    173.71500000000003`}, {526.668, 175.00400000000008`}, {
                    522.3519999999999, 169.78500000000003`}, {
                    526.2810000000001, 165.988}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{487.39099999999996`, 
                    130.445}, {486.42199999999997`, 134.113}, {
                    489.83599999999996`, 135.08200000000005`}, {493.055, 
                    134.30900000000003`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{479.148, 156.457}, {
                    481.078, 157.74599999999998`}, {483.012, 
                    159.16400000000004`}, {485.46099999999996`, 159.805}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{478.121, 142.293}, {
                    478.121, 145.38299999999998`}, {479.66400000000004`, 
                    147.957}, {481.078, 148.73000000000002`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{489.449, 
                    177.83599999999996`}, {489.191, 174.10200000000003`}, {
                    490.73799999999994`, 170.49599999999998`}, {
                    491.89799999999997`, 168.56200000000007`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{520.102, 
                    177.57800000000003`}, {518.234, 177.}, {516.559, 
                    176.28900000000004`}, {515.8519999999999, 
                    174.74599999999998`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{518.039, 
                    167.02000000000004`}, {518.9409999999999, 
                    167.78900000000004`}, {519.9730000000001, 
                    168.69099999999997`}, {520.4219999999999, 
                    169.33599999999996`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{566.719, 279.445}, {
                    566.719, 275.84000000000003`}, {562.215, 273.906}, {
                    559.254, 276.22700000000003`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{576.512, 
                    279.31600000000003`}, {578.504, 277.77}, {585.395, 
                    279.25}, {583.7850000000001, 283.24199999999996`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{568.137, 258.582}, {
                    566.719, 258.84000000000003`}, {564.2730000000001, 
                    260.38700000000006`}, {563.242, 261.67199999999997`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{582.305, 269.273}, {
                    579.988, 268.75800000000004`}, {578.4409999999999, 
                    269.273}, {577.2810000000001, 269.785}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{545.73, 256.395}, {
                    547.016, 256.395}, {550.105, 256.90999999999997`}, {
                    552.234, 258.004}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{541.8669999999998, 
                    279.188}, {540.191, 279.379}, {538.9649999999999, 
                    279.05899999999997`}, {538.004, 278.414}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{567.8159999999999, 
                    272.879}, {567.3669999999998, 271.266}, {566.207, 
                    268.75800000000004`}, {564.7890000000001, 
                    267.65999999999997`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{537.488, 267.211}, {
                    540.707, 268.629}, {544.6990000000001, 
                    257.67999999999995`}, {552.4259999999999, 261.543}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{553.07, 272.879}, {
                    552.039, 271.461}, {551.398, 269.273}, {551.266, 
                    267.34000000000003`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{399.047, 289.621}, {
                    400.078, 289.746}, {401.879, 290.133}, {
                    402.26599999999996`, 291.422}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{266.527, 169.723}, {
                    270.39099999999996`, 167.531}, {273.09799999999996`, 
                    163.79700000000003`}, {271.42199999999997`, 
                    158.26200000000006`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{443.60200000000003`, 
                    301.469}, {444.762, 300.695}, {449.14500000000004`, 
                    300.695}, {451.59, 301.59799999999996`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{454.68, 298.891}, {
                    454.551, 297.09000000000003`}, {455.066, 290.262}, {
                    451.59, 288.84799999999996`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{452.875, 289.746}, {
                    456.09799999999996`, 288.719}, {462.53499999999997`, 
                    289.105}, {464.59799999999996`, 295.02700000000004`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{460.09, 290.004}, {
                    461.762, 287.43}, {462.277, 282.406}, {457.258, 279.703}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{461.375, 285.754}, {
                    465.10900000000004`, 284.469}, {473.73799999999994`, 
                    284.34000000000003`}, {472.83599999999996`, 
                    291.67999999999995`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{469.875, 285.754}, {
                    472.453, 282.14799999999997`}, {483.78499999999997`, 
                    277.898}, {481.984, 285.371}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{459.445, 275.324}, {
                    463.824, 274.293}, {470.008, 277.25800000000004`}, {
                    467.42999999999995`, 284.98400000000004`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{479.79299999999995`, 
                    281.121}, {480.43799999999993`, 278.156}, {
                    494.85900000000004`, 275.06600000000003`}, {
                    492.92999999999995`, 281.762}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{490.22299999999996`, 
                    277.898}, {492.92999999999995`, 271.719}, {
                    507.22299999999996`, 272.23400000000004`}, {502.715, 
                    280.477}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{500.39799999999997`, 
                    274.03499999999997`}, {503.22999999999996`, 
                    270.55899999999997`}, {515.8519999999999, 272.621}, {
                    510.828, 280.99199999999996`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{510.699, 274.164}, {
                    518.555, 268.24199999999996`}, {527.6990000000001, 
                    276.74199999999996`}, {517.7810000000001, 282.922}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{522.2890000000001, 
                    276.09799999999996`}, {529.246, 270.55899999999997`}, {
                    537.746, 280.605}, {531.691, 283.438}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{467.301, 278.414}, {
                    469.48799999999994`, 277.77}, {474.125, 
                    278.02700000000004`}, {475.156, 282.02}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{473.41799999999995`, 
                    279.31600000000003`}, {473.16, 273.457}, {483.012, 
                    271.203}, {485.52299999999997`, 277.96500000000003`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{482.23799999999994`, 
                    274.293}, {484.043, 270.43}, {492.668, 
                    268.88700000000006`}, {494.08599999999996`, 274.422}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{492.668, 
                    271.84799999999996`}, {494.08599999999996`, 
                    267.98400000000004`}, {501.555, 268.371}, {503.617, 
                    272.363}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{500.914, 269.785}, {
                    503.22999999999996`, 264.766}, {512.762, 264.766}, {
                    514.949, 272.105}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{513.277, 
                    268.88700000000006`}, {517.012, 266.56600000000003`}, {
                    524.996, 267.469}, {524.3519999999999, 
                    274.67999999999995`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{522.805, 
                    269.52700000000004`}, {528.3439999999999, 265.023}, {
                    536.1990000000001, 269.398}, {532.3359999999999, 277.}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{531.949, 263.605}, {
                    534.914, 264.121}, {536.4569999999999, 270.043}, {
                    533.3669999999998, 271.59000000000003`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{463.309, 
                    262.57399999999996`}, {469.48799999999994`, 265.922}, {
                    470.648, 271.59000000000003`}, {466.39799999999997`, 
                    277.129}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{468.59, 
                    268.24199999999996`}, {472.453, 265.922}, {
                    479.79299999999995`, 268.371}, {481.078, 
                    274.03499999999997`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{473.871, 
                    267.59799999999996`}, {476.055, 264.766}, {476.441, 
                    261.285}, {473.60900000000004`, 258.06600000000003`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{475.672, 
                    263.99199999999996`}, {482.4959999999999, 
                    268.24199999999996`}, {490.9959999999999, 
                    260.38700000000006`}, {484.688, 255.621}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{483.527, 264.379}, {
                    485.074, 264.766}, {487.777, 267.59799999999996`}, {
                    488.03099999999995`, 270.81600000000003`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{486.617, 261.414}, {
                    489.449, 264.379}, {508.77, 258.324}, {
                    496.53099999999995`, 252.14499999999998`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{495.633, 
                    269.52700000000004`}, {499.367, 268.11299999999994`}, {
                    501.301, 262.832}, {495.633, 261.031}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{500.527, 256.652}, {
                    504.648, 260.902}, {517.5269999999999, 258.195}, {512.891,
                     252.78900000000002`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{509.801, 258.324}, {
                    512.117, 266.17999999999995`}, {525.898, 261.285}, {
                    521.391, 258.06600000000003`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{506.965, 
                    266.17999999999995`}, {507.35200000000003`, 264.637}, {
                    507.47999999999996`, 260.773}, {504.90599999999995`, 
                    258.711}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{518.555, 
                    267.72700000000003`}, {519.07, 266.438}, {
                    518.9409999999999, 263.99199999999996`}, {
                    517.7810000000001, 262.445}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{527.3119999999999, 
                    267.59799999999996`}, {528.086, 266.17999999999995`}, {
                    529.375, 263.477}, {526.539, 261.285}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{417.078, 326.836}, {
                    417.203, 319.496}, {419.78099999999995`, 314.602}, {
                    429.695, 319.238}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{420.168, 318.082}, {
                    415.27299999999997`, 311.51199999999994`}, {420.809, 
                    304.43}, {430.469, 311.51199999999994`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{405.10200000000003`, 
                    314.85900000000004`}, {411.79699999999997`, 
                    307.64799999999997`}, {423.77299999999997`, 312.93}, {
                    416.047, 323.875}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{424.16, 
                    308.67999999999995`}, {422.871, 301.59799999999996`}, {
                    428.668, 300.17999999999995`}, {433.42999999999995`, 
                    303.398}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{399.172, 313.703}, {
                    400.395, 306.582}, {407.672, 300.953}, {414.758, 
                    305.332}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{407.93399999999997`, 
                    303.914}, {407.93399999999997`, 293.74199999999996`}, {
                    421.969, 292.582}, {425.191, 303.14099999999996`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{420.168, 296.703}, {
                    424.672, 287.43}, {434.46099999999996`, 291.164}, {437.68,
                     296.832}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{410.25, 
                    311.51199999999994`}, {412.055, 307.004}, {415.66, 
                    301.98}, {424.03099999999995`, 305.719}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{384.49199999999996`, 
                    313.703}, {385.65200000000004`, 309.969}, {
                    392.35200000000003`, 305.461}, {400.078, 310.609}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{389.258, 308.938}, {
                    385.137, 302.88300000000004`}, {393.379, 297.219}, {
                    403.29699999999997`, 306.23}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{394.15200000000004`, 
                    301.469}, {395.828, 292.969}, {399.172, 
                    286.14099999999996`}, {411.28099999999995`, 
                    297.09000000000003`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{405.227, 292.711}, {
                    409.605, 287.30100000000004`}, {416.305, 283.953}, {
                    422.613, 293.09799999999996`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{427.25, 
                    291.164}, {426.863, 284.72700000000003`}, {428.148, 
                    281.508}, {433.172, 281.762}, {437.133, 
                    281.96500000000003`}, {440.89799999999997`, 
                    285.11299999999994`}, {443.09, 288.461}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{432.27299999999997`, 
                    281.762}, {432.14500000000004`, 274.422}, {
                    437.93799999999993`, 268.629}, {448.758, 
                    276.09799999999996`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{436.78099999999995`, 
                    273.137}, {434.719, 267.59799999999996`}, {
                    440.89799999999997`, 258.582}, {453.008, 263.219}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{411.148, 
                    287.81600000000003`}, {410.379, 280.73400000000004`}, {
                    416.945, 275.969}, {427.508, 285.11299999999994`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{416.305, 279.961}, {
                    416.691, 274.164}, {423.258, 267.211}, {
                    432.91799999999995`, 277.25800000000004`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{420.941, 272.621}, {
                    420.168, 262.703}, {429.309, 259.871}, {
                    437.03499999999997`, 267.469}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{407.16, 279.961}, {
                    409.219, 279.832}, {410.895, 281.633}, {
                    411.92199999999997`, 282.922}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{411.53499999999997`, 
                    272.75}, {413.34000000000003`, 272.363}, {
                    416.43399999999997`, 274.03499999999997`}, {417.465, 
                    276.09799999999996`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{416.047, 261.031}, {
                    418.105, 258.84000000000003`}, {425.059, 
                    260.38700000000006`}, {425.96099999999996`, 
                    263.34799999999996`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{423.77299999999997`, 
                    261.15999999999997`}, {427.637, 252.14499999999998`}, {
                    437.93799999999993`, 252.531}, {442.188, 262.703}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{440.258, 
                    259.09799999999996`}, {442.188, 253.816}, {447.082, 
                    250.469}, {455.066, 252.273}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{444.121, 253.688}, {
                    439.613, 246.34799999999998`}, {445.53499999999997`, 
                    237.719}, {455.578, 246.219}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{446.566, 242.742}, {
                    446.055, 238.105}, {450.305, 232.824}, {
                    456.09799999999996`, 232.184}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{427.508, 256.266}, {
                    425.96099999999996`, 245.832}, {433.42999999999995`, 
                    240.81199999999998`}, {442.832, 246.34799999999998`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{416.559, 251.242}, {
                    419.008, 249.309}, {423.387, 249.05100000000002`}, {
                    427.508, 250.59799999999998`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{432.53099999999995`, 
                    244.547}, {430.21099999999996`, 235.78900000000002`}, {
                    439.227, 229.477}, {446.953, 239.26600000000002`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{420.03499999999997`, 
                    249.824}, {420.168, 245.316}, {424.547, 
                    240.42600000000002`}, {432.14500000000004`, 241.84}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{453.395, 232.824}, {
                    448.23799999999994`, 229.34799999999998`}, {
                    447.21099999999996`, 223.168}, {454.42199999999997`, 
                    219.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{440.77, 234.629}, {
                    441.03099999999995`, 229.34799999999998`}, {443.477, 
                    226.38700000000003`}, {449.27, 225.871}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{433.172, 237.332}, {
                    425.445, 230.25}, {433.043, 222.00800000000004`}, {
                    442.188, 228.961}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{438.582, 226.773}, {
                    436.008, 218.65999999999997`}, {445.668, 
                    213.76600000000002`}, {450.816, 222.00800000000004`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{422.613, 244.031}, {
                    419.78099999999995`, 236.047}, {423.387, 
                    230.76600000000002`}, {429.953, 231.28100000000003`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{412.441, 
                    245.57399999999998`}, {412.828, 240.81199999999998`}, {
                    416.945, 239.137}, {421.582, 240.16799999999998`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{415.39799999999997`, 
                    240.555}, {411.92199999999997`, 233.85500000000002`}, {
                    417.203, 230.25}, {424.16, 232.824}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{445.28099999999995`, 
                    217.887}, {444.121, 213.637}, {444.762, 
                    210.54700000000003`}, {451.074, 209.12900000000002`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{445.668, 
                    211.83599999999996`}, {438.066, 208.35499999999996`}, {
                    437.42199999999997`, 201.01600000000002`}, {443.348, 
                    196.25}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{439.547, 
                    220.01200000000006`}, {435.555, 216.406}, {436.328, 
                    210.15999999999997`}, {440.707, 207.71500000000003`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{405.742, 243.516}, {
                    401.363, 239.19899999999998`}, {405.551, 
                    227.28900000000002`}, {415.207, 233.793}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{430.855, 
                    228.44899999999998`}, {424.92999999999995`, 223.555}, {
                    427.637, 214.668}, {437.42199999999997`, 217.113}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{421.066, 232.184}, {
                    417.977, 223.426}, {420.941, 220.33599999999996`}, {
                    427.895, 220.20700000000005`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{399.305, 
                    243.902}, {394.02299999999997`, 239.91}, {395.441, 
                    234.242}, {397.758, 231.66799999999998`}, {400.078, 
                    229.09}, {404.453, 230.25}, {405.871, 
                    233.59799999999998`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{388.227, 247.379}, {
                    382.305, 239.78100000000003`}, {388.227, 
                    230.76600000000002`}, {396.60200000000003`, 233.469}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    419.90999999999997`, 224.84}, {413.855, 222.652}, {
                    409.23799999999994`, 217.15599999999995`}, {412.953, 
                    212.34799999999996`}, {415.14500000000004`, 
                    209.51600000000002`}, {424.672, 209.12900000000002`}, {
                    427.375, 220.07800000000003`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{408.965, 
                    231.92600000000002`}, {405.48799999999994`, 226.902}, {
                    406.64500000000004`, 222.137}, {413.082, 
                    219.69099999999997`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{408.578, 
                    222.52300000000002`}, {404.84000000000003`, 220.461}, {
                    402.395, 218.01600000000002`}, {403.29699999999997`, 
                    213.50800000000004`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{400.207, 230.379}, {
                    398.789, 224.328}, {400.465, 220.59000000000003`}, {
                    404.195, 218.78900000000004`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{400.078, 223.168}, {
                    394.28099999999995`, 223.555}, {391.32, 
                    221.10500000000002`}, {393.25, 215.44099999999997`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{393.76599999999996`, 
                    221.75}, {388.10200000000003`, 223.812}, {387.195, 
                    228.703}, {389.64500000000004`, 233.85500000000002`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{388.871, 226.258}, {
                    382.691, 226.}, {379.98799999999994`, 
                    222.91000000000003`}, {379.98799999999994`, 
                    218.65999999999997`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{380.5, 
                    250.34}, {375.99199999999996`, 248.41}, {374.578, 
                    242.35500000000002`}, {376.25, 239.00799999999998`}, {
                    377.92599999999993`, 235.66}, {383.207, 235.402}, {
                    386.42599999999993`, 237.59}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{367.879, 255.105}, {
                    363.758, 250.469}, {368.52299999999997`, 241.453}, {
                    375.867, 243.64499999999998`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{357.32, 258.711}, {
                    353.457, 253.30100000000002`}, {357.707, 
                    244.28900000000002`}, {367.621, 246.863}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{368.137, 221.75}, {
                    367.105, 228.191}, {373.805, 232.441}, {382.047, 224.07}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{378.055, 
                    237.07399999999998`}, {375.605, 234.88700000000003`}, {
                    374.449, 231.41}, {374.832, 228.57799999999997`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{346.758, 
                    261.80100000000004`}, {342.508, 254.59}, {
                    347.66400000000004`, 248.023}, {356.805, 
                    250.59799999999998`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{370.58599999999996`, 
                    243.902}, {364.53099999999995`, 237.84799999999998`}, {
                    366.594, 231.79700000000003`}, {371.10200000000003`, 
                    228.32}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{366.719, 236.816}, {
                    357.578, 236.691}, {357.062, 226.129}, {
                    364.53099999999995`, 222.781}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{359.76599999999996`, 
                    247.379}, {356.03099999999995`, 244.805}, {354.871, 
                    237.719}, {361.312, 234.88700000000003`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{359.508, 231.539}, {
                    355.64500000000004`, 233.34}, {351.008, 231.152}, {
                    351.395, 226.64499999999998`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{353.715, 231.41}, {
                    350.234, 239.652}, {340.062, 238.234}, {340.965, 
                    229.734}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{356.547, 241.582}, {
                    354.35900000000004`, 241.195}, {349.97999999999996`, 
                    239.91}, {348.305, 236.559}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{348.949, 
                    250.85500000000002`}, {344.828, 246.219}, {348.047, 
                    240.684}, {351.395, 239.523}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{336.715, 263.863}, {
                    335.941, 258.324}, {338.133, 255.621}, {
                    345.08599999999996`, 256.137}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{339.16400000000004`, 
                    256.78100000000006`}, {336.457, 250.082}, {340.062, 
                    247.121}, {347.01599999999996`, 247.50799999999998`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{340.707, 248.539}, {
                    336.58599999999996`, 243.64499999999998`}, {
                    339.41799999999995`, 238.363}, {343.40999999999997`, 
                    236.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{338.777, 
                    242.35500000000002`}, {331.43799999999993`, 243.258}, {
                    330.277, 234.758}, {332.72299999999996`, 
                    230.76600000000002`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    332.85200000000003`, 264.508}, {328.34400000000005`, 
                    262.57399999999996`}, {325.77, 256.90999999999997`}, {
                    328.215, 253.43}, {330.66400000000004`, 249.953}, {
                    335.555, 251.11299999999997`}, {338.258, 
                    252.91799999999998`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{329.758, 
                    251.88700000000003`}, {326.027, 246.219}, {329.371, 
                    241.969}, {333.367, 240.29700000000003`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    315.33599999999996`, 265.152}, {312.375, 
                    262.05899999999997`}, {314.176, 255.75}, {
                    321.39099999999996`, 255.621}, {327.195, 255.516}, {
                    330.14500000000004`, 261.031}, {328.34400000000005`, 
                    264.895}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{320.35900000000004`, 
                    255.621}, {318.043, 250.469}, {319.457, 244.93}, {328.215,
                     245.832}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{331.949, 237.719}, {
                    326.539, 240.16799999999998`}, {319.328, 237.719}, {
                    322.42199999999997`, 231.28100000000003`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{321.648, 246.863}, {
                    319.457, 243.773}, {320.22999999999996`, 239.395}, {
                    322.676, 236.691}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{321.262, 238.621}, {
                    317.656, 237.977}, {314.176, 236.047}, {316.367, 
                    230.379}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{315.85200000000003`, 
                    235.016}, {311.215, 236.434}, {305.29299999999995`, 
                    233.082}, {308.89799999999997`, 228.32}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{308.125, 232.824}, {
                    304.133, 233.469}, {299.367, 229.219}, {
                    303.22999999999996`, 224.969}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{301.688, 
                    228.44899999999998`}, {298.078, 227.547}, {293.832, 
                    223.426}, {297.566, 220.20700000000005`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{319.84400000000005`, 
                    248.66799999999998`}, {314.691, 246.34799999999998`}, {
                    314.176, 240.555}, {316.625, 236.305}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{314.43399999999997`, 
                    259.355}, {306.707, 256.395}, {306.83599999999996`, 
                    246.09}, {315.33599999999996`, 242.871}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{311.72999999999996`, 
                    245.188}, {307.094, 242.484}, {306.191, 237.332}, {
                    309.28499999999997`, 233.984}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{303.617, 263.219}, {
                    300.527, 262.188}, {300.78499999999997`, 252.66}, {
                    309.027, 252.91799999999998`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{295.117, 260.}, {
                    288.93799999999993`, 255.879}, {296.40599999999995`, 
                    245.445}, {306.449, 252.91799999999998`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{300.914, 250.34}, {
                    300.012, 246.09}, {301.172, 241.453}, {307.9959999999999, 
                    240.938}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{301.301, 244.676}, {
                    296.40599999999995`, 242.871}, {295.504, 232.824}, {
                    304.39099999999996`, 232.055}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{285.715, 253.816}, {
                    279.40599999999995`, 248.023}, {290.867, 243.}, {295.117, 
                    251.371}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{276.96099999999996`, 
                    244.16}, {273.867, 240.42600000000002`}, {284.688, 
                    230.637}, {289.453, 246.992}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{290.60900000000004`, 
                    247.25}, {290.867, 243.38700000000003`}, {293.188, 
                    241.066}, {297.949, 240.81199999999998`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{297.824, 
                    237.07399999999998`}, {290.22299999999996`, 
                    235.91799999999998`}, {287.777, 226.38700000000003`}, {
                    296.277, 224.328}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{283.78499999999997`, 
                    238.363}, {283.527, 234.758}, {287.262, 
                    231.79700000000003`}, {291.512, 232.441}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{295.375, 224.582}, {
                    288.42199999999997`, 223.03900000000004`}, {287.52, 
                    214.02300000000002`}, {293.703, 214.53900000000004`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{290.47999999999996`, 
                    206.168}, {284.688, 207.906}, {284.559, 
                    214.79700000000003`}, {289.707, 217.37099999999998`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{285.715, 
                    212.223}, {280.824, 209.25799999999998`}, {282.754, 
                    202.176}, {285.332, 201.14499999999998`}, {
                    287.90599999999995`, 200.113}, {289.965, 
                    201.40200000000004`}, {290.22299999999996`, 
                    203.59400000000005`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{289.83599999999996`, 
                    193.676}, {290.35200000000003`, 190.32799999999997`}, {
                    277.92599999999993`, 191.61700000000002`}, {284.301, 
                    202.04700000000003`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{284.234, 193.098}, {
                    280.051, 186.52700000000004`}, {286.875, 
                    181.18400000000003`}, {291.191, 186.78500000000003`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{284.816, 185.176}, {
                    283.141, 179.89499999999998`}, {289.51599999999996`, 
                    176.098}, {293.637, 180.21900000000005`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{270.90599999999995`, 
                    234.629}, {268.59, 229.863}, {280.18, 
                    228.06199999999998`}, {280.953, 237.84799999999998`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{267.688, 227.547}, {
                    265.371, 218.27300000000002`}, {282.883, 
                    220.20700000000005`}, {278.375, 232.184}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{278.762, 226.}, {
                    281.21099999999996`, 224.582}, {288.551, 
                    224.45700000000002`}, {290.35200000000003`, 
                    232.31199999999998`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{285.074, 225.742}, {
                    285.59, 223.29700000000003`}, {287.777, 
                    220.33599999999996`}, {289.83599999999996`, 
                    219.43400000000003`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{276.703, 
                    223.29700000000003`}, {275.92999999999995`, 
                    218.27300000000002`}, {280.953, 214.152}, {286.746, 
                    214.53900000000004`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{277.60200000000003`, 
                    218.40200000000004`}, {274.77, 214.53900000000004`}, {
                    273.867, 207.07000000000005`}, {282.754, 206.555}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{264.082, 217.113}, {
                    262.66400000000004`, 213.12099999999998`}, {
                    271.03499999999997`, 209.}, {275.92999999999995`, 
                    215.57000000000005`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{261.504, 
                    206.94099999999997`}, {260.79699999999997`, 
                    203.91400000000004`}, {268.332, 199.85899999999998`}, {
                    272.582, 212.73400000000004`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{269.234, 206.168}, {
                    271.03499999999997`, 202.949}, {277.09, 
                    200.37099999999998`}, {280.824, 206.68400000000003`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{274.77, 202.82}, {
                    273.227, 198.312}, {277.477, 194.06200000000007`}, {
                    282.625, 195.35199999999998`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{265.113, 
                    203.85199999999998`}, {264.082, 197.41000000000003`}, {
                    271.551, 193.676}, {276.188, 197.02300000000002`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{260.219, 
                    201.01600000000002`}, {258.027, 192.77300000000002`}, {
                    268.59, 189.68400000000003`}, {272.582, 
                    195.86700000000002`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{269.875, 193.418}, {
                    270.262, 188.781}, {277.477, 184.78900000000004`}, {
                    283.141, 188.652}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{257., 189.555}, {256.484,
                     187.49599999999998`}, {265.113, 185.43400000000003`}, {
                    266.39799999999997`, 192.64499999999998`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{262.02, 
                    187.75400000000002`}, {264.082, 182.473}, {
                    271.03499999999997`, 181.18400000000003`}, {275.027, 
                    187.625}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{272.71099999999996`, 
                    185.04700000000003`}, {273.60900000000004`, 180.152}, {
                    279.92199999999997`, 177.449}, {285.46099999999996`, 
                    180.79700000000003`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{287.777, 
                    178.86700000000002`}, {286.35900000000004`, 
                    172.29700000000003`}, {293.188, 167.02000000000004`}, {
                    297.43799999999993`, 170.625}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{276.832, 
                    180.02300000000002`}, {274.77, 172.812}, {
                    283.78499999999997`, 168.69099999999997`}, {288.809, 
                    172.68400000000003`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{266.012, 
                    183.62900000000002`}, {265.4959999999999, 
                    176.93400000000003`}, {270.777, 172.94099999999997`}, {
                    276.832, 175.90200000000004`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{254.55100000000002`, 
                    182.988}, {252.75, 178.60900000000004`}, {262.277, 
                    175.00400000000008`}, {266.78499999999997`, 178.738}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{248.629, 
                    171.01200000000006`}, {251.07399999999998`, 168.176}, {
                    259.574, 171.01200000000006`}, {260.348, 177.32}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{258.027, 
                    172.68400000000003`}, {261.121, 169.07800000000003`}, {
                    268.46099999999996`, 167.14799999999997`}, {
                    271.42199999999997`, 174.875}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{268.848, 
                    170.88299999999998`}, {268.719, 165.344}, {278.633, 
                    161.35199999999998`}, {281.85200000000003`, 
                    171.52700000000004`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{293.508, 
                    169.52700000000004`}, {292.605, 166.824}, {
                    294.72999999999996`, 162.51200000000006`}, {299.176, 
                    161.99599999999998`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{285.332, 
                    171.20300000000003`}, {284.688, 168.113}, {289.195, 
                    163.79700000000003`}, {293.957, 165.53500000000003`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{294.85900000000004`, 
                    164.25}, {293.574, 160.89799999999997`}, {294.668, 
                    156.07000000000005`}, {299.176, 156.137}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{295.312, 
                    158.00400000000008`}, {291.96099999999996`, 
                    155.17200000000003`}, {293.379, 150.14799999999997`}, {
                    298.207, 149.95299999999997`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{293.574, 153.238}, {
                    288.809, 150.02000000000004`}, {290.47999999999996`, 
                    142.938}, {296.79299999999995`, 143.32}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{279.148, 
                    166.89099999999996`}, {279.148, 159.93400000000003`}, {
                    287.777, 158.906}, {289.453, 165.344}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{286.10200000000003`, 
                    161.223}, {284.816, 157.10200000000003`}, {
                    288.16400000000004`, 153.10900000000004`}, {293.445, 
                    154.27000000000004`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{287.133, 
                    111.51200000000006`}, {288.29299999999995`, 
                    109.83599999999996`}, {293.059, 112.67200000000003`}, {
                    291.77, 115.50400000000008`}, {290.47999999999996`, 
                    118.33599999999996`}, {285.43399999999997`, 
                    116.79700000000003`}, {285.97299999999996`, 113.832}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{290.60900000000004`, 
                    116.66400000000004`}, {291.254, 122.332}, {284.559, 
                    123.23000000000002`}, {282.883, 118.33599999999996`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{285.332, 
                    121.17200000000003`}, {287.004, 124.00400000000008`}, {
                    281.34000000000003`, 127.86700000000002`}, {279.02, 
                    123.74599999999998`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{281.082, 
                    125.42200000000003`}, {282.625, 129.543}, {276.188, 
                    131.344}, {275.672, 127.60900000000004`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{274.254, 
                    133.02000000000004`}, {275.027, 135.08200000000005`}, {
                    282.23799999999994`, 133.793}, {279.148, 129.543}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{284.688, 
                    124.39099999999996`}, {287.52, 126.96500000000003`}, {
                    282.754, 132.24599999999998`}, {279.79299999999995`, 
                    130.312}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{303.746, 
                    116.53500000000003`}, {301.49199999999996`, 
                    116.27700000000004`}, {299.176, 114.79700000000003`}, {
                    300.848, 110.031}, {302.008, 106.72300000000001`}, {
                    306.965, 106.555}, {307.672, 108.55099999999999`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    300.46099999999996`, 114.15199999999999`}, {
                    298.27299999999997`, 115.57000000000005`}, {293.508, 
                    113.18799999999999`}, {295.695, 108.55099999999999`}, {
                    297.34400000000005`, 105.05900000000003`}, {
                    301.49199999999996`, 106.488}, {302.137, 108.293}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{288.16400000000004`, 
                    107.52000000000004`}, {289.258, 105.59000000000003`}, {
                    294.72999999999996`, 106.42200000000003`}, {295.695, 
                    108.55099999999999`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{291.89799999999997`, 
                    113.89499999999998`}, {293.059, 114.668}, {295.18, 
                    113.70300000000003`}, {295.633, 112.738}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{291.512, 
                    145.64099999999996`}, {287.777, 143.195}, {290.094, 
                    135.723}, {295.89099999999996`, 137.65599999999995`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{290.35200000000003`, 
                    139.586}, {287.39099999999996`, 137.27000000000004`}, {
                    290.094, 130.05900000000003`}, {295.633, 
                    132.76200000000006`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{291.254, 
                    132.76200000000006`}, {289.195, 130.699}, {291.191, 
                    124.96900000000005`}, {296.53499999999997`, 
                    126.06200000000007`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{290.47999999999996`, 
                    129.926}, {289.324, 130.445}, {286.29699999999997`, 
                    130.05900000000003`}, {285.008, 128.125}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{287.133, 
                    156.00800000000004`}, {284.301, 153.301}, {
                    285.65200000000004`, 147.76200000000006`}, {
                    290.93399999999997`, 147.312}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{286.10200000000003`, 
                    150.33999999999997`}, {282.047, 148.344}, {282.047, 
                    140.29700000000003`}, {290.16, 139.973}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{285.78099999999995`, 
                    141.26200000000006`}, {283.527, 139.457}, {284.621, 
                    132.50400000000008`}, {290.41799999999995`, 133.406}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{287.648, 
                    133.66400000000004`}, {286.812, 132.82799999999997`}, {
                    286.684, 130.699}, {287.39099999999996`, 129.801}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{285.074, 136.305}, {
                    283.012, 136.238}, {280.309, 134.75799999999998`}, {
                    279.59799999999996`, 132.63299999999998`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{275.863, 
                    140.10200000000003`}, {276.637, 142.16400000000004`}, {
                    283.012, 142.03500000000003`}, {283.46099999999996`, 
                    135.98000000000002`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{284.105, 143.195}, {
                    283.203, 143.}, {281.469, 142.16400000000004`}, {
                    281.01599999999996`, 140.42200000000003`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{281.34000000000003`, 
                    162.05900000000003`}, {278.57, 159.54700000000003`}, {
                    277.219, 151.62900000000002`}, {285.65200000000004`, 
                    150.08200000000005`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{275.734, 
                    145.70300000000003`}, {275.734, 147.832}, {281.469, 
                    149.63299999999998`}, {283.46099999999996`, 
                    146.47700000000003`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{272.066, 
                    157.23000000000002`}, {272.902, 155.62099999999998`}, {
                    276.895, 153.43}, {279.34000000000003`, 
                    155.23400000000004`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    251.33200000000002`, 169.85199999999998`}, {
                    251.20299999999997`, 166.11700000000002`}, {
                    254.29299999999998`, 162.77000000000004`}, {258.543, 
                    163.281}, {262.79299999999995`, 163.79700000000003`}, {
                    263.695, 167.531}, {262.40599999999995`, 
                    169.98000000000002`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{259.188, 
                    163.15599999999995`}, {256.355, 159.676}, {259.832, 
                    154.78500000000003`}, {263.051, 156.199}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{262.40599999999995`, 
                    165.60200000000003`}, {264.082, 166.24599999999998`}, {
                    269.617, 167.02000000000004`}, {271.29299999999995`, 
                    164.44099999999997`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{244.508, 
                    164.57000000000005`}, {243.21899999999997`, 
                    162.64099999999996`}, {251.20299999999997`, 
                    160.70700000000005`}, {253.906, 164.44099999999997`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{251.20299999999997`, 
                    162.51200000000006`}, {250.945, 159.93400000000003`}, {
                    252.23399999999998`, 155.555}, {258.801, 
                    157.35899999999998`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{259.832, 
                    153.36700000000002`}, {260.863, 155.555}, {255.969, 
                    159.16400000000004`}, {252.23399999999998`, 
                    155.17200000000003`}, {248.5, 151.18}, {252.75, 
                    146.67200000000003`}, {255.066, 148.21500000000003`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{242.70299999999997`, 
                    161.99599999999998`}, {240.77299999999997`, 
                    158.64799999999997`}, {248.242, 152.531}, {
                    252.49200000000002`, 158.195}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    237.74599999999998`, 156.199}, {235.039, 153.43}, {
                    238.38700000000003`, 148.344}, {242.445, 
                    149.89099999999996`}, {246.5, 151.43400000000003`}, {
                    246.117, 155.68400000000003`}, {245.148, 
                    156.77700000000004`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{232.531, 
                    151.04700000000003`}, {230.34, 149.055}, {232.465, 
                    144.35199999999998`}, {235.49200000000002`, 
                    144.35199999999998`}, {238.516, 144.35199999999998`}, {
                    240.38700000000003`, 146.73400000000004`}, {239.805, 
                    149.76200000000006`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{244.82800000000003`, 
                    151.43400000000003`}, {244.441, 148.473}, {
                    248.82000000000002`, 146.41400000000004`}, {
                    251.65200000000002`, 149.18}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{251.781, 
                    154.59000000000003`}, {252.168, 155.23400000000004`}, {
                    251.848, 156.32799999999997`}, {251.20299999999997`, 
                    156.844}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{227.82800000000003`, 
                    147.05900000000003`}, {225.316, 145.05900000000003`}, {
                    230.727, 139.52300000000002`}, {234.137, 
                    144.60900000000004`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{247.21099999999998`, 
                    148.14799999999997`}, {245.602, 146.60500000000002`}, {
                    248.176, 142.551}, {250.75, 143.77300000000002`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{238.38700000000003`, 
                    145.31599999999997`}, {238.77299999999997`, 142.551}, {
                    244.184, 140.488}, {247.598, 144.738}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{241.35200000000003`, 
                    142.551}, {240.516, 140.80900000000003`}, {
                    242.18800000000002`, 138.03900000000004`}, {244.25, 
                    138.426}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{292.605, 
                    126.64499999999998`}, {290.60900000000004`, 
                    122.71500000000003`}, {296.984, 118.14499999999998`}, {
                    301.621, 122.91000000000003`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{297.242, 
                    120.78500000000003`}, {296.277, 118.65999999999997`}, {
                    297.43799999999993`, 115.695}, {299.176, 
                    114.60200000000003`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{291.191, 
                    116.33999999999997`}, {291.641, 118.27300000000002`}, {
                    294.40999999999997`, 120.07800000000003`}, {
                    296.92199999999997`, 119.17200000000003`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{287.84000000000003`, 
                    121.43}, {288.227, 123.168}, {290.547, 124.906}, {
                    292.28499999999997`, 124.45299999999997`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{439.484, 
                    201.78900000000004`}, {430.34000000000003`, 
                    201.65999999999997`}, {434.203, 186.98000000000002`}, {
                    442.059, 189.94099999999997`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{436.52299999999997`, 
                    190.973}, {434.719, 188.00800000000004`}, {438.195, 
                    183.30900000000003`}, {442.059, 186.07800000000003`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{441.03099999999995`, 
                    185.49599999999998`}, {438.324, 180.99200000000002`}, {
                    447.984, 174.10200000000003`}, {451.848, 
                    181.18400000000003`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{448.758, 
                    178.48000000000002`}, {448.883, 174.23000000000002`}, {
                    461.246, 171.52700000000004`}, {459.445, 
                    180.02300000000002`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{458.28499999999997`, 
                    175.39099999999996`}, {461.246, 170.36700000000002`}, {
                    472.324, 169.85199999999998`}, {471.16400000000004`, 
                    177.32}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{468.715, 172.168}, {
                    471.03499999999997`, 168.82}, {481.85200000000003`, 
                    166.76200000000006`}, {481.465, 173.71500000000003`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{424.805, 
                    214.53900000000004`}, {426.348, 210.54700000000003`}, {
                    431.625, 209.12900000000002`}, {437.42199999999997`, 
                    211.449}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{421.453, 
                    211.70700000000005`}, {425.059, 209.387}, {
                    419.78099999999995`, 198.82799999999997`}, {414.242, 
                    203.07800000000003`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{421.453, 205.137}, {
                    425.445, 203.20700000000005`}, {430.34000000000003`, 
                    204.62099999999998`}, {431.758, 210.28900000000004`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{429.309, 
                    205.91000000000003`}, {429.695, 202.949}, {433.945, 
                    200.62900000000002`}, {439.484, 201.78900000000004`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{419.395, 202.82}, {
                    424.547, 198.44099999999997`}, {417.078, 189.426}, {
                    413.727, 193.54700000000003`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{421.328, 199.473}, {
                    423.77299999999997`, 197.668}, {430.082, 198.699}, {
                    430.727, 203.46500000000003`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{427.895, 199.473}, {
                    428.40999999999997`, 196.37900000000002`}, {430.855, 
                    195.223}, {434.332, 195.09400000000005`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{419.90999999999997`, 
                    195.223}, {422.484, 191.61700000000002`}, {
                    428.92199999999997`, 190.586}, {431.758, 
                    195.35199999999998`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{428.92199999999997`, 
                    192.64499999999998`}, {428.668, 189.168}, {
                    432.53099999999995`, 186.33599999999996`}, {
                    436.52299999999997`, 187.10900000000004`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{414.887, 184.918}, {
                    418.234, 183.24599999999998`}, {421.84000000000003`, 
                    189.555}, {419.008, 193.93400000000003`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{418.75, 178.223}, {
                    422.742, 177.96500000000003`}, {423.258, 
                    184.01600000000002`}, {419.52299999999997`, 
                    187.36700000000002`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{427.895, 
                    172.68400000000003`}, {431.242, 173.457}, {
                    430.21099999999996`, 180.79700000000003`}, {
                    422.09799999999996`, 181.44099999999997`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{438.066, 
                    167.27700000000004`}, {441.28499999999997`, 168.176}, {
                    438.71099999999996`, 176.28900000000004`}, {429.828, 
                    175.77300000000002`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{450.305, 
                    164.44099999999997`}, {452.48799999999994`, 
                    167.78900000000004`}, {445.28099999999995`, 173.457}, {
                    439.355, 170.49599999999998`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{456.35200000000003`, 
                    159.805}, {460.348, 158.64799999999997`}, {463.051, 
                    169.20700000000005`}, {450.42999999999995`, 167.531}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{463.691, 159.805}, {
                    467.172, 160.70700000000005`}, {469.621, 
                    167.02000000000004`}, {459.445, 164.957}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{471.42199999999997`, 
                    159.293}, {474.512, 157.74599999999998`}, {
                    475.92999999999995`, 166.76200000000006`}, {466.527, 
                    164.312}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{419.52299999999997`, 
                    187.36700000000002`}, {423.387, 185.176}, {429.441, 
                    187.75400000000002`}, {428.92199999999997`, 
                    192.64499999999998`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{427.375, 
                    188.39499999999998`}, {428.668, 186.07800000000003`}, {
                    428.148, 181.57000000000005`}, {425.703, 
                    180.41000000000003`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{427.762, 182.988}, {
                    430.34000000000003`, 181.957}, {433.816, 
                    182.85899999999998`}, {435.875, 186.98000000000002`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{432.27299999999997`, 
                    182.988}, {433.043, 181.18400000000003`}, {433.305, 
                    177.57800000000003`}, {431.625, 175.77300000000002`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{432.91799999999995`, 
                    179.89499999999998`}, {435.75, 178.35199999999998`}, {
                    439.09799999999996`, 180.41000000000003`}, {440.512, 
                    183.375}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{438.71099999999996`, 
                    180.79700000000003`}, {440.77, 179.51200000000006`}, {
                    442.574, 173.457}, {439.09799999999996`, 
                    171.01200000000006`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{441.03099999999995`, 
                    173.844}, {443.477, 173.71500000000003`}, {447.082, 
                    173.71500000000003`}, {449.39799999999997`, 176.805}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{447.727, 
                    175.13299999999998`}, {449.91799999999995`, 174.488}, {
                    452.48799999999994`, 170.88299999999998`}, {451.59, 
                    167.65999999999997`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{451.715, 168.82}, {
                    454.168, 169.07800000000003`}, {458.414, 
                    170.75400000000002`}, {459.574, 173.71500000000003`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{458.414, 171.781}, {
                    460.477, 170.625}, {461.895, 168.176}, {461.633, 
                    165.344}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{461.633, 167.406}, {
                    464.078, 167.531}, {466.27, 168.82}, {466.914, 
                    171.52700000000004`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{466.27, 169.723}, {
                    468.074, 169.07800000000003`}, {470.262, 
                    167.02000000000004`}, {470.395, 164.57000000000005`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{470.133, 
                    166.11700000000002`}, {471.93799999999993`, 166.375}, {
                    473.22299999999996`, 167.531}, {474.383, 
                    169.33599999999996`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{479.277, 
                    169.59400000000005`}, {481.59799999999996`, 
                    167.27700000000004`}, {478.508, 159.54700000000003`}, {
                    473.73799999999994`, 160.96500000000003`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{429.828, 
                    325.67999999999995`}, {425.059, 322.844}, {
                    411.53499999999997`, 323.746}, {418.234, 
                    334.94899999999996`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{431.113, 
                    333.27700000000004`}, {421.715, 329.543}, {410.121, 
                    336.754}, {422.227, 344.609}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{419.008, 
                    347.18399999999997`}, {411.148, 347.18399999999997`}, {
                    405.871, 334.562}, {416.43399999999997`, 330.188}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    388.48799999999994`, 341.906}, {386.42599999999993`, 
                    337.914}, {393.76599999999996`, 333.53499999999997`}, {
                    398.789, 337.52700000000004`}, {402.68, 340.621}, {
                    402.395, 348.988}, {400.078, 352.207}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{384.49199999999996`, 
                    332.375}, {381.91799999999995`, 323.875}, {
                    400.85200000000003`, 323.35900000000004`}, {397.887, 
                    336.88300000000004`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{383.465, 319.754}, {
                    384.105, 313.31600000000003`}, {401.625, 315.375}, {
                    395.953, 328.38300000000004`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{398.01599999999996`, 
                    331.988}, {399.43399999999997`, 330.05899999999997`}, {
                    403.29699999999997`, 326.707}, {409.863, 327.352}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{401.105, 341.133}, {
                    401.688, 338.812}, {405.613, 337.01199999999994`}, {
                    410.637, 338.75}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{225.383, 
                    145.19099999999997`}, {220.93800000000002`, 
                    142.03500000000003`}, {227.766, 137.07800000000003`}, {
                    230.27299999999997`, 142.551}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{221.90200000000002`, 
                    142.738}, {217.461, 139.586}, {224.289, 
                    134.62900000000002`}, {226.797, 140.10200000000003`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{218.23399999999998`, 
                    140.35899999999998`}, {213.789, 137.20300000000003`}, {
                    220.617, 132.24599999999998`}, {223.129, 
                    137.71900000000005`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{214.371, 
                    138.17200000000003`}, {210.121, 135.918}, {215.078, 
                    130.37900000000002`}, {219.395, 135.27300000000002`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{210.184, 136.043}, {
                    205.934, 133.793}, {210.895, 128.25400000000002`}, {
                    215.207, 133.14799999999997`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{231.758, 142.676}, {
                    231.691, 139.39499999999998`}, {237.93800000000002`, 
                    138.03900000000004`}, {240.191, 142.938}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{235.684, 
                    139.64799999999997`}, {233.754, 137.20300000000003`}, {
                    237.29299999999998`, 134.176}, {239.227, 
                    135.27300000000002`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{227.379, 
                    140.10200000000003`}, {227.184, 137.332}, {232.594, 
                    135.723}, {235.23399999999998`, 138.75}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{230.34, 
                    137.20300000000003`}, {228.602, 134.949}, {232.016, 
                    131.92200000000003`}, {234.20299999999997`, 
                    132.82799999999997`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{223.77299999999997`, 
                    137.59000000000003`}, {223.965, 135.39799999999997`}, {
                    227.055, 132.89099999999996`}, {230.40200000000002`, 
                    134.30900000000003`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{225.76999999999998`, 
                    134.62900000000002`}, {224.48000000000002`, 
                    133.46900000000005`}, {225.125, 130.76200000000006`}, {
                    226.92600000000002`, 129.926}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{219.07, 134.824}, {
                    218.555, 132.82799999999997`}, {221.969, 
                    129.28500000000003`}, {225.445, 131.60200000000003`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{219.781, 
                    132.50400000000008`}, {217.71899999999997`, 
                    130.89499999999998`}, {217.977, 128.445}, {220.617, 
                    128.125}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{214.82000000000002`, 
                    132.76200000000006`}, {214.562, 131.41000000000003`}, {
                    216.305, 129.21900000000005`}, {218.49200000000002`, 
                    129.47700000000003`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{203.812, 
                    132.89099999999996`}, {201.75, 131.79700000000003`}, {
                    207.031, 126.195}, {210.312, 131.41000000000003`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{198.72299999999998`, 
                    130.57400000000007`}, {196.148, 129.34799999999996`}, {
                    202.523, 123.168}, {205.35500000000002`, 
                    129.47700000000003`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{215.40200000000002`, 
                    130.832}, {213.406, 130.37900000000002`}, {212.117, 
                    127.48000000000002`}, {213.789, 126.32400000000001`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{208.89800000000002`, 
                    129.801}, {208.641, 128.64099999999996`}, {211.086, 
                    126.71100000000001`}, {213.08200000000002`, 127.418}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{207.22299999999998`, 
                    129.28500000000003`}, {205.29299999999998`, 
                    128.05900000000003`}, {206.32000000000002`, 
                    124.64799999999997`}, {208.57399999999998`, 
                    125.16400000000004`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{200.33200000000002`, 
                    127.031}, {198.531, 125.68}, {199.754, 
                    122.97300000000001`}, {202.266, 123.61700000000002`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{203.617, 
                    127.22300000000001`}, {203.684, 126.51600000000002`}, {
                    205.29299999999998`, 125.42200000000003`}, {
                    206.64499999999998`, 125.87099999999998`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{194.086, 
                    128.38299999999998`}, {191.836, 127.418}, {191.961, 
                    121.75}, {199.562, 124.83999999999997`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{189., 
                    126.12900000000002`}, {185.844, 124.58200000000005`}, {
                    186.875, 120.332}, {193.766, 124.39099999999996`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{194.344, 
                    124.06600000000003`}, {193.508, 123.42200000000003`}, {
                    192.605, 120.59000000000003`}, {195.762, 
                    121.68799999999999`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{188.55100000000002`, 
                    122.71500000000003`}, {187.262, 121.55900000000003`}, {
                    188.098, 119.17200000000003`}, {190.934, 
                    120.07800000000003`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{181.918, 122.332}, {
                    179.602, 120.97700000000003`}, {184.68800000000002`, 
                    119.17200000000003`}, {188.098, 122.781}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{183.465, 
                    120.65599999999995`}, {182.434, 119.625}, {182.434, 
                    116.60200000000003`}, {185.137, 117.695}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{176.895, 
                    119.43400000000003`}, {175.35200000000003`, 
                    118.27300000000002`}, {177.98800000000003`, 
                    116.72700000000003`}, {182.82000000000002`, 
                    118.85199999999998`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{178.82800000000003`, 
                    117.75799999999998`}, {177.023, 116.27700000000004`}, {
                    177.21899999999997`, 114.41000000000003`}, {
                    179.85500000000002`, 114.988}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{173.48000000000002`, 
                    116.92200000000003`}, {171.48800000000003`, 
                    115.11700000000002`}, {174.383, 113.89499999999998`}, {
                    177.859, 115.375}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{173.547, 
                    114.92200000000003`}, {170.13299999999998`, 
                    113.37900000000002`}, {171.61299999999997`, 
                    110.54700000000003`}, {173.738, 111.64099999999996`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{287.52, 
                    105.07400000000007`}, {286.727, 103.37099999999998`}, {
                    289.324, 101.98400000000004`}, {291.77, 
                    102.37099999999998`}, {294.121, 102.738}, {296.367, 
                    104.67599999999999`}, {294.60200000000003`, 
                    107.39099999999996`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{294.72999999999996`, 
                    104.043}, {297.051, 102.238}, {301.172, 
                    104.30099999999999`}, {301.172, 107.00800000000004`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    436.78099999999995`, 376.93399999999997`}, {426.477, 
                    382.08599999999996`}, {405.10200000000003`, 391.617}, {
                    399.047, 383.887}, {404.582, 386.207}, {420.809, 
                    383.758}, {434.203, 371.395}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    436.78099999999995`, 376.93399999999997`}, {426.477, 
                    382.086}, {405.10200000000003`, 391.617}, {399.047, 
                    383.887}, {404.582, 386.207}, {420.809, 383.758}, {
                    434.203, 371.395}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{443.027, 377.47999999999996`}, {431.113, 
                    391.35900000000004`}, {424.09799999999996`, 388.25}, {
                    415.53099999999995`, 393.03099999999995`}, {407.484, 
                    397.52299999999997`}, {394.668, 398.441}, {392.184, 
                    391.29699999999997`}, {403.941, 397.02299999999997`}, {
                    414.734, 388.219}, {421.363, 387.15200000000004`}, {
                    430.469, 385.691}, {435.60900000000004`, 
                    378.65200000000004`}, {438.27299999999997`, 
                    375.414}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{443.027, 377.48}, {431.113, 391.359}, {
                    424.09799999999996`, 388.25}, {415.53099999999995`, 
                    393.031}, {407.484, 397.523}, {394.668, 
                    398.44100000000003`}, {392.184, 391.297}, {403.941, 
                    397.023}, {414.734, 388.219}, {421.363, 387.152}, {
                    430.469, 385.69100000000003`}, {435.60900000000004`, 
                    378.652}, {438.27299999999997`, 375.414}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{487.90599999999995`, 379.254}, {
                    481.72299999999996`, 393.41799999999995`}, {468.504, 
                    389.719}, {462.66400000000004`, 395.73799999999994`}, {
                    454.168, 404.49199999999996`}, {432.66, 412.605}, {
                    423.77299999999997`, 406.555}, {443.348, 
                    407.58599999999996`}, {451.684, 393.062}, {462.148, 
                    388.008}, {469.621, 384.402}, {477.60200000000003`, 
                    376.676}, {487.90599999999995`, 379.254}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{487.90599999999995`, 379.254}, {
                    481.72299999999996`, 393.418}, {468.504, 389.719}, {
                    462.66400000000004`, 395.738}, {454.168, 404.492}, {
                    432.66, 412.605}, {423.77299999999997`, 406.555}, {
                    443.348, 407.586}, {451.684, 393.062}, {462.148, 
                    388.008}, {469.621, 384.402}, {477.60200000000003`, 
                    376.676}, {487.90599999999995`, 379.254}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    464.727, 380.79699999999997`}, {454.168, 
                    393.93399999999997`}, {437.93799999999993`, 
                    405.52299999999997`}, {430.469, 401.14500000000004`}, {
                    440.258, 400.629}, {443.348, 393.805}, {450.305, 
                    389.42599999999993`}, {457.258, 385.047}, {454.168, 
                    378.73799999999994`}, {464.727, 
                    380.79699999999997`}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    464.727, 380.797}, {454.168, 393.93399999999997`}, {
                    437.93799999999993`, 405.523}, {430.469, 401.145}, {
                    440.258, 400.629}, {443.348, 393.805}, {450.305, 
                    389.426}, {457.258, 385.047}, {454.168, 378.738}, {
                    464.727, 380.797}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{414.5, 
                    357.617}, {403.42199999999997`, 361.73799999999994`}, {
                    381.789, 363.79699999999997`}, {371.742, 351.176}, {
                    388.48799999999994`, 348.34400000000005`}, {413.727, 
                    349.89099999999996`}, {414.5, 357.617}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{414.5, 
                    357.617}, {403.42199999999997`, 361.738}, {381.789, 
                    363.797}, {371.742, 351.176}, {388.48799999999994`, 
                    348.344}, {413.727, 349.891}, {414.5, 357.617}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{412.441, 352.72299999999996`}, {
                    401.363, 357.875}, {392.715, 350.68}, {382.305, 
                    351.691}, {362.47299999999996`, 353.625}, {348.305, 
                    352.465}, {346.504, 342.93399999999997`}, {
                    357.83599999999996`, 353.10900000000004`}, {376.895, 
                    344.73799999999994`}, {384.621, 346.79699999999997`}, {
                    392.35200000000003`, 348.85900000000004`}, {420.941, 
                    347.055}, {429.953, 343.191}, {425.316, 
                    348.85900000000004`}, {418.105, 350.40599999999995`}, {
                    412.441, 352.72299999999996`}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{412.441, 352.723}, {401.363, 
                    357.875}, {392.715, 350.67999999999995`}, {382.305, 
                    351.69100000000003`}, {362.47299999999996`, 353.625}, {
                    348.305, 352.46500000000003`}, {346.504, 
                    342.93399999999997`}, {357.83599999999996`, 353.109}, {
                    376.895, 344.738}, {384.621, 346.797}, {
                    392.35200000000003`, 348.85900000000004`}, {420.941, 
                    347.055}, {429.953, 343.19100000000003`}, {425.316, 
                    348.85900000000004`}, {418.105, 350.406}, {412.441, 
                    352.723}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{447.21099999999996`, 382.215}, {
                    444.637, 390.715}, {444.762, 399.72999999999996`}, {
                    457.512, 399.08599999999996`}, {454.29299999999995`, 
                    403.078}, {442.445, 405.137}, {440.512, 390.199}, {
                    426.477, 400.5}, {411.148, 402.305}, {408.32, 
                    393.41799999999995`}, {415.53099999999995`, 
                    399.60200000000003`}, {426.734, 395.094}, {440.125, 
                    379.895}, {441.28499999999997`, 380.539}, {444.375, 
                    381.828}, {447.21099999999996`, 382.215}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{447.21099999999996`, 
                    382.21500000000003`}, {444.637, 390.71500000000003`}, {
                    444.762, 399.73}, {457.512, 399.086}, {
                    454.29299999999995`, 403.078}, {442.445, 405.137}, {
                    440.512, 390.199}, {426.477, 400.5}, {411.148, 402.305}, {
                    408.32, 393.418}, {415.53099999999995`, 399.602}, {
                    426.734, 395.094}, {440.125, 379.895}, {
                    441.28499999999997`, 380.539}, {444.375, 
                    381.82800000000003`}, {447.21099999999996`, 
                    382.21500000000003`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIxIGYC4h1yra8D91U58Opumvtevdzh0FeNmH67Koed
IPGqcgdbruuLCyZWOhzzNu90ZKhweFtjbxp3oMpBNirF+r5pBVw9mF9d4ZD7
/PfKjw2VDotct33+G1PhINx84NTCqZUODCCQBzXPusLh0yXfJIFf5Q6djglP
LzhB6VNQ+/nKHbacKNs336HcoVpknfvDK2UOVyteqhmuKHMo3zdfSn91uYP7
wyqRdcFlEHddKHe4oHT7Z92WMgegq3fIrSyHmL8Eql653AGkLOFimUPGRKAP
Msvh/gU52399ucN9/97peXXlDuDwEKt0MLirwtZoWw7xV3YVRF13mcOy2UcU
NpyC+jcS6i6BGofHS4ESSWUO6OEJADBhoUo=
                    "]]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIxIGYC4h1yra8D91U58Olumvtevdzh0FeNmH67Kgew
eFW5gy3X9cUFEysdjnmbdzoyVDi8rbE3jTtQ5SAblWJ937QCrh7Mr65wyH3+
e+XHhkqHRa7bPv+NqXAQbj5wauHUSgcGEMiDmmdd4fDpkm+SwK9yh07HhKcX
nKD0Kaj9fOUOW06U7ZvvUO5QLbLO/eGVMoerFS/VDFeUOZTvmy+lv7rcweNh
lci64DKIuy6UO1xUuv2zbkuZA9DVO+RWlkPMXwJVr1zu4ANUlnCxzCFjItAH
meVw/4Kc7b++3OG+f+/0vLpyiL/FKh3076qwNdqWQ/yVXQVR113msGz2EYUN
p6D+jYS6S6DG4fFSoERSmQN6eAIAMlGhTg==
                    "],
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{422.227, 
                    356.328}, {416.066, 368.90599999999995`}, {396.082, 
                    357.48799999999994`}, {392.055, 369.672}, {386.555, 
                    351.82}, {420.47299999999996`, 361.699}, {422.227, 
                    356.328}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{422.227, 
                    356.32800000000003`}, {416.066, 368.906}, {396.082, 
                    357.488}, {392.055, 369.672}, {386.555, 351.82}, {
                    420.47299999999996`, 361.699}, {422.227, 
                    356.32800000000003`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{549.3359999999999, 342.676}, {553.5269999999999, 
                    340.594}, {557.148, 343.867}, {550.738, 
                    346.43799999999993`}, {554.934, 344.355}, {558.59, 
                    347.551}, {552.1800000000001, 350.117}, {556.375, 
                    348.039}, {560.031, 351.22999999999996`}, {553.621, 
                    353.801}, {551.91, 352.078}, {549.4649999999999, 
                    345.77}, {549.3359999999999, 342.676}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{549.3359999999999, 342.676}, {553.5269999999999, 
                    340.594}, {557.148, 343.867}, {550.738, 346.438}, {
                    554.934, 344.355}, {558.59, 347.55100000000004`}, {
                    552.1800000000001, 350.11699999999996`}, {556.375, 
                    348.039}, {560.031, 351.23}, {553.621, 353.801}, {551.91, 
                    352.078}, {549.4649999999999, 345.77}, {549.3359999999999,
                     342.676}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4vJ986X0bRodjnmbdzq+K3PwAVIJbY0OQPLp
ha5yh8qXaoYcZo0Ob2vsTeMOlDvobpr7fvmERofW14E75BIrHBYX2HJdv9Xo
sOVE2b75TyocOkD65kHNs6l0AJv/tNHh8FeNmP5FlQ5LQOp/Nzro31Vhazxc
6fCwSmSdu26Tgx3X9cUFrFUORxU2FGUYNjmAtCe4V0Hk/ZscJkuwhPFtroTY
f6XR4b5/7/S8eZUO05y7c57faXSwBelfX+EQ23/oq8ajRoeMiUAXi1c4yIEc
uq7R4YLS7Z91KhUODCAwu9FBq13s5jnlcoj7pyH8H5Vifd+/pdFh6ewjChvK
yhzQwwcAOMWKPA==
                    "]]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4vJ986X0bRodjnubdzq+K3PwAVIJbY0OQPLp
ha5yh8qXaoYcZo0O72rsTeMOlDvobpr7fvmERofW14E75BIrHBYX2HJdv9Xo
sOVE2b75TyocOkD65jU6HAOZZ1PpADb/aaPDoa8aMf2LKh2WgNT/bnTQv6vC
1ni40uFhlcg6d90mB6Do4gLWKoejChuKMgybIO5wr4LI+zc5TJFgCePbXAmx
/0qjw33/3ul58yodpjl35zy/0+hgB9K/vsIhth9o06NGh4yJb2vsxSsc5EAO
XdfocFHp9s86lQoHBhCY3eig3S5285xyOcT90xD+j0qxvu/f0uiwbPYRhQ1l
ZQ7o4QMAO9WKRA==
                    "],
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{555.648, 362.512}, {560.797, 
                    373.58599999999996`}, {566.711, 373.371}, {569.555, 
                    377.707}, {574.9649999999999, 385.949}, {
                    586.4219999999999, 376.289}, {596.082, 383.629}, {594.41, 
                    373.199}, {581.4019999999999, 376.93399999999997`}, {
                    575.738, 370.23799999999994`}, {570.07, 363.539}, {
                    565.434, 360.449}, {555.648, 362.512}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{555.648, 362.512}, {560.797, 373.586}, {566.711, 
                    373.371}, {569.555, 377.707}, {574.9649999999999, 
                    385.949}, {586.4219999999999, 376.289}, {596.082, 
                    383.629}, {594.41, 373.199}, {581.4019999999999, 
                    376.93399999999997`}, {575.738, 370.238}, {570.07, 
                    363.539}, {565.434, 360.449}, {555.648, 362.512}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{556.934, 358.90599999999995`}, {565.949, 
                    366.117}, {572.594, 361.305}, {578.828, 
                    365.08599999999996`}, {594.535, 374.617}, {
                    600.8519999999999, 363.156}, {614.887, 367.66}, {611.148, 
                    358.648}, {590.418, 366.375}, {581.4019999999999, 
                    359.676}, {572.387, 352.97999999999996`}, {540.707, 
                    346.543}, {556.934, 358.90599999999995`}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{556.934, 358.906}, {565.949, 366.117}, {572.594, 
                    361.305}, {578.828, 365.086}, {594.535, 374.617}, {
                    600.8519999999999, 363.156}, {614.887, 
                    367.65999999999997`}, {611.148, 358.648}, {590.418, 
                    366.375}, {581.4019999999999, 359.676}, {572.387, 
                    352.98}, {540.707, 346.543}, {556.934, 358.906}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{530.664, 307.52}, {530.531, 
                    311.641}, {526.668, 316.92199999999997`}, {521.262, 
                    317.566}, {515.8519999999999, 318.207}, {513.531, 
                    323.875}, {509.414, 324.133}, {505.29299999999995`, 
                    324.39099999999996`}, {502.58599999999996`, 332.633}, {
                    496.91799999999995`, 332.504}, {491.254, 332.375}, {
                    488.93799999999993`, 325.03499999999997`}, {502.199, 
                    318.34000000000003`}, {515.4649999999999, 311.641}, {
                    530.148, 303.914}, {530.664, 307.52}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{530.664, 307.52}, {530.531, 
                    311.64099999999996`}, {526.668, 316.922}, {521.262, 
                    317.56600000000003`}, {515.8519999999999, 318.207}, {
                    513.531, 323.875}, {509.414, 324.133}, {
                    505.29299999999995`, 324.391}, {502.58599999999996`, 
                    332.633}, {496.91799999999995`, 332.504}, {491.254, 
                    332.375}, {488.93799999999993`, 325.03499999999997`}, {
                    502.199, 318.34000000000003`}, {515.4649999999999, 
                    311.64099999999996`}, {530.148, 303.914}, {530.664, 
                    307.52}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{513.918, 
                    304.043}, {508.254, 303.78499999999997`}, {
                    507.47999999999996`, 295.543}, {502.074, 
                    295.28499999999997`}, {509.539, 291.29299999999995`}, {
                    514.949, 297.09}, {518.8119999999999, 
                    302.23799999999994`}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{513.918, 
                    304.043}, {508.254, 303.785}, {507.47999999999996`, 
                    295.543}, {502.074, 295.285}, {509.539, 291.293}, {
                    514.949, 297.09000000000003`}, {518.8119999999999, 
                    302.238}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{518.555, 
                    303.012}, {513.664, 298.89099999999996`}, {512.246, 
                    290.262}, {519.328, 287.816}, {515.0780000000001, 
                    293.676}, {526.8009999999999, 296.316}, {523.191, 
                    301.727}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{518.555, 
                    303.01199999999994`}, {513.664, 298.891}, {512.246, 
                    290.262}, {519.328, 287.81600000000003`}, {
                    515.0780000000001, 293.676}, {526.8009999999999, 
                    296.31600000000003`}, {523.191, 301.72700000000003`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{523.449, 
                    302.754}, {519.586, 295.28499999999997`}, {529.504, 
                    294.383}, {526.9259999999999, 288.719}, {532.594, 
                    290.004}, {533.496, 300.695}, {528.3439999999999, 
                    303.527}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{523.449, 
                    302.754}, {519.586, 295.285}, {529.504, 
                    294.38300000000004`}, {526.9259999999999, 288.719}, {
                    532.594, 290.004}, {533.496, 300.695}, {528.3439999999999,
                     303.52700000000004`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{485.58599999999996`, 
                    318.72299999999996`}, {494.85900000000004`, 
                    319.23799999999994`}, {503.34000000000003`, 
                    314.22299999999996`}, {509.027, 306.10200000000003`}, {
                    512.633, 300.953}, {524.738, 298.89099999999996`}, {
                    528.8589999999999, 303.012}, {532.98, 307.133}, {530.664, 
                    315.89099999999996`}, {520.3589999999999, 313.059}, {
                    517.7810000000001, 317.43799999999993`}, {510.312, 
                    315.89099999999996`}, {506.71099999999996`, 
                    319.4959999999999}, {503.10200000000003`, 
                    323.10200000000003`}, {489.191, 333.40599999999995`}, {
                    485.58599999999996`, 318.72299999999996`}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{485.58599999999996`, 318.723}, {
                    494.85900000000004`, 319.238}, {503.34000000000003`, 
                    314.223}, {509.027, 306.102}, {512.633, 300.953}, {
                    524.738, 298.891}, {528.8589999999999, 
                    303.01199999999994`}, {532.98, 307.133}, {530.664, 
                    315.891}, {520.3589999999999, 313.05899999999997`}, {
                    517.7810000000001, 317.438}, {510.312, 315.891}, {
                    506.71099999999996`, 319.496}, {503.10200000000003`, 
                    323.102}, {489.191, 333.406}, {485.58599999999996`, 
                    318.723}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}}}, {{{520.3589999999999, 
                    313.059}, {517.914, 312.543}, {517.141, 
                    308.29299999999995`}, {518.6840000000001, 
                    306.10200000000003`}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{520.3589999999999, 
                    313.05899999999997`}, {517.914, 312.543}, {517.141, 
                    308.293}, {518.6840000000001, 306.102}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}}}, {{{525.641, 
                    310.47999999999996`}, {526.414, 309.195}, {525.898, 
                    307.39099999999996`}, {525.512, 
                    306.48799999999994`}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{525.641, 310.48}, {
                    526.414, 309.195}, {525.898, 307.391}, {525.512, 
                    306.488}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}}}, {{{500.27, 
                    318.34000000000003`}, {505.03099999999995`, 318.082}, {
                    505.93799999999993`, 314.60200000000003`}, {
                    511.08599999999996`, 313.316}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{500.27, 
                    318.34000000000003`}, {505.03099999999995`, 318.082}, {
                    505.93799999999993`, 314.602}, {511.08599999999996`, 
                    313.31600000000003`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJ5IGZigAKheofc579XflxQ4rD1RNm++TwNDrG7PHmY
4kscsvaUTJYobXDImPi2xl61xEE2KsX6/tYGh9bXgTvkbhc7bAGp/9YA0T+h
2IFXd9Pc91GNDjvkgCpqih2Wzj6isGFTo4MVSOHaYgdbruuLC7iaIObdh8pv
bnI49FUjpp+nxOGyb5JAxOomh8cgCaNiCP9mk4O3eadjwvxihw7HhKcX5jU5
dIJokRIHwQjLLSc0ofKaJQ7TnLtznmtDzZtSAqE/NULkv0LNP9noYHBXha1x
a4nDts9/r1S8b3TQahe7eW5/CUSdQJODcPOBUwsNSxzK982X0j/aCPHX92KI
fZcbIf5PLnG4oHT7Z928Rgc+kPzhEoeYfqCN6Y1w+3WAwsu7oPrrSxys7/v3
Tl/XCHE/RwnEn/GN8PAEOeO7TqPDMZBD9hU7LCkAhtjjBgdQsPs/Lnbw4mHS
bl+LiA+w+8qh/PQSiL6eOggdVuqAHr8AWwfnhw==
                    "]]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJ5IGZigAKheoec579XflxQ4rD1RNm++TwNDnG7PHmY
4kscsvaUTJYobXDImPi2xl61xEE2KsX6/tYGh9bXgTvkbhc7bAGp/9YA0T+h
2IFXd9Pc91GNDjvkgCpqih2Wzj6isGFTo4MVSOHaYgdbruuLC7iaIObdh8pv
bnI4/FUjpp+nxOGyb5JAxOomh8cgCaNiCP9mk4OPeadjwvxihw7HhKcX5jU5
dIFokRIHwQjLLSc0ofKaJQ7TnLtznmtDzZtS4nAIRH9qhMh/hZp/stFB/64K
W+PWEodtn/9eqXjf6KDdLnbz3P4SB2+QOoEmB6HmA6cWGpY4lO+bL6V/tNGB
D+Sv78UQ+y43QvyfXOJwQen2z7p5UPnDJQ4x/UAb0xvh9usAhZd3QeXrSxys
7/v3Tl/XCHE/RwnEn/GN8PAEOeO7TqPDcZBD9hU7LCkAhtjjBgdQsPs/Lnbw
4mHSbl+LiA+w+8qh/PQSh2MgfT11EP1hpQ7o8QsAYl/nkA==
                    "],
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{538.648, 336.754}, {533.496, 
                    334.43799999999993`}, {536.8439999999999, 329.027}, {
                    528.8589999999999, 325.93799999999993`}, {520.875, 
                    322.84400000000005`}, {515.3359999999999, 315.762}, {
                    517.141, 309.71099999999996`}, {522.5509999999999, 
                    321.559}, {532.0780000000001, 321.043}, {
                    535.4259999999999, 325.68}, {538.777, 330.316}, {543.668, 
                    337.141}, {538.648, 336.754}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{538.648, 336.754}, {533.496, 334.438}, {
                    536.8439999999999, 329.02700000000004`}, {
                    528.8589999999999, 325.938}, {520.875, 322.844}, {
                    515.3359999999999, 315.762}, {517.141, 309.711}, {
                    522.5509999999999, 321.55899999999997`}, {
                    532.0780000000001, 321.043}, {535.4259999999999, 
                    325.67999999999995`}, {538.777, 330.31600000000003`}, {
                    543.668, 337.14099999999996`}, {538.648, 336.754}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIxIGYC4gtKt3/WPWhwcH9YJbLuf4mDLdf1xQX3Ghwy
Jr6tsc8sgdCLGxw+XfJNElhQ4uBj3umYsKvBYensIwobzhQ72Nz3751+sMFh
Rp5Q84GuYgcGEDjf4ADknVooX+wQlWJ9339HgwNIWd6WIgeBCMstJ341QMRF
ix0qX6oZclyA6n9Q7DDNuTvn+dsGB4O7KmyNuiUQdX8aHLaeKNs3P6jEYXEB
0IV8jQ475FpfB/aUOGTtKZksIdboYLUFqGBviQOIms/WCHF3eomDzqa575ez
NzqA/XkMar5hI8TcuVA+fyPE3XYlEP/0NjrIghQcLIG4zxyqvroU4m8tqHq/
UgdPHibtduZGB2GQf/+WOKCHJwBBqZ8M
                    "]]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIxIGYC4gtKt3/WPWhw8HhYJbLuf4mDLdf1xQX3Ghwy
Jr6tsc8sgdCLGxw+XfJNElhQ4uBj3umYsKvBYdnsIwobzhQ72Nz3751+sMFh
ep5Q84GuYgcGEDjf4ADknVooX+wQlWJ9339Hg8MDoLK8LUUOAhGWW078aoCI
ixY7VL5UM+S40OAwA6T/QbHDNOfunOdvGxz076qwNeqWQNT9aXDYcqJs3/yg
EofFBUAX8jU67JBrfR3YU+KQtadksoRYo4MVSMHeEog6tkaIu9NLHHQ2zX2/
nL3R4SLIn8eg5hs2QsydC+XzN0LcbVcC8U9vo4MMSMHBEoj7zKHqq0sdloL8
rQVV71fq4MnDpN3O3Ajx798SB/TwBABCqZ8M
                    "],
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{513.7890000000001, 345.383}, {
                    515.0780000000001, 343.449}, {516.3669999999998, 
                    338.559}, {515.207, 335.85200000000003`}, {
                    517.7810000000001, 337.39799999999997`}, {521.52, 
                    341.39099999999996`}, {522.676, 344.094}, {
                    527.9569999999999, 343.32}, {530.016, 336.754}, {524.996, 
                    333.92199999999997`}, {528.086, 333.92199999999997`}, {
                    533.3669999999998, 333.92199999999997`}, {536.328, 
                    337.39799999999997`}, {532.7230000000001, 
                    341.39099999999996`}, {521.52, 347.57}, {
                    513.7890000000001, 345.383}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{513.7890000000001, 
                    345.38300000000004`}, {515.0780000000001, 
                    343.44899999999996`}, {516.3669999999998, 
                    338.55899999999997`}, {515.207, 335.852}, {
                    517.7810000000001, 337.398}, {521.52, 341.391}, {522.676, 
                    344.094}, {527.9569999999999, 343.32}, {530.016, 
                    336.754}, {524.996, 333.922}, {528.086, 333.922}, {
                    533.3669999999998, 333.922}, {536.328, 337.398}, {
                    532.7230000000001, 341.391}, {521.52, 347.57}, {
                    513.7890000000001, 345.38300000000004`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxdlAtIFVEQhm8aYaESZWVFZlFiRphgRfZwCsQyohKSkhKRSimy8Ozr7u69
dxeJXkiYhVSEpVkJJVoWFhVa9jIQsfIWYmYikvZAJaSH1R7/g1ALy2H3zMz5
/29md07WgdTdgS6Xa4xzpzp3gHNn3F0fHDDToISaZ8qD+wpNzq9rvBhi0Kz0
XSs6nit0qG9LbcSQTqsn+MsOvlaoOHdSfl2Tjvh2hVz8StWJh28aUuj9poLi
3JM6Lef72SrxpeSXjrw9KuUUfjYTOwwaaNmYNTFDo+a5bd+9GSat4vVLVLrF
4/M8qP9ZxL/0QMd4DfqmeKk06fbgsEujpxuWHV2T4sXaq0L3Yy+Vn2uIrFqp
kR5WmdyZ5kPefA1663x0dE1md3ODSsmdTsQLH/H0TL+Ktc1Hc6rycgq7xXO/
D3F9Ku29JxWFL7Do4bfoHSfGadC32ULdGqF/p0UGP3edSi8dm9vyLaFDhc9K
i2Lb542z41Q6wnU0ivzfCrgMWFQb4TiOEueF2NTFDUWr5P4YFRc0zQZXJ35k
P8GmSdzfbJUcKq+0bBv58SryvDZ4NSjwfcoG360KPeI+1tngpSikPiiZEbvS
ppjDU982HZexH2/Dzw+JnC4XFHdZ4FwvET+mtswi/jo3XKaU4ICFh1cJ/6Uy
RXKON33o3x0Zujf7aCefux5J9NkLXWESPeHAL3jpMtdzlqFulUfMDaPQRTfO
f93uoRC+DjHw7jVRz8/Ql0smvdYcUBr7d76mM/Rz0ADvPAZuzEB/sxm4hZk4
12KY21YDfq4y6Moy4b+a0RczcUnGBxOc7zKcU29i3uIkcJzswf5aCfEt4ryv
ov47A/6yJSoKH5sW6tdHeYzEpxjoS4WE7+qPgbw0sZ9uIv+6BH/7DKzVEvy7
DMzzRhn1T+uYs2AZuj658b5c8F+qQ5+P4bv2aDj/DEPcFZUW8/ktF8/O3I1w
OSLiSxTa3/Ozoj+IgZNHhY5WCf25pmH/jchPdCNvnwRup92j8zXynfjd4Bgo
ow9jdehMkwUnHf6ZDB4xOuLzZXBI0vF/OCbmr1X8R4Zl9LnGLXgp9P//8C8A
IlPh
                    "]]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxdVAlIFFEY3lSiQiXMym6Nig5CBCsyy98gNCsyoaWiRKRSKix8c+3M7O4M
EmoRYRZ2EFZmJVRYWVhUWNllIJ1uER0mImklKiHdzdvvIZQwDOP7j+96G5e7
PWtTqMvlGuQ8Wc4T4jzZ15aGh4wzaH7dA+XmDYVGFDU0HY8waMK6jQvePVRo
Z9eq+on9Oi0aFqja8UKhioKoooZmHfVvFHLxvyydePnKfoXer9xTUbBPnOep
xF+VP3U6yPs2q5Rf9tlMeWdQ79MVucOzNXo8+fU3X7aJ+ZUqXeb1hV70fxb1
z7zAMVQDvpE+OrHkSt8vl0b3l80rTc3w4d2pAvddH5060hhbm6yRHn0+rdXt
pyjeN1UD3gY/labmtD9uVCmt1al45KflTntOQCU+Jue1n+JqC/PL2sV3j5/S
eV2XSluuS+UxMyy6/XX6+r2DNeDLtDC3TuDfYJHB96ar9MyhuaZIfLtVWsh5
nrco/s2UwXaCSiUcR5Po/61Al16L6ic6jKeJfRE2tVU7hKar5Pk4LWHIaBu6
OvXB8yQb/Cap5KjyXMuz0Z+oos9nQ69GBbz329B3tUJ3OI90G3opCqk3K8fG
J9s0q3jUq+bdMs4Tbej4XSLH5T0VbRaN5zrfkoivqa+y4HuMTBnhIbOKF1qo
PyFTLNfxkh/+XZWBO9NPwdx1SJQU9NlHuziuaInuccGPCf8OM+LrCmq9IjeM
ImdfPNq91ot3P4PenSbmBRh8OWnSc80RSmP/5msMg599BvQuZNCNGfA3j0G3
aBN8LIa8txjw7wwDrlwT/C8w+mKmzMn+YELnawz+3jIxN0GimVzHEV6cL5ZQ
/1Ts6xbz3xrglydReUyYOzKgD+gRrM8wSOG+1Ejw7Y+B++QW5+tM9J+TwG+r
gTxfkMDfZcCHFTLmH9CRs3AZuD55aD//f7XQf64OfH6Ge+3VsP8QQ/9pFfmt
Ft9O7oK6lIj6SoW2dfyo6RnCcB+9Kj3hOFok+HNWw/lL0Z/iQd9WCff7gGcg
X8E9AQ/yGCrDhzAd990tI8/ROvgzGXrM1FFfJEOPJTp47RL5a9Hgzy8Z+arz
CL0U+v/38C8RUlPn
                    "],
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{546.875, 367.90999999999997`}, {
                    547.2230000000001, 367.188}, {547.4019999999999, 
                    366.246}, {547.4019999999999, 365.08599999999996`}, {
                    547.4019999999999, 359.41799999999995`}, {
                    538.9019999999999, 359.16}, {538.391, 350.789}, {538.121, 
                    346.414}, {537.617, 343.965}, {534.6519999999999, 
                    344.47999999999996`}, {531.691, 344.9959999999999}, {
                    529.117, 349.633}, {531.949, 355.039}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{546.875, 367.90999999999997`}, {
                    547.2230000000001, 367.188}, {547.4019999999999, 
                    366.246}, {547.4019999999999, 365.086}, {
                    547.4019999999999, 359.418}, {538.9019999999999, 
                    359.15999999999997`}, {538.391, 350.789}, {538.121, 
                    346.414}, {537.617, 343.96500000000003`}, {
                    534.6519999999999, 344.48}, {531.691, 344.996}, {529.117, 
                    349.633}, {531.949, 355.039}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}}}, {{{437.93799999999993`, 
                    372.29699999999997`}, {435.805, 373.79699999999997`}, {
                    433.668, 374.40599999999995`}, {431.758, 
                    374.42199999999997`}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{437.93799999999993`, 
                    372.297}, {435.805, 373.797}, {433.668, 374.406}, {
                    431.758, 374.422}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    484.594, 382.684}, {491.414, 379.72999999999996`}, {
                    494.73799999999994`, 372.64500000000004`}, {504.648, 
                    372.29699999999997`}, {514.1840000000001, 371.965}, {
                    520.102, 358.133}, {536.07, 367.148}, {536.504, 
                    367.39099999999996`}, {536.9259999999999, 367.617}, {
                    537.3359999999999, 367.828}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    484.594, 382.68399999999997`}, {491.414, 379.73}, {
                    494.73799999999994`, 372.645}, {504.648, 372.297}, {
                    514.1840000000001, 371.96500000000003`}, {520.102, 
                    358.133}, {536.07, 367.148}, {536.504, 367.391}, {
                    536.9259999999999, 367.617}, {537.3359999999999, 
                    367.82800000000003`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}}}, {{{508., 380.301}, {506.578,
                     378.03499999999997`}, {506.254, 374.879}, {
                    506.64500000000004`, 372.105}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{508., 380.301}, {506.578,
                     378.03499999999997`}, {506.254, 374.879}, {
                    506.64500000000004`, 372.105}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{476.828, 351.176}, {464.727, 351.176}, {461.633, 
                    344.9959999999999}, {461.633, 339.07}, {461.633, 
                    333.148}, {467.301, 325.42199999999997`}, {477.348, 
                    325.42199999999997`}, {487.39099999999996`, 
                    325.42199999999997`}, {492.801, 331.60200000000003`}, {
                    492.801, 338.301}, {492.801, 344.9959999999999}, {486.617,
                     351.176}, {476.828, 351.176}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{476.828, 351.176}, {464.727, 351.176}, {461.633, 
                    344.996}, {461.633, 339.07}, {461.633, 
                    333.14799999999997`}, {467.301, 325.422}, {477.348, 
                    325.422}, {487.39099999999996`, 325.422}, {492.801, 
                    331.602}, {492.801, 338.30100000000004`}, {492.801, 
                    344.996}, {486.617, 351.176}, {476.828, 351.176}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{479.02, 325.68}, {478.762, 329.027}, {
                    472.71099999999996`, 328.512}, {472.965, 
                    331.08599999999996`}, {473.22299999999996`, 
                    333.66400000000004`}, {476.316, 334.691}, {476.316, 
                    338.301}, {476.316, 341.90599999999995`}, {
                    481.72299999999996`, 342.16400000000004`}, {483.527, 
                    339.328}, {485.328, 336.4959999999999}, {
                    490.73799999999994`, 330.957}, {491.89799999999997`, 
                    333.79299999999995`}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{479.02, 325.67999999999995`}, {478.762, 
                    329.02700000000004`}, {472.71099999999996`, 
                    328.51199999999994`}, {472.965, 331.086}, {
                    473.22299999999996`, 333.664}, {476.316, 
                    334.69100000000003`}, {476.316, 338.30100000000004`}, {
                    476.316, 341.906}, {481.72299999999996`, 342.164}, {
                    483.527, 339.328}, {485.328, 336.496}, {
                    490.73799999999994`, 330.957}, {491.89799999999997`, 
                    333.793}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}}}, {{{483.527, 339.328}, {
                    480.691, 336.4959999999999}, {479.40599999999995`, 
                    330.699}, {483.141, 326.195}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{483.527, 339.328}, {
                    480.691, 336.496}, {479.40599999999995`, 
                    330.69899999999996`}, {483.141, 326.195}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}}}, {{{487.39099999999996`, 
                    334.949}, {486.48799999999994`, 333.02}, {486.234, 
                    330.059}, {487.262, 328.254}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{487.39099999999996`, 
                    334.94899999999996`}, {486.48799999999994`, 333.02}, {
                    486.234, 330.05899999999997`}, {487.262, 328.254}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{535.488, 344.414}, {
                    544.9569999999999, 343.645}, {546.5659999999999, 
                    354.074}, {539.484, 354.719}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{523.8359999999999, 
                    372.555}, {520.555, 376.742}, {513.02, 378.156}, {512.891,
                     369.27}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    511.98799999999994`, 359.16}, {508.77, 367.148}, {500.527,
                     368.305}, {496.14500000000004`, 364.312}, {492.504, 
                    360.99199999999996`}, {492.414, 352.33599999999996`}, {
                    500.27, 350.53499999999997`}, {502.97299999999996`, 
                    353.754}, {508.254, 358.004}, {511.98799999999994`, 
                    359.16}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    511.98799999999994`, 359.15999999999997`}, {508.77, 
                    367.148}, {500.527, 368.305}, {496.14500000000004`, 
                    364.312}, {492.504, 360.992}, {492.414, 352.336}, {500.27,
                     350.53499999999997`}, {502.97299999999996`, 353.754}, {
                    508.254, 358.004}, {511.98799999999994`, 
                    359.15999999999997`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}}}, {{{508.445, 364.184}, {
                    503.809, 368.305}, {496.984, 360.51599999999996`}, {
                    503.168, 353.367}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{508.445, 
                    364.18399999999997`}, {503.809, 368.305}, {496.984, 
                    360.51599999999996`}, {503.168, 353.367}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    523.8359999999999, 372.555}, {521.004, 375.582}, {514.824,
                     373.199}, {516.559, 367.082}, {517.914, 369.914}, {
                    520.809, 372.29699999999997`}, {523.8359999999999, 
                    372.555}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    506.328, 356.059}, {508.28099999999995`, 
                    357.47299999999996`}, {510.29299999999995`, 358.637}, {
                    511.98799999999994`, 359.16}, {511.062, 361.453}, {
                    509.727, 363.184}, {508.184, 364.39099999999996`}, {
                    506.71099999999996`, 365.40599999999995`}, {502.477, 
                    359.715}, {506.328, 356.059}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    498.72299999999996`, 366.504}, {494.08599999999996`, 
                    369.594}, {489.83599999999996`, 369.336}, {
                    488.41799999999995`, 366.762}, {485.074, 366.891}, {
                    482.305, 364.44100000000003`}, {482.172, 359.547}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{489.324, 357.488}, {
                    483.78499999999997`, 361.28499999999997`}, {476.188, 
                    359.871}, {476.703, 351.371}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{473.35200000000003`, 
                    346.543}, {476.055, 348.73}, {479.91799999999995`, 
                    350.27700000000004`}, {482.883, 346.414}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{514.691, 
                    354.90999999999997`}, {513.664, 353.496}, {512.891, 
                    351.305}, {514.5619999999999, 347.957}, {512.504, 
                    350.664}, {507.35200000000003`, 350.664}, {501.812, 
                    343.44899999999996`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{526.9259999999999, 
                    355.297}, {520.23, 354.527}, {520.3589999999999, 
                    350.14799999999997`}, {525.766, 348.21500000000003`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{479.277, 371.652}, {
                    473.60900000000004`, 372.812}, {469.48799999999994`, 
                    369.46500000000003`}, {477.348, 366.633}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{490.09799999999996`, 
                    375.51599999999996`}, {482.10900000000004`, 377.449}, {
                    478.89099999999996`, 375.391}, {482.4959999999999, 
                    373.586}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{467.043, 
                    343.44899999999996`}, {466.78499999999997`, 
                    340.61699999999996`}, {468.328, 336.88300000000004`}, {
                    472.965, 341.133}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{468.59, 
                    334.94899999999996`}, {468.59, 334.17999999999995`}, {
                    468.46099999999996`, 333.27700000000004`}, {467.941, 
                    332.633}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{450.043, 
                    372.68399999999997`}, {445.148, 374.102}, {444.25, 
                    378.609}, {449.91799999999995`, 378.223}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{448.371, 362.254}, {
                    442.96099999999996`, 364.055}, {442.96099999999996`, 
                    369.336}, {447.465, 368.82}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{458.414, 364.957}, {
                    452.10200000000003`, 366.504}, {451.848, 370.883}, {
                    456.613, 370.238}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{459.188, 378.352}, {
                    455.84000000000003`, 378.609}, {450.688, 374.875}, {
                    459.316, 372.68399999999997`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{468.59, 370.883}, {
                    460.734, 372.039}, {460.863, 368.82}, {465.4959999999999, 
                    366.762}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{474.512, 378.352}, {
                    468.46099999999996`, 379.508}, {466.39799999999997`, 
                    375.902}, {470.52, 374.359}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{455.453, 356.07}, {
                    453.969, 357.293}, {452.75, 363.156}, {459.828, 361.414}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{470.133, 357.875}, {
                    465.371, 359.15999999999997`}, {460.863, 354.527}, {
                    465.23799999999994`, 351.82}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{476.441, 
                    363.40999999999997`}, {471.42199999999997`, 364.312}, {
                    467.172, 362.898}, {469.875, 361.094}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGZigAKXKocZeULNB7pKHYSbD5xaWFrlcEHp9s+6
aaUOx7zNOx33VUHoulIHxQ1FGRN1qx1ko1Ks73uWOgiB1BdXO+Q+/73yo0ap
g3a72M1zrjUO1SLr3B8+KoGYd7IGLg/mO9Y42HJdX1zwvcRh2ewjChtuVTsY
3FVhazyKMG86yD1rSh0OfdWI6eepdvh0yTdJYEophA6ocuDT3TT3fW4pxN0M
VQ6trwN3yO0sdXhXY28ad6gKrv8wSL9WNcT9bmUOvCB97DUOIG7CQYR7d8gB
TZhT6vB4KdBBU2ocFED+bIbyb9U4uD+sElnXXgrxl0oNRDypDKLftNoBHI7X
Sh0mS7CE8clWO5Tvmy+l317msBNkble1g9WWE2X7BMsg7pxaA1G/CMqXrYX7
HwCZTbJg
                    "]]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGZigAKXKofpeULNB7pKHYSbD5xaWFrlcFHp9s+6
aaUOx7zNOx33VTkcB9F1pQ6KG4oyJupWO8hEpVjf9yx1EAKpL652yHn+e+VH
jVIH7Xaxm+dcaxyqRNa5P3xUAjHvZA1cHsx3rHGw47q+uOB7icOy2UcUNtyq
dtC/q8LWeBRh3gyQe9aUOhz6qhHTz1Pt8OmSb5LAlFIIHVDlwKe7ae773FKI
OoYqh9bXgTvkdpY6vKuxN407VAXXfxikX6sa4n63MgdekD72GgcfIDfhIMK9
O+SAJswpdXi8FOigKTUQfzZD+bdqHDweAn3UXupQDfKXSg1EPKkMot+02gEc
jtdKHSZLsITxyVY7lO+bL6XfXuawE2RuV7WD5ZYTZfsEyyDunFoDUb8Iypet
hfsfAJlVsmE=
                    "],
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}}}, {{{523.57, 372.555}, {
                    520.738, 372.027}, {518.2030000000001, 370.367}, {516.559,
                     367.082}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{523.57, 372.555}, {
                    520.738, 372.027}, {518.2030000000001, 370.367}, {516.559,
                     367.082}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}}}, {{{436.26599999999996`, 
                    358.395}, {434.672, 360.379}, {435.395, 362.355}, {
                    433.684, 363.91799999999995`}}}]}}}}, {{{
                   {Thickness[0.0005555555555555556], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{436.26599999999996`, 
                    358.395}, {434.672, 360.379}, {435.395, 362.355}, {
                    433.684, 363.918}}},
                    CurveClosed->{0}]}}}}}}}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 720.}, {0., 480.}}], ",", 
           GraphicsBox[{{{
               {Thickness[0.0008680555555555555], {{{
                   {FaceForm[{RGBColor[
                    0.968627, 0.8784310000000001, 0.09019610000000002], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 576.}, {1152., 576.}, {1152., 0.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    1152., 296.}, {1152., 160.}, {0., 400.}, {0., 
                    536.}}}]}}}}, {{{
                   {Thickness[0.0008680555555555555], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    1152., 160.}, {1152., 40.}, {0., 280.}, {0., 
                    400.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.8117650000000001, 0.06666670000000002, 0.14902], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxdVn9QVFUUJiMW0RwSJjPUUScUB0r4wzADPMokg0BOUWoSu++9fbtLZGpR
aex7yy77HtoPKjKTqRxGQdEgYjSVzIgRA2vS8WdYiMg4hZrlGEEy2tS977ux
k8y8Yb+9957znfN997ydpqx+0nVnWFjYHezZwJ5R7KleNT7YpgZo8dhRievH
2en1BdLPxy/5SZ8/x36gyk7X6jtyUtf6KbnngYjAUQetUB/tXZLgJ29sU1Zf
q0Rh/G+in34a9hUfvCRR0u4t1+qj/GQ/kD121BiZclJZxMgQLj748sb7IkK4
qOo3bX64n97ezIick0awFX+bhPwMN05imf9xEGP73db+MoqPCGzKLHDQ2taa
+2dvKqOhhGffOXSXg1qmmL8+saiM1t/747G/9tjpj5N5SvQxH8XNZgU846Dj
07uHfSt9xLLMsT8u0dTml4qqbD76itEKH5Lohf6bu66/pxM7nX/xFZk6eAHJ
OnjtkmklXz+v0dPjHty95ZRM7NTScSUafc1o9HwvE8veMiVeo0peT7WMeGEa
dfI4fhn8u7yIXyj6860X67ki3pde2nvk1daaeSJeg1hPktHvHSF8cftHh6dW
34Y/9NK8z1mAbpn4v5qdXvCNUZCfxbfqKVRoB9vefMWL77cr4DNNE3ortO2x
fQN/p2kUw9f7FMrqK41tytdoKY93M4QtPWzOEWz5aryTfud9Xiz6k+ZE/zI0
6uZ+UZ2UyIWaqIHnL07UP0ujNelRXbWqivXnRL5Olc6suzwjpVEDryQXdJyk
0wmua4YLdZTp8NeAirjVOvp2QSVuo97PdOhzXIWf94Sw5Z+2ELbit+jg/6cK
/7yvw2+FLuhbrBO/NtO7XKhbEflj3MhbpKM/tW46NMgOrtJpTFftmvQVHuj7
hU7LeH3XPMgX60O+Wx4q5ffA7kP9tiLoVulDnWfE+Zs+5An3IP80P/hVqdh/
2k/8mvTMdRJv65q6AL3LiXQruCdnA/QIb1S7Qtw+zQvLRf3CH/5yxBtU6DXW
/si0IPrqdtI9y9nJG0HE61VxH98ywCPKA157DehZ54GvjxiUy3121AO/XjFw
Hxi2+NpM4jTTj3mQJ87EfNnpQf+TTWq4zi52roey+dzKNBHnhhv1ZJvQud5N
H2S+ubI/y0R9M92It8gkPg4CZ1zIx85bffzUhfpSTfif6Wvxjxfx+lXMkwQT
/junEm9TW46J+mLFec2Eng4XsV2n1+0X+9Nc0L/LpIXcL+0q+jcg4i9Toc+Q
SS/yD1edqO+C2F8g8FkT/Yp3ot4TJk3m5weUEWzxvhrCVr97FPBn560+/qDQ
KQaXD5qYD//pH1eBfA1C/5QK8J8bwtZ8fkMewZZPl4r5nlwxMo8s/FDF/+dT
UghbfphcAT0WyFTHG3l3BZVwYQrE/j4TOm2XiV/Plk6TPuH6t8jo50aTCvl9
2y+jn8+bNDMlsnHSPhn12k3MhyaZDvOBv9Ckkxwz/pY/Jpi4r/kiHvOj1T/2
Pmvn+BuBVQnvx48NwcdB/FYkBA3onO2AfgUG8XaU5jqITZfKzQ8beH8tcUCH
yQZt5f2sc4BftAEfzZCgV6QBv+ZLZI0Fm4H5sVoiDutHG5gPpyWK5vVGifUJ
MvIxbPk3T8Z9HB3CFn9bCGdwvsNB+H+WTHx8Z10O4n18S6INfH9rEPNnvQR/
1AbhvzwJ/EuC4BMm1s+XE6fZkWgH38hyeooLKRXS7b83/gUIKM2n
                    
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[1., 0.8, 0.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIlIGYC4qMKG4oyBFscLijd/lnHluTQ6Zjw9IJ2i8Pq
j5d8k2ySHI6A5P1aHDImvq2xP5nkYHPfv3d6TItDgS3X9cUWyQ6yUSnW99Nb
HLzNgTonJjts//z3SkVmiwMDCGxIdugAmZfV4qDG1jjV2TvF4RPQWIGcFodL
IPtupUDUZUPNY0l14NPdNPd9SovDKpD9JqkOj5fOPqIQ1+LwTSOm/1BmqkO7
2M1z36NbHLaeKNs3Py/VgRek3gvB3way3wrBBznP37zF4TjIgRmpDotBFum1
OOwtmSzBYpbqoAPUvlwJav7bFAc7oDMKFFschJsPnFoYmAIxR6fF4V2NvWmc
VIqDNcj/xi0OMiCDvyc7HP4K1GjS4tB/CMgA8sHh4NwCcbdACsS94S0OF0H+
NUpxAHmzAOj+/fOl9O8apEDUA/m90/OEmllSIOEM5BeBGJOTHQQiLLecMGpx
AJoS/HhnksPDKpF17hxQvmuSwxKQf/40O2wBuVMtCeK+T80OliAB5iQHg7sq
bI0fmyH+/5EIic93zZBwv5HokLUHGBD/mh1A0aR0P9EBPT0AAPiN+JY=
                    
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[1., 0.831373, 0.16470600000000002`], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4qWzjyhsONboILrO/WGVTbxDxsS3NfYPGh0Y
QKAh3kEgwnLLiXeNDpvnvl9+7He8A5D0Nv/Z6ND6OnCHXGmCgy3X9cUF/xod
CkGMDQkOfLqb5r5nbHK4qHT7Z927BIfKl2qGHDD+vwQHmagU6/tA9QUg9SqJ
DrIg/udGh60nyvbNV0p0ALvneaODS3fO898/Exwu+yYJRNxvdABZY3svweEK
iH8P6r4LCQ7yIIcA3dt/6KtGzPQEiHufNULsYU9w+HQJqOFWo0Pv9Dyh5hPx
DhX75kvpT2t08OJh0m7vi3fQv6vC1tjf6BDyGGhzRzzE3JpGh1p707hdE+Mh
5mQ1OswAaj+wKN5hC8idXo0O8bs8eZgOxzuAtCnYNzps+/z3SsXKeIcOx4Sn
F7yg4RUdD3GvX6ODH5CydIl3ABnnH97oIAIKb5V4B5CzDsQ1QsJdNN6hE6S/
oNHhuLd5p+OHOIj6zY0OD6uAOjjjHdDjCwB5h8qs
                    "]], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJ5IGYC4qgU6/v+wU0OFS/VDDly4h1i+g991QhvcvgP
Au3xDpd9kwQiUpocQh4vnX1kR7zD1hNl++YXNDkc8zbvdLwR78AAAo1NDhkT
39bYMyY4bP/890pFZ5ODDMhg8QQHkLKECU0O++dL6d91SHB4WCWyzn1Jk0MR
SMP2BAeb+/690xc0OQg3Hzi1UDbRAeyeZqj88kQHW67riwuKmxxAlO2nRIcj
ChuKMnKaHI6DDP6Q6DA9T6j5QHyTQ+vrwB1ycxMdgLY9vRDS5OADsjc00eHT
JaAHQqH2B0Dlgf4pBBnsAJXPbYL4wyLRoV3s5rnvJU0OVluAHpVPhPi/Euo+
xkSHC0q3f9Z1NTnE7fLkYepOcLADOay1yUH/rgpbo2MCxDyg+4CqsvYA/Qs2
NxRqPpCvs2nu++V+TQ7VwGB4aJQA8Z9Hk4MXD5N2+7t4h/fLgSHrCg3vDfEO
wNiI6XdqcpAHeTAPwd8MNOZYNIK/DRTumvGQ8PVucnDpznn+2zDeAT1+AaDz
25I=
                    "]], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4vfLj3mbqzY5PF46+4iCTYLD4a8aMf2aTQ4T
DgEZ2QkOny75JgloNzkwgMCBBAfr+/6907WaHO78rMvak5PokDnxbY09kL/q
I1Dhh0QHPt1Nc99rQM1LSHIAURvUmxxaXwfukEtNcpCNSrG+rwxVX5LkMM25
O+e5QJOD5ZYTZfuckxyAqosy+KD6VZIcsvaUTJbghcoLJzmU75svpc/f5HDz
3Pfgx28TIe4ThrrvQqJDuxhQRqLJAegq07hFiQ7yIIslmxzCQA4rT4TYJw41
/0iCw1agsfNFmxwuKt3+WXco3uEy0LgIoPrmA6cWupbFO6CHDwDaDYs8
                    
                    "]], FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {0,
                     1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4mnO3TnPdzQ6HPc273RckeBQvm++lP7uRoeL
Srd/1l1KcIjtP/RVY1+jA0j4rkaig/5dFbbG/Y0Oj5fOPqKQkeiwpMCW6/qB
RgeQspjliQ6fLvkmCRyB8r8nOmw5UbZv/rFGBxegNb8lkyDmn210eFtjbxpX
lORgfd+/dzpQ/ptGTP+hziSHGJDGrVDzI5IcsvaUTJZY0egQt8uTh8k4yWEx
yL5VjQ6WIIM3Jzo8rBJZ57620aH1deAOOcdEB8EIoAxQvVPC0wtK2VD3L4L6
TyLB4YjChqKMBVD7mRIc2sVunvsOlGcAAY4EhwqQ+1ZB3aOZ4FD5Us2QY0Oj
wyLXbZ//uiRA/LOt0QGoK/hxbYIDevgBAAJ8n60=
                    "]], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxdVQ9MlVUUf6IjYvJUaIRmSFhpmqJsCaXU79Ws/IOumI41dPfe77W9LA2V
JMn47p2pUWPkmFpzRQqGERUrYq0RGhC2aoWwxaohQ5blnBG2MtfKvvPOKbbe
9u3b+e495/zO75zfeTeZJx9+dGIoFJoQPKXBkxA8Nz4SXTpU7NCX/f2Vyk0K
m9rLajNiDskD9aUFRxVGG3tW5T3ucHR5269/dSuE6LfVIaJ+6M0u19iX/u1X
l7c7vLwldffJPo2lQ2urD5U7fByEmbTE4FJfoZm60+HO1s92dBQZrMqriqhd
Dhd33XPHxoMGVRToKYeNH62YnHDYcP6o5DcGvYQrwBfbH3gUSLzArun8bW5J
nkF3Vsu2WInDB0H4ur81nu6om5Fj5Px9jZ3nb12ctEH8ryjQ55oih+304YRi
PKsd1oUXvPdqreI4BQ5pu09+fqRK4RDVlSPxGhWCW6ONtzlU00Gr4vxzpb4u
hbMV173zwDyH34M0necVGkoLkgcWOGwNXvWLNG4n/9nCZ75mPNc4zFmc1Dwz
UWOY/C9aULi6bxRKKPGIZX6/U8jcc+GhD89Zxpum+fwny/2bp9kvOI/XG9Go
p/xnLeMp1MzfoMWJgKZBpUGwSgcs16Okny2W8azUCLoyf1+T5X7dr7n+44Jn
zbj9TAB7eMu4Hc+3R6Of2tVo0TQWJH5dY1pxwNQxid+kMXLscHdWg+V3q0YX
8bFf8LVL/grJ36GxgepdY7lvn2iQW8tCwXNGIz7PGRY5gzcnuumG5zFB7HWG
+xuS+M8Zjj9F6v/DMB/pgm+hx/3MtCB1tJd5INpHsyxSaT4OeNy/2YKvzQOl
Xztf+nfO47pyxT8UZf984WtGlPPfbXFLojtwX964HdcZxu24ntZHWQ/ZUn8k
iudJP+lSf3aU+x22CLpYNJISxSKqO8WyXq963I8pwsdpj/maZrGNBqbWY70k
/YvHA2UNX/DZHjL4mers9JnHStHnXp/1+obBEz/++ebYEp91s97DZrIzfJ7H
Vzw8SAOe4oNg1h/3eB4TfdZbcB7X0eVKxv2sx3thoo+XiOgbPK57us/4xwxO
U/5cn9+dBuWk/1qJHzOcv9nHKXKMCb4en/mNyf2vxS6R8zM+7iIcs2Q/XfJZ
//2a7XyZj70yfzuknxUaj1GdL1i+Xy778EWLHspfprGM7GrR53LNeq6xXHea
6K9G+E+TeX5b5iuseX6+kP5dqzlOr8SboHn+Tlnmb1BhFsXvtriX+t8v+6zL
Ml8dsl8+tVzvu+o/f+6HYn6+lHk+qHjOhmXeXlPcv19Evw2yX6/K/DZL/EmO
9d+ieF6SZf+3iX9Y9v9bClNpP6Q6nl8n8a53HL9Y9u1MByorc4VifueIHVF8
b5nEz1VYSfoplH0Lhf//3/0DDjwhTA==
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[1., 0.8, 0.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxdUwtIVEEU3SwspL8iESXmD8NEIiopwmMfTKzEjTKiZGZeoUn00SgrseQa
YlKb9DFYRFwNrajMNCzUxCwkQqwUy1jKJCJEQvuIZNDMztCDFoad8979nHPu
fUvEYef+qQ6HY4o8CfL4ydMT9n6ioIjQeuzygmnPGWbHNlR8u0lIV5c5HA71
ayc0dR1vqxQceW2VC+O6CdcPzaf2AY5rG0oPfukl7FDxgQKdofU5WQOEQGp/
UZVsY1++08aujp/RezKFrt9FeNc9vn2oRKA4WN5abOyrf9/GyyS92nuEoRvu
ztA6gZTVJYmskXB79PVWMWnqPSK8Urq2WXj4/U9v3gNCnDfCv7DJ4Fs2PqH0
1Np4i6pXRRjJT1iZ4bHwVNJ0VRDWs889YaWW7l9O2Ps4eaZfpqX7S7xT6U+3
oGjVuwkZ6n24hewWaayHcG44rTmkT2BM0pxbYd67BRqVL6Wk6xwwesjoTROo
PrIuoL+AUK78XmXji+rBIhsH9Mubv4Cy1XWGtA8/uPb7rI0HTwXdTSq0sU/v
eVNf5vvmdIXwS5bpWCx0vPQnJ6tsJD9J4JPCDYQn0jZvhMAbKWdXs+E7z8S3
Ek7Lv8Ex/g/7+n20sWeTnEQR1/n5hDXKiGGmeaSS5uVlOPk1avmMeMOnj+n9
WGHy3zKEKGNjCBvlmvyeMPGRBDn97JYgrv0OJ1xSxsRwvbcRZp4pZr+jzD5a
HLv3rf2QGk3IVXpdHDXK36UEBRPucN0/lnBUPq6e5Him/I00+ke55hNs4q9y
Pd8AwoDis9n0m05IVP3Hma4/y/jzkul5BRp9dQbHG/+LmZ6v0/hxgek8y+Ay
pvvmmno1DP9/338BdlTBuQ==
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.8117650000000001, 0.06666670000000002, 0.14902], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{647.48, 164.172}, {646.242, 166.059}, {646.984, 
                    168.336}, {648.8399999999999, 168.336}, {649.938, 
                    168.336}, {650.1519999999999, 168.066}, {
                    650.2810000000001, 166.48800000000003`}, {650.395, 
                    165.172}, {650.145, 164.375}, {649.414, 
                    163.71499999999997`}, {648.4219999999999, 162.816}, {
                    648.3589999999999, 162.83200000000002`}, {647.48, 
                    164.172}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 0.8, 0.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGYC4iu+SQIRdS0O/Ye+asR8TnKQjUqxvj+1xcHb
vNMxITDZYUmBLdf1+S0Q8cPJDgwgsKDFASS8uCTFIWtPyWQJIF+4+cCphT9T
HDx5mLTbN7c4XFS6/bNOLtUBaMrTC2egfL9Uhxl5Qs0HnkD56xB8yy0nyvY9
RvDf1dibxkmlOSydfURhw70Wh6KMiW9rxNMcdDbNfb/8MtQ9t1Mh/NMtDoUg
92xIdeDTBQocaHG4ADJ/WirE/TNbHLYCjZ8PtL9d7Oa57/0tDn3TgRbZpDpc
BvkfyAfba5QK8U9vi4MPyP+9KRBzuqDuPQf1f0uLA8hbSu3JDkcVNhRlZLY4
LHLd9vkvS7LDY5CDI6H6tyZB9Ee0ODiB1K+Ghm8ygg+Wz0Dwj4DMK2lxCAN5
5HSSA3r8AABNAMog
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[1., 0.831373, 0.16470600000000002`], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIxIGYC4ul5Qs0HttQ76N9VYWssTHbIff575cdD9Q4+
5p2OCVOTHa5WvFQzvFHv8LbG3jTuXrIDn+6mue8f1zvIRqVY3xdOcXB/WCWy
7n29Q8ZEoArPFIfDXzVi+hkaHG6e+x78uDUFYg5rg8PWE2X75s9KcQBpXy7Q
4OCU8PSC0ukUhyu+SQIRXA0Ora8Dd8i9TIHY86Eewr+ZAqHv1jvc/lmXtedC
ioMd1/XFBVfrHS4qAUUOpTg8Xjr7iMKlegdvkD0LUyDuOA5Vb5LioLChKGPi
5nqHb0BnHTqaDFG/qN7BpTvn+e+JyQ7vQPY11UPETZIh6hvrHY6DDDRIdtgC
cncfgg+2ZyqCfwjk32X1DsLNB04t9E12QA9PAEFxqOI=
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[1., 0.8, 0.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    623.727, 154.941}, {624.012, 155.79299999999998`}, {
                    622.383, 156.40200000000002`}, {621.6840000000001, 
                    155.70299999999997`}, {621.383, 155.406}, {621.305, 
                    154.895}, {621.508, 154.566}, {621.9649999999999, 
                    153.824}, {623.438, 154.07}, {623.727, 154.941}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 0.831373, 0.16470600000000002`], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJFIGYC4ul5Qs0H2OodMia+rbEXTHEo3zdfSt+w3uG4
t3mno02Kg9WWE2X7Iusdbv+sy9qzAMGvFlnn/vAegl8EMoA91QFo2qmF5vUO
qz5e8k0ySXVYNvuIwgYJBD9ulycPEzeCD7bvY53DzXPfgx/Lpjoc+qoR03+n
zoEBDFIh9Jw6h4tKQBcsSnGIBekPr4PYsxXm3jqHCSCN+qkOj5cCLRSqcwjl
0900d3Kqg8fDKpF1H2sd1A051sicSnWYLMESxncVwY9Ksb7vvxHBlwEJrK+F
hMfcVIdOx4SnFy7VOuwHWnO3JdXBEuTfx7UOra8Dd8hVpjpot4vdPAc0vw8U
kDGpDnZc1xcX/K11AOo2jdNLdbAF8eXrHKpA4bUsBWKfcZ3DDFC496VA9PfW
QcKlPsXhEzBYBE7UQewrSXHYCrRu/qk6iPv0oPJn6hxU2RqnOrOnQOLhQp1D
P8j/z5Mh5l9F8MHm30TwweH5oc6BG+gs21/JDujxDwBgU+hd
                    
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.8117650000000001, 0.06666670000000002, 0.14902], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    495.555, 164.176}, {495.09, 165.383}, {495.746, 
                    166.516}, {496.90999999999997`, 166.516}, {497.977, 
                    166.516}, {498.22999999999996`, 165.727}, {
                    497.65200000000004`, 164.21499999999997`}, {497.25, 
                    163.176}, {495.949, 163.148}, {495.555, 
                    164.176}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 0.8, 0.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    667.9449999999999, 166.383}, {668.23, 167.238}, {
                    666.5980000000001, 167.848}, {665.9019999999999, 
                    167.148}, {665.602, 166.85200000000003`}, {665.523, 
                    166.34}, {665.7230000000001, 166.012}, {666.1840000000001,
                     165.266}, {667.656, 165.516}, {667.9449999999999, 
                    166.383}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.8117650000000001, 0.06666670000000002, 0.14902], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxdVH1MTWEcvtKaUaY7i1HkM1tr5Q8jiYc7U0hj8zHS0ilOt9x76x4k9x6d
e8+RRtJExtJizcfMWopUYkiGJWQ0a/lqrRn5nJls3p/f3WzO9u7de97fx/P8
nuecKen2NZnDTSbTMLEsYvmJtaA3uaTinIb59fd2tu6RkFJ66/usGg0fXIvm
pKoSYnqmB2hlGqJpL5ZwzHIgp9+l4e6KucWLyyXsX5zW12n25T+Q0CC2qvJC
zAzQjlr2ZOBtzck74fMKsW50VF3l+kxU2Mzemx0qTi+98vV3wjYsHPn8jKPS
DRM956ygsmnxbkTMHnExNN0GEX2/+pELHwnPmlxEFoV0d4S5GU+EE/GUP1nF
xoy43mS3wrhXqQivzZPLmhWE0sVeFZubEgP9BhUQnNqdKvd7oYBgDTpV7Gqt
mhD92JefpnL9agVymXizQsWXJ0npY2wKnuUPzJzd5eb4JCfjbXMjlvhPzON6
YSrjbncwT6jY3v/r/Gc4+H6Lipc/VWtLlx1BdK5SceGzaPDOxvH5ezFK0Io/
kY1imm9RIYz3qxsnRWXB2qIcGS9reDxVVFBl3CGiBRraCYhDxm4Bb0SlT6+1
MuNu0JBK/C0yBs8K5b758s0y4kj/EA9I9pRxMs8lx8M4UmQEbxDMmj24Ltr6
n5K5/5AHhyn+vQyS48ccL+ufnIXb4nVpn5f5FFoZxy6d59GWg02k0y0dT6h/
gR3LA/0ii77reCVg2C442D9BBjrpPiCPdf2ts/5mJwSqrvyvOvuv3sn9u3X2
UaYCglXa5Kv3xqfvZZ19N6TgqRjHhlod1yaJiZp3cHzdv/NVqn/t3/nv/AZ0
hBGQSoX972+wngkKssgfSwwkvC4Ye6nECUprzDbYNzV5SCR+Bb77hlzGsc/A
cdo/OdhHLoPnYbUzX8lALhl7aDvrFWPghgjrCcxmv93UsUTYYqrFp0esznod
3Mp1z3s5viWD5xvsxSFq/FDiea30MB+vxHimeeCgfooEgrmsUcMM+n7tEv7/
P/wBILPrVg==
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[1., 0.8, 0.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxdk3tIVEEUxjcLW6REtBehm4nlRklJyEZm+5WhiG5mQYaUiNxZLxJmDyLN
FpyTSPlHRERBlMgmgURYRPbYNtGtrEDMDULKYrUHIj62sLAImtkZErow93Lu
3HPO9/3O3JUVh3azuRaLZY5YG8WKEutu73F/SwLBIi+fge5p+/5zSwk/xKP7
hYHa0dUZ1kTCyUW38kITBjYMpUY3JBHG652ZZbEMTUsG+37aCOK+ZySdYbhO
fJhC2NF88OvvfIakUiPrYyrh/YynylfIkB3z1luTRjhqnh+vL2Lo/P7nzYkM
woSsV8ow0nYlkJxFeNKyfP2QwbAw/c7VyVyt5zBDSNbfpfWcZYjoLyEUOM5s
K7/NINsVmQS/zLe6YWscK77v1vm1blT5jl1YVkxoDw+4Kk5X4p7sn6fr/arE
1I1nBY6thNcp72Y81SZ6JI8thEJZv1HHmwibZeNHpuKTqf0/MJVfu65XZ8Jb
IxwLPpeq46kr11T61xCkLNtiU/l1EFZFN1zMCVYqHi69/1Tr3UnYGytAlLgV
PxFLfM4kN4SraXshIYG6XraGmYqFn+3ln/tTgpqnU8+jlam8HELZw/wFUV6G
Sel3PindPXpeM1zlv2LKd5ireQQYLksfnzgGJJ92BlFlbVMfx3M5gHqGfvk+
wJGWYb2Z6NHz8XOlT8wn6KqI29fJ/+m9Lvl0cKVrcDaO8Dw1G0fO5zqGQHLH
EfPDbPxNjDEuxJXuMUP1H+aQad5eAwckjy8c8bJfm6F4jHJIjNnXDKyQoKe4
4ttsqPMWQ3gssM8T+///H38BLhp1tg==
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[0.831373, 0., 0.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    606.387, 168.33200000000002`}, {605.305, 169.984}, {
                    605.762, 171.195}, {607.4689999999999, 171.195}, {608.406,
                     171.195}, {608.9409999999999, 170.816}, {
                    609.2890000000001, 169.90200000000002`}, {
                    610.3359999999999, 167.14499999999998`}, {607.992, 
                    165.879}, {606.387, 168.33200000000002`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 0.8, 0.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxdVQ1IllcUth9E1pBmK9yW2d9KaKLRRitzPmXRmko/o6byuZp1rxphTjN1
uXrvdSExnPthVph89DdxcylOo8CZq2i1KMK2RdMIaRElzdmoLcbY7nnPoRcm
vMjh3nvO8zznOeeblr91jRoTERExyn3F7hvtvoz5exZv+NXD7LlRrZPXKSTf
mBlpRjwMPN65uXuLwububZ/FjjL4ni4eUKjsCT+fFG2QSe9+UnjQl5U/fobB
u6lPXTucrFFB5ykGp9y/GzM1qu7OmhuVY3Blev/jnZM03nh69JxaFxd+cr86
bWIQ+/kH1JN4x7PHlg8eUyiie7lS72uFrvPbe8LlBks23L4y/bDU3y35mhRe
czBK9ht8OeIO9ilMzt2UcvNQEEfQX5vUc/G+4pia3i6p95HCM9kLOs+flPuV
CqH60w8TThn8Vp32ytu5gue0wYSa3h8O5ihQ+pXDBtcv//nmrSKp/5zFoWXH
//jHvY/fPbT6xDSLddGJHU0VEr9s8SjBZc5T+L35XMb8JRYfuzKhDOGz2qKU
CKVL/pBF3V4H9HWFM+5afbXFYuL/luBrscz/O4VO0qfNMq9ojbNT20sL2y1u
HW08OzVWcz+7LUqoXwkai26urNt7wYLShOZp7u89yz7I0qBn7UMWvk+KNAbf
c0JdkveVkq9X8OyS81ap/6lmXActzlGCI5r5NljEkH5d8r7WIo6InpF6u4L4
qpMje2sQTyH91otejUHs+60kiP26a4VPvuBZo1m/css+ytXYQ8Bd/aUfbrnz
9zuCv07452n2T4PwSxN/N1n23xy57/gtIOEnaNROck4Iy/k4jZc6moabGwXv
sMIXxK9c6rUoHCEhN1m8GGk+Tw8r7keOZZ86f5LMJassiNYU529KU7/coowI
tinG/6rFt07GsZdlXmcI3z7xe7xlv59QrEuc6NUq8xQr+n4j/o6R+KLcj7JI
8veCzOeIeXLu4/nFsJ+Pip/7DOvRHMS+n68GsT8PdxTclPxYeVHm567gaTHM
d1Cxvh/I+2uih2fYj9dlX1UZno+/ZH7K5P1E8UOpYf3jNc9TheH9tkgz/h2G
dcrWPD8u9udho5y7+2sJb5nGCuJfJvxqNOMpFj1qxL/rDc/bNo0U6udCg69o
n2RqNKS7xicZ3Kd9kh/ElCb15yBeSPlTCthvLxj2X0EB79FI4ZdYwPq5/e3r
d0n81u/x/glpkCy9DyROlniM6DVe8P/rYRzVvyf7yeXrJ306FfPt8XgfFirG
d0B+L0rFvyGP+Q6I/7I85vNI8f5f4TGfIYVEwpcp5x2K+a3y2D9V0r88j/3r
9u0w+eV9j/d/quJ+hoVvnPT/gsdzOlvh/79n/wGN1yE9
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.8117650000000001, 0.06666670000000002, 0.14902], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{544.4259999999999, 180.895}, {544.2230000000001, 
                    181.42200000000003`}, {544.4730000000001, 
                    182.02700000000002`}, {545.0659999999999, 182.461}, {
                    545.891, 183.062}, {546.1519999999999, 183.059}, {
                    546.7850000000001, 182.42600000000002`}, {547.195, 
                    182.016}, {547.387, 181.312}, {547.215, 180.859}, {
                    546.8009999999999, 179.781}, {544.8439999999999, 
                    179.805}, {544.4259999999999, 180.895}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 0.8, 0.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxdVAtIFUEUfRmIRJhURIhFRWaQphJlZeJJrQhTy0BF/GU2s0/r+emnJHbF
wkTMTEyhREJMCpOorBBTs8yICglN+oiI/SRK+lhIBc28mRhwYdg9O3f2nnPu
vbs0PTt230ybzTZDrDCxXMTqXXItz3pKyA2ZNdSYw1AwviLQ7S0honz/h9+X
GfyHl7sWj5G6NzHUOuaWdL8ndDV4+g9HcBU/TrCqPheGtnH4Xa+faP5ImFfS
/fjiXQ6bvEYNLl3w8tmvQYOPdooP9RNOftp1Z3GFwVe+Po9KD5i2P8mwKDEj
eETw/VIYujblFVPf6yXUSV7tDEmVPZMrbxDi3QWTbIYHUt8JraeKQewmVRYR
vF2La8InGLbPdllVWkg4KAXM4cjsOFS98DihLzKobLMvx7lwcfAUKR0ZHDJ9
TD3BSz4McVw6LzLUEcaaxMMPDl+p///5Cxy3vv8dyHeQ4p3KIV+nZRF8At1a
vFJ0vEPjs9q/XM33Hlf8s7T+QY4d8nwyIbldMO/jyJf+xBE23nx0pLOLYyAq
3SMhlvBTyOy5yrFpJKaidichRcaXc9RIPdEEeWzY0vWJ1PnjOCaaH0YGRRDO
SKNiuOK9XvMP57gv/fMmHJvfum3UYXCe9K/a4DZBp6FV6w/T/IItpZfrfC8s
pfew9svDrnwsJsjwhq0GO+sbbbBTf7xd5SnQepPtKl+Owd9EG3nsNVi4964/
lbBBJog32OlPqMFOfqvtqh+idP2fWMrvdbr/MyyVz5UgunD3mOjf/mWvp4pc
dL32cMXXkxAn+9GHq/700/tTDAFyrrYQ3kwVZXb8YUpPgp7HAB1vab8TDZbT
GuJu8Gk5mC1M8TxAqs/KmJof0nzTmOrfOs3Xj+G25N+m67uGYfr/4B9wp97J

                    "]], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxdVX9ollUU/pwwhooMlTAx54bNzRrmLD5Jp4+JmDmzFFF0Wzbme+99v9S2
ZGm6Uu6VjxGyrEzZsGHLH6T5K1uy1lwr8lfKmqL9kmk6rKlME5X+CLvnPQcH
ffDyfYdz33Oe57nPOV9m6Yq5S/vGYrE+/lnqnxT/fPp6Qb8Lay0G29aT208H
eGxR2cROHz+eun7ztLjCd3dzimqqLI7NildPhUJRTdvdnA0WW5cPsq3PKlRP
XdLVftji13/eDpuHKjRQvZMW/S74X/kKBfSjU+o1KOyo+37kgW6LT6Y33vn3
ksKTh7b17Lpu8Ru9f0thVUv9sLHdEr+kMXNAyhPJPy36U70mzecfSL39mvHl
OjznYWTVaaz+K3tc2hiH0ePS9g6v1bhCDUc7DCJ+8zXjz3CMv1b4pTvmPV7i
G8LnSACiveSs8C0NmI+PiWbDhAA7ic8NiXWAvztml6anOGy4/vKREZsCDKe6
wxxIpqz7AXp2/TArnuOgN91cO6VYIUaffMf67lbYQn3GO9zzMNpOKHw07d3X
rvn4s9u+MDTC5pUfDH1a3v9G4meEzxnN3wUSd2uuP93xfaQY1me2Y/3TDAzV
KRG9Ug02U78Kh5+y/A3485F+lQ5vDdk347LPj704KnX9O5LPN3yfSYeNBHyh
QSHpVS39lhvWLyn8thrmZ4Vfl0HkP58/6q/9YixkvB9LPi9E8pFfztz/2qGD
+oUhDh+vbKk/5pBN97+nN474DEk8jKP+lQnG3+qwYGDeoW37E3iK8H/p2D/1
CUymg587rCF+7ydY170ST07AVz236gvhly71Gh3eoIMPQo6/cqxLV8h+8PUj
HOdDno+Dou++EGe9PRbWOdapSvgm5T7LQ5Bd5iwT/q+G7P/FgmeM9HtR+n1r
uP4EB6/SvCuPGvbxRMfznGm4bq7oW2YY3wDHdX407Oc7lvMHJO/nLfJrhmF/
XZX8JQ2frdC/W7znx6jI5yd1ztm45ZzMR4lh/Kcs41lm8AcZp80yn5kGt8j/
TZbx58r7zRbtdL/3NPvhhOyb3Rp5NO/tlnVap9mv52V/FPbGEd54b1xOxNoV
+71F+lcpnsed8v6HivvWWvbpdsW4aiyKm7zy13rj6HyOfhhH816mma+zKKHz
r2iQzXrWyT7N1LhM/NdY9m+TwghaDCss++mqYp+EluepQuNN2n9K9OzQ7L8S
4f+z5vmZJ/p4PaL9UCjx8xoZVL9Q+BZoFNO+myv7dJTGC+SnYunv922E3+OJ
9stIxfNQbrlPY8B+XSn3kx0wLv//QGWL4gH+///xHxEf4Jk=
                    
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.8117650000000001, 0.06666670000000002, 0.14902], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    640.777, 199.99200000000002`}, {639.508, 
                    200.92200000000003`}, {640.09, 202.41}, {
                    641.7230000000001, 202.41}, {643.211, 202.41}, {644.387, 
                    201.184}, {643.9609999999999, 200.07399999999998`}, {
                    643.586, 199.098}, {642.059, 199.059}, {640.777, 
                    199.99200000000002`}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    652.1990000000001, 203.47299999999998`}, {
                    651.7930000000001, 204.754}, {652.746, 
                    206.05100000000002`}, {654.094, 206.05100000000002`}, {
                    655.094, 206.05100000000002`}, {655.375, 204.848}, {
                    654.754, 203.23}, {654.3009999999999, 202.055}, {652.602, 
                    202.21499999999997`}, {652.1990000000001, 
                    203.47299999999998`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 0.8, 0.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    516.082, 182.812}, {516.1800000000001, 183.316}, {515.918,
                     183.684}, {515.4609999999999, 183.684}, {514.496, 
                    183.684}, {513.914, 182.83200000000002`}, {514.371, 
                    182.094}, {514.8399999999999, 181.33200000000002`}, {
                    515.879, 181.76999999999998`}, {516.082, 182.812}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    556.75, 187.359}, {556.75, 188.105}, {556.4689999999999, 
                    188.38700000000003`}, {555.848, 188.266}, {554.488, 
                    188.004}, {554.3399999999999, 186.281}, {555.672, 
                    186.281}, {556.418, 186.281}, {556.75, 186.617}, {556.75, 
                    187.359}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxdVGlIVUEYfWWJWZaVhJipbRaPwgyyjVef2mZloUGCaYkUzlzS1CJtm7ll
YhphWVEQJmkJhYlIi4k+xYXCH2pFqYmFWEhEheWCWNHM/QYHfHAZzn13vu98
55yZhYnHoo+42Gy2SeKJEc9k8WQ4i3yCtnLYcvlo/9hoErzL/BoYHMfh+9nN
aw6GEGgcWh6XX8nhdsqcrHo7gfupDvcODxPSxFLiS6DvwZ2mAC8THg28iUxc
TsCoOXHde6MJXa0j+/p6CWwSn6VGmFArXk8JpNAg68WYMCyWhngK7Yu6R1ms
xs0BFekkXuPc0IQv7YdMuHJLEEjVOF8WytF4/ZNXJ52NFPyzv0VVRZpQvPXZ
77/1FE6Jcdy2mLDU9fzN8CyKfENMmC5oOewUek97lW+fZYKk6bhAwCZ/U014
KsoVpRPk+4/jPJTAp72CyWcOvrGHN35KIuCxsrLwZxvH+VIInBHleis49ssg
QK4JJR9zrHuWwAK57wWHZcFuZb55BOu0KX2LlX42E/V3peP4YHXEjMnzNbb4
rKHoV6fyaw8FOb5fHUceYRRX4Z/Fw0FhblZ9y72bHNLli8VKD8bx/TQKG6SO
URykzSWdyt9V6vsOjaUd9a50HNeJGPV4UbDnzOtqDVf9dyp8QGFGcf7jat5K
tb+Ao1+Din+RyuNsA36JWHmWcZw/yMDvq1X/bQZU+YkdTo1fyzw1aDxT+tOs
6kVpbM15SOOgniWu59MMSO4fezhQw+HDKDNqMg2Q7SpKNbb0ztPYqpPNMT/p
BkjZUo8rvVcamBfCMZ8uBryQfKPV/C0UcRjHvJVTKJX97Bx1yKY4f4DC5xR2
53jeLlKQ8e39yND/AorzNDLMo3MCHta4W/L3NDDfTob97UrvKgYx8kOht3U+
Sxn2dxiYk1wGL3etzQ311tjiM0jHsZX/5xTk2EU3GOb9LkU9mhjmN1nx/8HQ
33Dl/xDDviEUZJuEEYZ1RN52yAM7qv5/T9CfPwzvo3YCMl57Z6u8viXo12qO
uRF5tupv5rBb1i0kmJMVHOvtJ7j6cbgqhfEn6IePOh+1SXBJ3jeBGlv3j11j
a/86lY/OJJh4v/4H4LaNtA==
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[1., 0., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    502.648, 195.906}, {502.648, 196.754}, {503.125, 
                    196.871}, {504.469, 196.35500000000002`}, {505.16, 
                    196.09}, {505.195, 195.934}, {504.64500000000004`, 
                    195.58200000000002`}, {503.566, 194.89800000000002`}, {
                    502.648, 195.047}, {502.648, 195.906}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.8117650000000001, 0.06666670000000002, 0.14902], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    504.72999999999996`, 198.164}, {504.72999999999996`, 
                    198.617}, {507.008, 199.809}, {507.875, 199.809}, {
                    508.887, 199.809}, {508.328, 198.359}, {507.199, 
                    198.055}, {505.562, 197.617}, {504.72999999999996`, 
                    197.65200000000002`}, {504.72999999999996`, 
                    198.164}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 0.8, 0.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    539.324, 194.605}, {539.324, 195.73399999999998`}, {
                    537.2930000000001, 195.578}, {537.0740000000001, 
                    194.434}, {536.93, 193.695}, {537.164, 193.52}, {538.105, 
                    193.65200000000002`}, {538.777, 193.75}, {539.324, 
                    194.176}, {539.324, 194.605}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    628.9609999999999, 202.547}, {629.168, 203.621}, {627.668,
                     204.348}, {626.875, 203.555}, {626.082, 202.762}, {
                    626.805, 201.258}, {627.883, 201.465}, {628.379, 
                    201.562}, {628.8669999999998, 202.047}, {
                    628.9609999999999, 202.547}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxdUltIVFEUHZVEwspS/BhM7KVSyDQfERXmEpGKiqigDymLwYk4Z66lQfTw
7ptJhD+9oEaI0J4Q1DRUyiAymZSFhFYQojXkMEhEWVRkmESdM/vQQBcO96z9
XvusBb792/wZLpcrTR2vOunqbFzZWrknSHjY7vbEwgLLTuWPDN4hNO47N9E0
LPDt1WZfTohQ4s26XTAqECk8+XHrdUJt94bsdI9E34/SnWcuGv9NifKZw9cO
BI3/vkTixqXHRSp/oqliRW1UQnUbfzFAeDtFoue5RFFYdcp10PnsULSdJFY9
UJdFDudB4vXhD8Xe5Q7m19SteTdHokD/PQ5OB+vntWRLznM7UFNFCscF52c4
aFPu3m7BeQonebYKtrtTeH38aF6oLIWTfH2m/qcUfqoDcuQ/7IktzmyulJhV
du/ylxIHmnZ5l4RLf7+I54lL5Lb0DlyJEXbMVoHTku2PiOOyAujXdTuI+Sqc
nMNP3E/htbrwLsKxvNC6+GfJfoswMvhze8Jv+h0nbNL2JwK6THgvYbXew13B
/mLCqN53qYmftPFy4ZspOmHmSdhsH5PQ69qi8JLM5gtVBwPMU2Eth4q5Fu8r
jXBWP/xug6uJeTZYsN5P3/raSJhUsuizLdZTg5n/vMX1q4zeOiyu/8fmOTot
3kO/ze9aY7FuwjaiOj4SYD202cx3RoD1M2Til5p9e40e1ftfre76/ruOmI8j
WJ9HzL5sgf/1/xc+N1Nd
                    "]], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIlIGYC4vfLj3mbt7Q4fNOI6T9Umu3QLnbz3Pe2Fofb
P+uy9jRkO4DlO1sc9O+qsDXORPDvgOTXIPiPl84+onAg20E2KsX6fm+LQ8bE
tzX2L7Mdtpwo2zd/covDcaAqR44ch8u+SQIRM1scVNkapzqr5zgwgMC8Focq
kXXuD90Q/K0gfX4IvrohxxqZvByHT5eABkxscVjkuu3z35wch+l5Qs0HgO4t
tOW6vtgnx+EhyKCaFocwPt1Nc7VzHI4obCjKKGlxqAaZr4XG90Lw43Z58jAF
5zgcBfErWxyKQB5IznEAimq317c4TDj0VSMmP8ehwzHh6YW+FofW14E75Hpz
HLL2lEyWmNDicEkJGGKrchyAofhVo7nFwaU75/nvgzkOOpvmvl9eBA2fB1D1
SdDwWQm1P6HFYQbIH35Q98e3OABlTeOEoPYD5cHhwAE1Pwfq3zfZEPeUQd17
ORtiTgU0vI5B47MMyl+U7TDNGeiwYqh7UrIdfIDRklAFtc8PGp9I6QEAyt/y
gg==
                    "]], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxdU2tIVEEYXa3UXhIWEVpmoiWYmFFJmewxkQiLrSSLEgnRsO7cW27Qg0QQ
Z5AIswepJCG9kCIkpIdEmJiERqTmUkiamIqYbivKmv4ImrkzONCF4XJm5jvf
d873zYa8s4cLFjgcjgC+wFcgX+uO56cMBDC8bL/QXNdg4PLYxqSQpQy7XvCN
TgP7lgXGl4cxsPFDTZF+jWficipbA8g89hY7t+eGEnRFf58rCWc4GprQeC+R
wFf/ITM5huF84U1vcSbB1bSTI11OhiurGvYO3iWw82cw5L7hTOME7/2ceCfD
km8Pz6WeMrFeJN7GJG+Vid0DrorqWIbMZM7Ua0q+hSqfy0KriB+nqLHCylqe
WvKeh2K/+Pst9BzIW3GsW2P7vF3j8tW9n/90UCT2xwSVFlmY+sIDeij4btZQ
gYVX0389l4Yo3tWFJ/YftGScl2JTUsiztTssDD2ubYsKVn7x+mzM6+2bKznz
lphYzsv0bWXIFvUGm2iLeu4ujGeIDSq9k95JwF31x3G/mgV/jfI3XPn9hEg+
B8MeLjs6wsSk8HeKolrozTalT8MUgian3JR9HdQ4Rfj3g8p8HKcKo/soVpa1
fLxfpLFb9CtLYzt/gonXQj/ns31bbMp6fRTXRQGfiDxfxCDCnacJNnO59dyP
LcLPBCL1z1Cpb9ZAVfo1Mjqp/B0xECmM+0Vl/78auCgujmls841qbOv+SeUc
TRs4wX8urs8hvjUEwmafR+F8NX+1VPbniCn5b2ssaFyVGtv9rVD60zS+IfyM
0PhBBp+MCaWXx9v97lPzXaPiO4j05ZGqv1G9jxYq99PIvN82X5Mh8bC6f8uQ
8zJB0S367DbkPPzW2Nbn09h+P7NU+l9h4P/3/g+ufdx1
                    "]], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4mnO3TnPLVsdeqfnCTUb5DlU7JsvpW/W6nDc
27zTMSHPwYuHSbv9ZYuDbFSK9f3Z+Q66m+a+X/4QwQfL30XwQZT/nRaIeR35
DhkT39bYA+XVDTnWyITlO1zxTRKIuNfiADZeMt+h8qWaIceDFodqkXXuD/ny
HbZ9/nul4hXUPOZ8h0+XgBo+tjjsBzrr7p88iHmsrQ4Gd1XYGvfmOVwGmSfe
6uCY8PSCUnmegx3X9cUFmq0OhbZABtA/D6uABgP9p8bWONX5d67Doa8aMf1W
rQ6rPgINZsiD2GPd6iDUfODUQtY8iLw1VL10ngN6+AAAnyeB0w==
                    
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.8117650000000001, 0.06666670000000002, 0.14902], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGI1IGYC4k+XfJMEjNsdLird/lnHlOnQ6Zjw9IJzu4Nw
84FTCzkzHZbNPqKwIaTd4ZtGTP+hixkO7WI3z333a3fgvr64wLYrw+HwV6CE
b7uDjzlQZ22GwzTn7pzn7u0Oqz4CDU7JcLgAMteu3aFaZJ37Q68MBz7dTXPf
m7Q77J8vpX/XIMPBk4dJu1293aH1deAOOdEMh8qXaoYc4u0Ox72BBv5Jh/C/
tUHsO5XuYHPfv3f6iTYHyy0nyvYtTnfQARq3fHKbA0h5wsp0B6Arv2rMRvDt
uIAaU9scQMrnL4Pq92hzuARy1y6o+cptDo+XAj36Jt3hYRXQocxtDkIg/wPd
IxuVYn3/eatDxsS3NfamUP8/bXXQv6vC1rgUwd8H8s+ODAdgaBVlANWDzTuS
4bCkwJbr+stWSPiczYCY/6YV4p5rGQ7g8P/QCgnfu1D1X1odXIDB+PthBkTf
v1aI/19lOBwFmc/Z5nAM5MErUPuF2hzCQAF7HGq/epvDnZ91WXvWZEDCJ6jN
IRQkn5wBDx+wfYlQ8w+2OQBNCX4cC43Pu20OoGCzbcpwkANFzK82SPyszHDY
CnK3bDvEvuvQ+FVqd1jkuu3z3x9Q/yClJwDhcCPP
                    "]], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxdVg9MVlUU/zQKpSA0Y6wQBUwoKHJNnRZxnMs/aX/dypp/mGUjHsL37nsp
uaSR416ck09yiVszVhqIMiMjZWbYAoFyKRnZyAiRlJBEhIwpMbv3/Q7i+ra3
t/Pdc8/9nd/5nXNfzKrsF1ff5vP5Runnff2M1k9vWf2imf8oejLkl13+VpeK
s8Zv/Ebbr77+eNtz2l4W+PZqwoCibZFBL4VpW/+7pVjbm+aknW/6zaWfnlkV
vvSaollVjWtrzri0rqbkvuRBhXeLS293TZ02ZkhRw6KZm+acGrHDHj6w8/KP
LplX2RDvP+lS+/oJ++ffUFRv/OsYj7aro/O7X6hy6bLB6yugS++kTl+x2yWf
9ysg7fX9xwEXuLV/epH2WOfS9rmbMzt1/KbYM9dy57m0WIdNu67oIRXRciKY
8V5VtKZzsPxKnUPhSzWSi4w/1QHOFsazR1DHpx/WTW5U1HdKJ/6sIGNWHlT0
pYZfct3GOVs5n89s8GMx/kyblhs+5zF/CTbixyjk0eOniSaBCXz+535KMXUZ
z/tL/eBnnCJtVUcX+8FnuIJfnh/4wxTNN46Wn3b79Uoo432e/UM5/2Q/mbTS
7mT8v2eDnxDmb1Y2cGlbmD9UFh2bXCnSxyr65KmD/UOZa8BHCPM7I/NmPK/e
ZCHuWI6XYiHvYEXx08ZURM22UJ/bFRm6SmZY4ONfifWpFvD0STqq6WgNt+B3
QdJWTeOywQzo86SkLUYoTRnQywGJd2kG9PCBpB6jl73sf4s9zvD1ikQeFeyf
Kukeo6crGdBbIsfX53s83mJ76/ES+UdY4CtO0orDC+8afb8FfURLajkxsKRj
ooU6TZI02yRyw4L+pzDeMJtqdVoBbXt5bh+xTdnbte3xFcd4j/D6dEnJrVPu
yOu2SVelOWexhI7uFVRn6vWapJ9zdOFJkEaVqHIlJZr6rxbgt1BSjHYr2sDr
hbxf2wWmXoV8Xq5AvjsYTyHH3yfB2yFBT5v9XzOeNkGmTIF6ScatqF/AT9fL
69dgB/1wWoK3SAfvVklmzGQlODTJCL1dQq+POeD/D4n+SOF1bUeZwLpfvfz/
5PotdOgJE+gSn7/EIdNG1VpPjxp8yx2eXxL9nc77fQr4bQd10HotNXVc7wD/
3azv9xzKOOJui4zg+ZnvgLco1nMBx4vleaAc9F+8Ap/D+xN5vm5woIcktt/i
/Unc/2846KMkxveyg/o/qJDfXM7nAQXdPeJAL1E834Ic1FfPB4/f0wLnB/H8
OSxoh9HhEOtPzztvfgxwvTbz/Otjfbwp0O9/sb4WcLxO7q9YrneHRF+PYn21
SfRBuw0+Wvm8Rtaztj0c1TZ417Y3N6rsm/rwzqu04XdWoh57bcQ5x3os4345
PzwPbPDSyXreY9Mhw28X67Xchp4vSuS1z8a86JaYdxU2nTPC72H/L3i+93J+
X9mYJ/2sz+Mjtud/nOd9P+tZ2x4OrT/vPrtgY76Gcj2CBM6P5/syRuBNikLN
O1Ug35V8X68UwJOjgD9fAG8u6ykggOdd9t8pwHeeAp/7uV4b+X45KlCffF5v
FtBnwfB9JcBvQKHfYhzaZfTykUJd0lmvxzherYP50aCgpwbur3pFC8x99YND
3vdIDfdLnAt83ynMkbUu+l/fx978LHehi7OcT60LvXYp1LuZv096uX9/dXE/
9nE/6O8Xb378zefr75v/fw/9B6bsL9Y=
                    "]], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxdU21IVFEQ3SwUKhaxEOnDTCSiDyTIzKw8UiGxlNQPsbAQMTQh3b3vaktt
QSy9SSJD9oeVlJSGFCKLX6mYLCnrIiRWRkiESERU6GIpFhZ0b3N/9eDymHfP
zJxzZt7mkqqT55Y7HI5l6mSoE6NOQ2WCP9RDmPXlZJwdldjZcT/a2kcYcWXW
5qo42hp2ZQ4Qvr8+VhIfkeiK1Aw2DRJ6k69/OzEs8UZ9LhwiBJJWFDifS8aN
EGZ0vXaJ+MKsrkiYcOHz0pO5exLewaZ16f3EdUolHjcOpwQ7CHnTl9a2r5d4
9uPPhFf1V1He9JgFTaM4QPiogdKCUxP0E7p1/jYLKluU+0z9eYH9U/m3GryE
Nf7Q6MNJgRu5xZ/GawgaVj8kUHT7xcLWakKCvu8UOLo6ZjtZxHWbTb6HkP4h
LfZao8Dp0uypfDcxj7sCDv2cIhxc+a7ZXW3ibIJOqywQqNX9Uoi/7xU4oHGr
CMqt3uRNAlpm3k+b68cJ3NH+z9js21cPJrSfszY26MZRDyhxcmxRxRt1vOBh
v6I23nq/bNn128P95myENUGn0TNvo0/PJ1WwP4sGv0dgh57vks36XYJ1xxHO
9KvMMoGKARlISiSU16sJXhH8TjN+BEy93YTLej4tAhf1PHOM3qeCeR4y82oz
94eNX93GryPEuJeC9R03+FiL9RQR+7LPYr0VxD5WWYz3mf18ZPbjpuHTZfah
jrhOr4Xzmn+d2d+Q2R+F/zfXMonx1Pe/rj4w/YKS79sIWXpBhyT7GSTGqf1v
cSsmnYRXOlb/x///z1+Qv4VC
                    "]], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxdUmtIlEEU3VbIUFlSJMooH6gsVqyCtWVEJwzFR8UGgYSpSIFEm8vMlGVP
seUiq8gaqCChuOWyFSGhsESIiIq/QouIiCiLkIhQg9Doj3eY+eUHF74zc++5
55472Y3NZy8lOByOLRxuDidHZvCXL95GaAr/vn38mUJvaejKUjuh7lVFipNx
ZYpzHwUJWaOiKRxTOJb0IRIgwq30F+WLj5Wp6yDM53z6d3dIoWViMMMTsrjf
5ncS+q6mtU92KnScaPgx/4BwZGzu+kS9wrQmvk/wfM7d2papMKMx6/n+ZGA6
a1YitYYzmwnc5WDdc4nLr9XDnfWEBc3fKlGo63yEVq2nTOLdqcbtNScJ/qX/
sdV0afhLCOPcbvCbgOvAy0fLXss3KRAJsMICwvsbP/OL4vZ+N0G3Hx0RWInO
VnldZOYKCxz9cqarL8nqDQnc5LJtiYRs7U9QYD+XRxMIVV6e9J5AhfYv0frV
I4wfyRYPC1TrPJfFTy3eZfGcwJ+3PJCbEN/Li1oXqO2e+usuIpy/yErypPG/
mMCntd3F0vh8iEyfUuvXYUKJ9tsnQTs+vlkrI7OHgDR85+x8MQk9fpT97Nc8
X6XRf5rg0J9bmb4XyPjkt9hP2KN/wgqLehHXCAW6UcTe37H75ve0+b1tADk1
HF8=
                    "]], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJZIGYC4qMKG4oyXNsdGEBgVonDp0u+SQLu7Q7a7WI3
z80sceDT3TT3vUe7w9sae9O4GSUOD6tE1rl7tztUA6mHU0ocrgCVR/hB5SeU
OFS+VDPkCGp34AXpay9xkI1Ksb4f2u5Qvm++lH51icPjpbOPKHi1O+Q+/73y
YwBUvxPUPAmofS7tDjvkWl8H3iuG8z1AFt8thrsPZMyGPcUOtlzXFxc4tDsA
Ve+Qmw5Vb94OEa8udogGWu9v1u4wWYIljK+9GOI+43aHjIlAF08sdgApX67b
7iADcidMv3q7Qw7IffOKHQzuqrA1KrY7LHLd9vnvgmKHrD0lkyWkoe5bADVP
rt3hagWQ8aPYIab/0FcNoH59kD7PEocOx4SnF4zaIe4uK3GY5tyd89yi3cHb
vNMxobfE4Qgo/O2h/geG7/Q8oeYDzoj4AIe3C9R8IH9JAdBnQD44HIF89PgD
AJqJyQQ=
                    "]], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    733.2810000000001, 283.699}, {733.3629999999999, 
                    283.58599999999996`}, {733.2890000000001, 283.574}, {
                    733.2810000000001, 283.641}, {733.2810000000001, 
                    283.656}, {733.2810000000001, 283.68}, {733.2810000000001,
                     283.699}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{707.8159999999999, 215.309}, {708.172, 
                    215.23399999999998`}, {708.512, 215.141}, {
                    708.8159999999999, 215.023}, {710.133, 214.52}, {
                    712.0780000000001, 213.465}, {715.109, 212.684}, {707.777,
                     212.758}, {707.777, 212.758}, {707.8119999999999, 
                    215.11299999999997`}, {707.8159999999999, 215.309}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGI1IGZigALudoe4XZ48TNzZDrZc1xcXiLc7qBtyrJER
ynbg0900971yuwM3UNj2VpbD0tlHFDbItzvMyBNqPjApy0EHKL1crt3h5rnv
wY9bsxy2ff57pUKq3WH/fCn9uzlZDvp3Vdgahdsd+g991YgJznLwNu90TOBp
h9CWWRD7mNodvmnE9B+SzXL4sPyYt/m3NofbP+uy9rBkQey52+ZQLbLO/eGl
TIdPl3yTBPa0ORwHGbAm0wFoytMLU9og9m/MdPABmTsLwQf6Sru9qM0BpExp
faZDDMghsW0Q/x7OdIhKsb7v79jmUAByyJdMiH2abRD/y2U52IHcJ9oGcZ9t
lkPlSzVDDpE2h70lkyVY1iH4YP8czHJ4DAogoPpCkHlnshymOnfnPBeDuudq
loN86+vAHRJQ99zPgrhPus0BZI3tsyyI/+TbHC4pAUPgFdQ8tTaIuz5lOUSD
3KvX5nAHFD53shyOKmwoyjBtg6i7kOVwGBjM/S5tDhkT39bYb81y2HqibN/8
FKg8MD5g4QOOz6wsBzmQe7a1OQBVm8alZTkATe+dfhpqX1eWw3tQfDxscxBu
PnBq4cYsh6w9QI//hpr3AKr/XxsknhmzHdDTEwBJJQ8N
                    "]], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGI1IGYC4qw9JZMlFNsdjnubdzryZDnobJr7frl+u4Mq
W+NUZ+Esh+gU6/v+du0OEw591Yi5nelw2TdJIMKy3YEBBKZkOjxeOvuIgkW7
Q+wuTx6m9kyH98uPeZsbtzvsBRrLkpfp8OkSUIN2u0Pv9Dyh5pBMBxB1QKnd
4ZLS7Z91VpkOYPvF2x2qRda5P5TLdJgBkudod7h57nvwY1ao/jdtEPuuZDhs
PVG2b/6RNgcfoHMT1mY4AF3XO31am4NTwtMLSpszHGL6gQ6di+Bv+/z3SkVe
G8R/GzIcjipsKMoIbYO4+0gGxD6TNodvGiCdUP2SbRD/ymdC7GFsg7jPLtNB
rvV14I7/rQ6OIPPXI/gXQf45lOnQLgZ0OUMbxP1nof5jboOovw4NH1aoex5k
QtzH0eZQlDHxbc3zTIj/eNocwvh0N819nekwzbk757kI1P9fMh0ugOyRg5p/
N9OhA2SwWpsDSLv9xUyHw0Bn91u0QdRty3SIBfknDiqfC42vuVD/ZWc6XAHF
5z6o/elQ8661OchGASO+OxMSHh/aIOG0CepevnaIeQ+h/hdqh8gzZTmgpycA
OWwazA==
                    "]], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGI1IGYCYtmoFOv7MysdLird/lnHlOnwtsbeNK6i0kG4
+cCphZyZDltOlO2bH1bp8E0jpv/QxQyHT5d8kwSSKh24ry8usO3KcKgWWef+
MKXSwce80zGhNsPhasVLNcOCSodVH4EKUzIc4nZ58jA1V0LUeWU4PF46+4jC
tEqH/fOl9O8aZDjkPv+98uOGSofW14E75EQzHPh0N819f7HS4bg30MA/6RC+
cBXEvlPpDh2OCU8v5FU5WIIctjjdYRnQuA03qhxAyhNWpjt4PKwSWXcSwQeb
a1oN8ccymP5qh0sg/+6Cmr+zGuKuN+kOtlxAi35WOwiB/A90zzGQQQY1DhkT
QSED9b9JjYP+XRW2xqUI/j6Qf3ZkOJSDGIY1EPOOZDjskAO6QKcGEj5nMyDm
q9dA3HMtw0EGFP7yNZDwvQtVL1bj4NKd8/z3wwyIvcw1EP+/gpr/thriritQ
+29VO4SBPHIcKr+x2uHOz7qsPWsyIOETVe0QCpJPzoCHD9i+RKj5tVUON899
D34cC41PlyoHkDNtmzIcDn8FKuSqgoTjygyH6XnAkDlSCbHvOjR+d1c6LHLd
9vnvjwwH9PQEADfzHaQ=
                    "]], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxNVg1MllUU/kDS/iTSZAz8Q52iZkg/OCjguPJvaVZstbU0c1nEh/C9P8q9
9003MkauGWotWs2x/sDPmEGhETotYOpyKZraiAiRqDmUMnPOrNG99zkJ3/bt
7tz3nnOe85zn3PdNXV3y5JoRoVAoRv+363+s/k+udwu2jRWUe+sPH0W6fDox
pfPaxjGCnnnhwe7l2l7co+7afaegt5LinorX9ub5q/raEwTWn3ycGy0oq/HI
+gOdPo3d9PW3H9wiqPRAdXJ6h0/xcz7f8ftNgg4/Om/z/JNDtl1P+PTJ+22T
6+PY/7hPOQZHjKBD5nybT+0GT0hQ08Ty/icafbJ4B0vp4it5D6z82KeQ/Qka
Y/JW+mTcVmn/gm36RKlPp8X56Rk6vo2z0Mf+bYJmVSR2HBvFeMcJWvvb9eil
No/OLt9SVTyL8ed51GsALmU8O13gLBH058llqxMec2mPNqu3C6x/O7Siecnt
sd1cz2cO+Jkpgb/IoUWGT0+CvzQH8fdL1DEQQZ4zEvkbIqS9miZ2sn9NhPsk
sV8VodGGx24J3soiwH9OIk84Ar9fJPA+HgHvfRL1p0fAx3kJ/D+XwO6XWLNK
gOuCJNdsVBQD10VJHy7Ye/nforWoU5+3/GYW3Yhn+01hqirWnbnA8XLC6Nsf
kmZk3Fw3PjuM/vwlyYSpzgyDj5EKz6eH4Zei6KBO25UQpndNvHsVbW25kvbs
9ULo83lFW0yi9kLo9z2FvDWF0MNpRQMm7y4+P8zuNnwtDZC3js+XBdDFpULo
LRogvs4/wTR0mG2fNwSoPzEMvpoDWml0kBIGry0BdRy7mt87IYy+fRNQtil4
MAz97w2AN94hjW5Rj7YtH+8M2XbVtuWrifHudygw+28HlN41bWRZv4M5fSkA
znEu+pUVwI9c6Dw2oNmm/2tc8NurKNXUsYGfn1Pw17blSds230YX9R5XwPMm
x48q6PxL9n9NAU+3C3yugt9lF/zqftl5HeVBp/kKvCV5WBcq9CXNI9PmyocU
9HqfR+NNonkKeXP4eabCvp5XW3+6Qv+WeJizaZw/36NWcz5Z0VyDb4XH95fC
3BWw/6AEfseD3rRea0yflAf8PazvVz3g+l5iLss9xDnEen6d4+2TmJMKD/PX
IMGn9rd9iEqc2+BBDzVsr2P/Wp7/Fz3gqmV8T3vgt06ivoe5nj0Sce7x0HeN
x/YlzuP+SvB7xgX+q3z/NLvQcZwCfn3f2bwJ3K83+P5LYX28zPqZoZBnsYt6
Mni+pnC/sxTqjmF9kMJ91eNgfwHnO8J6fkSB9yYH+9q2fWx0bujD5qt3gDdX
oR+7HPhlsx5reV7u//8+4HhzWc87eV7msF6jDnQ1WwH3pw7ui5kK912dA9xT
+fwXfL9P4vr2OeA1ifV5dMi254/yfZ/Eeta2vQe0/uy9+Cvn7+N+xLnIr/Vi
46e6PIcS936ei3pJAsdzLtY7JPCXu8A7gvVU6QJPiM/v4Pn8R4Cn3dyvawL3
1EEXea/w81MudDUg+H3lYv+swLylevSV0UuLAC49T3bO1nG8Vg86dfh9fZjn
yxWo8zt+vonfn1N94CsSmPP1PnS3TIC3qA/ecvl7pdWHXu8W6Pcp/j6ZJDC/
P/p4Pybz+15/v9i4iZy/i78vhn0P/QeJPxcd
                    "]], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxdk01IVFEUxyeLMSKmshKpSadJWgghLeyT6u8mCymphYsgkcHQRWlz3k3P
fX2ARZiVC3OhKSVlCUXIUEpT0CCMqAiJFRFDhMkQNUVZUVDUonc9d9XA5bx7
556P/++cuzbScPDIfJ/PN89bJd7K8taz8OvfZ64wvpzaVVI1oXC7ZyQUu8wY
K9/cWurtQzGqa29hfH++L7J0XKGrPufc8FlGPP/8pwMjCodqtk9XaEZH3oLK
wBOFNeYgyvhs4g0ovK1o66wnxrH3f+5861bwvCduXGIMjjcmemsUhoztZpTN
uCsGViuJ08bwdmUzkw7q2r1IKUbaFKYcsb9Y/IocNCV6VxVna4n/g3ChtPrd
VEBjucmTItGVo0VHkrDH5FmppY4HJH55GoEN96/N9hFajX9Qo/hNob+5h2Aw
VBdosVcJPvPbr7Fz0au+4yfs/qLGtNFZSaI7oeV8C8GjFM/PaLEFhB3Gb4kr
8bMJU4Z/oSt8P0aF5zoXQfMxG5XzsCtcf0aFW8jFS86s3/g3KvmCLkZNgQHC
UaMn18Uj058wCZ9l9v4mQr/p70JX9JeT8Pyqcfjx3sVZtYSiltzU5Ast3E+T
1PnQ8uiw8To1Tpr+3CLh3Gz13iWpg7XEvUeSp8nyGrK8GrXoeUqiL2Lv+x3R
s1vLnG1zbJ+1cGtw5L5fy3zetPORYaln0M5DmqWPcUfqTtv5Hbbz84GFc61C
ldGdZMkXU/J/P2OrAZ1UwvM6S5+8+Z+b+y7G3Lvx3sf/7+cf+nSByQ==
                    
                    "]], FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1,
                     3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3,
                     3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGINIGYC4kNfNWL6/1Q4ZEx8W2O/usThasVLNcMfFQ5x
uzx5mID83Oe/V378UuGgsKEoY+LKEofW14E75D5WOFSLrHN/uKTEweCuClvj
2wqHC0q3f9YtKHEQbj5wauFLKH8GVP3zCofpeULNB3pKHIC2mMZ9q3Cw3HKi
bF98iUP5vvlS+v8rHPRB5shD+X8rHB4vnX1E4Vixw33/3ul5CpUQfWuKHbTb
xW6ec6x0uAgyv6rYYZHrts9/YyodqkDucSt2iEqxvu9fXglxt0gxxLzuSoet
QOvmPyqCmDsBat6BIoedckAXrqqE+HsHVP5EpQOI2rCsCOLvx5UQcyYWOXQ6
Jjy98KoS4t7uIgc+3U1z33+sdFAEqWstclgG0vej0sHbHKiyvgjijg+VkPCa
VAQJj5dQ/qIiSLg/hvJXQflnofwTRQ4yIA+tr3TYAXLnjyIHj4dAn86thPhT
tRjijumVDuB4NCmGhMukSgdbruuLC5yLHbRA4dVf6WAFCu/AYodPl3yTBIoq
If4oKIaYFwr138piiL+B4TkDFF8PiiHuT6p0YAABjRKIv1wrIf7OhfJVKx1k
QQ6aWOJgB7JXtBJi72KoPGslJL6B6Qk9vQEAyQEzcw==
                    "]], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJZIGYC4vJ986X0SysdGEBgVomDbFSK9f3CSgftdrGb
52aWODxeOvuIQl6lw9sae9O4GSUOtlzXFxdkVjpUi6xzfzilxAGk3D8ZKj+h
xIFPd9Pc99GVDrwgur3E4Zi3eadjSKUD2J7qEgfLLSfK9mVXOuQ+/73yYwBU
fzXUPAmofWWVDjvkWl8H3iuG8z0eVomsu1sMdx9IeMOeYgegqh1y9ZUQejpU
/YRKiDurix1A1idMrnSYLMESxtdeDHHfzEqHjIlAF08shpizpNJBBmQuTP+G
SocckPvmFTssct32+e+eSgi9oBgSLieh7lsANe9wpcPVipdqhj+KIe7cWOmg
f1eFrdGzxOEdKFxmVTp8uuSbJFBWAlHXVwlxV28JJFwaof4Hhu8Fpds/6yoQ
8QH2RznUfCAfbC8wPMDunAXVjxR/AKgq1GU=
                    "]], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{418.719, 
                    283.699}, {418.637, 283.58599999999996`}, {
                    418.71099999999996`, 283.574}, {418.719, 283.641}, {
                    418.719, 283.656}, {418.719, 283.68}, {418.719, 
                    283.699}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{444.184, 215.309}, {443.828, 
                    215.23399999999998`}, {443.48799999999994`, 215.141}, {
                    443.184, 215.023}, {441.867, 214.52}, {
                    439.92199999999997`, 213.465}, {436.89099999999996`, 
                    212.684}, {444.22299999999996`, 212.758}, {
                    444.22299999999996`, 212.758}, {444.188, 
                    215.11299999999997`}, {444.184, 215.309}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGI1IGZigIJXlQ5xuzx5mLizHVpfB+6Qu1jpoG7IsUZG
KNvh8dLZRxR2VDpwX19cYHsry2HLibJ98w9UOszIE2o+MCnLYRlQesOhSoeb
574HP27NcpgswRLGd7rSYf98Kf27OVkOi1y3ff57o9Kh/9BXjZjgLIeMiW9r
7J9XOnibdzomWGZB7Ptd6fBNI6b/kGyWg8KGooyJwlUOt3/WZe1hyXK4oARk
uVQ5VIusc394KdNBJirF+n57lcNxkAFrMh2AppnGXauC2L8xE2L+aQQ/9/nv
lR+lqh0cE55eUFqf6eDxsEpknWs1xL+HMyHuqK12KLDlur74SybEvjXVEP/L
Qd13tRriPtssB17dTXPfX6922FsC9Ok6BB9szsEsBytQAAHVF4LMO5PlcLXi
pZrhpWqIe65mOYCCof8c1D33syDuO1HtwAUK32dZDrIg/x2sdrgEcserLAdL
kHmbqyHh/SkLYs/iaoc7oPC5k+VQvg8Y0FOrIfF0IcuhChROZdWQcNia5TAd
pM8MKp+TBQ8fcHxmZTkcBrlnUhUkHNOyHDpBDsuogtjXleWgCIoP2yoH4eYD
pxZuzHLQbhe7eY6zCmLeA6h+pioH/bsqbI2M2Q7o6QkAI9Mfpg==
                    "]], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGI1IGYCYu12sZvn9lY6HPc273TkyXJYNvuIwoYFlQ6q
bI1TnYWzHEDCCc2VDhMOfdWIuZ3pEJVifd+/t9KBAQSmZDpYbjlRtq+/0iF2
lycPU3umg8KGooyJMysd9pZMlmDJy3SQBWlYWenQOz1PqDkk0+Gi0u2fdbsq
HS6BaKtMB7D9FysdqkXWuT+Uy3S4ABJ/V+lw89z34MesmQ4yIP3qVRD7rmQ4
gIw5UFbl4ANy19oMByD59MKlKgcnIKW0OcPB42GVyLqjCD7QFWF8ytUQ/23I
cCjfN19KP7Ta4fFSoEePZEDsm1bt8E0jpv/QV6j+s9UQ/8pnOmRMfFtj/7ca
4j67TAeQcD9DjQPIWqX1CD7YX4cyHT5d8k0S+FcNcf9ZqP9+VkPUX890UASF
z1eoex5kQtz3vtqhCGTR80yI/55VO4Tx6W6a+zrT4WrFSzXDa9UQ/3/JdIgD
hfNhqPl3Mx3e1dibxm2qhrjzYqZDFcidfdUQf23LdHAH+ccZKp+b6WAFii9g
+ID9lw2Nz+YqiP3pUPOCqiDx1g3VL1/lMAPkrk1Q9z6uhJj3MNPhMMj/tyoh
8kxZDujpCQCbLRZr
                    "]], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxdU1tIVFEUHZUsQiRL+gi1mYFISosgkwp1pUWY2WsQLNSmsce9Z8LUj2lI
Ec6ZRKOPyZ6GiFSEESIS0YswsWka+ojRJAkTG0z6CLGQXkTQ2e1bQhcOh3Xu
PnuvtfY+Ds+JfUcSbDZbnF7r9YrXK3YqtXf7ewnaYkcNhOx99cZFidq8haM3
Wg20bnFPRXdJFOrN6TJRERz8kpktkX7g8OaJBsG7Q2JForxUNCHg7+9attYp
cX3bvdlf3y28RmK6sSCn6rVA1Dn2o6lQYtPdiK+/Q0BHjfgPSkze7AjZDYHk
7DudM945/Kk7XJLrm8MZzR/3PmiSqHpUnBTvEszvvEQa8Zgv0F6zODDwUGLl
ugU9aT4TO3PP6AiJ25+HSz17TNY3LPFE0xqPmpz3mUQD6V8lQNHRiMRG4ndM
gNLu1ve1G7V5iV7QcdesxJuX31yTZV6cJH1xCvVG23TjFS/rSVCct92LlHKd
aZ4ChY1r/KrUs6g8RbFf1db9dAWSleHwgq71bVCs74KAdrsimK9goy9TsP85
Cs9LtLC3JvuVpfBVhw1eNbEjKX51S7Ziv2vMf/n+4uVUCHOY0rirLRw2uY5f
IUw/UgVmyP+AwhD1Ld/qV1BhSWDgxbX9AvcJdypUEl/t1+Wis8c/3FLsT53A
n/l6rLhOm0Ax8Yso9r9HsD8jlp6IQJaW0z2hcI6Ejwnm+06B2uIctfCU4nl8
as1TSIHsL4iZaFmqK/cqnr/TJvvbrLBV0/o5ZLC+SgtLg3nZrXjD4HlNtvQd
Mthv3e86eg9uA/+/l983MH9T
                    "]], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxdVAtIVEEUtU1MzNI+RNiWupWZGmIQ9mH1mkR+sk0lUFtFrKB9T3eHkhQV
YyZMLULKxCJD+mFa2RZmImYhYRIk9jUVMRURCbO0EoOimXcHH7TweJydmTvn
nHvu889yJB1d6OLisoA/Fv4Y+FMelTnWE8vga1HktozfNugxDcwVxzBwET93
BZpn/rzP53hTmPs9o48Cy1J2NHXx/Y+7TrbXmhQoE+f3M9jNX6ZoBZZseXRt
KoLBsQuTRZGDCgwXrGzcG8ygkL+G41Ss68fgV6C1oqNchWr78tPPVzDw6L1J
zN0qTL9NyPL2ZnBZ/D+iwjsOUzwZVHT8DLTOyvOLGLyMDy+Pcs+G0dtXX/i5
6lg7/5fO4xBOp+4jRf5bVVDacitXd1IQtE1PFND0P6PQ8J0fLFNwfytF/rE6
1vgH6fiu2O+pgJBb10LhuDgwY4NvdZ3x4c061vQ16DivvdYn9BKFjW60KjpZ
AUHfWUqhf65YaWtRkH8hhRNiv68K6UJ4AUV/OP99XFYmx5p/r1VoEn3g+I3o
28VsWJt2ZNcQpZDRGutp8MpBH2so3NjDO2m0o3+NFBaLeq/sqP+BrDch150U
+rpnk0dtDpgSejjWeBkILBWC71D4bDlfbQ8i6EclhQ/5EwFhSQRKV/GTZyjy
sBG4RcwevWUUJkW+cgnm54qO4zwNwaX1OrYJ3zso+nRI1u+mMCTuiyCYx34K
JV8SW9atJ8hrhCLvEAK+YmGMQujgBjeaSrDf4xTzqsj1SQoxIpglst4Piavk
fTw/wULIfVnfwEDIsTwkIGKV6c7Qh3oyn1+tjzUE3yaGflh1rOnbrmMtX14E
rKK/mxkYxQVe0l8zw77sJHjvATkPmdI/KwM/J0+UQ+ohDP3Ik3yYnN9iAmYR
HCbX+X6troNhPuIJ5Auf0+S6v9RnYfjuc+B8WSTfVAdURZ/LHufzruVj0I7+
Jst5vm6XfWeY5085WOcUgwCR9zU5yO8sg4NC6OHsefyUl3HtVOexNl9GFeeJ
8x8Q9ZwK5iJH8kmU35cU+X2alvOVwCBd6Ou1wf/ft3+czzj7
                    "]], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxdlGtIVEEUxzeNCBF7ECJlZhEhLCFCtqxWeyJKzEp6ED1URHusljZ7R0vF
ghkrDSvZRA2k1B6KH4oILbGyJyWLREoPREIjRKS0LPpgD2jmnmMDLQzL796Z
8/if/9zFWUe27Q92OBzT1EpWK0itb32bs2Y7JZxZmzn86iSDVYOp5+qiJSzc
sy9x8AaD6/XPom+FSHjyIyataoiBIssbbPgaWx3y7rf4x2HLb1/6MiBgbtmj
QFOd4Svr73z/U2E4xaUyljHYpP/7BQyptPklDL62PE9xvRVwrKthfmwhg4v5
KlKvAGd5eP/LPAb6eEuPgGZdF2Ogsl9lDwU49E9S/FYBH3Xhlxl4/WOlnkYB
vUsGJk/0MUgODXKWK7b7jfHBnF3utu5G2l/ggwr9vFmAbtPf4oO27qNdDfcE
xL5fOkPMsqBO1xMQkNGpIu21MG8P1XvQgkStX4C4ycL43QL1HLOw3y4BeSO/
WiciOdbXJFDnNA7Fo8viZtZO9c/x3Fmqp9JwR9SpT1vPG1bUEeXn8FTPoUag
LtUc0qrUZBoN2/NtN2znf0EsKH8/5dtN7weJUzjqOyzgTZHaCMQjhmvXVR4e
GTVs6/yZ+t/Osf9x4kMcNup5TAiMU89xDj8FVEdM3xn2gINyzesi5bcp/lAy
72ZSqGHbL+HEfsN2vBzD46We+IwEDlG2UBL956L+4iTqmUn6uSX6zuLohw0S
7HtymuOctkjQ5aeqedzV9aVT/hrSg0uI1BuqOO4rkpCgjaT0tX1bTOePc/QP
p3xeDmv0HHIkPt/B0a8eij9pQe79guoIl8Q4FyzsJ1WCW8dfQH7LpvedPjyf
K/H+FPrw/nolpGv/LvKh3gck+ucxw3PplL+W7lOSRJ2KGT73kH7qPtr3YSXl
z6bvR7xh21crDNv1xkpo1/fKYvD/9+cvJcQFmA==
                    "]], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxlVwtwVsUVDtZSxiJoKkgQIUErWmxAGQZFIQdioVZtpqIOtYAMJTMIqOi/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                    "]], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{581.3359999999999, 389.578}, {577.234, 
                    386.332}, {573.5509999999999, 389.105}, {
                    573.5509999999999, 366.90999999999997`}, {
                    581.3359999999999, 366.812}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJxIGYC4gtKt3/WvWl0KN83X0pfvsqhXezmue/nGx2u
VrxUM5SrclhSYMt1fWOjg7d5p2OCbJVDh2PC0wvTGh1m5Ak1HxCqcqgEKuNo
gcpzVzkwgEBxo0NUivV9//+VDoIRlltOpEDNf13p8Hjp7CMK6Y0QdXWVEPHs
Jof7/r3T8wIqIeIbmxwmS7CE8b2sdHhUJbLOfVGTA9id/yodjihsKMqY0OTQ
+jpwhxzQvmVA4zbUNMHdo7Np7vvlSU0O1UBtD2Wg7ndtgpgL9M+2z3+vVGg1
OYCMfQjke/IwabdrQdUzVDlsOVG2bz6Q3wny56NKVP6RSgdYeIHtP4rga4EC
7jGCD6ZZqhzQwxcAkzSlgA==
                    "]], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{579.914, 451.809}, {577.98, 
                    432.89799999999997`}, {597.4409999999999, 423.395}, {
                    587.59, 436.562}, {601.043, 440.91799999999995`}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{577.746, 456.734}, {574.7890000000001, 
                    456.734}, {572.605, 455.633}, {572.605, 454.32}, {572.605,
                     453.012}, {574.7890000000001, 451.89799999999997`}, {
                    577.746, 451.89799999999997`}, {580.6990000000001, 
                    451.89799999999997`}, {582.8669999999998, 453.012}, {
                    582.8669999999998, 454.32}, {582.8669999999998, 
                    455.633}, {580.6990000000001, 456.734}, {577.746, 
                    456.734}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    579.9219999999999, 452.824}, {574.871, 
                    452.78499999999997`}, {574.871, 413.277}, {580.02, 
                    413.258}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}}}, {{{555.91, 
                    412.60200000000003`}, {555.094, 402.10900000000004`}, {
                    552.434, 394.789}, {548.73, 386.715}, {557.605, 
                    394.949}, {563.7810000000001, 387.617}, {
                    570.4730000000001, 395.078}, {577.2930000000001, 
                    388.77299999999997`}, {583.8549999999999, 
                    395.33599999999996`}, {590.672, 387.35900000000004`}, {
                    596.59, 393.92199999999997`}, {606.629, 386.715}, {
                    602.984, 394.79299999999995`}, {598.055, 401.637}, {
                    598.676, 412.98799999999994`}, {588.953, 405.77}, {
                    565.8519999999999, 404.469}, {555.91, 
                    412.60200000000003`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 0.8, 0.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{621.996, 130.48800000000003`}, {622., 
                    129.80100000000002`}, {621.3199999999999, 129.176}, {
                    620.5740000000001, 129.176}, {619.824, 129.176}, {619.145,
                     129.80100000000002`}, {619.148, 130.48800000000003`}, {
                    619.145, 131.172}, {619.824, 131.797}, {620.5740000000001,
                     131.797}, {621.3199999999999, 131.797}, {622., 
                    131.172}, {621.996, 130.48800000000003`}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{627.031, 132.164}, {627.035, 
                    131.48000000000002`}, {626.3549999999999, 
                    130.85500000000002`}, {625.609, 130.85500000000002`}, {
                    624.8589999999999, 130.85500000000002`}, {
                    624.1800000000001, 131.48000000000002`}, {
                    624.1840000000001, 132.164}, {624.1800000000001, 
                    132.85200000000003`}, {624.8589999999999, 133.477}, {
                    625.609, 133.477}, {626.3549999999999, 133.477}, {627.035,
                     132.85200000000003`}, {627.031, 132.164}}}]}}}}}}}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 1152.}, {0., 576.}}], ",", 
           GraphicsBox[{{{
               {Thickness[0.001388888888888889], {{{
                   {FaceForm[{RGBColor[
                    0.8627450000000002, 0.141176, 0.12156900000000001`], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 360.}, {720., 360.}, {720., 0.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 0.7803919999999999, 0.14902], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{0., 360.}, {
                    0., 0.}, {360., 180.}}}]}}}}, {{{
                   {Thickness[0.001388888888888889], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{0., 360.}, {
                    0., 0.}, {240., 180.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{61.824, 
                    236.348}, {71.20700000000001, 174.05100000000002`}, {
                    100.87499999999999`, 178.52}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{61.824, 
                    236.348}, {106.035, 191.465}, {84.66, 170.414}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{134.883, 
                    224.207}, {78.535, 196.035}, {91.953, 
                    169.19899999999998`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{134.883, 
                    224.207}, {105.859, 168.29299999999998`}, {79.23, 
                    182.117}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{27.703, 
                    170.617}, {89.85199999999999, 160.289}, {94.77, 
                    189.883}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{27.703, 
                    170.617}, {84.051, 198.79299999999998`}, {
                    97.46900000000001, 171.95700000000002`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{145.914, 
                    150.97299999999998`}, {101.70700000000001`, 195.859}, {
                    80.332, 174.805}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{145.914, 
                    150.97299999999998`}, {83.766, 161.30100000000002`}, {
                    88.684, 190.895}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    79.67199999999998, 117.85199999999999`}, {108.699, 
                    173.766}, {82.074, 187.59}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    79.67199999999998, 117.85199999999999`}, {70.289, 
                    180.148}, {99.95700000000001, 184.617}}}]}}}}}}}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 720.}, {0., 360.}}], ",", 
           GraphicsBox[{{{
               {Thickness[0.00125], {{{
                   {FaceForm[{RGBColor[
                    0.9098040000000001, 0.06666670000000002, 
                    0.17647100000000002`], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 480.}, {800., 480.}, {800., 0.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 0.9372550000000001, 0.], Opacity[
                    1.]}], FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{407.26599999999996`, 325.914}, {400.543, 
                    343.51599999999996`}, {414.945, 370.715}, {400.543, 
                    383.51599999999996`}, {405.34400000000005`, 364.316}, {
                    389.34400000000005`, 343.51599999999996`}, {393.824, 
                    325.914}, {398.305, 308.316}, {413.984, 308.316}, {
                    407.26599999999996`, 325.914}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    420.695, 323.801}, {416.812, 342.234}, {435.289, 
                    366.848}, {423.07, 381.742}, {424.809, 362.027}, {405.75, 
                    343.98799999999994`}, {407.42199999999997`, 325.902}, {
                    409.094, 307.82}, {424.582, 305.367}, {420.695, 
                    323.801}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    433.633, 319.60900000000004`}, {432.684, 
                    338.42599999999993`}, {454.78099999999995`, 
                    359.84400000000005`}, {445.043, 376.469}, {443.676, 
                    356.72299999999996`}, {422.03099999999995`, 341.887}, {
                    420.85200000000003`, 323.76599999999996`}, {419.676, 
                    305.641}, {434.58599999999996`, 300.79699999999997`}, {
                    433.633, 319.60900000000004`}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    445.758, 313.449}, {447.758, 332.18}, {
                    472.93799999999993`, 349.879}, {465.91799999999995`, 
                    367.82}, {461.47999999999996`, 348.53499999999997`}, {
                    437.78099999999995`, 337.26599999999996`}, {
                    433.78099999999995`, 319.551}, {429.78099999999995`, 
                    301.83599999999996`}, {443.754, 294.715}, {445.758, 
                    313.449}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    456.76599999999996`, 305.465}, {461.672, 
                    323.65200000000004`}, {489.312, 337.195}, {485.184, 
                    356.01599999999996`}, {477.78099999999995`, 337.66}, {
                    452.613, 330.23799999999994`}, {445.89099999999996`, 
                    313.363}, {439.172, 296.49199999999996`}, {451.855, 
                    287.277}, {456.76599999999996`, 305.465}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    466.39099999999996`, 295.85900000000004`}, {474.082, 
                    313.055}, {503.5, 322.105}, {502.367, 
                    341.34000000000003`}, {492.184, 324.367}, {
                    466.16400000000004`, 320.97299999999996`}, {456.887, 
                    305.363}, {447.60900000000004`, 289.75}, {458.695, 
                    278.66}, {466.39099999999996`, 295.85900000000004`}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    474.395, 284.863}, {484.684, 300.64500000000004`}, {
                    515.1519999999999, 304.984}, {517.043, 324.156}, {504.332,
                     308.98799999999994`}, {478.09799999999996`, 309.707}, {
                    466.49199999999996`, 295.73799999999994`}, {454.887, 
                    281.77}, {464.105, 269.082}, {474.395, 284.863}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    480.578, 272.754}, {493.207, 286.72999999999996`}, {
                    523.98, 286.25}, {528.848, 304.89099999999996`}, {
                    513.9219999999999, 291.89799999999997`}, {488.125, 
                    296.71099999999996`}, {474.477, 284.727}, {460.828, 
                    272.746}, {467.945, 258.77299999999997`}, {480.578, 
                    272.754}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    484.79299999999995`, 259.824}, {499.453, 
                    271.65200000000004`}, {529.7730000000001, 266.363}, {
                    537.496, 284.01599999999996`}, {520.719, 
                    273.51599999999996`}, {495.99199999999996`, 282.305}, {
                    480.637, 272.605}, {465.28499999999997`, 
                    262.90599999999995`}, {470.129, 247.99200000000002`}, {
                    484.79299999999995`, 259.824}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    486.92999999999995`, 246.395}, {503.262, 255.785}, {
                    532.383, 245.816}, {542.7700000000001, 262.043}, {524.559,
                     254.297}, {501.512, 266.848}, {484.828, 259.668}, {
                    468.14500000000004`, 252.49200000000002`}, {
                    470.59799999999996`, 237.004}, {486.92999999999995`, 
                    246.395}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    486.945, 232.797}, {504.543, 239.516}, {531.742, 
                    225.117}, {544.543, 239.516}, {525.3439999999999, 
                    234.71499999999997`}, {504.543, 250.71499999999997`}, {
                    486.945, 246.23399999999998`}, {469.34400000000005`, 
                    241.754}, {469.34400000000005`, 226.07399999999998`}, {
                    486.945, 232.797}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    484.828, 219.363}, {503.262, 223.24599999999998`}, {
                    527.875, 204.76999999999998`}, {542.7700000000001, 
                    216.98800000000003`}, {523.055, 215.25}, {
                    505.01599999999996`, 234.309}, {486.92999999999995`, 
                    232.637}, {468.848, 230.965}, {466.395, 
                    215.48000000000002`}, {484.828, 219.363}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    480.637, 206.42600000000002`}, {499.453, 207.379}, {
                    520.871, 185.277}, {537.496, 195.016}, {517.754, 
                    196.38700000000003`}, {502.914, 218.031}, {
                    484.79299999999995`, 219.207}, {466.668, 
                    220.38700000000003`}, {461.824, 205.47299999999998`}, {
                    480.637, 206.42600000000002`}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    474.477, 194.305}, {493.207, 192.30100000000002`}, {
                    510.90599999999995`, 167.121}, {528.848, 174.141}, {
                    509.562, 178.58200000000002`}, {498.29299999999995`, 
                    202.281}, {480.578, 206.277}, {462.863, 210.277}, {
                    455.742, 196.305}, {474.477, 194.305}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    466.49199999999996`, 183.29299999999998`}, {484.684, 
                    178.38700000000003`}, {498.22299999999996`, 150.75}, {
                    517.043, 154.875}, {498.688, 162.277}, {
                    491.26599999999996`, 187.445}, {474.395, 194.168}, {
                    457.52, 200.88700000000003`}, {448.305, 
                    188.20299999999997`}, {466.49199999999996`, 
                    183.29299999999998`}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    456.887, 173.672}, {474.082, 165.977}, {483.133, 
                    136.562}, {502.367, 137.691}, {485.39799999999997`, 
                    147.875}, {482.004, 173.895}, {466.39099999999996`, 
                    183.172}, {450.777, 192.44899999999998`}, {439.688, 
                    181.363}, {456.887, 173.672}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    445.89099999999996`, 165.668}, {461.672, 155.379}, {
                    466.012, 124.91000000000001`}, {485.184, 123.016}, {
                    470.01599999999996`, 135.73}, {470.734, 161.961}, {
                    456.76599999999996`, 173.566}, {442.79699999999997`, 
                    185.172}, {430.10900000000004`, 175.95700000000002`}, {
                    445.89099999999996`, 165.668}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    433.78099999999995`, 159.48000000000002`}, {447.758, 
                    146.85200000000003`}, {447.277, 116.07799999999999`}, {
                    465.91799999999995`, 111.21100000000001`}, {
                    452.92599999999993`, 126.141}, {457.73799999999994`, 
                    151.93800000000002`}, {445.758, 165.58200000000002`}, {
                    433.77299999999997`, 179.23}, {419.805, 
                    172.11299999999997`}, {433.78099999999995`, 
                    159.48000000000002`}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    420.85200000000003`, 155.26999999999998`}, {432.684, 
                    140.605}, {427.39099999999996`, 110.289}, {445.043, 
                    102.562}, {434.543, 119.34}, {443.332, 144.066}, {433.633,
                     159.42200000000003`}, {423.93399999999997`, 
                    174.77299999999997`}, {409.02299999999997`, 169.93}, {
                    420.85200000000003`, 155.26999999999998`}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    407.42199999999997`, 153.129}, {416.812, 136.797}, {
                    406.84400000000005`, 107.67999999999999`}, {423.07, 
                    97.289}, {415.324, 115.5}, {427.875, 138.547}, {420.695, 
                    155.23}, {413.52, 171.914}, {398.03099999999995`, 
                    169.461}, {407.42199999999997`, 153.129}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    393.824, 153.117}, {400.543, 135.516}, {
                    386.14500000000004`, 108.316}, {400.543, 95.516}, {
                    395.742, 114.715}, {411.742, 135.516}, {
                    407.26599999999996`, 153.117}, {402.78499999999997`, 
                    170.71499999999997`}, {387.105, 170.71499999999997`}, {
                    393.824, 153.117}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    380.39099999999996`, 155.23}, {384.27299999999997`, 
                    136.797}, {365.79699999999997`, 112.184}, {
                    378.01599999999996`, 97.289}, {376.28099999999995`, 
                    117.004}, {395.33599999999996`, 135.04299999999998`}, {
                    393.66400000000004`, 153.129}, {391.99199999999996`, 
                    171.21099999999998`}, {376.508, 173.664}, {
                    380.39099999999996`, 155.23}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    367.453, 159.42200000000003`}, {368.40599999999995`, 
                    140.605}, {346.305, 119.18799999999999`}, {356.047, 
                    102.562}, {357.414, 122.309}, {379.059, 
                    137.14499999999998`}, {380.234, 155.26999999999998`}, {
                    381.414, 173.39100000000002`}, {366.5, 
                    178.23399999999998`}, {367.453, 159.42200000000003`}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    355.332, 165.58200000000002`}, {353.328, 
                    146.85200000000003`}, {328.148, 129.15200000000002`}, {
                    335.168, 111.21100000000001`}, {339.60900000000004`, 
                    130.496}, {363.309, 141.766}, {367.309, 
                    159.48000000000002`}, {371.305, 177.19899999999998`}, {
                    357.33599999999996`, 184.316}, {355.332, 
                    165.58200000000002`}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    344.324, 173.566}, {339.414, 155.379}, {311.777, 
                    141.836}, {315.902, 123.016}, {323.305, 141.371}, {
                    348.477, 148.79299999999998`}, {355.195, 165.668}, {
                    361.91799999999995`, 182.539}, {349.22999999999996`, 
                    191.754}, {344.324, 173.566}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    334.699, 183.172}, {327.004, 165.977}, {297.59, 
                    156.92600000000002`}, {298.719, 137.691}, {308.902, 
                    154.664}, {334.92599999999993`, 158.059}, {344.203, 
                    173.672}, {353.47999999999996`, 189.281}, {
                    342.39099999999996`, 200.371}, {334.699, 183.172}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    326.695, 194.168}, {316.40599999999995`, 
                    178.38700000000003`}, {285.93799999999993`, 174.047}, {
                    284.047, 154.875}, {296.758, 170.04299999999998`}, {
                    322.98799999999994`, 169.324}, {334.594, 
                    183.29299999999998`}, {346.199, 197.266}, {336.984, 
                    209.94899999999998`}, {326.695, 194.168}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    320.512, 206.277}, {307.879, 192.30100000000002`}, {
                    277.105, 192.781}, {272.23799999999994`, 174.141}, {
                    287.168, 187.13299999999998`}, {312.965, 
                    182.32000000000002`}, {326.613, 194.305}, {340.258, 
                    206.285}, {333.141, 220.258}, {320.512, 206.277}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    316.29699999999997`, 219.207}, {301.633, 207.379}, {
                    271.316, 212.668}, {263.594, 195.016}, {280.367, 
                    205.516}, {305.094, 196.727}, {320.449, 
                    206.42600000000002`}, {335.805, 216.125}, {330.957, 
                    231.039}, {316.29699999999997`, 219.207}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    314.156, 232.637}, {297.824, 223.24599999999998`}, {
                    268.707, 233.21499999999997`}, {258.316, 
                    216.98800000000003`}, {276.53099999999995`, 
                    224.73399999999998`}, {299.578, 212.184}, {316.258, 
                    219.363}, {332.941, 226.539}, {330.48799999999994`, 
                    242.02700000000002`}, {314.156, 232.637}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    314.14500000000004`, 246.23399999999998`}, {296.543, 
                    239.516}, {269.34400000000005`, 253.914}, {256.543, 
                    239.516}, {275.742, 244.316}, {296.543, 228.316}, {
                    314.14500000000004`, 232.797}, {331.742, 237.277}, {
                    331.742, 252.95700000000002`}, {314.14500000000004`, 
                    246.23399999999998`}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    316.258, 259.668}, {297.824, 255.785}, {
                    273.21099999999996`, 274.262}, {258.316, 262.043}, {
                    278.03099999999995`, 263.78099999999995`}, {296.074, 
                    244.72299999999998`}, {314.156, 246.395}, {332.242, 
                    248.066}, {334.695, 263.555}, {316.258, 259.668}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    320.449, 272.605}, {301.633, 271.65200000000004`}, {
                    280.215, 293.754}, {263.594, 284.01599999999996`}, {
                    283.33599999999996`, 282.64500000000004`}, {298.172, 
                    261.}, {316.29699999999997`, 259.824}, {
                    334.41799999999995`, 258.64500000000004`}, {
                    339.26599999999996`, 273.559}, {320.449, 272.605}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    326.613, 284.727}, {307.879, 286.72999999999996`}, {
                    290.18, 311.90999999999997`}, {272.23799999999994`, 
                    304.89099999999996`}, {291.527, 300.449}, {
                    302.79299999999995`, 276.75}, {320.512, 272.754}, {
                    338.227, 268.754}, {345.34400000000005`, 282.727}, {
                    326.613, 284.727}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    334.594, 295.73799999999994`}, {316.40599999999995`, 
                    300.64500000000004`}, {302.863, 328.28099999999995`}, {
                    284.047, 324.156}, {302.39799999999997`, 316.754}, {
                    309.824, 291.58599999999996`}, {326.695, 284.863}, {
                    343.566, 278.14500000000004`}, {352.78499999999997`, 
                    290.828}, {334.594, 295.73799999999994`}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    344.203, 305.363}, {327.004, 313.055}, {317.953, 
                    342.469}, {298.719, 341.34000000000003`}, {315.691, 
                    331.156}, {319.08599999999996`, 305.137}, {334.699, 
                    295.85900000000004`}, {350.312, 286.582}, {
                    361.39799999999997`, 297.668}, {344.203, 305.363}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    355.195, 313.363}, {339.414, 323.65200000000004`}, {
                    335.078, 354.121}, {315.902, 356.01599999999996`}, {
                    331.07, 343.301}, {330.35200000000003`, 317.07}, {344.324,
                     305.465}, {358.29299999999995`, 293.85900000000004`}, {
                    370.977, 303.074}, {355.195, 313.363}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    367.309, 319.551}, {353.328, 332.18}, {353.812, 
                    362.953}, {335.168, 367.82}, {348.16400000000004`, 
                    352.895}, {343.35200000000003`, 327.09799999999996`}, {
                    355.332, 313.449}, {367.312, 299.801}, {
                    381.28499999999997`, 306.91799999999995`}, {367.309, 
                    319.551}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    380.234, 323.76599999999996`}, {368.40599999999995`, 
                    338.42599999999993`}, {373.695, 368.746}, {356.047, 
                    376.469}, {366.543, 359.691}, {357.754, 334.965}, {
                    367.453, 319.60900000000004`}, {377.15200000000004`, 
                    304.258}, {392.066, 309.10200000000003`}, {380.234, 
                    323.76599999999996`}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    393.66400000000004`, 325.902}, {384.27299999999997`, 
                    342.234}, {394.242, 371.35200000000003`}, {
                    378.01599999999996`, 381.742}, {385.762, 
                    363.53099999999995`}, {373.21099999999996`, 340.484}, {
                    380.39099999999996`, 323.801}, {387.57, 307.117}, {
                    403.055, 309.57}, {393.66400000000004`, 
                    325.902}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.9098040000000001, 0.06666670000000002, 
                    0.17647100000000002`], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{486.945, 239.516}, {486.945, 191.797}, {448.262, 
                    153.117}, {400.543, 153.117}, {352.828, 153.117}, {
                    314.14500000000004`, 191.797}, {314.14500000000004`, 
                    239.516}, {314.14500000000004`, 287.234}, {352.828, 
                    325.914}, {400.543, 325.914}, {448.262, 325.914}, {
                    486.945, 287.234}, {486.945, 239.516}}}]}}}}, {{{
                   {RGBColor[1., 0.9372550000000001, 0.], Thickness[
                    0.021882977499999998`], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{485.59799999999996`, 240.81199999999998`}, {
                    485.59799999999996`, 193.89099999999996`}, {447.559, 
                    155.85199999999998`}, {400.637, 155.85199999999998`}, {
                    353.715, 155.85199999999998`}, {315.676, 
                    193.89099999999996`}, {315.676, 240.81199999999998`}, {
                    315.676, 287.73400000000004`}, {353.715, 325.773}, {
                    400.637, 325.773}, {447.559, 325.773}, {
                    485.59799999999996`, 287.73400000000004`}, {
                    485.59799999999996`, 240.81199999999998`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 0.9372550000000001, 0.], Opacity[
                    1.]}], FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {
                    1, 3, 3}}}, {{{464.621, 244.23399999999998`}, {464.621, 
                    208.45700000000002`}, {435.93399999999997`, 179.453}, {
                    400.543, 179.453}, {365.156, 179.453}, {336.469, 
                    208.45700000000002`}, {336.469, 244.23399999999998`}, {
                    336.469, 280.012}, {365.156, 309.01599999999996`}, {
                    400.543, 309.01599999999996`}, {435.93399999999997`, 
                    309.01599999999996`}, {464.621, 280.012}, {464.621, 
                    244.23399999999998`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.9098040000000001, 0.06666670000000002, 
                    0.17647100000000002`], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{464.621, 279.707}, {414.574, 
                    279.707}, {374.004, 238.68800000000002`}, {374.004, 
                    188.094}, {374.004, 137.496}, {414.574, 96.477}, {464.621,
                     96.477}, {459.4959999999999, 92.93}, {407.508, 92.93}, {
                    365.367, 135.535}, {365.367, 188.094}, {365.367, 
                    240.648}, {407.508, 283.254}, {459.4959999999999, 
                    283.254}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{456.078, 285.76599999999996`}, {
                    402.719, 285.76599999999996`}, {359.465, 242.035}, {
                    359.465, 188.094}, {359.465, 134.148}, {402.719, 
                    90.418}, {456.078, 90.418}, {450.949, 86.453}, {
                    395.42999999999995`, 86.453}, {350.41799999999995`, 
                    131.961}, {350.41799999999995`, 188.094}, {
                    350.41799999999995`, 244.227}, {395.42999999999995`, 
                    289.72999999999996`}, {450.949, 289.72999999999996`}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{447.53499999999997`, 
                    292.49199999999996`}, {390.504, 292.49199999999996`}, {
                    344.27, 245.75}, {344.27, 188.094}, {344.27, 130.434}, {
                    390.504, 83.691}, {447.53499999999997`, 83.691}, {
                    442.40599999999995`, 79.391}, {383.02299999999997`, 
                    79.391}, {334.887, 128.059}, {334.887, 188.094}, {334.887,
                     248.129}, {383.02299999999997`, 296.79699999999997`}, {
                    442.40599999999995`, 296.79699999999997`}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{336.469, 279.707}, {
                    386.51599999999996`, 279.707}, {427.08599999999996`, 
                    238.68800000000002`}, {427.08599999999996`, 188.094}, {
                    427.08599999999996`, 137.496}, {386.51599999999996`, 
                    96.477}, {336.469, 96.477}, {341.594, 92.93}, {393.578, 
                    92.93}, {435.72299999999996`, 135.535}, {
                    435.72299999999996`, 188.094}, {435.72299999999996`, 
                    240.648}, {393.578, 283.254}, {341.594, 283.254}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{345.012, 285.76599999999996`}, {
                    398.367, 285.76599999999996`}, {441.621, 242.035}, {
                    441.621, 188.094}, {441.621, 134.148}, {398.367, 
                    90.418}, {345.012, 90.418}, {350.137, 86.453}, {405.66, 
                    86.453}, {450.668, 131.961}, {450.668, 188.094}, {450.668,
                     244.227}, {405.66, 289.72999999999996`}, {350.137, 
                    289.72999999999996`}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{353.555, 292.49199999999996`}, {
                    410.58599999999996`, 292.49199999999996`}, {456.82, 
                    245.75}, {456.82, 188.094}, {456.82, 130.434}, {
                    410.58599999999996`, 83.691}, {353.555, 83.691}, {358.68, 
                    79.391}, {418.062, 79.391}, {466.203, 128.059}, {466.203, 
                    188.094}, {466.203, 248.129}, {418.062, 
                    296.79699999999997`}, {358.68, 
                    296.79699999999997`}}}]}}}}}}}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 800.}, {0., 480.}}], ",", 
           GraphicsBox[{{{
               {Thickness[0.0020833333333333333`], {{{
                   {FaceForm[{RGBColor[
                    0.8078430000000001, 0.06666670000000002, 0.14902], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 320.}, {480., 320.}, {480., 0.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[0., 0.15686300000000003`, 0.407843], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     240.}, {480., 240.}, {480., 80.}, {0., 80.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{304., 160.}, {304., 124.65199999999999`}, {
                    275.348, 96.}, {240., 96.}, {204.65200000000002`, 96.}, {
                    176., 124.65199999999999`}, {176., 160.}, {176., 
                    195.348}, {204.65200000000002`, 224.}, {240., 224.}, {
                    275.348, 224.}, {304., 195.348}, {304., 160.}}}]}}}}}}}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 480.}, {0., 320.}}], ",", 
           GraphicsBox[{{{
               {Thickness[0.0004464285714285714], {{{
                   {FaceForm[{RGBColor[0.8, 0., 0.003921569999999999], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 1120.}, {2240., 1120.}, {2240., 
                    0.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     80.}, {2240., 80.}, {2240., 0.}, {0., 0.}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     240.}, {2240., 240.}, {2240., 160.}, {0., 160.}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     400.}, {2240., 400.}, {2240., 320.}, {0., 320.}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     560.}, {2240., 560.}, {2240., 480.}, {0., 480.}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     720.}, {2240., 720.}, {2240., 640.}, {0., 640.}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     880.}, {2240., 880.}, {2240., 800.}, {0., 800.}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     1040.}, {2240., 1040.}, {2240., 960.}, {0., 
                    960.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[0.003921569999999999, 0., 0.4], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     1120.}, {1120., 1120.}, {1120., 480.}, {0., 
                    480.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 0.8, 0.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4k7HhKcXztQ4MICAwwSHx0tnH1GoK4HzwXRD
tgNYnXIvnA+mGTrh/PJ986X077Sg6m9odEAxH8hvfR24Q+5sPZx/Qen2zzqf
RocjChuKMj40QvRXNkH0bWxy+HTJN0ngVKPDUZB8aZNDBcgevkaHy0DhiJAm
B+v7/r3TvRrgfFuu64sLzCvh/Nznv1d+tCmGmOPfCud3gMz/1QHng81Z1gPX
/7BKZJ37wn64+TB+u9jNc9+lGuH8Q181YvofNULMr+l3yJj4tsZ+dpPDNOfu
nOfm/Q6CEZZbTqQ3OoC41cwTHHbKAUPgVT08fNHDHwDvCqa9
                    "]], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4k+XfJMEHnY5XFC6/bNOotVh64myffO3tjvI
RqVY39/f5uDFw6TdvrTDwce80zEhttlBIMJyy4m2NoeKffOl9I3aHLZ//nul
4m6rAwMIHGhy4NXdNPe9WauDXOvrwB1A+WnO3TnPRZsdPEHmxDc7HP6qEdPP
0eLwsEpknfvBNgdBkHm3GxwuA50RIdPqcAgkb97ssGz2EYUNB9sh5jrUQ+yf
1w5R97bJ4fFSoALGTofj3kAJp3oHW67riwvSuhxs7vv3TrdodgAJJzh0Qdxz
r8FB/64KW+PzHog5XC0Q/Q7dDttA7pdqdtgC8veiPof3y495m1u2OgBVPb1w
thvi7kdQ/zn0O4DDq7MN4n6gfNaekskSqzog5izog7hjezvE/3bdEPOedDno
AJ2x/HEPRL6jwyEaGLz+dl0QcxV6IOGeCFV3qcNBBhT+/6C0XA8k3Ga2OwBD
pSijvQPi3v3tDgDqbsmS
                    "]]}}}}}}}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 2240.}, {0., 1120.}}], ",", 
           GraphicsBox[{{{
               {Thickness[0.001736111111111111], {{{
                   {FaceForm[{RGBColor[
                    0.8235290000000001, 0.06274510000000001, 
                    0.20392200000000002`], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 384.}, {576., 384.}, {576., 0.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[0., 0.494118, 0.22745100000000001`], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    96., 288.}, {480., 288.}, {480., 96.}, {96., 
                    96.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{376., 192.}, {376., 156.65200000000002`}, {
                    347.348, 128.}, {312., 128.}, {276.65200000000004`, 
                    128.}, {248., 156.65200000000002`}, {248., 192.}, {248., 
                    227.348}, {276.65200000000004`, 256.}, {312., 256.}, {
                    347.348, 256.}, {376., 227.348}, {376., 192.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[0., 0.494118, 0.22745100000000001`], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{400., 192.}, {400., 156.65200000000002`}, {
                    371.348, 128.}, {336., 128.}, {300.65200000000004`, 
                    128.}, {272., 156.65200000000002`}, {272., 192.}, {272., 
                    227.348}, {300.65200000000004`, 256.}, {336., 256.}, {
                    371.348, 256.}, {400., 227.348}, {400., 192.}}}]}}}}}}}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 576.}, {0., 384.}}], ",", 
           GraphicsBox[{{{
               {Thickness[0.00026041666666666666`], {{{
                   {FaceForm[{RGBColor[
                    0.7686270000000001, 0.15294100000000005`, 0.184314], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 1920.}, {3840., 1920.}, {3840., 
                    0.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.003921569999999999, 0.31764699999999996`, 
                    0.5921569999999999], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    1280., 1920.}, {2560., 1920.}, {2560., 0.}, {1280., 
                    0.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.976471, 0.8117650000000001, 0.007843139999999998], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{816., 1264.}, {816., 1166.797}, {
                    737.2030000000001, 1088.}, {640., 1088.}, {542.797, 
                    1088.}, {464., 1166.797}, {464., 1264.}, {464., 
                    1361.203}, {542.797, 1440.}, {640., 1440.}, {
                    737.2030000000001, 1440.}, {816., 1361.203}, {816., 
                    1264.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.7686270000000001, 0.15294100000000005`, 0.184314], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{832., 1344.}, {832., 1237.961}, {746.039, 
                    1152.}, {640., 1152.}, {533.9609999999999, 1152.}, {448., 
                    1237.961}, {448., 1344.}, {448., 1450.039}, {
                    533.9609999999999, 1536.}, {640., 1536.}, {746.039, 
                    1536.}, {832., 1450.039}, {832., 1344.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.976471, 0.8117650000000001, 0.007843139999999998], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{768., 1312.}, {768., 1241.309}, {710.691, 
                    1184.}, {640., 1184.}, {569.309, 1184.}, {512., 
                    1241.309}, {512., 1312.}, {512., 1382.6909999999998`}, {
                    569.309, 1440.}, {640., 1440.}, {710.691, 1440.}, {768., 
                    1382.6909999999998`}, {768., 1312.}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGZigIKGRgcw7TDDAcaXb30daPFmukO72M1z3480
QugZ0x1sua4vLrBuAsvviJ3uwKe7ae77jU0Ozt05z6uVoPIRzRBzGKZD6RY4
/9BXjZj+5Qj+p0u+SQJ+rXD9h0HyR1rh5le+VDPksG6D2w9xXxvcfTA+qvuh
/ANQ/oNWCH0Bjc8wE5VvAOU7QPUXQPkNUPkDaOph8g5QfgIaXwCND3NPAw5+
wwwHAN8kadg=
                    "]], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    288., 1056.}, {448., 1056.}, {448., 288.}, {288., 
                    288.}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    832., 1056.}, {992., 1056.}, {992., 288.}, {832., 
                    288.}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    480., 928.}, {800., 928.}, {800., 864.}, {480., 864.}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    480., 480.}, {800., 480.}, {800., 416.}, {480., 416.}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1,
                     0}}}, {{{480., 1056.}, {800., 1056.}, {640., 960.}}, {{
                    480., 384.}, {800., 384.}, {640., 288.}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{809.602, 672.}, {809.602, 578.3319999999999}, {
                    733.668, 502.39799999999997`}, {640., 
                    502.39799999999997`}, {546.3319999999999, 
                    502.39799999999997`}, {470.39799999999997`, 
                    578.3319999999999}, {470.39799999999997`, 672.}, {
                    470.39799999999997`, 765.668}, {546.3319999999999, 
                    841.602}, {640., 841.602}, {733.668, 841.602}, {809.602, 
                    765.668}, {809.602, 672.}}}]}}}}, {{{
                   {RGBColor[
                    0.7686270000000001, 0.15294100000000005`, 0.184314], 
                    Thickness[0.005], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{809.602, 672.}, {809.602, 578.3320000000001}, {
                    733.668, 502.39800000000014`}, {640., 
                    502.39800000000014`}, {546.3319999999999, 
                    502.39800000000014`}, {470.39799999999997`, 
                    578.3320000000001}, {470.39799999999997`, 672.}, {
                    470.39799999999997`, 765.6680000000001}, {
                    546.3319999999999, 841.6020000000001}, {640., 
                    841.6020000000001}, {733.668, 841.6020000000001}, {
                    809.602, 765.6680000000001}, {809.602, 672.}}},
                    CurveClosed->{1}]}}}}, {{{
                   {RGBColor[
                    0.7686270000000001, 0.15294100000000005`, 0.184314], 
                    Thickness[0.005], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGZigIEWhy7HhKcXfLocbO77907fiOA/Xjr7iEJS
q8MyILWBucsBxN1wv9Uha0/JZIm2ToeHVSLr3GPbHLx4mLTbOTodgLJFGcva
HMDGRnTA+cfAdDucLxBhueXElza4/gcg2qUNbv4KEH2sFW7/ExDt2Qp3H8Td
rQ4w98P4YPP9muF82agU6/tzmxzkQPS2FgcQ5a/QBKEtWxzkWl8H7ljUCKF3
N0PMj2x0+LD8mLc5N4IPoZvgfLDxKxrh+rd9/nul4nsD3Pxpzt05zysb4PZv
OVG2b/6Perj7PtTYm8al1cPdD+MDANeSp3k=
                    "],
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.7686270000000001, 0.15294100000000005`, 0.184314], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{672., 756.8009999999999}, {672., 739.125}, {
                    657.672, 724.8009999999999}, {640., 724.8009999999999}, {
                    622.328, 724.8009999999999}, {608., 739.125}, {608., 
                    756.8009999999999}, {608., 774.4730000000001}, {622.328, 
                    788.8009999999999}, {640., 788.8009999999999}, {657.672, 
                    788.8009999999999}, {672., 774.4730000000001}, {672., 
                    756.8009999999999}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{672., 587.1990000000001}, {672., 
                    569.5269999999999}, {657.672, 555.1990000000001}, {640., 
                    555.1990000000001}, {622.328, 555.1990000000001}, {608., 
                    569.5269999999999}, {608., 587.1990000000001}, {608., 
                    604.875}, {622.328, 619.1990000000001}, {640., 
                    619.1990000000001}, {657.672, 619.1990000000001}, {672., 
                    604.875}, {672., 587.1990000000001}}}]}}}}}}}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 3840.}, {0., 1920.}}], ",", 
           GraphicsBox[{{{
               {Thickness[0.0006944444444444445], {{{
                   {FaceForm[{RGBColor[0.996078, 0.796078, 0.], Opacity[1.]}],
                     FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    0., 960.}, {1440., 960.}, {1440., 480.}, {0., 
                    480.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.9176470000000001, 0.15686300000000003`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     480.}, {1440., 480.}, {1440., 0.}, {0., 0.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[0.20392200000000002`, 0.698039, 0.2], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     640.}, {1440., 640.}, {1440., 320.}, {0., 
                    320.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{812.992, 
                    378.68}, {512.0659999999999, 160.04299999999998`}, {
                    627.008, 513.8009999999999}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{684.48, 
                    336.92199999999997`}, {383.555, 555.559}, {755.52, 
                    555.559}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{605.055, 
                    446.23799999999994`}, {720., 800.}, {834.9449999999999, 
                    446.23799999999994`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{684.48, 
                    555.559}, {1056.4450000000002`, 555.559}, {755.52, 
                    336.92199999999997`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{812.992, 
                    513.8009999999999}, {927.934, 160.04299999999998`}, {
                    627.008, 378.68}}}]}}}}}}}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 1440.}, {0., 960.}}], ",", 
           GraphicsBox[{{{
               {Thickness[0.0020833333333333333`], {{{
                   {FaceForm[{RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 240.}, {480., 240.}, {480., 0.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    120., 240.}, {480., 240.}, {480., 160.}, {120., 
                    160.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[0., 0.501961, 0.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    120., 80.}, {480., 80.}, {480., 0.}, {120., 0.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    27.629, 198.945}, {40.523, 198.945}, {41.234, 198.945}, {
                    41.809, 198.406}, {41.809, 197.738}, {41.809, 191.664}, {
                    41.809, 190.996}, {41.234, 190.45700000000002`}, {40.523, 
                    190.45700000000002`}, {27.629, 190.45700000000002`}, {
                    26.914, 190.45700000000002`}, {26.34, 190.996}, {26.34, 
                    191.664}, {26.34, 197.738}, {26.34, 198.406}, {26.914, 
                    198.945}, {27.629, 198.945}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002951354166666667], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    27.629, 198.945}, {40.523, 198.945}, {41.234, 198.945}, {
                    41.809, 198.406}, {41.809, 197.738}, {41.809, 191.664}, {
                    41.809, 190.996}, {41.234, 190.457}, {40.523, 190.457}, {
                    27.629, 190.457}, {26.914, 190.457}, {26.34, 190.996}, {
                    26.34, 191.664}, {26.34, 197.738}, {26.34, 198.406}, {
                    26.914, 198.945}, {27.629, 198.945}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    27.957, 198.594}, {40.191, 198.594}, {40.867, 198.594}, {
                    41.413999999999994`, 198.098}, {41.413999999999994`, 
                    197.48800000000003`}, {41.413999999999994`, 191.918}, {
                    41.413999999999994`, 191.305}, {40.867, 190.812}, {40.191,
                     190.812}, {27.957, 190.812}, {27.281, 190.812}, {26.738, 
                    191.305}, {26.738, 191.918}, {26.738, 
                    197.48800000000003`}, {26.738, 198.098}, {27.281, 
                    198.594}, {27.957, 198.594}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752291666666667], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    27.957, 198.594}, {40.191, 198.594}, {40.867, 198.594}, {
                    41.413999999999994`, 198.098}, {41.413999999999994`, 
                    197.488}, {41.413999999999994`, 191.918}, {
                    41.413999999999994`, 191.305}, {40.867, 190.812}, {40.191,
                     190.812}, {27.957, 190.812}, {27.281, 190.812}, {26.738, 
                    191.305}, {26.738, 191.918}, {26.738, 197.488}, {26.738, 
                    198.098}, {27.281, 198.594}, {27.957, 198.594}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIFIGYCYn7dTXPfH3dwiNvlycPUn+FwfXGBLZe6owMX
iNGXARHXdnQoypj4tqY5w2H2EYUNRRWODsLNB04trMxwWOi67fPfLY4ON899
D37cmuEQYbnlRNk/RwcGEKjJcADKXqnY6egA0m5fmOFwUen2z7pTjg5Anmlc
UoaDtP5dFTZFJwdVtsapzskI/oRDXzVi/DMcKl+qGXLccXQ47m3e6RiAME82
KsX6vjPUvexODt80YvoPmSLM5wZJaGU4uHTnPP/d6egAdNW++WYI/4Ddb5gB
8Ze+o0MxiJbPcICFB9g/slD1ux0g7tPPcBBd5/6wKsXBYdXHS75JFlD/mzhA
3KOd4fAJKCxww95hEVgc6j5xBwenhKcXlIDu/QJ0/stj9g6PlwJD0ifDoV0M
aJMxgg9xnz3EP6kZDqdAFuyFyqdkOBwGBku/EDS+ijMcpkiwhPGttYf4uw5q
nrKDgxXIw93Q8ItxgLinAeGfY6DwbMlwAADQteMG
                    "]]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.00017376208333333334`], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIFIGYCYn7dTXPfH3dwiNvlycPUn+FwfXGBLZe6owMX
iNGXARHXdnQozpj4tqY5w2H2EYUNRRWODkLNB04trMxwWOi67fPfLY4ON899
D37cmuEQYbnlRNk/RwcGEKjJcADKXqnY6egA0m5fmOFwUen2z7pTjg7vauxN
45IyHKT176qwKTo5qLI1TnVORvD7D33ViPHPcKh8qWbIccfR4Zi3eadjAMI8
2agU6/vOUPeyOzl804jpP2SKMB/sfq0MB5funOe/Ox0dgK7aN98M4R+w+w0z
HIpADtOH+k8+wwEWHmD/yELV73aAuE8/w0F0nfvDqhQHh1UfL/kmWUD9b+Lg
IANyj3aGwyegsMANe4dFYHGo+8QdHJwSnl5QArr3C9D5L4/ZOzxeCgxJnwyH
djGgTcYIPsR99hD/pGY4nAJZsNfe4QlIPiXD4TAwWPqFoPFVnOEwRYIljG+t
PcTfdVDzlB0cQNGwrxsafjEOEPc0IPxzHBSeLRkOAMzd4wM=
                    "],
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{34.602000000000004`, 194.79299999999998`}, {
                    34.602000000000004`, 194.406}, {34.234, 194.094}, {
                    33.785000000000004`, 194.094}, {33.336, 194.094}, {32.973,
                     194.406}, {32.973, 194.79299999999998`}, {32.973, 
                    195.176}, {33.336, 195.48800000000003`}, {
                    33.785000000000004`, 195.48800000000003`}, {34.234, 
                    195.48800000000003`}, {34.602000000000004`, 195.176}, {
                    34.602000000000004`, 194.79299999999998`}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.00018712128065294733`], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{34.602000000000004`, 194.79308092799997`}, {
                    34.602000000000004`, 194.40591648}, {34.234, 
                    194.093901888}, {33.785000000000004`, 194.093901888}, {
                    33.336, 194.093901888}, {32.973, 194.40591648}, {32.973, 
                    194.79308092799997`}, {32.973, 195.175489056}, {33.336, 
                    195.488454912}, {33.785000000000004`, 195.488454912}, {
                    34.234, 195.488454912}, {34.602000000000004`, 
                    195.175489056}, {34.602000000000004`, 
                    194.79308092799997`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{28.723, 
                    198.23399999999998`}, {27.531000000000002`, 
                    197.176}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{28.723, 
                    198.23399999999998`}, {27.531000000000002`, 197.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{29.516000000000002`, 
                    198.23399999999998`}, {28.324, 197.176}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{29.516000000000002`, 
                    198.23399999999998`}, {28.324, 197.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{30.309, 
                    198.23399999999998`}, {29.117000000000004`, 
                    197.176}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{30.309, 
                    198.23399999999998`}, {29.117000000000004`, 197.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{31.102, 
                    198.23399999999998`}, {29.91, 197.176}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{31.102, 
                    198.23399999999998`}, {29.91, 197.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{31.895, 
                    198.23399999999998`}, {30.703, 197.176}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{31.895, 
                    198.23399999999998`}, {30.703, 197.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{32.688, 
                    198.23399999999998`}, {31.496, 197.176}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{32.688, 
                    198.23399999999998`}, {31.496, 197.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{33.48, 
                    198.23399999999998`}, {32.289, 197.176}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{33.48, 
                    198.23399999999998`}, {32.289, 197.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{34.273, 
                    198.23399999999998`}, {33.086, 197.176}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{34.273, 
                    198.23399999999998`}, {33.086, 197.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{35.066, 
                    198.23399999999998`}, {33.879, 197.176}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{35.066, 
                    198.23399999999998`}, {33.879, 197.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{35.858999999999995`, 
                    198.23399999999998`}, {34.672000000000004`, 
                    197.176}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{35.858999999999995`, 
                    198.23399999999998`}, {34.672000000000004`, 197.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{36.652, 
                    198.23399999999998`}, {35.465, 197.176}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{36.652, 
                    198.23399999999998`}, {35.465, 197.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{37.445, 
                    198.23399999999998`}, {36.258, 197.176}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{37.445, 
                    198.23399999999998`}, {36.258, 197.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{34.273, 
                    198.23399999999998`}, {33.086, 197.176}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{34.273, 
                    198.23399999999998`}, {33.086, 197.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{38.23800000000001, 
                    198.23399999999998`}, {37.050999999999995`, 
                    197.176}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{38.23800000000001, 
                    198.23399999999998`}, {37.050999999999995`, 197.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{39.031, 
                    198.23399999999998`}, {37.843999999999994`, 
                    197.176}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{39.031, 
                    198.23399999999998`}, {37.843999999999994`, 197.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{39.828, 
                    198.23399999999998`}, {38.637, 197.176}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{39.828, 
                    198.23399999999998`}, {38.637, 197.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{40.621, 
                    198.23399999999998`}, {39.43, 197.176}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{40.621, 
                    198.23399999999998`}, {39.43, 197.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{39.43, 
                    198.23399999999998`}, {40.621, 197.176}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{39.43, 
                    198.23399999999998`}, {40.621, 197.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{38.637, 
                    198.23399999999998`}, {39.828, 197.176}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{38.637, 
                    198.23399999999998`}, {39.828, 197.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{37.843999999999994`, 
                    198.23399999999998`}, {39.031, 197.176}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{37.843999999999994`, 
                    198.23399999999998`}, {39.031, 197.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{37.050999999999995`, 
                    198.23399999999998`}, {38.23800000000001, 
                    197.176}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{37.050999999999995`, 
                    198.23399999999998`}, {38.23800000000001, 197.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{36.258, 
                    198.23399999999998`}, {37.445, 197.176}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{36.258, 
                    198.23399999999998`}, {37.445, 197.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{35.465, 
                    198.23399999999998`}, {36.652, 197.176}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{35.465, 
                    198.23399999999998`}, {36.652, 197.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{34.672000000000004`, 
                    198.23399999999998`}, {35.858999999999995`, 
                    197.176}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{34.672000000000004`, 
                    198.23399999999998`}, {35.858999999999995`, 197.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{33.879, 
                    198.23399999999998`}, {35.066, 197.176}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{33.879, 
                    198.23399999999998`}, {35.066, 197.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{33.086, 
                    198.23399999999998`}, {34.273, 197.176}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{33.086, 
                    198.23399999999998`}, {34.273, 197.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{32.289, 
                    198.23399999999998`}, {33.48, 197.176}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{32.289, 
                    198.23399999999998`}, {33.48, 197.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{31.496, 
                    198.23399999999998`}, {32.688, 197.176}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{31.496, 
                    198.23399999999998`}, {32.688, 197.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{30.703, 
                    198.23399999999998`}, {31.895, 197.176}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{30.703, 
                    198.23399999999998`}, {31.895, 197.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{33.879, 
                    198.23399999999998`}, {35.066, 197.176}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{33.879, 
                    198.23399999999998`}, {35.066, 197.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{29.91, 
                    198.23399999999998`}, {31.102, 197.176}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{29.91, 
                    198.23399999999998`}, {31.102, 197.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{29.117000000000004`, 
                    198.23399999999998`}, {30.309, 197.176}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{29.117000000000004`, 
                    198.23399999999998`}, {30.309, 197.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{28.324, 
                    198.23399999999998`}, {29.516000000000002`, 
                    197.176}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{28.324, 
                    198.23399999999998`}, {29.516000000000002`, 197.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{27.531000000000002`, 
                    198.23399999999998`}, {28.723, 197.176}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{27.531000000000002`, 
                    198.23399999999998`}, {28.723, 197.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{28.723, 192.227}, {
                    27.531000000000002`, 191.164}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{28.723, 192.227}, {
                    27.531000000000002`, 191.164}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{29.516000000000002`, 
                    192.227}, {28.324, 191.164}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{29.516000000000002`, 
                    192.227}, {28.324, 191.164}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{30.309, 192.227}, {
                    29.117000000000004`, 191.164}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{30.309, 192.227}, {
                    29.117000000000004`, 191.164}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{31.102, 192.227}, {29.91,
                     191.164}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{31.102, 192.227}, {29.91,
                     191.164}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{31.895, 192.227}, {
                    30.703, 191.164}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{31.895, 192.227}, {
                    30.703, 191.164}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{32.688, 192.227}, {
                    31.496, 191.164}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{32.688, 192.227}, {
                    31.496, 191.164}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{33.48, 192.227}, {32.289,
                     191.164}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{33.48, 192.227}, {32.289,
                     191.164}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{34.273, 192.227}, {
                    33.086, 191.164}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{34.273, 192.227}, {
                    33.086, 191.164}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{35.066, 192.227}, {
                    33.879, 191.164}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{35.066, 192.227}, {
                    33.879, 191.164}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{35.858999999999995`, 
                    192.227}, {34.672000000000004`, 191.164}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{35.858999999999995`, 
                    192.227}, {34.672000000000004`, 191.164}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{36.652, 192.227}, {
                    35.465, 191.164}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{36.652, 192.227}, {
                    35.465, 191.164}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{37.445, 192.227}, {
                    36.258, 191.164}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{37.445, 192.227}, {
                    36.258, 191.164}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{34.273, 192.227}, {
                    33.086, 191.164}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{34.273, 192.227}, {
                    33.086, 191.164}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{38.23800000000001, 
                    192.227}, {37.050999999999995`, 191.164}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{38.23800000000001, 
                    192.227}, {37.050999999999995`, 191.164}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{39.031, 192.227}, {
                    37.843999999999994`, 191.164}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{39.031, 192.227}, {
                    37.843999999999994`, 191.164}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{39.828, 192.227}, {
                    38.637, 191.164}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{39.828, 192.227}, {
                    38.637, 191.164}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{40.621, 192.227}, {39.43,
                     191.164}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{40.621, 192.227}, {39.43,
                     191.164}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{39.43, 192.227}, {40.621,
                     191.164}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{39.43, 192.227}, {40.621,
                     191.164}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{38.637, 192.227}, {
                    39.828, 191.164}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{38.637, 192.227}, {
                    39.828, 191.164}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{37.843999999999994`, 
                    192.227}, {39.031, 191.164}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{37.843999999999994`, 
                    192.227}, {39.031, 191.164}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{37.050999999999995`, 
                    192.227}, {38.23800000000001, 191.164}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{37.050999999999995`, 
                    192.227}, {38.23800000000001, 191.164}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{36.258, 192.227}, {
                    37.445, 191.164}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{36.258, 192.227}, {
                    37.445, 191.164}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{35.465, 192.227}, {
                    36.652, 191.164}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{35.465, 192.227}, {
                    36.652, 191.164}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{34.672000000000004`, 
                    192.227}, {35.858999999999995`, 191.164}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{34.672000000000004`, 
                    192.227}, {35.858999999999995`, 191.164}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{33.879, 192.227}, {
                    35.066, 191.164}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{33.879, 192.227}, {
                    35.066, 191.164}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{33.086, 192.227}, {
                    34.273, 191.164}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{33.086, 192.227}, {
                    34.273, 191.164}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{32.289, 192.227}, {33.48,
                     191.164}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{32.289, 192.227}, {33.48,
                     191.164}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{31.496, 192.227}, {
                    32.688, 191.164}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{31.496, 192.227}, {
                    32.688, 191.164}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{30.703, 192.227}, {
                    31.895, 191.164}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{30.703, 192.227}, {
                    31.895, 191.164}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{33.879, 192.227}, {
                    35.066, 191.164}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{33.879, 192.227}, {
                    35.066, 191.164}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{29.91, 192.227}, {31.102,
                     191.164}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{29.91, 192.227}, {31.102,
                     191.164}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{29.117000000000004`, 
                    192.227}, {30.309, 191.164}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{29.117000000000004`, 
                    192.227}, {30.309, 191.164}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{28.324, 192.227}, {
                    29.516000000000002`, 191.164}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{28.324, 192.227}, {
                    29.516000000000002`, 191.164}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{27.531000000000002`, 
                    192.227}, {28.723, 191.164}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{27.531000000000002`, 
                    192.227}, {28.723, 191.164}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    92.371, 198.945}, {79.477, 198.945}, {78.766, 198.945}, {
                    78.191, 198.406}, {78.191, 197.738}, {78.191, 191.664}, {
                    78.191, 190.996}, {78.766, 190.45700000000002`}, {79.477, 
                    190.45700000000002`}, {92.371, 190.45700000000002`}, {
                    93.086, 190.45700000000002`}, {93.66, 190.996}, {93.66, 
                    191.664}, {93.66, 197.738}, {93.66, 198.406}, {93.086, 
                    198.945}, {92.371, 198.945}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002951354166666667], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    92.371, 198.945}, {79.477, 198.945}, {78.766, 198.945}, {
                    78.191, 198.406}, {78.191, 197.738}, {78.191, 191.664}, {
                    78.191, 190.996}, {78.766, 190.457}, {79.477, 190.457}, {
                    92.371, 190.457}, {93.086, 190.457}, {93.66, 190.996}, {
                    93.66, 191.664}, {93.66, 197.738}, {93.66, 198.406}, {
                    93.086, 198.945}, {92.371, 198.945}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    92.043, 198.594}, {79.809, 198.594}, {79.133, 198.594}, {
                    78.586, 198.098}, {78.586, 197.48800000000003`}, {78.586, 
                    191.918}, {78.586, 191.305}, {79.133, 190.812}, {79.809, 
                    190.812}, {92.043, 190.812}, {92.71900000000001, 
                    190.812}, {93.262, 191.305}, {93.262, 191.918}, {93.262, 
                    197.48800000000003`}, {93.262, 198.098}, {
                    92.71900000000001, 198.594}, {92.043, 
                    198.594}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752291666666667], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    92.043, 198.594}, {79.809, 198.594}, {79.133, 198.594}, {
                    78.586, 198.098}, {78.586, 197.488}, {78.586, 191.918}, {
                    78.586, 191.305}, {79.133, 190.812}, {79.809, 190.812}, {
                    92.043, 190.812}, {92.71900000000001, 190.812}, {93.262, 
                    191.305}, {93.262, 191.918}, {93.262, 197.488}, {93.262, 
                    198.098}, {92.71900000000001, 198.594}, {92.043, 
                    198.594}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIFIGYC4sqXaoYcc0Id4nZ58jD1ZziIrHN/WJUT6sB1
fXGBbV+Gw0Wl2z/rskIdijImvq1pznDYNPf98mPOoQ7CzQdOLazMcNC/q8LW
qBrqcPPc9+DHrRkOIY+Xzj7CEOrAAAI1GQ6qbI1TnZVDHUDa7QszHGbkCTUf
kAp1APJM45IyHIpBEu9DIOqSEfwJh75qxPhnOLh05zz/LRjqcNzbvNMxAGGe
bFSK9X3nDAdRkHv/hDh804jpP2SKMJ8b5H6tDIi/rEMdtpwo2zffDOEfsPsN
MxyOgczNCIXYK5/hAAsPsH9koeoXhULs1c+A2HM21GHVx0u+SRZQ/z+Fukc7
w8EZ5F7OMIdFrts+/zWBhueXUAenhKcXlIDuBVnryhfmAAomBZ8Mh3iQ+4wR
fHA4mYZB7EnNcOidDvSQAFQ+JcNBrvV14I5v0PgqznAA+WaPSBjEnXUZDntL
JkuwvAt1sAJ5uBsafhdDIe5pQPgH7O+WDAcAOIfkoA==
                    "]]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.00017376208333333334`], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIFIGYC4sqXaoYcc0Id4nZ58jD1ZziIrHN/WJUT6sB1
fXGBbV+Gw0Wl2z/rskIdijMmvq1pznDYNPf98mPOoQ5CzQdOLazMcNC/q8LW
qBrqcPPc9+DHrRkOIY+Xzj7CEOrAAAI1GQ6qbI1TnZVDHUDa7QszHGbkAXVK
hTq8q7E3jUvKgJj7PgSiLhnB7z/0VSPGP8PBpTvn+W/BUIdj3uadjgEI82Sj
UqzvO2c4iILc+yfE4ZtGTP8hU4T5YPdrZUD8ZR3qsOVE2b75Zgj/gN1vmAEx
NwPqP/kMB1h4gP0jC1W/KBRir34GxJ6zoQ6rPl7yTbKA+v9pqIMMyD3aGQ7O
IPdyhjksct32+a8JNDy/hDo4JTy9oAR0L8haV74wB1AwKfhkOMSD3GeM4IPD
yTQMYk9qhkPvdKCHBMIcnoDkUzIc5FpfB+74Bo2v4gwHkG/2iIRB3FmX4bC3
ZLIEy7tQB0uQh7uh4XcxFOKeBoR/joP83ZLhAAA0r+Sd
                    "],
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{85.398, 194.79299999999998`}, {85.398, 
                    194.406}, {85.766, 194.094}, {86.215, 194.094}, {86.664, 
                    194.094}, {87.027, 194.406}, {87.027, 
                    194.79299999999998`}, {87.027, 195.176}, {86.664, 
                    195.48800000000003`}, {86.215, 195.48800000000003`}, {
                    85.766, 195.48800000000003`}, {85.398, 195.176}, {85.398, 
                    194.79299999999998`}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.00018712128065294733`], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{85.398, 194.79308092799997`}, {85.398, 
                    194.40591648}, {85.766, 194.093901888}, {86.215, 
                    194.093901888}, {86.664, 194.093901888}, {87.027, 
                    194.40591648}, {87.027, 194.79308092799997`}, {87.027, 
                    195.175489056}, {86.664, 195.488454912}, {86.215, 
                    195.488454912}, {85.766, 195.488454912}, {85.398, 
                    195.175489056}, {85.398, 194.79308092799997`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{91.277, 
                    198.23399999999998`}, {92.46900000000001, 
                    197.176}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{91.277, 
                    198.23399999999998`}, {92.46900000000001, 197.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{90.48400000000001, 
                    198.23399999999998`}, {91.67599999999999, 
                    197.176}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{90.48400000000001, 
                    198.23399999999998`}, {91.67599999999999, 197.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{89.691, 
                    198.23399999999998`}, {90.883, 197.176}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{89.691, 
                    198.23399999999998`}, {90.883, 197.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{88.898, 
                    198.23399999999998`}, {90.09, 197.176}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{88.898, 
                    198.23399999999998`}, {90.09, 197.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{88.10499999999999, 
                    198.23399999999998`}, {89.29700000000001, 
                    197.176}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{88.10499999999999, 
                    198.23399999999998`}, {89.29700000000001, 197.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{87.312, 
                    198.23399999999998`}, {88.504, 197.176}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{87.312, 
                    198.23399999999998`}, {88.504, 197.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{86.52, 
                    198.23399999999998`}, {87.71100000000001, 
                    197.176}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{86.52, 
                    198.23399999999998`}, {87.71100000000001, 197.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{85.727, 
                    198.23399999999998`}, {86.91400000000002, 
                    197.176}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{85.727, 
                    198.23399999999998`}, {86.91400000000002, 197.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{84.93400000000001, 
                    198.23399999999998`}, {86.121, 197.176}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{84.93400000000001, 
                    198.23399999999998`}, {86.121, 197.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{84.141, 
                    198.23399999999998`}, {85.32799999999999, 
                    197.176}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{84.141, 
                    198.23399999999998`}, {85.32799999999999, 197.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{83.348, 
                    198.23399999999998`}, {84.535, 197.176}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{83.348, 
                    198.23399999999998`}, {84.535, 197.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{82.55499999999999, 
                    198.23399999999998`}, {83.742, 197.176}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{82.55499999999999, 
                    198.23399999999998`}, {83.742, 197.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{85.727, 
                    198.23399999999998`}, {86.91400000000002, 
                    197.176}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{85.727, 
                    198.23399999999998`}, {86.91400000000002, 197.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{81.762, 
                    198.23399999999998`}, {82.94900000000001, 
                    197.176}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{81.762, 
                    198.23399999999998`}, {82.94900000000001, 197.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{80.96900000000001, 
                    198.23399999999998`}, {82.15599999999999, 
                    197.176}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{80.96900000000001, 
                    198.23399999999998`}, {82.15599999999999, 197.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{80.17199999999998, 
                    198.23399999999998`}, {81.363, 197.176}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{80.17199999999998, 
                    198.23399999999998`}, {81.363, 197.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{79.37899999999999, 
                    198.23399999999998`}, {80.57, 197.176}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{79.37899999999999, 
                    198.23399999999998`}, {80.57, 197.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{80.57, 
                    198.23399999999998`}, {79.37899999999999, 
                    197.176}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{80.57, 
                    198.23399999999998`}, {79.37899999999999, 197.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{81.363, 
                    198.23399999999998`}, {80.17199999999998, 
                    197.176}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{81.363, 
                    198.23399999999998`}, {80.17199999999998, 197.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{82.15599999999999, 
                    198.23399999999998`}, {80.96900000000001, 
                    197.176}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{82.15599999999999, 
                    198.23399999999998`}, {80.96900000000001, 197.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{82.94900000000001, 
                    198.23399999999998`}, {81.762, 197.176}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{82.94900000000001, 
                    198.23399999999998`}, {81.762, 197.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{83.742, 
                    198.23399999999998`}, {82.55499999999999, 
                    197.176}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{83.742, 
                    198.23399999999998`}, {82.55499999999999, 197.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{84.535, 
                    198.23399999999998`}, {83.348, 197.176}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{84.535, 
                    198.23399999999998`}, {83.348, 197.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{85.32799999999999, 
                    198.23399999999998`}, {84.141, 197.176}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{85.32799999999999, 
                    198.23399999999998`}, {84.141, 197.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{86.121, 
                    198.23399999999998`}, {84.93400000000001, 
                    197.176}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{86.121, 
                    198.23399999999998`}, {84.93400000000001, 197.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{86.91400000000002, 
                    198.23399999999998`}, {85.727, 197.176}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{86.91400000000002, 
                    198.23399999999998`}, {85.727, 197.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{87.71100000000001, 
                    198.23399999999998`}, {86.52, 197.176}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{87.71100000000001, 
                    198.23399999999998`}, {86.52, 197.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{88.504, 
                    198.23399999999998`}, {87.312, 197.176}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{88.504, 
                    198.23399999999998`}, {87.312, 197.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{89.29700000000001, 
                    198.23399999999998`}, {88.10499999999999, 
                    197.176}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{89.29700000000001, 
                    198.23399999999998`}, {88.10499999999999, 197.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{86.121, 
                    198.23399999999998`}, {84.93400000000001, 
                    197.176}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{86.121, 
                    198.23399999999998`}, {84.93400000000001, 197.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{90.09, 
                    198.23399999999998`}, {88.898, 197.176}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{90.09, 
                    198.23399999999998`}, {88.898, 197.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{90.883, 
                    198.23399999999998`}, {89.691, 197.176}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{90.883, 
                    198.23399999999998`}, {89.691, 197.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{91.67599999999999, 
                    198.23399999999998`}, {90.48400000000001, 
                    197.176}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{91.67599999999999, 
                    198.23399999999998`}, {90.48400000000001, 197.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{92.46900000000001, 
                    198.23399999999998`}, {91.277, 197.176}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{92.46900000000001, 
                    198.23399999999998`}, {91.277, 197.176}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{91.277, 192.227}, {
                    92.46900000000001, 191.164}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{91.277, 192.227}, {
                    92.46900000000001, 191.164}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{90.48400000000001, 
                    192.227}, {91.67599999999999, 191.164}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{90.48400000000001, 
                    192.227}, {91.67599999999999, 191.164}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{89.691, 192.227}, {
                    90.883, 191.164}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{89.691, 192.227}, {
                    90.883, 191.164}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{88.898, 192.227}, {90.09,
                     191.164}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{88.898, 192.227}, {90.09,
                     191.164}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{88.10499999999999, 
                    192.227}, {89.29700000000001, 191.164}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{88.10499999999999, 
                    192.227}, {89.29700000000001, 191.164}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{87.312, 192.227}, {
                    88.504, 191.164}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{87.312, 192.227}, {
                    88.504, 191.164}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{86.52, 192.227}, {
                    87.71100000000001, 191.164}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{86.52, 192.227}, {
                    87.71100000000001, 191.164}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{85.727, 192.227}, {
                    86.91400000000002, 191.164}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{85.727, 192.227}, {
                    86.91400000000002, 191.164}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{84.93400000000001, 
                    192.227}, {86.121, 191.164}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{84.93400000000001, 
                    192.227}, {86.121, 191.164}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{84.141, 192.227}, {
                    85.32799999999999, 191.164}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{84.141, 192.227}, {
                    85.32799999999999, 191.164}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{83.348, 192.227}, {
                    84.535, 191.164}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{83.348, 192.227}, {
                    84.535, 191.164}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{82.55499999999999, 
                    192.227}, {83.742, 191.164}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{82.55499999999999, 
                    192.227}, {83.742, 191.164}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{85.727, 192.227}, {
                    86.91400000000002, 191.164}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{85.727, 192.227}, {
                    86.91400000000002, 191.164}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{81.762, 192.227}, {
                    82.94900000000001, 191.164}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{81.762, 192.227}, {
                    82.94900000000001, 191.164}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{80.96900000000001, 
                    192.227}, {82.15599999999999, 191.164}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{80.96900000000001, 
                    192.227}, {82.15599999999999, 191.164}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{80.17199999999998, 
                    192.227}, {81.363, 191.164}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{80.17199999999998, 
                    192.227}, {81.363, 191.164}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{79.37899999999999, 
                    192.227}, {80.57, 191.164}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{79.37899999999999, 
                    192.227}, {80.57, 191.164}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{80.57, 192.227}, {
                    79.37899999999999, 191.164}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{80.57, 192.227}, {
                    79.37899999999999, 191.164}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{81.363, 192.227}, {
                    80.17199999999998, 191.164}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{81.363, 192.227}, {
                    80.17199999999998, 191.164}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{82.15599999999999, 
                    192.227}, {80.96900000000001, 191.164}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{82.15599999999999, 
                    192.227}, {80.96900000000001, 191.164}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{82.94900000000001, 
                    192.227}, {81.762, 191.164}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{82.94900000000001, 
                    192.227}, {81.762, 191.164}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{83.742, 192.227}, {
                    82.55499999999999, 191.164}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{83.742, 192.227}, {
                    82.55499999999999, 191.164}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{84.535, 192.227}, {
                    83.348, 191.164}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{84.535, 192.227}, {
                    83.348, 191.164}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{85.32799999999999, 
                    192.227}, {84.141, 191.164}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{85.32799999999999, 
                    192.227}, {84.141, 191.164}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{86.121, 192.227}, {
                    84.93400000000001, 191.164}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{86.121, 192.227}, {
                    84.93400000000001, 191.164}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{86.91400000000002, 
                    192.227}, {85.727, 191.164}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{86.91400000000002, 
                    192.227}, {85.727, 191.164}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{87.71100000000001, 
                    192.227}, {86.52, 191.164}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{87.71100000000001, 
                    192.227}, {86.52, 191.164}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{88.504, 192.227}, {
                    87.312, 191.164}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{88.504, 192.227}, {
                    87.312, 191.164}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{89.29700000000001, 
                    192.227}, {88.10499999999999, 191.164}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{89.29700000000001, 
                    192.227}, {88.10499999999999, 191.164}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{86.121, 192.227}, {
                    84.93400000000001, 191.164}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{86.121, 192.227}, {
                    84.93400000000001, 191.164}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{90.09, 192.227}, {88.898,
                     191.164}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{90.09, 192.227}, {88.898,
                     191.164}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{90.883, 192.227}, {
                    89.691, 191.164}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{90.883, 192.227}, {
                    89.691, 191.164}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{91.67599999999999, 
                    192.227}, {90.48400000000001, 191.164}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{91.67599999999999, 
                    192.227}, {90.48400000000001, 191.164}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{92.46900000000001, 
                    192.227}, {91.277, 191.164}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{92.46900000000001, 
                    192.227}, {91.277, 191.164}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{50.605000000000004`, 181.15200000000002`}, {
                    31.359, 162.33200000000002`}, {23.148, 159.953}, {27., 
                    158.43800000000002`}, {30.855, 156.92200000000003`}, {
                    43.246, 166.63299999999998`}, {56.145, 179.535}, {69.039, 
                    192.43800000000002`}, {76.938, 203.918}, {73.086, 
                    205.434}, {69.23, 206.953}, {71.07, 201.172}, {
                    50.605000000000004`, 181.15200000000002`}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0004413333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{50.605000000000004`, 181.152}, {31.359, 
                    162.332}, {23.148, 159.95299999999997`}, {27., 158.438}, {
                    30.855, 156.92200000000003`}, {43.246, 
                    166.63299999999998`}, {56.145, 179.535}, {69.039, 
                    192.438}, {76.938, 203.918}, {73.086, 205.434}, {69.23, 
                    206.953}, {71.07, 201.172}, {50.605000000000004`, 
                    181.152}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    34.402, 167.477}, {41.145, 165.707}, {34.800999999999995`,
                     159.695}, {27.66, 157.21899999999997`}, {25.68, 
                    158.281}, {23.695, 159.34}, {29.246, 161.816}, {34.402, 
                    167.477}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    34.402, 167.477}, {41.145, 165.707}, {34.800999999999995`,
                     159.695}, {27.66, 157.219}, {25.68, 158.281}, {23.695, 
                    159.34}, {29.246, 161.816}, {34.402, 167.477}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    34.402, 166.76999999999998`}, {39.956999999999994`, 
                    165.35200000000003`}, {33.773, 159.57}, {27.66, 157.93}, {
                    26.078, 158.63299999999998`}, {24.487999999999996`, 
                    159.34}, {29.379, 161.32800000000003`}, {34.402, 
                    166.76999999999998`}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    34.402, 166.76999999999998`}, {39.956999999999994`, 
                    165.352}, {33.773, 159.57}, {27.66, 157.93}, {26.078, 
                    158.63299999999998`}, {24.487999999999996`, 159.34}, {
                    29.379, 161.32800000000003`}, {34.402, 
                    166.76999999999998`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJ5IGYC4qcXlG7/7PN2UGVrnOq8P81higRLGF+vt8Nx
b/NOxz1pDtcXF9hytXs79B/6qhGzPs3BNG6XJ0+TtwMXSGIVgu+UADRpcZrD
M5B5dd4O3zRi+g/NTXOofKlmyFHj7fB46ewjCjPSHH7VZe0pKYbaNznNYaHr
ts9/S7wdZuQJNR/og6qP8XbYN19K/25PmsObwB1yrd7eDiBrmNrTHHqnAxU6
eDvo31Vha2xNc3Dpznn+WxNqf3Oaw0WQ9VJQ+xrSHHKf/175kcnbofU10KBa
qPwrL4h9VWkOK44BPXrRy2HVx0u+SRVpDmDn7/KC6K+A+meel4MPMDgSKtMc
5hxR2FDU4eUAVJW1pybNQRPoza8VXg4gYxyB9gFdqd2e5gV3jxnI4UleDkUZ
E9/WAN1/GuThWC8HdUOONTJA/27//PdKRaSXw7sae9O4SVD/JXg57CmZLMEC
lDcA+TMV6t42hPlg9wLtaxe7ee57MsJ9MPPA8VOW5mAHYvh6OSwChXNBmgMA
EdfgEA==
                    "],
                    CurveClosed->{0}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJNIGYCYoO7KmyNS70chJoPnFqYmObwqy5rT8liLweX
7pznv4H8lce8zTsXejlcVLr9sy4pzeHZBSBjnpeDU8LTC0rJaQ6nFrpu+7zW
y8Fyy4myffFpDny6m+a+X+7lkDHxbY09UL8+yPxWL4dvGjH9h1LTHGy5ri8u
yPVyKAAxMqD2BXs5qBtyrJHJgvKNvRz6D33ViMlOc3gTuEOu9bYnnL/t898r
FTsR/MNAqn+RpwPIWNssqHynJ9z8T5d8kwQqPB0KQfyUNIcpEixhfLGeDu9q
7E3jgP6J2+XJw+Tt6VAtss79YVyaQ4r1ff9ec08HmSggKzrN4SnIv3qeDr3T
84SaI9IcFgG9+1fF08EK5N9gqHuFPR1kQer90xz4Qf5n94SEn2eaw+wjChuK
fnhA7HFPc1gOCs+PHhD3OKQ55D7/vfLjIw+HffOl9O8C+VrAYPp6wwNiv3Wa
A8hbXN89IP61hrqHzxMSH1ZpDqdB4S8L9Y9ZmoMmSL8FNHyMEe7xMe90TLCE
xt8/hPlgd770gMSXLdR/TzwcZgC9e8AuzWFPyWQJlmMIPjh8V3o4AG3P2uMA
Dd8ZHhB9NmkOIOPrqhDmg9VnekDiH2i/KDCYq1I8HFpfAyMWyI8AJRw/BB8A
wZYvwA==
                    "],
                    CurveClosed->{0}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJVIGYCYmn9uypsgZ4OlltOlO2TTnNoF7t57ruzp0MY
n+6muUC+Zkz/oa8cng4ZE9/W2EumOZjG7fLk+eQBVz/niMKGohseEHlZqPoT
Hg6rPl7yTVJIc9j2+e+Vip0eDkLNB04tVE1zWH7M27xzo4eDj3mnY4ImQr5a
ZJ37QzkE/12NvWmcVJrD9cUFtlzbPRzUDTnWyAilObwO3CHXutrDwaU75/lv
wTQIPRNqH0+aQ4r1ff/edg8HoC+CH3NC/VMM1c+W5rASZH+ih8OTpbOPKLCk
OawA8QM9HBa5Am1mSHM4tRDIsPVwAHmT6X+qw2yQ/zSg8n9SHQyAwdUo6uHg
lPD0gtLvVIdnF5Ru//zn7tAKctjPVIciUEC8d4fY9y3V4SJQuu6Wu0MVyH+f
Uh3YG6c6d99xd5iRBwyRd6kOfdOBjAvukPB5mepw+KtGTP8ldweQ8IFHqRD/
XHeHhM+9VEj4vHSH2HM71aEXpPADVP5aKsQ/jB4OaiD7L6U6FIPU8UP9cz7V
IRIUcXIeDsBQvb74RKoDAwgYQOPnaCokPjk8HGSjgDYfTnXIff575cdP7g7f
gM46dBDqnudQ+w8j3A9TDwDzNBH1
                    "],
                    CurveClosed->{0}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4l91WXtKDrs7qBtyrJHZlerQLnbz3PfN7g7V
IuvcHwL5kyVYwvhq3R3idnnyMO1PdVjkuu3z3xR3CH0g1WEKSJ4Xwb+odPtn
3Ss3h97peULNB6DmPXZz4Lq+uMB2X6oDiOI67uZQlDHxbc3uVAeQNVVb3BxU
2RqnOm9PdeDT3TT3/XI3h1UfL/kmbUl1iLDccqKsz80BaNiphRtTHaT176qw
Nbo5AE0Nfrw21QHoKu32NKj+5akOlS/VDDlioPYtSnUQBZkfAtU/N9WhGGSv
v5uDU8LTC0rTEfzHS2cfUZiQ6gAKG4YAKL8j1WH7579XKiLdHICu2De/DWH+
hENfNWLqUx3A4Zfs5gB2ViXUvXluDiBjGEpSHUxBAdfk5jADFBx5UPe0uDns
my+lfzcH6v42qH9zEP6VjUqxvp+d6gAAl/y3aw==
                    "],
                    CurveClosed->{0}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752354166666667], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxVU2lIVUEUfmqYiFlIRYU/TErFFn1Zlpr1lTO3LMVKEgspE0+JmVsSFSJI
gYhoRYZChKhECyEhYRBPkQjbKEwMWwgJNQsSM8EWM5p5c56XfgzcM+dw5tvu
8pyifeTjcDi81IE63uoMtBYn+jdYCDrX/az5AGFR246PZ+vtOjPu3pNTdRZc
ZZeXzMkgtMiOyZnzFg49SA7wTicsi/qwwrfEwtuXP9KHUnm+0EK0uq5U9cm8
S2PlaXb9uyLfVRZjYSoi68JDVe8K8F5VFWth6PrVRyF7CCdGp29NhFp4o/ft
JdyfnOk/vdRCysbqbdn7Cc+bFYB5Fnp2q4tM3udjoatJIcki+FZeSar5IxGv
YHQdJnRq3FPSzOcSNIvAMYnGQsXwKPMZlgh3+t0Jzie8Cn3/q+KdRF2DGigg
bNBE+yQyAte0XysidGg8TyVqdb+YkKzx90iDr4Rw5kuY088lDT9Vu3m/llBb
811qPjdhMK12QELDayokKNZ3Sz9LrNTAj5O2xeH4Jo0eedz/KQ0/hf9TrwL4
V0LLuvUI4aYm5mUZvFm8fy7rkWnXHr/+66fYtUrBQOtOe7+bbxKharFydpLx
g/X9Kk0etrC/g6x3AuvZz3rEEearNeOPeT6W+XVLbM8e6Q2NYX3bmV80QT87
foP7UYTvfak5Cxolbk+oj9UEUVMwOl0t0ad9imS9y9mPCII7z8ckgg8qZuGE
uRpvit1351tI+OvBSM6v097vnguRKNW8ojiPQczHyXr4SAxrf9Z7/BEmP7Ee
fbiO9+RLGH6bCfU6fy8EtMwVSj8te3GnMP9PImFEN9qEyWc8v98ijP6bPHqI
WT31v+y4KGb1dOtdJRCm31/HeMrFLJ+Fmn+ZMPlbS/gHDmu4cA==
                    "],
                    CurveClosed->{0}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752354166666667], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}}}, CompressedData["
1:eJxFUltIlEEU/t1i28JCwkRCukhaaiE+SFSYX81EdCMqkIJlEzkDRTeziK0k
sDCrZdWIqKiIsh6KiAqpEJHYpEJBTMLoIiVma7lrubZa2EIz/wz+A+fh48zM
dzlnftmBrWKSZVlJsvJluWTxwN7w+F0OS53FArPzexa4H3FkuasusjwBX9O6
ZFc7x+X9M089zxZYn+zKq+nmqB7c8mxOlsDKae8ayns46kPxRd65AjneulB8
gOPrnaut8zIE1DeBCEfz4Qvpk9MEXshrdTHDlyJQqAgkVrRVUx18SfG5BPzf
sws88n3JjCWPr48TgqrxhaMz8+PfE6M0oaflhlT+izDrwdreY60c7zvGtvVF
CUfV+2aO5Y2vj7QMmv5tjvIiKXyAsH2ZbNSafpggVT+s8HOsLu3vzAyb914H
23ls4BiVNkL9BDu/HJOHxLnKf7pz39ZrcfSpPCRf2801T0aiDF1K/w/z/yeG
g0pPhEArPm8OvmLa70/SPpsYVMxFMUJNmnTWwHBLfpP4TXg6knjrv2LwH8I1
pf8MQ63i/UeIdW0qS/EzbFx6dlVpktB6dzM9D7fAoV3no5U7mc7DY+ZbwrS/
6QI7VD4+pvOZYvZhD5uYjz2vCqb9JwjfbMFM78MYaZ7TDIqmOO7oW1jguZ8x
RFC7aNUz3BuWQmU+7SqfoNHb6+DjqXJwHwgRSVMdYBiqLC70dRPeKLpzxk8H
YZ/c5uGTpt/mYJvvJeE/RYpP9g==
                    "],
                    CurveClosed->{0}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxdVHtoTmEc/nxmtJbksuQWso1iNrlkvvN9zznuNmS0ZmPW/NyHz8h1PsaW
2zbGhkJjYrls5pJcRnJLQojELBZCriMkrbzv+f22E3+cTr/z/t7n97zP87yn
W/rChBlNXS5XE/Wkq8etnvlv/xypyzRxM27QJrOS0FCHPDnoNyqcOrFln1P7
ThMGpF4YHarqyyUd+tao/hXvI2JaZEn/YULz7OKhW/JM9K3pEZx9gNC2YmTt
yjOCv58Qrb8/lv5SwrUfPads/WYic3bhp6wyQplurJN5xwiXluxoHxRhNfLZ
e71rZWaSxTjlhOV6foaFyJgWxzsdlfWNViOfYVsy1AksPOhe/Tug5p39Xv9o
+XkLfkN1KD5aC9d9C0frHo5N303Qx3NXW8y/kHBE86m1+Lx5hNsHhp/9fsnC
5yzfgNTNhIF6Q6mFp/d+TXyVS+hob7T4POsJHyec65KbInzWiX79nLqd1qet
02+vuwU/IHq9MRF75tbSy8sIelvIWxOdk2nIi8VOnb9rQev1swleDVwj/pD4
89xkvGRHf7tOJARrv6oEb6Kcr1zWE4RfjlPb9FaZrF8S8Vy/8Jsues+R/rmS
n3TJwyLpTxO/VxHe3FfGjDNZ/7WEpMEKyGvip4rFVaVnL/X60dOEhi9Rehfo
/a0Ev4AYt5n0Fwr+V2CR5ldE7PszsN47Cfqzv17q7ZI/t4kqnTOFp1QYn99c
+OQQ9ug8vQPrqfjpuLheApp2INCgFxr94vsAhGth10i/H6xLNqGofVBiy6lg
/I2i12Rnv52XOIjOws8SvpmCFw2+TxkEfU2+RILzP1P8bSf8UiUPnYHnvwNz
qyaJvlEyf5LopfDs9yjh7wH7C/F7CKDt8g0mbAjTSQf70J+wWC9MA+IVnbQY
4TMLqNbzohvug+BHy/nHOrXtv+Jj+xcj/49Q4T+QME8b89rH54sl7ByqBLvo
w261/YpX9NvkY/0s4Rvn43yNJBTr/j9e1ite8njKy/jjRM80p879oAwI9/L+
8bLu8uKhXh8j/O8aPG+EzDtmcL9P9Nlh/Ms/x8DrQypJvSUvqw3WM5z4v3HI
4Hx3kfk3DD5fmPhxx+D72ea//hDCCXuw4AeJnl4D29StmdJU9K/1sJ8uwknd
v9eDUkWj3iV6pnig7bjiJti/oygP3x+F9xdVCpwI
                    "],
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{72.562, 
                    198.137}, {81.10499999999999, 212.879}, {86.773, 
                    225.42600000000002`}, {85.21100000000001, 226.141}, {
                    83.65599999999999, 226.859}, {75.465, 215.477}, {66.926, 
                    200.73399999999998`}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.00034917708333333334`], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{72.562, 
                    198.137}, {81.10499999999999, 212.879}, {86.773, 
                    225.426}, {85.21100000000001, 226.141}, {
                    83.65599999999999, 226.859}, {75.465, 215.477}, {66.926, 
                    200.73399999999998`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{72., 
                    198.395}, {80.23400000000001, 212.617}, {
                    85.91000000000001, 224.625}, {84.66799999999999, 
                    225.19899999999998`}, {83.426, 225.77299999999997`}, {
                    75.727, 214.695}, {67.488, 200.477}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.00030675208333333343`], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{72., 
                    198.39499999999998`}, {80.23400000000001, 212.617}, {
                    85.91000000000001, 224.625}, {84.66799999999999, 
                    225.199}, {83.426, 225.773}, {75.727, 214.695}, {67.488, 
                    200.477}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    70.586, 205.816}, {69.57799999999999, 
                    204.15200000000002`}, {68.52, 202.254}, {67.488, 
                    200.477}, {72., 198.395}, {73.027, 200.176}, {
                    74.15199999999999, 202.047}, {75.09400000000001, 
                    203.738}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0003481479166666667], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    70.586, 205.816}, {69.57799999999999, 204.152}, {68.52, 
                    202.254}, {67.488, 200.477}, {72., 198.39499999999998`}, {
                    73.027, 200.176}, {74.15199999999999, 202.047}, {
                    75.09400000000001, 203.738}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    70.965, 205.242}, {69.965, 203.578}, {69.266, 202.309}, {
                    68.23400000000001, 200.52700000000002`}, {71.617, 
                    198.97299999999998`}, {72.648, 200.75}, {73.406, 
                    201.99200000000002`}, {74.348, 203.684}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0003481479166666667], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    70.965, 205.242}, {69.965, 203.578}, {69.266, 202.309}, {
                    68.23400000000001, 200.527}, {71.617, 198.973}, {72.648, 
                    200.75}, {73.406, 201.992}, {74.348, 203.684}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    73.418, 203.316}, {71.164, 204.35500000000002`}, {69.16, 
                    200.89800000000002`}, {71.41400000000002, 
                    199.859}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002769611943733424], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    73.417948599, 203.315917393}, {71.16350044599997, 
                    204.35527949000002`}, {69.15984768300001, 
                    200.898620309}, {71.414295836, 199.859258212}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{73.422, 203.316}, {
                    69.164, 200.89800000000002`}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0003481479166666667], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{73.422, 203.316}, {
                    69.164, 200.898}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{71.41400000000002, 
                    199.859}, {71.164, 204.35500000000002`}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0003481479166666667], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{71.41400000000002, 
                    199.859}, {71.164, 204.355}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{83.613, 220.91}, {
                    81.35499999999999, 221.94899999999998`}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0003481479166666667], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{83.613, 220.91}, {
                    81.35499999999999, 221.949}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{82.836, 222.934}, {82.91400000000002, 222.625}, {
                    83.262, 222.44899999999998`}, {83.613, 222.539}, {83.965, 
                    222.625}, {84.18799999999999, 222.94899999999998`}, {
                    84.10499999999999, 223.258}, {84.027, 223.562}, {
                    83.67999999999999, 223.742}, {83.32799999999999, 
                    223.65200000000002`}, {82.977, 223.566}, {82.754, 
                    223.242}, {82.836, 222.934}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0004373646025411586], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{82.83573959999997, 222.933795676}, {
                    82.91418599999999, 222.62476281}, {83.26183340000001, 
                    222.448992254}, {83.61338199999999, 222.53949645}, {
                    83.96505909999999, 222.62536242599998`}, {
                    84.18728319999998, 222.94948530200003`}, {84.1058368, 
                    223.25776177800003`}, {84.0275189, 223.56215642400002`}, {
                    83.67974299999999, 223.7425652}, {83.32819439999999, 
                    223.65206100400002`}, {82.97651729999998, 
                    223.566195028}, {82.7542932, 223.24207215200002`}, {
                    82.83573959999997, 222.933795676}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{69.395, 181.15200000000002`}, {88.641, 
                    162.33200000000002`}, {96.85199999999999, 159.953}, {93., 
                    158.43800000000002`}, {89.145, 156.92200000000003`}, {
                    76.754, 166.63299999999998`}, {63.855, 179.535}, {50.961, 
                    192.43800000000002`}, {43.062000000000005`, 203.918}, {
                    46.913999999999994`, 205.434}, {50.77, 206.953}, {48.93, 
                    201.172}, {69.395, 181.15200000000002`}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0004413333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{69.395, 181.152}, {88.641, 162.332}, {
                    96.85199999999999, 159.95299999999997`}, {93., 158.438}, {
                    89.145, 156.92200000000003`}, {76.754, 
                    166.63299999999998`}, {63.855, 179.535}, {50.961, 
                    192.438}, {43.062000000000005`, 203.918}, {
                    46.913999999999994`, 205.434}, {50.77, 206.953}, {48.93, 
                    201.172}, {69.395, 181.152}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    85.598, 167.477}, {78.85499999999999, 165.707}, {85.199, 
                    159.695}, {92.34, 157.21899999999997`}, {94.32, 
                    158.281}, {96.30499999999999, 159.34}, {90.754, 
                    161.816}, {85.598, 167.477}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    85.598, 167.477}, {78.85499999999999, 165.707}, {85.199, 
                    159.695}, {92.34, 157.219}, {94.32, 158.281}, {
                    96.30499999999999, 159.34}, {90.754, 161.816}, {85.598, 
                    167.477}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    85.598, 166.76999999999998`}, {80.043, 
                    165.35200000000003`}, {86.227, 159.57}, {92.34, 157.93}, {
                    93.922, 158.63299999999998`}, {95.512, 159.34}, {90.621, 
                    161.32800000000003`}, {85.598, 
                    166.76999999999998`}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    85.598, 166.76999999999998`}, {80.043, 165.352}, {86.227, 
                    159.57}, {92.34, 157.93}, {93.922, 158.63299999999998`}, {
                    95.512, 159.34}, {90.621, 161.32800000000003`}, {85.598, 
                    166.76999999999998`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJ5IGYC4t7peULNFgEOqmyNU533pzls+/z3SoVlgMNx
b/NOxz1pDqLr3B9W2QQ49B/6qhGzPs3h2QWl2z/tAhy4ri8usF2F4DslPL2g
tDjNAWyeQ4DDN42Y/kNz0xxcunOe/3YMcHi8dPYRhRlpDs0HTi10dYPaNznN
Qf+uCluja4DDDKC2A31Q9YEBDvvmS+nf7Ulz4AbZExXgELfLk4epPc3BasuJ
sn3xARB9rWkOsSDxbKj9zWkQc4qg9jWkOXjxMGm31wU4tL4O3CFXm+YAct6B
Lqh9VWkOa2SiUqynBzis+njJN6kCqn8RVH8F1D8bAhx8gMGRUJnmsHnu++XH
dgc43P5Zl7WnJs0BZGzr4QCHY6DwAtoHFj+DcA84fM4FOBRlTHxbA3S/NMjh
FwMc1A051sgA/QsOh8sBDu9q7E3jJkH9dz7AYU/JZAkWoHwmUJv9Wah72xDm
g90LtG8vSN05hPtg5oHjpyzN4WGVyDr3mwEOi1yBMVuQ5gAAXi7g/Q==
                    
                    "],
                    CurveClosed->{0}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJNIGYC4syJb2vs1wY4CDUfOLUwMc0BRLmuC3Bw6c55
/hvIXyMTlWK9PsDhotLtn3VJaQ690/OEmjcEODglPL2glJzmIK1/V4VtZYCD
5ZYTZfvi0xwqXqoZcqwJcMgAmQvUDzZ/b4DDN42Y/kOpaQ4Pq0TWuZ8McCiw
5bq+OANq37UAB3WgLpksKP9ZgEP/oa8aMdlpDkBVBbZCgXC+KlvjVGdlBF++
9XXgDr1AiLosqLx1INz8drGb5747BzoUgvgpaQ7bPv+9UhEY6PCuxt40Duif
SyB/RQU6VAOd9TAuzcEvSSDCMiXQAeTt+9FQ/2YEQuiINAcDoHcbcwMdrED+
DYa6tyzQQRak3j/NoRLk/5pASPh5pjlsmvt++bHmQIe4XZ48TO7Q8GyHusch
zcGLh0m7vS/QYd98Kf27QD7QN3Ktk6H2W6c5gJxV1QL1rzXUPRWBkPiwgoZ/
IdQ/ZlD9yVD1xgj3+Jh3OiZYQvU3IMyPBbmrOxASX7ZQ//UGOswAKjtgl+aw
yBUYYnMQfBVQ+K4OdADanrXHARq+mwMh6mzSIOoOIcwHqz8dCIl/oP1g+myg
Ayja5ID8kMdLZx+5geADAA+pGxs=
                    "],
                    CurveClosed->{0}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJVIGYC4uKMiW9rwgMdLLecKNsnneawt2SyBEtcoEMY
n+6muUD+m8Adcq3VgQ4gZfaSaQ5PLyjd/tmGUL9p7vvlxyZD5WWh6mcHOqz6
eMk3SSHNQZWtcarz4kAHoeYDpxaqpjmskYlKsV4e6OBj3umYoImQrxZZ5/5Q
DsF/V2NvGieV5gASrloS6KBuyLFGRijNgev64gLbVYEOLt05z38LpjnE7/Lk
YdoMtY8nzcE/SSDCck+gw81z34Mfc0L9cwyqnw1q//lAhydLZx9RYIHyrwc6
LHLd9vkvQ5qDtP5dFbaHgQ5xIHP/p0L89xoq/ycV4s+vgQ5OCcCQ+J3q0Ds9
T6iZIcih9TXQ4z9THY55Az3GEQSx71uqwwyg9AGhIIcqkEc+pTrUAr21SzAI
Iv4uFRKO4kGQ8HmZ6iAHMkgsyAFk7IFHqQ5+IP+IBEHC516qgwoofLiDHIpA
DrkN1c8Olb+WCvHP/0AHNZD9l6Du+QH1z/lUh5DHQI9/CHQosAWG5IlUh/8g
8BwaP0dTHTaD/Ps70EEWaMz9w6kOQF3a7WxBDt80YvoPHYS6hwdq/2GE+2Hq
AZ/jAt4=
                    "],
                    CurveClosed->{0}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4uYDpxa6ygU5qBtyrJHZleqwt2SyBItakEO1
yDr3h0D+ts9/r1Q4BjnE7fLkYdqf6mBwV4Wt0TfIYZErUOYAVL4SwZ+eJ9R8
oCvIoRfMgJrXF+TAdX1xge2+VAdRoLFVc4IcijImvq3ZnerwTSOm/9DSIAdV
tsapzttTHSpeqgFdEuSw6uMl36QtqQ4hj5fOPrIjyEEI5NCNqQ7FIH37gxxu
nvse/HhtqsPtn3VZe85A9S9PdXDpznn++yLUvkVQ869C9c9NdTjmbd7peCPI
wSnh6QWl6Qg+yBqFCakO/0HgOpTfkQox93KQw5YTZfvmtyHMn3Doq0ZMfaoD
OPzOBTnog8KlEureE0EODCBQkurw7ILS7Z/7ghxmgIIjD+qevUEO++ZL6d/N
SXW4A3L/Hqh/cxD+lY1Ksb6fneoAABBoy4o=
                    "],
                    CurveClosed->{0}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752354166666667], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxVk1tIVVEQho8XzMpCRCXyPGiUillHsyyPmb+ZlKVd9pRomNnBKTFRuyAm
dkB8EAmLiKgIEYkoQnwwuyAqFaXSQ4QEGSYhWtFDRQiFdLG19prYdGDBmT2z
Z83/zb/jfLUWB7lcrgB1oE6gOpE926ca+yxEtDx63lXC+J5YeuHJPSfeP33z
+tOHFgZOX1oWXMRImVwZ0jxooaw/PyyQGKcqL35uGrHw5sUPmi6U+lHL1Kl4
eNfGtpxxJ9Zt8z5Y5h4VT8z5qwZmLOjXYvcydoYFrm79YmFc99vHWBXSfDl3
1kKBalN+gBHjUY3mLNO3WPr9sTDUudwzWco4m72hrD+A4O0brR86zOjKuz/7
O5hMfQVDRa8aFhKu1iiFR0XPEkJCami3u4rN8wjC+SvqTzXj/csVE3PRhKKl
a3o7amWeGEK7ztcx3ur53WTmO8HYdq764884MvpUrPFkR5HRqep3+8KLMyIJ
erzOGkZvx9dbw4vJ9D3OmNe/BWR4VEo+iIw+Nb99r4tM3yOMbvfBisx5y8yr
9O/R/X8Jj2In/rev//IFTlyXtej1jR1Of1tvLmNQ7z1E5gejSfNV/Gw/bGGM
aK7hwjuTodfTHCU8MhhnPsWnhrqlPp217VyuWMLWckU2TfjGi74URoOuT5a8
h9EarZyVRrjzbazQl8xGRyZhTL3mTxLeObKPRIbt5wKCxvIuQfxQ4uTtvRwi
KLV1WUni32NOf1tHLeGkfq7uz9d+rBc9qcLDT5jR+1kv+2kR/6QLnzaJveKv
dtG3Wfx3jaBl+xW/qUY1cReZ7ydL+N8Wf3rle+gR/puEx12Hp+2XBw5Pm/cA
IV7fv070P3b02Pqfif/WMv4C+lG0GA==
                    "],
                    CurveClosed->{0}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752354166666667], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}}}, CompressedData["
1:eJxFUl1IlEEUXbfYNC0sQqIWM8kSrJaIEDfNU9sPaZE5Q/RgIcsdiIgyih5K
BBEVkTKpKIolKkLo78EiRExCw6IHSR+KDB8Wk402tTK1MLG530x+A/Nw5sy9
99xz7+rwqVI1z+PxJOgb0Ner75H2vSnehwIePusVzhxrHqlsEcjyVV8L5Sj0
Z376U3VT4MbJpTUv1ypodLzjqkBt/GBbepZC9PyyJ3uaBS53TWSXrVLg59pG
gc/3b73K8CtUFm452t4g0HH2yvL5aQrpHFhn66UqDL/TBTQODK7xVSe5+DrX
8yqEGk/EpnX8ocUbWiPThOCzN+c6mwT4W9UkzenpvL0iMPidMJld1tQVEfjY
OyWGRgg7Of6OMHFxyz8WqChY+OHeF4Ic0kLbLB8jtEbGWnq6BXaUayUxG9/n
YsePAWHyDBMc/+LWD42d/sfd/07eWQEuk6HrreRGk6TJ89XmXyJxmvV8IxwI
px7O80vT7xgZ3zMlNFtR8JPwgn3cKHF31/PxmV9k5rTZ4t+Ep6x/q8QlNvAv
oT5NOxGS2JfbsL08QRm9xdLMw6fwulgTJdL4kWjnK6Xpb5Ey/mje6WOBQh/r
LpJz83HmtVua/mcIF5mANPswRUZXvgSvVeGEq2/dpsRH/lHCLJ9ciQc/+veH
//uTZ/VGXXxBr1l0gJDMPgQlRnmx3lt/grafXkJRijenfpvl37rYqddD+AcX
9FjD
                    "],
                    CurveClosed->{0}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxdVAtMjlEY/qXFiLnPXCKTy7Bqc1lZeisKUaPvnDUjlte9UTEZ+UlaVKLc
2loqhiGtyczcNRObGWXulyXE3NaINXM55ztPfZtv+/bt/c57nvd5n+c9xzdx
zdwlHV0uVwf1JqrXQ70zvD3GZEcKuhk9aWdYFVNb3OXRkeSQSieW3cedKalm
entv2LNWFV8pHeD/QuVPzU1q+hWG/GNMm0MnJFwIEuT/YrhXRjnTj1Hzd9f4
Ab+MaXnB5/TQvsg/zOST9XHOeS9BqXrhOFPFoHk8uRPqnWI6PO3ct9+frHY+
Z0q+Hr9Zb1GAxj/NFKHr37ZoZGDnikEnmar1+kWrnc+CC6qDUxbdV7Tdqp6f
V8b+iCMWJYeoDMXnr34OWnSyuW52YhGbvELL8C8An92W6TePaaBeKLfoS7pq
NIfpndaj0qInd3/GNWYxrdV9XLVMP5lseNSBzzbo986JbX1anHwb7w/w3Uwr
tF7dBAWfvbX+ShpTn8qoho3eggYrWq/WOvGug6t7ZS5natio/vSEPwx/VGzj
zXP0t2MJv3yBF4f+RmN9LviFOLGtT7gw+sUzBWleUeC3GHpHI38l00w9PzGY
hxQ2ebHwexMb3vHC6L+VyWo8WnxjkTB1lZ5qOnyyVgnS20pzUC8N+PnQZzPy
C7CeLShF89vHVKTgrxVi3g5AnwzEhUxD9Py5BV1at7e/p8KLTewRH5QOPtsx
b7nQU/Fz6WePIG2T2w29Toh2v2y9rwszZ1swX7XC/M9gUtP8YMN94O9gWqj1
qnf2d9W8ngpK0P83gd9L8E0FXhPOUxLThg8jAjt/Emb+l8LfFvBLQL/Ngp63
uldesqDve9S3oFcT5mc6+DfAX4Lfr4XBDWK6rHV6KChf549nqtU87gmapT6L
AsHnjqBnul5A23kAfgD6f+LE9vc9/AvEPLaC/0ScFy9p+guG3j2l8XUKm3tg
sDT6hWMexkkzX1HID5NGr1k4/3HS4MdAz2VObN9H67E/Fn5vlVSn12ey6SsP
9SKh937kh7LxrVi287fP8yFJb5TsQ8ei3zJp9vnhfj0gzXz7wO989NcP95+q
Z5/P3v/ld4GfZcD3hB9VkvbUtIya3xH+1krjpwv5j6XBdUGfD5I0rWseuE++
S3N+FN4/DLG/mg==
                    "],
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{47.438, 
                    198.137}, {38.895, 212.879}, {33.227000000000004`, 
                    225.42600000000002`}, {34.789, 226.141}, {
                    36.343999999999994`, 226.859}, {44.535000000000004`, 
                    215.477}, {53.074, 200.73399999999998`}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.00034917708333333334`], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{47.438, 
                    198.137}, {38.895, 212.879}, {33.227000000000004`, 
                    225.426}, {34.789, 226.141}, {36.343999999999994`, 
                    226.859}, {44.535000000000004`, 215.477}, {53.074, 
                    200.73399999999998`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{48., 
                    198.395}, {39.766000000000005`, 212.617}, {34.09, 
                    224.625}, {35.332, 225.19899999999998`}, {36.574, 
                    225.77299999999997`}, {44.273, 214.695}, {52.512, 
                    200.477}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.00030675208333333343`], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{48., 
                    198.39499999999998`}, {39.766000000000005`, 212.617}, {
                    34.09, 224.625}, {35.332, 225.199}, {36.574, 225.773}, {
                    44.273, 214.695}, {52.512, 200.477}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    49.413999999999994`, 205.816}, {50.422000000000004`, 
                    204.15200000000002`}, {51.48, 202.254}, {52.512, 
                    200.477}, {48., 198.395}, {46.973, 200.176}, {45.848, 
                    202.047}, {44.906, 203.738}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0003481479166666667], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    49.413999999999994`, 205.816}, {50.422000000000004`, 
                    204.152}, {51.48, 202.254}, {52.512, 200.477}, {48., 
                    198.39499999999998`}, {46.973, 200.176}, {45.848, 
                    202.047}, {44.906, 203.738}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    49.035000000000004`, 205.242}, {50.035000000000004`, 
                    203.578}, {50.734, 202.309}, {51.766000000000005`, 
                    200.52700000000002`}, {48.382999999999996`, 
                    198.97299999999998`}, {47.352, 200.75}, {46.594, 
                    201.99200000000002`}, {45.652, 203.684}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0003481479166666667], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    49.035000000000004`, 205.242}, {50.035000000000004`, 
                    203.578}, {50.734, 202.309}, {51.766000000000005`, 
                    200.527}, {48.382999999999996`, 198.973}, {47.352, 
                    200.75}, {46.594, 201.992}, {45.652, 203.684}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    46.582, 203.316}, {48.836, 204.35500000000002`}, {
                    50.839999999999996`, 200.89800000000002`}, {48.586, 
                    199.859}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002769611943733424], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    46.58167737800001, 203.316123686}, {48.83612553100003, 
                    204.355485783}, {50.839778294, 200.898826602}, {
                    48.58533014099999, 199.85946450500003`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{46.578, 203.316}, {
                    50.836, 200.89800000000002`}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0003481479166666667], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{46.578, 203.316}, {
                    50.836, 200.898}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{48.586, 199.859}, {
                    48.836, 204.35500000000002`}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0003481479166666667], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{48.586, 199.859}, {
                    48.836, 204.355}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{36.38699999999999, 
                    220.91}, {38.645, 221.94899999999998`}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0003481479166666667], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{36.38699999999999, 
                    220.91}, {38.645, 221.949}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{37.164, 222.934}, {37.086, 222.625}, {
                    36.73800000000001, 222.44899999999998`}, {
                    36.38699999999999, 222.539}, {36.035000000000004`, 
                    222.625}, {35.812, 222.94899999999998`}, {35.895, 
                    223.258}, {35.973, 223.562}, {36.32, 223.742}, {
                    36.672000000000004`, 223.65200000000002`}, {37.023, 
                    223.566}, {37.246, 223.242}, {37.164, 
                    222.934}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0004373646025411586], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{37.16445770000001, 222.933479778}, {
                    37.08623700000002, 222.62532413000002`}, {36.7385896, 
                    222.449553574}, {36.3868153, 222.539180552}, {
                    36.03513820000002, 222.625046528}, {35.8129141, 
                    222.949169404}, {35.894360500000005`, 223.25744588}, {
                    35.9729041, 223.562717744}, {36.320454300000016`, 
                    223.74224930200003`}, {36.672228600000004`, 
                    223.652622324}, {37.02390570000001, 223.566756348}, {
                    37.24612980000001, 223.242633472}, {37.16445770000001, 
                    222.933479778}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}}}, {{{54.105000000000004`, 206.016}, {
                    54.105000000000004`, 193.641}, {54.176, 188.977}, {
                    53.266000000000005`, 188.336}, {52.398, 
                    187.65200000000002`}, {28.324, 188.336}, {28.324, 
                    184.80100000000002`}, {28.324, 181.266}, {48.156, 
                    177.727}, {54.105000000000004`, 177.727}, {
                    62.035000000000004`, 177.727}, {66.004, 181.266}, {66.004,
                     188.336}, {66.004, 206.016}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0003178145833333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}}}, {{{54.105000000000004`, 
                    206.01600000000002`}, {54.105000000000004`, 
                    193.64100000000002`}, {54.176, 188.977}, {
                    53.266000000000005`, 188.336}, {52.398, 187.652}, {28.324,
                     188.336}, {28.324, 184.801}, {28.324, 181.266}, {48.156, 
                    177.727}, {54.105000000000004`, 177.727}, {
                    62.035000000000004`, 177.727}, {66.004, 181.266}, {66.004,
                     188.336}, {66.004, 206.01600000000002`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{54.105000000000004`, 202.48000000000002`}, {
                    54.105000000000004`, 200.71099999999998`}, {58.07, 
                    200.125}, {62.035000000000004`, 200.125}, {66.004, 
                    200.71099999999998`}, {66.004, 202.48000000000002`}, {
                    62.035000000000004`, 201.89100000000002`}, {58.07, 
                    201.89100000000002`}, {54.105000000000004`, 
                    202.48000000000002`}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{54.105000000000004`, 202.48}, {
                    54.105000000000004`, 200.711}, {58.07, 200.125}, {
                    62.035000000000004`, 200.125}, {66.004, 200.711}, {66.004,
                     202.48}, {62.035000000000004`, 201.891}, {58.07, 
                    201.891}, {54.105000000000004`, 202.48}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{54.105000000000004`, 206.016}, {
                    54.105000000000004`, 204.25}, {58.07, 203.66}, {
                    62.035000000000004`, 203.66}, {66.004, 204.25}, {66.004, 
                    206.016}, {62.035000000000004`, 205.42600000000002`}, {
                    58.07, 205.42600000000002`}, {54.105000000000004`, 
                    206.016}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{54.105000000000004`, 206.01600000000002`}, {
                    54.105000000000004`, 204.25}, {58.07, 203.66}, {
                    62.035000000000004`, 203.66}, {66.004, 204.25}, {66.004, 
                    206.01600000000002`}, {62.035000000000004`, 205.426}, {
                    58.07, 205.426}, {54.105000000000004`, 
                    206.01600000000002`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{54.105000000000004`, 204.25}, {
                    54.105000000000004`, 202.48000000000002`}, {58.07, 
                    201.89100000000002`}, {62.035000000000004`, 
                    201.89100000000002`}, {66.004, 202.48000000000002`}, {
                    66.004, 204.25}, {62.035000000000004`, 203.66}, {58.07, 
                    203.66}, {54.105000000000004`, 204.25}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{54.105000000000004`, 204.25}, {
                    54.105000000000004`, 202.48}, {58.07, 201.891}, {
                    62.035000000000004`, 201.891}, {66.004, 202.48}, {66.004, 
                    204.25}, {62.035000000000004`, 203.66}, {58.07, 203.66}, {
                    54.105000000000004`, 204.25}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{54.105000000000004`, 200.71099999999998`}, {
                    54.105000000000004`, 198.945}, {58.07, 
                    198.35500000000002`}, {62.035000000000004`, 
                    198.35500000000002`}, {66.004, 198.945}, {66.004, 
                    200.71099999999998`}, {62.035000000000004`, 200.125}, {
                    58.07, 200.125}, {54.105000000000004`, 
                    200.71099999999998`}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{54.105000000000004`, 200.711}, {
                    54.105000000000004`, 198.945}, {58.07, 198.355}, {
                    62.035000000000004`, 198.355}, {66.004, 198.945}, {66.004,
                     200.711}, {62.035000000000004`, 200.125}, {58.07, 
                    200.125}, {54.105000000000004`, 200.711}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{55.188, 203.242}, {55.188, 203.031}, {54.945, 
                    202.863}, {54.645, 202.863}, {54.348, 202.863}, {
                    54.105000000000004`, 203.031}, {54.105000000000004`, 
                    203.242}, {54.105000000000004`, 203.453}, {54.348, 
                    203.625}, {54.645, 203.625}, {54.945, 203.625}, {55.188, 
                    203.453}, {55.188, 203.242}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.00027523230299006575`], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{55.188, 203.24234895299998`}, {55.188, 
                    203.03123184700002`}, {54.945, 202.863372589}, {54.645, 
                    202.863372589}, {54.348, 202.863372589}, {
                    54.105000000000004`, 203.03123184700002`}, {
                    54.105000000000004`, 203.24234895299998`}, {
                    54.105000000000004`, 203.45323096200002`}, {54.348, 
                    203.625086869}, {54.645, 203.625086869}, {54.945, 
                    203.625086869}, {55.188, 203.45323096200002`}, {55.188, 
                    203.24234895299998`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{57.348, 203.055}, {57.348, 202.844}, {
                    57.105000000000004`, 202.672}, {56.809, 202.672}, {56.508,
                     202.672}, {56.266000000000005`, 202.844}, {
                    56.266000000000005`, 203.055}, {56.266000000000005`, 
                    203.262}, {56.508, 203.434}, {56.809, 203.434}, {
                    57.105000000000004`, 203.434}, {57.348, 203.262}, {57.348,
                     203.055}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.00027523230299006575`], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{57.348, 203.054741547}, {57.348, 
                    202.843859538}, {57.105000000000004`, 202.672003631}, {
                    56.809, 202.672003631}, {56.508, 202.672003631}, {
                    56.266000000000005`, 202.843859538}, {56.266000000000005`,
                     203.054741547}, {56.266000000000005`, 203.261862004}, {
                    56.508, 203.43371791100003`}, {56.809, 
                    203.43371791100003`}, {57.105000000000004`, 
                    203.43371791100003`}, {57.348, 203.261862004}, {57.348, 
                    203.054741547}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{59.512, 202.863}, {59.512, 
                    202.65200000000002`}, {59.27, 202.48000000000002`}, {
                    58.973, 202.48000000000002`}, {58.672000000000004`, 
                    202.48000000000002`}, {58.43, 202.65200000000002`}, {
                    58.43, 202.863}, {58.43, 203.07399999999998`}, {
                    58.672000000000004`, 203.242}, {58.973, 203.242}, {59.27, 
                    203.242}, {59.512, 203.07399999999998`}, {59.512, 
                    202.863}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752377784678158], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{59.512, 202.863295456}, {59.512, 
                    202.652414344}, {59.27, 202.48032407200003`}, {58.973, 
                    202.48032407200003`}, {58.672000000000004`, 
                    202.48032407200003`}, {58.43, 202.652414344}, {58.43, 
                    202.863295456}, {58.43, 203.07417656799998`}, {
                    58.672000000000004`, 203.242035112}, {58.973, 
                    203.242035112}, {59.27, 203.242035112}, {59.512, 
                    203.07417656799998`}, {59.512, 202.863295456}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{61.676, 202.863}, {61.676, 
                    202.65200000000002`}, {61.434, 202.48000000000002`}, {
                    61.137, 202.48000000000002`}, {60.836, 
                    202.48000000000002`}, {60.594, 202.65200000000002`}, {
                    60.594, 202.863}, {60.594, 203.07399999999998`}, {60.836, 
                    203.242}, {61.137, 203.242}, {61.434, 203.242}, {61.676, 
                    203.07399999999998`}, {61.676, 202.863}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752377784678158], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{61.676, 202.863295456}, {61.676, 
                    202.652414344}, {61.434, 202.48032407200003`}, {61.137, 
                    202.48032407200003`}, {60.836, 202.48032407200003`}, {
                    60.594, 202.652414344}, {60.594, 202.863295456}, {60.594, 
                    203.07417656799998`}, {60.836, 203.242035112}, {61.137, 
                    203.242035112}, {61.434, 203.242035112}, {61.676, 
                    203.07417656799998`}, {61.676, 202.863295456}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{63.839999999999996`, 203.055}, {
                    63.839999999999996`, 202.844}, {63.598000000000006`, 
                    202.672}, {63.297000000000004`, 202.672}, {63., 
                    202.672}, {62.758, 202.844}, {62.758, 203.055}, {62.758, 
                    203.262}, {63., 203.434}, {63.297000000000004`, 
                    203.434}, {63.598000000000006`, 203.434}, {
                    63.839999999999996`, 203.262}, {63.839999999999996`, 
                    203.055}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.00027523230299006575`], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{63.839999999999996`, 203.054741547}, {
                    63.839999999999996`, 202.843859538}, {63.598000000000006`,
                     202.672003631}, {63.297000000000004`, 202.672003631}, {
                    63., 202.672003631}, {62.758, 202.843859538}, {62.758, 
                    203.054741547}, {62.758, 203.261862004}, {63., 
                    203.43371791100003`}, {63.297000000000004`, 
                    203.43371791100003`}, {63.598000000000006`, 
                    203.43371791100003`}, {63.839999999999996`, 
                    203.261862004}, {63.839999999999996`, 203.054741547}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{66.004, 203.242}, {66.004, 203.031}, {65.762, 
                    202.863}, {65.46100000000001, 202.863}, {65.164, 
                    202.863}, {64.922, 203.031}, {64.922, 203.242}, {64.922, 
                    203.453}, {65.164, 203.625}, {65.46100000000001, 
                    203.625}, {65.762, 203.625}, {66.004, 203.453}, {66.004, 
                    203.242}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.00027523230299006575`], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{66.004, 203.24234895299998`}, {66.004, 
                    203.03123184700002`}, {65.762, 202.863372589}, {
                    65.46100000000001, 202.863372589}, {65.164, 
                    202.863372589}, {64.922, 203.03123184700002`}, {64.922, 
                    203.24234895299998`}, {64.922, 203.45323096200002`}, {
                    65.164, 203.625086869}, {65.46100000000001, 
                    203.625086869}, {65.762, 203.625086869}, {66.004, 
                    203.45323096200002`}, {66.004, 203.24234895299998`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{54.105000000000004`, 
                    197.176}, {66.004, 187.629}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{54.105000000000004`, 
                    197.176}, {66.004, 187.62900000000002`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{55.293000000000006`, 
                    197.176}, {66.004, 188.691}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{55.293000000000006`, 
                    197.176}, {66.004, 188.691}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{56.879, 196.824}, {
                    66.004, 189.754}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{56.879, 196.824}, {
                    66.004, 189.754}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{58.07, 196.824}, {66.004,
                     190.812}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{58.07, 196.824}, {66.004,
                     190.812}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{59.26200000000001, 
                    196.824}, {66.004, 191.871}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{59.26200000000001, 
                    196.824}, {66.004, 191.87099999999998`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{60.449, 196.824}, {
                    66.004, 192.934}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{60.449, 196.824}, {
                    66.004, 192.934}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{61.641, 196.824}, {
                    66.004, 193.996}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{61.641, 196.824}, {
                    66.004, 193.996}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{62.828, 196.824}, {
                    66.004, 194.69899999999998`}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{62.828, 196.824}, {
                    66.004, 194.699}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{64.02, 196.824}, {66.004,
                     195.406}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{64.02, 196.824}, {66.004,
                     195.406}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{65.20700000000001, 
                    196.824}, {66.004, 196.117}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{65.20700000000001, 
                    196.824}, {66.004, 196.11700000000002`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{54.105000000000004`, 
                    196.117}, {66.004, 186.566}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{54.105000000000004`, 
                    196.11700000000002`}, {66.004, 186.566}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{66.004, 197.176}, {
                    52.913999999999994`, 186.566}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{66.004, 197.176}, {
                    52.913999999999994`, 186.566}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{64.812, 197.176}, {
                    53.312, 187.984}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{64.812, 197.176}, {
                    53.312, 187.984}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{63.227000000000004`, 
                    196.824}, {54.105000000000004`, 189.754}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{63.227000000000004`, 
                    196.824}, {54.105000000000004`, 189.754}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{62.035000000000004`, 
                    196.824}, {54.105000000000004`, 190.812}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{62.035000000000004`, 
                    196.824}, {54.105000000000004`, 190.812}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{60.848, 196.824}, {
                    54.105000000000004`, 191.871}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{60.848, 196.824}, {
                    54.105000000000004`, 191.87099999999998`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{59.656, 196.824}, {
                    54.105000000000004`, 192.934}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{59.656, 196.824}, {
                    54.105000000000004`, 192.934}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{58.469, 196.824}, {
                    54.105000000000004`, 193.996}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{58.469, 196.824}, {
                    54.105000000000004`, 193.996}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{57.277, 196.824}, {
                    54.105000000000004`, 194.69899999999998`}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{57.277, 196.824}, {
                    54.105000000000004`, 194.699}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{56.09, 196.824}, {
                    54.105000000000004`, 195.406}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{56.09, 196.824}, {
                    54.105000000000004`, 195.406}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{54.895, 196.824}, {
                    54.105000000000004`, 196.117}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{54.895, 196.824}, {
                    54.105000000000004`, 196.11700000000002`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{66.004, 196.117}, {
                    52.913999999999994`, 185.508}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{66.004, 
                    196.11700000000002`}, {52.913999999999994`, 
                    185.50799999999998`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{66.004, 195.055}, {
                    52.913999999999994`, 184.44899999999998`}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{66.004, 195.055}, {
                    52.913999999999994`, 184.449}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{66.004, 193.996}, {
                    52.913999999999994`, 183.383}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{66.004, 193.996}, {
                    52.913999999999994`, 183.383}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{66.004, 192.934}, {
                    52.913999999999994`, 182.324}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{66.004, 192.934}, {
                    52.913999999999994`, 182.324}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{66.004, 191.871}, {
                    52.913999999999994`, 181.266}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{66.004, 
                    191.87099999999998`}, {52.913999999999994`, 181.266}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{66.004, 190.812}, {
                    52.913999999999994`, 180.20299999999997`}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{66.004, 190.812}, {
                    52.913999999999994`, 180.203}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{66.004, 189.754}, {
                    52.913999999999994`, 179.14499999999998`}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{66.004, 189.754}, {
                    52.913999999999994`, 179.145}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{66.004, 
                    188.68800000000002`}, {52.913999999999994`, 
                    178.078}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{66.004, 188.688}, {
                    52.913999999999994`, 178.078}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{66.004, 187.629}, {
                    53.707, 177.727}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{66.004, 
                    187.62900000000002`}, {53.707, 177.727}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{66.004, 186.566}, {
                    54.895, 177.727}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{66.004, 186.566}, {
                    54.895, 177.727}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{65.60499999999999, 
                    185.15200000000002`}, {56.879, 178.078}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{65.60499999999999, 
                    185.152}, {56.879, 178.078}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{65.20700000000001, 
                    183.738}, {58.07, 178.078}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{65.20700000000001, 
                    183.738}, {58.07, 178.078}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{64.41400000000002, 
                    181.97299999999998`}, {60.848, 
                    179.14499999999998`}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{64.41400000000002, 
                    181.973}, {60.848, 179.145}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{54.105000000000004`, 
                    195.055}, {65.60499999999999, 185.859}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{54.105000000000004`, 
                    195.055}, {65.60499999999999, 185.859}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{54.105000000000004`, 
                    193.996}, {65.60499999999999, 
                    184.80100000000002`}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{54.105000000000004`, 
                    193.996}, {65.60499999999999, 184.801}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{54.105000000000004`, 
                    192.934}, {65.20700000000001, 184.094}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{54.105000000000004`, 
                    192.934}, {65.20700000000001, 184.094}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{54.105000000000004`, 
                    191.871}, {65.20700000000001, 183.031}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{54.105000000000004`, 
                    191.87099999999998`}, {65.20700000000001, 183.031}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{54.105000000000004`, 
                    190.812}, {64.812, 182.324}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{54.105000000000004`, 
                    190.812}, {64.812, 182.324}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{53.707, 190.105}, {
                    64.41400000000002, 181.617}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{53.707, 190.105}, {
                    64.41400000000002, 181.61700000000002`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{53.707, 
                    189.04299999999998`}, {63.62500000000001, 
                    181.266}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{53.707, 189.043}, {
                    63.62500000000001, 181.266}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{53.312, 188.336}, {
                    63.227000000000004`, 180.555}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{53.312, 188.336}, {
                    63.227000000000004`, 180.555}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
                    187.629}, {62.434, 180.20299999999997`}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
                    187.62900000000002`}, {62.434, 180.203}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
                    186.566}, {62.035000000000004`, 179.496}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
                    186.566}, {62.035000000000004`, 179.496}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
                    185.508}, {60.848, 179.14499999999998`}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
                    185.50799999999998`}, {60.848, 179.145}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{54.105000000000004`, 198.945}, {
                    54.105000000000004`, 197.176}, {58.07, 196.59}, {
                    62.035000000000004`, 196.59}, {66.004, 197.176}, {66.004, 
                    198.945}, {62.035000000000004`, 198.35500000000002`}, {
                    58.07, 198.35500000000002`}, {54.105000000000004`, 
                    198.945}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{54.105000000000004`, 198.945}, {
                    54.105000000000004`, 197.176}, {58.07, 196.59}, {
                    62.035000000000004`, 196.59}, {66.004, 197.176}, {66.004, 
                    198.945}, {62.035000000000004`, 198.355}, {58.07, 
                    198.355}, {54.105000000000004`, 198.945}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
                    184.44899999999998`}, {60.050999999999995`, 
                    178.789}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
                    184.449}, {60.050999999999995`, 178.789}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
                    183.383}, {59.26200000000001, 
                    178.43800000000002`}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
                    183.383}, {59.26200000000001, 178.438}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
                    182.324}, {58.469, 178.078}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
                    182.324}, {58.469, 178.078}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
                    181.266}, {56.879, 178.078}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
                    181.266}, {56.879, 178.078}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
                    180.20299999999997`}, {56.09, 177.727}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
                    180.203}, {56.09, 177.727}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
                    179.14499999999998`}, {54.895, 177.727}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
                    179.145}, {54.895, 177.727}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{55.188, 197.941}, {55.188, 197.73}, {54.945, 
                    197.559}, {54.645, 197.559}, {54.348, 197.559}, {
                    54.105000000000004`, 197.73}, {54.105000000000004`, 
                    197.941}, {54.105000000000004`, 198.148}, {54.348, 
                    198.32000000000002`}, {54.645, 198.32000000000002`}, {
                    54.945, 198.32000000000002`}, {55.188, 198.148}, {55.188, 
                    197.941}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.00027523230299006575`], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{55.188, 197.941381797}, {55.188, 
                    197.730499788}, {54.945, 197.55864388100002`}, {54.645, 
                    197.55864388100002`}, {54.348, 197.55864388100002`}, {
                    54.105000000000004`, 197.730499788}, {54.105000000000004`,
                     197.941381797}, {54.105000000000004`, 198.148502254}, {
                    54.348, 198.320358161}, {54.645, 198.320358161}, {54.945, 
                    198.320358161}, {55.188, 198.148502254}, {55.188, 
                    197.941381797}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{57.348, 197.75}, {57.348, 197.539}, {
                    57.105000000000004`, 197.36700000000002`}, {56.809, 
                    197.36700000000002`}, {56.508, 197.36700000000002`}, {
                    56.266000000000005`, 197.539}, {56.266000000000005`, 
                    197.75}, {56.266000000000005`, 197.961}, {56.508, 
                    198.129}, {56.809, 198.129}, {57.105000000000004`, 
                    198.129}, {57.348, 197.961}, {57.348, 197.75}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.00027523230299006575`], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{57.348, 197.750012839}, {57.348, 
                    197.53913083000003`}, {57.105000000000004`, 
                    197.367274923}, {56.809, 197.367274923}, {56.508, 
                    197.367274923}, {56.266000000000005`, 
                    197.53913083000003`}, {56.266000000000005`, 
                    197.750012839}, {56.266000000000005`, 197.960894848}, {
                    56.508, 198.12898920300003`}, {56.809, 
                    198.12898920300003`}, {57.105000000000004`, 
                    198.12898920300003`}, {57.348, 197.960894848}, {57.348, 
                    197.750012839}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{59.512, 197.559}, {59.512, 197.348}, {59.27, 
                    197.176}, {58.973, 197.176}, {58.672000000000004`, 
                    197.176}, {58.43, 197.348}, {58.43, 197.559}, {58.43, 
                    197.76999999999998`}, {58.672000000000004`, 197.941}, {
                    58.973, 197.941}, {59.27, 197.941}, {59.512, 
                    197.76999999999998`}, {59.512, 197.559}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752377784678158], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{59.512, 197.55858931199998`}, {59.512, 
                    197.3477082}, {59.27, 197.17561792800004`}, {58.973, 
                    197.17561792800004`}, {58.672000000000004`, 
                    197.17561792800004`}, {58.43, 197.3477082}, {58.43, 
                    197.55858931199998`}, {58.43, 197.76947042400002`}, {
                    58.672000000000004`, 197.94132560000003`}, {58.973, 
                    197.94132560000003`}, {59.27, 197.94132560000003`}, {
                    59.512, 197.76947042400002`}, {59.512, 
                    197.55858931199998`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{61.676, 197.559}, {61.676, 197.348}, {61.434, 
                    197.176}, {61.137, 197.176}, {60.836, 197.176}, {60.594, 
                    197.348}, {60.594, 197.559}, {60.594, 
                    197.76999999999998`}, {60.836, 197.941}, {61.137, 
                    197.941}, {61.434, 197.941}, {61.676, 
                    197.76999999999998`}, {61.676, 197.559}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752377784678158], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{61.676, 197.55858931199998`}, {61.676, 
                    197.3477082}, {61.434, 197.17561792800004`}, {61.137, 
                    197.17561792800004`}, {60.836, 197.17561792800004`}, {
                    60.594, 197.3477082}, {60.594, 197.55858931199998`}, {
                    60.594, 197.76947042400002`}, {60.836, 
                    197.94132560000003`}, {61.137, 197.94132560000003`}, {
                    61.434, 197.94132560000003`}, {61.676, 
                    197.76947042400002`}, {61.676, 197.55858931199998`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{63.839999999999996`, 197.75}, {
                    63.839999999999996`, 197.539}, {63.598000000000006`, 
                    197.36700000000002`}, {63.297000000000004`, 
                    197.36700000000002`}, {63., 197.36700000000002`}, {62.758,
                     197.539}, {62.758, 197.75}, {62.758, 197.961}, {63., 
                    198.129}, {63.297000000000004`, 198.129}, {
                    63.598000000000006`, 198.129}, {63.839999999999996`, 
                    197.961}, {63.839999999999996`, 197.75}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.00027523230299006575`], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{63.839999999999996`, 197.750012839}, {
                    63.839999999999996`, 197.53913083000003`}, {
                    63.598000000000006`, 197.367274923}, {63.297000000000004`,
                     197.367274923}, {63., 197.367274923}, {62.758, 
                    197.53913083000003`}, {62.758, 197.750012839}, {62.758, 
                    197.960894848}, {63., 198.12898920300003`}, {
                    63.297000000000004`, 198.12898920300003`}, {
                    63.598000000000006`, 198.12898920300003`}, {
                    63.839999999999996`, 197.960894848}, {63.839999999999996`,
                     197.750012839}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{66.004, 197.941}, {66.004, 197.73}, {65.762, 
                    197.559}, {65.46100000000001, 197.559}, {65.164, 
                    197.559}, {64.922, 197.73}, {64.922, 197.941}, {64.922, 
                    198.148}, {65.164, 198.32000000000002`}, {
                    65.46100000000001, 198.32000000000002`}, {65.762, 
                    198.32000000000002`}, {66.004, 198.148}, {66.004, 
                    197.941}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.00027523230299006575`], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{66.004, 197.941381797}, {66.004, 
                    197.730499788}, {65.762, 197.55864388100002`}, {
                    65.46100000000001, 197.55864388100002`}, {65.164, 
                    197.55864388100002`}, {64.922, 197.730499788}, {64.922, 
                    197.941381797}, {64.922, 198.148502254}, {65.164, 
                    198.320358161}, {65.46100000000001, 198.320358161}, {
                    65.762, 198.320358161}, {66.004, 198.148502254}, {66.004, 
                    197.941381797}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{37.050999999999995`, 
                    180.555}, {51.328, 187.984}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{37.050999999999995`, 
                    180.555}, {51.328, 187.984}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{36.258, 180.91}, {
                    49.73800000000001, 187.984}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{36.258, 180.91}, {
                    49.73800000000001, 187.984}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{35.858999999999995`, 
                    181.617}, {48.156, 187.984}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{35.858999999999995`, 
                    181.61700000000002`}, {48.156, 187.984}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{35.465, 182.324}, {
                    46.172000000000004`, 187.984}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{35.465, 182.324}, {
                    46.172000000000004`, 187.984}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{34.672000000000004`, 
                    183.031}, {44.586, 187.984}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{34.672000000000004`, 
                    183.031}, {44.586, 187.984}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{35.066, 184.094}, {
                    41.809, 187.629}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{35.066, 184.094}, {
                    41.809, 187.62900000000002`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{34.672000000000004`, 
                    184.80100000000002`}, {39.828, 187.629}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{34.672000000000004`, 
                    184.801}, {39.828, 187.62900000000002`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{34.672000000000004`, 
                    185.859}, {38.23800000000001, 187.629}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{34.672000000000004`, 
                    185.859}, {38.23800000000001, 187.62900000000002`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{38.23800000000001, 
                    180.20299999999997`}, {51.723000000000006`, 
                    187.277}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{38.23800000000001, 
                    180.203}, {51.723000000000006`, 187.277}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{39.43, 179.848}, {52.121,
                     186.566}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{39.43, 179.848}, {52.121,
                     186.566}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{40.621, 179.496}, {
                    52.516, 185.859}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{40.621, 179.496}, {
                    52.516, 185.859}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{41.809, 
                    179.14499999999998`}, {51.723000000000006`, 
                    184.44899999999998`}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{41.809, 179.145}, {
                    51.723000000000006`, 184.449}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{43.395, 
                    179.14499999999998`}, {52.121, 183.738}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{43.395, 179.145}, {
                    52.121, 183.738}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{44.586, 178.789}, {
                    52.121, 182.68}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{44.586, 178.789}, {
                    52.121, 182.68}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{45.777, 
                    178.43800000000002`}, {51.723000000000006`, 
                    181.617}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{45.777, 178.438}, {
                    51.723000000000006`, 181.61700000000002`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{47.358999999999995`, 
                    178.43800000000002`}, {52.121, 180.91}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{47.358999999999995`, 
                    178.438}, {52.121, 180.91}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{48.949, 178.078}, {
                    52.121, 179.848}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{48.949, 178.078}, {
                    52.121, 179.848}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{50.535000000000004`, 
                    178.078}, {52.516, 179.14499999999998`}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{50.535000000000004`, 
                    178.078}, {52.516, 179.145}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{53.312, 188.336}, {51.328, 188.336}, {
                    50.668000000000006`, 184.80100000000002`}, {
                    50.668000000000006`, 181.266}, {51.328, 177.727}, {53.312,
                     177.727}, {52.648, 181.266}, {52.648, 
                    184.80100000000002`}, {53.312, 188.336}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{53.312, 188.336}, {51.328, 188.336}, {
                    50.668000000000006`, 184.801}, {50.668000000000006`, 
                    181.266}, {51.328, 177.727}, {53.312, 177.727}, {52.648, 
                    181.266}, {52.648, 184.801}, {53.312, 188.336}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{29.91, 183.383}, {
                    34.672000000000004`, 186.92200000000003`}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{29.91, 183.383}, {
                    34.672000000000004`, 186.922}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{29.91, 185.859}, {
                    34.672000000000004`, 181.617}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{29.91, 185.859}, {
                    34.672000000000004`, 181.61700000000002`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{37.050999999999995`, 187.629}, {
                    34.672000000000004`, 187.277}, {34.141, 185.035}, {34.141,
                     183.15200000000002`}, {34.672000000000004`, 180.91}, {
                    37.050999999999995`, 180.20299999999997`}, {36.52, 
                    182.445}, {36.52, 185.38700000000003`}, {
                    37.050999999999995`, 187.629}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.00019591270833333333`], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{37.050999999999995`, 187.62900000000002`}, {
                    34.672000000000004`, 187.277}, {34.141, 185.035}, {34.141,
                     183.152}, {34.672000000000004`, 180.91}, {
                    37.050999999999995`, 180.203}, {36.52, 182.445}, {36.52, 
                    185.387}, {37.050999999999995`, 187.62900000000002`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}}}, {{{65.988, 205.309}, {65.988, 207.094}, {
                    64.20700000000001, 207.078}, {63.016, 208.137}, {63.016, 
                    209.21499999999997`}, {57.074, 209.19899999999998`}, {
                    57.074, 208.137}, {55.88699999999999, 207.078}, {
                    54.105000000000004`, 207.078}, {54.105000000000004`, 
                    205.309}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0003369062500000001], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}}}, {{{65.988, 205.309}, {65.988, 207.094}, {
                    64.20700000000001, 207.078}, {63.016, 208.137}, {63.016, 
                    209.215}, {57.074, 209.199}, {57.074, 208.137}, {
                    55.88699999999999, 207.078}, {54.105000000000004`, 
                    207.078}, {54.105000000000004`, 205.309}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    57.5, 211.32000000000002`}, {62.594, 
                    211.32000000000002`}, {62.594, 209.199}, {57.5, 
                    209.199}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002847395833333333], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    57.5, 211.32}, {62.594, 211.32}, {62.594, 
                    209.19899999999998`}, {57.5, 209.19899999999998`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    57.926, 213.441}, {62.168, 213.441}, {62.168, 211.32}, {
                    57.926, 211.32}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002847395833333333], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    57.926, 213.441}, {62.168, 213.441}, {62.168, 211.32}, {
                    57.926, 211.32}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    57.926, 215.562}, {62.168, 215.562}, {62.168, 213.441}, {
                    57.926, 213.441}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002847395833333333], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    57.926, 215.562}, {62.168, 215.562}, {62.168, 213.441}, {
                    57.926, 213.441}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    58.348, 218.395}, {61.742999999999995`, 218.395}, {
                    61.742999999999995`, 215.56300000000002`}, {58.348, 
                    215.56300000000002`}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002847395833333333], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    58.348, 218.395}, {61.742999999999995`, 218.395}, {
                    61.742999999999995`, 215.56300000000002`}, {58.348, 
                    215.56300000000002`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    58.203, 220.86700000000002`}, {61.891000000000005`, 
                    220.86700000000002`}, {61.891000000000005`, 218.394}, {
                    58.203, 218.394}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002967500000000001], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    58.203, 220.867}, {61.891000000000005`, 220.867}, {
                    61.891000000000005`, 218.394}, {58.203, 218.394}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{65.16799999999999, 223.168}, {65.16799999999999, 
                    221.312}, {62.969, 219.809}, {60.25, 219.809}, {
                    57.535000000000004`, 219.809}, {55.332, 221.312}, {55.332,
                     223.168}, {55.332, 225.023}, {57.535000000000004`, 
                    226.52700000000002`}, {60.25, 226.52700000000002`}, {
                    62.969, 226.52700000000002`}, {65.16799999999999, 
                    225.023}, {65.16799999999999, 223.168}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002797843009704614], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{65.16799999999999, 223.167931868}, {
                    65.16799999999999, 221.31284951800004`}, {62.969, 
                    219.808938571}, {60.25, 219.808938571}, {
                    57.535000000000004`, 219.808938571}, {55.332, 
                    221.31284951800004`}, {55.332, 223.167931868}, {55.332, 
                    225.023014218}, {57.535000000000004`, 
                    226.52692516500005`}, {60.25, 226.52692516500005`}, {
                    62.969, 226.52692516500005`}, {65.16799999999999, 
                    225.023014218}, {65.16799999999999, 223.167931868}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4rhdnjxM0f4OYPp1tgOM72Pe6ZhwNtth9hGF
DUU//B2stpwo2zcbk7+nZLIES5u/w6qPl3yTOrIdTi903fb5rJ/DzXPfgx9X
Zjv0Ts8TalZA8A9/1YjpL/KF8126c57/nukD4TdmO/Drbpr73t0Hbj463+Cu
ClvjUx+4+2B8mPth/AJbruuLOXLg+qtF1rk/1MPkO4Ps3+nj8LbG3jTOKQfu
vv3zpfTvBuTA3Q/jw/wH48P8D9MPCx+Y+eh8WPjC3Ice/gCXa7OX
                    
                    "]]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002797833333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4rhdnjxM0f4OYPp1tgOM72Pe6ZhwNtth9hGF
DUU//B0st5wo2zcbk7+nZLIES5u/w6qPl3yTOrIdTi903fb5rJ/DzXPfgx9X
Zjv0Ts8TalZA8A9/1YjpL/KF8126c57/nukD4TdmO/Drbpr73t0Hbj463+Cu
ClvjUx+4+2B8mPth/EJbruuLOXLg+qtF1rk/1MPkO4Ps3+nj8K7G3jTOKQfu
vn3zpfTvBuTA3Q/jw/wH48P8D9MPCx+Y+eh8WPjC3Ice/gCTM7OU
                    "],
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYCYtO4XZ48n/wcQBTT62wHGN/HvNMx4Wy2Q3HG
xLc1/f4OvdPzhJonYPLtuK4vLpD1d1jkuu3z35psh9MLgYyzfg43z30PflyZ
DVGngOAf/qoR01/kC+fnPv+98iOTr8OWE2X75pdlO0jp31Vh2+gDNx+dH2EJ
VOnnC3cfjA9zP4xfYAt0GEcOXD830Jm2Vph8sP1Kvg7CzQdOLfTNgbtv/3yg
yoAcuPthfJj/YHyY/2H6YeEDMx+dDwtfmPvQwx8ALlew6g==
                    
                    "]]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002797833333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYCYtO4XZ48n/wcQBTT62wHGN/HvNMx4Wy2Q3HG
xLc1/f4OvdPzhJonYPLtuK4vLpD1d1jkuu3z35psh9MLgYyzfg43z30PflyZ
DVGngOAf/qoR01/kC+fnPv+98iOTr8OWE2X75pdlO0jp31Vh2+gDNx+dH2EJ
VOnnC3cfjA9zP4xfaAt0GEcOXD/ImbZWmHyw/Uq+DkLNB04t9M2Bu2/ffKDK
gBy4+2F8mP9gfJj/Yfph4QMzH50PC1+Y+9DDHwArf7Dj
                    "],
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{56.562000000000005`, 222.98800000000003`}, {
                    56.562000000000005`, 222.40200000000002`}, {56.012, 
                    221.93}, {55.332, 221.93}, {54.656, 221.93}, {
                    54.105000000000004`, 222.40200000000002`}, {
                    54.105000000000004`, 222.98800000000003`}, {
                    54.105000000000004`, 223.57399999999998`}, {54.656, 
                    224.05100000000002`}, {55.332, 224.05100000000002`}, {
                    56.012, 224.05100000000002`}, {56.562000000000005`, 
                    223.57399999999998`}, {56.562000000000005`, 
                    222.98800000000003`}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002797843009704614], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{56.562000000000005`, 222.988463436}, {
                    56.562000000000005`, 222.402602545}, {56.012, 
                    221.929772253}, {55.332, 221.929772253}, {54.656, 
                    221.929772253}, {54.105000000000004`, 222.402602545}, {
                    54.105000000000004`, 222.988463436}, {54.105000000000004`,
                     223.57432432700003`}, {54.656, 224.05060593500002`}, {
                    55.332, 224.05060593500002`}, {56.012, 
                    224.05060593500002`}, {56.562000000000005`, 
                    223.57432432700003`}, {56.562000000000005`, 
                    222.988463436}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{66.398, 222.98800000000003`}, {66.398, 
                    222.40200000000002`}, {65.848, 221.93}, {
                    65.16799999999999, 221.93}, {64.488, 221.93}, {
                    63.940999999999995`, 222.40200000000002`}, {
                    63.940999999999995`, 222.98800000000003`}, {
                    63.940999999999995`, 223.57399999999998`}, {64.488, 
                    224.05100000000002`}, {65.16799999999999, 
                    224.05100000000002`}, {65.848, 224.05100000000002`}, {
                    66.398, 223.57399999999998`}, {66.398, 
                    222.98800000000003`}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002797843009704614], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{66.398, 222.988463436}, {66.398, 
                    222.402602545}, {65.848, 221.929772253}, {
                    65.16799999999999, 221.929772253}, {64.488, 
                    221.929772253}, {63.940999999999995`, 222.402602545}, {
                    63.940999999999995`, 222.988463436}, {63.940999999999995`,
                     223.57432432700003`}, {64.488, 224.05060593500002`}, {
                    65.16799999999999, 224.05060593500002`}, {65.848, 
                    224.05060593500002`}, {66.398, 223.57432432700003`}, {
                    66.398, 222.988463436}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{61.48, 222.98800000000003`}, {61.48, 
                    222.40200000000002`}, {60.93, 221.93}, {60.25, 221.93}, {
                    59.574, 221.93}, {59.023, 222.40200000000002`}, {59.023, 
                    222.98800000000003`}, {59.023, 223.57399999999998`}, {
                    59.574, 224.05100000000002`}, {60.25, 
                    224.05100000000002`}, {60.93, 224.05100000000002`}, {
                    61.48, 223.57399999999998`}, {61.48, 
                    222.98800000000003`}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002797843009704614], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{61.48, 222.988463436}, {61.48, 222.402602545}, {
                    60.93, 221.929772253}, {60.25, 221.929772253}, {59.574, 
                    221.929772253}, {59.023, 222.402602545}, {59.023, 
                    222.988463436}, {59.023, 223.57432432700003`}, {59.574, 
                    224.05060593500002`}, {60.25, 224.05060593500002`}, {
                    60.93, 224.05060593500002`}, {61.48, 
                    223.57432432700003`}, {61.48, 222.988463436}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{61.48, 226.52700000000002`}, {61.48, 225.941}, {
                    60.93, 225.465}, {60.25, 225.465}, {59.574, 225.465}, {
                    59.023, 225.941}, {59.023, 226.52700000000002`}, {59.023, 
                    227.11299999999997`}, {59.574, 227.586}, {60.25, 
                    227.586}, {60.93, 227.586}, {61.48, 
                    227.11299999999997`}, {61.48, 
                    226.52700000000002`}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002797843009704614], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{61.48, 226.52692516500005`}, {61.48, 
                    225.941064274}, {60.93, 225.464782666}, {60.25, 
                    225.464782666}, {59.574, 225.464782666}, {59.023, 
                    225.941064274}, {59.023, 226.52692516500005`}, {59.023, 
                    227.11364888500003`}, {59.574, 227.58561634800003`}, {
                    60.25, 227.58561634800003`}, {60.93, 
                    227.58561634800003`}, {61.48, 227.11364888500003`}, {
                    61.48, 226.52692516500005`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{57.926, 206.371}, {57.926, 205.785}, {57.355, 
                    205.309}, {56.652, 205.309}, {55.949, 205.309}, {55.379, 
                    205.785}, {55.379, 206.371}, {55.379, 
                    206.95700000000002`}, {55.949, 207.43}, {56.652, 
                    207.43}, {57.355, 207.43}, {57.926, 
                    206.95700000000002`}, {57.926, 206.371}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002847359638519521], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{57.926, 206.37114037400002`}, {57.926, 
                    205.78548654000002`}, {57.355, 205.308965924}, {56.652, 
                    205.308965924}, {55.949, 205.308965924}, {55.379, 
                    205.78548654000002`}, {55.379, 206.37114037400002`}, {
                    55.379, 206.95679420800002`}, {55.949, 207.429982512}, {
                    56.652, 207.429982512}, {57.355, 207.429982512}, {57.926, 
                    206.95679420800002`}, {57.926, 206.37114037400002`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{64.715, 206.371}, {64.715, 205.785}, {64.145, 
                    205.309}, {63.440999999999995`, 205.309}, {
                    62.73800000000001, 205.309}, {62.168000000000006`, 
                    205.785}, {62.168000000000006`, 206.371}, {
                    62.168000000000006`, 206.95700000000002`}, {
                    62.73800000000001, 207.43}, {63.440999999999995`, 
                    207.43}, {64.145, 207.43}, {64.715, 
                    206.95700000000002`}, {64.715, 206.371}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002847359638519521], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{64.715, 206.37114037400002`}, {64.715, 
                    205.78548654000002`}, {64.145, 205.308965924}, {
                    63.440999999999995`, 205.308965924}, {62.73800000000001, 
                    205.308965924}, {62.168000000000006`, 
                    205.78548654000002`}, {62.168000000000006`, 
                    206.37114037400002`}, {62.168000000000006`, 
                    206.95679420800002`}, {62.73800000000001, 
                    207.429982512}, {63.440999999999995`, 207.429982512}, {
                    64.145, 207.429982512}, {64.715, 206.95679420800002`}, {
                    64.715, 206.37114037400002`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{57.074, 
                    209.19899999999998`}, {63.016, 209.19899999999998`}, {
                    60.047, 206.016}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.00028473541666666665`], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{57.074, 
                    209.199}, {63.016, 209.199}, {60.047, 
                    206.01600000000002`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{61.746, 206.72299999999998`}, {61.746, 
                    205.941}, {60.983999999999995`, 205.309}, {60.047, 
                    205.309}, {59.109, 205.309}, {58.348, 205.941}, {58.348, 
                    206.72299999999998`}, {58.348, 207.504}, {59.109, 
                    208.137}, {60.047, 208.137}, {60.983999999999995`, 
                    208.137}, {61.746, 207.504}, {61.746, 
                    206.72299999999998`}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0003796485856436213], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{61.746, 206.72269929}, {61.746, 
                    205.94127212600003`}, {60.983999999999995`, 
                    205.308965924}, {60.047, 205.308965924}, {59.109, 
                    205.308965924}, {58.348, 205.94127212600003`}, {58.348, 
                    206.72269929}, {58.348, 207.50412645400004`}, {59.109, 
                    208.136432656}, {60.047, 208.136432656}, {
                    60.983999999999995`, 208.136432656}, {61.746, 
                    207.50412645400004`}, {61.746, 206.72269929}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    54.004, 196.11299999999997`}, {62.137, 
                    196.11299999999997`}, {62.41, 196.11299999999997`}, {
                    62.629000000000005`, 195.945}, {62.629000000000005`, 
                    195.738}, {62.629000000000005`, 194.36700000000002`}, {
                    62.629000000000005`, 194.156}, {62.41, 
                    193.99200000000002`}, {62.137, 193.99200000000002`}, {
                    54.004, 193.99200000000002`}, {53.730000000000004`, 
                    193.99200000000002`}, {53.508, 194.156}, {53.508, 
                    194.36700000000002`}, {53.508, 195.738}, {53.508, 
                    195.945}, {53.730000000000004`, 196.11299999999997`}, {
                    54.004, 196.11299999999997`}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    54.004, 196.113}, {62.137, 196.113}, {62.41, 196.113}, {
                    62.629000000000005`, 195.945}, {62.629000000000005`, 
                    195.738}, {62.629000000000005`, 194.367}, {
                    62.629000000000005`, 194.156}, {62.41, 193.992}, {62.137, 
                    193.992}, {54.004, 193.992}, {53.730000000000004`, 
                    193.992}, {53.508, 194.156}, {53.508, 194.367}, {53.508, 
                    195.738}, {53.508, 195.945}, {53.730000000000004`, 
                    196.113}, {54.004, 196.113}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}}, {{1, 4, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgAmJ+KO3SnfP8d2SAw+Ols48o7Mlw2DT3/fJjwgi+Fw+T
dvs2f4dvGjH9hxYi+Itct33+24DgCzcfOLXQF8G/87Mua48Owry3NfamcUIZ
DjD7YPze6XlCzQsQfGn9uypsNwPg+mF8mPkwPsx+GB/mPph5MPej+w/GB2lr
XJrhYLXlRNk+fQQfbA5vgMOqj5d8kyYg+OqGHGtkytDkI9Dk7RDmtb4O3CGn
ibAPxvdLEoiwbEHwQd5yXYbQD+PDzEeRL0OTn4AwD+Z+dP8BAFDw06U=
                    
                    "]]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}}, {{1, 4, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgAmJ+KO3SnfP8d2SAw+Ols48o7Mlw2DT3/fJjwgi+Fw+T
dvs2f4dvGjH9hxYi+Itct33+24DgCzUfOLXQF8G//bMua48Owrx3NfamcUIZ
DjD7YPze6XlCzQsQfGn9uypsNwPg+mF8mPkwPsx+GB/mPph5MPej+w/GB2lr
XJrhYLXlRNk+fQQfbA5vgMOqj5d8kyYg+OqGHGtkytDkI9Dk7RDmtb4O3CGn
ibAPxvdLEoiwbEHwQd5yXYbQD+PDzEeRL0OTn4AwD+Z+dP8BAE+I06Q=
                    
                    "],
                    CurveClosed->{1, 1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}}, {{1, 4, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgAmJ+KM3eONW5u8fb4fbPuqw9GzIcPl3yTRKwQPDbxW6e
+/7Zy8Fqy4myfbMRfP27KmyNjQj+Itdtn//6IPjVIuvcHxohzPumEdN/SDbD
AWYfjC8NMughgi8K1Fal4gPXD+PDzIfxYfbD+DD3wcyDuR/dfzB+/6GvGjHH
MxyKMya+rfnvBedHWAIN6oP6Zw2Cf9zbvNOxB8FXN+RYI+OE4IOkExQR5sXu
8uRhYkfYB+NrAb35VcIHznfpznn+u9MHrh/Gh5kP48Psh/Fh7oOZB3M/uv8A
zm7Z+Q==
                    "]]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}}, {{1, 4, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgAmJ+KM3eONW5u8fb4fbPuqw9GzIcPl3yTRKwQPDbxW6e
+/7Zy8Fyy4myfbMRfP27KmyNjQj+Itdtn//6IPjVIuvcHxohzPumEdN/SDbD
AWYfjC8NMughgi8K1Fal4gPXD+PDzIfxYfbD+DD3wcyDuR/dfzB+/6GvGjHH
MxyKMya+rfnvBedHgAzqg/pnDYJ/3Nu807EHwVc35Fgj44Tg+wClExQR5sXt
8uRhYkfYB+NrAb35VcIHznfpznn+u9MHrh/Gh5kP48Psh/Fh7oOZB3M/uv8A
zfbZ/A==
                    "],
                    CurveClosed->{1, 1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}}, {{1, 4, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgAmJ+KO3Fw6Td/s3Tgfv64gLbWRkOZnG7PHkWIfh2XEBG
rKdD6+vAHXKtCH61yDr3h1kI/tYTZfvmxyH4qz5e8k1yQZinytY41Vk/wwFm
H4wPkmby9oLzIyy3nCjr84Lrh/Fh5sP4MPthfJj7YObB3I/uPxj/9s+6rD0b
Mhy2ff57pSITwZ99RGFD0Q8Ph7c19qZx0xB8oeYDpxaWIvgga/cFI/hge40R
5hXYAgNCAmEfjH/4q0ZMf5MXnN8udvPc989ecP0wPsx8GB9mP4wPcx/MPJj7
0f0HAM/n1e4=
                    "]]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}}, {{1, 4, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgAmJ+KO3Fw6Td/s3Tgev64gLbWRkOZnG7PHkWIfh2IEas
p0Pr68Adcq0IfrXIOveHWQj+lhNl++bHIfirPl7yTXJBmKfK1jjVWT/DAWYf
jA+SZvL2gvMjLIEm9XnB9cP4MPNhfJj9MD7MfTDzYO5H9x+Mf/tnXdaeDRkO
2z7/vVKRieDPPqKwoeiHh8O7GnvTuGkIvlDzgVMLSxF8K5CDghF8sL3GCPMK
bIE2SiDsg/EPf9WI6W/ygvPbxW6e+/7ZC64fxoeZD+PD7IfxYe6DmQdzP7r/
AMlX1ew=
                    "],
                    CurveClosed->{1, 1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}}, {{1, 4, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgAmJ+KL3Iddvnv1PcHfTvqrA17sxwmCzBEsb31w3Oz33+
e+XHJjeHm+e+Bz9eiOAX2HJdX9yC4Lt05zz/7YngF4LkdRDmtb4O3CEnmuEA
sw/GB8vresD51xcDTV7uAdcP48PMh/Fh9sP4MPfBzIO5H91/MH61yDr3h5cy
HD5d8k0SmOEG57M3TnXuPuPqkDHxbY39VgQf7J4JCD7YPls09ZII86y2nCjb
9zsdbh+Mbxq3y5Nnkgecbwc0tiDWE64fxoeZD+PD7EdRD3QfzDyY+9H9BwDC
Ud9Y
                    "]]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}}, {{1, 4, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgAmJ+KL3Iddvnv1PcHfTvqrA17sxwmCzBEsb31w3Oz33+
e+XHJjeHm+e+Bz9eiOAX2nJdX9yC4Lt05zz/7YngF4DkdRDmtb4O3CEnmuEA
sw/GB8vresD51xcDdS73gOuH8WHmw/gw+2F8mPtg5sHcj+4/GL9aZJ37w0sZ
Dp8u+SYJzHCD89kbpzp3n3F1yJj4tsZ+K4IPtm8Cgg+2zxZNvSTCPMstJ8r2
/U6H2wfjm8bt8uSZ5AHn2wGNLYj1hOuH8WHmw/gw+1HUA90HMw/mfnT/AQDA
6d9V
                    "],
                    CurveClosed->{1, 1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}}, {{1, 4, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgAmJ+KC26zv1hlU2QA9f1xQW26zIceqfnCTV/CITzVdka
pzpvDnS4oHT7Z900BD9j4tsa+0oEf+uJsn3z7dDkFRHmfdOI6T/EmeEAsw/G
P+Zt3unYgeDr31VhazwaBNcP48PMR5GvRPBh7oOZB3M/uv9g/P5DXzVijmdA
7N0bCOdbbgFaFB7o4NKd8/z3SgTfB2hsQiuCfxFknxGCv7dksgQLH8I8iL/T
4fbB+HG7PHmYdiP4IY+Xzj6iEAzXD+PDzIfxYfbD+DD3wcyDuR/dfwDn09cI

                    "]]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}}, {{1, 4, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgAmJ+KC26zv1hlU2QA9f1xQW26zIceqfnCTV/CITzVdka
pzpvDnS4qHT7Z900BD9j4tsa+0oEf8uJsn3z7dDkFRHmfdOI6T/EmeEAsw/G
P+Zt3unYgeDr31VhazwaBNcP48PMR5GvRPBh7oOZB3M/uv9g/P5DXzVijmdA
7N0bCOdbgiwKD3Rw6c55/nslgu8DNDahFcEH22eE4O8pmSzBwocwrw/s73S4
fTB+3C5PHqbdCH7I46WzjygEw/XD+DDzYXyY/TA+zH0w82DuR/cfAOhL1wk=

                    "],
                    CurveClosed->{1, 1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    66.45700000000001, 196.11299999999997`}, {70.699, 
                    196.11299999999997`}, {70.84400000000001, 
                    196.11299999999997`}, {70.96100000000001, 195.945}, {
                    70.96100000000001, 195.738}, {70.96100000000001, 
                    194.36700000000002`}, {70.96100000000001, 194.156}, {
                    70.84400000000001, 193.99200000000002`}, {70.699, 
                    193.99200000000002`}, {66.45700000000001, 
                    193.99200000000002`}, {66.316, 193.99200000000002`}, {
                    66.199, 194.156}, {66.199, 194.36700000000002`}, {66.199, 
                    195.738}, {66.199, 195.945}, {66.316, 
                    196.11299999999997`}, {66.45700000000001, 
                    196.11299999999997`}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    66.45700000000001, 196.113}, {70.699, 196.113}, {
                    70.84400000000001, 196.113}, {70.96100000000001, 
                    195.945}, {70.96100000000001, 195.738}, {
                    70.96100000000001, 194.367}, {70.96100000000001, 
                    194.156}, {70.84400000000001, 193.992}, {70.699, 
                    193.992}, {66.45700000000001, 193.992}, {66.316, 
                    193.992}, {66.199, 194.156}, {66.199, 194.367}, {66.199, 
                    195.738}, {66.199, 195.945}, {66.316, 196.113}, {
                    66.45700000000001, 196.113}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    61.992000000000004`, 196.465}, {64.465, 196.465}, {64.551,
                     196.465}, {64.617, 196.242}, {64.617, 195.965}, {64.617, 
                    194.137}, {64.617, 193.859}, {64.551, 193.637}, {64.465, 
                    193.637}, {61.992000000000004`, 193.637}, {61.906, 
                    193.637}, {61.839999999999996`, 193.859}, {
                    61.839999999999996`, 194.137}, {61.839999999999996`, 
                    195.965}, {61.839999999999996`, 196.242}, {61.906, 
                    196.465}, {61.992000000000004`, 196.465}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    61.992000000000004`, 196.465}, {64.465, 196.465}, {64.551,
                     196.465}, {64.617, 196.242}, {64.617, 195.965}, {64.617, 
                    194.137}, {64.617, 193.859}, {64.551, 193.637}, {64.465, 
                    193.637}, {61.992000000000004`, 193.637}, {61.906, 
                    193.637}, {61.839999999999996`, 193.859}, {
                    61.839999999999996`, 194.137}, {61.839999999999996`, 
                    195.965}, {61.839999999999996`, 196.242}, {61.906, 
                    196.465}, {61.992000000000004`, 196.465}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    48.902, 196.465}, {51.379, 196.465}, {51.461, 196.465}, {
                    51.527, 196.242}, {51.527, 195.965}, {51.527, 194.137}, {
                    51.527, 193.859}, {51.461, 193.637}, {51.379, 193.637}, {
                    48.902, 193.637}, {48.82, 193.637}, {48.754, 193.859}, {
                    48.754, 194.137}, {48.754, 195.965}, {48.754, 196.242}, {
                    48.82, 196.465}, {48.902, 196.465}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    48.902, 196.465}, {51.379, 196.465}, {51.461, 196.465}, {
                    51.527, 196.242}, {51.527, 195.965}, {51.527, 194.137}, {
                    51.527, 193.859}, {51.461, 193.637}, {51.379, 193.637}, {
                    48.902, 193.637}, {48.82, 193.637}, {48.754, 193.859}, {
                    48.754, 194.137}, {48.754, 195.965}, {48.754, 196.242}, {
                    48.82, 196.465}, {48.902, 196.465}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    40.324, 196.82000000000002`}, {45.273, 
                    196.82000000000002`}, {45.440999999999995`, 
                    196.82000000000002`}, {45.578, 196.54299999999998`}, {
                    45.578, 196.195}, {45.578, 193.91}, {45.578, 193.562}, {
                    45.440999999999995`, 193.285}, {45.273, 193.285}, {40.324,
                     193.285}, {40.160000000000004`, 193.285}, {40.023, 
                    193.562}, {40.023, 193.91}, {40.023, 196.195}, {40.023, 
                    196.54299999999998`}, {40.160000000000004`, 
                    196.82000000000002`}, {40.324, 
                    196.82000000000002`}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    40.324, 196.82}, {45.273, 196.82}, {45.440999999999995`, 
                    196.82}, {45.578, 196.543}, {45.578, 196.195}, {45.578, 
                    193.91}, {45.578, 193.562}, {45.440999999999995`, 
                    193.285}, {45.273, 193.285}, {40.324, 193.285}, {
                    40.160000000000004`, 193.285}, {40.023, 193.562}, {40.023,
                     193.91}, {40.023, 196.195}, {40.023, 196.543}, {
                    40.160000000000004`, 196.82}, {40.324, 196.82}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    74.809, 196.465}, {79.402, 196.465}, {79.559, 196.465}, {
                    79.684, 196.184}, {79.684, 195.84}, {79.684, 193.555}, {
                    79.684, 193.207}, {79.559, 192.93}, {79.402, 192.93}, {
                    74.809, 192.93}, {74.65199999999999, 192.93}, {74.527, 
                    193.207}, {74.527, 193.555}, {74.527, 195.84}, {74.527, 
                    196.184}, {74.65199999999999, 196.465}, {74.809, 
                    196.465}}}]}}}}, {{{
                   {RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    74.809, 196.465}, {79.402, 196.465}, {79.559, 196.465}, {
                    79.684, 196.184}, {79.684, 195.84}, {79.684, 193.555}, {
                    79.684, 193.207}, {79.559, 192.93}, {79.402, 192.93}, {
                    74.809, 192.93}, {74.65199999999999, 192.93}, {74.527, 
                    193.207}, {74.527, 193.555}, {74.527, 195.84}, {74.527, 
                    196.184}, {74.65199999999999, 196.465}, {74.809, 
                    196.465}}},
                    CurveClosed->{1}]}}}}}}}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 480.}, {0., 240.}}], ",", 
           GraphicsBox[{{{
               {Thickness[0.0010416666666666667`], {{{
                   {FaceForm[{RGBColor[1., 0.717647, 0.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 480.}, {960., 480.}, {960., 0.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 0.356863, 0.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    172., 440.}, {304., 440.}, {304., 40.}, {172., 
                    40.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[0., 0.3372549999999999, 0.254902], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    40., 440.}, {172., 440.}, {172., 40.}, {40., 
                    40.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.5529410000000001, 0.12549000000000002`, 0.160784], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    344., 440.}, {924., 440.}, {924., 40.}, {344., 
                    40.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 0.717647, 0.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4g7HhKcX1Lodtn3+e6XiZJQDOj86xfq+f1C3
w0JXoAhLhIOPeadjQlO3g1+SQITlkzAHm/v+vdNPdjv0Ts8TarYIddhyomzf
/OgehzUyUSnW4aEQ+Zk9EPUpwQ6yQOH7j3scLEEKxQMdlhTYcl2f3ONQ+VLN
kEPGx+GC0u2fdVN6HBaB7JviDdE/o8eBAQQSPDD4YPVpPQ57SyZLsIR5OBxV
2FCUEdjjsPKYt3mnooeDfOvrwB2GPQ6Hv2rE9F9yd7jsC3SIao+D/l0VtkZT
N4j/XnU75D7/vfJjkZvDNOfunOeh3Q5TgKbx8bpD+NHdDrOPgAz2h+gL7nZo
PnBqoatbsMOnS0ADfbodLoLcsSgEEn5W3Q4g6x0zwiDuNISG15FwiPs1uh28
eJi0299FYIQ3Oh8AZG64MA==
                    "]]}}}}, {{{
                   {Thickness[0.0017714645833333332`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4g7HhKcX1Lodtnz+e6XiZJQDOj86xfq+f1C3
wxLXbZ//skQ4+Jh3OiY0dTsEJAlEWD4Jc7C57987/WS3Q8/0PKFmi1CHLSfK
9s2P7nFYIxOVYh0eCpGf2QNRnxLsIAsUvv+4x8ECpFA80GFJgS3X9ck9Dg0v
1Qw5ZHwcLijd/lk3pcdhBci+Kd4Q/TN6HBhAIMEDgw9Wn9bjcKBksgRLmIfD
UYUNRRmBPQ4bjnmbdyp6OMi3vg7cYQiU/6oR03/J3eGyL9Ahqj0OBndV2BpN
3SD+e9XtkPH898qPRW4O05y7c56HdjvMAJrGx+sO4UcD+UdABvs76IP0BXc7
tBw4tdDVLdjh0yWggT7dDldA7lgUAgk/q26HE0DrHTPCIO40hIbXkXCI+zW6
HXx4mLTb30VghDc6HwB57rhI
                    "],
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 0.717647, 0.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4nc19qZxnyochJsPnFroW+6Azvc273RMmF3h
MD1PqPnAv3KHjIlva+ytKxxynv9e+dGtwgEo+/TCmnIH2agU6/sbKxxmgNR1
lDlcrXipZrgKKs9TBlGvVulwDGRgRanDp0u+SQK7Kh12yLW+DpQoc7igdPtn
XU2VQ+wuTx4m8TKIvb1VDh0g/XxlDgwg8AWTHwdSX1wGcdfXKofyffOl9OeW
OWi1i90897vK4dBXjZj+O2UOHg+rRNaxVjuAnOn/tQxCW1ZD7Mkuh/jXsBri
7ikVDm9B4SAH5XdUOOSC3C9U5bDIddvnvzMqHO77907P06t0kAEZtLwCYs71
Ckj4napw4NPdNPd9agXEnfeg4cVXAXH/O6j5RzDDG50PALzvvic=
                    
                    "]]}}}}, {{{
                   {Thickness[0.0017714645833333332`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4nc19qZxnyochJoPnFroW+6Azvc273RMmF3h
MCMPKPKv3CFj4tsae+sKh5znv1d+dKtwAMo+vbCm3EE2KsX6/kaouo4yh6sV
L9UMV0Hlecog6tUqHY6BDKwodfh0yTdJYFelww651teBEmUOF5Vu/6yrqXKI
3eXJwyRe5uADsre3yqEDpJ+vzIEBBL5g8uNA6ovLIO76WuVQvm++lP7cMgft
drGb535XORz6qhHTf6fMweNhlcg61moHkDP9v5ZBaMtqiP+yyyH+NayGuHtK
BSQc5KD8jgqHXJD7haocFrlu+/x3RoXDff/e6Xl6lQ4yIIOWV0Dcex2q71SF
A5/uprnvUysg7rwHDS++Coj730HVHcEMb3Q+AL5/vik=
                    "],
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 0.717647, 0.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4g7HhKcX1LodhJsPnFroW+6Azo9Osb7vH9Tt
MD1PqPnAv3IHH/NOx4Smboec579XfnSrcLC57987/WS3g2wUUOHGCoctJ8r2
zY/ucbha8VLNcBVUfmYPRL1aJUTd4x6HT5d8kwR2VTosKbDluj65x+GC0u2f
dTVVEHpKj4M3yJ7eKoj+GT0ODCDwBZMPVp/W45Ax8W2N/dcqh6MKG4oyAnsc
tNrFbp77XeUg3/o6cIdhj4PHwyqRdazVDpeB1kao9jiAnOFvWQ3x3yuofw2r
HaY5d+c8D+12AJpmGicH5Ud3O+SC3C9U5aB/V4WtMbjbAeSMPL1KiD98uiHu
vV4BCT+rbgc+3U1z36dWQNxpCA0vPmh4aEDNP4IZ3uh8ADOCwEA=
                    
                    "]]}}}}, {{{
                   {Thickness[0.0017714645833333332`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4g7HhKcX1LodhJoPnFroW+6Azo9Osb7vH9Tt
MCMPKPKv3MHHvNMxoanbIef575Uf3SocbO77904/2e0gGwVUuLHCYcuJsn3z
o3scrla8VDNcBZWf2QNRr1YJUfe4x+HTJd8kgV2VDksKbLmuT+5xuKh0+2dd
TZXDBRA9pQdiT28VRP+MHgcGEPiCyQerT+txyJj4tsb+a5XDUYUNRRmBPQ7a
7WI3z/2ucpBvfR24w7DHweNhlcg61mqHy0BrI1R7HEDO8LeshvjvFdS/htUO
05y7c56Hdju8q7E3jZOD8qO7HXJB7heqctC/q8LWGNztAHJGnl4lxB8+3RD3
Xq+AhJ9VtwOf7qa571MrIO40hIYXHzQ8NKDmH8EMb3Q+ADUSwEI=
                    "],
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 0.717647, 0.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4nc19qZxnyoctn3+e6XiZJQDOt/bvNMxYXaF
w0JXoAhLhEPGxLc19tYVDn5JAhGWT8IcgLJPL6wpd+idnifUbBHqMANIHego
c1gjE5ViHR4Kkecpg6hPCXY4BjKwotTBcsuJsn3igQ475FpfB0qUOVS+VDPk
kPFxiN3lycMkXuawCGTfFG+HDpB+vjIHBhBI8MDgx4HUF5c57C2ZLMES5uFQ
vm++lP7cMoeVIIsUPRwOfdWI6b9T5nAYRF9ydwC66r7/1zIH/bsqbI2mbhD/
ZZc75D7/vfJjkZvD1QqgQ6ZUOEwBmsbH6w7hd1Q4zD6isKEowx/irhkVDs0H
Ti10dQt2AHnz/vIKh4tKt3/WLQqBhN+pCog/M8Ig7rwHDa8j4RD3v6tw8OJh
0m5/F4ER3uh8AO3bthc=
                    "]]}}}}, {{{
                   {Thickness[0.0017714645833333332`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4nc19qZxnyoctnz+e6XiZJQDOt/bvNMxYXaF
wxLXbZ//skQ4ZEx8W2NvXeEQkCQQYfkkzAEo+/TCmnKHnul5Qs0WoQ4zgNSB
jjKHNTJRKdbhoRB5njKI+pRgh2MgAytKHSy2nCjbJx7osEOu9XWgRJlDw0s1
Qw4ZH4fYXZ48TOJlDitA9k3xdugA6ecrc2AAgQQPDH4cSH1xmcOBkskSLGEe
DuX75kvpzy1z2ACySNHD4dBXjZj+O0B5EH3J3QHoqvv+X8scDO6qsDWaukH8
l13ukPH898qPRW4OVyuADplS4TADaBofrzuE3wHkH1HYUJTh77AI5K4ZFQ4t
B04tdHULdgB58/7yCocrSrd/1i0KgYTfqQqHEyCDM8Ig7rwHDa8j4RD3v6tw
8OFh0m5/F4ER3uh8AANqti8=
                    "],
                    CurveClosed->{1}]}}}}, {{{
                   {Thickness[0.004633204166666667], 
                    FilledCurveBox[{CompressedData["
1:eJxTTMoPSmJiYGDQZ2RgYAbSDEAOIwMjMzOQhDCIRPjVw2WJN5ZIlQSVUa6A
bPVoKqnud2JMINsNBGONoMn4FVArXkhyJIWxQKqbKYxHAMnLCKY=
                    
                    "], {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4,
                     3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}}}, {CompressedData["
1:eJxdW3mcT+UaH0v2O8mSJblZwkXkhgm58wppoYT8fsxqFmMs8zu/ddDiLL/l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                    "], CompressedData["
1:eJxdVn9MlVUYvlErhsQynQNaJmSNQoP+YGry4yUqRswRtgxDrkYQrtn1O59O
r2XZPae7m2tpyIxWmXlTzDBWJkiuQQNDsVYUmBVzIv1gXQrQrOUs1znnfeRr
sbFvz33PeX887/O+35dWvXpxbZzP56vX/+Z57utF1deVKdrz+pFZ7x9x6DJe
cPDYuo5Bh1bW/7axYK6iH8yBVEE+8zdF0djGghz/3YLPT0hKmntgx/ijgsy1
naOSnhy5uO9staCuPzKWbdU4PFrePrNEUNvv/wwENbb30gU98fHahuTvJd0e
mfHdF52I1+9hnZW78ksP32Qc9UryHy5JjOt3aOHpspcaeyQN6Ucg5lDWqdlX
h7qRzxWI1ybpRPCXW+/MFtRq8tsnOU65oOGnprcUb5P0SI3xJLjO5yRNU58c
3/WQoPUdO1OzVku6yxSWJmi3k5dwslySuXZmzKHNhSt+6rvHw02Gx0IP2/o0
Plo6b3NhAvIpknS98Z8paINOK/4+SdeafMuAtb/GgD6xSpCuMjOSLzmPNYLy
E06+7SwAnxsEnTGBciQ1JF+1JGm9h20fAv+zV8JfouS+XHLolaIXV41c6WGT
5gqfhy3/F0N8P0XQjYaov0KUZ/MQNKDbWPFniDJNf5ZCD+dwXvNpeR0PMd/N
gnJNv34NcZ96BfvX56P3amYOChrf21M67+8Q8/0M/CWhXynoX5qkvvTBC88u
wf056G8Q93OgvzcE39O4xxT2jofNtfoPBdc/H/W2C+o39eRJ5kHbXzV9KIT/
FsG6KoYewuhXqWQ+dP3GvPcBSU+b/scLCpq+PS5ZV/Nx3oX+F8PfJsk6Wgt7
GPHDuL8F/qKC53QLzkehx7ckz+XzuN8sOW8X5w8jvxLMZzf4yEA/PpdUZebp
GszjCUntM7XCtH4tL99gPs467P9b2M87/Psg+jED+jiF/PPQnyHEq0E+w5J1
rOvbbvgfhr4jmLcfUd/LgqZW6E10s2L+86GnhYrjTxdc1/2K411w+HyF4vkY
cVgPldhnow73p0qRUYF/wqE5Bi9X3I9kMYltX4o8bPl9AfwuUzzPr0FvxYrz
6MS8ZcEeA993KPrK8BNDPbcorvMzQZWmnlRF3YbnKOyJiPcfbPVz3MO23hHM
82nsj4ddtvd72O7LPg/bfI+C7wKX8+uQPH+zXK6vDfqJg7/90GsM+ngXeo5h
n70pJ+s1bWn3SzKyCgRd3mN+3N/mYauXJpd/fwzzvculCZNfAPltctnfOthr
XdZPBPst3+U+NcB+G+rdj3m4JBi3Il68y/3plKzTStTbhX28Bvn1YB4iLuuw
18NWzwMetvtjCvQ2FflOU5N82fm5QbGfLkHZZu+lob9j2C8Zip/pLj+zFecx
2+V9lKvYz3nMR6FifofQj6WK+WgTdMj0Qyjeb43Qyw7obTnmr0mxHrTdvj+b
kf8h7NsDivVwDP5bMT+d2L8fKebvA9hbMC8PCvrUBN6jqNgQXQD7bnxf5KIf
2xXP/yLkG1a832qwD+uQ/1bBvNUh/yLoqw75puB9WKv4ffuzw3GqMY/92E9V
iPee931jeY56+PL3z7/RviXx
                    "], CompressedData["
1:eJxNVGtIFVEQvghJSJaZRNjLykyysJISNXO0h5SaFP2w0BRLEjG7OItdNQrP
wVRCzIJUTMxXIkRImNrLxExFKKSMKLKLRNjLTEVIQuqMMz9aWA6ze84332N2
16WeO5rmYrPZDpib1tyvftsXZiuYehWX6uGHEBtcEpkSrsBG10Wpdyr41FTd
63MN4eAil4CiXQo2Fy1/9/IRwtKEkLaBYAVvHAboC8JEc19McJiCGDr3RGqD
17mm8PuRRoT08vELETEKiiNTPg8Z/MVb79VMJCo431XrHXhK9ucrfh6EUEL7
ShUkPTSdk5F5ViogOq05CM9m/BPLbinI97obPWr4rTVtOk29THcP1tUgJJb1
zPjXKQggvg+QzzUoCHd722DvQHht4BL6Ffi0ZqeX5yLM+zGmGDdK9Jq6nwRF
Cf8fwi8NYdWJ02HOnwpC2wZyunJFz7joqUVw0PpNQf3+9um5TtHjFL9tFjTa
DZNRBZVZnrrbzYJD1G9SgTvhOIXfrPAZFPwFGpzxpRVZdxA6pueGHe6a9d9E
CKMX3pr1FiD0krCVmvNRCEQ33kdDBfUzeWQ8tq6v2KChh/ANvz3ky0YNZ8f+
tEx+QNg24utaYOr5dQbhvpFZa+r5eVhvwS/KK0pz3qMIN/ZeyRxL1KyzUfgn
az5XjxBIOGc0+/8UYTTPEM8UPUNS2zX7PCvn7cLf2+JzduG/z+I8szXjxlus
x6FZZ4TFPAs09BFBXwsayO88zX6+R0ii+cjQEEL5VUteJzXjZiG0k7+HNUQT
MZPnMPEJ1TzPHxG2mDiag6TfCDIvP83zUIXsq8ljNW04jkCPaz01z8Mx2e8q
fl6W+f6reH8Twm4yZk6+x3qZ59+K/UmW/KZkvryQ5+iF4hzjEJ5T/i0y/4WC
X6XgNulLkfqqYn9ipV+xvN+B7HexzOMmZJ6mntflgZz7JfkfLBG8//4n/wAn
LwFL
                    "], {{648.8359999999999, 326.855}, {646.438, 
                    329.01599999999996`}, {644.7850000000001, 331.074}, {
                    645.164, 331.43399999999997`}, {645.543, 
                    331.79299999999995`}, {645.9689999999999, 331.895}, {
                    646.113, 331.66}, {646.254, 331.42999999999995`}, {
                    648.215, 329.367}, {650.4649999999999, 327.082}, {
                    655.6519999999999, 321.82}, {654.586, 321.672}, {
                    648.8359999999999, 326.855}}, CompressedData["
1:eJxdVGtIVEEY3RYTMZNNIkVcsyWyB6VFYGLSMRWTCKkfISolS8JSZEvcqS2k
mLmEKISIhVGE1VaSREhtJhEWPVT6IZI9aM2sNOxBmaaklNTMnW9bcGG5fHNn
znfO+c7cJe4DOyrsNpstX/7Vs+3nzHPfS44r5x6ntH43YFO/JxzOkj1Zg06G
H82dWzM6OU583d6enM2QHf3K7+3nkKs1OV4GR3FmoPsLx+GOpsS00ww1OeUf
e8c4utT7swwbB4tONsYIfa6BYYHa7xRoSIjYGVvH0FgZZz7YLHBV9Q/h7RKY
v/rm+dEihiFF7LjQz5WEd0HgjDrnYCiMsa+qvivwTi5XRjNUL3rd86tX4FK+
VBbB0LfN7SgeEtg/8vvamD1cW/rmhmuLdxTT+oNC60llCHQf6mjqIf6FDA8n
l5fV3RK4rdalPsu/gICCK/LT+T7Sc5ChVK2PE1+QP/Gm1rOO8PaZ8NR/q9qU
QXinTGx5f3ThjUyGxcr4KlPz8JDeUlP728I0bgXhtTKorp5aE72u/uljXvL7
uqn7ric9LYSXzvBBtilwm3jh+7xsrYvwc02MP5PGJNG8XYSXQv5GUr2G4bJX
7hgQUHTKc5nW8YbmK+sjEjZqWCBtYGkkTyX8TwKS9dOL8eTHKPkp52f5PhGu
rXlPzXr/R+CR8s0eri0fpoz/tZWHoKF5+YnPpIFYlSuf0PpCeuKF9lNQHucR
Xi3Tc5zg2p8q0jvCtd8GnQ9yKJqVZaQvdJ/yyP8ujnSlP9T/L9f5vmNg7z2j
IUH2t9ZnDO2HvB9WvzjyM4nyn0LzcFBeNzComBTYyJ8S6jeH8rqbIUsRk/gq
FvXyPln9UgXak2Ww8si/FdR/2tD3L1Fo/m8NnY9owrtvQG1rHqb7321g9vfj
H3Wl+0g=
                    "], CompressedData["
1:eJxTTMoPSmViYGAQBmIQbct1fXFBSLPDTrnW14GbSh2iUqzv+3s0Q+iTpQ6d
jglPLwQ2O+Q8/73y47lSh/J986X0O5odckH8C6UOYP2nmx3076qwNV4udXhY
JbLO/UuzgyzIgJelDts+/71SodLiMD1PqPmAWplD1p6SyRLeLRD14WUOh79q
xPSHtkDU+5Y5THPuznlu0AKxX7oMop+/xSFj4tsa+7dQ991udrDacqJsH9B9
7WI3z31fAXXfvlIHm/v+vdMnNDt4gByyE+r+kmaHB0DhPKD/3i8/5m2e3Qxx
z7pSB91Nc98vT2x2APp+h9zqUocjChuKMsKh8mug/kMKHwAzJJYO
                    
                    "], CompressedData["
1:eJxdVGtIFFEU3raIkpAeIpFWJoE9FNMyk7Q9lmJlKho5s45uu+O+lDJ7kFEm
Rtw7SYlJ5QMpMzMpRCKWEPOFlmlBiAYSi4hZ9qMiI7IkpO7dc3GhgdmZs/fc
73znO9+dDeqJDJtep9MlsZs/8zvO3FhdRUDHr20yFHXVrwl3EaguWHm555UM
seNp5dUD3vWRFHW5PEkgfGzj4ks2CZrqngc91lPYd/XYpz95ErDolDOQQhpL
i4mVwTVwtqs+hMJfflXLsJ58Tm+LoHDaWfm1eFSGK/Hmj0ORFJ7+mHt7blCG
Kg60ncKX9LZ15JmId4n8Ihl8w57c/hZHwWe0sTAuUoaJ836tSQkUTO0Hlund
EvJLpzA1FOyebZUw30nhoiHK1N4gwaHosngzEfUqJeyrXOA3S5Bl3T2eViPw
t8iwQo5xDTRR6GQyLeqXIZnv76Mwsym7ojdMRhw/DdyzJfkd1zIhlJVrNmi4
f68McfwlQIMALthDBest1UDzf/fmV24OTHIBV2lwL5EhZZuAdbFVS9XgJS+0
3wy9P1khhwZcpuBuM3jmVawhnz2W+TgkYklLoOqN1/JG6izIr0iDI1yIRgvk
VDDETFHvrgXyWNuGnRqw3yjTHQvqHaohrxYLPgNFvRkLlHEiOtFfgYr96TXs
67eKfQUJPa7n4jxiNLjAxjThY0V+vqK/UisoXO8ZCt3MdmM9VvTPawqrmPsa
jDb0YSvFfkZsuF4g5jNlR37hFB59H05RnQ70o5sAY3F4kjhwfyNBvFoH3C/k
jAnmT9uRL4s9eP52OMj17yRQzjcm2HDeCylwexgmchEvg6KPUlT0i0yhhv/v
q+K5UIQ/5o7CdHN/crSJIl5pNuIkCf7DCnCbljD/e/TaoWA/m0V+kILzmiLo
3wUK1n1AIJXL+iELda8leP4Gs+A9Pw+UYJ3ELHjB9TpOoIHP+6YR8+1iPcqI
+psIJPD98TLqYxT4Lgn9rIjzfkvCeTu9sQfvpDfu434lZP48/v99+Qe+3O82

                    "], CompressedData["
1:eJxdVGtIlEEU3SKyLKWHRQ8TszJ7qohEmXmzRDPDHuqPqNhvx91ZNEsyCuyb
AemlQpmFJGlIWdFDxR5GVFZU9ISwB2RYbGbij7DSUjExmpk77RctLLuHuXPP
PefeudMd29c7h9psts3iK383ZsZ4Ut8ymB05oibwhB0iPswcXtDO4NDxbeP2
3rPDsUnDMvy7GHSacdFbflt48bUnu+7MMLz48epFRcs3GZDUmh9QN8ggdHhB
2YpsA+NiONytmhL+wTQwzwGOfEcNuN8TtqkkjUO45G01INb3bXXuZA5L5L04
B9jkJ4CDTG8vckDb2YqHwUk6vkifmxb2X3Dl5LfXHFJkfI8DlL5WDvu/rLsR
lEAwroPDKEETm0VAiHx2qk3zVRBoCmnp5806voEg7y0OGTJxHwEZVrWPw3h5
r5PASxmfz7GOMwSC63e4S7drvWkE3KVC8WYOuVKYwHMPTnz3IopDvL29KaSa
wDKpt4chz+RMzPOTwbsXfRva/JyQ0zFwoSuCw6WuV2sclU7kXcMhTyb2OPGe
wNOk0DYnlMu2hen657jQzyEc0mX9eS70Q/R3luyPD8V6+hj6MZd6+6f8i6ag
xiCQw2H5Zz6FPQF1ia1LOfo0kcID2b8sjvn6XNhP0Q91r9eF9ZVwuCjrD6Bw
I0hU9oSjvhwKDdLPYg6nE67/GPxI0a9w7fdjiv766n42Uqx/gHnPu0XaMb0M
egXt/U6Nuxnm9XWjLy8Z8ke4UV8tQ5/i3ejvVgY7JDFxoy6Bt9xcNXroP1jV
O9LCag7PU9S7luEclVHs/1TN94Zi/HcTSmSgjxt9eWTivHmoF6u+77Ow0r2Q
YlyXCY+kkcMo5Ev/l+n36q/15mv9EyjGmRo3uvB8JYMjkj/OBYlS/9/6PjsR
x2hc6MT3nK3fs82Jc0QZNO4UJ0GZ6H8UwzmsJXBO2FDvy/BdpRPkE3qVP5UE
8z03QY5h7G8CnlSxWcpN3AviPan5KTbR7xKC81pgwle5J5IJ9qdQn88j+L6v
6nyfHCCmor2pycQ5u+zA+F+mdx+ofoxlXqzqXmVhxZfIcO4iHbD7jni4flp/
s4F99Zg4T2JfKX2hDN7386zbYp8p/hQGLRLnGt75UP3ZaOFX8jfZwiqfv4F+
ntT+p9nxHdRYWPFdt7Dy86nev3l2+H9//wHKOZ9v
                    
                    "], CompressedData["
1:eJxNVWtsFFUYbRpDGi0E26YhgstDRSwh5WVMRfCIBVQkaAlo5BHS3YGZO1Mo
FUoVvDMbIg8JtBUNAsHyEBOThodKKWhaUgoFf/CQWm1lgaaxlSglUG1jGhLv
d7/LLJtsJmfn3u873znn3h1ZuLLASk1JSSlUX3o6lbfXv1wT4OO/3q6NHI9C
45YACwaN+3ZvVxSvp6eO3TQ0jkd/PVg89edYiDsO7WkckW6FWO16fknEQuOI
oyV2WhxXRv3+nyyx8MGt0RPS7gZYfEqtbLLw5HuxKTfqAxyYUdNzv2wZ3nxh
yytLPwlQPFV1+Go511sf8Lp5Nugxd02AZwbEP3/1iM31Cwy/2Q7zuOkz/wsC
3cSjTaK+6oncRKMHr6v/m7vbJY6fL62r+tLDNBrEksjccPqn/Vs8qO5/XJ4o
MYwarfVwY+62nSsikvsprPv3f8Tzl3qgtncUfnZCWvWwEo/r5ki0Xuyb1/Gc
x7wXmvoJl+fcJ/EY7c8x+zskz7vaQ21EMe+UzH+Nh4Z/xywq75awyYc8D7NJ
nx7J/bM9FNE8f5r6rS7zbZHcp9rFZdK9UaJXlWmIuzhJ9U9JqF/Fj2+5yPte
Ea6XrBtcrK1TQp2VqKDGuS7z+05i+84VGRvSXRDN4l2S/bwnmK8t2e8GgV/K
lMEzJc/9lGB+XhJrXcuTWOt9zfBrF9zvqkT+VuXUSJfnvSSxLuvwrPbpLsju
yiuGf8zl/b8ZvYpcEM3TvRJNtLHC5X3/SExXy0b1i1Af7c8xEepDMlRtFKE+
GaTnfBHqo/OTL0J9zlH9ySLUR/N8XIT6lJN+fQ7XVfqUkIFNJp9KnzbiP8a8
95JY8/40iXX9hOR8XXc4D80P9BGY1f5h1uFLhu8MEeqTm3h6QNwRoT56/SrB
ufj7Qd6NH30SKfTJEthM6ztNPtscvEb1EyYPPzgYuym79WLC5LHSwY4hjywY
1CXxIg2y0kEOve8z52WSE9bTPtTZGEjzNEl8QT7ttvG1kuOo0ns0rd9q8zxn
JK7R/J7N+ncYP1+y+Znhsx69y9n3TJ/rdSexnrN2WYj1+hqLczrEZ37vW5zX
8T6fp5kW83zDx3wSPtNiv+f47N9DWOuVn8T0SJRZ7MM6n/U9abF++5NY169O
4iV0D/b4Jt8WIppwwOfhWAyLKEj5Ad4hPsNjuDqncPC7bsD5OhjlvJUG7M+e
KE703G8uiwfMd0cUZykQ2wKjbxTanoqA+W429/lnAZ+DjVG+3w4FfG/uNvf/
Q/8H/wPhWdiy
                    "], {{484.76599999999996`, 196.805}, {
                    484.76599999999996`, 199.41}, {479.387, 202.195}, {
                    472.953, 202.918}, {467.758, 203.5}, {467.672, 203.465}, {
                    467.672, 200.871}, {467.672, 198.72299999999998`}, {
                    468.48799999999994`, 197.879}, {472.074, 196.316}, {
                    477.83599999999996`, 193.809}, {484.76599999999996`, 
                    194.07399999999998`}, {484.76599999999996`, 196.805}}, {{
                    490.66400000000004`, 197.04299999999998`}, {493.289, 
                    199.42200000000003`}, {494.53099999999995`, 202.254}, {
                    492.953, 202.254}, {491.137, 202.254}, {486.32, 197.93}, {
                    486.32, 196.30100000000002`}, {486.32, 193.758}, {487.215,
                     193.91}, {490.66400000000004`, 197.04299999999998`}}, {{
                    485.07, 204.75}, {485.29299999999995`, 
                    206.22299999999998`}, {484.383, 207.20299999999997`}, {
                    481.65200000000004`, 208.43800000000002`}, {475.77, 
                    211.094}, {468.734, 212.324}, {467.039, 
                    210.99200000000002`}, {463.91799999999995`, 208.539}, {
                    465.9959999999999, 205.24599999999998`}, {471.039, 
                    204.65200000000002`}, {473.07, 204.414}, {475.824, 
                    203.797}, {477.16, 203.277}, {481.03499999999997`, 
                    201.77299999999997`}, {484.72299999999996`, 
                    202.45700000000002`}, {485.07, 204.75}}, {{485.07, 
                    212.63299999999998`}, {485.387, 214.73}, {484.043, 
                    215.48000000000002`}, {473.08599999999996`, 219.34}, {
                    464.90599999999995`, 222.21899999999997`}, {
                    461.28499999999997`, 220.859}, {463.89799999999997`, 
                    215.895}, {464.809, 214.164}, {466.34000000000003`, 
                    213.375}, {469.76599999999996`, 212.859}, {472.316, 
                    212.477}, {475.801, 211.73}, {477.508, 
                    211.19899999999998`}, {482.074, 209.781}, {484.715, 
                    210.281}, {485.07, 212.63299999999998`}}, {{490.562, 
                    220.02}, {492.215, 221.695}, {493.566, 223.672}, {493.566,
                     224.414}, {493.566, 226.816}, {487.039, 222.562}, {
                    486.207, 219.617}, {485.207, 216.08200000000002`}, {
                    486.824, 216.23}, {490.562, 220.02}}, {{485.074, 
                    220.516}, {485.43399999999997`, 222.906}, {481.457, 
                    225.062}, {473.637, 226.72299999999998`}, {467.902, 
                    227.941}, {465.371, 227.25}, {465.801, 224.586}, {
                    466.03499999999997`, 223.129}, {467.945, 222.066}, {
                    473.367, 220.375}, {482.039, 217.668}, {484.648, 
                    217.69899999999998`}, {485.074, 220.516}}, CompressedData["
1:eJxTTMoPSmViYGCQB2IQrX9Xha3xdJ1DgS3X9cVfchy02sVunsuud+g/9FUj
pjnXweNhlci6ynoHNbbGqc6v8xwuKt3+WfeozuGbRkz/Ic98B8stJ8r2La5z
WOS67fPfgnwHd5D66joH2agU6/vRUH5ynQOQdH/Ilu+QMfFtjX0gVP/RPAfF
DUUZE2PrHCaA7PPPc5ieJ9R8oAzBB6uvR/CvVrxUM2yrc/A273RMsETwtwKd
MV8OwRduPnBq4cJcB5C3CibWQtyXkeswWYIljE+31mEGyJ5zuQ5WIPdz1kL8
9SnX4YF/7/S8XzVw+8D+E6+F88HhoYvgV4P8ZVPrcPPc9+DHa6HyhrUOQNOy
9nzIc3hXY28ap1QLCQ/vfIcLIHu+1DgUgzyWnQ8R31gDCX+PfAchkLulaxxc
unOe//6ZB4kP+RqHffOl9O/OyHUA+vrphR01DnG7PHmYmHMdjoECwqzW4fHS
2UcUOnIcQMb5e9Y5FILMa8hxQI9fAIGY6Mg=
                    "], CompressedData["
1:eJxTTMoPSmViYGBQAmIQbbnlRNm+9DqH1teBO+Q48xwmS7CE8RXWOczIE2o+
IJXnsMh12+e/OXUO3zRi+g+Z5jnYcV1fXBBb5wCibP3yHLzNOx0TrOscwOY0
5zmU75svpW9b51CUMfFtzeU8h8NfgRqToObp5TuAlM2vq3NQZWuc6lyc73C1
4qWaYRPU/Jv5DlrtYjfPddc5yEalWN//WOhwQen2z7o5dQ65z3+v/JhT6jAd
ZM49qHu5Kxw+XfJNEjCrd+DT3TT3/eoKB6Brnl6IgPJfV0Do4HqIPW8qHB4v
nX1E4VcdxJ/rKxze1tibxrXVOeyQA5qYUOFwDOQhvToHK5BDf5ZD9D2odYjd
5cnDlF4Osd+n1kEb5M7AMgeFDUCfStZCwulOCZwPdt/BQjj/Esgfv6D+l6mF
2NOSD7HfrBYSHvr5Dh0g9/vVOlwEqb+XB3FvQK0DkJe150CeQw4oHOyg5mXl
QcLLuBYSvkZ5EPfp1TqAgt/+b66D+8MqkXVAeXB4fs6F2B9S6wBUdWrh1lyI
/S51DuqGHGtkjuU6oKcHAMJ3/wg=
                    "], CompressedData["
1:eJxTTMoPSmViYGCQA2IQfVRhQ1HG1UaHY97mnY5hRQ7TnLtznl9vdODT3TT3
fWyRwxXfJIGIS40O0/OEmg+0FDl8ugQUONnocOirRkz/miIIvavRYeuJsn3z
XxU5zACp29LoUC2yzv3hlyKHrD0lkyUWIPi2XNcXF8Qj+J48TNrt3xscls4+
orBBr9gB5IyEngaHqxUv1Qz7ih0uKN3+WefXABE/WuzwGKTQsgHijkvFDvKt
rwN3GDY4MIDAkWIHgQjLLSfkGiDqFhQ7ZE58W2Nv1+AQtwtok3exQ7vYzXPf
8xog/pUrdqjYN19Kf1YDxB/fihwqgdZyCDc6aIMUHi1yiO0Hyngh+GBzsxB8
magU6/tAfu7z3ys/HipyWAbyR0Sjww45oMP6ihxA0v7ejQ7AUDm1ML3IYdvn
v1cq8hsdrLYAAyy1COKvZmj4phQ5LC4AhtC8Roi/44og9JpGB15QfIRD3Xeh
0aHDMeHpBTeofiQ+enwCAHk04P4=
                    "]}]}}}}, {{{
                   {Thickness[0.004633204166666667], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], JoinedCurveBox[{CompressedData["
1:eJxTTMoPSmJiYGDQZ2RgYAbSDEAOIwMjMzOQhDCIRPjVw2WJN5ZIlQSVUa6A
bPVoKqnud2JMINsNBGONoMn4FVArXkhyJIWxQKqbKYxHAMnLCKY=
                    
                    "], {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4,
                     3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}}}, {CompressedData["
1:eJxdW3mcTlUfH0v2d5IlS/LawovIGybkdWRJRQl5HmY1Zox1nvusgxbPvffZ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                    
                    "], CompressedData["
1:eJxdVn9MlVUYvlErhoxlOgdU5iVrFBr0B0uTHy9REZojbBmGohGEawy/8+nw
2i+753R3s1aGZrTKzJtihjEzQXINGhiKtbIuacWcQD9YlwI0aznLdc55H/la
bOzb+51z3vO8z/O87/38lasWVcf5fL4G/W+eZ75eWHlliaKmNw7N2HvIoYvx
7fuP1Hf0O7Sy4bcn82cr+mGn3pAqyGf+JinSb7Mr7hC8f1xS0ux9W8ceFmSO
bRuRVDt8fvfpSkFdf6Qv3ajj0Ehp+/RiQW2//9MX0LE9lybosY/XbE7+XlJG
eNp3X3TivqgXa1Tuyi+9+DqTqFdSxcHixLioQ/NOlbzY2CPJPOpiDmWenHl5
sBt4LsF9bZL6Ar/ceGuWoFaDb7fke0oFDT0+taVok6SHqkwmwXU+I+kq9cnR
7Q8IWtuxLTVzlaS5pjC/oB1ObsKJUklP6GODow5tKFjx07E7vdjyWODFtj4d
9yy4bUNBAvAUSppi8mcIWqdhxd8NvCWIdb7X6jSCWkG6yoxwnqR6g2O1oLyE
E+84c8HnOkGDBn+2pFeSL1uctNaLrQ51/1svR75EybpccOjVwhdqhy/1YgNz
hc+LLf/ng3w+RdC1hqi/gsAhqE/LWPZnkG42+iyBH85gv+bT8joWZL6bBeUY
oX4Nsk69gvPr/ZG7NDP7BY3t0kz9HWT/PYV8SdArBfr5JX2V1n/u6cU4Pwv6
BnA+G/57U/C5bPD/rhf79bGGDwXXPwf1tguKmnpyJd1reNDrVget33GTv0Ww
TkWS8YWg1wLJfOj6zfKu+6B/vKCA0e1Ryb6ag/0u/L8I+dZLet74aA3WQ7g/
hPMvSTIyDkYEmTR7dWx9F4Ef35bcl8/ifLOkRoPbxf6DwFeM/uwGH+nQ43P0
0xXox28ktU/XDtP+tbwcR3+cdjj/t1g/6/D7fugxDf44Cfy50GdA0mFzXxXw
DAGPrm+L4X8I/g6j334EHy8LmlymO+96xfznwU/zFN8/VVCuyTNf8X3nHN5f
prg/hh32Qznm2YjD+ixTNGrm17hDs0y8XLEeyWIitroUerHl9znwu1Qxf6/D
b0WK6+lEv2ViPQa+b1HMTwz13KC43s8ElZt6UhXzHMF6Iu77T2z9c9SLbb3D
6OdTmB8Purwe9WI7L495scV7GHznu4yvQ3L/zXC5vjb4Jw759sCvMfjjPfg5
hnn2lpyo18jSXiFpwMzjgMt5KnB+kxdbPppcfv8I+nu7S+MGXx3wrXc5Xz3W
q132TxjzLc/lujZj/SbUuwf9cEFw3Ir74l3Wp1PSNcZI5ai3C/N4NfD1oB/C
LvdZrxdbP/d5sZ0fk+C3ycA7RU3wZXW9WnGeLkFZZu75oe8o5ku64nvTXI6z
FD9nujyPchR1mzxn0R8FivkdgB5LFPPRJuiA0UMoMjAbGuGXrfDbcvRfE/yt
1+3vZzPwH8C83afYD0eQvxX904n5+5Fi/j7Aegvy3S/oU3PxTkX3GKLzsb4D
3xc50GML+mUh8IYUz8sqzMMa4N8omLca4C+Ev2qANwW/h9U4/7PD9VUifxTz
aRni973vG8t3xIsvfv/8C0mFJgw=
                    "], CompressedData["
1:eJxNVGtIVEEUXoQkpIeJRNjLykyysJKSNPPT3plJ0Q+LTRdLEhFbPBfxEYUz
mFqIWZCKiflKhAiJUntZmGUIhZQhRbYtFfYyUxGSkJrZOT+6cBnO3plzvtfs
stSTB9O8bDbbTvXqNe9r8PqZ2QLjLxNSfYMJ+yJKYx3RAjb9nOZ6o8DH5pqe
wIuEPbO8Qos3CYQWz3/z4h5hXtLmW88iBAZyVaMvhNGWp/ERUcKce8C16te5
pOj7gSZCesXIqZh4gXOxjs/9qv+ctTdrR+0COV11AWHHeH+BML+HE0r1vjKB
5LtqcgoZnFUC1xScthzC48kQe/lVgXz/G7vcCt9SNaZT1X7yUV99LcFe3j0Z
Ui+wWuO9Q9A02hoFtvoMNjo7CK9Uu6RegcC27PSKPIJHj2GBbt03jvmqWqEq
jY1j/D8YXxph0ZHjUa6fAkqFnK485jPCfOoIuXr9JtCwo31iupP5uFhvm4Um
Z7TPoFugMksh9rGwV88b4/4uxjfFePq4/wyJD4lllVnXCR0T0wO5syUKNP8r
hCiX+hAgDd9CQo8mtlDitfZHEDTcxECJKj1P+ZFx37q0YIU0/RU+jy4rJTKH
/7SOvSOsGwryLlR1mF4nCbcVzTpVe/Kw3MIv7VecNH67CZe3nc8ctkvjbxPj
T5HQ8tQ1kOlzQpo5DwlubVwm8+nn2imNzlN83sn4AyxE63NOxr/dMn5mM75E
y/DJlYZnjGVwFkr0av+CLDRqvfOZ71vCUZ2PDIlIDbCG/UqWJl9ZhHat736J
3RqY8nNA44mUJs/vCWuUHS3hPG+IjI/B0uShmswc5YcnJ4fJ6OAnTR4O8X5v
iU8a51nO91+BxXp/M2GL9nOa72MD5/m3MPqksH/jnC9/Mro853wnEJ5o/1v5
vhZx/2q+Pw6uLwijzz6eV8LfN5DRu4TzuIqMniWcR1+CPuY4w/3ncr///k/+
ASkHAVA=
                    "], {{648.8359999999999, 326.855}, {646.438, 
                    329.01599999999996`}, {644.7850000000001, 
                    331.07399999999996`}, {645.164, 331.43399999999997`}, {
                    645.543, 331.793}, {645.9689999999999, 331.895}, {646.113,
                     331.65999999999997`}, {646.254, 331.43}, {648.215, 
                    329.367}, {650.4649999999999, 327.082}, {
                    655.6519999999999, 321.82}, {654.586, 
                    321.67199999999997`}, {648.8359999999999, 
                    326.855}}, CompressedData["
1:eJxdVG1Ik1EUXsNETGRJNBG1JdH6oKwITMx6TMWkQupHiEoNSRgVNuLespDi
vS8hDkJEwyiij1WSREiNkoiKKBv9EMs+aGZWGvZBmaaklNS97z1r4GDcnfvx
nPM85zmbX7lvW5XdZrMVyq9ab/6cel7z0sDl0w9d7d8ZbOrzyEBa2a6c/jSO
H62dm7I6DRz7urUjPZcjN/5VwNdrQO7W5/k4HKXZwdAXAwfvnk3JPMFRn+f5
2D1C56c41vaXHG9JEFin3jVxzFb30wSak2O2JzZwtFQnmfc3CJ0/grdDIHHZ
9TPDJRwDl+TBUaHXJYR3TuCkeufgKE6wL627LaC2q+M56ua+7vrVLXChUDKL
4ejZUukoHRDYO/T7yog9Glv8ZkZjv6o7jmv+YYEDio+bIxiSv7qo/mKOB+OL
KhpuCL0v+Vn6BQUUXEmA3vcQn/0c5Wp/lOoF6eM0NZ9VhLfHhLfxW+36LMJr
NrHx/eE517I55inha02dz0t8y02tbxvXuFWE186hsnr9Jp5m9E4e8ZHeV03N
bzXxaSO8FRwfZJqiShMvaj4vXJlB+PkmRp9JYVKp3xmE5yJ9YyleznHRJ2/0
CWyW5Xjyuebxhvor40MSNm5QILNvQazhJvxPArLqJ+edpMcw6Sn7Z/loLBpb
/Z6Ydv5HaN3s0djSYYL9jy0/hBmUTJ4A1TPOtK9qhOYX4eMUWk9Bfpwl9Orn
uo9jhtanlvgOGRhUejN6HzbwTuWrIH6ReSog/R8bmn8k/19Dr7cYdt9hTclO
8vsU03rI+bDyJZGeqeR/F/XDQX5dw6FsUmQjfcoo3wzy606OHCWExFe2aJTz
ZOVzC3SkS2MVkH6LKf8k0/OXQv59y7Q/4gnvHoO61jpI8x1imP7/8Q9/zftP

                    "], CompressedData["
1:eJxTTMoPSmViYGAQBmIQbct1fXFBSLPDDrnW14GbSh2iUqzv+3s0Q+iTpQ6d
jglPLwQ2O+Q8/73y47lSh/J986X0O6D8C6UOYP2nmx3076qwNV4udXhYJbLO
/UuzgwzIgJelDts+/71SodLiMCNPqPmAWplD1p6SyRLeLRD14WUOh79qxPSH
tjjIgtT7ljlMc+7OeW7QArFfugyin7/FIWPi2xr7t1D33W52sNxyomwf0H3t
YjfPfV8Bdc++Ugeb+/690yc0O3iAHLIT6v6SZgeQcB7Qf++XH/M2z26GuGdd
qYPuprnvlyc2OwB9v0NudanDEYUNRRnhUPk1UP8hhQ8AMHyWCw==
                    
                    "], CompressedData["
1:eJxdVAlIVFEUnUzCQqRFJGookyArRbNVyjyaYpuZBv4/M2ozozNOUrYgGSFh
xHsvyaiozIhSM5NAJGIIsU3asIIIC6JMxLQF2ozIkgh61zso9OHz/+Xf5Zxz
z/tz3DtzPEEWiyVD3/QsuVl2cnqNgIWueBPlt+tmxPkFakunHup4bGJVb9bR
M51j359nuieb/QLxPXMnHPQYaDp3P/JqkASObP/wZ5sBHe3xWSU26rTEVSb8
nXtv182TXF9rYrb4lN22SKLMd+JLxUsTh1Oc754lSPh//H2x75GJmjW60WKJ
z9lts8SNQLwikF9uIiz22vlvSRKhLxt3JSWY6Nsf3pqRJuFsXxca1G0wvmyJ
j8+iuodbDc73SVQmLy1obzCwcXlVilNItNG8EwbjOhro32zAXrSyN6tWIoT6
LzAxxUz0dzZJdGiZgh+a2ED19yR+R+cduxtr4jr1CVd4M3yg5GZ1LmL0uOZk
xfhSTSRN0i8zFabHacGuOHjeRIXqiFdPfxXmo58EnKZQn6475RVAs1ioNik8
pEFrnbj7Uw8qVkjVMkXdcWJkXxUK9Ahe7RqNoxeFtFjdY7GViJxzMb5yhVwS
otGF/GO6Y67CRZpX78I2TTt5mcLXCi3QBRfrHaMwQLhaXIzPGpg35EIV7cui
QLSSSt3ML0gxr99uKOIVGdDjeCHvI1GB1tQ3qYjxhSl0Er/KIjhI7yGtr7Zd
T0cR++eJBLmvwebBGfJhq2Q+zz38vVTy/Pdexhcn0fK9K9PtK2Y/dgu8fvpr
S78o5vpGwf3OFuPSLkIsOH/Qy3h1PNIvwov1pP8tgWoqTPPwvsdLlJBOfYXc
L0eyjzLd7BdT8nkJc4PWfNAR8MffrRhs1psskDhOhZV5IJslZwT82+UA2fSA
9v+IXksczGd+ID/Swft6L9i/4xw897LAZpJ1wM66nxV8/h7Z8ZaElgLbaU66
HQ9Irx2C/XXKxvlewTiW2lj/AoE0qk8xWR+b4PPrN9jPDoEY4nXa4H37xuKR
frvH4nvkVyFGz+P//5d/+0nqVw==
                    "], CompressedData["
1:eJxdVH9MlVUYvjmWxYT1A10qMqPGCDVwzjUl4MlyoMHUQv5wwu53D/eeO0xg
6Wqj75zNhSauImtOlzpnVrOGTk2YU2CMGqFtDq1N+8FuhMw/GBoUMHO6znve
4/1ad7v7vmfn/d73eZ73fc/TkYbXojNCoVC1+dNzU21hYt01hZylj7RlfhpG
weCzD+8YUfhwf/0T7/aE8clTKVXp4wq3/JLlNfcDvPJs/1vdz3hJ3PfqCy0v
bfZQNtSUcfKegsmy7+UtHlZQXKFGz5F5+YO+hzHKs0sjl+p97KF3Mndza6Xm
ukMeilKvHWucqzl/SQQh+mVolJv04ZYIhr84+N3CMhff4s79AKcvOXP49o8u
fjICq29Io3l0w7ms1QL5FHdTg8oU1QkYkZeODrt6BwUGsn+9o6+7+HYBkhW+
oFFFiacFKOxIs+bvxgSuUHyTZh6fCyw89WZ8b4NGN+mtFIjvNYqrNRpJmMF5
7835+fIyjVXhkYHsYwLFRGRSMd+5tZznb4VfLk+/PpwWxdabd78aL9D4evxq
ReRQFE9S3QqN7ZQ4EWV+BmeS0OEoDlDbcjV2Ef/nYuznQ47/thj7YfqbQ/2Z
KZnPtGI/8mSyf5bPcgk7Bpka79PLYol3Mk6WDr2ocZV0z5H4lvpXpznfdIz7
afpheUzFmF+r458hcS5r5+iGfs36tkq0k597ND5b3fHXvd8l+5Xv+H4v2d9U
188uyfzvquT5hEn72JTClCnbO+bwhOI+pcaxgD64otBG9QvirO+EYn6r4uzv
G4r9FHHuv8Hh82tmzfgPtnwfDfANmsPjkvWuVzwP+yT3f75ivT9Jjv/Tx0cU
ODPOfvb5PG8JmcS2780Btt89Lzlu3Of9SpFoIv+L3b6mO71NTv9syXG+w10x
Pn9Fcf2SGEpJ/wN+N6KMC50/u6O8z1sU+ilPKIqdNEdSoXO7OcmqZf+XOb0n
BL40NpxKVbx/GwXXM3qtP4cE5/vB5/m6L5BY98H++gNOv9knOz97fPa7VfC8
7vD5vlkruD+7fdTQ+SLB+/2Nj1mU748IzFSMDAz4PB+nIxz/j5+8D2w/HldJ
bPdnTYBtvVKFOpq7pRG8TYub5u6z6x7rTPjooHky95XVl2Pm4Y6u6zT3ma1f
rvAb4UYvOR+2P5sCbJ9rA2znM91jPw+7flSGeQ/aAmzrdQTY+nnR3b/bwvj/
/f0vArCfhA==
                    "], CompressedData["
1:eJxNVX9sTWcYbmSRZulkaxuRza4fE7qKYJuI0Xm2VW1+xBCyjIj03sM53zmo
ooruO+cGpTO0bLMRis6SJY2xTVe2VFO1sj8wjLUUTbd2C2rWaSONxPd+77dz
3eTekzfn/fG8z/N83x2Uu2yW1SspKSlXfenplN0tmlgVYMPtmdWRY1Ho+EqA
uX1GfLu3PYp3U3oN3/RCHClXK/KyLsbC+I9De+oHplhh3FE0ccyCiIX6gUfy
7eQ4Lg6+9lDmW1jz99DRyfcDLDyhMhssvPhBbPzNkwEOTqrqfFS4CNPGlry5
8KMAeVlPX634cjH3KwrQn/Jm26DHjFUBhvaOf/r2Nzb3n2XwTXXQSjhu+Sgm
/GcF42iSqCl/fmRzvQevvefr+9skjp0pqCnf5+ENNSbPkkhbX/vLgRIPavqf
F16RjGu1h5sztu5aGpE8T8V6fs+HoLKsAg809p6Kh41Oruyf73HfTInGc92z
W1/2uM88iVTq3+zynvsl12ea+lbJ+670UB3ZeHtmm8RGwr/KQ92DjPnbOyTr
MM7DVOKn09T39bCE9vnL9G90Ge8VyXMqXVwg3uslulSburiL49T/hMT1h1L8
9J6Lcd8rwCcl2og3uFhNRJ2WKKXBI13G953Ex7uWpq5PcUEw876QrOe/gvHa
Ev8Qz3UCvxUqgXMk6/WSYHxeItbP7YlY833d4GsRPO+SRM4WpdQgl/c9L1GU
fnhyy1suSO6yXyWaCH/M5frfJeu9xAXBrO2SOEOFpS7WUd1/ElBpg3tEyE8T
6XNUhPxUkW7FIuRH8zlHhPxo/2SLkJ+fqf9rIuRH+/Y5EfKj+et2QOXlip+V
thKwwfgzx/CfYd57ibiB+u5IxLp/s/If+euGw364/D8/ApNb1qYfPm/wThIh
P6Oah/SOOyLkR+cvF+yLOya/xOjRLZFEn3SBzZTfZvzV5OAd6q/mb6PBPzoY
vqlv4zkVC/JjmYOd/Z6a26dd4nVaZJmDTHrfbc7Lq07YT+tXY+MZ2qdB4jPS
abeNrxQdRxTfQyh/i837nDL6ejbz32r4nmAzP6k+89G1mM9Jmo/PqV9HItZ7
Vi8KY51fZeEu+bSfz/hWWOzXUT7vm2OxX6b4fJ+kWaz3dJ/1eyLWfGUn4lry
R6HFvK7z+XncYv4OJGLdvzIRL6B7sNM3/rYQ0YADPg9HY1C/DzKyzf02IIZL
03Offd8N2F8VUfZbQcD67Inih85HlwvjAePdGcVpMsTWwPAbhZanNGC8m819
/knA57k4yvfboYDvzd3m/n/i/+AxP5jYyg==
                    "], {{
                    484.76599999999996`, 196.805}, {484.76599999999996`, 
                    199.41000000000003`}, {479.387, 202.195}, {472.953, 
                    202.918}, {467.758, 203.5}, {467.672, 
                    203.46500000000003`}, {467.672, 200.87099999999998`}, {
                    467.672, 198.723}, {468.48799999999994`, 
                    197.87900000000002`}, {472.074, 196.31599999999997`}, {
                    477.83599999999996`, 193.80900000000003`}, {
                    484.76599999999996`, 194.07400000000007`}, {
                    484.76599999999996`, 196.805}}, {{490.66400000000004`, 
                    197.043}, {493.289, 199.42200000000003`}, {
                    494.53099999999995`, 202.25400000000002`}, {492.953, 
                    202.25400000000002`}, {491.137, 202.25400000000002`}, {
                    486.32, 197.93}, {486.32, 196.301}, {486.32, 
                    193.75799999999998`}, {487.215, 193.91000000000003`}, {
                    490.66400000000004`, 197.043}}, {{485.07, 204.75}, {
                    485.29299999999995`, 206.223}, {484.383, 
                    207.20300000000003`}, {481.65200000000004`, 208.438}, {
                    475.77, 211.09400000000005`}, {468.734, 212.324}, {
                    467.039, 210.99200000000002`}, {463.91799999999995`, 
                    208.53900000000004`}, {465.9959999999999, 
                    205.24599999999998`}, {471.039, 204.652}, {473.07, 
                    204.41400000000004`}, {475.824, 203.79700000000003`}, {
                    477.16, 203.27700000000004`}, {481.03499999999997`, 
                    201.77300000000002`}, {484.72299999999996`, 202.457}, {
                    485.07, 204.75}}, {{485.07, 212.63299999999998`}, {
                    485.387, 214.73000000000002`}, {484.043, 
                    215.48000000000002`}, {473.08599999999996`, 
                    219.33999999999997`}, {464.90599999999995`, 
                    222.21900000000005`}, {461.28499999999997`, 
                    220.85899999999998`}, {463.89799999999997`, 
                    215.89499999999998`}, {464.809, 214.16400000000004`}, {
                    466.34000000000003`, 213.375}, {469.76599999999996`, 
                    212.85899999999998`}, {472.316, 212.47700000000003`}, {
                    475.801, 211.73000000000002`}, {477.508, 211.199}, {
                    482.074, 209.781}, {484.715, 210.281}, {485.07, 
                    212.63299999999998`}}, {{490.562, 220.02000000000004`}, {
                    492.215, 221.695}, {493.566, 223.67200000000003`}, {
                    493.566, 224.414}, {493.566, 226.816}, {487.039, 
                    222.56200000000007`}, {486.207, 219.61700000000002`}, {
                    485.207, 216.08200000000005`}, {486.824, 
                    216.23000000000002`}, {490.562, 220.02000000000004`}}, {{
                    485.074, 220.51600000000002`}, {485.43399999999997`, 
                    222.906}, {481.457, 225.06199999999998`}, {473.637, 
                    226.723}, {467.902, 227.941}, {465.371, 227.25}, {465.801,
                     224.586}, {466.03499999999997`, 223.12900000000002`}, {
                    467.945, 222.06600000000003`}, {473.367, 220.375}, {
                    482.039, 217.668}, {484.648, 217.699}, {485.074, 
                    220.51600000000002`}}, CompressedData["
1:eJxTTMoPSmViYGCQB2IQrX9Xha3xdJ1DgS3X9cVfchy02sVunsuud+g/9FUj
pjnXweNhlci6ynoHVbbGqc6v8xwuKt3+WfeozuGbRkz/Ic98B8stJ8r2La5z
WOS67fPfgnwHd5D66joH2agU6/vRUH5ynUO1yDr3h2z5DhkT39bYB9Y5fAXp
P5rnoLihKGNibB3EPv88h+l5Qs0HyhB8sPp6BP9qxUs1w7Y6Bx/zTscESwR/
K9AZ8+UQfOHmA6cWLsx1AHmrYGKtw2KQ+zJyHSZLsITx6dY6zADZcy7XwQrk
fs5ahwsgf33KdXjg3zs971cN3D6w/8Rr4XxweOgi+GB/2dQ63Dz3PfjxWqi8
Ya0D0LSsPR/yHN7V2JvGKdVCwsM7H2LPlxqHYpDHsvMh4htrHApBDvXIdxAC
uVu6xsG5O+f57595kPiQr3HYP19K/+6MXAegr59e2FHjELfLk4eJOdfhmDcw
IMxqHZ4snX1EoSPHAWScvyc0PhtyHNDjFwB7QOjD
                    
                    "], CompressedData["
1:eJxTTMoPSmViYGBQAmIQbbnlRNm+9DqHtteBO+Q48xwmS7CE8RXWOczIE2o+
IJXnsMh12+e/OXUOXzVi+g+Z5jnYcV1fXBBb5wCibP3yHLzNOx0TrOscwOY0
5zmU75svpW9b51CUMfFtzeU8h8MgjUlQ8/TyHUDK5tfVOaiwNU51Ls53uFrx
Us2wqc7hG8j8m/kOWu1iN8911znIRKVY3/9Y6HBB6fbPujl1DjnPf6/8mFPq
MB1kzr06h1aQe7krHD5d8k0SMKt34NPdNPf96goHoGueXoiA8l9XQOjgeog9
byocHi+dfUThV53DFJA/11c4vK2xN41rq3PYIQc0MaHC4RjIQ3pQ//wsh+h7
UOsQt8uThym9HGK/T62DNsidgWUOChuAPpWshYTTnRI4H+y+g4Vw/kWQP35B
/S9TC7GnJR9iv1mtgyooPPTzHTpA7veDqr+XB3FvQK0DkJe150AeJBzsoPJZ
eZDwMq6FhK9RHsR9erUOoOC3/5vr4P6wSmQdUF4WFJ6fcyH2h9Q6AFWdWrg1
F2K/S52DuiHHGpljuQ7o6QEAve//BQ==
                    "], CompressedData["
1:eJxTTMoPSmViYGCQA2IQfVRhQ1HG1UaH497mnY5hRQ7TnLtznl9vdODT3TT3
fWyRwxXfJIGIS40OM/KEmg+0FDl8ugQUONnocPirRkz/miKHQyB6V6PDlhNl
++a/KoKo29LoUC2yzv3hlyKHrD0lkyUWIPi2XNcXF8Qj+J48TNrt3xscls0+
orBBr9gB5IyEngaHaxUv1Qz7ih0uKN3+WefX4OADEj9a7PB4KVChZQPEHZeK
HeRbXwfuMGxwYACBI8UOAhGWW07INUDULSh2yJz4tsbersEhbhfQJu9ih3ax
m+e+5zVA/CtX7FCxb76U/qwGiD++FTlUAq3lEG500AYpPFrkENsPlPFC8MHm
ZiH4MlEp1veB/Jznv1d+PFQE8UdEo8MOOaDD+oocQNL+3o0OwFA5tTC9yGHb
579XKvIbHaxAAZZaBPFvMzR8U4ocFhcAQ2heo8NFkL/jiiD+XwONj3Co+y40
OnQ5Jjy94AbVj8RHj08AglzhCw==
                    "]},
                    
                    CurveClosed->{1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
                     1, 1, 1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 0.717647, 0.], Opacity[1.]}], 
                    FilledCurveBox[{CompressedData["
1:eJxTTMoPSmJiYGDQZ2RgYAbSDEAOIwMjMzOQhDCIRPjVw2WJN5ZIlQSVUa6A
bPVoKqnud2JMINsNBGONoMn4FVArXkhyJIWxQKqbKYxHAMnLCKY=
                    
                    "], {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4,
                     3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}}}, {CompressedData["
1:eJxdW3mcT+UaH0v2O8mSJblZwkXkhgm58wppoYT8fsxqFmMs8zu/ddDiLL/l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                    "], CompressedData["
1:eJxdVn9MlVUYvlErhsQynQNaJmSNQoP+YGry4yUqRswRtgxDrkYQrtn1O59O
r2XZPae7m2tpyIxWmXlTzDBWJkiuQQNDsVYUmBVzIv1gXQrQrOUs1znnfeRr
sbFvz33PeX887/O+35dWvXpxbZzP56vX/+Z57utF1deVKdrz+pFZ7x9x6DJe
cPDYuo5Bh1bW/7axYK6iH8yBVEE+8zdF0djGghz/3YLPT0hKmntgx/ijgsy1
naOSnhy5uO9staCuPzKWbdU4PFrePrNEUNvv/wwENbb30gU98fHahuTvJd0e
mfHdF52I1+9hnZW78ksP32Qc9UryHy5JjOt3aOHpspcaeyQN6Ucg5lDWqdlX
h7qRzxWI1ybpRPCXW+/MFtRq8tsnOU65oOGnprcUb5P0SI3xJLjO5yRNU58c
3/WQoPUdO1OzVku6yxSWJmi3k5dwslySuXZmzKHNhSt+6rvHw02Gx0IP2/o0
Plo6b3NhAvIpknS98Z8paINOK/4+SdeafMuAtb/GgD6xSpCuMjOSLzmPNYLy
E06+7SwAnxsEnTGBciQ1JF+1JGm9h20fAv+zV8JfouS+XHLolaIXV41c6WGT
5gqfhy3/F0N8P0XQjYaov0KUZ/MQNKDbWPFniDJNf5ZCD+dwXvNpeR0PMd/N
gnJNv34NcZ96BfvX56P3amYOChrf21M67+8Q8/0M/CWhXynoX5qkvvTBC88u
wf056G8Q93OgvzcE39O4xxT2jofNtfoPBdc/H/W2C+o39eRJ5kHbXzV9KIT/
FsG6KoYewuhXqWQ+dP3GvPcBSU+b/scLCpq+PS5ZV/Nx3oX+F8PfJsk6Wgt7
GPHDuL8F/qKC53QLzkehx7ckz+XzuN8sOW8X5w8jvxLMZzf4yEA/PpdUZebp
GszjCUntM7XCtH4tL99gPs467P9b2M87/Psg+jED+jiF/PPQnyHEq0E+w5J1
rOvbbvgfhr4jmLcfUd/LgqZW6E10s2L+86GnhYrjTxdc1/2K411w+HyF4vkY
cVgPldhnow73p0qRUYF/wqE5Bi9X3I9kMYltX4o8bPl9AfwuUzzPr0FvxYrz
6MS8ZcEeA993KPrK8BNDPbcorvMzQZWmnlRF3YbnKOyJiPcfbPVz3MO23hHM
82nsj4ddtvd72O7LPg/bfI+C7wKX8+uQPH+zXK6vDfqJg7/90GsM+ngXeo5h
n70pJ+s1bWn3SzKyCgRd3mN+3N/mYauXJpd/fwzzvculCZNfAPltctnfOthr
XdZPBPst3+U+NcB+G+rdj3m4JBi3Il68y/3plKzTStTbhX28Bvn1YB4iLuuw
18NWzwMetvtjCvQ2FflOU5N82fm5QbGfLkHZZu+lob9j2C8Zip/pLj+zFecx
2+V9lKvYz3nMR6FifofQj6WK+WgTdMj0Qyjeb43Qyw7obTnmr0mxHrTdvj+b
kf8h7NsDivVwDP5bMT+d2L8fKebvA9hbMC8PCvrUBN6jqNgQXQD7bnxf5KIf
2xXP/yLkG1a832qwD+uQ/1bBvNUh/yLoqw75puB9WKv4ffuzw3GqMY/92E9V
iPee931jeY56+PL3z7/RviXx
                    "], CompressedData["
1:eJxNVGtIFVEQvghJSJaZRNjLykyysJISNXO0h5SaFP2w0BRLEjG7OItdNQrP
wVRCzIJUTMxXIkRImNrLxExFKKSMKLKLRNjLTEVIQuqMMz9aWA6ze84332N2
16WeO5rmYrPZDpib1tyvftsXZiuYehWX6uGHEBtcEpkSrsBG10Wpdyr41FTd
63MN4eAil4CiXQo2Fy1/9/IRwtKEkLaBYAVvHAboC8JEc19McJiCGDr3RGqD
17mm8PuRRoT08vELETEKiiNTPg8Z/MVb79VMJCo431XrHXhK9ucrfh6EUEL7
ShUkPTSdk5F5ViogOq05CM9m/BPLbinI97obPWr4rTVtOk29THcP1tUgJJb1
zPjXKQggvg+QzzUoCHd722DvQHht4BL6Ffi0ZqeX5yLM+zGmGDdK9Jq6nwRF
Cf8fwi8NYdWJ02HOnwpC2wZyunJFz7joqUVw0PpNQf3+9um5TtHjFL9tFjTa
DZNRBZVZnrrbzYJD1G9SgTvhOIXfrPAZFPwFGpzxpRVZdxA6pueGHe6a9d9E
CKMX3pr1FiD0krCVmvNRCEQ33kdDBfUzeWQ8tq6v2KChh/ANvz3ky0YNZ8f+
tEx+QNg24utaYOr5dQbhvpFZa+r5eVhvwS/KK0pz3qMIN/ZeyRxL1KyzUfgn
az5XjxBIOGc0+/8UYTTPEM8UPUNS2zX7PCvn7cLf2+JzduG/z+I8szXjxlus
x6FZZ4TFPAs09BFBXwsayO88zX6+R0ii+cjQEEL5VUteJzXjZiG0k7+HNUQT
MZPnMPEJ1TzPHxG2mDiag6TfCDIvP83zUIXsq8ljNW04jkCPaz01z8Mx2e8q
fl6W+f6reH8Twm4yZk6+x3qZ59+K/UmW/KZkvryQ5+iF4hzjEJ5T/i0y/4WC
X6XgNulLkfqqYn9ipV+xvN+B7HexzOMmZJ6mntflgZz7JfkfLBG8//4n/wAn
LwFL
                    "], {{648.8359999999999, 326.855}, {646.438, 
                    329.01599999999996`}, {644.7850000000001, 331.074}, {
                    645.164, 331.43399999999997`}, {645.543, 
                    331.79299999999995`}, {645.9689999999999, 331.895}, {
                    646.113, 331.66}, {646.254, 331.42999999999995`}, {
                    648.215, 329.367}, {650.4649999999999, 327.082}, {
                    655.6519999999999, 321.82}, {654.586, 321.672}, {
                    648.8359999999999, 326.855}}, CompressedData["
1:eJxdVGtIVEEY3RYTMZNNIkVcsyWyB6VFYGLSMRWTCKkfISolS8JSZEvcqS2k
mLmEKISIhVGE1VaSREhtJhEWPVT6IZI9aM2sNOxBmaaklNTMnW9bcGG5fHNn
znfO+c7cJe4DOyrsNpstX/7Vs+3nzHPfS44r5x6ntH43YFO/JxzOkj1Zg06G
H82dWzM6OU583d6enM2QHf3K7+3nkKs1OV4GR3FmoPsLx+GOpsS00ww1OeUf
e8c4utT7swwbB4tONsYIfa6BYYHa7xRoSIjYGVvH0FgZZz7YLHBV9Q/h7RKY
v/rm+dEihiFF7LjQz5WEd0HgjDrnYCiMsa+qvivwTi5XRjNUL3rd86tX4FK+
VBbB0LfN7SgeEtg/8vvamD1cW/rmhmuLdxTT+oNC60llCHQf6mjqIf6FDA8n
l5fV3RK4rdalPsu/gICCK/LT+T7Sc5ChVK2PE1+QP/Gm1rOO8PaZ8NR/q9qU
QXinTGx5f3ThjUyGxcr4KlPz8JDeUlP728I0bgXhtTKorp5aE72u/uljXvL7
uqn7ric9LYSXzvBBtilwm3jh+7xsrYvwc02MP5PGJNG8XYSXQv5GUr2G4bJX
7hgQUHTKc5nW8YbmK+sjEjZqWCBtYGkkTyX8TwKS9dOL8eTHKPkp52f5PhGu
rXlPzXr/R+CR8s0eri0fpoz/tZWHoKF5+YnPpIFYlSuf0PpCeuKF9lNQHucR
Xi3Tc5zg2p8q0jvCtd8GnQ9yKJqVZaQvdJ/yyP8ujnSlP9T/L9f5vmNg7z2j
IUH2t9ZnDO2HvB9WvzjyM4nyn0LzcFBeNzComBTYyJ8S6jeH8rqbIUsRk/gq
FvXyPln9UgXak2Ww8si/FdR/2tD3L1Fo/m8NnY9owrtvQG1rHqb7321g9vfj
H3Wl+0g=
                    "], CompressedData["
1:eJxTTMoPSmViYGAQBmIQbct1fXFBSLPDTrnW14GbSh2iUqzv+3s0Q+iTpQ6d
jglPLwQ2O+Q8/73y47lSh/J986X0O5odckH8C6UOYP2nmx3076qwNV4udXhY
JbLO/UuzgyzIgJelDts+/71SodLiMD1PqPmAWplD1p6SyRLeLRD14WUOh79q
xPSHtkDU+5Y5THPuznlu0AKxX7oMop+/xSFj4tsa+7dQ991udrDacqJsH9B9
7WI3z31fAXXfvlIHm/v+vdMnNDt4gByyE+r+kmaHB0DhPKD/3i8/5m2e3Qxx
z7pSB91Nc98vT2x2APp+h9zqUocjChuKMsKh8mug/kMKHwAzJJYO
                    
                    "], CompressedData["
1:eJxdVGtIFFEU3raIkpAeIpFWJoE9FNMyk7Q9lmJlKho5s45uu+O+lDJ7kFEm
Rtw7SYlJ5QMpMzMpRCKWEPOFlmlBiAYSi4hZ9qMiI7IkpO7dc3GhgdmZs/fc
73znO9+dDeqJDJtep9MlsZs/8zvO3FhdRUDHr20yFHXVrwl3EaguWHm555UM
seNp5dUD3vWRFHW5PEkgfGzj4ks2CZrqngc91lPYd/XYpz95ErDolDOQQhpL
i4mVwTVwtqs+hMJfflXLsJ58Tm+LoHDaWfm1eFSGK/Hmj0ORFJ7+mHt7blCG
Kg60ncKX9LZ15JmId4n8Ihl8w57c/hZHwWe0sTAuUoaJ836tSQkUTO0Hlund
EvJLpzA1FOyebZUw30nhoiHK1N4gwaHosngzEfUqJeyrXOA3S5Bl3T2eViPw
t8iwQo5xDTRR6GQyLeqXIZnv76Mwsym7ojdMRhw/DdyzJfkd1zIhlJVrNmi4
f68McfwlQIMALthDBest1UDzf/fmV24OTHIBV2lwL5EhZZuAdbFVS9XgJS+0
3wy9P1khhwZcpuBuM3jmVawhnz2W+TgkYklLoOqN1/JG6izIr0iDI1yIRgvk
VDDETFHvrgXyWNuGnRqw3yjTHQvqHaohrxYLPgNFvRkLlHEiOtFfgYr96TXs
67eKfQUJPa7n4jxiNLjAxjThY0V+vqK/UisoXO8ZCt3MdmM9VvTPawqrmPsa
jDb0YSvFfkZsuF4g5jNlR37hFB59H05RnQ70o5sAY3F4kjhwfyNBvFoH3C/k
jAnmT9uRL4s9eP52OMj17yRQzjcm2HDeCylwexgmchEvg6KPUlT0i0yhhv/v
q+K5UIQ/5o7CdHN/crSJIl5pNuIkCf7DCnCbljD/e/TaoWA/m0V+kILzmiLo
3wUK1n1AIJXL+iELda8leP4Gs+A9Pw+UYJ3ELHjB9TpOoIHP+6YR8+1iPcqI
+psIJPD98TLqYxT4Lgn9rIjzfkvCeTu9sQfvpDfu434lZP48/v99+Qe+3O82

                    "], CompressedData["
1:eJxdVGtIlEEU3SKyLKWHRQ8TszJ7qohEmXmzRDPDHuqPqNhvx91ZNEsyCuyb
AemlQpmFJGlIWdFDxR5GVFZU9ISwB2RYbGbij7DSUjExmpk77RctLLuHuXPP
PefeudMd29c7h9psts3iK383ZsZ4Ut8ymB05oibwhB0iPswcXtDO4NDxbeP2
3rPDsUnDMvy7GHSacdFbflt48bUnu+7MMLz48epFRcs3GZDUmh9QN8ggdHhB
2YpsA+NiONytmhL+wTQwzwGOfEcNuN8TtqkkjUO45G01INb3bXXuZA5L5L04
B9jkJ4CDTG8vckDb2YqHwUk6vkifmxb2X3Dl5LfXHFJkfI8DlL5WDvu/rLsR
lEAwroPDKEETm0VAiHx2qk3zVRBoCmnp5806voEg7y0OGTJxHwEZVrWPw3h5
r5PASxmfz7GOMwSC63e4S7drvWkE3KVC8WYOuVKYwHMPTnz3IopDvL29KaSa
wDKpt4chz+RMzPOTwbsXfRva/JyQ0zFwoSuCw6WuV2sclU7kXcMhTyb2OPGe
wNOk0DYnlMu2hen657jQzyEc0mX9eS70Q/R3luyPD8V6+hj6MZd6+6f8i6ag
xiCQw2H5Zz6FPQF1ia1LOfo0kcID2b8sjvn6XNhP0Q91r9eF9ZVwuCjrD6Bw
I0hU9oSjvhwKDdLPYg6nE67/GPxI0a9w7fdjiv766n42Uqx/gHnPu0XaMb0M
egXt/U6Nuxnm9XWjLy8Z8ke4UV8tQ5/i3ejvVgY7JDFxoy6Bt9xcNXroP1jV
O9LCag7PU9S7luEclVHs/1TN94Zi/HcTSmSgjxt9eWTivHmoF6u+77Ow0r2Q
YlyXCY+kkcMo5Ev/l+n36q/15mv9EyjGmRo3uvB8JYMjkj/OBYlS/9/6PjsR
x2hc6MT3nK3fs82Jc0QZNO4UJ0GZ6H8UwzmsJXBO2FDvy/BdpRPkE3qVP5UE
8z03QY5h7G8CnlSxWcpN3AviPan5KTbR7xKC81pgwle5J5IJ9qdQn88j+L6v
6nyfHCCmor2pycQ5u+zA+F+mdx+ofoxlXqzqXmVhxZfIcO4iHbD7jni4flp/
s4F99Zg4T2JfKX2hDN7386zbYp8p/hQGLRLnGt75UP3ZaOFX8jfZwiqfv4F+
ntT+p9nxHdRYWPFdt7Dy86nev3l2+H9//wHKOZ9v
                    
                    "], CompressedData["
1:eJxNVWtsFFUYbRpDGi0E26YhgstDRSwh5WVMRfCIBVQkaAlo5BHS3YGZO1Mo
FUoVvDMbIg8JtBUNAsHyEBOThodKKWhaUgoFf/CQWm1lgaaxlSglUG1jGhLv
d7/LLJtsJmfn3u873znn3h1ZuLLASk1JSSlUX3o6lbfXv1wT4OO/3q6NHI9C
45YACwaN+3ZvVxSvp6eO3TQ0jkd/PVg89edYiDsO7WkckW6FWO16fknEQuOI
oyV2WhxXRv3+nyyx8MGt0RPS7gZYfEqtbLLw5HuxKTfqAxyYUdNzv2wZ3nxh
yytLPwlQPFV1+Go511sf8Lp5Nugxd02AZwbEP3/1iM31Cwy/2Q7zuOkz/wsC
3cSjTaK+6oncRKMHr6v/m7vbJY6fL62r+tLDNBrEksjccPqn/Vs8qO5/XJ4o
MYwarfVwY+62nSsikvsprPv3f8Tzl3qgtncUfnZCWvWwEo/r5ki0Xuyb1/Gc
x7wXmvoJl+fcJ/EY7c8x+zskz7vaQ21EMe+UzH+Nh4Z/xywq75awyYc8D7NJ
nx7J/bM9FNE8f5r6rS7zbZHcp9rFZdK9UaJXlWmIuzhJ9U9JqF/Fj2+5yPte
Ea6XrBtcrK1TQp2VqKDGuS7z+05i+84VGRvSXRDN4l2S/bwnmK8t2e8GgV/K
lMEzJc/9lGB+XhJrXcuTWOt9zfBrF9zvqkT+VuXUSJfnvSSxLuvwrPbpLsju
yiuGf8zl/b8ZvYpcEM3TvRJNtLHC5X3/SExXy0b1i1Af7c8xEepDMlRtFKE+
GaTnfBHqo/OTL0J9zlH9ySLUR/N8XIT6lJN+fQ7XVfqUkIFNJp9KnzbiP8a8
95JY8/40iXX9hOR8XXc4D80P9BGY1f5h1uFLhu8MEeqTm3h6QNwRoT56/SrB
ufj7Qd6NH30SKfTJEthM6ztNPtscvEb1EyYPPzgYuym79WLC5LHSwY4hjywY
1CXxIg2y0kEOve8z52WSE9bTPtTZGEjzNEl8QT7ttvG1kuOo0ns0rd9q8zxn
JK7R/J7N+ncYP1+y+Znhsx69y9n3TJ/rdSexnrN2WYj1+hqLczrEZ37vW5zX
8T6fp5kW83zDx3wSPtNiv+f47N9DWOuVn8T0SJRZ7MM6n/U9abF++5NY169O
4iV0D/b4Jt8WIppwwOfhWAyLKEj5Ad4hPsNjuDqncPC7bsD5OhjlvJUG7M+e
KE703G8uiwfMd0cUZykQ2wKjbxTanoqA+W429/lnAZ+DjVG+3w4FfG/uNvf/
Q/8H/wPhWdiy
                    "], {{484.76599999999996`, 196.805}, {
                    484.76599999999996`, 199.41}, {479.387, 202.195}, {
                    472.953, 202.918}, {467.758, 203.5}, {467.672, 203.465}, {
                    467.672, 200.871}, {467.672, 198.72299999999998`}, {
                    468.48799999999994`, 197.879}, {472.074, 196.316}, {
                    477.83599999999996`, 193.809}, {484.76599999999996`, 
                    194.07399999999998`}, {484.76599999999996`, 196.805}}, {{
                    490.66400000000004`, 197.04299999999998`}, {493.289, 
                    199.42200000000003`}, {494.53099999999995`, 202.254}, {
                    492.953, 202.254}, {491.137, 202.254}, {486.32, 197.93}, {
                    486.32, 196.30100000000002`}, {486.32, 193.758}, {487.215,
                     193.91}, {490.66400000000004`, 197.04299999999998`}}, {{
                    485.07, 204.75}, {485.29299999999995`, 
                    206.22299999999998`}, {484.383, 207.20299999999997`}, {
                    481.65200000000004`, 208.43800000000002`}, {475.77, 
                    211.094}, {468.734, 212.324}, {467.039, 
                    210.99200000000002`}, {463.91799999999995`, 208.539}, {
                    465.9959999999999, 205.24599999999998`}, {471.039, 
                    204.65200000000002`}, {473.07, 204.414}, {475.824, 
                    203.797}, {477.16, 203.277}, {481.03499999999997`, 
                    201.77299999999997`}, {484.72299999999996`, 
                    202.45700000000002`}, {485.07, 204.75}}, {{485.07, 
                    212.63299999999998`}, {485.387, 214.73}, {484.043, 
                    215.48000000000002`}, {473.08599999999996`, 219.34}, {
                    464.90599999999995`, 222.21899999999997`}, {
                    461.28499999999997`, 220.859}, {463.89799999999997`, 
                    215.895}, {464.809, 214.164}, {466.34000000000003`, 
                    213.375}, {469.76599999999996`, 212.859}, {472.316, 
                    212.477}, {475.801, 211.73}, {477.508, 
                    211.19899999999998`}, {482.074, 209.781}, {484.715, 
                    210.281}, {485.07, 212.63299999999998`}}, {{490.562, 
                    220.02}, {492.215, 221.695}, {493.566, 223.672}, {493.566,
                     224.414}, {493.566, 226.816}, {487.039, 222.562}, {
                    486.207, 219.617}, {485.207, 216.08200000000002`}, {
                    486.824, 216.23}, {490.562, 220.02}}, {{485.074, 
                    220.516}, {485.43399999999997`, 222.906}, {481.457, 
                    225.062}, {473.637, 226.72299999999998`}, {467.902, 
                    227.941}, {465.371, 227.25}, {465.801, 224.586}, {
                    466.03499999999997`, 223.129}, {467.945, 222.066}, {
                    473.367, 220.375}, {482.039, 217.668}, {484.648, 
                    217.69899999999998`}, {485.074, 220.516}}, CompressedData["
1:eJxTTMoPSmViYGCQB2IQrX9Xha3xdJ1DgS3X9cVfchy02sVunsuud+g/9FUj
pjnXweNhlci6ynoHNbbGqc6v8xwuKt3+WfeozuGbRkz/Ic98B8stJ8r2La5z
WOS67fPfgnwHd5D66joH2agU6/vRUH5ynQOQdH/Ilu+QMfFtjX0gVP/RPAfF
DUUZE2PrHCaA7PPPc5ieJ9R8oAzBB6uvR/CvVrxUM2yrc/A273RMsETwtwKd
MV8OwRduPnBq4cJcB5C3CibWQtyXkeswWYIljE+31mEGyJ5zuQ5WIPdz1kL8
9SnX4YF/7/S8XzVw+8D+E6+F88HhoYvgV4P8ZVPrcPPc9+DHa6HyhrUOQNOy
9nzIc3hXY28ap1QLCQ/vfIcLIHu+1DgUgzyWnQ8R31gDCX+PfAchkLulaxxc
unOe//6ZB4kP+RqHffOl9O/OyHUA+vrphR01DnG7PHmYmHMdjoECwqzW4fHS
2UcUOnIcQMb5e9Y5FILMa8hxQI9fAIGY6Mg=
                    "], CompressedData["
1:eJxTTMoPSmViYGBQAmIQbbnlRNm+9DqH1teBO+Q48xwmS7CE8RXWOczIE2o+
IJXnsMh12+e/OXUO3zRi+g+Z5jnYcV1fXBBb5wCibP3yHLzNOx0TrOscwOY0
5zmU75svpW9b51CUMfFtzeU8h8NfgRqToObp5TuAlM2vq3NQZWuc6lyc73C1
4qWaYRPU/Jv5DlrtYjfPddc5yEalWN//WOhwQen2z7o5dQ65z3+v/JhT6jAd
ZM49qHu5Kxw+XfJNEjCrd+DT3TT3/eoKB6Brnl6IgPJfV0Do4HqIPW8qHB4v
nX1E4VcdxJ/rKxze1tibxrXVOeyQA5qYUOFwDOQhvToHK5BDf5ZD9D2odYjd
5cnDlF4Osd+n1kEb5M7AMgeFDUCfStZCwulOCZwPdt/BQjj/Esgfv6D+l6mF
2NOSD7HfrBYSHvr5Dh0g9/vVOlwEqb+XB3FvQK0DkJe150CeQw4oHOyg5mXl
QcLLuBYSvkZ5EPfp1TqAgt/+b66D+8MqkXVAeXB4fs6F2B9S6wBUdWrh1lyI
/S51DuqGHGtkjuU6oKcHAMJ3/wg=
                    "], CompressedData["
1:eJxTTMoPSmViYGCQA2IQfVRhQ1HG1UaHY97mnY5hRQ7TnLtznl9vdODT3TT3
fWyRwxXfJIGIS40O0/OEmg+0FDl8ugQUONnocOirRkz/miIIvavRYeuJsn3z
XxU5zACp29LoUC2yzv3hlyKHrD0lkyUWIPi2XNcXF8Qj+J48TNrt3xscls4+
orBBr9gB5IyEngaHqxUv1Qz7ih0uKN3+WefXABE/WuzwGKTQsgHijkvFDvKt
rwN3GDY4MIDAkWIHgQjLLSfkGiDqFhQ7ZE58W2Nv1+AQtwtok3exQ7vYzXPf
8xog/pUrdqjYN19Kf1YDxB/fihwqgdZyCDc6aIMUHi1yiO0Hyngh+GBzsxB8
magU6/tAfu7z3ys/HipyWAbyR0Sjww45oMP6ihxA0v7ejQ7AUDm1ML3IYdvn
v1cq8hsdrLYAAyy1COKvZmj4phQ5LC4AhtC8Roi/44og9JpGB15QfIRD3Xeh
0aHDMeHpBTeofiQ+enwCAHk04P4=
                    "]}]}}}}}}}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 960.}, {0., 480.}}], ",", 
           GraphicsBox[{{{{
                {Thickness[0.0010416666666666667`], {{{
                    {FaceForm[{RGBColor[
                    0.890196, 0.0392157, 0.09019610000000002], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 640.}, {960., 640.}, {960., 0.}}}]}}}}, {{{
                    {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{500., 320.}, {500., 231.63299999999998`}, {
                    428.367, 160.}, {340., 160.}, {251.63299999999998`, 
                    160.}, {180., 231.63299999999998`}, {180., 320.}, {180., 
                    408.367}, {251.63299999999998`, 480.}, {340., 480.}, {
                    428.367, 480.}, {500., 408.367}, {500., 320.}}}]}}}}, {{{
                    {FaceForm[{RGBColor[
                    0.890196, 0.0392157, 0.09019610000000002], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{508., 320.}, {508., 249.309}, {450.691, 192.}, {
                    380., 192.}, {309.309, 192.}, {252., 249.309}, {252., 
                    320.}, {252., 390.691}, {309.309, 448.}, {380., 448.}, {
                    450.691, 448.}, {508., 390.691}, {508., 
                    320.}}}]}}}}}}}}, {{{
                {RGBColor[1., 1., 1.], 
                 PolygonBox[{{521.9449999999999, 302.03905243264535`}, {
                  521.9449999999999, 243.914}, {556.1093226919377, 
                  290.9381676425142}, {611.387, 272.977}, {577.2235256317572, 
                  320.}, {611.387, 367.02299999999997`}, {556.1093226919377, 
                  349.06183235748574`}, {521.9449999999999, 
                  396.08599999999996`}, {521.9449999999999, 
                  337.96094756735465`}, {466.668, 320.}}]}}}}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 960.}, {0., 640.}}], ",", 
           GraphicsBox[{{{
               {Thickness[0.0010416666666666667`], {{{
                   {FaceForm[{RGBColor[
                    0.854902, 0.14509800000000003`, 0.11372500000000002`], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 720.}, {960., 720.}, {960., 0.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 0.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{480., 504.}, {
                    435.5, 367.047}, {526.805, 337.383}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{480., 504.}, {
                    524.5, 367.047}, {433.195, 337.383}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{616.953, 
                    404.5}, {472.953, 404.5}, {472.953, 308.5}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{616.953, 
                    404.5}, {500.453, 319.855}, {444.027, 
                    397.52299999999997`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{564.641, 
                    243.5}, {520.145, 380.453}, {428.84000000000003`, 
                    350.789}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{564.641, 
                    243.5}, {448.14500000000004`, 328.14500000000004`}, {
                    504.57, 405.809}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{343.047, 
                    404.5}, {487.047, 404.5}, {487.047, 308.5}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{343.047, 
                    404.5}, {459.547, 319.855}, {515.9730000000001, 
                    397.52299999999997`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    395.35900000000004`, 243.5}, {439.855, 380.453}, {531.16, 
                    350.789}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    395.35900000000004`, 243.5}, {511.855, 
                    328.14500000000004`}, {455.42999999999995`, 
                    405.809}}}]}}}}}}}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 960.}, {0., 720.}}], ",", 
           GraphicsBox[{{{
               {Thickness[0.00078125], {{{
                   {FaceForm[{RGBColor[
                    0.007843139999999998, 0.309804, 0.635294], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 640.}, {1280., 640.}, {1280., 0.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     533.3319999999999}, {1280., 533.3319999999999}, {1280., 
                    106.66799999999984`}, {0., 106.66799999999984`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.9294119999999999, 0.109804, 0.15294100000000005`], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     515.555}, {1280., 515.555}, {1280., 
                    124.44599999999991`}, {0., 124.44599999999991`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{568.891, 320.}, {568.891, 241.453}, {505.215, 
                    177.777}, {426.668, 177.777}, {348.121, 177.777}, {
                    284.445, 241.453}, {284.445, 320.}, {284.445, 398.547}, {
                    348.121, 462.22299999999996`}, {426.668, 
                    462.22299999999996`}, {505.215, 462.22299999999996`}, {
                    568.891, 398.547}, {568.891, 320.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.9294119999999999, 0.109804, 0.15294100000000005`], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{426.668, 
                    457.777}, {384.09, 326.742}, {449.60900000000004`, 
                    305.457}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{426.668, 
                    457.777}, {469.242, 326.742}, {403.727, 305.457}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    557.6990000000001, 362.574}, {419.92199999999997`, 
                    362.574}, {419.92199999999997`, 293.688}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    557.6990000000001, 362.574}, {446.23799999999994`, 
                    281.594}, {405.746, 337.324}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{295.633, 
                    362.574}, {407.09799999999996`, 281.594}, {447.59, 
                    337.324}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{295.633, 
                    362.574}, {433.40999999999997`, 362.574}, {
                    433.40999999999997`, 293.688}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    507.65200000000004`, 208.535}, {465.074, 339.57}, {
                    399.559, 318.28099999999995`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    507.65200000000004`, 208.535}, {396.188, 289.52}, {
                    436.676, 345.25}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{345.684, 
                    208.535}, {457.148, 289.52}, {416.656, 345.25}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{345.684, 
                    208.535}, {388.258, 339.57}, {453.777, 
                    318.28099999999995`}}}]}}}}}}}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 1280.}, {0., 640.}}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           GraphicsBox[{{{
               {Thickness[0.0011111111111111111`], {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {900., 0.}, {900., 600.}, {0., 600.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[0.91, 0.067, 0.17600000000000002`], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{389.99969999999996`, 
                    600.0003}, {389.99969999999996`, 
                    360.00030000000004`}, {-0.0003000000000383807, 
                    360.00030000000004`}, {-0.0003000000000383807, 
                    240.00030000000004`}, {389.99969999999996`, 
                    240.00030000000004`}, {389.99969999999996`, 
                    0.0003000000000383807}, {510.00069999999994`, 
                    0.0003000000000383807}, {510.00069999999994`, 
                    240.00030000000004`}, {899.9997, 240.00030000000004`}, {
                    899.9997, 360.00030000000004`}, {510.00069999999994`, 
                    360.00030000000004`}, {510.00069999999994`, 600.0003}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{172.9215, 539.9021999999999}, {180.2365, 
                    501.41219999999987`}, {180.2365, 461.88819999999987`}, {
                    172.9215, 423.39819999999986`}, {186.4875, 
                    425.09019999999987`}, {200.2125, 425.09019999999987`}, {
                    213.7785, 423.39819999999986`}, {206.4635, 
                    461.88819999999987`}, {206.4635, 501.41219999999987`}, {
                    213.7785, 539.9021999999999}, {200.2125, 
                    538.2091999999999}, {186.4875, 538.2091999999999}, {
                    172.9215, 539.9021999999999}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{251.6022, 502.07849999999996`}, {213.1122, 
                    494.76349999999996`}, {173.5882, 494.76349999999996`}, {
                    135.09820000000002`, 502.07849999999996`}, {
                    136.79020000000003`, 488.5125}, {136.79020000000003`, 
                    474.78749999999997`}, {135.09820000000002`, 461.2215}, {
                    173.5882, 468.53649999999993`}, {213.1122, 
                    468.53649999999993`}, {251.6022, 461.2215}, {249.9092, 
                    474.78749999999997`}, {249.9092, 488.5125}, {251.6022, 
                    502.07849999999996`}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{686.2215, 176.6022}, {693.5365, 138.1122}, {
                    693.5365, 98.5882}, {686.2215, 60.098200000000006`}, {
                    699.7875, 61.79020000000001}, {713.5125, 
                    61.79020000000001}, {727.0785, 60.098200000000006`}, {
                    719.7635, 98.5882}, {719.7635, 138.1122}, {727.0785, 
                    176.6022}, {713.5125, 174.9092}, {699.7875, 174.9092}, {
                    686.2215, 176.6022}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{764.9021999999999, 138.77849999999998`}, {
                    726.4121999999999, 131.46349999999998`}, {
                    686.8881999999999, 131.46349999999998`}, {
                    648.3981999999999, 138.77849999999998`}, {
                    650.0901999999999, 125.21249999999998`}, {
                    650.0901999999999, 111.48749999999998`}, {
                    648.3981999999999, 97.92149999999998}, {686.8881999999999,
                     105.23649999999998`}, {726.4121999999999, 
                    105.23649999999998`}, {764.9021999999999, 
                    97.92149999999998}, {763.2091999999999, 
                    111.48749999999998`}, {763.2091999999999, 
                    125.21249999999998`}, {764.9021999999999, 
                    138.77849999999998`}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{686.2215, 539.9021999999999}, {693.5365, 
                    501.41219999999987`}, {693.5365, 461.88819999999987`}, {
                    686.2215, 423.39819999999986`}, {699.7875, 
                    425.09019999999987`}, {713.5125, 425.09019999999987`}, {
                    727.0785, 423.39819999999986`}, {719.7635, 
                    461.88819999999987`}, {719.7635, 501.41219999999987`}, {
                    727.0785, 539.9021999999999}, {713.5125, 
                    538.2091999999999}, {699.7875, 538.2091999999999}, {
                    686.2215, 539.9021999999999}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{764.9021999999999, 502.07849999999996`}, {
                    726.4121999999999, 494.76349999999996`}, {
                    686.8881999999999, 494.76349999999996`}, {
                    648.3981999999999, 502.07849999999996`}, {
                    650.0901999999999, 488.5125}, {650.0901999999999, 
                    474.78749999999997`}, {648.3981999999999, 461.2215}, {
                    686.8881999999999, 468.53649999999993`}, {
                    726.4121999999999, 468.53649999999993`}, {
                    764.9021999999999, 461.2215}, {763.2091999999999, 
                    474.78749999999997`}, {763.2091999999999, 488.5125}, {
                    764.9021999999999, 502.07849999999996`}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{172.9215, 176.6022}, {180.2365, 138.1122}, {
                    180.2365, 98.5882}, {172.9215, 60.098200000000006`}, {
                    186.4875, 61.79020000000001}, {200.2125, 
                    61.79020000000001}, {213.7785, 60.098200000000006`}, {
                    206.4635, 98.5882}, {206.4635, 138.1122}, {213.7785, 
                    176.6022}, {200.2125, 174.9092}, {186.4875, 174.9092}, {
                    172.9215, 176.6022}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{251.6022, 138.77849999999998`}, {213.1122, 
                    131.46349999999998`}, {173.5882, 131.46349999999998`}, {
                    135.09820000000002`, 138.77849999999998`}, {
                    136.79020000000003`, 125.21249999999998`}, {
                    136.79020000000003`, 111.48749999999998`}, {
                    135.09820000000002`, 97.92149999999998}, {173.5882, 
                    105.23649999999998`}, {213.1122, 105.23649999999998`}, {
                    251.6022, 97.92149999999998}, {249.9092, 
                    111.48749999999998`}, {249.9092, 125.21249999999998`}, {
                    251.6022, 138.77849999999998`}}}]}}}}}}}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 900.}, {0., 600.}}], ",", 
           GraphicsBox[{{{
               {Thickness[0.001388888888888889], {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     480.}, {720., 480.}, {720., 240.}, {0., 
                    240.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.8352940000000001, 0.168627, 0.117647], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     240.}, {720., 240.}, {720., 0.}, {0., 0.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[0., 0.223529, 0.65098], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     320.}, {720., 320.}, {720., 160.}, {0., 160.}}}]}}}}}}}},
            
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 720.}, {0., 480.}}], ",", 
           GraphicsBox[{{{
               {Thickness[0.001893939393939394], {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 384.}, {528., 384.}, {528., 0.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0., 0.21960800000000003`, 0.7215689999999999], Opacity[
                    1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{0., 348.}, {528., 348.}, {528., 288.}, {0., 
                    288.}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     96.}, {528., 96.}, {528., 36.}, {0., 36.}}}]}}}}, {{{
                   {RGBColor[0., 0.21960800000000003`, 0.7215689999999999], 
                    Thickness[0.024999999999999998`], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{264., 
                    261.938}, {203.43, 157.031}, {324.57, 157.031}}},
                    CurveClosed->{1}]}}}}, {{{
                   {RGBColor[0., 0.21960800000000003`, 0.7215689999999999], 
                    Thickness[0.024999999999999998`], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    264.00000000000006`, 122.06200000000018`}, {
                    324.56999999999994`, 226.96900000000002`}, {
                    203.43000000000004`, 226.96900000000002`}}},
                    CurveClosed->{1}]}}}}}}}},
            ImageSize->{{128}, {85}},
            PlotRange->{{0, 528}, {36, 348}}], ",", 
           GraphicsBox[{{{
               {Thickness[0.0008333333333333334], {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 720.}, {1200., 720.}, {1200., 0.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.8078430000000001, 0.06666670000000002, 0.14902], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{1200., 720.}, {
                    296., 720.}, {480., 648.}, {296., 576.}, {480., 504.}, {
                    296., 432.}, {480., 360.}, {296., 288.}, {480., 216.}, {
                    296., 144.}, {480., 72.}, {296., 0.}, {1200., 
                    0.}}}]}}}}}}}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 1200.}, {0., 720.}}], ",", 
           GraphicsBox[{{{
               {Thickness[0.0015625], {{{
                   {FaceForm[{RGBColor[
                    0.8784310000000001, 0., 0.14509800000000003`], Opacity[
                    1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{0., 308.202}, {640., 308.202}, {640., 
                    103.40099999999998`}, {0., 103.40099999999998`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.011764699999999998`, 0.180392, 0.631373], Opacity[1.]}],
                     FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    0., 410.6}, {640., 410.6}, {640., 308.202}, {0., 
                    308.202}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     103.40100000000001`}, {640., 103.40100000000001`}, {640.,
                     0.9990000000000094}, {0., 
                    0.9990000000000094}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{317.59, 
                    285.811}, {317.59, 285.811}, {317.441, 290.022}, {319.895,
                     290.069}, {322.348, 290.022}, {322.199, 285.811}, {
                    322.199, 285.811}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{317.59, 
                    285.811006}, {317.59, 285.811006}, {317.441, 
                    290.02200600000003`}, {319.895, 290.069006}, {322.348, 
                    290.02200600000003`}, {322.199, 285.811006}, {322.199, 
                    285.811006}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}}}, {{{418.93399999999997`, 
                    175.721}, {418.93399999999997`, 196.73299999999998`}, {
                    419.617, 199.39700000000002`}, {421.879, 201.756}, {
                    423.582, 202.225}, {423.582, 221.93200000000002`}, {
                    421.012, 221.93200000000002`}, {419.75, 218.58}, {419.75, 
                    218.58}, {415.375, 199.319}, {415.375, 
                    175.88100000000003`}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}}}, {{{418.93399999999997`, 
                    175.72100600000002`}, {418.93399999999997`, 196.733006}, {
                    419.617, 199.39700600000003`}, {421.879, 201.756006}, {
                    423.582, 202.225006}, {423.582, 221.932006}, {421.012, 
                    221.932006}, {419.75, 218.580006}, {419.75, 218.580006}, {
                    415.375, 199.319006}, {415.375, 175.88100600000004`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    374.449, 217.545}, {380.75800000000004`, 217.545}, {
                    380.75800000000004`, 204.178}, {374.449, 
                    204.178}}}]}}}}, {{{
                   {Thickness[0.001292146875], CapForm["Round"], JoinForm[
                    "Round"], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    374.449, 217.545006}, {380.75800000000004`, 217.545006}, {
                    380.75800000000004`, 204.178006}, {374.449, 204.178006}}},
                    
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    262.316, 217.545}, {378.847, 217.545}, {378.847, 
                    172.70499999999998`}, {262.316, 
                    172.70499999999998`}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm["Round"], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    262.316, 217.545006}, {378.847, 217.545006}, {378.847, 
                    172.705006}, {262.316, 172.705006}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{221.262, 
                    175.79899999999998`}, {221.262, 196.73299999999998`}, {
                    220.578, 199.39700000000002`}, {218.316, 201.756}, {
                    216.61299999999997`, 202.225}, {216.61299999999997`, 
                    220.651}, {220.445, 218.58}, {224.82000000000002`, 
                    199.319}, {224.82000000000002`, 
                    175.79899999999998`}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{221.262, 175.799006}, {
                    221.262, 196.733006}, {220.578, 199.39700600000003`}, {
                    218.316, 201.756006}, {216.61299999999997`, 202.225006}, {
                    216.61299999999997`, 220.65100600000002`}, {220.445, 
                    218.580006}, {224.82000000000002`, 199.319006}, {
                    224.82000000000002`, 175.799006}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}}}, {{{221.262, 175.721}, {
                    221.262, 196.73299999999998`}, {220.578, 
                    199.39700000000002`}, {218.316, 201.756}, {
                    216.61299999999997`, 202.225}, {216.61299999999997`, 
                    221.93200000000002`}, {219.18800000000002`, 
                    221.93200000000002`}, {220.445, 218.58}, {220.445, 
                    218.58}, {224.82000000000002`, 199.319}, {
                    224.82000000000002`, 175.88100000000003`}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}}}, {{{221.262, 
                    175.72100600000002`}, {221.262, 196.733006}, {220.578, 
                    199.39700600000003`}, {218.316, 201.756006}, {
                    216.61299999999997`, 202.225006}, {216.61299999999997`, 
                    221.932006}, {219.18800000000002`, 221.932006}, {220.445, 
                    218.580006}, {220.445, 218.580006}, {224.82000000000002`, 
                    199.319006}, {224.82000000000002`, 175.88100600000004`}}},
                    
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    216.73, 170.354}, {218.535, 171.272}, {220.59, 173.409}, {
                    221.262, 175.79899999999998`}, {418.97299999999996`, 
                    175.79899999999998`}, {419.64500000000004`, 173.409}, {
                    421.699, 171.272}, {423.504, 170.354}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    216.73, 170.35400600000003`}, {218.535, 
                    171.27200599999998`}, {220.59, 173.409006}, {221.262, 
                    175.799006}, {418.97299999999996`, 175.799006}, {
                    419.64500000000004`, 173.409006}, {421.699, 
                    171.27200599999998`}, {423.504, 170.35400600000003`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    372.828, 192.791}, {376.5, 192.791}, {376.5, 175.9}, {
                    372.828, 175.9}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Round"], 
                    JoinForm["Round"], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    372.828, 192.791006}, {376.5, 192.791006}, {376.5, 
                    175.90000600000002`}, {372.828, 175.90000600000002`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    262.316, 201.135}, {378.847, 201.135}, {378.847, 
                    195.92399999999998`}, {262.316, 
                    195.92399999999998`}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm["Round"], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    262.316, 201.135006}, {378.847, 201.135006}, {378.847, 
                    195.924006}, {262.316, 195.924006}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    262.316, 208.202}, {378.847, 208.202}, {378.847, 
                    203.60399999999998`}, {262.316, 
                    203.60399999999998`}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm["Round"], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    262.316, 208.20200599999998`}, {378.847, 
                    208.20200599999998`}, {378.847, 203.60400599999997`}, {
                    262.316, 203.60400599999997`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    262.316, 215.256}, {378.847, 215.256}, {378.847, 
                    210.799}, {262.316, 210.799}}}]}}}}, {{{
                   {Thickness[0.0011818156249999998`], CapForm["Butt"], 
                    JoinForm["Round"], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    262.316, 215.256006}, {378.847, 215.256006}, {378.847, 
                    210.79900600000002`}, {262.316, 210.79900600000002`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    374.449, 217.545}, {380.75800000000004`, 217.545}, {
                    380.75800000000004`, 204.178}, {374.449, 
                    204.178}}}]}}}}, {{{
                   {Thickness[0.001292146875], CapForm["Round"], JoinForm[
                    "Round"], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    374.449, 217.545006}, {380.75800000000004`, 217.545006}, {
                    380.75800000000004`, 204.178006}, {374.449, 204.178006}}},
                    
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{421.484, 
                    170.354}, {419.715, 171.155}, {417.137, 173.342}, {
                    417.137, 175.545}, {417.137, 201.70499999999998`}, {
                    418.348, 203.866}, {373.78099999999995`, 203.866}, {
                    375.52, 201.70499999999998`}, {375.52, 175.545}, {375.52, 
                    173.342}, {373.75, 171.155}, {371.97999999999996`, 
                    170.354}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{421.484, 
                    170.35400600000003`}, {419.715, 171.15500600000001`}, {
                    417.137, 173.342006}, {417.137, 175.545006}, {417.137, 
                    201.705006}, {418.348, 203.86600600000003`}, {
                    373.78099999999995`, 203.86600600000003`}, {375.52, 
                    201.705006}, {375.52, 175.545006}, {375.52, 173.342006}, {
                    373.75, 171.15500600000001`}, {371.97999999999996`, 
                    170.35400600000003`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    292.98799999999994`, 192.791}, {296.65999999999997`, 
                    192.791}, {296.65999999999997`, 175.9}, {
                    292.98799999999994`, 175.9}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Round"], 
                    JoinForm["Round"], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    292.98799999999994`, 192.791006}, {296.65999999999997`, 
                    192.791006}, {296.65999999999997`, 175.90000600000002`}, {
                    292.98799999999994`, 175.90000600000002`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    343.156, 192.791}, {346.82800000000003`, 192.791}, {
                    346.82800000000003`, 175.9}, {343.156, 175.9}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Round"], 
                    JoinForm["Round"], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    343.156, 192.791006}, {346.82800000000003`, 192.791006}, {
                    346.82800000000003`, 175.90000600000002`}, {343.156, 
                    175.90000600000002`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{349.301, 
                    170.354}, {347.22299999999996`, 171.155}, {344.203, 
                    173.342}, {344.203, 175.545}, {344.203, 
                    200.42800000000003`}, {346.90599999999995`, 203.866}, {
                    292.863, 203.866}, {295.453, 200.42800000000003`}, {
                    295.453, 175.545}, {295.453, 173.342}, {293.379, 
                    171.155}, {291.301, 170.354}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{349.301, 
                    170.35400600000003`}, {347.22299999999996`, 
                    171.15500600000001`}, {344.203, 173.342006}, {344.203, 
                    175.545006}, {344.203, 200.428006}, {346.90599999999995`, 
                    203.86600600000003`}, {292.863, 203.86600600000003`}, {
                    295.453, 200.428006}, {295.453, 175.545006}, {295.453, 
                    173.342006}, {293.379, 171.15500600000001`}, {291.301, 
                    170.35400600000003`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    302.47299999999996`, 192.791}, {306.145, 192.791}, {
                    306.145, 175.9}, {302.47299999999996`, 175.9}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Round"], 
                    JoinForm["Round"], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    302.47299999999996`, 192.791006}, {306.145, 192.791006}, {
                    306.145, 175.90000600000002`}, {302.47299999999996`, 
                    175.90000600000002`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    333.51599999999996`, 192.791}, {337.188, 192.791}, {
                    337.188, 175.9}, {333.51599999999996`, 175.9}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Round"], 
                    JoinForm["Round"], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    333.51599999999996`, 192.791006}, {337.188, 192.791006}, {
                    337.188, 175.90000600000002`}, {333.51599999999996`, 
                    175.90000600000002`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{291.895, 232.178}, {291.895, 
                    203.86200000000002`}, {347.215, 203.86200000000002`}, {
                    347.215, 209.959}, {347.29299999999995`, 232.178}, {
                    345.03099999999995`, 231.291}, {344.633, 
                    229.24099999999999`}, {344.633, 229.24099999999999`}, {
                    344.633, 217.178}, {294.715, 217.178}, {294.715, 
                    229.24099999999999`}, {294.715, 229.24099999999999`}, {
                    294.156, 231.291}, {291.895, 232.178}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{291.895, 232.17800599999998`}, {291.895, 
                    203.862006}, {347.215, 203.862006}, {347.215, 
                    209.95900600000002`}, {347.29299999999995`, 
                    232.17800599999998`}, {345.03099999999995`, 231.291006}, {
                    344.633, 229.241006}, {344.633, 229.241006}, {344.633, 
                    217.17800599999998`}, {294.715, 217.17800599999998`}, {
                    294.715, 229.241006}, {294.715, 229.241006}, {294.156, 
                    231.291006}, {291.895, 232.17800599999998`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{339.707, 
                    170.354}, {337.89799999999997`, 171.155}, {
                    333.96099999999996`, 173.342}, {333.96099999999996`, 
                    175.545}, {333.96099999999996`, 203.389}, {334.348, 
                    204.944}, {336.457, 205.86200000000002`}, {337.812, 
                    206.83}, {301.129, 206.83}, {302.875, 205.905}, {304.82, 
                    205.13899999999998`}, {305.52, 203.389}, {305.52, 
                    175.545}, {305.52, 173.342}, {302.402, 171.155}, {
                    300.59799999999996`, 170.354}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{339.707, 
                    170.35400600000003`}, {337.89799999999997`, 
                    171.15500600000001`}, {333.96099999999996`, 173.342006}, {
                    333.96099999999996`, 175.545006}, {333.96099999999996`, 
                    203.38900600000002`}, {334.348, 204.944006}, {336.457, 
                    205.862006}, {337.812, 206.83000600000003`}, {301.129, 
                    206.83000600000003`}, {302.875, 205.90500600000001`}, {
                    304.82, 205.139006}, {305.52, 203.38900600000002`}, {
                    305.52, 175.545006}, {305.52, 173.342006}, {302.402, 
                    171.15500600000001`}, {300.59799999999996`, 
                    170.35400600000003`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{344.629, 
                    206.53}, {344.629, 226.58800000000002`}, {
                    339.60200000000003`, 226.58800000000002`}, {
                    339.60200000000003`, 228.541}, {299.828, 228.541}, {
                    299.828, 226.58800000000002`}, {294.801, 
                    226.58800000000002`}, {294.801, 206.53}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{344.629, 
                    206.53000600000001`}, {344.629, 226.588006}, {
                    339.60200000000003`, 226.588006}, {339.60200000000003`, 
                    228.541006}, {299.828, 228.541006}, {299.828, 
                    226.588006}, {294.801, 226.588006}, {294.801, 
                    206.53000600000001`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    263.234, 192.791}, {266.90999999999997`, 192.791}, {
                    266.90999999999997`, 175.9}, {263.234, 175.9}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Round"], 
                    JoinForm["Round"], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    263.234, 192.791006}, {266.90999999999997`, 192.791006}, {
                    266.90999999999997`, 175.90000600000002`}, {263.234, 
                    175.90000600000002`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{218.539, 
                    170.354}, {220.312, 171.155}, {222.89100000000002`, 
                    173.342}, {222.89100000000002`, 175.545}, {
                    222.89100000000002`, 201.70499999999998`}, {221.676, 
                    203.866}, {266.246, 203.866}, {264.504, 
                    201.70499999999998`}, {264.504, 175.545}, {264.504, 
                    173.342}, {266.277, 171.155}, {268.047, 
                    170.354}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{218.539, 
                    170.35400600000003`}, {220.312, 171.15500600000001`}, {
                    222.89100000000002`, 173.342006}, {222.89100000000002`, 
                    175.545006}, {222.89100000000002`, 201.705006}, {221.676, 
                    203.86600600000003`}, {266.246, 203.86600600000003`}, {
                    264.504, 201.705006}, {264.504, 175.545006}, {264.504, 
                    173.342006}, {266.277, 171.15500600000001`}, {268.047, 
                    170.35400600000003`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    223.312, 221.27599999999998`}, {227.429, 
                    221.27599999999998`}, {227.429, 206.01799999999997`}, {
                    223.312, 206.01799999999997`}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Round"], 
                    JoinForm["Round"], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    223.312, 221.276006}, {227.429, 221.276006}, {227.429, 
                    206.01800599999999`}, {223.312, 206.01800599999999`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    223.289, 224.538}, {227.402, 224.538}, {227.402, 
                    221.323}, {223.289, 221.323}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Round"], 
                    JoinForm["Round"], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    223.289, 224.538006}, {227.402, 224.538006}, {227.402, 
                    221.323006}, {223.289, 221.323006}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{259.051, 
                    170.354}, {257.28099999999995`, 171.155}, {
                    254.69899999999998`, 173.342}, {254.69899999999998`, 
                    175.545}, {254.69899999999998`, 200.424}, {
                    258.40599999999995`, 203.866}, {228.10899999999998`, 
                    203.866}, {231.812, 200.424}, {231.812, 175.545}, {
                    231.812, 173.342}, {229.23399999999998`, 171.155}, {
                    227.465, 170.354}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{259.051, 
                    170.35400600000003`}, {257.28099999999995`, 
                    171.15500600000001`}, {254.69899999999998`, 173.342006}, {
                    254.69899999999998`, 175.545006}, {254.69899999999998`, 
                    200.42400600000002`}, {258.40599999999995`, 
                    203.86600600000003`}, {228.10899999999998`, 
                    203.86600600000003`}, {231.812, 200.42400600000002`}, {
                    231.812, 175.545006}, {231.812, 173.342006}, {
                    229.23399999999998`, 171.15500600000001`}, {227.465, 
                    170.35400600000003`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{254.809, 
                    170.354}, {253.035, 171.155}, {250.45700000000002`, 
                    173.342}, {250.45700000000002`, 175.545}, {
                    250.45700000000002`, 198.038}, {252.883, 
                    201.47899999999998`}, {233.63299999999998`, 
                    201.47899999999998`}, {236.059, 198.038}, {236.059, 
                    175.545}, {236.059, 173.342}, {233.48000000000002`, 
                    171.155}, {231.707, 170.354}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{254.809, 
                    170.35400600000003`}, {253.035, 171.15500600000001`}, {
                    250.45700000000002`, 173.342006}, {250.45700000000002`, 
                    175.545006}, {250.45700000000002`, 198.038006}, {252.883, 
                    201.479006}, {233.63299999999998`, 201.479006}, {236.059, 
                    198.038006}, {236.059, 175.545006}, {236.059, 
                    173.342006}, {233.48000000000002`, 171.15500600000001`}, {
                    231.707, 170.35400600000003`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    412.42199999999997`, 170.354}, {410.65200000000004`, 
                    171.155}, {408.074, 173.342}, {408.074, 175.545}, {
                    408.074, 200.424}, {411.777, 203.866}, {
                    381.47999999999996`, 203.866}, {385.188, 200.424}, {
                    385.188, 175.545}, {385.188, 173.342}, {382.605, 
                    171.155}, {380.83599999999996`, 170.354}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    412.42199999999997`, 170.35400600000003`}, {
                    410.65200000000004`, 171.15500600000001`}, {408.074, 
                    173.342006}, {408.074, 175.545006}, {408.074, 
                    200.42400600000002`}, {411.777, 203.86600600000003`}, {
                    381.47999999999996`, 203.86600600000003`}, {385.188, 
                    200.42400600000002`}, {385.188, 175.545006}, {385.188, 
                    173.342006}, {382.605, 171.15500600000001`}, {
                    380.83599999999996`, 170.35400600000003`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{408.18, 
                    170.354}, {406.40599999999995`, 171.155}, {403.828, 
                    173.342}, {403.828, 175.545}, {403.828, 198.038}, {
                    406.254, 201.47899999999998`}, {387.004, 
                    201.47899999999998`}, {389.42999999999995`, 198.038}, {
                    389.42999999999995`, 175.545}, {389.42999999999995`, 
                    173.342}, {386.85200000000003`, 171.155}, {385.078, 
                    170.354}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{408.18, 
                    170.35400600000003`}, {406.40599999999995`, 
                    171.15500600000001`}, {403.828, 173.342006}, {403.828, 
                    175.545006}, {403.828, 198.038006}, {406.254, 
                    201.479006}, {387.004, 201.479006}, {389.42999999999995`, 
                    198.038006}, {389.42999999999995`, 175.545006}, {
                    389.42999999999995`, 173.342006}, {386.85200000000003`, 
                    171.15500600000001`}, {385.078, 170.35400600000003`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    238.66, 201.47899999999998`}, {247.855, 
                    201.47899999999998`}, {247.855, 170.35399999999998`}, {
                    238.66, 170.35399999999998`}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    238.66, 201.479006}, {247.855, 201.479006}, {247.855, 
                    170.354006}, {238.66, 170.354006}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    331.78099999999995`, 170.354}, {330.012, 171.155}, {
                    327.42999999999995`, 173.342}, {327.42999999999995`, 
                    175.545}, {327.42999999999995`, 199.319}, {328.887, 
                    201.47899999999998`}, {310.77, 201.47899999999998`}, {
                    312.227, 199.319}, {312.227, 175.545}, {312.227, 
                    173.342}, {309.64500000000004`, 171.155}, {307.875, 
                    170.354}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    331.78099999999995`, 170.35400600000003`}, {330.012, 
                    171.15500600000001`}, {327.42999999999995`, 173.342006}, {
                    327.42999999999995`, 175.545006}, {327.42999999999995`, 
                    199.319006}, {328.887, 201.479006}, {310.77, 
                    201.479006}, {312.227, 199.319006}, {312.227, 
                    175.545006}, {312.227, 173.342006}, {309.64500000000004`, 
                    171.15500600000001`}, {307.875, 170.35400600000003`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    315.23799999999994`, 201.467}, {324.41799999999995`, 
                    201.467}, {324.41799999999995`, 170.36200000000002`}, {
                    315.23799999999994`, 170.36200000000002`}}}]}}}}, {{{
                   {Thickness[0.0012262218749999998`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    315.23799999999994`, 201.46700600000003`}, {
                    324.41799999999995`, 201.46700600000003`}, {
                    324.41799999999995`, 170.36200600000004`}, {
                    315.23799999999994`, 170.36200600000004`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    392.03099999999995`, 201.47899999999998`}, {
                    401.22599999999994`, 201.47899999999998`}, {
                    401.22599999999994`, 170.35399999999998`}, {
                    392.03099999999995`, 170.35399999999998`}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    392.03099999999995`, 201.479006}, {401.22599999999994`, 
                    201.479006}, {401.22599999999994`, 170.354006}, {
                    392.03099999999995`, 170.354006}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    310.617, 213.29899999999998`}, {329.043, 
                    213.29899999999998`}, {329.043, 206.51}, {310.617, 
                    206.51}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm["Round"], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    310.617, 213.299006}, {329.043, 213.299006}, {329.043, 
                    206.510006}, {310.617, 206.510006}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}}}, {{{329.242, 208.315}, {
                    329.26599999999996`, 210.36200000000002`}, {335.219, 
                    210.455}, {338.28499999999997`, 212.202}, {301.469, 
                    212.202}, {304.53499999999997`, 210.455}, {310.355, 
                    210.311}, {310.355, 208.315}, {311.60200000000003`, 
                    204.33800000000002`}, {326.84000000000003`, 
                    203.72899999999998`}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm["Round"], 
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}}}, {{{329.242, 208.315006}, {
                    329.26599999999996`, 210.362006}, {335.219, 
                    210.45500600000003`}, {338.28499999999997`, 
                    212.20200599999998`}, {301.469, 212.20200599999998`}, {
                    304.53499999999997`, 210.45500600000003`}, {310.355, 
                    210.31100600000002`}, {310.355, 208.315006}, {
                    311.60200000000003`, 204.338006}, {326.84000000000003`, 
                    203.729006}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    336.43799999999993`, 229.959}, {336.43799999999993`, 
                    234.975}, {336.648, 236.909}, {338.191, 236.909}, {
                    338.191, 220.955}, {334.40999999999997`, 219.584}, {
                    331.715, 214.76}, {331.715, 214.76}, {307.945, 214.76}, {
                    307.945, 214.76}, {305.246, 219.584}, {301.469, 
                    220.955}, {301.469, 236.909}, {303.367, 236.909}, {
                    303.379, 234.889}, {303.379, 229.959}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    336.43799999999993`, 229.95900600000002`}, {
                    336.43799999999993`, 234.975006}, {336.648, 236.909006}, {
                    338.191, 236.909006}, {338.191, 220.95500600000003`}, {
                    334.40999999999997`, 219.58400600000002`}, {331.715, 
                    214.760006}, {331.715, 214.760006}, {307.945, 
                    214.760006}, {307.945, 214.760006}, {305.246, 
                    219.58400600000002`}, {301.469, 220.95500600000003`}, {
                    301.469, 236.909006}, {303.367, 236.909006}, {303.379, 
                    234.88900600000002`}, {303.379, 229.95900600000002`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    308.29699999999997`, 226.98700000000002`}, {
                    311.35900000000004`, 223.311}, {311.074, 217.077}, {
                    311.039, 213.401}, {328.801, 213.401}, {
                    328.76599999999996`, 217.077}, {328.47999999999996`, 
                    223.311}, {331.543, 226.98700000000002`}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    308.29699999999997`, 226.98700600000004`}, {
                    311.35900000000004`, 223.31100600000002`}, {311.074, 
                    217.077006}, {311.039, 213.40100600000002`}, {328.801, 
                    213.40100600000002`}, {328.76599999999996`, 217.077006}, {
                    328.47999999999996`, 223.31100600000002`}, {331.543, 
                    226.98700600000004`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    226.14499999999998`, 192.791}, {229.81699999999998`, 
                    192.791}, {229.81699999999998`, 175.9}, {
                    226.14499999999998`, 175.9}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Round"], 
                    JoinForm["Round"], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    226.14499999999998`, 192.791006}, {229.81699999999998`, 
                    192.791006}, {229.81699999999998`, 175.90000600000002`}, {
                    226.14499999999998`, 175.90000600000002`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    412.719, 221.27599999999998`}, {416.832, 
                    221.27599999999998`}, {416.832, 206.01799999999997`}, {
                    412.719, 206.01799999999997`}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Round"], 
                    JoinForm["Round"], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    412.719, 221.276006}, {416.832, 221.276006}, {416.832, 
                    206.01800599999999`}, {412.719, 206.01800599999999`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    216.73, 170.35400600000003`}, {218.535, 
                    171.27200599999998`}, {220.59, 173.409006}, {221.262, 
                    175.799006}, {418.97299999999996`, 175.799006}, {
                    419.64500000000004`, 173.409006}, {421.699, 
                    171.27200599999998`}, {423.504, 170.35400600000003`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    257.633, 192.791}, {261.305, 192.791}, {261.305, 175.9}, {
                    257.633, 175.9}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Round"], 
                    JoinForm["Round"], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    257.633, 192.791006}, {261.305, 192.791006}, {261.305, 
                    175.90000600000002`}, {257.633, 175.90000600000002`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{220.434, 226.475}, {220.434, 203.866}, {223.004, 
                    203.866}, {223.004, 226.53}, {222.078, 
                    226.99800000000002`}, {221.207, 227.07299999999998`}, {
                    220.434, 226.475}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{220.434, 226.475006}, {220.434, 
                    203.86600600000003`}, {223.004, 203.86600600000003`}, {
                    223.004, 226.53000600000001`}, {222.078, 226.998006}, {
                    221.207, 227.073006}, {220.434, 226.475006}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}}}, {{{220.516, 
                    211.846}, {223.70299999999997`, 210.21699999999998`}, {
                    226.859, 208.33}, {227.656, 203.866}, {220.516, 
                    203.866}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}}}, {{{220.516, 
                    211.84600600000002`}, {223.70299999999997`, 210.217006}, {
                    226.859, 208.33000600000003`}, {227.656, 
                    203.86600600000003`}, {220.516, 203.86600600000003`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    259.39099999999996`, 217.545}, {265.7, 217.545}, {265.7, 
                    204.178}, {259.39099999999996`, 204.178}}}]}}}}, {{{
                   {Thickness[0.001292146875], CapForm["Round"], JoinForm[
                    "Round"], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    259.39099999999996`, 217.545006}, {265.7, 217.545006}, {
                    265.7, 204.178006}, {259.39099999999996`, 204.178006}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{264.719, 218.62}, {264.719, 203.866}, {266.801, 
                    203.866}, {266.801, 218.655}, {266.15200000000004`, 
                    218.959}, {265.262, 219.006}, {264.719, 218.62}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{264.719, 218.620006}, {264.719, 
                    203.86600600000003`}, {266.801, 203.86600600000003`}, {
                    266.801, 218.65500600000001`}, {266.15200000000004`, 
                    218.95900600000002`}, {265.262, 219.006006}, {264.719, 
                    218.620006}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}}}, CompressedData["
1:eJxlVWtIFFEU3t20l2WmoRK2aoVFFhIUsUl1/BEmZQ8LiwoRKYtyZ69z75Rp
SiEhEWFSUBARS5nUD1nEFokISwnzx6KlVIpJpPQyou2xWATdx8wZ1gbmx8e9
c875vvOdM5llvqLD0xwOh5O/5fx18feqlljfOYfCnevdGYFHFWDh8PPCsgTm
hQ2zX94icRTO55WO94W8kBHQjzaN6rD/UO7ojkEvPN267nzeGx0m6449ZCna
f/jJz+UHG1/pKn61Bkn1nb3+cR3iV7Xd+NqiqfgRHZJfhyK7l2iQ/7Z6QWsK
hce9/s3BXBs3fTm9aa1u4w9/7n577tdgo/g+lkKrOAhpkCYK4/XFFPMMeT5Y
JPALXdVR7lN1D+tgXE6NKR7ywbtmXtiEDpzd4mEngfs9Jx7dDOuw8yJX4qZ5
/lsH73ueUPOp/PMo4poFPHOajRMFv2Wmfmds3CXyt03BYZ/SYT6F4Pe/A1Wz
CBwVRGdQWCnkySJKd54//dznXR1bCAh5S6dR6BaNOE5UnlQKCfs87T11RNWR
QeFBwRxXdiGBDjf/0G3e95h4jY1l/FIzfz4BIXMJPxc26G0git8KCqc+Zq2e
eY3AXFFvOgUh1+Q9ovzgoaq+vv+x1Cvf5HObwGAVD7SNwjMu80I/Uf0/YNbb
TEDIHdAowNqSBwX3zPsVFJzZDcmvnxLlzz0UigSREaL020xBlFk9QSBnZOn0
szzfwUbecVel0msvhRZhzCQTH6GwScT/QWAFDxuqobC9jCv4i4BIE6o1659Z
qfQkJt5Zqfp3gSGWfq5lik+ciU8xxSdCQMhUd4WBSwQOEzjJr+U0M6xHhHHf
Z1iv5B9kyEf6uYUhX9mfSwz1kPwvMtRLxvMz1FPeDzDUW/JpZ9gPMQbxXQz7
NRVLfw0xGBNEggTWt/MB6WfoBznvPQz9IvW8ztBP1nmU/97YWPpjmKFf5ZyO
MfSznIdJhn6X/XEa0fPwk+G8yD3zieE8Sb4DDOctCrfZ2JpXj+A3yqLne8LG
/aKfLgOx1H+WgftC9jvBwH0i902mgftG1rfcwH0k/Zxm4L6S/ogw3GcyP9fD
2ncWtvahha19Kb+PNXCfVog6kw3ctw7xLDVwH0t/uA3c11Ox9MMiA/e99Nc3
hv8D6c+vDP8XFrb+J/8ApYz8HQ==
                    "]]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}}}, CompressedData["
1:eJxlVWtIFFEUVrPSnrZKRW2mFWb2kCCz7XkMYnsYVpQ9MelhRu7sde6dMrei
shKJMC0qiLKlzDIqWUokSKRCRdBWS3osKdI7DVMysaKae2fmLNrA/PiYmXvO
953vfBO+zb5mZz8fHx9f9U5Rbz/1Pi+ZsiqGUNjauHF6SXkaGPjWkLdSELPB
gkEvrpLBFBY7ujrcdTYIK5FT85plCL7sbk1otEHliticuCYZXGV/q9ko6T/8
qCtyS+5LWTs/U4LgrIoa53sZKlOsxe1FknZ+twxPTTv8106UwNqSGXJnFIVM
/9g1pfO8ePlkU3yM7MXOmEV/GpwSLOTf96ew68je7JA6CcybdsxrVvt7mHvV
4oqzwziOn8ngiC5PzU2xA4cJHhlm1N4OSnxth7eFF5+Etckw/+jYKR5fAver
95YXdMoQWDXNYSrQn/+UISI8r7RDsmv1h1PEjpA71hazF5s4v8kUirl+h71Y
1Hf1wZ12GDbddal9BIX800s9GYEEUvO+Hlg0kMKghE9dRREEcuKS37vV+r/C
Z28oW0qAy5vcj8KVhz8zUvcQ6GxYuS1oNIWv37MeVB8iYPv462ZHGIXzHxID
pq4kUBZ6vHV1qKoXf9+i41leLM5PpnCG17cSUKvHJKnP4+/WVtZkE41fFIV1
J9JjAy4QGMr7HU/hkc3W0lNMND9YqNaf+38s9LLqfK4RaMz4HDEznkJhcOD1
MU6izX+z3m8hAS53iUTB3HCjYlmx/n4ahaaqevOrSqL5cy2FGet2n2x9QzT9
llD4tjz/Y2Ybgeg3kwYcUevNmTb0d6RfuqbXegrHtp9bkBOs4136+d8JRGWP
fFXnoBD1d1OS5QeBqRwf1PsPSNf0JDpela7N7yRDLPx8kGl8But4P4NznE83
AfcET8+hs0zrv5PAvvKCMdGFDPtRp1EWep9hv4J/KUM+ws9FDPmK+ZxmqIfg
f4qhXuI8J0M9xfslDPUWfO4xnMeZ0f6Jwx4znFdfLPz1mmnzLiUw9566IPUM
/SD2vZqhX4SeFxn6yXjey39NXiz84WHoV5EX7xj6WexDD0O/i/n4Kr33oYvh
vlzn+n1huE+C73OG+9YLu7zY2FcL59fMeu93mxfX83n6KYiF/oEK5oWYd5CC
eSLyJlzBvBH9RSqYR8LPZgXzSvijm2GeifqqHkbeGdjIQwMbeSm+769gnqZx
fiMVzFsffk1SMI+FP0IVzOu+WPhhnIJ5L/zVwfB/IPzZzvB/YWDjf/IPab3x
Fw==
                    "],
                    CurveClosed->{1}]}}}}, {{{
                   {Thickness[0.001], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{311.277, 271.655006}, {
                    328.816, 271.655006}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    318.28099999999995`, 269.10400000000004`}, {315.848, 
                    270.358}, {315.848, 273.94}, {316.84400000000005`, 
                    273.639}, {317.96099999999996`, 273.518}, {318.066, 
                    271.93199999999996`}, {318.414, 274.194}, {319.039, 
                    274.084}, {320.02, 274.967}, {321., 274.084}, {321.625, 
                    274.194}, {321.97299999999996`, 271.93199999999996`}, {
                    322.082, 273.518}, {323.199, 273.639}, {324.191, 
                    273.94}, {324.191, 270.358}, {321.758, 
                    269.10400000000004`}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    318.28099999999995`, 269.104006}, {315.848, 
                    270.35800600000005`}, {315.848, 273.94000600000004`}, {
                    316.84400000000005`, 273.639006}, {317.96099999999996`, 
                    273.518006}, {318.066, 271.932006}, {318.414, 
                    274.194006}, {319.039, 274.08400600000004`}, {320.02, 
                    274.967006}, {321., 274.08400600000004`}, {321.625, 
                    274.194006}, {321.97299999999996`, 271.932006}, {322.082, 
                    273.518006}, {323.199, 273.639006}, {324.191, 
                    273.94000600000004`}, {324.191, 270.35800600000005`}, {
                    321.758, 269.104006}}},
                    CurveClosed->{1}]}}}}, {{{
                   {Thickness[0.001], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{309.195, 266.178006}, {
                    330.621, 266.178006}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    318.117, 263.22499999999997`}, {314.078, 266.002}, {
                    314.078, 269.303}, {315.4959999999999, 
                    268.97499999999997`}, {317.08599999999996`, 
                    268.84200000000004`}, {317.242, 267.10400000000004`}, {
                    317.734, 269.584}, {318.625, 270.87}, {320.02, 271.834}, {
                    321.41799999999995`, 270.87}, {322.309, 269.584}, {
                    322.801, 267.10400000000004`}, {322.957, 
                    268.84200000000004`}, {324.547, 268.97499999999997`}, {
                    325.965, 269.303}, {325.965, 266.002}, {
                    321.92199999999997`, 263.22499999999997`}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    318.117, 263.225006}, {314.078, 266.002006}, {314.078, 
                    269.303006}, {315.4959999999999, 268.975006}, {
                    317.08599999999996`, 268.84200599999997`}, {317.242, 
                    267.104006}, {317.734, 269.58400600000004`}, {318.625, 
                    270.870006}, {320.02, 271.83400600000004`}, {
                    321.41799999999995`, 270.870006}, {322.309, 
                    269.58400600000004`}, {322.801, 267.104006}, {322.957, 
                    268.84200599999997`}, {324.547, 268.975006}, {325.965, 
                    269.303006}, {325.965, 266.002006}, {321.92199999999997`, 
                    263.225006}}},
                    CurveClosed->{1}]}}}}, {{{
                   {Thickness[0.001], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{307.121, 259.534006}, {
                    332.625, 259.534006}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    317.832, 254.069}, {313.188, 258.14700000000005`}, {
                    313.188, 262.99799999999993`}, {314.816, 262.514}, {
                    316.64500000000004`, 262.319}, {316.824, 259.764}, {
                    317.39099999999996`, 263.409}, {318.414, 
                    265.29499999999996`}, {320.02, 266.71299999999997`}, {
                    321.629, 265.29499999999996`}, {322.648, 263.409}, {
                    323.219, 259.764}, {323.395, 262.319}, {325.227, 
                    262.514}, {326.855, 262.99799999999993`}, {326.855, 
                    258.14700000000005`}, {322.207, 254.069}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    317.832, 254.069006}, {313.188, 258.14700600000003`}, {
                    313.188, 262.99800600000003`}, {314.816, 262.514006}, {
                    316.64500000000004`, 262.319006}, {316.824, 259.764006}, {
                    317.39099999999996`, 263.409006}, {318.414, 265.295006}, {
                    320.02, 266.71300599999995`}, {321.629, 265.295006}, {
                    322.648, 263.409006}, {323.219, 259.764006}, {323.395, 
                    262.319006}, {325.227, 262.514006}, {326.855, 
                    262.99800600000003`}, {326.855, 258.14700600000003`}, {
                    322.207, 254.069006}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    326.39799999999997`, 248.647}, {322.199, 242.834}, {
                    317.441, 242.834}, {313.23799999999994`, 
                    248.647}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    326.39799999999997`, 248.647006}, {322.199, 
                    242.83400600000002`}, {317.441, 242.83400600000002`}, {
                    313.23799999999994`, 248.647006}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    310.82, 238.893}, {312.92199999999997`, 
                    237.74499999999998`}, {313.699, 235.455}, {
                    313.92199999999997`, 231.159}, {325.75, 231.159}, {
                    325.97299999999996`, 235.455}, {326.75, 
                    237.74499999999998`}, {328.85200000000003`, 
                    238.893}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    310.82, 238.893006}, {312.92199999999997`, 237.745006}, {
                    313.699, 235.45500600000003`}, {313.92199999999997`, 
                    231.159006}, {325.75, 231.159006}, {325.97299999999996`, 
                    235.45500600000003`}, {326.75, 237.745006}, {
                    328.85200000000003`, 238.893006}}},
                    CurveClosed->{1}]}}}}, {{{
                   {Thickness[0.001], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{304.945, 251.412006}, {
                    335.191, 251.412006}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.001], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{304.25, 242.159006}, {
                    335.40599999999995`, 242.159006}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}}}, {{{329.027, 248.647}, {
                    329.027, 254.48700000000002`}, {327.03099999999995`, 
                    253.936}, {325.73799999999994`, 252.752}, {325.16, 
                    251.151}, {325.16, 253.08800000000002`}, {
                    322.60900000000004`, 257.557}, {319.828, 259.78}, {
                    317.039, 257.29099999999994`}, {314.445, 253.248}, {
                    314.4959999999999, 251.151}, {314.02299999999997`, 
                    252.678}, {312.629, 253.936}, {310.629, 
                    254.48700000000002`}, {310.629, 248.647}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm["Round"], 
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}}}, {{{329.027, 248.647006}, {
                    329.027, 254.48700600000004`}, {327.03099999999995`, 
                    253.93600600000002`}, {325.73799999999994`, 252.752006}, {
                    325.16, 251.15100600000002`}, {325.16, 253.088006}, {
                    322.60900000000004`, 257.557006}, {319.828, 
                    259.78000599999996`}, {317.039, 257.29100600000004`}, {
                    314.445, 253.24800599999998`}, {314.4959999999999, 
                    251.15100600000002`}, {314.02299999999997`, 
                    252.67800599999998`}, {312.629, 253.93600600000002`}, {
                    310.629, 254.48700600000004`}, {310.629, 248.647006}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}}}, {{{329.90999999999997`, 
                    238.893}, {329.90999999999997`, 244.72899999999998`}, {
                    327.72299999999996`, 244.18200000000002`}, {326.305, 
                    242.99800000000002`}, {325.672, 241.393}, {325.672, 
                    243.334}, {322.879, 247.803}, {319.828, 250.026}, {316.77,
                     247.538}, {313.92599999999993`, 243.495}, {313.984, 
                    241.393}, {313.465, 242.924}, {311.93399999999997`, 
                    244.18200000000002`}, {309.746, 244.72899999999998`}, {
                    309.746, 238.893}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm["Round"], 
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}}}, {{{329.90999999999997`, 
                    238.893006}, {329.90999999999997`, 244.729006}, {
                    327.72299999999996`, 244.182006}, {326.305, 242.998006}, {
                    325.672, 241.393006}, {325.672, 243.33400600000002`}, {
                    322.879, 247.803006}, {319.828, 250.02600600000002`}, {
                    316.77, 247.538006}, {313.92599999999993`, 
                    243.49500600000002`}, {313.984, 241.393006}, {313.465, 
                    242.92400600000002`}, {311.93399999999997`, 244.182006}, {
                    309.746, 244.729006}, {309.746, 238.893006}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}}}, {{{332.371, 226.909}, {
                    332.371, 233.64299999999997`}, {329.648, 232.944}, {
                    327.957, 230.92800000000003`}, {327.10200000000003`, 
                    229.752}, {327.10200000000003`, 233.401}, {322.984, 
                    238.959}, {319.828, 240.78}, {316.594, 
                    238.91299999999998`}, {312.559, 233.166}, {312.559, 
                    229.752}, {311.676, 230.92000000000002`}, {310.008, 
                    232.944}, {307.28499999999997`, 233.64299999999997`}, {
                    307.28499999999997`, 226.909}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm["Round"], 
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}}}, {{{332.371, 226.909006}, {
                    332.371, 233.64300599999999`}, {329.648, 232.944006}, {
                    327.957, 230.928006}, {327.10200000000003`, 229.752006}, {
                    327.10200000000003`, 233.40100600000002`}, {322.984, 
                    238.95900600000002`}, {319.828, 240.780006}, {316.594, 
                    238.912006}, {312.559, 233.166006}, {312.559, 
                    229.752006}, {311.676, 230.920006}, {310.008, 
                    232.944006}, {307.28499999999997`, 233.64300599999999`}, {
                    307.28499999999997`, 226.909006}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}}}, {{{330.89799999999997`, 
                    211.959}, {330.89799999999997`, 218.88500000000002`}, {
                    328.4959999999999, 217.944}, {327.777, 215.627}, {327.02, 
                    214.053}, {327.316, 221.077}, {323.066, 228.627}, {
                    319.828, 230.541}, {316.59, 228.627}, {312.258, 
                    220.916}, {312.637, 214.053}, {311.85900000000004`, 
                    215.61599999999999`}, {311.16, 217.944}, {308.758, 
                    218.88500000000002`}, {308.758, 211.959}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm["Round"], 
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}}}, {{{330.89799999999997`, 
                    211.95900600000002`}, {330.89799999999997`, 
                    218.88500600000003`}, {328.4959999999999, 217.944006}, {
                    327.777, 215.62700600000002`}, {327.02, 214.053006}, {
                    327.316, 221.077006}, {323.066, 228.62700600000002`}, {
                    319.828, 230.541006}, {316.59, 228.62700600000002`}, {
                    312.258, 220.916006}, {312.637, 214.053006}, {
                    311.85900000000004`, 215.616006}, {311.16, 217.944006}, {
                    308.758, 218.88500600000003`}, {308.758, 
                    211.95900600000002`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    412.746, 224.538}, {416.859, 224.538}, {416.859, 
                    221.323}, {412.746, 221.323}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Round"], 
                    JoinForm["Round"], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    412.746, 224.538006}, {416.859, 224.538006}, {416.859, 
                    221.323006}, {412.746, 221.323006}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    378.777, 192.791}, {382.449, 192.791}, {382.449, 175.9}, {
                    378.777, 175.9}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Round"], 
                    JoinForm["Round"], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    378.777, 192.791006}, {382.449, 192.791006}, {382.449, 
                    175.90000600000002`}, {378.777, 175.90000600000002`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    410.262, 192.791}, {413.934, 192.791}, {413.934, 175.9}, {
                    410.262, 175.9}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Round"], 
                    JoinForm["Round"], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    410.262, 192.791006}, {413.934, 192.791006}, {413.934, 
                    175.90000600000002`}, {410.262, 175.90000600000002`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{294.801, 
                    211.95900600000002`}, {344.629, 211.95900600000002`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    310.617, 211.952006}, {329.086, 211.952006}, {329.086, 
                    205.16700600000001`}, {310.617, 205.16700600000001`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}}}, {{{329.215, 
                    201.47899999999998`}, {329.215, 208.401}, {326.695, 
                    207.803}, {326.543, 206.873}, {325.742, 205.323}, {
                    326.039, 209.518}, {323.066, 214.303}, {319.828, 
                    216.21699999999998`}, {316.59, 214.303}, {313.621, 
                    209.518}, {313.91799999999995`, 205.323}, {313.117, 
                    206.873}, {313.01599999999996`, 207.803}, {310.441, 
                    208.401}, {310.441, 201.47899999999998`}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}}}, {{{329.215, 201.479006}, {
                    329.215, 208.40100600000002`}, {326.695, 207.803006}, {
                    326.543, 206.873006}, {325.742, 205.32300600000002`}, {
                    326.039, 209.51800599999999`}, {323.066, 214.303006}, {
                    319.828, 216.217006}, {316.59, 214.303006}, {313.621, 
                    209.51800599999999`}, {313.91799999999995`, 
                    205.32300600000002`}, {313.117, 206.873006}, {
                    313.01599999999996`, 207.803006}, {310.441, 
                    208.40100600000002`}, {310.441, 201.479006}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}}}, {{{266.801, 
                    211.846}, {263.613, 210.21699999999998`}, {260.457, 
                    208.33}, {259.66, 203.866}, {266.801, 
                    203.866}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}}}, {{{266.801, 
                    211.84600600000002`}, {263.613, 210.217006}, {260.457, 
                    208.33000600000003`}, {259.66, 203.86600600000003`}, {
                    266.801, 203.86600600000003`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    223.004, 221.27599999999998`}, {227.42999999999998`, 
                    221.27599999999998`}, {227.42999999999998`, 
                    203.95999999999998`}, {223.004, 
                    203.95999999999998`}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Round"], 
                    JoinForm["Round"], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    223.004, 221.276006}, {227.42999999999998`, 221.276006}, {
                    227.42999999999998`, 203.960006}, {223.004, 203.960006}}},
                    
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    223.004, 224.538}, {227.402, 224.538}, {227.402, 
                    221.323}, {223.004, 221.323}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Round"], 
                    JoinForm["Round"], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    223.004, 224.538006}, {227.402, 224.538006}, {227.402, 
                    221.323006}, {223.004, 221.323006}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    259.39099999999996`, 217.545}, {265.7, 217.545}, {265.7, 
                    204.178}, {259.39099999999996`, 204.178}}}]}}}}, {{{
                   {Thickness[0.001292146875], CapForm["Round"], JoinForm[
                    "Round"], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    259.39099999999996`, 217.545006}, {265.7, 217.545006}, {
                    265.7, 204.178006}, {259.39099999999996`, 204.178006}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJ7IGYCYqstJ8r2Zec45D7/vfJjU6YDjC9289z3YPNc
h8dLZx9RmILgc19fXGA7K8dhp1zr68A1OQ5VIuvcH35D8B0Tnl5QUs+F8126
c57/Vsx1OL3QddvnpzkOsbs8eZjYcx3ctn3+e0Uk1yEOxH+f41A6WYIlzC7X
IWPi2xr7izkOB04BNZTnOgg3A1k/cxwOf9WI6X8ElReF6p+Q6xDOp7tpbnyu
QwfI4rJcB5AzHwfmOgBdVSWyCupeq1wHkDZTpjwHLhAf6N5kgQjLLQJ5EPM0
cx1sQRIz8yDusc6F+Fc9D+L/Fqh/dPIcQMbEFeU6LAMKb8iD8uNyHaJSrO/7
78xzWAT05l+TXAeQs95fz3NgAIEMqLxjvkMByCKgeSxhQBUn8xzU2BqnOq/O
hbjnAoIPjg+pfDi/PmtPyeSOfEj4Lc916AT5918+1L48B6BrijJECzD4QFfv
kLPNcwBFw0r3AodVHy/5JhUg+EWgAFiM4IPjfzVCPzofHB+W+XD79e+qsDWa
5sPdB+PD3A/jw/wHDs+YfLj/b/2sy9pTkQ8PH4h9+fDwA4dvUz48fMH8vHx4
+BeCwhNoHix+vgGTyaGl+fD4A/tvez48fi8p3f5Z9yofHv8XQPxl+fD0UQ1K
z3358PQDDr/GfHj6KgaZdzofnv7A6f15Pjx9grStYy+Ap1+wez7mw9M3mH8z
H57+Z+QJNR/Ylw/PH+Dw3ZkPzz9g9S8R/PJ986X0lQvg/B0gWq0Anj8vgvxj
hcmH5W8Ajzbb3g==
                    "]]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJ7IGYCYqstJ8r2Zec4qCpO3PaxKdMBxj8vlMISYp7r
8Hjp7CMKUxB87uuLC2xn5TgURUj9CFyT41Alss794TcE3zHh6QUl9Vw436U7
5/lvxVyHltu3Dn1+muMQu8uTh4k91+H/+w6uqyK5DnEg/vscB92zawXC7HId
Mia+rbG/mONQyWIetK0810G4+cCphT9zHKr192X0P4LKi0L1T8h1COfT3TQ3
PtfBsfrrxwtluQ43z30PfhyY65DeWNYusgrqXqtcBy91IR9TpjwHLhAf6F5p
r7euWwTyIOZp5jp8c87ZUDAzD+Ie61yIf9XzIP5vgfpHJ88BqNo0rijXIf5q
pO6GPCg/DujOeRde++/Mc1jkuu3zX5Nch2Np7qveX89zYACBDKi8Y75DgS3Q
BUDz9vYvttx0Ms9Bja1xqvPqXIh7LiD44PiQyofzzZcENk7uyIeE3/JcByeQ
f//lQ+3Lc1i491dFhmgBBr/1deAOOVugPzmNmFa5Fzis+njJN6kAwS8CBcBi
BB8c/6sR+tH54PiwzIfbr39Xha3RNB/uPhgf5n4YH+Y/cHjG5MP9f+tnXdae
inx4+EDsy4eHHzh8m/Lh4Qvm5+XDw78QFJ5A82Dx800jpv/Q0nx4/IH9tz0f
Hr+XlG7/rHuVD4//CyD+snx4+qgGpee+fHj6AYdfYz48fRWDzDudD09/4PT+
PB+ePt0fAnMEewE8/YLd8zEfnr7B/Jv58PQ/I0+o+cC+fHj+AIfvznx4/gGr
f4ngl++bL6WvXADn75ADulCtAJ4/L4L8Y4XJh+VvAFeLyus=
                    "],
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    245.73, 246.42000000000002`}, {247.59, 
                    247.97899999999998`}, {247.59, 249.97899999999998`}, {
                    246.91, 249.91299999999998`}, {246.539, 249.678}, {
                    246.035, 249.02200000000002`}, {245.60899999999998`, 
                    250.346}, {244.672, 251.38100000000003`}, {243.414, 
                    252.026}, {242.15200000000002`, 251.38100000000003`}, {
                    241.21499999999997`, 250.393}, {240.789, 249.069}, {
                    240.285, 249.725}, {239.914, 249.91299999999998`}, {
                    239.23399999999998`, 249.97899999999998`}, {
                    239.23399999999998`, 247.97899999999998`}, {241.094, 
                    246.42000000000002`}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    245.73, 246.420006}, {247.59, 247.979006}, {247.59, 
                    249.979006}, {246.91, 249.912006}, {246.539, 
                    249.67800599999998`}, {246.035, 249.022006}, {
                    245.60899999999998`, 250.34600600000002`}, {244.672, 
                    251.38100600000004`}, {243.414, 252.02600600000002`}, {
                    242.15200000000002`, 251.38100600000004`}, {
                    241.21499999999997`, 250.393006}, {240.789, 249.069006}, {
                    240.285, 249.725006}, {239.914, 249.912006}, {
                    239.23399999999998`, 249.979006}, {239.23399999999998`, 
                    247.979006}, {241.094, 246.420006}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    246.727, 241.405}, {247.59, 243.27599999999998`}, {247.59,
                     245.873}, {246.91, 245.80700000000002`}, {246.539, 
                    245.569}, {246.035, 244.901}, {245.60899999999998`, 
                    246.248}, {244.672, 247.295}, {243.414, 247.948}, {
                    242.15200000000002`, 247.295}, {241.21499999999997`, 
                    246.295}, {240.789, 244.95200000000003`}, {240.285, 
                    245.61599999999999`}, {239.914, 245.80700000000002`}, {
                    239.23399999999998`, 245.873}, {239.23399999999998`, 
                    243.27599999999998`}, {240.098, 241.405}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    246.727, 241.40500600000001`}, {247.59, 243.276006}, {
                    247.59, 245.873006}, {246.91, 245.80700600000003`}, {
                    246.539, 245.569006}, {246.035, 244.90100600000002`}, {
                    245.60899999999998`, 246.24800599999998`}, {244.672, 
                    247.295006}, {243.414, 247.948006}, {242.15200000000002`, 
                    247.295006}, {241.21499999999997`, 246.295006}, {240.789, 
                    244.952006}, {240.285, 245.616006}, {239.914, 
                    245.80700600000003`}, {239.23399999999998`, 245.873006}, {
                    239.23399999999998`, 243.276006}, {240.098, 
                    241.40500600000001`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    246.85500000000002`, 234.623}, {249.617, 237.991}, {
                    249.617, 241.311}, {248.605, 241.198}, {248.055, 
                    240.795}, {247.309, 239.666}, {246.676, 241.94}, {245.281,
                     242.44}, {243.414, 243.541}, {241.54299999999998`, 
                    242.44}, {240.148, 242.02200000000002`}, {239.516, 
                    239.74499999999998`}, {238.76999999999998`, 240.877}, {
                    238.21899999999997`, 241.198}, {237.207, 241.311}, {
                    237.207, 237.991}, {239.969, 234.623}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    246.85500000000002`, 234.623006}, {249.617, 
                    237.99100600000003`}, {249.617, 241.31100600000002`}, {
                    248.605, 241.198006}, {248.055, 240.795006}, {247.309, 
                    239.666006}, {246.676, 241.940006}, {245.281, 
                    242.440006}, {243.414, 243.541006}, {241.54299999999998`, 
                    242.440006}, {240.148, 242.022006}, {239.516, 
                    239.745006}, {238.76999999999998`, 240.87700600000002`}, {
                    238.21899999999997`, 241.198006}, {237.207, 
                    241.31100600000002`}, {237.207, 237.99100600000003`}, {
                    239.969, 234.623006}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4oyJb2vsv+Y5HP6qEdNfl+OAzn+8dPYRhZh8
hx1yra8Db+Q4cF1fXGCblO+gsKEoYyJnLpxvYgwE1bkO72rsTeOs8h0OgfSX
5ToU2AJViOQ7XKt4qWaYk+ugytY41fl7noMdWGOug7ohxxqZe3kO91SAErNz
HWJ3efIwbc9zePF75cdLW3Mh7snNcxC7ee578ONch36QwcoI+ePe5p2Of3Lh
+p0Snl5QAqqDmf8N6IxDR3Ph9jOAwIJcuPvA/qvIhbsfxof5D+hroNdz4f4H
85/mwsMHnQ8ABFCbJg==
                    "]]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4oyJb2vsv+Y51Ojvy+ivy3FA5z9eOvuIQky+
Q2GE1I/AGzkOXNcXF9gm5TvcfMleOpEzF85/k3PC3rg61+Fdjb1pnFW+QzVI
f1muQ4EtUIVIvkP/pjpjw5xcB1W2xqnO3/McvjnnbCiwzXVQN+RYI3Mvz2Fa
3OzeqbNzHWJ3efIwbc9zWGBq/+/S1lyIe3LzHM4LpbCEPM516D/0VSNGGSF/
3Nu80/FPLly/U8LTC0pAdTDzv2nE9B86mgu3nwEEFuTC3Qf2X0Uu3P0wPsx/
ra8Dd8i15sL9D+Y/zYWHDzofANFqmVA=
                    "],
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4tbXgTvkFPMd6rL2lEz+kuWAzlc35Fgjsy7f
IVkgwnLLhGwHb/NOx4SN+Q52XNcXF5xF8A9/1Yjpr8txKLQFStTkO4jdPPc9
uDzHYeuJsn3zvfIdcp//XvkxKMfBcgtQQDnfYeLbGntTLqg8U76D27bPf6/M
yXGoFlnn/vBcnkNA7/Q8IeZchwyQwtw8iHqvXIdikAA3Qh5s3vVcuH4Qd/62
XLj5ViCB/ly4/SBnPY7NhbsP7F/NXLj7YXyY/1TZGqc6G+fC/Q92z85cePig
8wGGoKCb
                    "]]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4tbXgTvkFPMdzJcENk7+kuWAzlc35Fgjsy7f
QdrrreuWCdkO3uadjgkb8x2+OedsKDiL4Nfo78vor8txKLTlur64Jt/hvFAK
S0h5jsPWE2X75nvlO6gqTtz2MSjHwXILUEA538FLXcjHlAsqz5Tv8P99B9fV
OTkO1SLr3B+ey3PgPK5TLcSc65Ax8W2NfW4eRL1XrkMxSIAbIQ8273ouXD+I
O39bLtx8K5BAfy7c/pvnvgc/js2Fuw/sX81cuPthfJj/VNkapzob58L9D3bP
zlx4+KDzAeAhlNE=
                    "],
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4tbXgTvkFPMdlhTYcl3nznJA5ws3Hzi1cGa+
Q4TllhNlbVkO3uadjgkb8x3uqbA1Tt2N4Ltt+/z3Sk62QyFQ2+KafAcQVZCa
7bD1RNm++V75Dh+WH/M2d8x2ABmzTznfYfYRhQ1FP7Ig8kz5DgG90/OEurMd
qkXWuT88l+eQ+/z3yo/3sh0yJr6tsc/NcwCKVomo5TgUgwS4EfJg867nwvWD
uPO35cLNtwIJ9OfC7b957nvw49hcuPvA/tXMhbsfxof5L4xPd9Nc91y4/8Hu
2ZkLDx90PgCrxZ/i
                    "]]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4tbXgTvkFPMdYlddErvOneWAzhduPnBq4cx8
B4Fiz6tlbVkO3uadjgkb8x2mxc3unbobwf//voPrak62Q6Et1/XFNfkO35xz
NhSkZjtsPVG2b75XvsOKh9ER5o7ZDpZbgALK+Q4h/7buKfqRBZFnynfgPK5T
LdSd7VAtss794bk8BzXFids+3st2yJj4tsY+N88hvbGsXUQtx6EYJMCNkAeb
dz0Xrh/Enb8tF26+FUigPxdu/81z34Mfx+bC3Qf2r2Yu3P0wPsx/YXy6m+a6
58L9D3bPzlx4+KDzASGmnw0=
                    "],
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{250.555, 
                    204.131}, {249.45700000000002`, 208.91299999999998`}, {
                    248.512, 212.455}, {243.21899999999997`, 216.053}, {
                    237.93, 212.455}, {236.984, 208.91299999999998`}, {
                    235.88700000000003`, 204.131}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{250.555, 
                    204.131006}, {249.45700000000002`, 208.912006}, {248.512, 
                    212.45500600000003`}, {243.21899999999997`, 216.053006}, {
                    237.93, 212.45500600000003`}, {236.984, 208.912006}, {
                    235.88700000000003`, 204.131006}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}}}, {{{253.277, 
                    201.47899999999998`}, {253.277, 208.401}, {250.875, 
                    207.459}, {248.70299999999997`, 206.065}, {
                    247.90200000000002`, 204.51399999999998`}, {247.008, 
                    208.35800000000003`}, {245.285, 210.053}, {243.137, 
                    212.377}, {240.99200000000002`, 210.053}, {239.555, 
                    208.35800000000003`}, {238.66, 204.51399999999998`}, {
                    237.859, 206.065}, {235.68800000000002`, 207.459}, {
                    233.285, 208.401}, {233.285, 
                    201.47899999999998`}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}}}, {{{253.277, 201.479006}, {
                    253.277, 208.40100600000002`}, {250.875, 
                    207.45900600000002`}, {248.70299999999997`, 206.065006}, {
                    247.90200000000002`, 204.514006}, {247.008, 
                    208.35800600000002`}, {245.285, 210.053006}, {243.137, 
                    212.37700600000002`}, {240.99200000000002`, 210.053006}, {
                    239.555, 208.35800600000002`}, {238.66, 204.514006}, {
                    237.859, 206.065006}, {235.68800000000002`, 
                    207.45900600000002`}, {233.285, 208.40100600000002`}, {
                    233.285, 201.479006}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{220.434, 226.475}, {220.434, 203.866}, {223.004, 
                    203.866}, {223.004, 226.53}, {222.078, 
                    226.99800000000002`}, {221.207, 227.07299999999998`}, {
                    220.434, 226.475}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{220.434, 226.475006}, {220.434, 
                    203.86600600000003`}, {223.004, 203.86600600000003`}, {
                    223.004, 226.53000600000001`}, {222.078, 226.998006}, {
                    221.207, 227.073006}, {220.434, 226.475006}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}}}, {{{220.516, 
                    211.846}, {223.70299999999997`, 210.21699999999998`}, {
                    226.859, 208.33}, {227.656, 203.866}, {220.516, 
                    203.866}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}}}, {{{220.516, 
                    211.84600600000002`}, {223.70299999999997`, 210.217006}, {
                    226.859, 208.33000600000003`}, {227.656, 
                    203.86600600000003`}, {220.516, 203.86600600000003`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{264.719, 218.62}, {264.719, 203.866}, {266.801, 
                    203.866}, {266.801, 218.655}, {266.15200000000004`, 
                    218.959}, {265.262, 219.006}, {264.719, 218.62}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{264.719, 218.620006}, {264.719, 
                    203.86600600000003`}, {266.801, 203.86600600000003`}, {
                    266.801, 218.65500600000001`}, {266.15200000000004`, 
                    218.95900600000002`}, {265.262, 219.006006}, {264.719, 
                    218.620006}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}}}, {{{266.801, 
                    211.959}, {263.613, 210.33}, {260.457, 208.444}, {259.66, 
                    203.97899999999998`}, {266.801, 
                    203.97899999999998`}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}}}, {{{266.801, 
                    211.95900600000002`}, {263.613, 210.33000600000003`}, {
                    260.457, 208.444006}, {259.66, 203.979006}, {266.801, 
                    203.979006}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{419.715, 226.475}, {419.715, 203.866}, {417.141, 
                    203.866}, {417.141, 226.53}, {418.07, 
                    226.99800000000002`}, {418.93799999999993`, 
                    227.07299999999998`}, {419.715, 226.475}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{419.715, 226.475006}, {419.715, 
                    203.86600600000003`}, {417.141, 203.86600600000003`}, {
                    417.141, 226.53000600000001`}, {418.07, 226.998006}, {
                    418.93799999999993`, 227.073006}, {419.715, 226.475006}}},
                    
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJ7IGYC4uPe5p2Op8odcp//XvmxKdMBxhe7ee57sHmu
w33/3ul59xB8hQ1FGRMfljvslGt9Hbgmx0EmKsX6Pn8FnM8AAhoIvh3X9cUF
qhUOpxe6bvv8FKpevMLBbdvnv1dEch34dDfNfc9d4VA6WYIlzC7XAUTx/S13
OHAKqKE81yFj4tsae8EKh8NfNWL6H0Hl5aH6J+Q6HAO516XCocMx4emFslwH
EDfBtsJhnfvDKpFVUPcaVjiAjDFlyoPwge5NFoiw3CKQBzFPs8LBFuTOmXkQ
9wDVg/2rnudwQen2z7owqH908hyEm4Eu861wWDb7iMKGvDwHIRDfucIB5C3/
nXkOOaBw1KuAmHM9DxJ+HlB5x3yH6XlAHUDzgLbqbjqZ5/Dpkm+SQBbUPRcQ
fHB8SOXD+fVZe0omd+Q78ILMTa9w6AT5918+xL51FQ5HQB4TLcDgx+3y5GHa
XOHQDZJwL3DYcqJs3/wzCP7Vipdqhs8QfLA/XyH0o/PB8WFYCbe/fN98KX39
Srj7YHyY+2F8mP8ugsLTqRLu/xmg8AiohIcP2L6sSnj4gcM7tBIevuDw9q6E
hz9YP9A8WPyA1aVXwuMP7L+CSnj8gs3rrITHPyiZrAOqh6UPWZAB0ZXw9LMI
mGz/hlTC0xfYvKpKePoDp/eOSnj6fLwU6LA5lfD0C3ZPbyU8fYP5jZXw9G8J
ipDiSnj+AIdXYSU8/4DVdyL4YP9vR/DB/t9VCc+f4Pg/h8mH5W8A2B3VVg==

                    "]]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJ7IGYC4uPe5p2Op8odVBUnbvvYlOkA458XSmEJMc91
uO/fOz3vHoKvsKEoY+LDcoeiCKkfgWtyHGSiUqzv81fA+QwgoIHg23FdX1yg
WuHQcvvWoc9PoerFKxz+v+/guiqS68Cnu2nue+4KB92zawXC7HIdJkuwhPH9
LXeoZDEP2lae65Ax8W2NvWCFQ7X+voz+R1B5eaj+CbkOx0DudalwcKz++vFC
Wa4DiJtgW+GQ3ljWLrIK6l7DCgcvdSEfU6Y8CB/oXmmvt65bBPIg5mlWOHxz
ztlQMDMP4h6gerB/1fMcLijd/lkXBvWPTp6DcPOBUwt9Kxzir0bqbsjLcxAC
8Z0rHITnXXjtvzPPIef575Uf9SocjqW5r3p/PQ8Sfh5Qecd8h+l5QB1A8/b2
L7bcdDLP4dMl3ySBLKh7LiD44PiQyofzzZcENk7uyHfgBbkvvcLBCeTff/kQ
+9ZVOCzc+6siQ7QAgx+3y5OHaXOFQwanEdMq9wKHLSfK9s0/g+BfrXipZvgM
wd8p1/o68BVCPzofHB+GlXD7y/fNl9LXr4S7D8aHuR/Gh/nvIig8nSrh/p8B
Co+ASnj4gO3LqoSHHzi8Qyvh4QsOb+9KePiD9QPNg8UPKHn5p1fC4w/sv4JK
ePyCzeushMe/+8MqkXVA9bD0IQsyILoSnn4WuW77/DekEp6+wOZVVcLTHzi9
d1TC0+fjpbOPKMyphKdfsHt6K+HpG8xvrISnf0tQhBRXwvMHOLwKK+H5B6y+
E8EH+387gg/2/65KeP4Ex/85TD4sfwMAoHLEYw==
                    "],
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    399.008, 246.42000000000002`}, {400.867, 
                    247.97899999999998`}, {400.867, 249.97899999999998`}, {
                    400.188, 249.91299999999998`}, {399.816, 249.678}, {
                    399.312, 249.02200000000002`}, {398.887, 250.346}, {
                    397.949, 251.38100000000003`}, {396.688, 252.026}, {
                    395.42999999999995`, 251.38100000000003`}, {
                    394.49199999999996`, 250.393}, {394.066, 249.069}, {
                    393.562, 249.725}, {393.191, 249.91299999999998`}, {
                    392.512, 249.97899999999998`}, {392.512, 
                    247.97899999999998`}, {394.371, 
                    246.42000000000002`}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    399.008, 246.420006}, {400.867, 247.979006}, {400.867, 
                    249.979006}, {400.188, 249.912006}, {399.816, 
                    249.67800599999998`}, {399.312, 249.022006}, {398.887, 
                    250.34600600000002`}, {397.949, 251.38100600000004`}, {
                    396.688, 252.02600600000002`}, {395.42999999999995`, 
                    251.38100600000004`}, {394.49199999999996`, 250.393006}, {
                    394.066, 249.069006}, {393.562, 249.725006}, {393.191, 
                    249.912006}, {392.512, 249.979006}, {392.512, 
                    247.979006}, {394.371, 246.420006}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{400.,
                     241.405}, {400.867, 243.27599999999998`}, {400.867, 
                    245.873}, {400.188, 245.80700000000002`}, {399.816, 
                    245.569}, {399.312, 244.901}, {398.887, 246.248}, {
                    397.949, 247.295}, {396.688, 247.948}, {
                    395.42999999999995`, 247.295}, {394.49199999999996`, 
                    246.295}, {394.066, 244.95200000000003`}, {393.562, 
                    245.61599999999999`}, {393.191, 245.80700000000002`}, {
                    392.512, 245.873}, {392.512, 243.27599999999998`}, {
                    393.375, 241.405}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{400.,
                     241.40500600000001`}, {400.867, 243.276006}, {400.867, 
                    245.873006}, {400.188, 245.80700600000003`}, {399.816, 
                    245.569006}, {399.312, 244.90100600000002`}, {398.887, 
                    246.24800599999998`}, {397.949, 247.295006}, {396.688, 
                    247.948006}, {395.42999999999995`, 247.295006}, {
                    394.49199999999996`, 246.295006}, {394.066, 244.952006}, {
                    393.562, 245.616006}, {393.191, 245.80700600000003`}, {
                    392.512, 245.873006}, {392.512, 243.276006}, {393.375, 
                    241.40500600000001`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    400.133, 234.623}, {402.895, 237.991}, {402.895, 
                    241.311}, {401.883, 241.198}, {401.332, 240.795}, {
                    400.58599999999996`, 239.666}, {399.953, 241.94}, {
                    398.559, 242.44}, {396.688, 243.541}, {394.82, 242.44}, {
                    393.42599999999993`, 242.02200000000002`}, {
                    392.79299999999995`, 239.74499999999998`}, {392.047, 
                    240.877}, {391.4959999999999, 241.198}, {390.484, 
                    241.311}, {390.484, 237.991}, {393.246, 
                    234.623}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    400.133, 234.623006}, {402.895, 237.99100600000003`}, {
                    402.895, 241.31100600000002`}, {401.883, 241.198006}, {
                    401.332, 240.795006}, {400.58599999999996`, 239.666006}, {
                    399.953, 241.940006}, {398.559, 242.440006}, {396.688, 
                    243.541006}, {394.82, 242.440006}, {393.42599999999993`, 
                    242.022006}, {392.79299999999995`, 239.745006}, {392.047, 
                    240.87700600000002`}, {391.4959999999999, 241.198006}, {
                    390.484, 241.31100600000002`}, {390.484, 
                    237.99100600000003`}, {393.246, 234.623006}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4skSLGF8/JUOh79qxPTX5Tig8y8q3f5Z51Tp
sEOu9XXgjRwHxQ1FGRNdKx0UQDRnLpxvYgwE1bkOws0HTi00rHQ4BNJflusw
PU+o+YBcpcO1ipdqhjm5DgwgIFDpYMd1fXGBba6D/l0VtkbmSod7QGrq7FwH
Xt1Nc9+/r3B48Xvlx0tbcx3idnnyMJ2ucBC7ee578ONch8dLZx9RWIaQB7tz
UgVcP9j8tgq4+VEp1vf9yyvg9t/3752el1IBd98FkP8CKuDuh/Fh/osF2R9e
Afc/mN9eAQ8fdD4AYnmREg==
                    "]]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4skSLGF8/JUONfr7MvrrchzQ+ReVbv+sc6p0
KIyQ+hF4I8dBcUNRxkTXSoebL9lLJ3Lmwvlvck7YG1fnOgg3Hzi10LDSoRqk
vyzXYXqeUPMBuUqH/k11xoY5uQ4MICBQ6fDNOWdDgW2ug/5dFbZG5kqHaXGz
e6fOznXg1d009/37CocFpvb/Lm3NdYjb5cnDdLrC4bxQCkvI41yHx0tnH1FY
hpA//FUjpn9SBVw/2Py2Crj5USnW9/3LK+D23/fvnZ6XUgF33wWQ/wIq4O6H
8WH+iwXZH14B9z+Y314BDx90PgAvoo88
                    "],
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4kWu2z7/Val0qMvaUzL5S5YDOt+W6/riguxK
h2SBCMstE7IdJkuwhPHlVjrYgcTPIviHv2rE9NflOCybfURhQ1Clg9jNc9+D
y3McrLacKNtnWemQ+/z3yo9BOQ475FpfB6pVOkx8W2NvygWVF610cANae2VO
joNsVIr1/d8VDgG90/OEmHMd4nZ58jCdroCo98p1uFrxUs1wFkIebF5DBVy/
Jci8/Aq4+WD5mAq4/SDj/Z0r4O4Di2tUwN0P48P8xwACehWo/i+sgIcPOh8A
E0eazg==
                    "]]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4kWu2z7/Val0MF8S2Dj5S5YDOt+W6/riguxK
B2mvt65bJmQ7TJZgCePLrXT45pyzoeAsgl+jvy+jvy7HYdnsIwobgiodzgul
sISU5zhYbTlRts+y0kFVceK2j0E5DjvkWl8HqlU6eKkL+ZhyQeVFKx3+v+/g
ujonx0E2KsX6/u8KB87jOtVCzLkOcbs8eZhOV0DUe+U6XK14qWY4CyEPNq+h
Aq7fEmRefgXcfLB8TAXcfpDx/s4VcPflPv+98qNGBdz9MD7MfwwgoFeB6v/C
Cnj4oPMBbMiPBA==
                    "],
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4kWu2z7/Val0WFJgy3WdO8sBnZ8x8W2NfWKl
Q4TllhNlbVkOkyVYwvhyKx3uqbA1Tt2N4LsBtV3JyXZYNvuIwoagSgeg7sUF
qdkOVkBt+ywrHT4sP+Zt7pjtsEOu9XWgWqUDSFnRjyyIvGilQ0Dv9Dyh7mwH
2agU6/u/Kxxyn/9e+fFetkPcLk8eptMVDuvcH1aJqOU4XK14qWY4CyEPNq+h
Aq4f5Mx9+RVw88HyMRVw+0HG+ztXwN0HNkejAu5+GB/mP6CuTkeLClT/F1bA
wwedDwA3dZqj
                    "]]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4kWu2z7/Val0iF11Sew6d5YDOj9j4tsa+8RK
B4Fiz6tlbVkOkyVYwvhyKx2mxc3unbobwf//voPrak62w7LZRxQ2BFU6fHPO
2VCQmu1gteVE2T7LSocVD6MjzB2zHXbItb4OVKt0CPm3dU/RjyyIvGilA+dx
nWqh7mwH2agU6/u/KxzUFCdu+3gv2yFulycP0+kKh/TGsnYRtRyHqxUv1Qxn
IeTB5jVUwPVbgszLr4CbD5aPqYDbDzLe37kC7r7c579XftSogLsfxof575i3
eaejRQWq/wsr4OGDzgcArUeZzg==
                    "],
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{403.832, 
                    204.131}, {402.734, 208.91299999999998`}, {401.789, 
                    212.455}, {396.4959999999999, 216.053}, {391.207, 
                    212.455}, {390.262, 208.91299999999998`}, {
                    389.16400000000004`, 204.131}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{403.832, 
                    204.131006}, {402.734, 208.912006}, {401.789, 
                    212.45500600000003`}, {396.4959999999999, 216.053006}, {
                    391.207, 212.45500600000003`}, {390.262, 208.912006}, {
                    389.16400000000004`, 204.131006}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}}}, {{{419.633, 
                    211.846}, {416.445, 210.21699999999998`}, {413.633, 
                    208.33}, {412.832, 203.866}, {419.633, 203.866}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}}}, {{{419.633, 
                    211.84600600000002`}, {416.445, 210.217006}, {413.633, 
                    208.33000600000003`}, {412.832, 203.86600600000003`}, {
                    419.633, 203.86600600000003`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{375.42999999999995`, 218.62}, {
                    375.42999999999995`, 203.866}, {373.34400000000005`, 
                    203.866}, {373.34400000000005`, 218.655}, {
                    373.9959999999999, 218.959}, {374.887, 219.006}, {
                    375.42999999999995`, 218.62}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{375.42999999999995`, 218.620006}, {
                    375.42999999999995`, 203.86600600000003`}, {
                    373.34400000000005`, 203.86600600000003`}, {
                    373.34400000000005`, 218.65500600000001`}, {
                    373.9959999999999, 218.95900600000002`}, {374.887, 
                    219.006006}, {375.42999999999995`, 218.620006}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}}}, {{{
                    373.34400000000005`, 211.846}, {376.53099999999995`, 
                    210.21699999999998`}, {379.688, 208.33}, {
                    380.48799999999994`, 203.866}, {373.34400000000005`, 
                    203.866}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}}}, {{{
                    373.34400000000005`, 211.84600600000002`}, {
                    376.53099999999995`, 210.217006}, {379.688, 
                    208.33000600000003`}, {380.48799999999994`, 
                    203.86600600000003`}, {373.34400000000005`, 
                    203.86600600000003`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{375.42999999999995`, 218.62}, {
                    375.42999999999995`, 203.866}, {373.34400000000005`, 
                    203.866}, {373.34400000000005`, 218.655}, {
                    373.9959999999999, 218.959}, {374.887, 219.006}, {
                    375.42999999999995`, 218.62}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{375.42999999999995`, 218.620006}, {
                    375.42999999999995`, 203.86600600000003`}, {
                    373.34400000000005`, 203.86600600000003`}, {
                    373.34400000000005`, 218.65500600000001`}, {
                    373.9959999999999, 218.95900600000002`}, {374.887, 
                    219.006006}, {375.42999999999995`, 218.620006}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}}}, {{{
                    373.34400000000005`, 211.846}, {376.53099999999995`, 
                    210.21699999999998`}, {379.688, 208.33}, {
                    380.48799999999994`, 203.866}, {373.34400000000005`, 
                    203.866}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}}}, {{{
                    373.34400000000005`, 211.84600600000002`}, {
                    376.53099999999995`, 210.217006}, {379.688, 
                    208.33000600000003`}, {380.48799999999994`, 
                    203.86600600000003`}, {373.34400000000005`, 
                    203.86600600000003`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}}}, {{{338.191, 
                    232.01399999999998`}, {338.191, 237.768}, {343.156, 
                    238.416}, {343.156, 238.416}, {343.156, 233.295}, {
                    341.26599999999996`, 233.377}, {340.355, 231.678}, {
                    340.355, 229.155}, {340.355, 226.627}, {341.879, 
                    226.58800000000002`}, {341.879, 226.58800000000002`}, {
                    341.879, 212.05700000000002`}, {338.191, 
                    212.05700000000002`}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}}}, {{{338.191, 232.014006}, {
                    338.191, 237.76800599999999`}, {343.156, 238.416006}, {
                    343.156, 238.416006}, {343.156, 233.295006}, {
                    341.26599999999996`, 233.37700600000002`}, {340.355, 
                    231.67800599999998`}, {340.355, 229.15500600000001`}, {
                    340.355, 226.62700600000002`}, {341.879, 226.588006}, {
                    341.879, 226.588006}, {341.879, 212.05700600000003`}, {
                    338.191, 212.05700600000003`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}}}, {{{301.48799999999994`, 
                    232.01399999999998`}, {301.48799999999994`, 237.768}, {
                    296.52299999999997`, 238.416}, {296.52299999999997`, 
                    238.416}, {296.52299999999997`, 233.295}, {298.414, 
                    233.377}, {299.324, 231.678}, {299.324, 229.155}, {
                    299.324, 226.627}, {297.801, 226.58800000000002`}, {
                    297.801, 226.58800000000002`}, {297.801, 
                    212.05700000000002`}, {301.48799999999994`, 
                    212.05700000000002`}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}}}, {{{301.48799999999994`, 
                    232.014006}, {301.48799999999994`, 237.76800599999999`}, {
                    296.52299999999997`, 238.416006}, {296.52299999999997`, 
                    238.416006}, {296.52299999999997`, 233.295006}, {298.414, 
                    233.37700600000002`}, {299.324, 231.67800599999998`}, {
                    299.324, 229.15500600000001`}, {299.324, 
                    226.62700600000002`}, {297.801, 226.588006}, {297.801, 
                    226.588006}, {297.801, 212.05700600000003`}, {
                    301.48799999999994`, 212.05700600000003`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}}}, {{{406.637, 
                    201.55700000000002`}, {406.637, 208.483}, {404.234, 
                    207.541}, {402.062, 206.147}, {401.262, 204.596}, {
                    400.367, 208.44}, {398.64500000000004`, 210.135}, {
                    396.4959999999999, 212.459}, {394.348, 210.135}, {
                    392.90999999999997`, 208.44}, {392.01599999999996`, 
                    204.596}, {391.215, 206.147}, {389.043, 207.541}, {
                    386.641, 208.483}, {386.641, 
                    201.55700000000002`}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}}}, {{{406.637, 
                    201.55700600000003`}, {406.637, 208.48300600000002`}, {
                    404.234, 207.541006}, {402.062, 206.147006}, {401.262, 
                    204.59600600000002`}, {400.367, 208.440006}, {
                    398.64500000000004`, 210.135006}, {396.4959999999999, 
                    212.45900600000002`}, {394.348, 210.135006}, {
                    392.90999999999997`, 208.440006}, {392.01599999999996`, 
                    204.59600600000002`}, {391.215, 206.147006}, {389.043, 
                    207.541006}, {386.641, 208.48300600000002`}, {386.641, 
                    201.55700600000003`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    194.39100000000002`, 145.05700000000002`}, {445.605, 
                    145.05700000000002`}, {445.60900000000004`, 132.225}, {
                    194.395, 132.225}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    194.39100000000002`, 145.057006}, {445.605, 145.057006}, {
                    445.60900000000004`, 132.225006}, {194.395, 132.225006}}},
                    
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    187.76999999999998`, 132.24499999999998`}, {452.227, 
                    132.24499999999998`}, {452.22999999999996`, 119.432}, {
                    187.77299999999997`, 119.432}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    187.76999999999998`, 132.245006}, {452.227, 132.245006}, {
                    452.22999999999996`, 119.432006}, {187.77299999999997`, 
                    119.432006}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    207.586, 164.248}, {432.41400000000004`, 164.248}, {
                    432.41400000000004`, 155.947}, {207.586, 
                    155.947}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    207.586, 164.24800599999998`}, {432.41400000000004`, 
                    164.24800599999998`}, {432.41400000000004`, 155.947006}, {
                    207.586, 155.947006}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    201.012, 156.002}, {438.98900000000003`, 156.002}, {
                    438.98900000000003`, 145.127}, {201.01200000000003`, 
                    145.127}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    201.012, 156.002006}, {438.98900000000003`, 156.002006}, {
                    438.98900000000003`, 145.127006}, {201.01200000000003`, 
                    145.127006}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    211.512, 170.635}, {428.48900000000003`, 170.635}, {
                    428.48900000000003`, 164.31099999999998`}, {
                    211.51200000000003`, 164.31099999999998`}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    211.512, 170.635006}, {428.48900000000003`, 170.635006}, {
                    428.48900000000003`, 164.311006}, {211.51200000000003`, 
                    164.311006}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    235.062, 170.6}, {251.453, 170.6}, {251.453, 
                    119.46699999999998`}, {235.062, 
                    119.46699999999998`}}}]}}}}, {{{
                   {Thickness[0.0013056953125000002`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    235.062, 170.600006}, {251.453, 170.600006}, {251.453, 
                    119.46700600000003`}, {235.062, 119.46700600000003`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    238.691, 170.6}, {247.824, 170.6}, {247.824, 
                    119.46699999999998`}, {238.691, 
                    119.46699999999998`}}}]}}}}, {{{
                   {Thickness[0.001303675], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    238.691, 170.600006}, {247.824, 170.600006}, {247.824, 
                    119.46700600000003`}, {238.691, 119.46700600000003`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{238.523, 164.291006}, {
                    247.98800000000003`, 164.291006}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{238.523, 157.893006}, {
                    247.98800000000003`, 157.893006}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{238.523, 
                    151.49100599999997`}, {247.98800000000003`, 
                    151.49100599999997`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{238.523, 
                    145.09200600000003`}, {247.98800000000003`, 
                    145.09200600000003`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{238.523, 
                    138.69400600000006`}, {247.98800000000003`, 
                    138.69400600000006`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{238.523, 
                    132.29100599999998`}, {247.98800000000003`, 
                    132.29100599999998`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{238.523, 
                    125.89300600000001`}, {247.98800000000003`, 
                    125.89300600000001`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    311.52, 170.6}, {327.911, 170.6}, {327.911, 
                    119.46699999999998`}, {311.52, 
                    119.46699999999998`}}}]}}}}, {{{
                   {Thickness[0.0013056953125000002`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    311.52, 170.600006}, {327.911, 170.600006}, {327.911, 
                    119.46700600000003`}, {311.52, 119.46700600000003`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    315.262, 170.6}, {324.395, 170.6}, {324.395, 
                    119.46699999999998`}, {315.262, 
                    119.46699999999998`}}}]}}}}, {{{
                   {Thickness[0.001303675], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    315.262, 170.600006}, {324.395, 170.600006}, {324.395, 
                    119.46700600000003`}, {315.262, 119.46700600000003`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{315.309, 164.303006}, {
                    324.121, 164.303006}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{315.309, 
                    157.89700600000003`}, {324.121, 157.89700600000003`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{315.309, 151.495006}, {
                    324.121, 151.495006}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{315.309, 
                    145.09200600000003`}, {324.121, 145.09200600000003`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{315.309, 
                    138.69000600000004`}, {324.121, 138.69000600000004`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{315.309, 
                    132.28400600000003`}, {324.121, 132.28400600000003`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{315.309, 
                    125.88100600000001`}, {324.121, 125.88100600000001`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    388.43399999999997`, 170.6}, {404.825, 170.6}, {404.825, 
                    119.46699999999998`}, {388.43399999999997`, 
                    119.46699999999998`}}}]}}}}, {{{
                   {Thickness[0.0013056953125000002`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    388.43399999999997`, 170.600006}, {404.825, 170.600006}, {
                    404.825, 119.46700600000003`}, {388.43399999999997`, 
                    119.46700600000003`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    392.062, 170.6}, {401.195, 170.6}, {401.195, 
                    119.46699999999998`}, {392.062, 
                    119.46699999999998`}}}]}}}}, {{{
                   {Thickness[0.001303675], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    392.062, 170.600006}, {401.195, 170.600006}, {401.195, 
                    119.46700600000003`}, {392.062, 119.46700600000003`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{391.89799999999997`, 
                    164.291006}, {401.363, 164.291006}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{391.89799999999997`, 
                    157.893006}, {401.363, 157.893006}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{391.89799999999997`, 
                    151.49100599999997`}, {401.363, 151.49100599999997`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{391.89799999999997`, 
                    145.09200600000003`}, {401.363, 145.09200600000003`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{391.89799999999997`, 
                    138.69400600000006`}, {401.363, 138.69400600000006`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{391.89799999999997`, 
                    132.29100599999998`}, {401.363, 132.29100599999998`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{391.89799999999997`, 
                    125.89300600000001`}, {401.363, 125.89300600000001`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    270.42999999999995`, 192.791}, {274.10599999999994`, 
                    192.791}, {274.10599999999994`, 175.9}, {
                    270.42999999999995`, 175.9}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Round"], 
                    JoinForm["Round"], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    270.42999999999995`, 192.791006}, {274.10599999999994`, 
                    192.791006}, {274.10599999999994`, 175.90000600000002`}, {
                    270.42999999999995`, 175.90000600000002`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    278.10900000000004`, 192.791}, {281.785, 192.791}, {
                    281.785, 175.9}, {278.10900000000004`, 175.9}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Round"], 
                    JoinForm["Round"], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    278.10900000000004`, 192.791006}, {281.785, 192.791006}, {
                    281.785, 175.90000600000002`}, {278.10900000000004`, 
                    175.90000600000002`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    285.79299999999995`, 192.791}, {289.465, 192.791}, {
                    289.465, 175.9}, {285.79299999999995`, 175.9}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Round"], 
                    JoinForm["Round"], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    285.79299999999995`, 192.791006}, {289.465, 192.791006}, {
                    289.465, 175.90000600000002`}, {285.79299999999995`, 
                    175.90000600000002`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    350.113, 192.791}, {353.785, 192.791}, {353.785, 175.9}, {
                    350.113, 175.9}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Round"], 
                    JoinForm["Round"], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    350.113, 192.791006}, {353.785, 192.791006}, {353.785, 
                    175.90000600000002`}, {350.113, 175.90000600000002`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    357.79299999999995`, 192.791}, {361.46899999999994`, 
                    192.791}, {361.46899999999994`, 175.9}, {
                    357.79299999999995`, 175.9}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Round"], 
                    JoinForm["Round"], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    357.79299999999995`, 192.791006}, {361.46899999999994`, 
                    192.791006}, {361.46899999999994`, 175.90000600000002`}, {
                    357.79299999999995`, 175.90000600000002`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    365.47299999999996`, 192.791}, {369.14899999999994`, 
                    192.791}, {369.14899999999994`, 175.9}, {
                    365.47299999999996`, 175.9}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Round"], 
                    JoinForm["Round"], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    365.47299999999996`, 192.791006}, {369.14899999999994`, 
                    192.791006}, {369.14899999999994`, 175.90000600000002`}, {
                    365.47299999999996`, 175.90000600000002`}}},
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    312.191, 277.08799999999997`}, {311.78499999999997`, 
                    280.28799999999995`}, {328.004, 280.28799999999995`}, {
                    327.59799999999996`, 277.08799999999997`}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    312.191, 277.088006}, {311.78499999999997`, 280.288006}, {
                    328.004, 280.288006}, {327.59799999999996`, 277.088006}}},
                    
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    313.277, 280.35}, {312.92999999999995`, 282.979}, {
                    326.85900000000004`, 282.979}, {326.512, 
                    280.35}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    313.277, 280.350006}, {312.92999999999995`, 282.979006}, {
                    326.85900000000004`, 282.979006}, {326.512, 280.350006}}},
                    
                    CurveClosed->{1}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    315.48799999999994`, 283.077}, {315.258, 285.709}, {
                    324.53099999999995`, 285.709}, {324.301, 
                    283.077}}}]}}}}, {{{
                   {Thickness[0.0012000000000000001`], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    315.48799999999994`, 283.077006}, {315.258, 285.709006}, {
                    324.53099999999995`, 285.709006}, {324.301, 283.077006}}},
                    
                    CurveClosed->{1}]}}}}}}}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 640.}, {0., 411.}}], ",", 
           GraphicsBox[{{{
               {Thickness[0.0010416666666666667`], {{{
                   {FaceForm[{RGBColor[
                    0.8078430000000001, 0.06666670000000002, 0.14902], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 640.}, {960., 640.}, {960., 0.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     320.}, {960., 320.}, {960., 0.}, {0., 0.}}}]}}}}}}}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 960.}, {0., 640.}}], ",", 
           GraphicsBox[{{{
               {Thickness[0.001388888888888889], {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 480.}, {720., 480.}, {720., 0.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[0.737255, 0., 0.17647100000000002`], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{504., 240.}, {504., 160.47299999999998`}, {
                    439.527, 96.}, {360., 96.}, {280.47299999999996`, 96.}, {
                    216., 160.47299999999998`}, {216., 240.}, {216., 
                    319.527}, {280.47299999999996`, 384.}, {360., 384.}, {
                    439.527, 384.}, {504., 319.527}, {504., 240.}}}]}}}}}}}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 720.}, {0., 480.}}], ",", 
           GraphicsBox[{{{
               {Thickness[0.0016666666666666668`], {{{
                   {FaceForm[{RGBColor[
                    0.9294119999999999, 0.109804, 0.141176], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 400.}, {600., 400.}, {600., 0.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     300.}, {600., 300.}, {600., 100.}, {0., 
                    100.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[0., 0.65098, 0.31764699999999996`], 
                    Opacity[1.]}], FilledCurveBox[{CompressedData["
1:eJxTTMoPSmJiYGDYBMTMQMzAxMDIzAxEDIwMQARhD29Ef29SYiNV4oWgIWgK
AO1qBvs=
                    "], {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4,
                     3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {CompressedData["
1:eJx9WWmUVNURHhYFhYMIAwjCBBUGjQtwYgRB5cKgaARRUfRNdw9098z0Mr28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                    "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQPVmCJYzPsNABTCcWONhyXV9cYFzo0Po6cIcckM8A
AmYI+S0nyvbNt0Dwl84+orDBB8GPSrG+7x9d6PAYJBFT4OBt3umYkFjocOir
Rkx/SIGD/l0VtkYg/22NvWlcCNT8pEIHPt1Nc98HF0D0AfmWIIuA/OMgA4B8
hQ1FGROB/HcgfUlQ+4D8i0q3f9YB+dUi69wfBhU4lO+bL6WfXOhgBdIfWAAx
JxlqXwDUvhSo//wLHD5d8k0SAPKrQPr9CiDqgPyrFS/VDJH4siCP+RY43Pfv
nZ4H5BuA/OGLkIeEA4J/DORuJD7Yf94I/eBw8kbIx+3y5GFC4j8AqfOChgeQ
Dw43T4T7c5//XvnRowBibjI0fD0Q/gWrA/KFmg+cWgjkuz8E+RAav/HQ8LEs
cADGztMLHoUQdykUOKCkB/4CSLjIQdUzQsNLpNBhkeu2z3+/5EPs5y10iAW5
/3s+JFyAfJCxSkA+2HyeQgdg7L2tAfLB9vBA4xfIB4cTD9S9P/Ih4cxd6LDq
I9AiIB/sbiC/AORwIB8cbtzQ+PsJNZ+r0OESKB38ync4DAoHIN8JZP9vqH1s
hRBxpgIHYVB4sELTpwCCD7ZfA8HXahe7eQ6YvjxA9vNC3RuPFj7A9A4ADNBT
Sg==
                    "], CompressedData["
1:eJxTTMoPSmViYGAQBmIQHbvLk4fJvtgh9/nvlR+1Chz076qwNSLx3R9WiaxD
4j9eOvuIggOC3+GY8PRCHIJvy3V9cUFxscOhrxox/TIFDkLNB04tLC922HKi
bN98lgKHTpD6mmKHvSWTJVjO5TtcULr9s66g2MEAZO/efLj5MD7YXBUEv3zf
fCl90WIHJ6AxSofzHRQ3FGVM5C12eFtjbxp3Kd9BJirF+j57sYO6IccamXv5
EPexFTtYgRzwPt9hkeu2z385EO5pfR24Qw6o/2rFSzVDGShfsdjhIshdQP+g
hw8AONOPXA==
                    "], CompressedData["
1:eJxTTMoPSmViYGAQA2IQnfv898qPS4ocGEBArsBBqPnAqYX7ixweL519REGh
wGGnXOvrwFNFDjtAtACCDyR3yN3Nh/Nlo1Ks73fnO3Q6Jjy9sKvI4aLS7Z91
RfkOwiDzCqHqffMdbLmuLy5wLnLQv6vC1miaDxGXLHLYeqJs33ytfIerFS/V
DAWKHFTZGqc6G+dD3AXkF2VMfFsD5IPdxw+1zxhqHj/UvSb5Dt7mQBcA+cdA
DBOo+UD+/vlS+neB/MkSLGF8QP4i122f/wL5VluAFn8thMjn5Dvw6W6a+567
yKF3ep5Q8xaofu8ih9hdnjxM3/MdLEHqi4sg/gSGR7XIOveHE4oc7vsDdcgU
OKCHJwB+5Zh8
                    "], {{320.469, 257.85200000000003`}, {
                    322.90999999999997`, 257.92999999999995`}, {323.219, 
                    256.777}, {322.027, 253.35200000000003`}, {321.617, 
                    252.172}, {319.914, 251.21499999999997`}, {318.25, 
                    251.21499999999997`}, {315.812, 251.21499999999997`}, {
                    315.29299999999995`, 251.805}, {315.605, 254.262}, {
                    315.887, 256.445}, {316.96099999999996`, 257.441}, {
                    319.383, 257.746}, {319.78499999999997`, 
                    257.79699999999997`}, {320.14500000000004`, 
                    257.84000000000003`}, {320.469, 
                    257.85200000000003`}}, CompressedData["
1:eJxTTMoPSmViYGBQBWIQbct1fXHBxkKHKpF17g/T8h1m5Ak1H9hU6OCY8PSC
Unq+ww651teBWxDyihuKMiZuRfBzn/9e+fEJgg8273ihw+Ols48obMlzOPxV
I6a/q9DhbY29aVxSHsS8kEIH/bsqbI2SeQ7LgMo2SBU6qBtyrJH5lQtRz1Xo
cEHp9s86sTyHB/690/OA/OkgdwH5x73NOx2BfFW2xqnO4nkOVyteqhkC+f2H
gBqBfKDpO+Q4EeaD3cFRCNEnkwcRZy90qAa5Vy4P4l52qHnyeQ7l++ZL6bND
3a8ANQ/I7wU5AMifLMESxgfkg8UV8yD+Zit0uAhyr1IexJ1AftwuTx4m5TwH
kDEbgHxgqL2tAfLvg/wD5B8DuUclDxIuQD5Qd9YeFWj4APk+QOkEVYT6LSfK
9s1XQ6gHu1cdoR7sP408BwYQAPK5gd6y1ULwJ4DCRxvBD+PT3TQXiQ+mdRB8
sHlAflSK9X1/oH9vnvse/LgXGl6VhQ4g79jHQuMbKf0AAGv56A4=
                    
                    "], CompressedData["
1:eJxTTMoPSmViYGCQB2IQfeirRkx/XrFD6+vAHXIncx3K982X0m8tdth6omzf
/HO5Dvp3VdgaJ0Pl5+Y6CDUfOLWwu9iB6/riAlunXIeoFOv7/u3FDlZbgBr4
cx1m5AFVFBQ73PlZl7XnTY5Dlcg694d+xQ6Pl84+ovAkx2GR67bPf02KHYRB
5tyF8lWKHWRBBt3Pcch5/nvlR7liB3VDjjUy76D65aD2Aflg9wL51SBxJH7c
Lk8epvc5Dse8zTsd5aDuAfIZQADIvw1yz4cciLhsMcRfH3McPB4CbQDyvwGN
OQTkG4DEZaHmf8pxABmXAOQ7JTy9oPQZwe8HWQzkT5ZgCeOThbr/M9Q/MsUQ
e7/kQMwB8vcDg/UukD8dFD5A/tsae9O4bzkOIOfMl4Ga9z0HEi6SxQ7FGRPf
1gDD89Ml3yQBtWKHQltgCNjkQuQdoe5thfIDofZtgMZXYrHD3hKgy47lOqDH
LwAEcN+m
                    "], CompressedData["
1:eJxTTMoPSmViYGCQAGIQbXBXha1xb5FD6+vAHXJbcx22nCjbN39fkYOPeadj
ApCvsKEoY+J+hPwFpds/6w4g+LJRKdb33yL45fvmS+l/LXLImPi2xj411+GY
N9CgM0UO+4HCd01yHUDK/XcWOWwF2SOX65Dz/PfKj8uKHPaWTJZg4ct1ANr6
9MKCIofHS2cfUeCBugeJDzYPyFdja5zqzJ3r8OmSb5IAEl8GZMH8IocJh75q
xAD5tlzXFxfMR+gH24/EB7t/dpHDRZC/YPY3Idyn1S5281x6kQNQNmuPQa4D
SNsGsyIHdUOONTJBuQ5XK16qGeYVOTCAQEuuw4w8oeYDXUUO4HCdm+sA9FUY
31qoeZtyHdDDGwDyRK63
                    "], {{323.703, 234.539}, {325.039, 
                    234.60899999999998`}, {326.49199999999996`, 
                    234.35200000000003`}, {327.902, 233.758}, {330.465, 
                    232.684}, {330.96099999999996`, 231.754}, {
                    330.47299999999996`, 228.945}, {329.812, 225.129}, {
                    327.72999999999996`, 224.70299999999997`}, {
                    320.60900000000004`, 226.969}, {317.113, 
                    228.08200000000002`}, {316.754, 228.61299999999997`}, {
                    317.871, 230.92200000000003`}, {318.941, 233.125}, {
                    321.14500000000004`, 234.40200000000002`}, {323.703, 
                    234.539}}, CompressedData["
1:eJxTTMoPSmViYGAQBmIQfczbvNPxXYGDKlvjVGfjXAf9uypsje8R/GWzjyhs
+IDgM4DAJwS/WmSd+0OXQjh/h1zr68CAQocLSrd/1olB1WsUOqz+eMk3aU2O
wwP/3ul5UoUO++ZL6d/tyHGYkSfUfIChEEIH5ThsOVG2bz7QPUBVQs0mOQ6d
jglPL1wqcHhbY28ax5bjsBNk/qkCBzWQfdxQ9TsKHB4vBTo0JMdBYUNRxsTF
BRB3rcpxWOS67fPfOQUQdzzJcciYCDRpeYED1/XFBbZsUP9tKICoU4G690SB
w0WQ+41yHdDDBwASMn/g
                    "], CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQYiBQ4u3TnPf7/McYhKsb7vb17gIAtivM5xaH0d
uEPOt8DhktLtn3WnoPKZBQ7fNGL6D2XmOOQ+/73y44QCh4yJb2vsH2Y7eDys
ElkXWuBQBBLYnO2gsAHIki9wuHnue/DjzmyHCyBzxKD6J2Y79B/6qhFzOR9i
H3+OQ9wuTx6m2fkOE0Di8TkOPuadjgmt+Q6Pl84+ojAlxwGoO2vPlHwH/bsq
bI1bcxzUDTnWyEzLd+idnifUvCPHAeyfGfkQek8OxF8z8x1mAKUP7MuB+GMW
1Pz9OQ5WW06U7QPaV2jLdX3xgRyH495AC+fkQ/xzMMdh/3wp/btAPtj9QD6Y
npvv4JTw9ILS4RyHiyDz5uU7WILMAfLB9myC2n8jx6EYZNDtfIi/Huc4AH3z
9AJPgcOqj5d8k15Aw5O/wOEWyF9AvnDzgVMLBaHh9RLqH6T4AQB+fMn0
                    
                    "], {{338.85200000000003`, 218.539}, {341.305, 
                    218.73399999999998`}, {343.812, 217.008}, {343.453, 
                    214.21899999999997`}, {342.9959999999999, 210.676}, {
                    339.129, 209.65200000000002`}, {335.949, 
                    212.21499999999997`}, {334.051, 213.74599999999998`}, {
                    333.97999999999996`, 214.312}, {335.453, 216.535}, {
                    336.29699999999997`, 217.805}, {337.566, 218.434}, {
                    338.85200000000003`, 218.539}}, CompressedData["
1:eJxTTMoPSmViYGCQB2IQfd+/d3qeR5HD/vlS+ndrshxko1Ks73sWObS+Dtwh
V5vloH9Xha3RGyG/yHXb578+CP4OOaDKAATf27zTMSG4yKE4Y+Lbmuosh0+X
fJMEwoochJsPnFpYmeXg/rBKZF14kcNxkMKKLAeFDUUZEyOLHLacKNs3vyzL
Iff575Ufo4ocCmy5ri8ugZoXXeTAAAIlUPNiihxm5Ak1HyjKcgC7H8hXN+RY
IwPkg80B8r9pxPQfKsxymCzBEsYXW+Rw+2dd1p6CLAeQs+yB/FUfgQYVQM2P
hZoP5Gu3i908B+Q7Jjy9oJSfBRGPg9qXl+XweOnsIwpAPtAU0zgg/9BXoEVA
vgEonHKzHKaD1MVBww/GT4H6PzbLoQNkcFqRgxPIfOcsiDlA+WqRde4P5RDu
d+nOAYZEpgOf7qa5702LHCxBEu2ZDqDo8Vctcojd5cnD9DwTYr9YEcRdNlkQ
c1Sg/quAhg9S/AIATUjYeQ==
                    "], CompressedData["
1:eJxTTMoPSmViYGDQA2IQPSNPqPlAQKFD3C5PHiblLAdbruuLCxILHYoyJr6t
Uc9ymA6Sryl08DbvdEwQzHJ4vHT2EYUZhQ6WW06U7Xuc6QDWv6rQoQCk8Uim
wwP/3ul5mwodLijd/lm3LNPhasVLNUMgvxdk0IRMiH4g/22NvWlcX6YDAwgA
+VYg87ozHbTbxW6e21jo8E0jpv9QZ6aDx8MqkXUboeZ3ZDoINx84tRDIB7ur
LRPiXiBfCCTemukAcrY9kA+0PWtPS6ZDtcg694cbCh2cEp5eUGrOdFgGtH4D
kA/SZtuUCXEHkL/Iddvnvw2ZDjJRKdb31xc6TDj0VSOmPtNBYQMwJIB8dUOO
NTJ1UPvWQ91Xm+kAUu4P5O+fL6V/tybToXwfkAHk94EcCOTHgsIVyAf7G8gH
Gdu/Duqeaqj9QD44HKsyIeGwthDij8pMh9znv1d+XFPooMrWONW5HBp+a6D2
l2Y68Olumvt+daGD/l0VtsZSqHuB/FUfL/kmlWRC4m011P4SaHgvKHS4CIqf
JKh/26HhmZbpsEOu9XVgDtT+iZkOiiDzQqHxtyXTYSvQefOdoPofQd3nUOjA
DQrPX9DwBvLB6n4h5ItBBv5G8GVB9v5GqD8OcugfhDzQFTvk/iL4BiD/IfHB
/hGBpk83qH6FLAf09AwAlTtZfA==
                    "], {{301.66, 
                    208.57399999999998`}, {302.141, 208.61299999999997`}, {
                    302.641, 208.14499999999998`}, {303.477, 
                    207.21899999999997`}, {304.53099999999995`, 206.059}, {
                    305.76599999999996`, 203.84}, {306.215, 202.277}, {
                    307.29699999999997`, 198.523}, {305.59, 
                    196.95700000000002`}, {302.25, 198.66}, {298.668, 
                    200.48800000000003`}, {297.79699999999997`, 
                    203.38700000000003`}, {299.867, 206.648}, {300.66, 
                    207.89100000000002`}, {301.148, 208.52700000000002`}, {
                    301.66, 208.57399999999998`}}, CompressedData["
1:eJxTTMoPSmViYGBQBWIQDQYpxQ6OCU8vKOVnOhz+qhHTX1Ts4ATiF2c6vK2x
N41rK3Yoypj4tsY90wFE2XcXO9w89z348d8Mh8dLZx9R6Ct2iNvlycN0OcOh
fN98KX2gPFjfugyHC0q3f9a1QM1bnOFw3793eh4S/2rFSzXDFqj6RVDzkPh8
upvmvm8udnDpznn+e2GGg8IGoEuA/G9AZx4C8r3NOx0TgHz9uypsjUD+ZAmW
MD4gH+xOIP8iyP6mYof9QGfdXQC1D8gvtOW6vngB1D4kPti+xmIH2agU6/vz
Mxy028VunkPiW205UbYPyAfTQD7YXiR5kDEFSHwQ5Y+kvlpknfvDBoT8MqD1
G5D4YGVIfHA4IPF3yLW+DkTiHwMFABIfHJ9IfF6Qf+oRfDCdjOBbgiwMLoaE
0yUEv296nlCzTiacHwYKmPBMh9znv1d+jIKGV06mA3r6AQC7qQgE
                    
                    "], CompressedData["
1:eJxTTMoPSmViYGDQA2IQXS2yzv0hS4GDS3fO898HMxy028VunlNE8Mv3zZfS
ty5wAKvbl+EgG5Vifd+7wIEBBHZkONhyXV9ckF7gUAhirMlwsNpyomxfZYHD
fqC2u3MyHLYCufObChy4gcpsuzIcLijd/lnXUuCgbsixRqYtw+FqxUs1w7YC
h4yJb2vsGzMcWl8H7pBrh+qvyXAQaj5waiGQDzanKgNib0eBQxif7qa55RkO
x7zNOx2BfB8glVCa4TAjD6gDyAfakrWnIMNh2ewjChuAfDW2xqnO2Qj1QNtM
49IyHBa5bvv8F+ieApD7XTIcpoP05xQ4TDj0VSNGOsNBCxQe9lD/vkl3uAhy
vxTU/CPpDlWgcNmW79APUj893QHk/flp+Q6PlwIt7kh30L+rwtb4MA/irrx0
B1WQO87nQeQr0h0sQRqm50HMfQc1rywP4h6TDIi6mDyI+UD/gt0Vneew6uMl
36QWBL8X5HAkPsRfCD44fFsRfLC7gHxwuAD54HhpQ8iD3YHEj93lycPUDg1/
oHuKQAa2I9wH9geQfxwUvkA+JJ4yIOkiBuoeIB8cr0A+SFlCJzT8Y6DuAfIN
QHRsHiT9AfnCoPgH8mHpB6yvEuqe5VD3JOQ7fNOI6T8ETK/o6RkA8GtGnw==

                    "], {{339.984, 185.88700000000003`}, {344.828, 186.098}, {
                    347.445, 182.824}, {342.18, 178.758}, {
                    338.79299999999995`, 176.141}, {333.816, 176.035}, {
                    330.734, 178.523}, {328.51599999999996`, 180.312}, {
                    328.629, 180.566}, {332.668, 183.285}, {
                    335.22299999999996`, 185.}, {337.82, 185.789}, {339.984, 
                    185.88700000000003`}}, CompressedData["
1:eJxTTMoPSmViYGBQBWIQfbXipZphVJmDS3fO898H0xwUNhRlTIwuc+C6vrjA
9lCaw2QJljC+2DKHm+e+Bz8Gyu+Qa30dGIdQb7XlRNm+TAT/mLd5p2NLmUPs
Lk8epuVpDhkT39bYzyxzAOoCak1zACmfv6/MYd98Kf27HmkOF5Ru/6wD8veD
+C5pDlrtYjfP9Zc5OCY8vaB0PdVBqPnAqYXlZQ5AU0zj5qU6AG1Z+TEO6p7C
VIh4GNS9eakQ9yHxP13yTRJA4jOAABKfT3fT3PehCL7HwyqRdUh8YZD9SHxF
UPgg8aNSrO/7I/HB/kXil4M8isTPBbk/BMGvFlnn/hCJDw4fvzIHdUOONTJF
qQ6HvmrE9OuUOdz5WZe1pybVARS8CZzQ8GhLdTgOEnhUCgnfiamQ+DtZ6lBo
CzRxA4IPC08YHxz+N1Ih8QfkO4Hkb0PDA8hf5Lrt8987qQ6Pl84+onChFBLe
smkQcYMyBxmQx7enOaCnHwBpDxOs
                    "], {{268.883, 176.648}, {
                    269.10900000000004`, 176.66}, {269.375, 176.648}, {269.66,
                     176.648}, {272.99199999999996`, 176.648}, {274.828, 
                    173.906}, {274.828, 168.92200000000003`}, {274.828, 
                    162.22299999999998`}, {270.746, 162.762}, {
                    268.85900000000004`, 169.70299999999997`}, {267.219, 
                    175.74599999999998`}, {267.055, 176.547}, {268.883, 
                    176.648}}, CompressedData["
1:eJxNk21IVFEQhhcRifwgLCJExRZTCUL8EWGx7KhFREQUsfdai4XsgUVEt1NY
lEiiYRFSErHaJkuK/ogQiRLpw0Skwh+6H9ZmKRIRIWFRUSAhNHPuwDkXLofn
zpwz55137vb65uMizeVyefGlVT0BCWp9L+DzUGS6qFPC/huNX/8tCMjZ9aj/
R1xCacWGh/ljAn4ljtRvWpTwt8x/c6qf85E3d0zO3EdePtodbkIeODD2e/2e
5pfRvPIl5Jj741ob8uJaW8Nz5OtVZ77EkNU5Bqv7IF/eMnLwE3LBycC+5YiO
35r6U+Y3uCSj/U5NROdX42c38oUJKiwhQXXvav7e6t1dhxzsWW31ImemBkMe
I6709GkuXyrOaO/T+Yf3YGUjrpZezR9In8Ehz8bUYK/er/QZ8XzSFxbw9uJK
SQXefwfp6RJOndcSKh+/aZmoEbBK9x6R8OAnGuESMF549duxKxJeUWJnwNkf
5H4WC+e7n/t3jvtzQoKPjH3G/vgkvDh/e1v6rGblt8FPsHzUYHWOwWSDe05A
uCm3Y9LH/iBfowCyRfUM3kt6jHylJ6bj3RRAvkR1kM9S/5BR7XihJZ01zv2z
2I8499div5BpW8jieUYuGpXBHov1JQTkks/IlOZBVj5YrA85m+Yfue7poay0
pHB8s3m+ktxfW+crP2ydr/wy8kl21GY/kYfRplGb/UnyPNs8H/Osp5b7Mc96
anmekHd2bV2YPSWd/+od6zvN56f4vsb//R8cH8Yx
                    
                    "], CompressedData["
1:eJxTTMoPSmViYGDQAGIQfeirRkz/vEKHjIlva+wnpjoASdO4JYUQelKqg8Fd
FbbGtYUOE8AKUx0eL519RGEXlN+d6mDLdX1xweVChyKQAc2pDsuA0hteFTp4
m3c6JkSmOoC1vSt06JueJ9Ssk+oQlWJ93/9zocPekskSLN9SIOo/FDrIgiTO
pzh8uuSbJADUD7ZnT4qDwgagyS8LHbaeKNs3f1eKwwygMQdeFDqs+ghUuCPF
4WrFSzVDIN8x4ekFpe0pDvog9z4vdACqOrVwa4rDFpC+Z1DztqQ48Olumvv+
aaFDtcg694ebUhyEQeqA/ItKt3/WAflAV4XxAflg8Y0pDiBnH3gCDR8gH+zf
x4UOxSCB9SkOViALHhY63Dz3Pfjx2hSHYyCPPyh0aH0duEMOyAe7436hw52f
dVl71kDdc6/QYTXI/UA+AwgA+cdB+oB8sLvuFELEgXxwON5G8MH+vYVQD3bv
2UKHcJDH1kPDbw/UvxdSIO6GxR9/KkT/HKh8BDS+p0DDtyoVYt/0Qod986X0
73akQtw/Heq/Tmj8z0DE/wVQuM2Auqcn1UG7XezmuZmFkHjqS3XQAvFnFzoU
ggJuAjQ9IKU3ADaTNHQ=
                    "]}]}}}}}}}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 600.}, {0., 400.}}], ",", 
           GraphicsBox[{{{{
                {Thickness[0.0017211703958691911`], {{{
                    {RGBColor[0., 0.21960800000000003`, 0.5764710000000001], 
                    Thickness[0.07213642512908776], Opacity[1.], CapForm[
                    "Butt"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, {{{21.047, 365.337471}, {507.949, 
                    365.337471}, {21.047, 670.247471}, {21.047, 
                    21.04847099999995}, {507.949, 21.04847099999995}, {21.047,
                     507.946471}}},
                    CurveClosed->{1}]}}}}, {{{
                    {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{159.875, 
                    129.36100000000002`}, {142.77299999999997`, 
                    88.99700000000001}, {125.66799999999999`, 
                    129.36100000000002`}}}]}}}}}}}}, {{{{
                 {RGBColor[
                  0.8627450000000002, 0.07843140000000001, 
                   0.23529400000000003`], 
                  PolygonBox[{{{21.047, 365.337}, {507.949, 365.337}, {21.047,
                    670.247}}}]}}}}, {{{
                 {RGBColor[
                  0.8627450000000002, 0.07843140000000001, 
                   0.23529400000000003`], 
                  PolygonBox[{{21.047, 21.048}, {507.949, 21.048}, {21.047, 
                   507.947}}]}}}}}, {{{
                {Thickness[0.0017211703958691911`], 
                 {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                  FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                   3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4r0lkyVYnrk5uG37/PfKr1qH4oyJb2vq/RwW
SOnfVZlQ7dB84NRCV79Ih9eBO+Rab1Y63PpZl7XnRiKc/67G3jSOKx3OFwZp
EMyB62cAgR+5cPNh/AJbruuLU2ocgKrYGlfmOGjG9B/6eqHKIW6XJw9TdpbD
QaC12zZWOhSC1OlkOERabjlRNqnCoRVkEWuqgypb41Tn1+Vw98D4vdPzhJoj
YuF8kPN2cYbD9d8Gqe8JgpsPdo+CD9x+WHjA3IcePgAXt4qb
                   "]], 
                  FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                   3}}}, {{{187.90200000000002`, 434.552}, {
                   187.90200000000002`, 409.626}, {167.695, 
                   389.42299999999994`}, {142.77299999999997`, 
                   389.42299999999994`}, {117.848, 389.42299999999994`}, {
                   97.645, 409.626}, {97.645, 434.552}, {97.645, 459.474}, {
                   117.848, 479.677}, {142.77299999999997`, 479.677}, {
                   167.695, 479.677}, {187.90200000000002`, 459.474}, {
                   187.90200000000002`, 434.552}}}], 
                  FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                   160.04299999999998`, 476.243}, {155., 
                   496.02099999999996`}, {142.77299999999997`, 479.677}}}], 
                  FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{174.684, 
                   466.462}, {177.594, 486.661}, {160.04299999999998`, 
                   476.243}}}], 
                  FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{184.465, 
                   451.822}, {194.883, 469.368}, {174.684, 466.462}}}], 
                  FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                   187.90200000000002`, 434.552}, {204.242, 446.779}, {
                   184.465, 451.822}}}], 
                  FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{184.465, 
                   417.282}, {204.242, 422.325}, {187.90200000000002`, 
                   434.552}}}], 
                  FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{174.684, 
                   402.64200000000005`}, {194.883, 399.73199999999997`}, {
                   184.465, 417.282}}}], 
                  FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{125.504, 
                   476.243}, {130.547, 496.02099999999996`}, {
                   142.77299999999997`, 479.677}}}], 
                  FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{110.863, 
                   466.462}, {107.953, 486.661}, {125.504, 476.243}}}], 
                  FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{101.082, 
                   451.822}, {90.664, 469.368}, {110.863, 466.462}}}], 
                  FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{97.645, 
                   434.552}, {81.30499999999999, 446.779}, {101.082, 
                   451.822}}}], 
                  FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{101.082, 
                   417.282}, {81.30499999999999, 422.325}, {97.645, 
                   434.552}}}], 
                  FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{110.863, 
                   402.64200000000005`}, {90.664, 399.73199999999997`}, {
                   101.082, 417.282}}}], 
                  FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                   3}}}, {{{208.85500000000002`, 193.19299999999998`}, {
                   208.85500000000002`, 156.697}, {179.26999999999998`, 
                   127.111}, {142.77299999999997`, 127.111}, {106.277, 
                   127.111}, {76.691, 156.697}, {76.691, 
                   193.19299999999998`}, {76.691, 229.689}, {106.277, 
                   259.279}, {142.77299999999997`, 259.279}, {
                   179.26999999999998`, 259.279}, {208.85500000000002`, 
                   229.689}, {208.85500000000002`, 193.19299999999998`}}}], 
                  FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{159.875, 
                   129.36100000000002`}, {142.77299999999997`, 
                   88.99700000000001}, {125.66799999999999`, 
                   129.36100000000002`}}}], 
                  FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                   125.66799999999999`, 257.025}, {142.77299999999997`, 
                   297.392}, {159.875, 257.025}}}], 
                  FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                   78.94100000000002, 176.091}, {38.574, 
                   193.19299999999998`}, {78.94100000000002, 210.298}}}], 
                  FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{206.605, 
                   210.298}, {246.969, 193.19299999999998`}, {206.605, 
                   176.091}}}], 
                  FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                   125.66799999999999`, 129.36100000000002`}, {
                   90.67599999999999, 102.95400000000001`}, {96.043, 
                   146.466}}}], 
                  FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{159.875, 
                   257.025}, {194.871, 283.4309999999999}, {189.5, 
                   239.923}}}], 
                  FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                   78.94100000000002, 210.298}, {52.535000000000004`, 
                   245.29}, {96.043, 239.923}}}], 
                  FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{206.605, 
                   176.091}, {233.012, 141.095}, {189.5, 146.466}}}], 
                  FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{96.043, 
                   146.466}, {52.535000000000004`, 141.095}, {
                   78.94100000000002, 176.091}}}], 
                  FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{189.5, 
                   239.923}, {233.012, 245.29}, {206.605, 210.298}}}], 
                  FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{96.043, 
                   239.923}, {90.67599999999999, 283.4309999999999}, {
                   125.66799999999999`, 257.025}}}], 
                  FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{189.5, 
                   146.466}, {194.871, 102.95400000000001`}, {159.875, 
                   129.36100000000002`}}}]}}}}}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 581.}, {0., 709.}}], ",", 
           GraphicsBox[{{{{
                {Thickness[0.001388888888888889], {{{
                    {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 480.}, {720., 480.}, {720., 0.}}}]}}}}, {{{
                    {FaceForm[{RGBColor[
                    0.003921569999999999, 0.254902, 0.109804], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    180., 480.}, {720., 480.}, {720., 0.}, {180., 
                    0.}}}]}}}}, {{{
                    {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{594., 240.}, {594., 160.47299999999998`}, {
                    529.5269999999999, 96.}, {450., 96.}, {
                    370.47299999999996`, 96.}, {306., 160.47299999999998`}, {
                    306., 240.}, {306., 319.527}, {370.47299999999996`, 
                    384.}, {450., 384.}, {529.5269999999999, 384.}, {594., 
                    319.527}, {594., 240.}}}]}}}}, {{{
                    {FaceForm[{RGBColor[
                    0.003921569999999999, 0.254902, 0.109804], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{585.4649999999999, 360.414}, {633.898, 
                    305.92599999999993`}, {628.992, 222.49200000000002`}, {
                    574.504, 174.059}, {520.016, 125.62899999999999`}, {
                    436.582, 130.535}, {388.148, 185.023}, {339.719, 
                    239.512}, {344.625, 322.941}, {399.113, 371.375}, {
                    453.59799999999996`, 419.809}, {537.031, 414.902}, {
                    585.4649999999999, 360.414}}}]}}}}}}}}, {{{
                {RGBColor[1., 1., 1.], 
                 PolygonBox[{{473.984, 299.066}, {508.04896572377527`, 
                  291.59710042426104`}, {511.47299999999996`, 256.895}, {
                  529.1002640300983, 286.9815069648755}, {563.168, 279.512}, {
                  539.9966282021564, 305.5796022787413}, {539.9966282021563, 
                  305.5796022787413}, {557.625, 335.668}, {525.6781375521971, 
                  321.6877862374376}, {502.508, 347.754}, {505.9325235671064, 
                  313.0469406822399}}]}}}}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 720.}, {0., 480.}}], ",", 
           GraphicsBox[{{{
               {Thickness[0.001388888888888889], {{{
                   {FaceForm[{RGBColor[
                    0., 0.21960800000000003`, 0.6588240000000001], Opacity[
                    1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{0., 0.}, {0., 360.}, {720., 360.}, {720., 
                    0.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.8078430000000001, 0.06666670000000002, 0.14902], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     180.}, {720., 180.}, {720., 0.}, {0., 0.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{311.77, 
                    180.}, {0., 0.}, {0., 360.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.988235, 0.8196080000000001, 0.08627450000000002], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{148., 180.}, {148., 160.117}, {131.883, 144.}, {
                    112., 144.}, {92.117, 144.}, {76., 160.117}, {76., 
                    180.}, {76., 199.883}, {92.117, 216.}, {112., 216.}, {
                    131.883, 216.}, {148., 199.883}, {148., 180.}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    36., 180.}, {40.676, 175.324}, {112., 180.}, {40.676, 
                    184.676}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{44., 
                    171.047}, {47.815999999999995`, 167.23399999999998`}, {
                    112., 180.}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{44., 
                    188.953}, {47.815999999999995`, 192.766}, {112., 180.}}}],
                     FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    58.26200000000001, 233.738}, {58.26200000000001, 
                    227.129}, {112., 180.}, {64.871, 233.738}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{57.586, 
                    221.754}, {57.586, 216.359}, {112., 180.}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    70.24600000000001, 234.414}, {75.641, 234.414}, {112., 
                    180.}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    112., 256.}, {107.324, 251.324}, {112., 180.}, {
                    116.67599999999999`, 251.324}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    103.04700000000001`, 248.}, {99.23400000000001, 
                    244.184}, {112., 180.}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{120.953, 
                    248.}, {124.766, 244.184}, {112., 180.}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    165.738, 233.738}, {159.129, 233.738}, {112., 180.}, {
                    165.738, 227.129}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{153.754, 
                    234.414}, {148.359, 234.414}, {112., 180.}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{166.414, 
                    221.754}, {166.414, 216.359}, {112., 180.}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    188., 180.}, {183.324, 184.676}, {112., 180.}, {183.324, 
                    175.324}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{180., 
                    188.953}, {176.184, 192.766}, {112., 180.}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{180., 
                    171.047}, {176.184, 167.23399999999998`}, {112., 180.}}}],
                     FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    165.738, 126.262}, {165.738, 132.871}, {112., 180.}, {
                    159.129, 126.262}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{166.414, 
                    138.24599999999998`}, {166.414, 143.641}, {112., 180.}}}],
                     FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{153.754, 
                    125.586}, {148.359, 125.586}, {112., 180.}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    112., 104.}, {116.67599999999999`, 108.67599999999999`}, {
                    112., 180.}, {107.324, 108.67599999999999`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{120.953, 
                    112.}, {124.766, 115.816}, {112., 180.}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    103.04700000000001`, 112.}, {99.23400000000001, 
                    115.816}, {112., 180.}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    58.26200000000001, 126.262}, {64.871, 126.262}, {112., 
                    180.}, {58.26200000000001, 132.871}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    70.24600000000001, 125.586}, {75.641, 125.586}, {112., 
                    180.}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{57.586, 
                    138.24599999999998`}, {57.586, 143.641}, {112., 180.}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, {{{275.77, 180.}, {262.242, 175.297}, {
                    261.949, 160.98000000000002`}, {253.297, 
                    172.39100000000002`}, {239.59, 168.24599999999998`}, {
                    247.76999999999998`, 180.}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, {{{275.77, 180.}, {262.242, 
                    184.70299999999997`}, {261.949, 199.02}, {253.297, 
                    187.60899999999998`}, {239.59, 191.754}, {
                    247.76999999999998`, 180.}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, {{{18., 31.176000000000002`}, {
                    20.691000000000003`, 45.242000000000004`}, {
                    8.437999999999999, 52.656}, {22.648, 
                    54.440999999999995`}, {25.91, 68.387}, {32., 55.426}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, {{{18., 31.176000000000002`}, {
                    28.836000000000002`, 40.543}, {41.382999999999996`, 
                    33.633}, {35.824, 46.836}, {46.27, 56.633}, {32., 
                    55.426}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, {{{18., 328.824}, {28.836000000000002`, 
                    319.457}, {41.382999999999996`, 326.367}, {35.824, 
                    313.16400000000004`}, {46.27, 303.367}, {32., 304.574}}}],
                     FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, {{{18., 328.824}, {20.691000000000003`, 
                    314.758}, {8.437999999999999, 307.34400000000005`}, {
                    22.648, 305.559}, {25.91, 291.613}, {32., 
                    304.574}}}]}}}}}}}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 720.}, {0., 360.}}], ",", 
           GraphicsBox[{{{
               {Thickness[0.001639344262295082], {{{
                   {FaceForm[{RGBColor[
                    0.5529410000000001, 0.105882, 0.23921600000000004`], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     240.}, {609.602, 240.}, {609.602, 0.}, {0., 
                    0.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGZiQAd5DhhCYJABF7/1sy5rj0Sew81z34MfL9Vy
gMlPkWAJ41tr5QCTh4i7wOW3ff57pWKlF1xeha1xqvPqAAdU80Pg8rdBdEg4
XB6iPgrN/Di4/Lsae9O4VQlweaHmA6cWhiahmZ8Cl4eoT4XLQ9Sno5mfiWZ+
Fpr5OWjm5zkAADWeXto=
                    "]]}}}}}}}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 610.}, {0., 240.}}], ",", 
           GraphicsBox[{{{
               {Thickness[0.00028935185185185184`], {{{
                   {FaceForm[{RGBColor[
                    0.9294119999999999, 0.160784, 0.223529], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     2304.}, {3456., 2304.}, {3456., 1152.}, {0., 
                    1152.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     1152.}, {3456., 1152.}, {3456., 0.}, {0., 0.}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJDIGYCYm/zTseE1kkODGAw2wHGf6lmyKEjO8tBla1x
qnPEJAc+3U1z861mOrSL3TxXzjjJgWONTNSTjBlgdWtWTXQACn8Pnj7d4fbP
uiwbrYkOP4IfL5W+Ps3hsm+SwI3OCQ5yra8Dd5hNc5jq3J3z/FI/WDxi2lSH
bZ//XqkI6nM4qrCh6IXoVIj963sg+vdPcciY+LbGnqfbYe775ce8M6Y4CERY
bjnh1ukA1G1pYj3F4fHS2UcUGtvhfP27KmyNu1vh/EqQA781w/WD7Q9qgpsP
tO3phfUNcPun5wk1H4irg7uvfN98Kf271XD3A2VPLYyuhPtPNirF+n5kOdz/
IOds+FcKDx+wexaXwMNvsgRLGN/7Ynj4wviw8IfxxYHmXX40G67/4yXfpAlH
58DNB9s/fS7cfnA8ZMyDuw9sv8Z8uPsfVomscz85H+4/sPkmC+D+nwcMH+7S
BfDwAbpCt2jBAnj4AU2XuXV6ATx8z38Pfpz6aAE8/GF8WPzA+LD4g+mHxS/M
fFj8o9gPTB8w98HSD8z9sPQF8x8s/cH8D0ufsPCBpV9Y+MHSNyx80dM/AJyY
ZBE=
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.9294119999999999, 0.160784, 0.223529], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJDIGYCYh/zTscHS6c4MIDBbAcYv9CW6/pizVkOGRPf
1thXT3HwBoonBM90kG99HWihOcXhsm+SQETvDIdls48oGFyf7DD3/fJj3sen
O0SlWN8/HzsZol9wOkT/sUkO69wfVolUTXN4qWbIsUZvEti+hkdTHfaUTJZg
qZzosOVE2T75zKkOLt05z39vmuBgfd+/V1x8qsM0Z6DAzX6HT5eAFh6F2qvb
53Bqoeu24llTHLYC9c1v6IHz+XQ3zX1/uQvOB7tbvROuH+Q+/9ntcPPB7uNv
g9sP1r+4Be4+wQjLLSdKmuHuB0kvd22C+28qyH1BjXD/Ly4ASqxrgIePAEg/
VwM8/IC+DePLroeHL4wPC38Yv//QV42Ya7Ph+kHum79mDtx8HZA7iubC7U8C
KbSYB3cfWP+7eXD3B+2Qa33dOh/uP1AaOMC3AO5/UDwWeC+Ahw/IvJKSBfDw
axe7ea587gJ4+Err31U5tmkBPPxhfFj8wPiw+IPph8UvzHxY/MPsh6UPFPcB
0w/M/bD0BfMfLP3B/A9Ln7DwgaVfWPjB0jcsfNHTPwCAp1ta
                    
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{805.758, 1717.547}, {746.906, 
                    1762.6909999999998`}, {688.0740000000001, 1717.527}, {
                    710.727, 1790.3239999999998`}, {651.6880000000001, 
                    1835.195}, {724.535, 1835.043}, {746.883, 1907.941}, {
                    769.254, 1835.051}, {842.102, 1835.23}, {783.082, 
                    1790.336}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{1267.508, 1717.547}, {1208.6599999999999`, 
                    1762.6909999999998`}, {1149.8239999999998`, 1717.527}, {
                    1172.477, 1790.3239999999998`}, {1113.441, 1835.195}, {
                    1186.289, 1835.043}, {1208.6329999999998`, 1907.941}, {
                    1231.008, 1835.051}, {1303.8519999999999`, 1835.23}, {
                    1244.8319999999999`, 1790.336}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{1036.867, 1888.9180000000001`}, {978.02, 
                    1934.062}, {919.1840000000001, 1888.895}, {
                    941.8359999999999, 1961.6909999999998`}, {
                    882.8009999999999, 2006.566}, {955.648, 2006.41}, {
                    977.996, 2079.309}, {1000.3669999999998`, 
                    2006.4180000000001`}, {1073.2150000000001`, 2006.598}, {
                    1014.191, 1961.703}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{892.156, 1443.348}, {833.309, 1488.492}, {
                    774.4730000000001, 1443.328}, {797.125, 1516.125}, {
                    738.09, 1560.996}, {810.938, 1560.8439999999998`}, {
                    833.2850000000001, 1633.742}, {855.656, 
                    1560.8519999999999`}, {928.504, 1561.031}, {869.48, 
                    1516.137}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{1181.105, 1443.348}, {1122.258, 1488.492}, {
                    1063.4260000000002`, 1443.328}, {1086.0739999999998`, 
                    1516.125}, {1027.039, 1560.996}, {1099.887, 
                    1560.8439999999998`}, {1122.234, 1633.742}, {1144.605, 
                    1560.8519999999999`}, {1217.453, 1561.031}, {1158.434, 
                    1516.137}}}]}}}}}}}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 3456.}, {0., 2304.}}], ",", 
           GraphicsBox[{{{
               {Thickness[0.001388888888888889], {{{
                   {FaceForm[{RGBColor[
                    0.9294119999999999, 0.109804, 0.141176], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 480.}, {720., 480.}, {720., 0.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     400.}, {720., 400.}, {720., 80.}, {0., 80.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.141176, 0.11372500000000002`, 0.309804], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     320.}, {720., 320.}, {720., 160.}, {0., 160.}}}]}}}}}}}},
            
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 720.}, {0., 480.}}], ",", 
           GraphicsBox[{{{
               {Thickness[0.001388888888888889], {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 480.}, {720., 480.}, {720., 0.}}}]}}}}, {{{
                   {Thickness[0.001388888888888889], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    110.387, 334.301}, {176.94899999999998`, 
                    434.14500000000004`}, {243.512, 389.77}, {
                    176.94899999999998`, 289.92199999999997`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    121.48, 314.883}, {199.137, 431.371}, {
                    207.45700000000002`, 425.824}, {129.80100000000002`, 
                    309.33599999999996`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    146.441, 298.242}, {224.098, 414.72999999999996`}, {
                    232.418, 409.184}, {154.762, 292.695}}}]}}}}, {{{
                   {Thickness[0.001388888888888889], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    476.48799999999994`, 90.23}, {543.0509999999999, 
                    190.078}, {609.613, 145.69899999999998`}, {
                    543.0509999999999, 45.855}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    487.582, 70.816}, {565.238, 187.305}, {573.559, 
                    181.758}, {495.902, 65.27}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    512.543, 54.176}, {590.1990000000001, 170.664}, {598.52, 
                    165.117}, {520.8629999999999, 48.629000000000005`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    498.676, 141.539}, {504.22299999999996`, 149.859}, {
                    587.4259999999999, 94.391}, {581.879, 86.07}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.776471, 0.047058800000000005`, 0.188235], Opacity[1.]}],
                     FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{426.562, 339.848}, {481.707, 303.082}, {
                    496.60900000000004`, 228.578}, {459.848, 
                    173.43800000000002`}, {423.082, 118.293}, {348.578, 
                    103.391}, {293.43799999999993`, 140.15200000000002`}, {
                    238.29299999999998`, 176.918}, {223.39100000000002`, 
                    251.42200000000003`}, {260.15200000000004`, 306.562}, {
                    296.91799999999995`, 361.707}, {371.42199999999997`, 
                    376.60900000000004`}, {426.562, 339.848}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0., 0.20392200000000002`, 0.47058800000000006`], Opacity[
                    1.]}], FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {
                    1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4gf+vdPznAocFrlu+/xXo9hBla1xqnN4nkOH
Y8LTC22FEPGQfIfW14E75CTzHKbnCTUf8Cl0KM6Y+LbmdbZDzvPfKz++K3K4
ee578OO9mQ7l++ZL6WeWQuR3ZzkwgEBDGYRmgJo7rdzhuLd5p+OiAofJEixh
fIJVEFqx0AGkzX5zNUSeq8DB4K4KW2NorUOVyDr3h89yHYCypnFXaiH0pwwH
xQ1FGRP31jjsLQGasC7VYensIwobllU76IP0ZSY52HFdX1zwtNLBasuJsn38
CQ6HvmrE9P8oh9gzNc4B6JtTC7nLIP7iioW4/2exgxcPk3b7ujiH2F2ePEzh
RQ77gcJ3WxIh6rYUOGwFGjd/UzLUXGj4mKZDxL3yHKpB7uXLdvABeiOhNdfh
1s+6rD0v8jDCFz38ASyVsr0=
                    "]]}}}}, {{{
                   {Thickness[0.001388888888888889], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    176.94899999999998`, 45.855}, {110.387, 
                    145.69899999999998`}, {176.94899999999998`, 190.078}, {
                    243.512, 90.23}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    199.137, 48.629000000000005`}, {121.48, 165.117}, {
                    129.80100000000002`, 170.664}, {207.45700000000002`, 
                    54.176}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    224.098, 65.27}, {146.441, 181.758}, {154.762, 187.305}, {
                    232.418, 70.816}}}]}}}}, {{{
                   {Thickness[0.001388888888888889], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    543.0509999999999, 289.92199999999997`}, {
                    476.48799999999994`, 389.77}, {543.0509999999999, 
                    434.14500000000004`}, {609.613, 334.301}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    565.238, 292.695}, {487.582, 409.184}, {495.902, 
                    414.72999999999996`}, {573.559, 298.242}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    590.1990000000001, 309.33599999999996`}, {512.543, 
                    425.824}, {520.8629999999999, 431.371}, {598.52, 
                    314.883}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    504.22299999999996`, 330.141}, {498.676, 
                    338.46099999999996`}, {581.879, 393.92999999999995`}, {
                    587.4259999999999, 385.60900000000004`}}}]}}}}, {{{
                   {Thickness[0.001388888888888889], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    540.277, 348.168}, {529.1840000000001, 364.809}, {545.824,
                     375.902}, {556.918, 359.262}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    163.08200000000002`, 102.71100000000001`}, {157.535, 
                    111.031}, {190.816, 133.21899999999997`}, {196.363, 
                    124.898}}}]}}}}}}}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 720.}, {0., 480.}}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           GraphicsBox[{{{
               {Thickness[0.000925925925925926], {{{
                   {FaceForm[{RGBColor[1., 0.6, 0.2], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 720.}, {1080., 720.}, {1080., 0.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     480.}, {1080., 480.}, {1080., 240.}, {0., 
                    240.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.0705882, 0.533333, 0.027451000000000003`], Opacity[
                    1.]}], FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{0., 240.}, {1080., 240.}, {1080., 0.}, {0., 
                    0.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[0., 0., 0.533333], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{636., 360.}, {636., 306.97999999999996`}, {
                    593.02, 264.}, {540., 264.}, {486.97999999999996`, 
                    264.}, {444., 306.97999999999996`}, {444., 360.}, {444., 
                    413.02}, {486.97999999999996`, 456.}, {540., 456.}, {
                    593.02, 456.}, {636., 413.02}, {636., 360.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{624., 360.}, {624., 313.60900000000004`}, {
                    586.391, 276.}, {540., 276.}, {493.60900000000004`, 
                    276.}, {456., 313.60900000000004`}, {456., 360.}, {456., 
                    406.39099999999996`}, {493.60900000000004`, 444.}, {540., 
                    444.}, {586.391, 444.}, {624., 406.39099999999996`}, {
                    624., 360.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[0., 0., 0.533333], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{556.8009999999999, 360.}, {556.8009999999999, 
                    350.72299999999996`}, {549.277, 343.199}, {540., 
                    343.199}, {530.7230000000001, 343.199}, {
                    523.1990000000001, 350.72299999999996`}, {
                    523.1990000000001, 360.}, {523.1990000000001, 369.277}, {
                    530.7230000000001, 376.801}, {540., 376.801}, {549.277, 
                    376.801}, {556.8009999999999, 369.277}, {
                    556.8009999999999, 360.}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{627.4449999999999, 348.48799999999994`}, {
                    627.145, 346.188}, {625.031, 344.57}, {622.734, 
                    344.871}, {620.434, 345.176}, {618.8159999999999, 
                    347.28499999999997`}, {619.117, 349.58599999999996`}, {
                    619.4219999999999, 351.883}, {621.531, 353.504}, {623.828,
                     353.199}, {626.129, 352.89799999999997`}, {627.75, 
                    350.789}, {627.4449999999999, 348.48799999999994`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    540., 276.}, {542.879, 326.39799999999997`}, {540., 
                    350.39799999999997`}, {537.121, 326.39799999999997`}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{621.484, 326.246}, {620.5980000000001, 
                    324.105}, {618.141, 323.08599999999996`}, {616., 
                    323.97299999999996`}, {613.8549999999999, 324.863}, {
                    612.8399999999999, 327.32}, {613.727, 
                    329.46099999999996`}, {614.613, 331.605}, {617.07, 
                    332.621}, {619.215, 331.734}, {621.3549999999999, 
                    330.848}, {622.375, 328.39099999999996`}, {621.484, 
                    326.246}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    518.258, 278.863}, {534.086, 326.801}, {537.516, 
                    350.727}, {528.523, 328.289}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{609.9730000000001, 306.309}, {608.5619999999999, 
                    304.469}, {605.9259999999999, 304.121}, {604.086, 
                    305.53099999999995`}, {602.246, 306.945}, {601.898, 
                    309.582}, {603.309, 311.42199999999997`}, {
                    604.7230000000001, 313.262}, {607.3589999999999, 
                    313.60900000000004`}, {609.1990000000001, 312.195}, {
                    611.039, 310.78499999999997`}, {611.387, 308.148}, {
                    609.9730000000001, 306.309}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    498., 287.254}, {525.695, 329.46099999999996`}, {
                    535.1990000000001, 351.688}, {520.707, 
                    332.34000000000003`}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{593.691, 290.027}, {591.8519999999999, 
                    288.613}, {589.215, 288.96099999999996`}, {587.805, 
                    290.801}, {586.391, 292.641}, {586.738, 295.277}, {
                    588.5780000000001, 296.691}, {590.418, 
                    298.10200000000003`}, {593.055, 297.754}, {
                    594.4689999999999, 295.914}, {595.879, 294.074}, {595.531,
                     291.43799999999993`}, {593.691, 290.027}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    480.60200000000003`, 300.60200000000003`}, {518.277, 
                    334.203}, {533.211, 353.21099999999996`}, {
                    514.2030000000001, 338.277}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{573.754, 278.51599999999996`}, {571.609, 
                    277.625}, {569.1519999999999, 278.64500000000004`}, {
                    568.266, 280.78499999999997`}, {567.379, 
                    282.92999999999995`}, {568.395, 285.387}, {570.539, 
                    286.27299999999997`}, {572.6800000000001, 287.16}, {
                    575.137, 286.14500000000004`}, {576.0269999999999, 
                    284.}, {576.914, 281.85900000000004`}, {575.895, 
                    279.402}, {573.754, 278.51599999999996`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    467.254, 318.}, {512.3399999999999, 340.707}, {
                    531.6880000000001, 355.199}, {509.46099999999996`, 
                    345.695}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{551.512, 272.555}, {549.211, 272.25}, {547.102, 
                    273.871}, {546.8009999999999, 276.172}, {546.496, 
                    278.469}, {548.117, 280.578}, {550.414, 280.883}, {
                    552.715, 281.184}, {554.824, 279.566}, {555.129, 
                    277.26599999999996`}, {555.43, 274.969}, {
                    553.8119999999999, 272.855}, {551.512, 272.555}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    458.863, 338.258}, {508.289, 348.52299999999997`}, {
                    530.727, 357.51599999999996`}, {506.801, 
                    354.08599999999996`}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{528.488, 272.555}, {526.1880000000001, 
                    272.855}, {524.57, 274.969}, {524.871, 
                    277.26599999999996`}, {525.176, 279.566}, {
                    527.2850000000001, 281.184}, {529.586, 280.883}, {531.883,
                     280.578}, {533.504, 278.469}, {533.1990000000001, 
                    276.172}, {532.898, 273.871}, {530.7890000000001, 
                    272.25}, {528.488, 272.555}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    456., 360.}, {506.39799999999997`, 357.121}, {530.398, 
                    360.}, {506.39799999999997`, 362.879}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{506.246, 278.51599999999996`}, {504.105, 
                    279.402}, {503.08599999999996`, 281.85900000000004`}, {
                    503.97299999999996`, 284.}, {504.863, 
                    286.14500000000004`}, {507.32, 287.16}, {
                    509.46099999999996`, 286.27299999999997`}, {511.605, 
                    285.387}, {512.621, 282.92999999999995`}, {511.734, 
                    280.78499999999997`}, {510.848, 278.64500000000004`}, {
                    508.39099999999996`, 277.625}, {506.246, 
                    278.51599999999996`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    458.863, 381.742}, {506.801, 365.914}, {530.727, 
                    362.484}, {508.289, 371.477}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{486.309, 290.027}, {484.469, 
                    291.43799999999993`}, {484.121, 294.074}, {
                    485.53099999999995`, 295.914}, {486.945, 297.754}, {
                    489.582, 298.10200000000003`}, {491.42199999999997`, 
                    296.691}, {493.262, 295.277}, {493.60900000000004`, 
                    292.641}, {492.195, 290.801}, {490.78499999999997`, 
                    288.96099999999996`}, {488.148, 288.613}, {486.309, 
                    290.027}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    467.254, 402.}, {509.46099999999996`, 374.305}, {
                    531.6880000000001, 364.801}, {512.3399999999999, 
                    379.29299999999995`}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{470.027, 306.309}, {468.613, 308.148}, {
                    468.96099999999996`, 310.78499999999997`}, {470.801, 
                    312.195}, {472.641, 313.60900000000004`}, {475.277, 
                    313.262}, {476.691, 311.42199999999997`}, {
                    478.10200000000003`, 309.582}, {477.754, 306.945}, {
                    475.914, 305.53099999999995`}, {474.074, 304.121}, {
                    471.43799999999993`, 304.469}, {470.027, 306.309}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    480.60200000000003`, 419.39799999999997`}, {
                    514.2030000000001, 381.72299999999996`}, {533.211, 
                    366.789}, {518.277, 385.79699999999997`}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{458.51599999999996`, 326.246}, {457.625, 
                    328.39099999999996`}, {458.64500000000004`, 330.848}, {
                    460.78499999999997`, 331.734}, {462.92999999999995`, 
                    332.621}, {465.387, 331.605}, {466.27299999999997`, 
                    329.46099999999996`}, {467.16, 327.32}, {
                    466.14500000000004`, 324.863}, {464., 
                    323.97299999999996`}, {461.85900000000004`, 
                    323.08599999999996`}, {459.402, 324.105}, {
                    458.51599999999996`, 326.246}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    498., 432.746}, {520.707, 387.66}, {535.1990000000001, 
                    368.312}, {525.695, 390.539}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{452.555, 348.48799999999994`}, {452.25, 
                    350.789}, {453.871, 352.89799999999997`}, {456.172, 
                    353.199}, {458.469, 353.504}, {460.578, 351.883}, {
                    460.883, 349.58599999999996`}, {461.184, 
                    347.28499999999997`}, {459.566, 345.176}, {
                    457.26599999999996`, 344.871}, {454.969, 344.57}, {
                    452.855, 346.188}, {452.555, 348.48799999999994`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    518.258, 441.137}, {528.523, 391.71099999999996`}, {
                    537.516, 369.27299999999997`}, {534.086, 393.199}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{452.555, 371.512}, {452.855, 373.812}, {454.969, 
                    375.42999999999995`}, {457.26599999999996`, 375.129}, {
                    459.566, 374.824}, {461.184, 372.715}, {460.883, 
                    370.414}, {460.578, 368.117}, {458.469, 
                    366.4959999999999}, {456.172, 366.801}, {453.871, 
                    367.10200000000003`}, {452.25, 369.21099999999996`}, {
                    452.555, 371.512}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    540., 444.}, {537.121, 393.60200000000003`}, {540., 
                    369.60200000000003`}, {542.879, 393.60200000000003`}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{458.51599999999996`, 393.754}, {459.402, 
                    395.895}, {461.85900000000004`, 396.914}, {464., 
                    396.027}, {466.14500000000004`, 395.137}, {467.16, 
                    392.68}, {466.27299999999997`, 390.539}, {465.387, 
                    388.395}, {462.92999999999995`, 387.379}, {
                    460.78499999999997`, 388.26599999999996`}, {
                    458.64500000000004`, 389.15200000000004`}, {457.625, 
                    391.60900000000004`}, {458.51599999999996`, 393.754}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    561.742, 441.137}, {545.914, 393.199}, {542.484, 
                    369.27299999999997`}, {551.477, 391.71099999999996`}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{470.027, 413.691}, {471.43799999999993`, 
                    415.53099999999995`}, {474.074, 415.879}, {475.914, 
                    414.469}, {477.754, 413.055}, {478.10200000000003`, 
                    410.41799999999995`}, {476.691, 408.578}, {475.277, 
                    406.73799999999994`}, {472.641, 406.39099999999996`}, {
                    470.801, 407.805}, {468.96099999999996`, 409.215}, {
                    468.613, 411.85200000000003`}, {470.027, 413.691}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    582., 432.746}, {554.305, 390.539}, {544.8009999999999, 
                    368.312}, {559.2930000000001, 387.66}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{486.309, 429.97299999999996`}, {488.148, 
                    431.387}, {490.78499999999997`, 431.039}, {492.195, 
                    429.199}, {493.60900000000004`, 427.35900000000004`}, {
                    493.262, 424.72299999999996`}, {491.42199999999997`, 
                    423.309}, {489.582, 421.89799999999997`}, {486.945, 
                    422.246}, {485.53099999999995`, 424.08599999999996`}, {
                    484.121, 425.92599999999993`}, {484.469, 428.562}, {
                    486.309, 429.97299999999996`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    599.398, 419.39799999999997`}, {561.7230000000001, 
                    385.79699999999997`}, {546.7890000000001, 366.789}, {
                    565.797, 381.72299999999996`}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{506.246, 441.484}, {508.39099999999996`, 
                    442.375}, {510.848, 441.355}, {511.734, 439.215}, {
                    512.621, 437.07}, {511.605, 434.613}, {
                    509.46099999999996`, 433.727}, {507.32, 
                    432.84000000000003`}, {504.863, 433.855}, {
                    503.97299999999996`, 436.}, {503.08599999999996`, 
                    438.141}, {504.105, 440.59799999999996`}, {506.246, 
                    441.484}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    612.746, 402.}, {567.66, 379.29299999999995`}, {
                    548.3119999999999, 364.801}, {570.539, 374.305}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{528.488, 447.445}, {530.7890000000001, 447.75}, {
                    532.898, 446.129}, {533.1990000000001, 443.828}, {533.504,
                     441.53099999999995`}, {531.883, 439.42199999999997`}, {
                    529.586, 439.117}, {527.2850000000001, 438.816}, {525.176,
                     440.43399999999997`}, {524.871, 442.734}, {524.57, 
                    445.03099999999995`}, {526.1880000000001, 
                    447.14500000000004`}, {528.488, 447.445}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    621.137, 381.742}, {571.711, 371.477}, {549.2730000000001,
                     362.484}, {573.1990000000001, 365.914}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{551.512, 447.445}, {553.8119999999999, 
                    447.14500000000004`}, {555.43, 445.03099999999995`}, {
                    555.129, 442.734}, {554.824, 440.43399999999997`}, {
                    552.715, 438.816}, {550.414, 439.117}, {548.117, 
                    439.42199999999997`}, {546.496, 441.53099999999995`}, {
                    546.8009999999999, 443.828}, {547.102, 446.129}, {549.211,
                     447.75}, {551.512, 447.445}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    624., 360.}, {573.602, 362.879}, {549.602, 360.}, {
                    573.602, 357.121}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{573.754, 441.484}, {575.895, 
                    440.59799999999996`}, {576.914, 438.141}, {
                    576.0269999999999, 436.}, {575.137, 433.855}, {
                    572.6800000000001, 432.84000000000003`}, {570.539, 
                    433.727}, {568.395, 434.613}, {567.379, 437.07}, {568.266,
                     439.215}, {569.1519999999999, 441.355}, {571.609, 
                    442.375}, {573.754, 441.484}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    621.137, 338.258}, {573.1990000000001, 
                    354.08599999999996`}, {549.2730000000001, 
                    357.51599999999996`}, {571.711, 348.52299999999997`}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{593.691, 429.97299999999996`}, {595.531, 
                    428.562}, {595.879, 425.92599999999993`}, {
                    594.4689999999999, 424.08599999999996`}, {593.055, 
                    422.246}, {590.418, 421.89799999999997`}, {
                    588.5780000000001, 423.309}, {586.738, 
                    424.72299999999996`}, {586.391, 427.35900000000004`}, {
                    587.805, 429.199}, {589.215, 431.039}, {591.8519999999999,
                     431.387}, {593.691, 429.97299999999996`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    612.746, 318.}, {570.539, 345.695}, {548.3119999999999, 
                    355.199}, {567.66, 340.707}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{609.9730000000001, 413.691}, {611.387, 
                    411.85200000000003`}, {611.039, 409.215}, {
                    609.1990000000001, 407.805}, {607.3589999999999, 
                    406.39099999999996`}, {604.7230000000001, 
                    406.73799999999994`}, {603.309, 408.578}, {601.898, 
                    410.41799999999995`}, {602.246, 413.055}, {604.086, 
                    414.469}, {605.9259999999999, 415.879}, {
                    608.5619999999999, 415.53099999999995`}, {
                    609.9730000000001, 413.691}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    599.398, 300.60200000000003`}, {565.797, 338.277}, {
                    546.7890000000001, 353.21099999999996`}, {
                    561.7230000000001, 334.203}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{621.484, 393.754}, {622.375, 
                    391.60900000000004`}, {621.3549999999999, 
                    389.15200000000004`}, {619.215, 388.26599999999996`}, {
                    617.07, 387.379}, {614.613, 388.395}, {613.727, 
                    390.539}, {612.8399999999999, 392.68}, {613.8549999999999,
                     395.137}, {616., 396.027}, {618.141, 396.914}, {
                    620.5980000000001, 395.895}, {621.484, 393.754}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    582., 287.254}, {559.2930000000001, 
                    332.34000000000003`}, {544.8009999999999, 351.688}, {
                    554.305, 329.46099999999996`}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{627.4449999999999, 371.512}, {627.75, 
                    369.21099999999996`}, {626.129, 367.10200000000003`}, {
                    623.828, 366.801}, {621.531, 366.4959999999999}, {
                    619.4219999999999, 368.117}, {619.117, 370.414}, {
                    618.8159999999999, 372.715}, {620.434, 374.824}, {622.734,
                     375.129}, {625.031, 375.42999999999995`}, {627.145, 
                    373.812}, {627.4449999999999, 371.512}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    561.742, 278.863}, {551.477, 328.289}, {542.484, 
                    350.727}, {545.914, 326.801}}}]}}}}}}}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 1080.}, {0., 720.}}], ",", 
           GraphicsBox[{{{
               {Thickness[0.0007936507936507937], {{{
                   {FaceForm[{RGBColor[
                    0.13725500000000002`, 0.623529, 0.25098000000000004`], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 720.}, {1260., 720.}, {1260., 0.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     480.}, {1260., 480.}, {1260., 240.}, {0., 
                    240.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[0.854902, 0., 0.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     240.}, {1260., 240.}, {1260., 0.}, {0., 0.}}}]}}}}, {{{
                   {RGBColor[1., 1., 1.], Thickness[0.0044444444444444444`], 
                    Opacity[1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}}, {{0, 2, 0}}}, {{{579.602, 516.398}, {
                    646.8009999999999, 516.398}}, {{579.602, 494.}, {579.602, 
                    505.19899999999996`}, {602., 505.19899999999996`}, {602., 
                    494.}, {624.398, 494.}, {624.398, 505.19899999999996`}, {
                    613.1990000000001, 505.19899999999996`}}, {{
                    646.8009999999999, 494.}, {635.602, 494.}, {635.602, 
                    505.19899999999996`}, {658., 505.19899999999996`}, {658., 
                    516.398}}, {{658., 505.19899999999996`}, {658., 494.}, {
                    680.398, 494.}, {680.398, 516.398}}, {{669.1990000000001, 
                    516.398}, {669.1990000000001, 494.}}, {{590.8009999999999,
                     494.}, {590.805, 494.}}},
                    CurveClosed->{0, 0, 0, 0, 0, 0}]}}}}, {{{
                   {RGBColor[1., 1., 1.], Thickness[0.005312127152597305], 
                    Opacity[1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{
                    579.6013999999999, 481.602}, {624.3986, 481.602}}, {{
                    635.6013999999999, 481.602}, {680.3986, 481.602}}},
                    CurveClosed->{0, 0}]}}}}, {{{
                   {RGBColor[1., 1., 1.], Thickness[0.0044444444444444444`], 
                    Opacity[1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}}, {{0, 2, 0}}}, {{{579.602, 226.}, {
                    646.8009999999999, 226.}}, {{579.602, 
                    203.60199999999998`}, {579.602, 214.801}, {602., 
                    214.801}, {602., 203.60199999999998`}, {624.398, 
                    203.60199999999998`}, {624.398, 214.801}, {
                    613.1990000000001, 214.801}}, {{646.8009999999999, 
                    203.60199999999998`}, {635.602, 203.60199999999998`}, {
                    635.602, 214.801}, {658., 214.801}, {658., 226.}}, {{658.,
                     214.801}, {658., 203.60199999999998`}, {680.398, 
                    203.60199999999998`}, {680.398, 226.}}, {{
                    669.1990000000001, 226.}, {669.1990000000001, 
                    203.60199999999998`}}, {{590.8009999999999, 
                    203.60199999999998`}, {590.805, 203.60199999999998`}}},
                    CurveClosed->{0, 0, 0, 0, 0, 0}]}}}}, {{{
                   {RGBColor[1., 1., 1.], Thickness[0.005312127152597305], 
                    Opacity[1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{
                    579.6013999999999, 238.39799999999997`}, {624.3986, 
                    238.39799999999997`}}, {{635.6013999999999, 
                    238.39799999999997`}, {680.3986, 238.39799999999997`}}},
                    CurveClosed->{0, 0}]}}}}, {{{
                   {RGBColor[1., 1., 1.], Thickness[0.0044444444444444444`], 
                    Opacity[1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}}, {{0, 2, 0}}}, {{{691.602, 516.398}, {
                    758.8009999999999, 516.398}}, {{691.602, 494.}, {691.602, 
                    505.19899999999996`}, {714., 505.19899999999996`}, {714., 
                    494.}, {736.398, 494.}, {736.398, 505.19899999999996`}, {
                    725.1990000000001, 505.19899999999996`}}, {{
                    758.8009999999999, 494.}, {747.602, 494.}, {747.602, 
                    505.19899999999996`}, {770., 505.19899999999996`}, {770., 
                    516.398}}, {{770., 505.19899999999996`}, {770., 494.}, {
                    792.398, 494.}, {792.398, 516.398}}, {{781.1990000000001, 
                    516.398}, {781.1990000000001, 494.}}, {{702.8009999999999,
                     494.}, {702.805, 494.}}},
                    CurveClosed->{0, 0, 0, 0, 0, 0}]}}}}, {{{
                   {RGBColor[1., 1., 1.], Thickness[0.005312127152597305], 
                    Opacity[1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{
                    691.6013999999999, 481.602}, {736.3986, 481.602}}, {{
                    747.6013999999999, 481.602}, {792.3986, 481.602}}},
                    CurveClosed->{0, 0}]}}}}, {{{
                   {RGBColor[1., 1., 1.], Thickness[0.0044444444444444444`], 
                    Opacity[1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}}, {{0, 2, 0}}}, {{{691.602, 226.}, {
                    758.8009999999999, 226.}}, {{691.602, 
                    203.60199999999998`}, {691.602, 214.801}, {714., 
                    214.801}, {714., 203.60199999999998`}, {736.398, 
                    203.60199999999998`}, {736.398, 214.801}, {
                    725.1990000000001, 214.801}}, {{758.8009999999999, 
                    203.60199999999998`}, {747.602, 203.60199999999998`}, {
                    747.602, 214.801}, {770., 214.801}, {770., 226.}}, {{770.,
                     214.801}, {770., 203.60199999999998`}, {792.398, 
                    203.60199999999998`}, {792.398, 226.}}, {{
                    781.1990000000001, 226.}, {781.1990000000001, 
                    203.60199999999998`}}, {{702.8009999999999, 
                    203.60199999999998`}, {702.805, 203.60199999999998`}}},
                    CurveClosed->{0, 0, 0, 0, 0, 0}]}}}}, {{{
                   {RGBColor[1., 1., 1.], Thickness[0.005312127152597305], 
                    Opacity[1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{
                    691.6013999999999, 238.39799999999997`}, {736.3986, 
                    238.39799999999997`}}, {{747.6013999999999, 
                    238.39799999999997`}, {792.3986, 238.39799999999997`}}},
                    CurveClosed->{0, 0}]}}}}, {{{
                   {RGBColor[1., 1., 1.], Thickness[0.0044444444444444444`], 
                    Opacity[1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}}, {{0, 2, 0}}}, {{{355.60200000000003`, 
                    516.398}, {422.801, 516.398}}, {{355.60200000000003`, 
                    494.}, {355.60200000000003`, 505.19899999999996`}, {378., 
                    505.19899999999996`}, {378., 494.}, {400.39799999999997`, 
                    494.}, {400.39799999999997`, 505.19899999999996`}, {
                    389.199, 505.19899999999996`}}, {{422.801, 494.}, {
                    411.60200000000003`, 494.}, {411.60200000000003`, 
                    505.19899999999996`}, {434., 505.19899999999996`}, {434., 
                    516.398}}, {{434., 505.19899999999996`}, {434., 494.}, {
                    456.39799999999997`, 494.}, {456.39799999999997`, 
                    516.398}}, {{445.199, 516.398}, {445.199, 494.}}, {{
                    366.801, 494.}, {366.805, 494.}}},
                    CurveClosed->{0, 0, 0, 0, 0, 0}]}}}}, {{{
                   {RGBColor[1., 1., 1.], Thickness[0.005312127152597305], 
                    Opacity[1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{355.6014, 
                    481.602}, {400.3986, 481.602}}, {{411.60139999999996`, 
                    481.602}, {456.3986, 481.602}}},
                    CurveClosed->{0, 0}]}}}}, {{{
                   {RGBColor[1., 1., 1.], Thickness[0.0044444444444444444`], 
                    Opacity[1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}}, {{0, 2, 0}}}, {{{355.60200000000003`, 
                    226.}, {422.801, 226.}}, {{355.60200000000003`, 
                    203.60199999999998`}, {355.60200000000003`, 214.801}, {
                    378., 214.801}, {378., 203.60199999999998`}, {
                    400.39799999999997`, 203.60199999999998`}, {
                    400.39799999999997`, 214.801}, {389.199, 214.801}}, {{
                    422.801, 203.60199999999998`}, {411.60200000000003`, 
                    203.60199999999998`}, {411.60200000000003`, 214.801}, {
                    434., 214.801}, {434., 226.}}, {{434., 214.801}, {434., 
                    203.60199999999998`}, {456.39799999999997`, 
                    203.60199999999998`}, {456.39799999999997`, 226.}}, {{
                    445.199, 226.}, {445.199, 203.60199999999998`}}, {{
                    366.801, 203.60199999999998`}, {366.805, 
                    203.60199999999998`}}},
                    CurveClosed->{0, 0, 0, 0, 0, 0}]}}}}, {{{
                   {RGBColor[1., 1., 1.], Thickness[0.005312127152597305], 
                    Opacity[1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{355.6014, 
                    238.39799999999997`}, {400.3986, 238.39799999999997`}}, {{
                    411.60139999999996`, 238.39799999999997`}, {456.3986, 
                    238.39799999999997`}}},
                    CurveClosed->{0, 0}]}}}}, {{{
                   {RGBColor[1., 1., 1.], Thickness[0.0044444444444444444`], 
                    Opacity[1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}}, {{0, 2, 0}}}, {{{467.60200000000003`, 
                    516.398}, {534.8009999999999, 516.398}}, {{
                    467.60200000000003`, 494.}, {467.60200000000003`, 
                    505.19899999999996`}, {490., 505.19899999999996`}, {490., 
                    494.}, {512.398, 494.}, {512.398, 505.19899999999996`}, {
                    501.199, 505.19899999999996`}}, {{534.8009999999999, 
                    494.}, {523.602, 494.}, {523.602, 505.19899999999996`}, {
                    546., 505.19899999999996`}, {546., 516.398}}, {{546., 
                    505.19899999999996`}, {546., 494.}, {568.398, 494.}, {
                    568.398, 516.398}}, {{557.1990000000001, 516.398}, {
                    557.1990000000001, 494.}}, {{478.801, 494.}, {478.805, 
                    494.}}},
                    CurveClosed->{0, 0, 0, 0, 0, 0}]}}}}, {{{
                   {RGBColor[1., 1., 1.], Thickness[0.005312127152597305], 
                    Opacity[1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{
                    467.60139999999996`, 481.602}, {512.3986, 481.602}}, {{
                    523.6013999999999, 481.602}, {568.3986, 481.602}}},
                    CurveClosed->{0, 0}]}}}}, {{{
                   {RGBColor[1., 1., 1.], Thickness[0.0044444444444444444`], 
                    Opacity[1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}}, {{0, 2, 0}}}, {{{467.60200000000003`, 
                    226.}, {534.8009999999999, 226.}}, {{467.60200000000003`, 
                    203.60199999999998`}, {467.60200000000003`, 214.801}, {
                    490., 214.801}, {490., 203.60199999999998`}, {512.398, 
                    203.60199999999998`}, {512.398, 214.801}, {501.199, 
                    214.801}}, {{534.8009999999999, 203.60199999999998`}, {
                    523.602, 203.60199999999998`}, {523.602, 214.801}, {546., 
                    214.801}, {546., 226.}}, {{546., 214.801}, {546., 
                    203.60199999999998`}, {568.398, 203.60199999999998`}, {
                    568.398, 226.}}, {{557.1990000000001, 226.}, {
                    557.1990000000001, 203.60199999999998`}}, {{478.801, 
                    203.60199999999998`}, {478.805, 203.60199999999998`}}},
                    CurveClosed->{0, 0, 0, 0, 0, 0}]}}}}, {{{
                   {RGBColor[1., 1., 1.], Thickness[0.005312127152597305], 
                    Opacity[1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{
                    467.60139999999996`, 238.39799999999997`}, {512.3986, 
                    238.39799999999997`}}, {{523.6013999999999, 
                    238.39799999999997`}, {568.3986, 238.39799999999997`}}},
                    CurveClosed->{0, 0}]}}}}, {{{
                   {RGBColor[1., 1., 1.], Thickness[0.0044444444444444444`], 
                    Opacity[1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}}, {{0, 2, 0}}}, {{{1027.6019999999999`, 
                    516.398}, {1094.801, 516.398}}, {{1027.6019999999999`, 
                    494.}, {1027.6019999999999`, 505.19899999999996`}, {1050.,
                     505.19899999999996`}, {1050., 494.}, {1072.398, 494.}, {
                    1072.398, 505.19899999999996`}, {1061.1989999999998`, 
                    505.19899999999996`}}, {{1094.801, 494.}, {
                    1083.6019999999999`, 494.}, {1083.6019999999999`, 
                    505.19899999999996`}, {1106., 505.19899999999996`}, {
                    1106., 516.398}}, {{1106., 505.19899999999996`}, {1106., 
                    494.}, {1128.398, 494.}, {1128.398, 516.398}}, {{
                    1117.1989999999998`, 516.398}, {1117.1989999999998`, 
                    494.}}, {{1038.801, 494.}, {1038.805, 494.}}},
                    CurveClosed->{0, 0, 0, 0, 0, 0}]}}}}, {{{
                   {RGBColor[1., 1., 1.], Thickness[0.005312127152597305], 
                    Opacity[1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{1027.6014, 
                    481.602}, {1072.3986, 481.602}}, {{1083.6013999999998`, 
                    481.602}, {1128.3986, 481.602}}},
                    CurveClosed->{0, 0}]}}}}, {{{
                   {RGBColor[1., 1., 1.], Thickness[0.0044444444444444444`], 
                    Opacity[1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}}, {{0, 2, 0}}}, {{{1027.6019999999999`, 
                    226.}, {1094.801, 226.}}, {{1027.6019999999999`, 
                    203.60199999999998`}, {1027.6019999999999`, 214.801}, {
                    1050., 214.801}, {1050., 203.60199999999998`}, {1072.398, 
                    203.60199999999998`}, {1072.398, 214.801}, {
                    1061.1989999999998`, 214.801}}, {{1094.801, 
                    203.60199999999998`}, {1083.6019999999999`, 
                    203.60199999999998`}, {1083.6019999999999`, 214.801}, {
                    1106., 214.801}, {1106., 226.}}, {{1106., 214.801}, {
                    1106., 203.60199999999998`}, {1128.398, 
                    203.60199999999998`}, {1128.398, 226.}}, {{
                    1117.1989999999998`, 226.}, {1117.1989999999998`, 
                    203.60199999999998`}}, {{1038.801, 203.60199999999998`}, {
                    1038.805, 203.60199999999998`}}},
                    CurveClosed->{0, 0, 0, 0, 0, 0}]}}}}, {{{
                   {RGBColor[1., 1., 1.], Thickness[0.005312127152597305], 
                    Opacity[1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{1027.6014, 
                    238.39799999999997`}, {1072.3986, 
                    238.39799999999997`}}, {{1083.6013999999998`, 
                    238.39799999999997`}, {1128.3986, 238.39799999999997`}}},
                    CurveClosed->{0, 0}]}}}}, {{{
                   {RGBColor[1., 1., 1.], Thickness[0.0044444444444444444`], 
                    Opacity[1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}}, {{0, 2, 0}}}, {{{1139.6019999999999`, 
                    516.398}, {1206.801, 516.398}}, {{1139.6019999999999`, 
                    494.}, {1139.6019999999999`, 505.19899999999996`}, {1162.,
                     505.19899999999996`}, {1162., 494.}, {1184.398, 494.}, {
                    1184.398, 505.19899999999996`}, {1173.1989999999998`, 
                    505.19899999999996`}}, {{1206.801, 494.}, {
                    1195.6019999999999`, 494.}, {1195.6019999999999`, 
                    505.19899999999996`}, {1218., 505.19899999999996`}, {
                    1218., 516.398}}, {{1218., 505.19899999999996`}, {1218., 
                    494.}, {1240.398, 494.}, {1240.398, 516.398}}, {{
                    1229.1989999999998`, 516.398}, {1229.1989999999998`, 
                    494.}}, {{1150.801, 494.}, {1150.805, 494.}}},
                    CurveClosed->{0, 0, 0, 0, 0, 0}]}}}}, {{{
                   {RGBColor[1., 1., 1.], Thickness[0.005312127152597305], 
                    Opacity[1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{
                    1139.6013999999998`, 481.602}, {1184.3986, 481.602}}, {{
                    1195.6013999999998`, 481.602}, {1240.3986, 481.602}}},
                    CurveClosed->{0, 0}]}}}}, {{{
                   {RGBColor[1., 1., 1.], Thickness[0.0044444444444444444`], 
                    Opacity[1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}}, {{0, 2, 0}}}, {{{1139.6019999999999`, 
                    226.}, {1206.801, 226.}}, {{1139.6019999999999`, 
                    203.60199999999998`}, {1139.6019999999999`, 214.801}, {
                    1162., 214.801}, {1162., 203.60199999999998`}, {1184.398, 
                    203.60199999999998`}, {1184.398, 214.801}, {
                    1173.1989999999998`, 214.801}}, {{1206.801, 
                    203.60199999999998`}, {1195.6019999999999`, 
                    203.60199999999998`}, {1195.6019999999999`, 214.801}, {
                    1218., 214.801}, {1218., 226.}}, {{1218., 214.801}, {
                    1218., 203.60199999999998`}, {1240.398, 
                    203.60199999999998`}, {1240.398, 226.}}, {{
                    1229.1989999999998`, 226.}, {1229.1989999999998`, 
                    203.60199999999998`}}, {{1150.801, 203.60199999999998`}, {
                    1150.805, 203.60199999999998`}}},
                    CurveClosed->{0, 0, 0, 0, 0, 0}]}}}}, {{{
                   {RGBColor[1., 1., 1.], Thickness[0.005312127152597305], 
                    Opacity[1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{
                    1139.6013999999998`, 238.39799999999997`}, {1184.3986, 
                    238.39799999999997`}}, {{1195.6013999999998`, 
                    238.39799999999997`}, {1240.3986, 238.39799999999997`}}},
                    CurveClosed->{0, 0}]}}}}, {{{
                   {RGBColor[1., 1., 1.], Thickness[0.0044444444444444444`], 
                    Opacity[1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}}, {{0, 2, 0}}}, {{{803.602, 516.398}, {
                    870.8009999999999, 516.398}}, {{803.602, 494.}, {803.602, 
                    505.19899999999996`}, {826., 505.19899999999996`}, {826., 
                    494.}, {848.398, 494.}, {848.398, 505.19899999999996`}, {
                    837.1990000000001, 505.19899999999996`}}, {{
                    870.8009999999999, 494.}, {859.602, 494.}, {859.602, 
                    505.19899999999996`}, {882., 505.19899999999996`}, {882., 
                    516.398}}, {{882., 505.19899999999996`}, {882., 494.}, {
                    904.398, 494.}, {904.398, 516.398}}, {{893.1990000000001, 
                    516.398}, {893.1990000000001, 494.}}, {{814.8009999999999,
                     494.}, {814.805, 494.}}},
                    CurveClosed->{0, 0, 0, 0, 0, 0}]}}}}, {{{
                   {RGBColor[1., 1., 1.], Thickness[0.005312127152597305], 
                    Opacity[1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{
                    803.6013999999999, 481.602}, {848.3986, 481.602}}, {{
                    859.6013999999999, 481.602}, {904.3986, 481.602}}},
                    CurveClosed->{0, 0}]}}}}, {{{
                   {RGBColor[1., 1., 1.], Thickness[0.0044444444444444444`], 
                    Opacity[1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}}, {{0, 2, 0}}}, {{{803.602, 226.}, {
                    870.8009999999999, 226.}}, {{803.602, 
                    203.60199999999998`}, {803.602, 214.801}, {826., 
                    214.801}, {826., 203.60199999999998`}, {848.398, 
                    203.60199999999998`}, {848.398, 214.801}, {
                    837.1990000000001, 214.801}}, {{870.8009999999999, 
                    203.60199999999998`}, {859.602, 203.60199999999998`}, {
                    859.602, 214.801}, {882., 214.801}, {882., 226.}}, {{882.,
                     214.801}, {882., 203.60199999999998`}, {904.398, 
                    203.60199999999998`}, {904.398, 226.}}, {{
                    893.1990000000001, 226.}, {893.1990000000001, 
                    203.60199999999998`}}, {{814.8009999999999, 
                    203.60199999999998`}, {814.805, 203.60199999999998`}}},
                    CurveClosed->{0, 0, 0, 0, 0, 0}]}}}}, {{{
                   {RGBColor[1., 1., 1.], Thickness[0.005312127152597305], 
                    Opacity[1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{
                    803.6013999999999, 238.39799999999997`}, {848.3986, 
                    238.39799999999997`}}, {{859.6013999999999, 
                    238.39799999999997`}, {904.3986, 238.39799999999997`}}},
                    CurveClosed->{0, 0}]}}}}, {{{
                   {RGBColor[1., 1., 1.], Thickness[0.0044444444444444444`], 
                    Opacity[1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}}, {{0, 2, 0}}}, {{{915.602, 516.398}, {
                    982.8009999999999, 516.398}}, {{915.602, 494.}, {915.602, 
                    505.19899999999996`}, {938., 505.19899999999996`}, {938., 
                    494.}, {960.398, 494.}, {960.398, 505.19899999999996`}, {
                    949.1990000000001, 505.19899999999996`}}, {{
                    982.8009999999999, 494.}, {971.602, 494.}, {971.602, 
                    505.19899999999996`}, {994., 505.19899999999996`}, {994., 
                    516.398}}, {{994., 505.19899999999996`}, {994., 494.}, {
                    1016.398, 494.}, {1016.398, 516.398}}, {{
                    1005.1990000000001`, 516.398}, {1005.1990000000001`, 
                    494.}}, {{926.8009999999999, 494.}, {926.805, 494.}}},
                    CurveClosed->{0, 0, 0, 0, 0, 0}]}}}}, {{{
                   {RGBColor[1., 1., 1.], Thickness[0.005312127152597305], 
                    Opacity[1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{
                    915.6013999999999, 481.602}, {960.3986, 481.602}}, {{
                    971.6013999999999, 481.602}, {1016.3986, 481.602}}},
                    CurveClosed->{0, 0}]}}}}, {{{
                   {RGBColor[1., 1., 1.], Thickness[0.0044444444444444444`], 
                    Opacity[1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}}, {{0, 2, 0}}}, {{{915.602, 226.}, {
                    982.8009999999999, 226.}}, {{915.602, 
                    203.60199999999998`}, {915.602, 214.801}, {938., 
                    214.801}, {938., 203.60199999999998`}, {960.398, 
                    203.60199999999998`}, {960.398, 214.801}, {
                    949.1990000000001, 214.801}}, {{982.8009999999999, 
                    203.60199999999998`}, {971.602, 203.60199999999998`}, {
                    971.602, 214.801}, {994., 214.801}, {994., 226.}}, {{994.,
                     214.801}, {994., 203.60199999999998`}, {1016.398, 
                    203.60199999999998`}, {1016.398, 226.}}, {{
                    1005.1990000000001`, 226.}, {1005.1990000000001`, 
                    203.60199999999998`}}, {{926.8009999999999, 
                    203.60199999999998`}, {926.805, 203.60199999999998`}}},
                    CurveClosed->{0, 0, 0, 0, 0, 0}]}}}}, {{{
                   {RGBColor[1., 1., 1.], Thickness[0.005312127152597305], 
                    Opacity[1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{
                    915.6013999999999, 238.39799999999997`}, {960.3986, 
                    238.39799999999997`}}, {{971.6013999999999, 
                    238.39799999999997`}, {1016.3986, 238.39799999999997`}}},
                    CurveClosed->{0, 0}]}}}}, {{{
                   {RGBColor[1., 1., 1.], Thickness[0.0044444444444444444`], 
                    Opacity[1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}}, {{0, 2, 0}}}, {{{243.602, 516.398}, {
                    310.801, 516.398}}, {{243.602, 494.}, {243.602, 
                    505.19899999999996`}, {266., 505.19899999999996`}, {266., 
                    494.}, {288.39799999999997`, 494.}, {288.39799999999997`, 
                    505.19899999999996`}, {277.199, 505.19899999999996`}}, {{
                    310.801, 494.}, {299.60200000000003`, 494.}, {
                    299.60200000000003`, 505.19899999999996`}, {322., 
                    505.19899999999996`}, {322., 516.398}}, {{322., 
                    505.19899999999996`}, {322., 494.}, {344.39799999999997`, 
                    494.}, {344.39799999999997`, 516.398}}, {{333.199, 
                    516.398}, {333.199, 494.}}, {{254.80100000000002`, 
                    494.}, {254.805, 494.}}},
                    CurveClosed->{0, 0, 0, 0, 0, 0}]}}}}, {{{
                   {RGBColor[1., 1., 1.], Thickness[0.005312127152597305], 
                    Opacity[1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{
                    243.60139999999998`, 481.602}, {288.39859999999993`, 
                    481.602}}, {{299.6014, 481.602}, {344.39859999999993`, 
                    481.602}}},
                    CurveClosed->{0, 0}]}}}}, {{{
                   {RGBColor[1., 1., 1.], Thickness[0.0044444444444444444`], 
                    Opacity[1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}}, {{0, 2, 0}}}, {{{243.602, 226.}, {
                    310.801, 226.}}, {{243.602, 203.60199999999998`}, {
                    243.602, 214.801}, {266., 214.801}, {266., 
                    203.60199999999998`}, {288.39799999999997`, 
                    203.60199999999998`}, {288.39799999999997`, 214.801}, {
                    277.199, 214.801}}, {{310.801, 203.60199999999998`}, {
                    299.60200000000003`, 203.60199999999998`}, {
                    299.60200000000003`, 214.801}, {322., 214.801}, {322., 
                    226.}}, {{322., 214.801}, {322., 203.60199999999998`}, {
                    344.39799999999997`, 203.60199999999998`}, {
                    344.39799999999997`, 226.}}, {{333.199, 226.}, {333.199, 
                    203.60199999999998`}}, {{254.80100000000002`, 
                    203.60199999999998`}, {254.805, 203.60199999999998`}}},
                    CurveClosed->{0, 0, 0, 0, 0, 0}]}}}}, {{{
                   {RGBColor[1., 1., 1.], Thickness[0.005312127152597305], 
                    Opacity[1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{
                    243.60139999999998`, 238.39799999999997`}, {
                    288.39859999999993`, 238.39799999999997`}}, {{299.6014, 
                    238.39799999999997`}, {344.39859999999993`, 
                    238.39799999999997`}}},
                    CurveClosed->{0, 0}]}}}}, {{{
                   {RGBColor[1., 1., 1.], Thickness[0.0044444444444444444`], 
                    Opacity[1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}}, {{0, 2, 0}}}, {{{19.602, 516.398}, {
                    86.801, 516.398}}, {{19.602, 494.}, {19.602, 
                    505.19899999999996`}, {42., 505.19899999999996`}, {42., 
                    494.}, {64.398, 494.}, {64.398, 505.19899999999996`}, {
                    53.199000000000005`, 505.19899999999996`}}, {{86.801, 
                    494.}, {75.60199999999999, 494.}, {75.60199999999999, 
                    505.19899999999996`}, {98., 505.19899999999996`}, {98., 
                    516.398}}, {{98., 505.19899999999996`}, {98., 494.}, {
                    120.398, 494.}, {120.398, 516.398}}, {{109.199, 
                    516.398}, {109.199, 494.}}, {{30.801000000000002`, 
                    494.}, {30.805, 494.}}},
                    CurveClosed->{0, 0, 0, 0, 0, 0}]}}}}, {{{
                   {RGBColor[1., 1., 1.], Thickness[0.005312127152597305], 
                    Opacity[1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{
                    19.601399999999998`, 481.602}, {64.3986, 481.602}}, {{
                    75.6014, 481.602}, {120.3986, 481.602}}},
                    CurveClosed->{0, 0}]}}}}, {{{
                   {RGBColor[1., 1., 1.], Thickness[0.0044444444444444444`], 
                    Opacity[1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}}, {{0, 2, 0}}}, {{{19.602, 226.}, {86.801,
                     226.}}, {{19.602, 203.60199999999998`}, {19.602, 
                    214.801}, {42., 214.801}, {42., 203.60199999999998`}, {
                    64.398, 203.60199999999998`}, {64.398, 214.801}, {
                    53.199000000000005`, 214.801}}, {{86.801, 
                    203.60199999999998`}, {75.60199999999999, 
                    203.60199999999998`}, {75.60199999999999, 214.801}, {98., 
                    214.801}, {98., 226.}}, {{98., 214.801}, {98., 
                    203.60199999999998`}, {120.398, 203.60199999999998`}, {
                    120.398, 226.}}, {{109.199, 226.}, {109.199, 
                    203.60199999999998`}}, {{30.801000000000002`, 
                    203.60199999999998`}, {30.805, 203.60199999999998`}}},
                    CurveClosed->{0, 0, 0, 0, 0, 0}]}}}}, {{{
                   {RGBColor[1., 1., 1.], Thickness[0.005312127152597305], 
                    Opacity[1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{
                    19.601399999999998`, 238.39799999999997`}, {64.3986, 
                    238.39799999999997`}}, {{75.6014, 238.39799999999997`}, {
                    120.3986, 238.39799999999997`}}},
                    CurveClosed->{0, 0}]}}}}, {{{
                   {RGBColor[1., 1., 1.], Thickness[0.0044444444444444444`], 
                    Opacity[1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}}, {{0, 2, 0}}}, {{{131.602, 516.398}, {
                    198.80100000000002`, 516.398}}, {{131.602, 494.}, {
                    131.602, 505.19899999999996`}, {154., 
                    505.19899999999996`}, {154., 494.}, {176.39800000000002`, 
                    494.}, {176.39800000000002`, 505.19899999999996`}, {
                    165.19899999999998`, 505.19899999999996`}}, {{
                    198.80100000000002`, 494.}, {187.602, 494.}, {187.602, 
                    505.19899999999996`}, {210., 505.19899999999996`}, {210., 
                    516.398}}, {{210., 505.19899999999996`}, {210., 494.}, {
                    232.39800000000002`, 494.}, {232.39800000000002`, 
                    516.398}}, {{221.19899999999998`, 516.398}, {
                    221.19899999999998`, 494.}}, {{142.80100000000002`, 
                    494.}, {142.805, 494.}}},
                    CurveClosed->{0, 0, 0, 0, 0, 0}]}}}}, {{{
                   {RGBColor[1., 1., 1.], Thickness[0.005312127152597305], 
                    Opacity[1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{131.6014, 
                    481.602}, {176.39860000000002`, 481.602}}, {{
                    187.60139999999998`, 481.602}, {232.39859999999993`, 
                    481.602}}},
                    CurveClosed->{0, 0}]}}}}, {{{
                   {RGBColor[1., 1., 1.], Thickness[0.0044444444444444444`], 
                    Opacity[1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}}, {{0, 2, 0}}}, {{{131.602, 226.}, {
                    198.80100000000002`, 226.}}, {{131.602, 
                    203.60199999999998`}, {131.602, 214.801}, {154., 
                    214.801}, {154., 203.60199999999998`}, {
                    176.39800000000002`, 203.60199999999998`}, {
                    176.39800000000002`, 214.801}, {165.19899999999998`, 
                    214.801}}, {{198.80100000000002`, 203.60199999999998`}, {
                    187.602, 203.60199999999998`}, {187.602, 214.801}, {210., 
                    214.801}, {210., 226.}}, {{210., 214.801}, {210., 
                    203.60199999999998`}, {232.39800000000002`, 
                    203.60199999999998`}, {232.39800000000002`, 226.}}, {{
                    221.19899999999998`, 226.}, {221.19899999999998`, 
                    203.60199999999998`}}, {{142.80100000000002`, 
                    203.60199999999998`}, {142.805, 203.60199999999998`}}},
                    CurveClosed->{0, 0, 0, 0, 0, 0}]}}}}, {{{
                   {RGBColor[1., 1., 1.], Thickness[0.005312127152597305], 
                    Opacity[1.], CapForm["Round"], JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{131.6014, 
                    238.39799999999997`}, {176.39860000000002`, 
                    238.39799999999997`}}, {{187.60139999999998`, 
                    238.39799999999997`}, {232.39859999999993`, 
                    238.39799999999997`}}},
                    CurveClosed->{0, 0}]}}}}, {{{
                   {FaceForm[{RGBColor[0.854902, 0., 0.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{666.664, 
                    424.33599999999996`}, {666.664, 424.33599999999996`}, {
                    731.7850000000001, 373.40999999999997`}, {683.918, 
                    300.22299999999996`}, {729., 327.77299999999997`}, {
                    732.895, 403.53499999999997`}, {666.664, 
                    424.33599999999996`}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{630., 431.57}, {619.637, 419.883}, {601.824, 
                    431.504}, {607.9449999999999, 444.234}, {618.66, 
                    425.03099999999995`}, {630., 440.547}, {630., 440.547}, {
                    630., 440.547}, {641.3399999999999, 
                    425.03099999999995`}, {652.055, 444.234}, {
                    658.1800000000001, 431.504}, {640.3669999999998, 
                    419.883}, {630., 431.57}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJtIGZigIINzQ6trwN3yPEXOmz7/PdKRUmzQ+7z3ys/
rsLkv19+zNv8RZODHdf1xQW+hQ5HFDYUZeg3ORz6qhHTf67QocMx4emFYwg+
WF662QFsD0sRRNyq2aF833wpfWVMvhzIIY8bHabnCTUfmFLs4GPe6ZjwqtEh
Y+LbGvvWMgdbkL3/Gh22nCjbN7+u0qHypZohx8kmh6sVQEZaFUG+N8i8hEYI
7V3m8AHknyKo/+8WOSwuANoQ1ewAcvZE6XI43wpkoWWVwzTn7pznFc0Q8zyq
HGDhN1mCJYzvOGF+1p6SyRLPEfpj+oEhwNoCNx/Gh9kvGGG55cRbhPvA/v7f
Cnd/u9jNc9+ntTgcAwkA/UeIfxgU3omtkPAFhp/Nff/e6aWtDlEp1vf9geH7
sEpknXtNq0MnKB6B4X8U5BDVFkj4A+MHnQ82z6XF4dMl3yQBYPyC43FmC8Sd
wPgHyxu0wvlg/5S3OBjcVWFrBKYfTx4m7fbXzQ5xu4Cs1Zh8sPvXQ9MHMH0C
AGVtMXs=
                    "]], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    593.3399999999999, 424.33599999999996`}, {
                    593.3399999999999, 424.33599999999996`}, {528.219, 
                    373.40999999999997`}, {576.086, 300.22299999999996`}, {
                    531., 327.77299999999997`}, {527.102, 
                    403.53499999999997`}, {593.3399999999999, 
                    424.33599999999996`}}}]}}}}}}}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 1260.}, {0., 720.}}], ",", 
           GraphicsBox[{{{
               {Thickness[0.001388888888888889], {{{
                   {FaceForm[{RGBColor[
                    0.8078430000000001, 0.06666670000000002, 0.14902], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     480.}, {720., 480.}, {720., 320.}, {0., 
                    320.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     320.}, {720., 320.}, {720., 160.}, {0., 160.}}}]}}}}, {{{
                   
                   {Thickness[0.001388888888888889], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     160.}, {720., 160.}, {720., 0.}, {0., 0.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[0., 0.478431, 0.23921600000000004`], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{218.918, 
                    180.562}, {214.781, 185.102}, {223.13299999999998`, 
                    194.102}, {227.26999999999998`, 189.562}, {231.406, 
                    185.02}, {223.055, 176.02}, {218.92200000000003`, 
                    180.57}}, CompressedData["
1:eJxlVQ1olVUYvpqOMce1plmm2UxbUsawJWEiveXC9pOmwzVMxIbd7+d8937n
O99Wq9lIRpmV3o2MnCZOLxs1NYeVmKitFWUqNoRh+7mpSNiQFhplIkHnnOd0
L9SFy8fznfe873Oe5z3vN7PWX/Hi2Egk0ij/6tl19ewztX0WFeVseH/xUIyG
bjS5R9stun9e7r7pozESduuv66ss2vJBoqB5rkVf7rqrOF1oEV+Udy5lW1Tx
6KYn1n4VownnUnzRoEXV0YcO7twbo/tUvok2PfbZiZeOX4lR6Tve5ZsjFrX0
/jFndYVFeSr+oEWDql6ujXpbLPpOJay0qe9eyaTT1Ct1wCtiU6Wq95pDf85Z
nex1HHp18idLLh6yaZuk17PUpbtXrVt4PmmDR6NLEfXjNt4fyGId35vFOl+/
i/O02fTGleWHZ9ww66dtvL+NUaOqV+BAlxJGxenZORvmO9CjxqzXOjj/pwz8
Wwye6NECpUfK4FkeDZy5XnXpi+y6zjfggN81Rpc6dnxTWOoiLu1msPbtoyzW
z3dd7HNdOlb33p3j3nRJ0Xx8KstgrftoFu956tDvf59mNKz0HTb7jzD4nc8o
UOf60KxXMvj0NqNQJWaGn8fgy04GvTwT18ng71sm31FGZ5Wv2xn65aTRr59R
UvXFdQafJnjwu9AD3yc9xJd74Ftn3jd54Lfeo80q/1YPvJIe/D/lgdf4OOq6
cfT5tCzW/sz+D54bB4+vvQzWffkXy+B/9Ts8Q3bKifB/WOvYlUDfpEKcfzhB
0o35a5pCPKM++qUmhI59Jr4kxH1pzWLNZ4fpr3FBBuu+SfkZrOvsi8OH9izW
/dyRxbov9jPo9qNPk5p7Tu5OJ6i/YaRoXpTDlwU+4m7n0LnSJxXeU2Tw6z78
eIQj/34Tv5jjPg349ODGKQNnlnN6+qK8qWM41ldycw5O8nQ/99Vwuibb+dZc
Ti8flwJbZn06x/nrTf4Sw6uZkyrPy8y+rRxz5gWDt5s8Doeu7ZzU8i5u6kn9
dN5bjI6vBKQeyw4EmCejAXg+L7B/haBv1YZfBJ1fJhWrFtQpX3dLrH1eJUi6
Xx0dEci/VtCaI2X5Y4cEfFgnqLBbTozvBc1Uz3qz3zZxzYIuqLwPC4pfvvnx
1RYBvpNN3B6BeSh56f7aZvhcMLwdQYpm908BeFQJUu3/WzrAvLlHQLe2ALoV
B1Sg/F5odGzluBd7E6SuYVL6/7mq/0AcPPI5+qQwjvd5HP07JY56bRz3PWr6
rCzIYO3DJpHBWneJtc45CdSX+DlFOJlAvs2CRlX+PB/naxWYt3f42N8hUGel
6b+GEHEVHOfdGCLPEm70DOFbKTc+hOj3qRx+jK9DH/zg43yizsyJLNbrkxzU
rXczWPv7rIu4JhtzbJaLfjxlYa4MOlgvN9/NBvP9GmO+l9MczPdjMcSX24jv
ihleFuaa/D7/A9PgVSI=
                    "], CompressedData["
1:eJxTTMoPSmViYGCQB2IQrbChKGPi8xIHoeYDpxYezXWA8atE1rk/bCtwmCzB
Esb3usThbY29aZxdIYT/ucRBq13s5jnnQgdbruuLC36WODxeOvuIgkehQ+7z
3ys/ipRC+EaFDse8zTsdDUod4nZ58jAJF0LM9y51kI1Ksb7/ucDhasVLNcMa
KP9ggcN9/97peXNKHfh0N819v7jAIWMi0ObzpQ5bTpTtm19S4HDoq0ZM/xWo
+uwCh2qQO4+UOujfVWFrTCxwuKB0+2fdhFKHHJA77AoctEHunFgKoT0R/EWu
2z7/LcmF88Hmt2VBwuE7gv/pkm+SQFAZnD8jD6giqczBB+ithN4siHt6yiDi
h7Ig9h8oc9g/X0r/Lks2xB+HyyDh8SfL4TgoPFZB+RVZEHMXlEHC2y0L4q+p
ZRB/P82EqJ9U5qDK1jjVeX6mgyVIQ3eZAwMIKGQ6CIPcu7MUQktmwuOvH+Qw
YQQfHH/Hch0AiJroxA==
                    "]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {CompressedData["
1:eJxlUltIFGEUXiQ2iDCpzSTMVrsQUW0iS1lsHukhTGGxy4bW6hJGtc7O/DNF
NZc1TCyFIsJiBdFNwqCHZDMDidzEwi6QuA9hEmUiIV0WKaiQemjOnHHmwYfh
55v//Od83/m+/OPCgRMZDocD9A/P4v6X55JFMgQyt/Z1loehum73pL9YhsGz
bTmLuuqhfEdraahMhvdzDeEnWRx88l+L8Zdk+L3p2PXhKAdprcRb0yvDiqah
190pDs4n46s9aZnezXGAbWe9CpSGPo8VzHIwie85BaRTN9LaDAf7phRXr6DA
xOifg9NiBDZfyZ4YPaMAXpfk8zD8Sx+k169BYrU87EK+lQqkCnRGEg/uhN6p
UAHmWzJ+p4WH6Z6O5+6dCs1P8dD8rXIgr1YB/Zb5nAK8vfBlY6GkwAsscAsQ
mfl778dtc74sAId4RCE9b8z77wq088ubhrIY8VumQs3jsqUZRYz0u2xs1OfY
GOkkclXSu0qw8CNdRrwhYuENzsZbe2Nh4te3EBu6bkYsPJCnK8tmaKPDkVBp
7n5GurtVaMWFVzOqbzdxHaM+V1XQ3Q1kRkx+l20cQ528jQ1/Lqq05w4Gng/r
nY1xlXx+wOAZ+jPPL8no3ZQKd7HvVwYtONepwQgSc4kwhr5t0chPn0h8/Rr1
C4pUd0ij3FSJ1K9KI54BEwc1MHJbzyx8BB/EeQvP78/g93MhNvpxIuQij3Fz
XrNIPF5p5HObiQc12I66e2xs5PO+jY3994uUh48a5fydCEHMweIo7eefSHv0
RKn/WonyeTRK/lRI9P+kWR+SyOeuKGC82UMJ9uDZGSXeT21s9FkpWPgwClp3
mva/TbawkWuvTLmpCMN/ybjHEQ==
                    "], {{423.09799999999996`, 
                    217.445}, {423.09799999999996`, 222.164}, {
                    420.47999999999996`, 222.164}, {416.965, 222.164}, {
                    413.754, 218.848}, {413.754, 215.21099999999998`}, {
                    413.754, 212.727}, {423.09799999999996`, 212.727}, {
                    423.09799999999996`, 217.441}}, CompressedData["
1:eJxTTMoPSmViYGBQBGIQHbfLk4dJuM7hm0ZM/6GbuQ4w/kWl2z/rJhU4XADR
YnUOM/KEmg94FToc+gpUKFfncLXipZphQKFD7vPfKz+q1EHUhRQ6bDlRtm++
Q53Dff/e6Xl2hQ4MIBBT51C+b76Uvnyhg7d5p2NCeZ0Dr+6mue//F0DMWVHn
YAXSeBZq34k6B/eHVSLr1hc4KGwoypj4G2pfQ4FDtcg694cM9Q62XNcXF5QX
OLS+Dtwh97HOYZHrts9/cwog7ttT53AcZJFXgYNsVIr1/b11EHWhCH4ByICO
XDhfla1xqvP0LIg9avVwPtC1Ty+0IPhgcyfVO+wHeufunCyIv7bXOwBd+bbm
cpaDIsi9Z+sdgL4Xav6SBQnHR/UON899D37MmQ3x59N6iD+YsiHh96Ie4o7f
WRB3Pq6HhNPJLIi6G/XQ+MiC+O9cvUMYHzAAo6HqD9c7+IDUf8100L+rwta4
v94B5Gyl9ZkQ9++Aul8/E2KfEDQ+lRB8dUOONTK3ch0AX6j2uw==
                    
                    "], CompressedData["
1:eJxTTMoPSmViYGBQBGIQ/Xjp7CMKp6ocqkXWuT9MKXSISrG+77+9yuFtjb1p
XE6hg3DzgVMLF1Y5eDysEllXWejw6ZJvksCsKod3IPmmQof7/r3T8/qqHNxB
8v2FDse8zTsdp1Q5LHLd9vnvBKj8viqHByC6qxCij6vaAWTthrpCh9znv1d+
tIDyewodMiYCbU6udgC7aw9Uf0e1g3a72M1zTwsdrla8VDPcA+VfLHRYBtJ3
o9qhCuT+Y4UQd3+rdjj0VSOm/0Chww651teB/6odZEEeO1wI8adQjcMFpds/
685A/WNRA1HPUwRRb1IDcb9CkYMWyB79Goh+yyKHTseEpxdcaiD6zIog7gis
gfhfugji/uwaB17dTXPfPy90YACBsBpIuCyDhq9qjcNxEH9SoYMd1/XFBbw1
UH8i3A/2J5BvueVE2b7z1Q5AV+2Qmwj1z4JqiHlzCiHunlHtMFmCJYxvNlR9
M9S/rdDwDK2GmBsG1c9XDYlPT2h4AuN/ep5Q8wFg/AMAyiz3BA==
                    
                    "], {{436.72299999999996`, 290.289}, {435.117, 291.484}, {
                    431.72299999999996`, 297.59799999999996`}, {431.594, 
                    299.543}, {431.47999999999996`, 301.21099999999996`}, {
                    431.754, 301.72299999999996`}, {432.84400000000005`, 
                    301.895}, {434.754, 302.191}, {435.633, 300.809}, {
                    437.10200000000003`, 295.22299999999996`}, {438.305, 
                    290.64500000000004`}, {438.18, 289.199}, {436.727, 
                    290.289}}}]}}}}}}}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 720.}, {0., 480.}}], ",", 
           GraphicsBox[{{{
               {Thickness[0.001388888888888889], {{{
                   {Thickness[0.001388888888888889], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 480.}, {720., 480.}, {720., 0.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     480.}, {720., 480.}, {720., 160.}, {0., 
                    160.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.8078430000000001, 0.06666670000000002, 0.14902], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     480.}, {720., 480.}, {720., 320.}, {0., 
                    320.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[0., 0.478431, 0.23921600000000004`], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{216., 292.}, {
                    199.93, 242.547}, {230.363, 232.656}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{216., 292.}, {
                    232.07, 242.547}, {201.637, 232.656}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{265.453, 
                    256.07}, {213.453, 256.07}, {213.453, 224.07}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{265.453, 
                    256.07}, {223.38700000000003`, 225.504}, {204.578, 
                    251.395}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{166.547, 
                    256.07}, {208.61299999999997`, 225.504}, {
                    227.42200000000003`, 251.395}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{166.547, 
                    256.07}, {218.547, 256.07}, {218.547, 224.07}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{246.566, 
                    197.93}, {230.496, 247.38700000000003`}, {200.062, 
                    237.496}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{246.566, 
                    197.93}, {204.496, 228.496}, {223.305, 254.383}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{185.434, 
                    197.93}, {227.504, 228.496}, {208.695, 254.383}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{185.434, 
                    197.93}, {201.504, 247.38700000000003`}, {
                    231.93800000000002`, 237.496}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{504., 292.}, {
                    487.92999999999995`, 242.547}, {518.3629999999999, 
                    232.656}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{504., 292.}, {
                    520.07, 242.547}, {489.637, 232.656}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{553.453, 
                    256.07}, {501.453, 256.07}, {501.453, 224.07}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{553.453, 
                    256.07}, {511.387, 225.504}, {492.578, 251.395}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{454.547, 
                    256.07}, {496.613, 225.504}, {515.4219999999999, 
                    251.395}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{454.547, 
                    256.07}, {506.547, 256.07}, {506.547, 224.07}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    534.5659999999999, 197.93}, {518.496, 
                    247.38700000000003`}, {488.062, 237.496}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    534.5659999999999, 197.93}, {492.4959999999999, 
                    228.496}, {511.305, 254.383}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    473.43399999999997`, 197.93}, {515.504, 228.496}, {
                    496.695, 254.383}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    473.43399999999997`, 197.93}, {489.504, 
                    247.38700000000003`}, {519.938, 237.496}}}]}}}}}}}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 720.}, {0., 480.}}], ",", 
           GraphicsBox[{{{
               {Thickness[0.0010416666666666667`], {{{
                   {FaceForm[{RGBColor[0., 0.4, 0.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 480.}, {960., 480.}, {960., 0.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     480.}, {960., 480.}, {960., 137.14499999999998`}, {0., 
                    137.14499999999998`}}}]}}}}, {{{
                   {FaceForm[{RGBColor[0.8, 0., 0.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     480.}, {960., 480.}, {960., 342.855}, {0., 
                    342.855}}}]}}}}, {{{
                   {FaceForm[{RGBColor[0.972549, 0.764706, 0.], Opacity[1.]}],
                     FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4k7HhKcXztQ4PF46+4jCmTyHi0q3f9a9qnHg
ur64wNYo38Fyy4myfdq1Dq2vA3fIZeY7LHLd9vlvSi1EvU++wzFv807HebUO
IGOU9PMdtgKVzz9V61BoCzThQJ7Dff/e6XlnaiHiXgi+/l0VtkbGLAeFDUUZ
E43rMPgw9SDjE0zr4OZZgdyTWAe3L26XJw/T7DpU91ypg7vXAGSuaD3cP+X7
5kvpG9fD/RuVYn3fP7je4ZtGTP+h3nyIuFO9A4jaYFYAcS9bPcQdnQUOy0Di
p+ocPl3yTRK4U+DAAAJpdRB38xdC+Axo/Fm1cD7YPtNauH6w+M8auPmyIAV7
a+D2g+k1NXD3occXAG2yx5Q=
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4h1yra8DxWod3tXYm8a9ynfIff575UenWodC
W67ri//kOzzw752eV1TrAOQV2H7Kd2AAgTm1DvvnS+nfPZPvINx84NTCo7UO
YXy6m+Yuz3cAmrZD7mWtg+WWE2X70qHqGeoc9oHUS+Q7VImsc38oVgeXB9tr
VQfXD1aeUgc3X3FDUcbE3jq4/ZMlWML49tbB3efxEGjiyzq4+8H6H9VB1OkW
QPQfrXPQbhe7eS6xACI+uw7ijrYCh0NfNWL6C+ocQNa/X13g8BZkjkWdwyLX
bZ//HiiAux/GFwL593gtnA9yRkF/LVw/OPxSauHmg8PPqhZuP9g4uVq4+9DD
HwAHcqwN
                    "]]}}}}, {{{
                   {FaceForm[{RGBColor[0.972549, 0.764706, 0.], Opacity[1.]}],
                     FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4vv+vdPzztQ6WG45UbZve7aDwV0VtsajtQ6t
rwN3yMlmO4DlV9Q6gKTnt2U5KGwoyphYWetQLbLO/SFXlsOy2UcUNnjVOjgm
PL2g1J/p8HgpUICr1uFtjb1pnF4mRP3BGoj89wyHRa7bPv+tqHGQjUqxvr8/
A6Jfo8aB6/riAttNGQ4XlG7/rLtT7XDc27zT8UKGww45oEsmVEPk32U4HPqq
EdPvUe0gA9JvnunAq7tp7nv+agd1Q441MosyHWxBCu9XOWwFuXddhsP0PKHm
AyVVDoUgiTfpDrG7PHmYvlc6xIHoxekO5fvmS+lXVjrog/wdme4wWYIljO91
hYNLd87z353pEH83VED8q5QB4a+ocAjlA1rMnOrg/rBKZN3/Kog9y1Ih7tWp
dmAAgQ1Q976odnAC+V86DRIubbUOqz5e8k26kQZx7/9ah5vnvgc/ZsxyAADR
07hx
                    "]], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYCYoUNRRkTjescLLecKNu3PdvhotLtn3VWdQ6t
rwN3yMlmO4Dlw+scQNLz27Ic7vv3Ts9rq3OoFlnn/pAryyEqxfq+/9Y6B8eE
pxeU+jMdZEECX+sc3tbYm8bpZULU29VD5L9nOMTu8uRhaq+HqNufAdF/vd6B
6/riAttNGQ4z8oSaDwg2OBz3Nu90vJDhsKTAluu6eQNE/l2GgxzIYdENDjIg
jeaZDpUv1Qw5Khoc1A051sgsynR4WAV02IQGh60g967LgNBHGxwKgcYsfpPu
cAHkP5ZGhziQOxanOxwBedC50UH/rgpbY2S6w7bPf69UdDU6uHTnPP/dme6w
dDZQxf5GiH+VMiD81Y0OoXy6m+YypzrE9B/6qtHQ4DAd5O5lqRD3ZjY4MIDA
Bqh7uRscnED+l05zEG4+cGphZZ3Dqo+XfJNupDkAdcf0M9Q53Dz3PfgxY5YD
AAodtds=
                    "]], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{451.777, 177.38700000000003`}, {
                    446.551, 166.10899999999998`}, {436.10900000000004`, 
                    164.172}, {426.977, 173.277}, {426.977, 173.277}, {
                    430.648, 175.871}, {434.578, 176.586}, {
                    433.84400000000005`, 179.72299999999998`}, {435.355, 
                    184.062}, {437.484, 186.406}, {439.719, 184.883}, {
                    442.83599999999996`, 181.82000000000002`}, {443.629, 
                    178.266}, {449.133, 178.977}, {451.777, 
                    177.38700000000003`}, {451.777, 177.38700000000003`}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{492.64500000000004`, 178.664}, {
                    485.65200000000004`, 168.38700000000003`}, {
                    475.03499999999997`, 168.176}, {467.508, 
                    178.64499999999998`}, {467.508, 178.64499999999998`}, {
                    471.551, 180.605}, {475.547, 180.672}, {475.328, 
                    183.88700000000003`}, {477.527, 187.92200000000003`}, {
                    480.012, 189.89100000000002`}, {481.965, 188.02}, {
                    484.543, 184.496}, {484.746, 180.85500000000002`}, {
                    490.29699999999997`, 180.664}, {492.64500000000004`, 
                    178.664}, {492.64500000000004`, 178.664}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{533.172, 173.26999999999998`}, {
                    524.605, 164.26999999999998`}, {514.094, 165.789}, {
                    508.371, 177.344}, {508.371, 177.344}, {512.6800000000001,
                     178.621}, {516.633, 178.035}, {516.9409999999999, 
                    181.242}, {519.766, 184.86700000000002`}, {522.539, 
                    186.40200000000002`}, {524.164, 184.242}, {526.133, 
                    180.344}, {525.738, 176.71899999999997`}, {
                    531.1840000000001, 175.625}, {533.172, 
                    173.26999999999998`}, {533.172, 
                    173.26999999999998`}}}]}}}}, {{{
                   {RGBColor[0.972549, 0.764706, 0.], Thickness[
                    0.011428571875], Opacity[1.], CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{413.484, 
                    152.23000000000002`}, {456.58599999999996`, 
                    165.05900000000003`}, {503.414, 165.05900000000003`}, {
                    546.516, 152.23000000000002`}}},
                    CurveClosed->{0}]}}}}, {{{
                   {FaceForm[{RGBColor[0.972549, 0.764706, 0.], Opacity[1.]}],
                     FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{480., 332.57}, {490.078, 301.559}, {463.695, 
                    320.727}, {496.305, 320.727}, {469.92199999999997`, 
                    301.559}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{432., 319.71099999999996`}, {442.078, 288.699}, {
                    415.695, 307.863}, {448.305, 307.863}, {
                    421.92199999999997`, 288.699}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{396.863, 284.57}, {406.93799999999993`, 
                    253.559}, {380.559, 272.727}, {413.16400000000004`, 
                    272.727}, {386.78499999999997`, 253.559}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{384., 236.57}, {394.078, 205.559}, {367.695, 
                    224.727}, {400.305, 224.727}, {373.92199999999997`, 
                    205.559}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{528., 319.71099999999996`}, {517.9219999999999, 
                    288.699}, {544.305, 307.863}, {511.695, 307.863}, {
                    538.0780000000001, 288.699}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{563.137, 284.57}, {553.0619999999999, 253.559}, {
                    579.4409999999999, 272.727}, {546.8359999999999, 
                    272.727}, {573.215, 253.559}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{576., 236.57}, {565.9219999999999, 205.559}, {
                    592.305, 224.727}, {559.695, 224.727}, {586.0780000000001,
                     205.559}}}]}}}}}}}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 960.}, {0., 480.}}], ",", 
           GraphicsBox[{{{
               {Thickness[0.0010416666666666667`], {{{
                   {FaceForm[{RGBColor[0., 0.619608, 0.286275], Opacity[1.]}],
                     FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    0., 480.}, {960., 480.}, {960., 320.}, {0., 
                    320.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     320.}, {960., 320.}, {960., 160.}, {0., 
                    160.}}}]}}}}, {{{
                   {Thickness[0.0010416666666666667`], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     160.}, {960., 160.}, {960., 0.}, {0., 0.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.8078430000000001, 0.06666670000000002, 0.14902], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     480.}, {240., 480.}, {240., 0.}, {0., 0.}}}]}}}}}}}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 960.}, {0., 480.}}], ",", 
           GraphicsBox[{{{
               {Thickness[0.001388888888888889], {{{
                   {FaceForm[{RGBColor[1., 1., 1.], Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 480.}, {720., 480.}, {720., 0.}}}]}}}}, {{{
                   {FaceForm[{RGBColor[
                    0.8078430000000001, 0.06666670000000002, 0.14902], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     480.}, {720., 480.}, {720., 320.}, {0., 
                    320.}}}]}}}}, {{{
                   {Thickness[0.001388888888888889], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     160.}, {720., 160.}, {720., 0.}, {0., 0.}}}]}}}}}}}},
            AspectRatio->Automatic,
            ImageSize->{{128}, {85}},
            PlotRange->{{0., 720.}, {0., 480.}}]}], "}"}]}], "}"}]], 
       "ExerciseOutput",ExpressionUUID->
       "e8a49ce9-a9b3-4b70-be39-57bb1754f0a0"],
      Apply[TextCell, 
       Cell[
        BoxData[
         RowBox[{"{", 
           RowBox[{
             RowBox[{"{", 
               RowBox[{
                 GraphicsBox[{
                   Thickness[0.0010416666666666667`], {
                    Thickness[0.0010416666666666667`], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 480.}, {960., 480.}, {960., 0.}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     320.}, {960., 320.}, {960., 160.}, {0., 160.}}}]}, {
                    FaceForm[{
                    RGBColor[0., 0.478431, 0.23921600000000004`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     160.}, {960., 160.}, {960., 0.}, {0., 0.}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.8078430000000001, 0.06666670000000002, 0.14902], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{480., 240.}, {
                    0., 0.}, {0., 480.}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    180.32800000000003`, 231.71099999999998`}, {159.875, 
                    229.80100000000002`}, {162.57, 209.36700000000002`}, {
                    148.32800000000003`, 224.22299999999998`}, {134.086, 
                    209.36700000000002`}, {136.781, 229.80100000000002`}, {
                    116.32799999999999`, 231.71099999999998`}, {133.93, 
                    242.33200000000002`}, {122.664, 259.57}, {
                    141.92200000000003`, 252.38700000000003`}, {
                    148.32800000000003`, 271.969}, {154.73399999999998`, 
                    252.38700000000003`}, {173.99200000000002`, 259.57}, {
                    162.727, 242.33200000000002`}}}]}}, AspectRatio -> 
                  Automatic, ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 960.}, {0., 480.}}], ",", 
                 GraphicsBox[{
                   Thickness[0.0020833333333333333`], {
                    FaceForm[{
                    RGBColor[0., 0.6, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 320.}, {480., 320.}, {480., 0.}}}]}, {
                    FaceForm[{
                    RGBColor[0.74902, 0., 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     320.}, {320., 320.}, {320., 0.}, {0., 0.}}}]}, {
                    Thickness[0.0020833333333333333`], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     320.}, {160., 320.}, {160., 0.}, {0., 0.}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{255.602, 139.32800000000003`}, {
                    262.28099999999995`, 139.32800000000003`}, {262.309, 
                    136.80100000000002`}, {263.789, 134.09}, {265.867, 
                    132.531}, {253.062, 132.531}, {255.066, 
                    134.35200000000003`}, {255.61299999999997`, 136.504}, {
                    255.602, 139.32800000000003`}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{255.602, 139.328}, {262.28099999999995`, 
                    139.328}, {262.309, 136.80100000000002`}, {263.789, 
                    134.09}, {265.867, 132.531}, {253.062, 132.531}, {255.066,
                     134.352}, {255.61299999999997`, 136.504}, {255.602, 
                    139.328}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    213.36700000000002`, 177.176}, {217.02700000000002`, 
                    173.14499999999998`}, {262.574, 173.07}, {266.309, 
                    177.102}, {254.66, 177.25}, {248.984, 181.207}, {230.691, 
                    181.281}, {225.39100000000002`, 177.176}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4t7peULNDLkON899D368M83BcsuJsn3f8xze
1dibxu1Kc2AAAZt8h7cg/r00h4yJQFZgvoP+XRW2xsB0h/3zpfTvBuRD9E9M
d5CNSrG+758P0ReQ4VAtss794ak8BzW2xqnOqzMcfMw7HRNc8yDyGzIcvEF8
wzyHRa7bPv8F8rmvLy6wlcpzKLTlur74QAbEfJE8iDmXMiDuY89zeLx09hGF
PxkOTglPLyhx5zlcULr9s04s0+HOz7qsPX9yIeaJZELs+ZDr0Po6cIecaCZE
/+dciLlA/cdBDniR68AFsvdahoNLd87z3w9zIfYdynBY/fGSb9KZXLh7QcF1
YBtUfl0GxJ0CuRD7l2VAwmVpDiScdDMchJsPnFq4Msfhm0ZM/yFg+PSBDFiT
4xC3y5OHSTvdYRXI/B05EHVv0xzQ4wMAqua5vQ==
                    "]]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4t7peULNDLkON899D368M83BcsuJsn3f8xze
1dibxu1Kc2AAAZt8h7cg/r00h4yJQFZgvoP+XRW2xsB0h/3zpfTvBuRD9E9M
d5CNSrG+758P0ReQ4VAtss794ak8B1W2xqnOqzMcfMw7HRNc8yDyGzIcvEF8
wzyHRa7bPv8F8rmvLy6wlcpzKLDlur74QAbEfJE8hyqQOZcyIO5jz3N4snT2
EYU/GQ5OCU8vKHHnOVxQuv2zTizT4c7Puqw9f3Ih5olkQuz5kOvQ+jpwh5xo
JkT/51yHfSBzgfqPgxzwIteBC2TvtQwHl+6c578f5kLsO5ThsPrjJd+kM7lw
94KC68C2XIi/1mU4FILcKZALsX9ZBiRcluZAwkk3w0G4+cCphStzHL5pxPQf
AoZPH8iANTkOcbs8eZi00x1WgczfkQNR9zbNAT0+AKdmubk=
                    "], 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    206.129, 125.73400000000001`}, {273.703, 
                    125.73400000000001`}, {267.656, 130.664}, {212.176, 
                    130.664}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1,
                     0}, {0, 1, 0}}, {{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, {{{237.11299999999997`, 
                    144.24599999999998`}, {238.344, 140.55100000000002`}, {
                    241.14499999999998`, 140.55100000000002`}, {
                    238.90200000000002`, 144.25}, {237.11299999999997`, 
                    144.25}}, {{235.54299999999998`, 140.55100000000002`}, {
                    236.254, 136.895}, {239.539, 136.85500000000002`}, {
                    238.344, 140.555}}, {{241.105, 140.516}, {243.383, 
                    136.895}, {248.05100000000002`, 136.895}, {
                    244.39100000000002`, 140.555}}, CompressedData["
1:eJxTTMoPSmViYGAwB2IQ/U0jpv/QxiwHVbbGqc7tCQ6LXLd9/suQ7bB/vpT+
3QsJDkUZE9/WGGc7yEalWN/nT3RgAAGTbAfu64sLbLMSHfTvqrA1fkXwb577
HvwYyA/j09001zzR4bi3eacjR44DiEqQTHR4vHT2EQWVHIcJh75qxEhDzXuR
41Boy3V9sUyiQ5XIOveHz3IceqfnCTVPSHQoAIlH4OBzpEDcF5zjIANy3/MU
iH0ZuQ7qhhxrZLJSIfbezHXYB/JPRqrDrZ91WXsssuHyMP7bGnvTuLpUB6Hm
A6cWxhfA+VcrXqoZJhTA1XOB/CmWBzcP7O4HeRD3APmhIH8vzoeE44oUB5Dz
7JfmQ8KXHcEHh0NIskPcLk8epm4EHxwfnfmQ8GdJgfPB9NYUB6eEpxeUVudB
9EWnOqz6eMk36UcuRD40FRL+sbkQfwemQtydl+Owt2SyBMu+FIg7C6B8NgTf
EWTu+WSIO+/nOtwBhcuZZAerLSfK9t3OdfABmdebDHG/aB4kHjKSIe7uyIPE
o0uywwWl2z/r2vIcWl8H7pB7mgQJ3xt5EP+cSYKkl5t5EPvzkiD6bfIh4eaM
4IPd/zDRYQbQeQeq8h2qQeliVyIknsvzIe4NT4S6Mx81PbEg+GBzGvMdwkHm
9ydA0seJPFR+Th5cPTjeP+Wi6teEun9CAsTe5bkOLt05z39PTIDY14FQD/b3
S0T6fgcy71UOPH8BANfndxw=
                    "], {{231.289, 
                    144.21099999999998`}, {231.289, 140.555}, {235.547, 
                    140.555}, {234.684, 144.21099999999998`}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1,
                     0}, {0, 1, 0}}, {{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, {{{237.11299999999997`, 144.246}, {
                    238.344, 140.55100000000002`}, {241.14499999999998`, 
                    140.55100000000002`}, {238.90200000000002`, 144.25}, {
                    237.11299999999997`, 144.25}}, {{235.54299999999998`, 
                    140.55100000000002`}, {236.254, 136.895}, {239.539, 
                    136.85500000000002`}, {238.344, 140.555}}, {{241.105, 
                    140.516}, {243.383, 136.895}, {248.05100000000002`, 
                    136.895}, {244.39100000000002`, 140.555}}, CompressedData["
1:eJxTTMoPSmViYGAwB2IQ/U0jpv/QxiwHNbbGqc7tCQ6LXLd9/suQ7bB/vpT+
3QsJDkUZE9/WGGc7yEalWN/nT3RgAAGTbAeu64sLbLMSHfTvqrA1fkXwb577
HvwYyA/j09001zzR4bi3eacjR46DD5BKkEx0eLx09hEFlRyHCYe+asRIQ817
keNQaAs0QSbRoUpknfvDZzkOvdPzhJonJDoUgMQjMPl9ID5HCsR9wTkQ9z1P
gdiXkeugbsixRiYr1QHETbiZC/FPRqrDrZ91WXsssuHyMP7bGnvTuLpUB6Hm
A6cWxhfA+VcrXqoZJhTA1YP9KZYHNw/s7gd5EPcA+aEgfy/Od1gMCscVKQ4g
59kvzYeELzuCDw6HkGSHuF2ePEzdCD44PjrzHfaBzGdJgfO/guitKQ5OCU8v
KK3Og+iLTnVY9fGSb9KPXIh8aCok/GNzIf4OTIW4Oy/HYU/JZAmWfSmQcCyA
8tkQfEeQueeTHVRB7ryf63AbFC5nkh2stpwo23cbal5vMsT9onkQf2ckQ9zd
kQeJR5dkhwtKQJ1teQ6trwN3yD1NgoTvjTyIf84kQdLLzTyI/XlJEP02+ZBw
c0bwwfY9THSYAXTegap8h2pQutiV6CADiufyfEg4hCc63AG7Mx81PbEg+GBz
GvMh6bE/AZI+TuSh8nPy4OrB8f4pF1W/JjS+JyRAwml5roNzd87z3xMTIPZ1
INSD/f0Skb7fgcx7lQPPXwDcN3ca
                    "], {{231.289, 144.211}, {
                    231.289, 140.555}, {235.547, 140.555}, {234.684, 
                    144.211}}}, CurveClosed -> {1, 1, 1, 1, 1}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    231.512, 150.67199999999997`}, {234.164, 
                    150.67199999999997`}, {234.164, 144.58599999999996`}, {
                    231.512, 144.58599999999996`}}}, CurveClosed -> {1}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    227.76999999999998`, 144.16}, {230.35500000000002`, 
                    144.16}, {230.34, 148.637}, {230.305, 150.582}, {
                    232.05100000000002`, 152.547}, {232.89100000000002`, 
                    152.60899999999998`}, {233.816, 152.64499999999998`}, {
                    235.184, 150.773}, {235.227, 148.78900000000002`}, {
                    235.266, 144.14499999999998`}, {238.012, 144.152}, {
                    238.012, 155.67999999999998`}, {227.76999999999998`, 
                    155.625}}}, CurveClosed -> {1}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    248.238, 141.488}, {251.449, 141.488}, {251.449, 
                    138.988}, {248.238, 138.988}}}, CurveClosed -> {1}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    246.336, 145.78500000000003`}, {249.54700000000003`, 
                    145.78500000000003`}, {249.54700000000003`, 
                    143.28100000000003`}, {246.336, 143.28100000000003`}}}, 
                    CurveClosed -> {1}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    243.238, 150.07799999999997`}, {246.449, 
                    150.07799999999997`}, {246.449, 147.57799999999997`}, {
                    243.238, 147.57799999999997`}}}, CurveClosed -> {1}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    240.594, 153.695}, {243.805, 153.695}, {243.805, 
                    151.195}, {240.594, 151.195}}}, CurveClosed -> {1}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, {{{238.465, 144.14499999999998`}, {
                    241.75, 144.031}, {247.60899999999998`, 138.844}, {
                    247.60899999999998`, 141.902}, {245.63299999999998`, 
                    143.32}, {245.63299999999998`, 145.75}, {242.758, 
                    147.39100000000002`}, {242.758, 150.004}, {
                    239.95700000000002`, 150.938}, {239.95700000000002`, 
                    154.484}, {238.539, 155.64499999999998`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    252.344, 151.71899999999997`}, {253.129, 
                    151.71899999999997`}, {253.129, 146.08199999999997`}, {
                    252.344, 146.08199999999997`}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    252.344, 151.719}, {253.129, 151.719}, {253.129, 
                    146.082}, {252.344, 146.082}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4gmHvmrE7M502DdfSv9uRKqD1ZYTZftmZzqE
8elumtud6rC3ZLIES1mmw0Wl2z/rhFIdGEDgS4bDcW/zTscdKQ5FGRPf1mzP
cHBMeHpBqT/FwQconNCb4aB/V4WtUTHFYZHrts9/ezIcQMrsbyY7xO3y5GHq
znCwBNmzPBli7qQMB67riwtsy5Lh6sF8t2SIOZ0ZEHs1kh1unvse/Dgzw6HA
FqjiSZJDMcjg+gyHfpA/LidBxHdkQPyzIslhRp5Q8wGmTIdVHy/5JnkkQcxX
yXSIBblDHSrvlAkR50ly6JsOFIjJhPhjLVS+KNOh9XXgDrmvSQ5bgc6e35Xp
oG7IsUbGKRniroZMSDjNS4aIH4Kqf5oMoT9C+aLQ8ErPcjgGCj+XFAdukD+j
shyEmw+cWhiZ4gAAUFevAg==
                    "]]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4gmHvmrE7M502D9fSv9uRKqD1ZYTZftmZzqE
8elumtud6rC3ZLIES1mmwwWl2z/rhFIdGEDgS4bDcW/zTscdKQ5FGRPf1mzP
cHBMeHpBqT/FwQconNCb4aB/V4WtUTHFYZHrts9/ezIcMoHK7G8mO8Tt8uRh
6s5wsATZszzZ4SLI3EkZDlzXFxfYliXD1YP5bskQczozIPZqJDvcPPc9+HFm
hkOBLVDFkySHYpD99RkO/SB/XE6CiO/IgPhnRZLDjDyh5gNMmQ6rPl7yTfJI
gpivkglxhzpU3ikTIs6T5NA3HSgQk+kA8l7CWqh8UaZD6+vAHXJfkxy2Ap09
vyvTQd2QY42MUzLEXQ2ZDntA4TQvGSJ+CKr+aTKE/gjli0LDKz3L4RjIApcU
B26QP6OyHISbD5xaGJniAABSL68D
                    "], CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[0.74902, 0., 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGI9IGYC4ts/67L2bMl0kI1Ksb5/PtmhWmSd+8NVmQ4X
lIAyz5IdjnubdzrOyXTYWzJZguVfssO7GnvTuK5MB67riwtshVIceqfnCTVX
QNWrpTiosjVOdU7OdAjj09001zwFYq431Hz7FAcfoHEJppkQcz1SHN6CzJPL
dHBKeHpBKRjK58t0cATx06F8tkyHRa7bPv8tSHGYcOirRsz/DAfh5gOnFtam
ODCAwJ8Mh0JboIt6UhxugfzzI8Nh64myffNnIfhg96xOgdjzOwNi/v4Uh1Uf
L/kmAeXB5u9JcagC+f9bhsMMoLcO7IKa/yXDoQBk/o4Uh6KMiW9rtmc4FIPo
/hSH1teBO+R6oe5RTHG4A7KvJ8NB/64KW+PNZIh+GP9oMiQcujMc1A051shs
SoarB4fnvGQHkLH2EzMcbp77Hvx4YjJE39QMh28aMf2HWqHmzYGqr0t2OAYK
xyUZkHgoSYaIr8uAxFdeMsT/O6D2ZyZDzD0LVZ+QDHHHM2h4xUHd8wdqfliy
w+Ols48oiEDj3w/K14HGl3WyAzj9OGRCwkclGRKeIZmQdMCfDAkvYHrYAjL/
W5KDAcgduZmQ+HqQBFGXnwkJ92dJEHcWZkLs+ZAEsac4EyL+NQninw6E/eB4
a4Gmpx6oe5DSMwC1Tkwb
                    "]]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGI9IGYC4ts/67L2bMl0kI1Ksb5/PtmhWmSd+8NVmQ4X
lYAyz5IdjnubdzrOyXTYUzJZguVfssO7GnvTuK5MB67riwtshVIceqfnCTVX
QNWrpTiosjVOdU7OdAjj09001zwFYq431Hz7FAcfoHEJppkQcz1SHN6CzJPL
dHBMeHpBKRjK58t0cALx06F8tkyHRa7bPv8tSHGYcOirRsz/DAfh5gOnFtam
ODCAwJ8Mh0JboIt6UhxugfzzI8Nhy4myffNnIfhg96xOgZj7OwNi3/4Uh1Uf
L/kmAeXB5u9JcagC+f9bhsMMoLcO7IKa/wVq/o4Uh6KMiW9rtmc4FIPo/hSH
1teBO+R6oe5RTHG4A7KvJ8PB4K4KW+PNZIh+IF8PxD+aDAmH7gwHdUOONTKb
kuHqweE5L9kBZKz9xAyHm+e+Bz+emOygD9I3NcMB6Ov+Q61Q8+ZA1dclOxwD
heOSDEg8lCRDxNdlQOIrLxni/x1Q92QmQ8w9C1WfkAxxx7MMh62g8IqDuucP
1PywZIfHS2cfURCBxr8flK8DjS/rZAdw+nHIdCgAhY9KMiQ8QzIh6YA/GRJe
wPQANv9bEsQduVD1D5Ig6vIzIenuWRLEv4WZEHs+JEHiqzgTEn5fkyD+6UDY
D463Fmh66oG6Byk9AwC1BkwY
                    "], CurveClosed -> {1}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    199.85500000000002`, 166.09}, {199.469, 163.402}, {
                    200.965, 162.51199999999997`}, {202.375, 161.988}, {
                    203.836, 161.47299999999998`}, {205.031, 159.906}, {
                    205.648, 158.488}}}, CurveClosed -> {0}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{196.238, 
                    157.246}, {196.85500000000002`, 154.934}, {198.477, 
                    155.223}, {199.89100000000002`, 154.703}, {201.348, 
                    154.184}, {202.88700000000003`, 152.336}, {203.5, 
                    150.922}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    204.48800000000003`, 172.414}, {205.227, 
                    172.89100000000002`}, {219.43, 148.97299999999998`}, {
                    218.691, 148.496}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    204.48800000000003`, 172.414}, {205.227, 
                    172.89100000000002`}, {219.43, 148.97299999999998`}, {
                    218.691, 148.496}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{206.016, 173.36700000000002`}, {206.016, 
                    172.512}, {205.23399999999998`, 171.73}, {204.379, 
                    171.73}, {203.523, 171.73}, {202.742, 172.512}, {202.742, 
                    173.36700000000002`}, {202.742, 174.227}, {203.523, 
                    175.004}, {204.379, 175.004}, {205.23399999999998`, 
                    175.004}, {206.016, 174.227}, {206.016, 
                    173.36700000000002`}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{206.016, 173.36700000000002`}, {206.016, 
                    172.51199999999997`}, {205.23399999999998`, 
                    171.73000000000002`}, {204.379, 171.73000000000002`}, {
                    203.523, 171.73000000000002`}, {202.742, 
                    172.51199999999997`}, {202.742, 173.36700000000002`}, {
                    202.742, 174.22700000000003`}, {203.523, 175.004}, {
                    204.379, 175.004}, {205.23399999999998`, 175.004}, {
                    206.016, 174.22700000000003`}, {206.016, 
                    173.36700000000002`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    218.16, 192.586}, {223.914, 192.586}, {223.914, 
                    191.26600000000002`}, {218.16, 191.26600000000002`}}}]}, {
                   
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    218.16, 192.58599999999998`}, {223.914, 
                    192.58599999999998`}, {223.914, 191.266}, {218.16, 
                    191.266}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    218.16, 190.078}, {223.914, 190.078}, {223.914, 
                    179.055}, {218.16, 179.055}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    218.16, 190.07799999999997`}, {223.914, 
                    190.07799999999997`}, {223.914, 179.05499999999998`}, {
                    218.16, 179.05499999999998`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    217.809, 194.09}, {224.191, 194.05100000000002`}, {
                    224.441, 196.21499999999997`}, {222.281, 198.555}, {
                    221.02, 198.531}, {219.77299999999997`, 198.469}, {
                    217.758, 196.164}, {217.809, 194.09}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    217.809, 194.08999999999997`}, {224.191, 194.051}, {
                    224.441, 196.215}, {222.281, 198.555}, {221.02, 
                    198.531}, {219.77299999999997`, 198.469}, {217.758, 
                    196.164}, {217.809, 194.08999999999997`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {CompressedData["
1:eJxTTMoPSmViYGBQBmIQ7ZTw9IKSc65D3/Q8oeacDIfHS2cfUZDJhdAxGQ5c
1xcX2P7LcQjn0900Vz/DQTYqxfr+6xyI+j/pDvp3Vdgab+Y4eJt3OiacTHe4
qHT7Z92lHAdVtsapzv3pDmDzb+c49ILUJyD4VltOlO2LT3d4W2NvGncPar5/
usMMoLIDj3IcGEDAJd1BBmTfc6h663SHRa7bPv99k+NQlDHxbY1xusNWoPD8
TzkQWg/qnp85Dj4g9+imOxwHOYwB6h+ddAeQMfPZciHm6ac7cIP8x5ULUW+a
7nDz3Pfgx7y5DnG7PHmYgPaB1fHnQtzplO7gCHI/P1TeO91hwqGvGjHcUH51
ukMYyB9A/iVQOKyCqheHmn8VGj5KuVB3ZUDCzRJqvloGJHySoepdMyD+ysp1
qBZZ5/7QKwNiT36uA8j79oHQ+ADyLUHuDM9wAJqetacgFxJvcRkQc3JzIeqS
MxyAnr2+OAOqPj0D4v74XIdikIH5GQ6FIPmAXAd1Q441MkVQ9yClDwAIJfB7

                    "], CompressedData["
1:eJxTTMoPSmViYGBQAmIQ7Zjw9IKSe66Dt3mnY0JihkPv9Dyh5oBch4yJb2vs
UzMcCm25ri+OyXWI2+XJw5Sc4aB/V4WtMRHKj89wkI1Ksb6fnOuwf76U/t2Y
DIfHS2cfUUjJdSgGGRCNkAebH5nhUAQSB/LB9oZnONw89z34MdC8/kNfNWKC
oeqjoeb7ZzgwgIBBrgPQNaZxehkOMiB58VyIO1ih6rlzIe6+kQ7h/89xCOPT
3TR3dTrEPQy5DtUi69wfVkHlmXMd1A051sh4pTus+njJN4klF+Iu53SHi0q3
f9Yx5UJou3SI/4H6rbacKNtnnQ4x51+OwyLXbZ//WqRD3P83B2KPBdT83zkQ
9wD53zRi+g/9zHHYBwofIB/s7q85kPCxhvI/5kDc45Tu4AMKp7c5Drd+1mXt
8UiHhNvLHEh4BKc7AF1TYPsMqj4Jyr+X47C3ZLIESx9U/9McB1W2xqnOx9Mh
4fwd6p4f6RB3cORC3K2ZAYln1VwHJ5A6YPijpwcAtQ3lmA==
                    "]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxlU1tIVFEUHcaSiLDQKInRJlHHnk6FWiPi1oqCsidUiNkk2j5G20or6Ali
ffjRU6IgJjFzwEl6SEUfZSJBESEmQUVIhPQVfURURESdc/eSggaGw71n77XX
XmvdWTV7NtYl+Xw+v/3PxPmofUb+yAmh0MIJPYGIoYf729LHVQt9y6s6MzDb
kHe/XOjswNe8qt9MOcnNF5YVCR2ZemPl+0FGndCno6UF1VeYNqfM742FhA67
+51Mo12XHwfDQqcuNqS2LGFyR3+haN10Jp/7rRKa+Kpzb0kyU5+bt1Vo6Z2n
B/uSmMw5i7wD+H6m/JHs5OZ68BvP9CLr7Y/jDUKnHfAkpkbX0CTKM43p5McN
9zMPCF3/PFxRE0B9I/BDmGew/1rMqxN6M/h90+gx8N8t+r6bdW/bb1F2PXiJ
e6tfkyv4yarXNeiTanRuj1DCnelG+24JXXI6ZBpKa+l/1nEb+DmG7lpa7b1C
GZW1xe/mGiqLfhjKugl9FhkadvwT4FtodL8O8C0xut95oYjbrxT+/eOvN68V
/BYYKnf4bXi2+Ooj/Aob1bET+s4zqnuXKI85Rv2Mi/KweRly7+PwP9fo3Dj0
yjaqu8XzeAXBJwb8gFF/D0EfP/ZnoSeri1rLXkPvKPgmmK6uuPfll81L2PVZ
v9bYsug28KlAXnlMXyYHE60HXuDvvcdzGvyrHfMPeakR2uLyOpn1O9iO+hRW
HSpRb5/3lVin1sPvKchTGfhkMOW6ecWoj7Dqvxh5ZeS7AH7GML8c+jxnzdk6
0T6bN09Py9+bG/zf3z+xPLCC
                    "]]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    217.848, 170.09}, {224.27, 170.09}, {224.27, 161.203}, {
                    217.848, 161.203}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    217.848, 170.09}, {224.27, 170.09}, {224.27, 161.203}, {
                    217.848, 161.203}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    218.22299999999998`, 156.121}, {224.422, 156.121}, {
                    224.422, 154.25400000000002`}, {218.22299999999998`, 
                    154.25400000000002`}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    218.22299999999998`, 156.121}, {224.422, 156.121}, {
                    224.422, 154.25400000000002`}, {218.22299999999998`, 
                    154.25400000000002`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    218.07, 152.84}, {224.418, 152.84}, {224.418, 145.895}, {
                    218.07, 145.895}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    218.07, 152.84}, {224.418, 152.84}, {224.418, 145.895}, {
                    218.07, 145.895}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    217.625, 144.47299999999998`}, {224.566, 
                    144.47299999999998`}, {224.566, 140.58999999999997`}, {
                    217.625, 140.58999999999997`}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    217.625, 144.47299999999998`}, {224.566, 
                    144.47299999999998`}, {224.566, 140.58999999999997`}, {
                    217.625, 140.58999999999997`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    218.48000000000002`, 157.79299999999998`}, {
                    224.07399999999998`, 157.79299999999998`}, {225.184, 
                    159.641}, {217.477, 159.641}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    218.48000000000002`, 157.793}, {224.07399999999998`, 
                    157.793}, {225.184, 159.641}, {217.477, 159.641}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    226.023, 164.602}, {226.078, 169.45700000000002`}, {
                    229.93, 169.45700000000002`}, {228.418, 168.207}, {
                    227.008, 166.695}, {226.023, 164.602}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    226.023, 164.60199999999998`}, {226.078, 
                    169.45700000000002`}, {229.93, 169.45700000000002`}, {
                    228.418, 168.20700000000002`}, {227.008, 166.695}, {
                    226.023, 164.60199999999998`}}}, CurveClosed -> {1}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYCYqeEpxeUorMdijImvq0JTnFY/fGSb1JMtgPX
9cUFtkYpDi7dOc9/N2Y7LHLd9vmvA4L/TSOm/1AgmnxLisPWE2X75jdlO/RN
zxNq3pPiUGgLNKkh2+H2z7qsPQ9SHFaBzAfyw/h0N839DeUfyHbYN19K/+6X
FAcGEADyweJPUhyOe5t3OgL5ba8Dd8jtTIGYcwBqf20KxF4gP26XJw+Td4pD
L8heIP9tjb1pHND970D0q2yIuEkKRN9LhHr9uypsjUB+KMg9zQj+zXPfgx9f
RagvBoXP/xQHdUOONTJA81pB7jFNhdgPDC+wu01SHWSjUqzvR0P9y4Dgg8Pl
WooDLLxV2RqnOncj+LDwBwDld7xQ
                    "], CurveClosed -> {1}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    218.85500000000002`, 152.016}, {223.41000000000003`, 
                    152.016}, {223.41000000000003`, 146.34}, {
                    218.85500000000002`, 146.34}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    221.76999999999998`, 149.664}, {223.37499999999997`, 
                    149.664}, {223.37499999999997`, 148.73}, {
                    221.76999999999998`, 148.73}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    221.76999999999998`, 149.664}, {223.37499999999997`, 
                    149.664}, {223.37499999999997`, 148.73}, {
                    221.76999999999998`, 148.73}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    218.969, 149.664}, {220.535, 149.664}, {220.535, 
                    148.73}, {218.969, 148.73}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    218.969, 149.664}, {220.535, 149.664}, {220.535, 
                    148.73}, {218.969, 148.73}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    220.535, 151.945}, {221.769, 151.945}, {221.769, 
                    149.629}, {220.535, 149.629}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    220.535, 151.945}, {221.769, 151.945}, {221.769, 
                    149.629}, {220.535, 149.629}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    220.535, 148.76999999999998`}, {221.769, 
                    148.76999999999998`}, {221.769, 146.30499999999998`}, {
                    220.535, 146.30499999999998`}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    220.535, 148.77}, {221.769, 148.77}, {221.769, 146.305}, {
                    220.535, 146.305}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{195.191, 
                    208.824}, {195.477, 204.371}, {194.094, 
                    201.92600000000002`}, {191.73399999999998`, 202.297}, {
                    191.086, 204.76999999999998`}, {192.566, 
                    206.42600000000002`}, {195.191, 208.824}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{195.191, 
                    208.824}, {195.477, 204.371}, {194.094, 201.926}, {
                    191.73399999999998`, 202.297}, {191.086, 
                    204.76999999999998`}, {192.566, 206.426}, {195.191, 
                    208.824}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{190.016, 
                    198.953}, {187.918, 200.02}, {189.434, 208.164}, {190.238,
                     211.57399999999998`}, {190.83200000000002`, 207.18}, {
                    191.82800000000003`, 200.93}, {190.016, 198.953}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{190.016, 
                    198.95299999999997`}, {187.918, 200.01999999999998`}, {
                    189.434, 208.164}, {190.238, 211.574}, {
                    190.83200000000002`, 207.18}, {191.82800000000003`, 
                    200.93}, {190.016, 198.95299999999997`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{190.762, 
                    198.566}, {194.285, 197.344}, {197.07399999999998`, 
                    201.137}, {198.02, 205.535}, {195.10899999999998`, 
                    201.52}, {190.375, 201.516}, {190.762, 198.566}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{190.762, 
                    198.56599999999997`}, {194.285, 197.344}, {
                    197.07399999999998`, 201.137}, {198.02, 205.535}, {
                    195.10899999999998`, 201.51999999999998`}, {190.375, 
                    201.516}, {190.762, 198.56599999999997`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{188.09, 
                    194.45700000000002`}, {185.33200000000002`, 195.184}, {
                    186.99200000000002`, 203.824}, {187.49200000000002`, 
                    207.281}, {188.098, 203.71099999999998`}, {190., 
                    195.637}, {188.09, 194.45700000000002`}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{188.09, 
                    194.457}, {185.33200000000002`, 195.184}, {
                    186.99200000000002`, 203.824}, {187.49200000000002`, 
                    207.281}, {188.098, 203.711}, {190., 195.637}, {188.09, 
                    194.457}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{189.031, 
                    194.727}, {189.18800000000002`, 197.707}, {192.156, 
                    196.848}, {194.207, 198.43800000000002`}, {193.871, 
                    196.94899999999998`}, {192.60899999999998`, 194.309}, {
                    189.031, 194.727}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{189.031, 
                    194.727}, {189.18800000000002`, 197.707}, {192.156, 
                    196.848}, {194.207, 198.438}, {193.871, 196.949}, {
                    192.60899999999998`, 194.309}, {189.031, 194.727}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{185.656, 
                    190.73399999999998`}, {182.92600000000002`, 
                    191.47299999999998`}, {184.566, 200.76999999999998`}, {
                    184.41, 204.598}, {185.21099999999998`, 
                    201.29299999999998`}, {187.75, 191.63299999999998`}, {
                    185.656, 190.73399999999998`}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{185.656, 
                    190.734}, {182.92600000000002`, 191.47299999999998`}, {
                    184.566, 200.76999999999998`}, {184.41, 204.598}, {
                    185.21099999999998`, 201.293}, {187.75, 
                    191.63299999999998`}, {185.656, 190.734}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{186.93, 
                    191.137}, {189.164, 190.41}, {192.129, 191.863}, {192.363,
                     194.52700000000002`}, {190.434, 193.21899999999997`}, {
                    187.359, 194.21899999999997`}, {186.93, 191.137}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{186.93, 
                    191.137}, {189.164, 190.41}, {192.129, 191.863}, {192.363,
                     194.527}, {190.434, 193.219}, {187.359, 194.219}, {
                    186.93, 191.137}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{183.617, 
                    186.63299999999998`}, {181.004, 186.42200000000003`}, {
                    182.172, 194.344}, {182.176, 201.71899999999997`}, {
                    183.13299999999998`, 194.824}, {185.75, 188.512}, {
                    183.617, 186.63299999999998`}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{183.617, 
                    186.63299999999998`}, {181.004, 186.422}, {182.172, 
                    194.344}, {182.176, 201.719}, {183.13299999999998`, 
                    194.824}, {185.75, 188.51199999999997`}, {183.617, 
                    186.63299999999998`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{184.52, 
                    186.99200000000002`}, {186.285, 186.105}, {189.445, 
                    187.52}, {190.348, 190.5}, {187.16, 189.117}, {
                    185.02700000000002`, 190.469}, {184.52, 
                    186.99200000000002`}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{184.52, 
                    186.992}, {186.285, 186.105}, {189.445, 
                    187.51999999999998`}, {190.348, 190.5}, {187.16, 
                    189.117}, {185.02700000000002`, 190.469}, {184.52, 
                    186.992}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{205.023, 
                    204.695}, {204.559, 200.83200000000002`}, {
                    202.98000000000002`, 198.586}, {200.621, 
                    198.95700000000002`}, {199.97299999999998`, 
                    201.42600000000002`}, {201.883, 203.008}, {205.023, 
                    204.695}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{205.023, 
                    204.695}, {204.559, 200.832}, {202.98000000000002`, 
                    198.58599999999998`}, {200.621, 198.957}, {
                    199.97299999999998`, 201.426}, {201.883, 
                    203.00799999999998`}, {205.023, 204.695}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{198.785, 
                    194.785}, {202.70299999999997`, 194.227}, {
                    204.11299999999997`, 197.23399999999998`}, {206.75, 
                    201.08200000000002`}, {203.055, 198.406}, {198.637, 
                    197.848}, {198.785, 194.785}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{198.785, 
                    194.785}, {202.70299999999997`, 194.227}, {
                    204.11299999999997`, 197.23399999999998`}, {206.75, 
                    201.082}, {203.055, 198.406}, {198.637, 197.848}, {
                    198.785, 194.785}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{197.672, 
                    195.22299999999998`}, {195.535, 197.789}, {197.602, 
                    201.008}, {199.23399999999998`, 203.75}, {198.883, 
                    199.668}, {200.27299999999997`, 197.39800000000002`}, {
                    197.672, 195.22299999999998`}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{197.672, 
                    195.223}, {195.535, 197.789}, {197.602, 
                    201.00799999999998`}, {199.23399999999998`, 203.75}, {
                    198.883, 199.668}, {200.27299999999997`, 
                    197.39800000000002`}, {197.672, 195.223}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{196.727, 
                    190.99200000000002`}, {196.48800000000003`, 193.5}, {
                    200.758, 194.055}, {202.691, 195.44899999999998`}, {
                    202.039, 194.}, {201.055, 190.102}, {196.727, 
                    190.99200000000002`}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{196.727, 
                    190.992}, {196.48800000000003`, 193.5}, {200.758, 
                    194.055}, {202.691, 195.449}, {202.039, 194.}, {201.055, 
                    190.10199999999998`}, {196.727, 190.992}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    195.83200000000002`, 190.93800000000002`}, {192.879, 
                    191.26999999999998`}, {194.105, 196.285}, {
                    196.22299999999998`, 199.07}, {195.33200000000002`, 
                    195.227}, {197.781, 192.55100000000002`}, {
                    195.83200000000002`, 190.93800000000002`}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    195.83200000000002`, 190.938}, {192.879, 191.27}, {
                    194.105, 196.285}, {196.22299999999998`, 199.07}, {
                    195.33200000000002`, 195.227}, {197.781, 192.551}, {
                    195.83200000000002`, 190.938}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    193.60899999999998`, 186.762}, {190.24599999999998`, 
                    188.24599999999998`}, {192.40200000000002`, 192.461}, {
                    193.664, 194.94899999999998`}, {193.125, 191.684}, {
                    195.82000000000002`, 189.191}, {193.60899999999998`, 
                    186.762}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    193.60899999999998`, 186.762}, {190.24599999999998`, 
                    188.246}, {192.40200000000002`, 192.461}, {193.664, 
                    194.949}, {193.125, 191.684}, {195.82000000000002`, 
                    189.191}, {193.60899999999998`, 186.762}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    194.27299999999997`, 187.15200000000002`}, {196.035, 
                    184.848}, {199.47299999999998`, 187.84}, {200.18, 
                    191.33200000000002`}, {197.18800000000002`, 188.84}, {
                    194.977, 189.25}, {194.27299999999997`, 
                    187.15200000000002`}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    194.27299999999997`, 187.152}, {196.035, 
                    184.84799999999998`}, {199.47299999999998`, 187.84}, {
                    200.18, 191.332}, {197.18800000000002`, 188.84}, {194.977,
                     189.25}, {194.27299999999997`, 187.152}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4rhdnjxMwekOXNcXF9jGpTrIRKVY33dPd2AA
gTOpDpeUbv+sm5XuUJQx8W3N5DQHWZB8fLrD3pLJEiz/0iDqw9MdCm2BJvCk
O3ibdzomFKY79B/6qhFjnO5w89z34MeN6RB90ukOYXy6m+bOhtr3Lc1B3ZBj
jcy2dAenhKcXlLrTHEDW2B9Md5iRJ9R8YFOawyLXbZ//nkl3+KYR03/obhpE
/ByUr5nusH++lP7dL+kOvdOBEhbpDq2vA3fI8WZAaMd0h2KQgfoZDlUi69wf
uqVD7FPLgLhXId3hzs+6rD0yGRD3/U6D+JsDqv9kmgM4fOQzIPYdTXPoA9mj
A1V/GCofnAEJh+9pkHAqhsrzQ93Zm+HgAwoX1XSH2yD7tmQ4WG45UbaPOd3h
Iih8+zIcQkHh8jjNwaU75/lvwQyH1R8v+SbVpDno31Vha5wJDUffNIdqkD+C
EPEFABcywTw=
                    "]]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4rhdnjxMwekOXNcXF9jGpTrIRKVY33dPd2AA
gTOpDpeUbv+sm5XuUJQx8W3N5DQHWZB8fLrDnpLJEiz/0iDqw9MdCm2BJvCk
O3ibdzomFKY79B/6qhFjnO5w89z34MeN6RB90ukOYXy6m+bOhtr3Lc1B3ZBj
jcy2dAfHhKcXlLrTHEDW2B9Md5iRJ9R8YFOawyLXbZ//nkl3+KYR03/obhpE
/ByUr5nusH++lP7dL+kOfdOBEhbpDq2vA3fI8WZAaMd0h2KQgfoZDtUi69wf
uqVD7FPLcCgAuVch3eHOz7qsPTIZEPf9ToP4myPDoQ2k/2SaAzh85DMcvoLs
O5oGsUcHqv4wVD4Yyv+eBgmnYiifH+rO3gxIuKimO9wG2bclw8Fyy4myfczp
DhdB4duX4RAKCpfHaQ4u3TnPfwtmOKz+eMk3qSbNQf+uClvjTGg4+qZB/BGE
iC8AFarBOw==
                    "], CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4qKMiW9ritMcRNa5P6y6Euuwf76U/t2UNAeX
7pznv29C+QFpDu1iN899fxzrELfLk4cpOc0BSGq3b4t1WPXxkm/SlzSH3ul5
Qs0BMQ4XlW7/rJNLd/imEdN/6G00hP8p3YEBBBRiHApsua4vPpEBUR8R4xDG
p7tp7u8MB78kgQjLMzEOws0HTi2cmAlxT0kshP8wE2LOpVgHkLYDYVkOxSB3
P4+F0OuzHDKBlP3aWId9IPfeyHIA2lJgOynWAejq4McfsyD2TYh1OOZt3ul4
Jcth09z3y4+djnXYcqJs3/xtWQ5PLwAtYItzCAW5Z3KWgyVIIjzOwTEBKJOf
5bBGJirFuj/OYcKhrxox8lkONfamcbs44x1AwvenZzo8A+m3i3cAGZ+gmQlx
l3i8Q+vrwB1yvRmQ8HoWBwkHngyIvHwcJJwK0yH+B4Z/ISh8FNIh9q2Phbjj
eJoD0PdZe7bEOqDHFwBlE80j
                    "]]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4qKMiW9ritMcRNa5P6y6Euuwf76U/t2UNAeX
7pznv29C+QFpDm1iN899fxzrELfLk4cpOc3Bi4dJu31brMOqj5d8k76kOfRN
zxNqDohxuKh0+2edXLrDN42Y/kNvoyH8T+kODCCgEONQYMt1ffGJDIj6iBiH
MD7dTXN/Zzj4JQlEWJ6JcRBuPnBq4cRMiHtKYiH8h5kOl0DmXIp1AGk7EJbl
AHb381iHYhC9PsshC0jZr4112Ady740sB57riwtsJ8U6AF0d/PhjFsS+CbEO
x7zNOx2vZDlsmvt++bHTsQ5bTpTtm78ty+HJBaAFbHEOoSD3TM5ysAJJhMc5
OCY8vaCUn+WwRiYqxbo/zmHCoa8aMfJZDjX2pnG7OOMdQML3p2c6PAPpt4t3
ABmfoJnpUAJyl3i8Q+vrwB1yvRkOHqDwehYHCQeeDIj75eMg4VSYDvE/MPwL
QeGjkA6xb32sgyXIHcfTHO78rMvasyXWAT2+AGtDzSk=
                    "], 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    217.84, 109.32}, {218.684, 109.215}, {219.21899999999997`,
                     107.57799999999999`}, {219.637, 108.68799999999999`}, {
                    220.34, 110.48}, {219.848, 111.906}, {219.055, 111.75}, {
                    218.117, 111.5}, {216.535, 109.402}, {217.84, 
                    109.32}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    217.84, 109.32}, {218.684, 109.215}, {219.21899999999997`,
                     107.57799999999997`}, {219.637, 108.68799999999999`}, {
                    220.34, 110.47999999999999`}, {219.848, 111.906}, {
                    219.055, 111.75}, {218.117, 111.5}, {216.535, 
                    109.40199999999999`}, {217.84, 109.32}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4gmHvmrE8Kc5ZEx8W2O/NdXhuLd5p+OHVIdv
GjH9h66mQsR/pjqoG3KskXmU6qDK1jjVWT3NYeuJsn3zgXyrLUCGd5rDItdt
n/8+SXVgAIEpaRBzzqQ6FIMMWA/lP0h1KLDlur74RJrDRaXbP+s+pULM2ZcG
0eeQBrH3ZJqDJcjcZKg959Icwvh0N80tT3MoBOm/k+ZQJbLO/eG0NAfZqBTr
+7/TIO5LS4OYH5HuoH9Xha3xYqpD3/Q8oeYz6Q6OCU8vKMmnOuwtmSzB8i/d
YdXHS75JBSkQd0tkOAB9aRrHlwJx73+o/tJkCL00HeIOvmSHWz/rsvasSHcA
2lJgm5bs8Hjp7CMKHemQcFqYDPFnQrrDJZD/XiVD7NVPd5gBdMYBrxSIvRVp
DuEg//inOqCHPwBV9Ldy
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    188.42600000000002`, 149.24599999999998`}, {
                    191.60899999999998`, 149.23399999999998`}, {192.156, 
                    153.504}, {192.156, 154.69899999999998`}, {190.59, 
                    154.39800000000002`}, {187.82800000000003`, 151.785}, {
                    188.42600000000002`, 149.24599999999998`}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    188.42600000000002`, 149.246}, {191.60899999999998`, 
                    149.234}, {192.156, 153.504}, {192.156, 
                    154.69899999999998`}, {190.59, 154.398}, {
                    187.82800000000003`, 151.78500000000003`}, {
                    188.42600000000002`, 149.246}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{215.961, 
                    107.793}, {218.227, 107.277}, {218.195, 
                    112.73400000000001`}, {215.879, 115.04700000000001`}, {
                    216.89800000000002`, 111.543}, {214.176, 108.336}, {
                    215.961, 107.793}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{215.961, 
                    107.793}, {218.227, 107.27700000000002`}, {218.195, 
                    112.73400000000001`}, {215.879, 115.047}, {
                    216.89800000000002`, 111.54299999999998`}, {214.176, 
                    108.33600000000001`}, {215.961, 107.793}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{215.078, 
                    107.84}, {215.23, 105.24600000000001`}, {
                    208.71499999999997`, 108.17999999999999`}, {207.039, 
                    110.195}, {210.88700000000003`, 108.562}, {
                    214.89100000000002`, 109.91400000000002`}, {215.078, 
                    107.84}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{215.078, 
                    107.84}, {215.23, 105.24600000000001`}, {
                    208.71499999999997`, 108.17999999999998`}, {207.039, 
                    110.195}, {210.88700000000003`, 108.56199999999998`}, {
                    214.89100000000002`, 109.91399999999999`}, {215.078, 
                    107.84}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    212.22299999999998`, 111.543}, {212.45700000000002`, 
                    109.031}, {206.57399999999998`, 111.242}, {
                    204.83200000000002`, 113.203}, {208.69899999999998`, 
                    111.953}, {211.969, 113.613}, {212.22299999999998`, 
                    111.543}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    212.22299999999998`, 111.54299999999998`}, {
                    212.45700000000002`, 109.031}, {206.57399999999998`, 
                    111.24199999999999`}, {204.83200000000002`, 113.203}, {
                    208.69899999999998`, 111.953}, {211.969, 
                    113.61299999999997`}, {212.22299999999998`, 
                    111.54299999999998`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{213.305, 
                    111.191}, {215.57, 110.67599999999999`}, {
                    215.20299999999997`, 116.32}, {213., 118.262}, {214.059, 
                    114.49600000000001`}, {211.523, 111.738}, {213.305, 
                    111.191}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{213.305, 
                    111.191}, {215.57, 110.67599999999999`}, {
                    215.20299999999997`, 116.32}, {213., 118.262}, {214.059, 
                    114.49600000000001`}, {211.523, 111.738}, {213.305, 
                    111.191}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    210.92200000000003`, 114.62499999999999`}, {
                    213.18800000000002`, 114.109}, {211.88700000000003`, 
                    118.96900000000001`}, {210.207, 120.91000000000001`}, {
                    210.48000000000002`, 117.367}, {209.363, 
                    114.91000000000001`}, {210.92200000000003`, 
                    114.62499999999999`}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    210.92200000000003`, 114.625}, {213.18800000000002`, 
                    114.10899999999998`}, {211.88700000000003`, 118.969}, {
                    210.207, 120.91}, {210.48000000000002`, 
                    117.36700000000002`}, {209.363, 114.91}, {
                    210.92200000000003`, 114.625}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    209.71899999999997`, 114.641}, {209.953, 112.051}, {
                    205.375, 114.039}, {203.598, 116.488}, {
                    207.42600000000002`, 115.238}, {209.465, 
                    116.70700000000001`}, {209.71899999999997`, 114.641}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    209.71899999999997`, 114.64099999999999`}, {209.953, 
                    112.05100000000002`}, {205.375, 114.03899999999999`}, {
                    203.598, 116.488}, {207.42600000000002`, 115.238}, {
                    209.465, 116.70700000000002`}, {209.71899999999997`, 
                    114.64099999999999`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    208.47299999999998`, 116.609}, {209.95700000000002`, 
                    117.67599999999999`}, {208.383, 120.5}, {205.555, 
                    120.324}, {205.83200000000002`, 118.617}, {206.809, 
                    115.621}, {208.47299999999998`, 116.609}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    208.47299999999998`, 116.60899999999998`}, {
                    209.95700000000002`, 117.67599999999999`}, {208.383, 
                    120.5}, {205.555, 120.32400000000001`}, {
                    205.83200000000002`, 118.61699999999999`}, {206.809, 
                    115.62100000000001`}, {208.47299999999998`, 
                    116.60899999999998`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    219.63299999999998`, 104.902}, {219.781, 102.309}, {
                    213.266, 103.60199999999999`}, {211.21899999999997`, 
                    106.363}, {215.32800000000003`, 105.586}, {219.441, 
                    106.98}, {219.63299999999998`, 104.902}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    219.63299999999998`, 104.90199999999999`}, {219.781, 
                    102.309}, {213.266, 103.60199999999998`}, {
                    211.21899999999997`, 106.363}, {215.32800000000003`, 
                    105.58600000000001`}, {219.441, 106.97999999999999`}, {
                    219.63299999999998`, 104.90199999999999`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{193.742, 
                    109.543}, {193.977, 106.95700000000001`}, {186.863, 
                    109.801}, {185.086, 112.25}, {188.91, 111.}, {
                    193.48800000000003`, 111.613}, {193.742, 109.543}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{193.742, 
                    109.54299999999998`}, {193.977, 106.95700000000002`}, {
                    186.863, 109.80100000000002`}, {185.086, 112.25}, {188.91,
                     111.}, {193.48800000000003`, 111.61299999999997`}, {
                    193.742, 109.54299999999998`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{198.105, 
                    108.44100000000002`}, {199.59, 109.508}, {196.559, 
                    112.258}, {194.14499999999998`, 112.902}, {194.418, 
                    111.199}, {196.441, 107.453}, {198.105, 
                    108.44100000000002`}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{198.105, 
                    108.441}, {199.59, 109.50799999999998`}, {196.559, 
                    112.25800000000001`}, {194.14499999999998`, 
                    112.90199999999999`}, {194.418, 111.19899999999998`}, {
                    196.441, 107.453}, {198.105, 108.441}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{198.559, 
                    106.648}, {198.71899999999997`, 104.32}, {190.93, 
                    105.598}, {188.895, 107.74600000000001`}, {195.594, 
                    106.535}, {198.34, 108.641}, {198.559, 106.648}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{198.559, 
                    106.64799999999997`}, {198.71899999999997`, 104.32}, {
                    190.93, 105.59799999999998`}, {188.895, 
                    107.74600000000001`}, {195.594, 106.535}, {198.34, 
                    108.64099999999999`}, {198.559, 106.64799999999997`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{202.207, 
                    105.098}, {203.07399999999998`, 102.93400000000001`}, {
                    195.598, 103.46100000000001`}, {192.97299999999998`, 
                    104.71900000000001`}, {197.21499999999997`, 104.754}, {
                    201.61299999999997`, 106.60199999999999`}, {202.207, 
                    105.098}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{202.207, 
                    105.09799999999998`}, {203.07399999999998`, 102.934}, {
                    195.598, 103.46100000000001`}, {192.97299999999998`, 
                    104.719}, {197.21499999999997`, 104.75400000000002`}, {
                    201.61299999999997`, 106.60199999999998`}, {202.207, 
                    105.09799999999998`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    205.70299999999997`, 103.52}, {206.531, 101.582}, {
                    199.617, 101.62499999999999`}, {196.24599999999998`, 
                    102.695}, {200.71099999999998`, 102.73}, {
                    204.88700000000003`, 105.438}, {205.70299999999997`, 
                    103.52}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    205.70299999999997`, 103.51999999999998`}, {206.531, 
                    101.582}, {199.617, 101.625}, {196.24599999999998`, 
                    102.695}, {200.71099999999998`, 102.73000000000002`}, {
                    204.88700000000003`, 105.43799999999999`}, {
                    205.70299999999997`, 103.51999999999998`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    210.73399999999998`, 102.48}, {211.961, 
                    100.18799999999999`}, {204.664, 99.965}, {202.297, 
                    101.09400000000001`}, {206.516, 101.67199999999998`}, {
                    209.691, 104.285}, {210.73399999999998`, 102.48}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    210.73399999999998`, 102.47999999999999`}, {211.961, 
                    100.18799999999999`}, {204.664, 99.965}, {202.297, 
                    101.094}, {206.516, 101.67199999999997`}, {209.691, 
                    104.28500000000003`}, {210.73399999999998`, 
                    102.47999999999999`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{202.191, 
                    106.398}, {199.871, 104.938}, {199.996, 109.25}, {198.148,
                     112.238}, {201.05100000000002`, 109.598}, {203.766, 
                    107.79700000000001`}, {202.191, 106.398}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{202.191, 
                    106.398}, {199.871, 104.93799999999999`}, {199.996, 
                    109.25}, {198.148, 112.238}, {201.05100000000002`, 
                    109.59799999999998`}, {203.766, 107.79700000000003`}, {
                    202.191, 106.398}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{206.305, 
                    104.848}, {204.35500000000002`, 103.12499999999999`}, {
                    202.80100000000002`, 109.043}, {201.02700000000002`, 
                    112.367}, {203.895, 109.203}, {208.102, 106.281}, {
                    206.305, 104.848}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{206.305, 
                    104.84799999999998`}, {204.35500000000002`, 103.125}, {
                    202.80100000000002`, 109.04299999999998`}, {
                    201.02700000000002`, 112.36700000000002`}, {203.895, 
                    109.203}, {208.102, 106.28100000000003`}, {206.305, 
                    104.84799999999998`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{211.742, 
                    103.199}, {210.094, 101.289}, {205.32800000000003`, 
                    108.816}, {203.594, 112.73400000000001`}, {
                    206.23399999999998`, 109.684}, {213.055, 104.82}, {
                    211.742, 103.199}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{211.742, 
                    103.19899999999998`}, {210.094, 101.28900000000002`}, {
                    205.32800000000003`, 108.816}, {203.594, 
                    112.73400000000001`}, {206.23399999999998`, 109.684}, {
                    213.055, 104.82}, {211.742, 103.19899999999998`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{207.105, 
                    97.45700000000001}, {206.281, 94.551}, {
                    194.15200000000002`, 100.195}, {192.797, 103.117}, {
                    199.738, 99.44100000000002}, {207.26999999999998`, 
                    100.21100000000001`}, {207.105, 97.45700000000001}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{207.105, 
                    97.45700000000002}, {206.281, 94.55100000000002}, {
                    194.15200000000002`, 100.195}, {192.797, 
                    103.11699999999999`}, {199.738, 99.441}, {
                    207.26999999999998`, 100.21100000000001`}, {207.105, 
                    97.45700000000002}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYCYtmoFOv7zKkOYLo/2WFGnlDzgV8pDmF8upvm
zk52KLTlur74QYpDOIgPlHdMeHpB6XmKgxOILk52yJj4tsb+bYrDnZ91WXt8
kh1unvse/Fg1FaK/PclBla1xqnN7qoPllhNl+5yTIOadSXX4phHTf0gwyUH/
rgpbo2W6Q+vrwB1yBxMd4nZ58jDdT3eoFlnn/nBeooNLd87z35YZEH09iQ5A
ssC2LQPijnio/MEMh+kgd4slQtyzMgNibmmig495p2PC1AyIe3YnQsUzHISb
D5xaCLT/gtLtn3VhGQ6LXLd9/huT5LDq4yXfJJYMiH/XQ92/Pt2BAQS2JEHc
KZgOcf/OJIdekMUuaRB1x5Mg4bge6l/2ZEg4JUP56tDwMk2F+DM42QE9/AFt
n6we
                    "]]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYCYtmoFOv7zKkOYLo/2WFGnlDzgV8pDmF8upvm
zk52KLTlur74AZQPlHdMeHpB6XkKhC5OdsiY+LbG/m2Kw+2fdVl7fJIdbp77
HvxYNRWivj3JQZWtcapze6qD5ZYTZfuckyDmnUl1+KYR039IMMlB/64KW6Nl
ukPr68AdcgcTHeJ2efIw3U93qBZZ5/5wXqKDS3fO89+WGRB9PYkOQLLAti0D
Yn88VP5gBsTdYokQ96zMcNADmVua6OBj3umYMDUD4p7diRD7SjMchJsPnFoI
tP+CEtDlYRkOi1y3ff4bk+Sw6uMl3yQWqPr1UPevT3dgAIEtSRB3CqZD3L8z
yaF3OtBilzQHNZC640mQcFwP9S97soMTyJ3JUL46NLxMUyH+DE52QA9/AGl3
rBs=
                    "], CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{196.434, 
                    132.105}, {197.98800000000003`, 130.95700000000002`}, {
                    199.707, 135.066}, {197.73, 138.97299999999998`}, {
                    197.668, 135.21499999999997`}, {194.68, 
                    133.94899999999998`}, {196.434, 132.105}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{196.434, 
                    132.105}, {197.98800000000003`, 130.95700000000002`}, {
                    199.707, 135.066}, {197.73, 138.97299999999998`}, {
                    197.668, 135.215}, {194.68, 133.94899999999998`}, {
                    196.434, 132.105}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{197.93, 
                    128.336}, {200.08200000000002`, 127.67599999999999`}, {
                    200.758, 131.484}, {199.34, 134.535}, {
                    199.57399999999998`, 131.258}, {195.953, 129.285}, {
                    197.93, 128.336}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{197.93, 
                    128.336}, {200.08200000000002`, 127.67599999999999`}, {
                    200.758, 131.484}, {199.34, 134.535}, {
                    199.57399999999998`, 131.258}, {195.953, 
                    129.28500000000003`}, {197.93, 128.336}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{199.566, 
                    125.312}, {201.648, 124.277}, {202.43800000000002`, 
                    128.125}, {200.941, 130.984}, {201.105, 127.34}, {197.965,
                     126.262}, {199.566, 125.312}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{199.566, 
                    125.31199999999998`}, {201.648, 124.27700000000002`}, {
                    202.43800000000002`, 128.125}, {200.941, 130.984}, {
                    201.105, 127.34}, {197.965, 126.262}, {199.566, 
                    125.31199999999998`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    198.71099999999998`, 125.07799999999999`}, {
                    197.88700000000003`, 122.617}, {193.105, 127.203}, {
                    192.30100000000002`, 129.69899999999998`}, {
                    195.26999999999998`, 126.75}, {199.305, 
                    127.07799999999999`}, {198.71099999999998`, 
                    125.07799999999999`}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    198.71099999999998`, 125.07799999999997`}, {
                    197.88700000000003`, 122.61699999999999`}, {193.105, 
                    127.203}, {192.30100000000002`, 129.69899999999998`}, {
                    195.26999999999998`, 126.75}, {199.305, 
                    127.07799999999997`}, {198.71099999999998`, 
                    125.07799999999997`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    196.54299999999998`, 128.848}, {195.605, 126.383}, {
                    189.594, 132.727}, {188.266, 135.781}, {
                    191.23399999999998`, 132.836}, {197.21099999999998`, 
                    130.586}, {196.54299999999998`, 128.848}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    196.54299999999998`, 128.84799999999998`}, {195.605, 
                    126.38300000000001`}, {189.594, 132.72700000000003`}, {
                    188.266, 135.78100000000003`}, {191.23399999999998`, 
                    132.836}, {197.21099999999998`, 130.586}, {
                    196.54299999999998`, 128.84799999999998`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    195.35200000000003`, 132.54299999999998`}, {194.414, 
                    129.742}, {187.879, 137.207}, {186.02700000000002`, 
                    139.85200000000003`}, {189.14499999999998`, 136.941}, {
                    196.059, 134.578}, {195.35200000000003`, 
                    132.54299999999998`}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    195.35200000000003`, 132.54299999999998`}, {194.414, 
                    129.742}, {187.879, 137.20700000000002`}, {
                    186.02700000000002`, 139.852}, {189.14499999999998`, 
                    136.941}, {196.059, 134.57799999999997`}, {
                    195.35200000000003`, 132.54299999999998`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    195.14499999999998`, 135.312}, {197.445, 135.758}, {
                    195.012, 137.676}, {192.191, 140.79299999999998`}, {
                    192.062, 137.512}, {192.598, 135.21899999999997`}, {
                    195.14499999999998`, 135.312}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    195.14499999999998`, 135.31199999999998`}, {197.445, 
                    135.758}, {195.012, 137.676}, {192.191, 140.793}, {
                    192.062, 137.51199999999997`}, {192.598, 135.219}, {
                    195.14499999999998`, 135.31199999999998`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{191.266, 
                    137.176}, {192.258, 138.258}, {190.312, 
                    138.71899999999997`}, {187.90200000000002`, 
                    141.42200000000003`}, {187.547, 139.602}, {190.137, 
                    136.262}, {191.266, 137.176}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{191.266, 
                    137.176}, {192.258, 138.258}, {190.312, 138.719}, {
                    187.90200000000002`, 141.422}, {187.547, 
                    139.60199999999998`}, {190.137, 136.262}, {191.266, 
                    137.176}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    202.39800000000002`, 125.016}, {203.66, 124.277}, {204.52,
                     126.859}, {202.953, 129.195}, {202.594, 
                    126.66799999999999`}, {201.24599999999998`, 125.965}, {
                    202.39800000000002`, 125.016}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    202.39800000000002`, 125.01599999999999`}, {203.66, 
                    124.27700000000002`}, {204.52, 126.85900000000001`}, {
                    202.953, 129.195}, {202.594, 126.66799999999998`}, {
                    201.24599999999998`, 125.965}, {202.39800000000002`, 
                    125.01599999999999`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{175.047, 
                    141.297}, {172.375, 139.691}, {168.125, 146.09}, {
                    166.99200000000002`, 148.72299999999998`}, {169.34, 
                    145.69899999999998`}, {175.555, 142.941}, {175.047, 
                    141.297}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{175.047, 
                    141.29700000000003`}, {172.375, 139.691}, {168.125, 
                    146.09}, {166.99200000000002`, 148.723}, {169.34, 
                    145.69899999999998`}, {175.555, 142.941}, {175.047, 
                    141.29700000000003`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    177.32000000000002`, 137.566}, {175.84, 
                    135.92600000000002`}, {171.184, 140.383}, {169.566, 
                    142.641}, {172.062, 140.48000000000002`}, {
                    177.97299999999998`, 140.22299999999998`}, {
                    177.32000000000002`, 137.566}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    177.32000000000002`, 137.566}, {175.84, 
                    135.92600000000002`}, {171.184, 140.383}, {169.566, 
                    142.641}, {172.062, 140.48}, {177.97299999999998`, 
                    140.223}, {177.32000000000002`, 137.566}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    179.85500000000002`, 134.22299999999998`}, {
                    179.36700000000002`, 131.984}, {172.57, 137.02}, {
                    170.98000000000002`, 139.406}, {173.914, 
                    136.64499999999998`}, {180.30100000000002`, 136.895}, {
                    179.85500000000002`, 134.22299999999998`}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    179.85500000000002`, 134.223}, {179.36700000000002`, 
                    131.984}, {172.57, 137.01999999999998`}, {
                    170.98000000000002`, 139.406}, {173.914, 
                    136.64499999999998`}, {180.30100000000002`, 136.895}, {
                    179.85500000000002`, 134.223}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{178.816, 
                    131.80100000000002`}, {177.766, 129.781}, {172.238, 
                    134.781}, {170.914, 137.39100000000002`}, {174.289, 
                    134.441}, {179.672, 133.797}, {178.816, 
                    131.80100000000002`}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{178.816, 
                    131.80100000000002`}, {177.766, 129.78100000000003`}, {
                    172.238, 134.78100000000003`}, {170.914, 
                    137.39100000000002`}, {174.289, 134.441}, {179.672, 
                    133.79700000000003`}, {178.816, 131.80100000000002`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{175.977, 
                    141.625}, {177.71899999999997`, 143.465}, {176.977, 
                    144.324}, {175.707, 147.22299999999998`}, {175.012, 
                    144.24599999999998`}, {173.961, 143.059}, {175.977, 
                    141.625}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{175.977, 
                    141.625}, {177.71899999999997`, 143.465}, {176.977, 
                    144.324}, {175.707, 147.223}, {175.012, 144.246}, {
                    173.961, 143.059}, {175.977, 141.625}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{178.289, 
                    138.15200000000002`}, {181.453, 138.012}, {
                    178.32000000000002`, 141.863}, {177.57, 145.094}, {
                    177.844, 141.41}, {176.758, 138.504}, {178.289, 
                    138.15200000000002`}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{178.289, 
                    138.152}, {181.453, 138.01199999999997`}, {
                    178.32000000000002`, 141.863}, {177.57, 145.094}, {
                    177.844, 141.41}, {176.758, 138.504}, {178.289, 
                    138.152}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{180.305, 
                    135.098}, {182.496, 135.59}, {181.863, 138.695}, {180.184,
                     142.44899999999998`}, {180.531, 138.39100000000002`}, {
                    178.32800000000003`, 136.047}, {180.305, 135.098}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{180.305, 
                    135.09799999999998`}, {182.496, 135.59}, {181.863, 
                    138.695}, {180.184, 142.44899999999998`}, {180.531, 
                    138.39100000000002`}, {178.32800000000003`, 136.047}, {
                    180.305, 135.09799999999998`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{179.559, 
                    128.961}, {178.73399999999998`, 126.49600000000001`}, {
                    172.5, 132.20299999999997`}, {171.508, 134.363}, {174.66, 
                    131.71499999999997`}, {180.117, 130.809}, {179.559, 
                    128.961}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{179.559, 
                    128.961}, {178.73399999999998`, 126.49600000000001`}, {
                    172.5, 132.203}, {171.508, 134.363}, {174.66, 131.715}, {
                    180.117, 130.809}, {179.559, 128.961}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{183.297, 
                    125.113}, {182.359, 122.648}, {175.824, 127.645}, {
                    173.824, 130.36700000000002`}, {177.762, 127.27}, {
                    183.777, 127.55499999999999`}, {183.297, 125.113}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{183.297, 
                    125.11299999999997`}, {182.359, 122.64799999999997`}, {
                    175.824, 127.64499999999998`}, {173.824, 
                    130.36700000000002`}, {177.762, 127.27000000000001`}, {
                    183.777, 127.555}, {183.297, 125.11299999999997`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{187.105, 
                    121.23}, {186.055, 117.79700000000001`}, {
                    179.22299999999998`, 123.281}, {177.184, 125.965}, {
                    181.535, 122.645}, {187.66, 123.67599999999999`}, {
                    187.105, 121.23}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{187.105, 
                    121.23000000000002`}, {186.055, 117.79700000000003`}, {
                    179.22299999999998`, 123.28100000000003`}, {177.184, 
                    125.965}, {181.535, 122.64499999999998`}, {187.66, 
                    123.67599999999999`}, {187.105, 121.23000000000002`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{180.68, 
                    130.055}, {182.535, 129.094}, {183.285, 134.363}, {
                    182.238, 138.08200000000002`}, {182.254, 134.023}, {
                    178.516, 131.008}, {180.68, 130.055}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{180.68, 
                    130.055}, {182.535, 129.094}, {183.285, 134.363}, {
                    182.238, 138.082}, {182.254, 134.023}, {178.516, 
                    131.00799999999998`}, {180.68, 130.055}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{183.848, 
                    125.871}, {186.078, 125.21100000000001`}, {185.371, 
                    130.88700000000003`}, {183.465, 134.57}, {
                    183.21899999999997`, 130.92200000000003`}, {
                    181.57399999999998`, 127.45700000000001`}, {183.848, 
                    125.871}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{183.848, 
                    125.87100000000001`}, {186.078, 125.21100000000001`}, {
                    185.371, 130.88700000000003`}, {183.465, 134.57}, {
                    183.21899999999997`, 130.922}, {181.57399999999998`, 
                    127.45700000000002`}, {183.848, 125.87100000000001`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{187.809, 
                    121.953}, {190.30100000000002`, 121.812}, {188.586, 
                    126.82}, {186.531, 129.641}, {186.879, 
                    125.95700000000001`}, {185.71899999999997`, 
                    122.37899999999999`}, {187.809, 121.953}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{187.809, 
                    121.953}, {190.30100000000002`, 121.81199999999998`}, {
                    188.586, 126.82}, {186.531, 129.641}, {186.879, 
                    125.95700000000002`}, {185.71899999999997`, 
                    122.37899999999999`}, {187.809, 121.953}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{183.441, 
                    119.816}, {182.691, 118.54700000000001`}, {180.859, 
                    120.895}, {177.85200000000003`, 122.60499999999999`}, {
                    180.555, 121.898}, {183.77299999999997`, 120.992}, {
                    183.441, 119.816}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{183.441, 
                    119.816}, {182.691, 118.547}, {180.859, 
                    120.89500000000001`}, {177.85200000000003`, 
                    122.60499999999999`}, {180.555, 121.898}, {
                    183.77299999999997`, 120.99199999999999`}, {183.441, 
                    119.816}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{182.016, 
                    162.008}, {184.34, 163.727}, {182.566, 166.945}, {182.016,
                     170.008}, {181.26999999999998`, 167.105}, {179.297, 
                    163.297}, {182.016, 162.008}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{182.016, 
                    162.00799999999998`}, {184.34, 163.72700000000003`}, {
                    182.566, 166.945}, {182.016, 170.00799999999998`}, {
                    181.26999999999998`, 167.105}, {179.297, 
                    163.29700000000003`}, {182.016, 162.00799999999998`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    181.93800000000002`, 157.71899999999997`}, {178.441, 
                    158.141}, {178.969, 162.656}, {178.863, 165.52}, {179.914,
                     161.63299999999998`}, {182.777, 160.977}, {
                    181.93800000000002`, 157.71899999999997`}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    181.93800000000002`, 157.719}, {178.441, 158.141}, {
                    178.969, 162.656}, {178.863, 165.51999999999998`}, {
                    179.914, 161.63299999999998`}, {182.777, 160.977}, {
                    181.93800000000002`, 157.719}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    182.48800000000003`, 158.305}, {185.441, 158.477}, {
                    185.285, 161.836}, {185.445, 165.238}, {183.945, 
                    162.11299999999997`}, {182.172, 161.629}, {
                    182.48800000000003`, 158.305}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    182.48800000000003`, 158.305}, {185.441, 158.477}, {
                    185.285, 161.836}, {185.445, 165.238}, {183.945, 
                    162.11299999999997`}, {182.172, 161.629}, {
                    182.48800000000003`, 158.305}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    182.36700000000002`, 154.129}, {180.07, 153.945}, {
                    178.875, 156.20299999999997`}, {178.348, 
                    159.72299999999998`}, {180.52700000000002`, 
                    156.48000000000002`}, {182.512, 157.48800000000003`}, {
                    182.36700000000002`, 154.129}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    182.36700000000002`, 154.129}, {180.07, 153.945}, {
                    178.875, 156.203}, {178.348, 159.723}, {
                    180.52700000000002`, 156.48}, {182.512, 157.488}, {
                    182.36700000000002`, 154.129}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{183.191, 
                    154.406}, {186.148, 154.02700000000002`}, {185.676, 
                    157.469}, {185.555, 160.004}, {184.65200000000002`, 
                    157.586}, {182.24599999999998`, 156.824}, {183.191, 
                    154.406}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{183.191, 
                    154.406}, {186.148, 154.02700000000002`}, {185.676, 
                    157.469}, {185.555, 160.004}, {184.65200000000002`, 
                    157.586}, {182.24599999999998`, 156.824}, {183.191, 
                    154.406}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{178.586, 
                    155.863}, {178.82000000000002`, 153.617}, {180.238, 
                    149.758}, {182.523, 150.625}, {183.469, 153.383}, {
                    180.516, 153.934}, {178.586, 155.863}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{178.586, 
                    155.863}, {178.82000000000002`, 153.617}, {180.238, 
                    149.758}, {182.523, 150.625}, {183.469, 153.383}, {
                    180.516, 153.934}, {178.586, 155.863}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{183.23, 
                    150.383}, {182.207, 152.35500000000002`}, {185.555, 
                    153.34}, {186.266, 155.89800000000002`}, {186.672, 
                    152.23399999999998`}, {186.33200000000002`, 
                    149.83200000000002`}, {183.23, 150.383}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{183.23, 
                    150.383}, {182.207, 152.35500000000002`}, {185.555, 
                    153.34}, {186.266, 155.898}, {186.672, 152.234}, {
                    186.33200000000002`, 149.832}, {183.23, 150.383}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    173.70299999999997`, 173.727}, {175.54299999999998`, 
                    175.71099999999998`}, {173.918, 178.85200000000003`}, {
                    173.36700000000002`, 181.914}, {172.621, 179.012}, {
                    171.324, 175.164}, {173.70299999999997`, 173.727}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    173.70299999999997`, 173.72700000000003`}, {
                    175.54299999999998`, 175.711}, {173.918, 178.852}, {
                    173.36700000000002`, 181.914}, {172.621, 
                    179.01199999999997`}, {171.324, 175.164}, {
                    173.70299999999997`, 173.72700000000003`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{173.648, 
                    170.039}, {170.418, 169.71099999999998`}, {169.637, 
                    176.285}, {169.305, 179.10899999999998`}, {
                    170.35500000000002`, 175.22299999999998`}, {174.078, 
                    173.445}, {173.648, 170.039}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{173.648, 
                    170.039}, {170.418, 169.711}, {169.637, 
                    176.28500000000003`}, {169.305, 179.10899999999998`}, {
                    170.35500000000002`, 175.223}, {174.078, 173.445}, {
                    173.648, 170.039}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{174.312, 
                    170.105}, {176.594, 171.285}, {176.066, 173.824}, {
                    176.781, 175.73}, {175.24599999999998`, 
                    173.39100000000002`}, {173.848, 173.055}, {174.312, 
                    170.105}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{174.312, 
                    170.105}, {176.594, 171.28500000000003`}, {176.066, 
                    173.824}, {176.781, 175.73000000000002`}, {
                    175.24599999999998`, 173.39100000000002`}, {173.848, 
                    173.055}, {174.312, 170.105}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{173.672, 
                    165.80100000000002`}, {170.29299999999998`, 165.512}, {
                    168.277, 172.789}, {168.172, 175.656}, {
                    169.22299999999998`, 171.766}, {174.066, 169.656}, {
                    173.672, 165.80100000000002`}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{173.672, 
                    165.80100000000002`}, {170.29299999999998`, 
                    165.51199999999997`}, {168.277, 172.78900000000002`}, {
                    168.172, 175.656}, {169.22299999999998`, 
                    171.76600000000002`}, {174.066, 169.656}, {173.672, 
                    165.80100000000002`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    174.32000000000002`, 165.91}, {177.5, 
                    166.64499999999998`}, {177.117, 168.69899999999998`}, {
                    176.641, 172.02700000000002`}, {175.629, 168.676}, {
                    173.85500000000002`, 169.38700000000003`}, {
                    174.32000000000002`, 165.91}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    174.32000000000002`, 165.91}, {177.5, 
                    166.64499999999998`}, {177.117, 168.69899999999998`}, {
                    176.641, 172.02700000000002`}, {175.629, 168.676}, {
                    173.85500000000002`, 169.38700000000003`}, {
                    174.32000000000002`, 165.91}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    173.63299999999998`, 161.602}, {169.914, 160.969}, {
                    170.176, 166.848}, {167.227, 171.11299999999997`}, {
                    169.777, 167.945}, {174.375, 163.953}, {
                    173.63299999999998`, 161.602}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    173.63299999999998`, 161.60199999999998`}, {169.914, 
                    160.969}, {170.176, 166.84799999999998`}, {167.227, 
                    171.11299999999997`}, {169.777, 167.945}, {174.375, 
                    163.953}, {173.63299999999998`, 161.60199999999998`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    174.47299999999998`, 161.80100000000002`}, {177.277, 
                    161.71899999999997`}, {177.55100000000002`, 165.941}, {
                    177.395, 167.656}, {176.75, 165.94899999999998`}, {
                    173.453, 164.32800000000003`}, {174.47299999999998`, 
                    161.80100000000002`}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    174.47299999999998`, 161.80100000000002`}, {177.277, 
                    161.719}, {177.55100000000002`, 165.941}, {177.395, 
                    167.656}, {176.75, 165.94899999999998`}, {173.453, 
                    164.328}, {174.47299999999998`, 161.80100000000002`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{167.824, 
                    166.129}, {169.21899999999997`, 161.605}, {171.195, 
                    157.07}, {173.63299999999998`, 157.414}, {
                    174.80100000000002`, 159.98800000000003`}, {
                    171.32000000000002`, 160.316}, {167.824, 166.129}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{167.824, 
                    166.129}, {169.21899999999997`, 161.605}, {171.195, 
                    157.07}, {173.63299999999998`, 157.414}, {
                    174.80100000000002`, 159.988}, {171.32000000000002`, 
                    160.316}, {167.824, 166.129}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{174.512, 
                    158.078}, {173.48800000000003`, 160.05100000000002`}, {
                    176.836, 161.035}, {177.547, 163.598}, {177.953, 
                    159.934}, {177.61299999999997`, 157.52700000000002`}, {
                    174.512, 158.078}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{174.512, 
                    158.07799999999997`}, {173.48800000000003`, 
                    160.05100000000002`}, {176.836, 161.035}, {177.547, 
                    163.59799999999998`}, {177.953, 159.934}, {
                    177.61299999999997`, 157.52700000000002`}, {174.512, 
                    158.07799999999997`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{168.785, 
                    160.961}, {170.77299999999997`, 156.88700000000003`}, {
                    171.672, 152.20299999999997`}, {174.40200000000002`, 
                    152.883}, {175.42200000000003`, 156.05100000000002`}, {
                    171.38700000000003`, 156.71499999999997`}, {168.785, 
                    160.961}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{168.785, 
                    160.961}, {170.77299999999997`, 156.88700000000003`}, {
                    171.672, 152.203}, {174.40200000000002`, 152.883}, {
                    175.42200000000003`, 156.05100000000002`}, {
                    171.38700000000003`, 156.715}, {168.785, 160.961}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{174.969, 
                    153.656}, {173.79299999999998`, 155.812}, {
                    177.14499999999998`, 156.57399999999998`}, {177.965, 
                    159.547}, {178.41, 155.656}, {177.99200000000002`, 
                    152.883}, {174.969, 153.656}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{174.969, 
                    153.656}, {173.79299999999998`, 155.81199999999998`}, {
                    177.14499999999998`, 156.57399999999998`}, {177.965, 
                    159.547}, {178.41, 155.656}, {177.99200000000002`, 
                    152.883}, {174.969, 153.656}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{180.695, 
                    181.238}, {182.656, 180.71099999999998`}, {
                    184.71499999999997`, 182.91}, {184., 186.207}, {181.758, 
                    185.648}, {180.73, 183.61299999999997`}, {180.695, 
                    181.238}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{180.695, 
                    181.238}, {182.656, 180.711}, {184.71499999999997`, 
                    182.91}, {184., 186.20700000000002`}, {181.758, 
                    185.64799999999997`}, {180.73, 183.61299999999997`}, {
                    180.695, 181.238}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC0c0HTi08m+qw+uMl36Q7aQ5xuzx5mC6nOszI
E2o+sC/NwTHh6QWl76kODCCwJ82h0Jbr+uI3qQ57SyZLsDxLc5CNSrG+/xgq
z5Hu8LbG3jTuUaqD/l0VtkbFdLj61teBO+Rs0x22nijbN/9XKkRffDrEnG+p
DtUi69wfzkp3KM6Y+LbmdapDEYjenO5w+2dd1p4HqQ4+5p2OCWfTHQxA5u5N
dQCaWmC7Lx3i7jOpDjfPfQ9+vDLd4Q5I/R2o/CSo+rupDiDj7BOh7ruU6vAO
RHulO4Ty6W6aezjVoXc60MMa6Q5hIP7xVAj9O80BPXwAlGyLqw==
                    
                    "]]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC0c0HTi08m+qw+uMl36Q7aQ5xuzx5mC6nOszI
E2o+sC/NwTHh6QWl76kODCCwJ82h0Jbr+uI3qQ57SiZLsDxLc5CNSrG+/xgq
z5Hu8LbG3jTuUaqD/l0VtkbFdLj61teBO+Rs0x22nijbN/9XKkRffLrDXpA5
31IdqkXWuT+cle5QnDHxbc3rVIciEL053eH2z7qsPQ9SHbzNOx0TzqY7GIDM
3ZvqADS1wHZfOsTdZ1Idbp77Hvx4ZbrDHZD6O1D5SVD1d1MdQMbZJ0LddynV
4R2I9kp3COXT3TT3cKpD33SghzXSHcJA/OOpEPp3mgN6+AAAkxSLqg==
                    
                    "], CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4thdnjxM4hkO++dL6d91SXWYkSfUfOBfukPG
xLc19oqpEPpsugNYnXmqQxyI/pzuwAACGakON899D34smOEQzqe7aW5/qsPe
kskSLHYZEPkNUP2OGQ6LXLd9/nsj1cFyy4myfc5Q+3jSHLiuLy6wTcpwsAKJ
R6dB9NdlQMTL0hy2AoXnz8qA0JPSHMJA9uzOgLgzKw1i7pwMB5moFOv74VD1
VRkOws0HTi10THNY9fGSb1JKhsM3jZj+Q09THVpfB+6QS81wuKh0+2fdoVQH
WZC+5AwHVbbGqc5A94PdZZDhwA2yPyvVAT18ADOmhG0=
                    "]]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4thdnjxM4hkO++ZL6d91SXWYkSfUfOBfukPG
xLc19oqpEPpsukMcSJ15KoT+nO7AAAIZqQ43z30PfiyY4RDGp7tpbn+qw96S
yRIsdhkQ+Q1Q/Y4ZDotdt33+eyPVwXLLibJ9zlD7eNIcuK4vLrBNynCwAolH
p0H012VAxMvSHLYChefPynAASc+flAaxZ3cGxJ1ZaQ6LQObOyXCQjUqxvh8O
VV+V4SDcfODUQsc0h1UfL/kmpWQ4fNWI6T/0NNWh9XXgDrnUDIcLSrd/1h1K
hehLznBQZWuc6gx0/36Quwyg9melOqCHDwAx7oRo
                    "], 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4hl5Qs0HTqU7cF1fXGBbl+pwUen2z7pN6Q6X
QHRUqoNsVIr1/e50B1W2xqnO+akO3zRi+g8tTHfonQ7UuCLV4Zi3eafjlnSH
x0tnH1G4kAoxZ1u6Q8bEtzX2jGkO1SLr3B/CzJdLcwjj090093m6AzeI75Xm
sOrjJd8kiQyIurw0iDkmGQ4gYxM60xyArsjaE5ABsXdpGsTejAyHdzX2pnFd
aRBz/TIc1A051sgUpTm8BYnrZUDEg9IcrLacKNvHneGwFUjN10pzKLAFyvxI
d+gDmcMDNf9KOkT/pVSI+U/SHUJB7lyc6oAePgBisIf1
                    "]]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4hl5Qs0HTqU7cF1fXGBbl+pwUen2z7pN6RA6
KtVBNirF+n53uoMqW+NU5/xUh28aMf2HFqY79E0HalyR6nDM27zTcUu6w+Ol
s48oXEiFmLMt3SFj4tsae8Y0h2qRde4PYebLpTmE8elumvscyvdKc1j18ZJv
kkQGRF1eGsQckwwHH6CxCZ1pDkBXZO0JyHD4CrJ3aZpDL8jejAyHdzX2pnFd
aRBz/DIc1A051sgUpTm8BYnrZUDEg9IcrLacKNvHneEAouZrpTkU2AJlfkDd
zwM1/0o6RP+lVIj5T9IdQkHuXJzqgB4+AGGgh/M=
                    "], 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYCYsstJ8r2mac5TM8Taj5gluawf76U/l2TNIdV
Hy/5JrGkORjcVWFrjE1zOO5t3un4I9UhjE9309zoNIeMiW9r7B3THG6e+x78
OBKqrjfNQTYqxfq+cpqDKlvjVOfLaQ6LXLd9/usC5bunOwB1mcaFpTkwgEBD
ugPI+vlA/uOls48ovEiH0D5pDhMOfdWIkc9wqBZZ5/7QKc2B6/riAtuwDIj5
0mkQc4wyHLaC9GulQdzFnuEQt8uTh8k6zUHdkGONzLV0iLh6moNjwtMLSuXp
Dk4gGqi/H2Q+0D1AX59a+DUV4r89aQ4u3TnPf1umOfSCAqQizQE9fAAfS4EP

                    "]]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYCYsstJ8r2mac5zMgTaj5gluawf76U/l2TNIdV
Hy/5JrGkORjcVWFrjE1zOO5t3un4I9UhjE9309zoNIeMiW9r7B3THG6e+x78
ODLNQR+krjfNQTYqxfq+cpoDkDfV+XKawyLXbZ//uqQ5qIH47ukOQF2mcWFp
Dgwg0JDuALJ+PpD/ZOnsIwov0h0eg2ifNIcJh75qxMhnOFSLrHN/6JTmwHV9
cYFtWAbEfOk0h3cgc4wyHLaC9GulQdzFnuEQt8uTh8k6zUHdkGONzLV0iLh6
moNTwtMLSuXpEFoaaj7QPUBfn1r4NRXivz1pDi7dOc9/W6Y59E0HBkhFmgN6
+AAAITuBFQ==
                    "], CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4rc19qZxy9IcMiYCWb7pDr3T84SaF6Q5xO3y
5GGST4eIV6Y5zAAKH5BKdyiw5bq+uCXN4bi3eadjTLqDuiHHGpm+NAcQN2Fi
uoPVlhNl+/qh5u1EqAeb+yTdwQekrjTN4ZLS7Z91UhkQuirNASR9oCzD4ea5
78GPW9McWl8H7pCbm+Ggf1eFrXFimsM3jZj+Q0czHGSiUqzvb09z2FsyWYJl
XYaDJci+5WkOQFsKbPsyIOLToO7JzHBY5Lrt898paQ53ftZl7ZHJgLhrYRpE
/AfUfxvTHB4vnX1E4Ui6w/75Uvp310DNr0t3gIUP2N3A8AEAehyKbA==
                    
                    "]]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4rc19qZxy9IcMiYCWb7pDr3T84SaF6Q5xO3y
5GGST4eIV6Y5zAAKH5BKdyiw5bq+uCXN4bi3eadjTLqDuiHHGpm+NAcQN2Fi
uoPVlhNl+/rTHDJB+nYi1IPNfZLu4ANSV5rmcEnp9s86qQwIXQU1vyzD4ea5
78GPW9McWl8H7pCbm+Ggf1eFrXFimsM3jZj+Q0czHGSiUqzvb09z2FMyWYJl
XYaDJci+5WkOQFsKbPsyHPaCxKelQezJzHBY5Lrt898paQ53ftZl7ZHJgPhn
YZrDYpD4D6j/NqY5PF46+4jCkXSH/fOl9O+ugZpfl+4ACx+w/4DhAwB7lIpt

                    "], CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4sdLZx9RkEh1EG4+cGrhzGSH4oyJb2u0Ux0u
Kt3+WdeU7ACW90l1cOnOef57YrLD2xp70zi9VAeQMvuNyQ57SyZLsIilOlwC
qT8F5ctB9V9KdnBMeHpBiR+q/mOyQ+/0PKFmhlSHUD7dTXOFUyDijKkOW06U
7ZuvlgKx/30KRJ99ioMVSOJ+isMFkHlhKRD3nEhx2ApSb5fiwAACN1IcnEDq
tVMcZKNSrO+/htJA88HufZbiMANo7QGmFIi7PqU4rP54yTfpTbLDvvlS+nc5
Uh1unvse/PhoskMRyH7mVIdvGjH9hzZC/Y8UPgCcGY/J
                    "]]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4sdLZx9RkEh1EG4+cGrhzGSH4oyJb2u0Ux0u
KN3+WdeU7ACW90l1cO7Oef57YrLD2xp70zi9VAeQMvuNyQ57SyZLsIilOlwE
qT8F5ctB9V9KdnBMeHpBiR+q/mOyQ+/0PKFmhlSHUD7dTXOFUyDijKkOW0+U
7ZuvlgKx/30KRJ99ioPVFqDE/RSI+WEpEPecSIGot0txYACBG1D12ikOslEp
1vdfQ2mg+WD3PktxmAG09gAT1JxPKQ6rP17yTXqT7LBvvpT+XY5Uh5vnvgc/
PprsUASynznV4ZtGTP+hjVD/I4UPAJkBj8Y=
                    "], 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{185.07, 137.11299999999997`}, {187.023, 
                    136.15200000000002`}, {188.504, 133.754}, {188.602, 
                    131.805}, {188.76999999999998`, 129.555}, {189.09, 
                    127.66}, {190.102, 126.062}, {188.496, 126.508}, {187.727,
                     129.07}, {187.496, 131.523}, {187.266, 134.059}, {
                    185.89800000000002`, 135.16}, {185.07, 
                    137.11299999999997`}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{185.07, 137.11299999999997`}, {187.023, 
                    136.152}, {188.504, 133.75400000000002`}, {188.602, 
                    131.805}, {188.76999999999998`, 129.555}, {189.09, 
                    127.66}, {190.102, 126.06199999999998`}, {188.496, 
                    126.50799999999998`}, {187.727, 129.07}, {187.496, 
                    131.523}, {187.266, 134.059}, {185.89800000000002`, 
                    135.16}, {185.07, 137.11299999999997`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{189.137, 132.406}, {190.48800000000003`, 
                    129.914}, {192.375, 128.965}, {192.47299999999998`, 
                    127.113}, {192.637, 124.98400000000001`}, {192.797, 
                    124.87899999999999`}, {193.375, 122.785}, {191.785, 
                    123.20700000000001`}, {191.383, 123.348}, {190.953, 
                    126.531}, {190.691, 128.76999999999998`}, {
                    188.89800000000002`, 130.348}, {189.137, 132.406}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{189.137, 132.406}, {190.48800000000003`, 
                    129.914}, {192.375, 128.965}, {192.47299999999998`, 
                    127.11299999999997`}, {192.637, 124.98400000000001`}, {
                    192.797, 124.87899999999999`}, {193.375, 
                    122.78500000000003`}, {191.785, 123.20700000000002`}, {
                    191.383, 123.34799999999998`}, {190.953, 126.531}, {
                    190.691, 128.77}, {188.89800000000002`, 
                    130.34799999999998`}, {189.137, 132.406}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{231.176, 
                    109.34400000000001`}, {231.934, 107.91400000000002`}, {
                    232.805, 105.73400000000001`}, {234.38700000000003`, 
                    106.133}, {234.41, 107.23}, {232.68, 107.988}, {231.176, 
                    109.34400000000001`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    233.52700000000002`, 108.85499999999999`}, {236.598, 
                    107.598}, {239.24599999999998`, 107.91000000000001`}, {
                    239.57399999999998`, 105.98}, {236.69899999999998`, 
                    105.66799999999999`}, {235.64499999999998`, 
                    106.85199999999999`}, {233.52700000000002`, 
                    108.85499999999999`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{220.68, 119.008}, {222.74599999999998`, 
                    117.316}, {224.086, 115.383}, {224.71099999999998`, 
                    112.887}, {225.363, 110.559}, {226.281, 108.703}, {
                    227.625, 106.613}, {225.434, 108.10499999999999`}, {
                    224.059, 110.141}, {223.36700000000002`, 112.586}, {
                    222.762, 114.992}, {222.05100000000002`, 116.793}, {
                    220.68, 119.008}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{223.22299999999998`, 119.016}, {
                    225.43800000000002`, 117.24600000000001`}, {
                    227.52700000000002`, 115.242}, {228.15200000000002`, 
                    112.742}, {228.805, 110.418}, {229.19899999999998`, 
                    108.637}, {230.691, 106.324}, {228.35200000000003`, 
                    107.816}, {227.42200000000003`, 110.074}, {
                    226.73399999999998`, 112.52}, {226.129, 114.926}, {
                    224.742, 116.727}, {223.22299999999998`, 119.016}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4tbXgTvkLuY4NB84tdDVL8ZBla1xqvP5HAeu
64sLbLNiHG79rMvacyPHYUaeUPOBphiHY97mnY5Pchycu3Oe/+6Mcdh6omzf
/F9Q+VkxDotct33+K5Dr0DsdKLAixsEx4ekFJfVch4Ug8S0xDqs+XvJNcsh1
kNa/q8J2MMbhotLtn3V+uRB9c6DmAfkZE9/W2LfGQMwF8r9pxPQfio1xCOfT
3TTXP9dBdJ37wyobhHovHibtdrkYiD7fXAegaVcqfkY7CIM85pnrIAfy6Ldo
h5vnvgc/toXa/zHaIW6XJ1BnrgPIuQdeRUPsE8p18EsSiLB8Eu1gtQVowf8c
h1iQutPRDrdB4fEhB+K/HdGQcHqU4wD05e2fx6D6b+U4FIMc8hxq39Uch+Og
cGOAhu/lHIj9hjEO6OEPAG3WvnI=
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4oyJb2vsH+Y6NB84tdDVL8YhbpcnD9PjXAeu
64sLbLNiHML4dDfNvZ3rsNB12+e/LTEO3uadjgkXcx1E1rk/rOqJcfAB8ffm
OmSCzJkb46B/V4WtcWWuw8MqoIqFMQ690/OEmqfkOhSDLJof49D6OnCHXG2u
w3GQQQtiHFTZGqc6l+c6fNOI6T80NcbBMeHpBSUgf2/JZAmWuhiHWJB7gHw5
kMawGIi7ynIh5hog1M8Acg8IxTis+njJN6ki18EA5I630Q4MIADkg5QfeBXt
cFHp9s+6plwHsL+fRjv0H/qqETM510EeZP69aIi7NuQ6LAL59040xL0Hcx02
zX2//NjhaIetJ8r2zT8H9d/GaIg77+VC7DkAlb8Hdc+jaAegLaZx96Dm/YmG
hMP9XAdpUEAZxjighz8ADGG3Xg==
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4p1yra8DlQod9s2X0r8bkerweOnsIwpGhQ5h
fLqb5nanOixy3fb5r0uhw0Wl2z/rhFIdGECgrdDhuLd5p+OOFIdjIHpJoYNj
wtMLSv0pDlEp1vf9dxY66N9VYWtUTIHQQH7GxLc19jeTIebsKnSw3HKibN/y
ZIfpeULNB7YVOnBdX1xgW5YMVw/muyVD9O0uhNirkewwWYIljO90oUOBLVDF
kySI/QcKHfoPfdWIuZzk4P6wSmTdYqh/ViQ5gKyZX1fosOrjJd8kjyQHA5D5
uYUOsbs8eZjUofJxhRB/8iQ5WIEEAgsdfIDGJqyFyrsVOgBDaYfc1ySHZcDg
2WBV6KBuyLFGxikZ4i6HQoe9JUCXzUt2yHn+e+VHOaj6p8kOIGcWsEP5otDw
OlMAoV1SHKpF1rk/vFTgINx84NTCyBQHAD+Yrl4=
                    "]]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4p1yra8DlQod9s+X0r8bkerweOnsIwpGhQ5h
fLqb5nanOixy3fb5r0uhwwWl2z/rhFIdGECgrdDhuLd5p+OOFIdjIHpJoYNj
wtMLSv0pDlEp1vf9dxY66N9VYWtUTIHQQH7mxLc19jeTHS6CzNlV6GC55UTZ
vuXJDtPzhJoPbCt04Lq+uMC2LBmuHsx3S3bIAOnbXQixVyPZYbIESxjf6UKH
AlugiidJEPsPFDr0H/qqEXM5ycH9YZXIusVQ/6xIcgBZM7+u0GHVx0u+SR5J
DgYg83MLHeJ2efIwqUPl4woh/uRJcrACCQQWOoCMTVgLlXcrdACG0g65r0kO
y4DBs8Gq0EHdkGONjFMyxF0OhQ57SoAum5fskPP898qPclD1T5MdQM4sYIfy
RaHhdaYAQrukOFSLrHN/eKnAQbj5wKmFkSkOAEFwrl8=
                    "], 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[0.74902, 0., 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGI9IGYCYuHmA6cWqhY6yEalWN8/n+xw+KtGTL9WocMF
pds/654lQ8QNCx32lkyWYPmX7NDpmPD0glWhA9f1xQW2QikOlltOlO1zhqpX
S3F4W2NvGudX6BDGp7tprnmKw6dLvkkCUVDz7VMcQJR/aqHDcW/zTkePFIh5
BYUOTkBKKRjKryh0AFFK6VB+TaHDItdtn/8WpDjskGt9HdhQ6AB2d22KAwMI
NBU6FNoCXdST4iAEEm8udNgKdNb8WQg+2D2rUxwe+PdOz2uCmr8/xUGrXezm
uWao+XtSHA6B/N9S6DAjD6hzF9T8tkKHApD5O1IcjoHcvaTQoThj4tua/hQH
kHDBTqh7FFMgNJCvf1eFrfFmMkT/Lij/aDIkPIB8dUOONTKbkuHqweE5L9kB
ZHzC9kKHm+e+Bz+emOwAssZ+a6HDN6CzDrVCzdsEVV8HjZ+1hQ5AXwk1lyQ7
VIusc3+4AhpfeckQ/y+G2p+Z7AAUDeObCVWfkOyQ+/z3yo890PCKg7qnEWp+
WLIDKNjel0LN84PyM6HxZQ01Px4aPirJDtqg8AwtdFBla5zqzJ8MCS9gegAl
k/nfkiD+8YTG14MkSHrxKHSoArn7GVTevdDh8dLZRxQ+JDncB8WXG9T9X5Mg
9lkj7DcAidtC01MP1P1I6RkA3wVEIA==
                    "]]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGI9IGYCYuHmA6cWqhY6yEalWN8/n+xw+KtGTL9WocNF
pds/654lQ8QNCx32lEyWYPmX7NDpmPD0glWhA9f1xQW2QikOlltOlO1zhqpX
S3F4W2NvGudX6BDGp7tprnmKw6dLvkkCUVDz7VMcQJR/aqHDcW/zTkePFIh5
BYUOIEopGMqvKHRwAvHTofyaQodFrts+/y1Icdgh1/o6sKHQAezu2hQHBhBo
KnQotAW6qCfFQQgk3lzoAHLW/FkIPtg9q1McHvj3Ts9rgtq3P8VBq13s5rlm
qPl7UhwOgfzfUugwIw+ocxfU/Dao+TtSHI6B3L2k0KE4Y+Lbmv4UB5BwwU6o
exRTIDSQb3BXha3xZjJE/65CBz0Q/2gyJDyAfHVDjjUym5Lh6sHhOS/ZAWR8
wvZCh5vnvgc/npjsALLGfmuhA8hZh1qh5m2Cqq+Dxs/aQgegr4SaS5IdqkXW
uT9cAY2vvGSI/xdD3ZOZ7AAUDeObCVWfkOyQ+/z3yo89hQ5bQeEVB3VPI9T8
sGQHULC9L4Wa5wflZ0LDzxpqfnyhQwEoIFSSHbRB4Rla6KDK1jjVmT8ZEl5+
UPO/JUH84wlV/yAJkl48CiHufgaVdy90eLx09hGFD0kO90Hx5QYNv69JEPus
EfaD/WULTU89UPcjpWcA3r1EHQ==
                    "], CurveClosed -> {1}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    280.14500000000004`, 166.09}, {280.53099999999995`, 
                    163.402}, {279.03499999999997`, 162.51199999999997`}, {
                    277.625, 161.988}, {276.16400000000004`, 
                    161.47299999999998`}, {274.969, 159.906}, {
                    274.35200000000003`, 158.488}}}, CurveClosed -> {0}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{283.762, 
                    157.246}, {283.14500000000004`, 154.934}, {
                    281.52299999999997`, 155.223}, {280.10900000000004`, 
                    154.703}, {278.65200000000004`, 154.184}, {277.113, 
                    152.336}, {276.5, 150.922}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    275.512, 172.414}, {274.77299999999997`, 
                    172.89100000000002`}, {260.57, 148.97299999999998`}, {
                    261.309, 148.496}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    275.512, 172.414}, {274.77299999999997`, 
                    172.89100000000002`}, {260.57, 148.97299999999998`}, {
                    261.309, 148.496}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{273.984, 173.36700000000002`}, {273.984, 
                    172.512}, {274.76599999999996`, 171.73}, {275.621, 
                    171.73}, {276.477, 171.73}, {277.258, 172.512}, {277.258, 
                    173.36700000000002`}, {277.258, 174.227}, {276.477, 
                    175.004}, {275.621, 175.004}, {274.76599999999996`, 
                    175.004}, {273.984, 174.227}, {273.984, 
                    173.36700000000002`}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{273.984, 173.36700000000002`}, {273.984, 
                    172.51199999999997`}, {274.76599999999996`, 
                    171.73000000000002`}, {275.621, 171.73000000000002`}, {
                    276.477, 171.73000000000002`}, {277.258, 
                    172.51199999999997`}, {277.258, 173.36700000000002`}, {
                    277.258, 174.22700000000003`}, {276.477, 175.004}, {
                    275.621, 175.004}, {274.76599999999996`, 175.004}, {
                    273.984, 174.22700000000003`}, {273.984, 
                    173.36700000000002`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    256.08599999999996`, 192.586}, {261.84, 192.586}, {261.84,
                     191.26600000000002`}, {256.08599999999996`, 
                    191.26600000000002`}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    256.08599999999996`, 192.58599999999998`}, {261.84, 
                    192.58599999999998`}, {261.84, 191.266}, {
                    256.08599999999996`, 191.266}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    256.08599999999996`, 190.078}, {261.84, 190.078}, {261.84,
                     179.055}, {256.08599999999996`, 179.055}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    256.08599999999996`, 190.07799999999997`}, {261.84, 
                    190.07799999999997`}, {261.84, 179.05499999999998`}, {
                    256.08599999999996`, 179.05499999999998`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    262.191, 194.09}, {255.809, 194.05100000000002`}, {
                    255.559, 196.21499999999997`}, {257.719, 198.555}, {
                    258.97999999999996`, 198.531}, {260.227, 198.469}, {
                    262.242, 196.164}, {262.191, 194.09}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    262.191, 194.08999999999997`}, {255.809, 194.051}, {
                    255.559, 196.215}, {257.719, 198.555}, {
                    258.97999999999996`, 198.531}, {260.227, 198.469}, {
                    262.242, 196.164}, {262.191, 194.08999999999997`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {CompressedData["
1:eJxTTMoPSmViYGBQBmIQvX++lP7dPXkOfdPzhJpzMhxko1Ks7z/Oc3i8dPYR
hZgMh28aMf2HGPMdwvl0N83Vz4CIi+RD1P9Jd7igdPtnnVq+g7d5p2PCyXQH
g7sqbI26+Q6qbI1TnfvTHcDmq+Q79ILUJyD4VltOlO2LT3cQbj5waqEi1Hz/
dIeMiW9r7GXzHRhAwCUdYp8EVL11ukPcLk8eJuF8hyKQQuN0Bx+Qvbz5DluB
0vP1oO5hy4eI66ZD9P2H+kcnHeLOn3kQcf10iP++5kHUm6Y7qBtyrJH5lAex
B2jfcZCGD3kOQFeZxjlB3f8BKu+d7lBgy3V98RcovzrdYdXHS75JQP4lkDtW
pTvsA6l/ATX/KjR87uZBzGXIcAA5Y/4xqPlqGRDz50DVu2ZA6Kl5DtUi69wf
emU4LHLd9vnvhDxIOAVC4wPItwQZFJ4BDfc8B6CrCmzjMiDhMikPEq/JGQ5A
z2rETIeqT89wKAS5f0GeQzHIwPwMhwkg+fV5kHAogroHKX0AAM/u82U=
                    
                    "], CompressedData["
1:eJxTTMoPSmViYGBQAmIQvW++lP7dHXkO3uadjgmJGQ7FGRPf1qzPcwBR9qkZ
Dv2HvmrELM5ziNvlycOUnOFwUen2z7p5UH58hsPjpbOPKMzJc9gPMicmw0E2
KsX6/uw8iDnRCHmw+ZEZDn3T84SagXzHhKcXlMIzHNQNOdbIAM0D2xMMVb8E
ar5/hgMDCFzIcwC6xjRODyr/Is9B/64KWyMrlP8lz6EXZO6NdAifId8hjE93
09zV6RD3/M9zqBZZ5/6wCir/Jw9ir1c6RN3vPIcikHud0x0MQOb+zYP40y7d
YQLIXUD9VltOlO2zTndofR24Q44x32GR67bPfy3SIeYw5UPMtYCaz5IPcQ+Q
z3V9cYEtW74DOJyB/Esgc7nyIeEDNA9sD18+xByndIetQGvmC+U73PpZl7XH
I90BZO18sXxIeASnO3zTiOk/JAlVnwTlK+Y77C2ZLMHSB9Uvle+gytY41fl4
OsReDqh7fqRDwv17nsPNc9+DH2tmOMwACh+4lefgBBIHhj96egAAMkbv9g==

                    "]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxlk1tIVFEUhoeRJEosNCpiNBNN7aYF3YzBZQURpV3EQpvEpFqbsFUR+JAl
iBR0sZJIh2KcLCLSqIgC6TKJBJmIiURZJhERPUQPPVSID7X3Wb8UNHA4HPba
//rW/6+ZU3Vg6544n8/nt89svFdXfh5IrxXKWjzxViDf0NrT1V/G2oR+ZofO
decY8s4fCZ3v/pEd+s30brRu3+Meodppt9d97Gea9ObaweBroW9HC5ZWtDK1
fx8sqhoSOuLO9zKllO9e9eGlUGOLJDWsYDJNtvKF0LbEhfciM5h87tcpqhPP
VOj63RBaeb+nJhbHFLbXulqh72caSB8erWsG3wSm3JGM+PomobNOP4H1fUYo
M77+4ppkVs5TQh2OK8CU5+oboZ+Ffi2Yvxj9Lgm97f9V8ukY+C+Ict9kOv51
S2eqvT/sfHiFc+vfYVcwxurXDviTZKjUzVki6stMo1ybRPukGp2rGPqZhjYu
P1lYWSSqO9/Q0+is3JHN8GeJ0XlLwbvMaJ8K8AaNzrdfKN/NV4D8/snX61cD
vkXQr8a31U9u6Opt24W88gy9d3OG4O8CQ5MdR7nQoMthnlHuMlFfcsBXhvzn
GuUqg18Zhp5vsANaPa9vGniqoB8wmu8J+OM3FHN1YdF7Q/A7Ct52pp0P1yf4
7b54c9u8Htixo1fBU4R9DY/7y+RsiTZDL/D33PNnOvK7PJ4f9iUitN3lOIXp
UNAmcQX1idi/66i3397/5A7ynop9ioEnhdWHZ6jPZ/WhD/vKrL72Is8I+j+B
P32sudwV5bT75s1h+T2utP/z/QOeprBY
                    "]]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    255.73, 170.09}, {262.152, 170.09}, {262.152, 161.203}, {
                    255.73, 161.203}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    255.73, 170.09}, {262.152, 170.09}, {262.152, 161.203}, {
                    255.73, 161.203}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    255.578, 156.121}, {261.777, 156.121}, {261.777, 
                    154.25400000000002`}, {255.57799999999997`, 
                    154.25400000000002`}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    255.578, 156.121}, {261.777, 156.121}, {261.777, 
                    154.25400000000002`}, {255.57799999999997`, 
                    154.25400000000002`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    255.58200000000002`, 152.84}, {261.93, 152.84}, {261.93, 
                    145.895}, {255.582, 145.895}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    255.58200000000002`, 152.84}, {261.93, 152.84}, {261.93, 
                    145.895}, {255.582, 145.895}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    255.434, 144.47299999999998`}, {262.375, 
                    144.47299999999998`}, {262.375, 140.58999999999997`}, {
                    255.434, 140.58999999999997`}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    255.434, 144.47299999999998`}, {262.375, 
                    144.47299999999998`}, {262.375, 140.58999999999997`}, {
                    255.434, 140.58999999999997`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    261.52, 157.79299999999998`}, {255.92600000000002`, 
                    157.79299999999998`}, {254.816, 159.641}, {
                    262.52299999999997`, 159.641}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    261.52, 157.793}, {255.92600000000002`, 157.793}, {
                    254.816, 159.641}, {262.52299999999997`, 159.641}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    253.977, 164.602}, {253.92200000000003`, 
                    169.45700000000002`}, {250.07, 169.45700000000002`}, {
                    251.58200000000002`, 168.207}, {252.99200000000002`, 
                    166.695}, {253.977, 164.602}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    253.977, 164.60199999999998`}, {253.92200000000003`, 
                    169.45700000000002`}, {250.07, 169.45700000000002`}, {
                    251.58200000000002`, 168.20700000000002`}, {
                    252.99200000000002`, 166.695}, {253.977, 
                    164.60199999999998`}}}, CurveClosed -> {1}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4gf+vdPzggocijImvq0JTnHQbhe7eS6wwIHr
+uICW6MUh9hdnjxM9gUOi1y3ff7rgOB/04jpPxSIJt+S4rB09hGFDXYFDn3T
84Sa96Q4uD+sElkHlL/9sy5rz4MUBy2Q+UB+GJ/uprm/oXz5Aod986X0735J
cWAAAYUCh1UfL/kmPUlxkIlKsb4PlG97HbhDbmeKg1DzgVML5aH216Y46N9V
YWsE8uNA7vBOcbDccqJsH5D/tsbeNA7o/k7HhKcXuAocekHuMUlxaAWZw41Q
D/K2PZAfCnJPM4J/89z34MdXEeqLQRL/Uxxyn/9e+RFoHljcNBViPzC8wO42
SXX4BHS2QBDUvwwI/lags+ZfS3GAhbcqW+NU524EHxb+ACCvraM=
                    "], 
                    CurveClosed -> {1}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    256.59, 152.016}, {261.145, 152.016}, {261.145, 146.34}, {
                    256.59, 146.34}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    256.625, 149.664}, {258.23, 149.664}, {258.23, 148.73}, {
                    256.625, 148.73}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    256.625, 149.664}, {258.23, 149.664}, {258.23, 148.73}, {
                    256.625, 148.73}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    259.465, 149.664}, {261.03099999999995`, 149.664}, {
                    261.03099999999995`, 148.73}, {259.465, 148.73}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    259.465, 149.664}, {261.03099999999995`, 149.664}, {
                    261.03099999999995`, 148.73}, {259.465, 148.73}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    258.22999999999996`, 151.945}, {259.46399999999994`, 
                    151.945}, {259.46399999999994`, 149.629}, {
                    258.22999999999996`, 149.629}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    258.22999999999996`, 151.945}, {259.46399999999994`, 
                    151.945}, {259.46399999999994`, 149.629}, {
                    258.22999999999996`, 149.629}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    258.22999999999996`, 148.76999999999998`}, {
                    259.46399999999994`, 148.76999999999998`}, {
                    259.46399999999994`, 146.30499999999998`}, {
                    258.22999999999996`, 146.30499999999998`}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    258.22999999999996`, 148.77}, {259.46399999999994`, 
                    148.77}, {259.46399999999994`, 146.305}, {
                    258.22999999999996`, 146.305}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{284.809, 
                    208.824}, {284.52299999999997`, 204.371}, {
                    285.90599999999995`, 201.92600000000002`}, {
                    288.26599999999996`, 202.297}, {288.914, 
                    204.76999999999998`}, {287.43399999999997`, 
                    206.42600000000002`}, {284.809, 208.824}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{284.809, 
                    208.824}, {284.52299999999997`, 204.371}, {
                    285.90599999999995`, 201.926}, {288.26599999999996`, 
                    202.297}, {288.914, 204.76999999999998`}, {
                    287.43399999999997`, 206.426}, {284.809, 208.824}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{289.984, 
                    198.953}, {292.082, 200.02}, {290.566, 208.164}, {289.762,
                     211.57399999999998`}, {289.168, 207.18}, {288.172, 
                    200.93}, {289.984, 198.953}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{289.984, 
                    198.95299999999997`}, {292.082, 200.01999999999998`}, {
                    290.566, 208.164}, {289.762, 211.574}, {289.168, 
                    207.18}, {288.172, 200.93}, {289.984, 
                    198.95299999999997`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    289.23799999999994`, 198.566}, {285.715, 197.344}, {
                    282.92599999999993`, 201.137}, {281.97999999999996`, 
                    205.535}, {284.89099999999996`, 201.52}, {289.625, 
                    201.516}, {289.23799999999994`, 198.566}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    289.23799999999994`, 198.56599999999997`}, {285.715, 
                    197.344}, {282.92599999999993`, 201.137}, {
                    281.97999999999996`, 205.535}, {284.89099999999996`, 
                    201.51999999999998`}, {289.625, 201.516}, {
                    289.23799999999994`, 198.56599999999997`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    291.90999999999997`, 194.45700000000002`}, {294.668, 
                    195.184}, {293.008, 203.824}, {292.508, 207.281}, {
                    291.902, 203.71099999999998`}, {290., 195.637}, {
                    291.90999999999997`, 194.45700000000002`}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    291.90999999999997`, 194.457}, {294.668, 195.184}, {
                    293.008, 203.824}, {292.508, 207.281}, {291.902, 
                    203.711}, {290., 195.637}, {291.90999999999997`, 
                    194.457}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{290.969, 
                    194.727}, {290.812, 197.707}, {287.84400000000005`, 
                    196.848}, {285.79299999999995`, 198.43800000000002`}, {
                    286.129, 196.94899999999998`}, {287.39099999999996`, 
                    194.309}, {290.969, 194.727}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{290.969, 
                    194.727}, {290.812, 197.707}, {287.84400000000005`, 
                    196.848}, {285.79299999999995`, 198.438}, {286.129, 
                    196.949}, {287.39099999999996`, 194.309}, {290.969, 
                    194.727}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    294.34400000000005`, 190.73399999999998`}, {297.074, 
                    191.47299999999998`}, {295.43399999999997`, 
                    200.76999999999998`}, {295.59, 204.598}, {294.789, 
                    201.29299999999998`}, {292.25, 191.63299999999998`}, {
                    294.34400000000005`, 190.73399999999998`}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    294.34400000000005`, 190.734}, {297.074, 
                    191.47299999999998`}, {295.43399999999997`, 
                    200.76999999999998`}, {295.59, 204.598}, {294.789, 
                    201.293}, {292.25, 191.63299999999998`}, {
                    294.34400000000005`, 190.734}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{293.07, 
                    191.137}, {290.83599999999996`, 190.41}, {287.871, 
                    191.863}, {287.637, 194.52700000000002`}, {289.566, 
                    193.21899999999997`}, {292.641, 194.21899999999997`}, {
                    293.07, 191.137}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{293.07, 
                    191.137}, {290.83599999999996`, 190.41}, {287.871, 
                    191.863}, {287.637, 194.527}, {289.566, 193.219}, {
                    292.641, 194.219}, {293.07, 191.137}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{296.383, 
                    186.63299999999998`}, {298.9959999999999, 
                    186.42200000000003`}, {297.828, 194.344}, {297.824, 
                    201.71899999999997`}, {296.867, 194.824}, {294.25, 
                    188.512}, {296.383, 186.63299999999998`}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{296.383, 
                    186.63299999999998`}, {298.9959999999999, 186.422}, {
                    297.828, 194.344}, {297.824, 201.719}, {296.867, 
                    194.824}, {294.25, 188.51199999999997`}, {296.383, 
                    186.63299999999998`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    295.47999999999996`, 186.99200000000002`}, {293.715, 
                    186.105}, {290.555, 187.52}, {289.65200000000004`, 
                    190.5}, {292.84000000000003`, 189.117}, {
                    294.97299999999996`, 190.469}, {295.47999999999996`, 
                    186.99200000000002`}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    295.47999999999996`, 186.992}, {293.715, 186.105}, {
                    290.555, 187.51999999999998`}, {289.65200000000004`, 
                    190.5}, {292.84000000000003`, 189.117}, {
                    294.97299999999996`, 190.469}, {295.47999999999996`, 
                    186.992}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{274.977, 
                    204.695}, {275.441, 200.83200000000002`}, {277.02, 
                    198.586}, {279.379, 198.95700000000002`}, {280.027, 
                    201.42600000000002`}, {278.117, 203.008}, {274.977, 
                    204.695}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{274.977, 
                    204.695}, {275.441, 200.832}, {277.02, 
                    198.58599999999998`}, {279.379, 198.957}, {280.027, 
                    201.426}, {278.117, 203.00799999999998`}, {274.977, 
                    204.695}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{281.215, 
                    194.785}, {277.29699999999997`, 194.227}, {275.887, 
                    197.23399999999998`}, {273.25, 201.08200000000002`}, {
                    276.945, 198.406}, {281.363, 197.848}, {281.215, 194.785}}
                    }]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{281.215, 
                    194.785}, {277.29699999999997`, 194.227}, {275.887, 
                    197.23399999999998`}, {273.25, 201.082}, {276.945, 
                    198.406}, {281.363, 197.848}, {281.215, 194.785}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{282.328, 
                    195.22299999999998`}, {284.465, 197.789}, {
                    282.39799999999997`, 201.008}, {280.76599999999996`, 
                    203.75}, {281.117, 199.668}, {279.727, 
                    197.39800000000002`}, {282.328, 195.22299999999998`}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{282.328, 
                    195.223}, {284.465, 197.789}, {282.39799999999997`, 
                    201.00799999999998`}, {280.76599999999996`, 203.75}, {
                    281.117, 199.668}, {279.727, 197.39800000000002`}, {
                    282.328, 195.223}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    283.27299999999997`, 190.99200000000002`}, {283.512, 
                    193.5}, {279.242, 194.055}, {277.309, 
                    195.44899999999998`}, {277.96099999999996`, 194.}, {
                    278.945, 190.102}, {283.27299999999997`, 
                    190.99200000000002`}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    283.27299999999997`, 190.992}, {283.512, 193.5}, {279.242,
                     194.055}, {277.309, 195.449}, {277.96099999999996`, 
                    194.}, {278.945, 190.10199999999998`}, {
                    283.27299999999997`, 190.992}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{284.168, 
                    190.93800000000002`}, {287.121, 191.26999999999998`}, {
                    285.895, 196.285}, {283.777, 199.07}, {284.668, 
                    195.227}, {282.219, 192.55100000000002`}, {284.168, 
                    190.93800000000002`}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{284.168, 
                    190.938}, {287.121, 191.27}, {285.895, 196.285}, {283.777,
                     199.07}, {284.668, 195.227}, {282.219, 192.551}, {
                    284.168, 190.938}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    286.39099999999996`, 186.762}, {289.754, 
                    188.24599999999998`}, {287.59799999999996`, 192.461}, {
                    286.33599999999996`, 194.94899999999998`}, {286.875, 
                    191.684}, {284.18, 189.191}, {286.39099999999996`, 
                    186.762}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    286.39099999999996`, 186.762}, {289.754, 188.246}, {
                    287.59799999999996`, 192.461}, {286.33599999999996`, 
                    194.949}, {286.875, 191.684}, {284.18, 189.191}, {
                    286.39099999999996`, 186.762}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{285.727, 
                    187.15200000000002`}, {283.965, 184.848}, {280.527, 
                    187.84}, {279.82, 191.33200000000002`}, {282.812, 
                    188.84}, {285.02299999999997`, 189.25}, {285.727, 
                    187.15200000000002`}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{285.727, 
                    187.152}, {283.965, 184.84799999999998`}, {280.527, 
                    187.84}, {279.82, 191.332}, {282.812, 188.84}, {
                    285.02299999999997`, 189.25}, {285.727, 187.152}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4gtKt3/WhRU5cF1fXGAbl+rw6ZJvkkBMkQMD
CJxJdZiRJ9R8wKjIoShj4tuayWkQ+YAih70lkyVY/kH5IUUOhbZAE3jSHaJS
rO/7uxc59B/6qhFjnO4AVBXGZ1/kIAuSkE53uFrxUs3QCGrftzSH3Oe/V35U
KXJwSnh6Qak7zcHbvNMxQb4IYu+mNAf9uypsjZJFDt80YvoP3U1z2HKibN98
CShfM91BcQPQZaxFDr3TgRos0h1Azij4WejQ+jpwh5xjusMxkIEvCh2qRNa5
P3RLh9j3phDiXoV0B+HmA6cWfiyEuO93GsTff6D6T6Y5gMPnQyHEvqNpDlYg
B7yEqj8Mlb9W6CAD4n9Pg9h3DCrPnw4xZ2ehgw/IX6pQ+5YWOliCzGFOh/hz
R6FDKJ/uprmP0xxid3nyMH0vdFj9ERiwNWkOoGC3Ny5yuHnue/Bj3zQHULD2
I8UXAIuTyOo=
                    "]]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4gtKt3/WhRU5cF1fXGAbl+rw6ZJvkkBMkQMD
CJxJdZiRJ9R8wKjIoShj4tuayWkQ+YAihz0lkyVY/kH5IUUOhbZAE3jSHaJS
rO/7uxc59B/6qhFjnO4AVBXGZ1/kIAuSkE53uFrxUs3QCGrftzSH3Oe/V35U
KXJwTHh6Qak7zcHbvNMxQb4IYu+mNAf9uypsjZJFDt80YvoP3U1z2HKibN98
CShfM91BcQPQZaxFDn3TgRos0h1Azij4WejQ+jpwh5xjusMxkIEvCh2qRda5
P3RLh9j3ptChAKRQId1BuPnAqYUfCyHu+50G8fefQoc2kP6TaQ7g8PlQ6PAV
ZN/RNAcrkANeQtUfhspfg/K/p0HsOwbl86dD3LGzEOIvVah9SwsdLEHmMKdD
/Lmj0CGUT3fT3MdpDrG7PHmYvhc6rP4IDNiaNAdQsNsbFzncPPc9+LFvmgMo
WPuR4gsAigvI6Q==
                    "], CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4mPe5p2Ox4ocRNa5P6y6EuuguKEoY+LZIgeX
7pznv2/GOiiA+NeLHNrFbp77/jjW4YLS7Z9154ocPHmYtNu3xTpogyRaixx6
p+cJNQfEOMwAUgcKihy+acT0H3ob7QASPsBW5MAAAgoxDkBbRNbNLoSoj4hx
uFrxUs2wqdDBL0kgwvJMjEP5vvlS+uaFEPeUxEL4/IUOF0H2Xop12HKibN/8
KwUOxRkT39Y8j3UAu39FgUMmkGu/FureyQUOXNcXF9hOinWYLMESxtdeALFv
QqyDbFSK9f2pBQ6b5r5ffux0rMPS2UcUNiwpcHgK8hhbHMQ92wocLEEWhcc5
3PcH6jxR4LBGBqixP85hh1zr68APBQ419qZxuzjjHT5d8k0SMCl0eAbSbxfv
ADLeP7sQ4j7xeAdbkEN2FkLC61kcJBx+QeXl4xyApu2Qcy+C+B8Y/uDwyS+C
2Lc+1uExyIFzihyAvs/aswXqX6T4AgDJDcnj
                    "]]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4mPe5p2Ox4ocRNa5P6y6EuuguKEoY+LZIgeX
7pznv2/GOiiA+NeLHNrEbp77/jjW4YLS7Z9154ocvHiYtNu3xTpotwMlWosc
+qbnCTUHxDjMAFIHCoocvmnE9B96G+0AEj7AVuTAAAIKMQ5AW0TWzS6EqI+I
cbha8VLNsKnQwS9JIMLyTIxD+b75UvrmhRD3lMRC+PyFDpdA9l6Kddhyomzf
/CsFDkBXva15HusAdv+KAocsINd+LdS9kwsceK4vLrCdFOswWYIljK+9AGLf
hFgH2agU6/tTCxw2zX2//NjpWIels48obFhS4PAE5DG2OIh7thU4WIEsCo9z
uO/fOz3vRIHDGhmgxv44hx1yra8DPxQ41Nibxu3ijHf4dMk3ScCk0OEZSL9d
vAPIeP/sQocSkPvE4x1suYAO2Vno4AEKr2dxkHD4VQhxv3ycA9C0HXLuRRD/
A8MfHD75RRD71sc6PAY5cE6Rw52fdVl7tkD9ixRfAM89yek=
                    "], 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    262.16, 109.32}, {261.316, 109.215}, {260.78099999999995`,
                     107.57799999999999`}, {260.363, 108.68799999999999`}, {
                    259.66, 110.48}, {260.15200000000004`, 111.906}, {260.945,
                     111.75}, {261.883, 111.5}, {263.465, 109.402}, {262.16, 
                    109.32}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    262.16, 109.32}, {261.316, 109.215}, {260.78099999999995`,
                     107.57799999999997`}, {260.363, 108.68799999999999`}, {
                    259.66, 110.47999999999999`}, {260.15200000000004`, 
                    111.906}, {260.945, 111.75}, {261.883, 111.5}, {263.465, 
                    109.40199999999999`}, {262.16, 109.32}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4h1yra8DfxQ5ZEx8W2O/NdVBJirF+j57scM3
jZj+Q1dTHbzNOx0TmIsd1A051sg8SnUAqjKNe1PksPVE2b75QP7jpbOPKNwq
cljkuu3z3yepDgwgsK3I4ThI45lUh2MgegWU/yDVwf1hlci62UUOF5Vu/6z7
lOqwDKh9w4IiiD6HNAega3bIAeUttwAtSE6DyM8ocgjj0900tzzNwQOkf2KR
A5B0fzgtzeHTJd8kgaYiiPvS0iDmBxc56N9VYWu8mOpgBTJHssjBMeHpBSX5
VIg7GYocVn0EaixIgaj7XAjxF18KxL0MUP2lyZBw0YX6ly/ZQaj5wKmF2kUO
XNcXF9imJTuAnPXeGhp+C5Mh4edf5HAJ5L9XyQ73/Xun52UUOczIA+r0SnHQ
ahe7ee5wkUM4SKN/qgN6+AMAUBKzZA==
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{291.574, 
                    149.24599999999998`}, {288.39099999999996`, 
                    149.23399999999998`}, {287.84400000000005`, 153.504}, {
                    287.84400000000005`, 154.69899999999998`}, {
                    289.40999999999997`, 154.39800000000002`}, {292.172, 
                    151.785}, {291.574, 149.24599999999998`}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{291.574, 
                    149.246}, {288.39099999999996`, 149.234}, {
                    287.84400000000005`, 153.504}, {287.84400000000005`, 
                    154.69899999999998`}, {289.40999999999997`, 154.398}, {
                    292.172, 151.78500000000003`}, {291.574, 149.246}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{264.039, 
                    107.793}, {261.77299999999997`, 107.277}, {261.805, 
                    112.73400000000001`}, {264.121, 115.04700000000001`}, {
                    263.10200000000003`, 111.543}, {265.824, 108.336}, {
                    264.039, 107.793}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{264.039, 
                    107.793}, {261.77299999999997`, 107.27700000000002`}, {
                    261.805, 112.73400000000001`}, {264.121, 115.047}, {
                    263.10200000000003`, 111.54299999999998`}, {265.824, 
                    108.33600000000001`}, {264.039, 107.793}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    264.92199999999997`, 107.84}, {264.77, 
                    105.24600000000001`}, {271.28499999999997`, 
                    108.17999999999999`}, {272.96099999999996`, 110.195}, {
                    269.113, 108.562}, {265.10900000000004`, 
                    109.91400000000002`}, {264.92199999999997`, 107.84}}}]}, {
                   
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    264.92199999999997`, 107.84}, {264.77, 
                    105.24600000000001`}, {271.28499999999997`, 
                    108.17999999999998`}, {272.96099999999996`, 110.195}, {
                    269.113, 108.56199999999998`}, {265.10900000000004`, 
                    109.91399999999999`}, {264.92199999999997`, 107.84}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{267.777, 
                    111.543}, {267.543, 109.031}, {273.42599999999993`, 
                    111.242}, {275.168, 113.203}, {271.301, 111.953}, {
                    268.03099999999995`, 113.613}, {267.777, 111.543}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{267.777, 
                    111.54299999999998`}, {267.543, 109.031}, {
                    273.42599999999993`, 111.24199999999999`}, {275.168, 
                    113.203}, {271.301, 111.953}, {268.03099999999995`, 
                    113.61299999999997`}, {267.777, 111.54299999999998`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{266.695, 
                    111.191}, {264.42999999999995`, 110.67599999999999`}, {
                    264.79699999999997`, 116.32}, {267., 118.262}, {265.941, 
                    114.49600000000001`}, {268.477, 111.738}, {266.695, 
                    111.191}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{266.695, 
                    111.191}, {264.42999999999995`, 110.67599999999999`}, {
                    264.79699999999997`, 116.32}, {267., 118.262}, {265.941, 
                    114.49600000000001`}, {268.477, 111.738}, {266.695, 
                    111.191}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{269.078, 
                    114.62499999999999`}, {266.812, 114.109}, {268.113, 
                    118.96900000000001`}, {269.79299999999995`, 
                    120.91000000000001`}, {269.52, 117.367}, {270.637, 
                    114.91000000000001`}, {269.078, 114.62499999999999`}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{269.078, 
                    114.625}, {266.812, 114.10899999999998`}, {268.113, 
                    118.969}, {269.79299999999995`, 120.91}, {269.52, 
                    117.36700000000002`}, {270.637, 114.91}, {269.078, 
                    114.625}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    270.28099999999995`, 114.641}, {270.047, 112.051}, {
                    274.625, 114.039}, {276.402, 116.488}, {272.574, 
                    115.238}, {270.53499999999997`, 116.70700000000001`}, {
                    270.28099999999995`, 114.641}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    270.28099999999995`, 114.64099999999999`}, {270.047, 
                    112.05100000000002`}, {274.625, 114.03899999999999`}, {
                    276.402, 116.488}, {272.574, 115.238}, {
                    270.53499999999997`, 116.70700000000002`}, {
                    270.28099999999995`, 114.64099999999999`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{271.527, 
                    116.609}, {270.043, 117.67599999999999`}, {271.617, 
                    120.5}, {274.445, 120.324}, {274.168, 118.617}, {273.191, 
                    115.621}, {271.527, 116.609}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{271.527, 
                    116.60899999999998`}, {270.043, 117.67599999999999`}, {
                    271.617, 120.5}, {274.445, 120.32400000000001`}, {274.168,
                     118.61699999999999`}, {273.191, 115.62100000000001`}, {
                    271.527, 116.60899999999998`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{260.367, 
                    104.902}, {260.219, 102.309}, {266.734, 
                    103.60199999999999`}, {268.78099999999995`, 106.363}, {
                    264.672, 105.586}, {260.559, 106.98}, {260.367, 
                    104.902}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{260.367, 
                    104.90199999999999`}, {260.219, 102.309}, {266.734, 
                    103.60199999999998`}, {268.78099999999995`, 106.363}, {
                    264.672, 105.58600000000001`}, {260.559, 
                    106.97999999999999`}, {260.367, 104.90199999999999`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{286.258, 
                    109.543}, {286.02299999999997`, 106.95700000000001`}, {
                    293.137, 109.801}, {294.914, 112.25}, {291.09, 111.}, {
                    286.512, 111.613}, {286.258, 109.543}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{286.258, 
                    109.54299999999998`}, {286.02299999999997`, 
                    106.95700000000002`}, {293.137, 109.80100000000002`}, {
                    294.914, 112.25}, {291.09, 111.}, {286.512, 
                    111.61299999999997`}, {286.258, 109.54299999999998`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{281.895, 
                    108.44100000000002`}, {280.40999999999997`, 109.508}, {
                    283.441, 112.258}, {285.855, 112.902}, {285.582, 
                    111.199}, {283.559, 107.453}, {281.895, 
                    108.44100000000002`}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{281.895, 
                    108.441}, {280.40999999999997`, 109.50799999999998`}, {
                    283.441, 112.25800000000001`}, {285.855, 
                    112.90199999999999`}, {285.582, 111.19899999999998`}, {
                    283.559, 107.453}, {281.895, 108.441}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{281.441, 
                    106.648}, {281.28099999999995`, 104.32}, {289.07, 
                    105.598}, {291.105, 107.74600000000001`}, {
                    284.40599999999995`, 106.535}, {281.66, 108.641}, {
                    281.441, 106.648}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{281.441, 
                    106.64799999999997`}, {281.28099999999995`, 104.32}, {
                    289.07, 105.59799999999998`}, {291.105, 
                    107.74600000000001`}, {284.40599999999995`, 106.535}, {
                    281.66, 108.64099999999999`}, {281.441, 
                    106.64799999999997`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    277.79299999999995`, 105.098}, {276.92599999999993`, 
                    102.93400000000001`}, {284.402, 103.46100000000001`}, {
                    287.027, 104.71900000000001`}, {282.78499999999997`, 
                    104.754}, {278.387, 106.60199999999999`}, {
                    277.79299999999995`, 105.098}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    277.79299999999995`, 105.09799999999998`}, {
                    276.92599999999993`, 102.934}, {284.402, 
                    103.46100000000001`}, {287.027, 104.719}, {
                    282.78499999999997`, 104.75400000000002`}, {278.387, 
                    106.60199999999998`}, {277.79299999999995`, 
                    105.09799999999998`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    274.29699999999997`, 103.52}, {273.469, 101.582}, {
                    280.383, 101.62499999999999`}, {283.754, 102.695}, {
                    279.289, 102.73}, {275.113, 105.438}, {
                    274.29699999999997`, 103.52}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    274.29699999999997`, 103.51999999999998`}, {273.469, 
                    101.582}, {280.383, 101.625}, {283.754, 102.695}, {
                    279.289, 102.73000000000002`}, {275.113, 
                    105.43799999999999`}, {274.29699999999997`, 
                    103.51999999999998`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    269.26599999999996`, 102.48}, {268.039, 
                    100.18799999999999`}, {275.33599999999996`, 99.965}, {
                    277.703, 101.09400000000001`}, {273.484, 
                    101.67199999999998`}, {270.309, 104.285}, {
                    269.26599999999996`, 102.48}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    269.26599999999996`, 102.47999999999999`}, {268.039, 
                    100.18799999999999`}, {275.33599999999996`, 99.965}, {
                    277.703, 101.094}, {273.484, 101.67199999999997`}, {
                    270.309, 104.28500000000003`}, {269.26599999999996`, 
                    102.47999999999999`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{277.809, 
                    106.398}, {280.129, 104.938}, {280.004, 109.25}, {
                    281.85200000000003`, 112.238}, {278.949, 109.598}, {
                    276.234, 107.79700000000001`}, {277.809, 106.398}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{277.809, 
                    106.398}, {280.129, 104.93799999999999`}, {280.004, 
                    109.25}, {281.85200000000003`, 112.238}, {278.949, 
                    109.59799999999998`}, {276.234, 107.79700000000003`}, {
                    277.809, 106.398}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{273.695, 
                    104.848}, {275.64500000000004`, 103.12499999999999`}, {
                    277.199, 109.043}, {278.97299999999996`, 112.367}, {
                    276.105, 109.203}, {271.89799999999997`, 106.281}, {
                    273.695, 104.848}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{273.695, 
                    104.84799999999998`}, {275.64500000000004`, 103.125}, {
                    277.199, 109.04299999999998`}, {278.97299999999996`, 
                    112.36700000000002`}, {276.105, 109.203}, {
                    271.89799999999997`, 106.28100000000003`}, {273.695, 
                    104.84799999999998`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{268.258, 
                    103.199}, {269.90599999999995`, 101.289}, {274.672, 
                    108.816}, {276.40599999999995`, 112.73400000000001`}, {
                    273.76599999999996`, 109.684}, {266.945, 104.82}, {
                    268.258, 103.199}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{268.258, 
                    103.19899999999998`}, {269.90599999999995`, 
                    101.28900000000002`}, {274.672, 108.816}, {
                    276.40599999999995`, 112.73400000000001`}, {
                    273.76599999999996`, 109.684}, {266.945, 104.82}, {
                    268.258, 103.19899999999998`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{272.895, 
                    97.45700000000001}, {273.719, 94.551}, {285.848, 
                    100.195}, {287.203, 103.117}, {280.262, 
                    99.44100000000002}, {272.72999999999996`, 
                    100.21100000000001`}, {272.895, 97.45700000000001}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{272.895, 
                    97.45700000000002}, {273.719, 94.55100000000002}, {
                    285.848, 100.195}, {287.203, 103.11699999999999`}, {
                    280.262, 99.441}, {272.72999999999996`, 
                    100.21100000000001`}, {272.895, 97.45700000000002}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4k+XfJME6oodZKNSrO/3JztsPVG2b35TsUMY
n+6mubOTHdwfVoms6y92CAfxgfL3/Xun5/UUOzglPL2gVJzs4G3e6ZjQWexw
52dd1h6fZIfJEixhfLlQ/e1JDm9r7E3jbIodLLcADXZOcvAAmSdZ7PBNI6b/
kGCSQ8ZEoIrkIofW14E75A4mOlxQuv2zTqDIoVpknfvDeYkOcbs8eZgeFzoU
2nJdX9yTCBHfU+jgCLI/PtEhFiQ/v9Bhep5Q8wGxRIh7Vhc66N9VYWssTXQA
ect/ayHEPbsTIfYdLXQQbj5waiHQfrC+K4UOi1y3ff4bk+Sg3S5289zfQoh/
10Pdr1HkwAACW5IcQM4oKC+CuH9nkoMVyF93ixxU2RqnOh9PcgCHpwbUv+zQ
8PKD8tWh4ZVaDPFXcLIDevgDAJdbrTE=
                    "]]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4k+XfJME6oodZKNSrO/3JztsPVG2b35TsUMY
n+6mubOTHdwfVoms64fygfL3/Xun5/UUOzgmPL2gVJzs4G3e6ZjQWexw+2dd
1h6fZIfJEixhfLlQ9e1JDm9r7E3jbIodLLcADXZOcvAAmSdZ7PBNI6b/kGCS
Q8ZEoIrkIofW14E75A4mOlxQApokUORQLbLO/eG8RIe4XZ48TI8LHQptua4v
7kmEiO8phNgfn+gQC5KfX+gwI0+o+YBYIsQ9qwsd9O6qsDWWJjqAvOW/tRDi
nt2JEPuOFjoINx84tRBo/3SQviuFDotct33+G5PkoN0udvPcX6j69VD3axQ5
MIDAliQHkDMKyosg7t+Z5GAF8tfdIgc1tsapzseTHMDhqQH1Lzs0vPygfHVo
eKUWQ/wVnOyAHv4AkzOtLg==
                    "], CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{283.566, 
                    132.105}, {282.012, 130.95700000000002`}, {
                    280.29299999999995`, 135.066}, {282.27, 
                    138.97299999999998`}, {282.332, 135.21499999999997`}, {
                    285.32, 133.94899999999998`}, {283.566, 132.105}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{283.566, 
                    132.105}, {282.012, 130.95700000000002`}, {
                    280.29299999999995`, 135.066}, {282.27, 
                    138.97299999999998`}, {282.332, 135.215}, {285.32, 
                    133.94899999999998`}, {283.566, 132.105}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{282.07, 
                    128.336}, {279.91799999999995`, 127.67599999999999`}, {
                    279.242, 131.484}, {280.66, 134.535}, {
                    280.42599999999993`, 131.258}, {284.047, 129.285}, {
                    282.07, 128.336}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{282.07, 
                    128.336}, {279.91799999999995`, 127.67599999999999`}, {
                    279.242, 131.484}, {280.66, 134.535}, {
                    280.42599999999993`, 131.258}, {284.047, 
                    129.28500000000003`}, {282.07, 128.336}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    280.43399999999997`, 125.312}, {278.35200000000003`, 
                    124.277}, {277.562, 128.125}, {279.059, 130.984}, {
                    278.895, 127.34}, {282.03499999999997`, 126.262}, {
                    280.43399999999997`, 125.312}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    280.43399999999997`, 125.31199999999998`}, {
                    278.35200000000003`, 124.27700000000002`}, {277.562, 
                    128.125}, {279.059, 130.984}, {278.895, 127.34}, {
                    282.03499999999997`, 126.262}, {280.43399999999997`, 
                    125.31199999999998`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{281.289, 
                    125.07799999999999`}, {282.113, 122.617}, {286.895, 
                    127.203}, {287.699, 129.69899999999998`}, {
                    284.72999999999996`, 126.75}, {280.695, 
                    127.07799999999999`}, {281.289, 125.07799999999999`}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{281.289, 
                    125.07799999999997`}, {282.113, 122.61699999999999`}, {
                    286.895, 127.203}, {287.699, 129.69899999999998`}, {
                    284.72999999999996`, 126.75}, {280.695, 
                    127.07799999999997`}, {281.289, 125.07799999999997`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{283.457, 
                    128.848}, {284.395, 126.383}, {290.40599999999995`, 
                    132.727}, {291.734, 135.781}, {288.76599999999996`, 
                    132.836}, {282.789, 130.586}, {283.457, 128.848}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{283.457, 
                    128.84799999999998`}, {284.395, 126.38300000000001`}, {
                    290.40599999999995`, 132.72700000000003`}, {291.734, 
                    135.78100000000003`}, {288.76599999999996`, 132.836}, {
                    282.789, 130.586}, {283.457, 128.84799999999998`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{284.648, 
                    132.54299999999998`}, {285.58599999999996`, 129.742}, {
                    292.121, 137.207}, {293.97299999999996`, 
                    139.85200000000003`}, {290.855, 136.941}, {283.941, 
                    134.578}, {284.648, 132.54299999999998`}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{284.648, 
                    132.54299999999998`}, {285.58599999999996`, 129.742}, {
                    292.121, 137.20700000000002`}, {293.97299999999996`, 
                    139.852}, {290.855, 136.941}, {283.941, 
                    134.57799999999997`}, {284.648, 132.54299999999998`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{284.855, 
                    135.312}, {282.555, 135.758}, {284.98799999999994`, 
                    137.676}, {287.809, 140.79299999999998`}, {
                    287.93799999999993`, 137.512}, {287.402, 
                    135.21899999999997`}, {284.855, 135.312}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{284.855, 
                    135.31199999999998`}, {282.555, 135.758}, {
                    284.98799999999994`, 137.676}, {287.809, 140.793}, {
                    287.93799999999993`, 137.51199999999997`}, {287.402, 
                    135.219}, {284.855, 135.31199999999998`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{288.734, 
                    137.176}, {287.742, 138.258}, {289.688, 
                    138.71899999999997`}, {292.09799999999996`, 
                    141.42200000000003`}, {292.453, 139.602}, {289.863, 
                    136.262}, {288.734, 137.176}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{288.734, 
                    137.176}, {287.742, 138.258}, {289.688, 138.719}, {
                    292.09799999999996`, 141.422}, {292.453, 
                    139.60199999999998`}, {289.863, 136.262}, {288.734, 
                    137.176}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    277.60200000000003`, 125.016}, {276.34000000000003`, 
                    124.277}, {275.47999999999996`, 126.859}, {277.047, 
                    129.195}, {277.40599999999995`, 126.66799999999999`}, {
                    278.754, 125.965}, {277.60200000000003`, 125.016}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    277.60200000000003`, 125.01599999999999`}, {
                    276.34000000000003`, 124.27700000000002`}, {
                    275.47999999999996`, 126.85900000000001`}, {277.047, 
                    129.195}, {277.40599999999995`, 126.66799999999998`}, {
                    278.754, 125.965}, {277.60200000000003`, 
                    125.01599999999999`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{304.953, 
                    141.297}, {307.625, 139.691}, {311.875, 146.09}, {313.008,
                     148.72299999999998`}, {310.66, 145.69899999999998`}, {
                    304.445, 142.941}, {304.953, 141.297}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{304.953, 
                    141.29700000000003`}, {307.625, 139.691}, {311.875, 
                    146.09}, {313.008, 148.723}, {310.66, 
                    145.69899999999998`}, {304.445, 142.941}, {304.953, 
                    141.29700000000003`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{302.68, 
                    137.566}, {304.16, 135.92600000000002`}, {308.816, 
                    140.383}, {310.43399999999997`, 142.641}, {
                    307.93799999999993`, 140.48000000000002`}, {302.027, 
                    140.22299999999998`}, {302.68, 137.566}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{302.68, 
                    137.566}, {304.16, 135.92600000000002`}, {308.816, 
                    140.383}, {310.43399999999997`, 142.641}, {
                    307.93799999999993`, 140.48}, {302.027, 140.223}, {302.68,
                     137.566}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    300.14500000000004`, 134.22299999999998`}, {300.633, 
                    131.984}, {307.42999999999995`, 137.02}, {309.02, 
                    139.406}, {306.08599999999996`, 136.64499999999998`}, {
                    299.699, 136.895}, {300.14500000000004`, 
                    134.22299999999998`}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    300.14500000000004`, 134.223}, {300.633, 131.984}, {
                    307.42999999999995`, 137.01999999999998`}, {309.02, 
                    139.406}, {306.08599999999996`, 136.64499999999998`}, {
                    299.699, 136.895}, {300.14500000000004`, 134.223}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{301.184, 
                    131.80100000000002`}, {302.234, 129.781}, {307.762, 
                    134.781}, {309.08599999999996`, 137.39100000000002`}, {
                    305.71099999999996`, 134.441}, {300.328, 133.797}, {
                    301.184, 131.80100000000002`}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{301.184, 
                    131.80100000000002`}, {302.234, 129.78100000000003`}, {
                    307.762, 134.78100000000003`}, {309.08599999999996`, 
                    137.39100000000002`}, {305.71099999999996`, 134.441}, {
                    300.328, 133.79700000000003`}, {301.184, 
                    131.80100000000002`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    304.02299999999997`, 141.625}, {302.28099999999995`, 
                    143.465}, {303.02299999999997`, 144.324}, {
                    304.29299999999995`, 147.22299999999998`}, {
                    304.98799999999994`, 144.24599999999998`}, {306.039, 
                    143.059}, {304.02299999999997`, 141.625}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    304.02299999999997`, 141.625}, {302.28099999999995`, 
                    143.465}, {303.02299999999997`, 144.324}, {
                    304.29299999999995`, 147.223}, {304.98799999999994`, 
                    144.246}, {306.039, 143.059}, {304.02299999999997`, 
                    141.625}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    301.71099999999996`, 138.15200000000002`}, {298.547, 
                    138.012}, {301.68, 141.863}, {302.42999999999995`, 
                    145.094}, {302.156, 141.41}, {303.242, 138.504}, {
                    301.71099999999996`, 138.15200000000002`}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    301.71099999999996`, 138.152}, {298.547, 
                    138.01199999999997`}, {301.68, 141.863}, {
                    302.42999999999995`, 145.094}, {302.156, 141.41}, {
                    303.242, 138.504}, {301.71099999999996`, 138.152}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{299.695, 
                    135.098}, {297.504, 135.59}, {298.137, 138.695}, {299.816,
                     142.44899999999998`}, {299.469, 138.39100000000002`}, {
                    301.672, 136.047}, {299.695, 135.098}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{299.695, 
                    135.09799999999998`}, {297.504, 135.59}, {298.137, 
                    138.695}, {299.816, 142.44899999999998`}, {299.469, 
                    138.39100000000002`}, {301.672, 136.047}, {299.695, 
                    135.09799999999998`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{300.441, 
                    128.961}, {301.26599999999996`, 126.49600000000001`}, {
                    307.5, 132.20299999999997`}, {308.49199999999996`, 
                    134.363}, {305.34000000000003`, 131.71499999999997`}, {
                    299.883, 130.809}, {300.441, 128.961}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{300.441, 
                    128.961}, {301.26599999999996`, 126.49600000000001`}, {
                    307.5, 132.203}, {308.49199999999996`, 134.363}, {
                    305.34000000000003`, 131.715}, {299.883, 130.809}, {
                    300.441, 128.961}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{296.703, 
                    125.113}, {297.641, 122.648}, {304.176, 127.645}, {
                    306.176, 130.36700000000002`}, {302.23799999999994`, 
                    127.27}, {296.22299999999996`, 127.55499999999999`}, {
                    296.703, 125.113}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{296.703, 
                    125.11299999999997`}, {297.641, 122.64799999999997`}, {
                    304.176, 127.64499999999998`}, {306.176, 
                    130.36700000000002`}, {302.23799999999994`, 
                    127.27000000000001`}, {296.22299999999996`, 127.555}, {
                    296.703, 125.11299999999997`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{292.895, 
                    121.23}, {293.945, 117.79700000000001`}, {300.777, 
                    123.281}, {302.816, 125.965}, {298.465, 122.645}, {
                    292.34000000000003`, 123.67599999999999`}, {292.895, 
                    121.23}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{292.895, 
                    121.23000000000002`}, {293.945, 117.79700000000003`}, {
                    300.777, 123.28100000000003`}, {302.816, 125.965}, {
                    298.465, 122.64499999999998`}, {292.34000000000003`, 
                    123.67599999999999`}, {292.895, 121.23000000000002`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{299.32, 
                    130.055}, {297.465, 129.094}, {296.715, 134.363}, {
                    297.762, 138.08200000000002`}, {297.746, 134.023}, {
                    301.484, 131.008}, {299.32, 130.055}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{299.32, 
                    130.055}, {297.465, 129.094}, {296.715, 134.363}, {
                    297.762, 138.082}, {297.746, 134.023}, {301.484, 
                    131.00799999999998`}, {299.32, 130.055}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    296.15200000000004`, 125.871}, {293.92199999999997`, 
                    125.21100000000001`}, {294.629, 130.88700000000003`}, {
                    296.53499999999997`, 134.57}, {296.78099999999995`, 
                    130.92200000000003`}, {298.42599999999993`, 
                    127.45700000000001`}, {296.15200000000004`, 125.871}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    296.15200000000004`, 125.87100000000001`}, {
                    293.92199999999997`, 125.21100000000001`}, {294.629, 
                    130.88700000000003`}, {296.53499999999997`, 134.57}, {
                    296.78099999999995`, 130.922}, {298.42599999999993`, 
                    127.45700000000002`}, {296.15200000000004`, 
                    125.87100000000001`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{292.191, 
                    121.953}, {289.699, 121.812}, {291.414, 126.82}, {293.469,
                     129.641}, {293.121, 125.95700000000001`}, {
                    294.28099999999995`, 122.37899999999999`}, {292.191, 
                    121.953}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{292.191, 
                    121.953}, {289.699, 121.81199999999998`}, {291.414, 
                    126.82}, {293.469, 129.641}, {293.121, 
                    125.95700000000002`}, {294.28099999999995`, 
                    122.37899999999999`}, {292.191, 121.953}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{296.559, 
                    119.816}, {297.309, 118.54700000000001`}, {299.141, 
                    120.895}, {302.148, 122.60499999999999`}, {299.445, 
                    121.898}, {296.227, 120.992}, {296.559, 119.816}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{296.559, 
                    119.816}, {297.309, 118.547}, {299.141, 
                    120.89500000000001`}, {302.148, 122.60499999999999`}, {
                    299.445, 121.898}, {296.227, 120.99199999999999`}, {
                    296.559, 119.816}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{297.984, 
                    162.008}, {295.66, 163.727}, {297.43399999999997`, 
                    166.945}, {297.984, 170.008}, {298.72999999999996`, 
                    167.105}, {300.703, 163.297}, {297.984, 162.008}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{297.984, 
                    162.00799999999998`}, {295.66, 163.72700000000003`}, {
                    297.43399999999997`, 166.945}, {297.984, 
                    170.00799999999998`}, {298.72999999999996`, 167.105}, {
                    300.703, 163.29700000000003`}, {297.984, 
                    162.00799999999998`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{298.062, 
                    157.71899999999997`}, {301.559, 158.141}, {
                    301.03099999999995`, 162.656}, {301.137, 165.52}, {
                    300.08599999999996`, 161.63299999999998`}, {
                    297.22299999999996`, 160.977}, {298.062, 
                    157.71899999999997`}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{298.062, 
                    157.719}, {301.559, 158.141}, {301.03099999999995`, 
                    162.656}, {301.137, 165.51999999999998`}, {
                    300.08599999999996`, 161.63299999999998`}, {
                    297.22299999999996`, 160.977}, {298.062, 157.719}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{297.512, 
                    158.305}, {294.559, 158.477}, {294.715, 161.836}, {
                    294.555, 165.238}, {296.055, 162.11299999999997`}, {
                    297.828, 161.629}, {297.512, 158.305}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{297.512, 
                    158.305}, {294.559, 158.477}, {294.715, 161.836}, {
                    294.555, 165.238}, {296.055, 162.11299999999997`}, {
                    297.828, 161.629}, {297.512, 158.305}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{297.633, 
                    154.129}, {299.92999999999995`, 153.945}, {301.125, 
                    156.20299999999997`}, {301.65200000000004`, 
                    159.72299999999998`}, {299.47299999999996`, 
                    156.48000000000002`}, {297.48799999999994`, 
                    157.48800000000003`}, {297.633, 154.129}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{297.633, 
                    154.129}, {299.92999999999995`, 153.945}, {301.125, 
                    156.203}, {301.65200000000004`, 159.723}, {
                    299.47299999999996`, 156.48}, {297.48799999999994`, 
                    157.488}, {297.633, 154.129}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{296.809, 
                    154.406}, {293.85200000000003`, 154.02700000000002`}, {
                    294.324, 157.469}, {294.445, 160.004}, {295.348, 
                    157.586}, {297.754, 156.824}, {296.809, 154.406}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{296.809, 
                    154.406}, {293.85200000000003`, 154.02700000000002`}, {
                    294.324, 157.469}, {294.445, 160.004}, {295.348, 
                    157.586}, {297.754, 156.824}, {296.809, 154.406}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{301.414, 
                    155.863}, {301.18, 153.617}, {299.762, 149.758}, {297.477,
                     150.625}, {296.53099999999995`, 153.383}, {299.484, 
                    153.934}, {301.414, 155.863}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{301.414, 
                    155.863}, {301.18, 153.617}, {299.762, 149.758}, {297.477,
                     150.625}, {296.53099999999995`, 153.383}, {299.484, 
                    153.934}, {301.414, 155.863}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{296.77, 
                    150.383}, {297.79299999999995`, 152.35500000000002`}, {
                    294.445, 153.34}, {293.734, 155.89800000000002`}, {
                    293.328, 152.23399999999998`}, {293.668, 
                    149.83200000000002`}, {296.77, 150.383}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{296.77, 
                    150.383}, {297.79299999999995`, 152.35500000000002`}, {
                    294.445, 153.34}, {293.734, 155.898}, {293.328, 
                    152.234}, {293.668, 149.832}, {296.77, 150.383}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    306.29699999999997`, 173.727}, {304.457, 
                    175.71099999999998`}, {306.082, 178.85200000000003`}, {
                    306.633, 181.914}, {307.379, 179.012}, {308.676, 
                    175.164}, {306.29699999999997`, 173.727}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    306.29699999999997`, 173.72700000000003`}, {304.457, 
                    175.711}, {306.082, 178.852}, {306.633, 181.914}, {
                    307.379, 179.01199999999997`}, {308.676, 175.164}, {
                    306.29699999999997`, 173.72700000000003`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    306.35200000000003`, 170.039}, {309.582, 
                    169.71099999999998`}, {310.363, 176.285}, {310.695, 
                    179.10899999999998`}, {309.64500000000004`, 
                    175.22299999999998`}, {305.92199999999997`, 173.445}, {
                    306.35200000000003`, 170.039}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    306.35200000000003`, 170.039}, {309.582, 169.711}, {
                    310.363, 176.28500000000003`}, {310.695, 
                    179.10899999999998`}, {309.64500000000004`, 175.223}, {
                    305.92199999999997`, 173.445}, {306.35200000000003`, 
                    170.039}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{305.688, 
                    170.105}, {303.40599999999995`, 171.285}, {
                    303.93399999999997`, 173.824}, {303.219, 175.73}, {
                    304.754, 173.39100000000002`}, {306.15200000000004`, 
                    173.055}, {305.688, 170.105}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{305.688, 
                    170.105}, {303.40599999999995`, 171.28500000000003`}, {
                    303.93399999999997`, 173.824}, {303.219, 
                    175.73000000000002`}, {304.754, 173.39100000000002`}, {
                    306.15200000000004`, 173.055}, {305.688, 170.105}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{306.328, 
                    165.80100000000002`}, {309.707, 165.512}, {
                    311.72299999999996`, 172.789}, {311.828, 175.656}, {
                    310.777, 171.766}, {305.93399999999997`, 169.656}, {
                    306.328, 165.80100000000002`}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{306.328, 
                    165.80100000000002`}, {309.707, 165.51199999999997`}, {
                    311.72299999999996`, 172.78900000000002`}, {311.828, 
                    175.656}, {310.777, 171.76600000000002`}, {
                    305.93399999999997`, 169.656}, {306.328, 
                    165.80100000000002`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{305.68, 
                    165.91}, {302.5, 166.64499999999998`}, {302.883, 
                    168.69899999999998`}, {303.35900000000004`, 
                    172.02700000000002`}, {304.371, 168.676}, {
                    306.14500000000004`, 169.38700000000003`}, {305.68, 
                    165.91}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{305.68, 
                    165.91}, {302.5, 166.64499999999998`}, {302.883, 
                    168.69899999999998`}, {303.35900000000004`, 
                    172.02700000000002`}, {304.371, 168.676}, {
                    306.14500000000004`, 169.38700000000003`}, {305.68, 
                    165.91}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{306.367, 
                    161.602}, {310.08599999999996`, 160.969}, {309.824, 
                    166.848}, {312.77299999999997`, 171.11299999999997`}, {
                    310.22299999999996`, 167.945}, {305.625, 163.953}, {
                    306.367, 161.602}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{306.367, 
                    161.60199999999998`}, {310.08599999999996`, 160.969}, {
                    309.824, 166.84799999999998`}, {312.77299999999997`, 
                    171.11299999999997`}, {310.22299999999996`, 167.945}, {
                    305.625, 163.953}, {306.367, 161.60199999999998`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{305.527, 
                    161.80100000000002`}, {302.72299999999996`, 
                    161.71899999999997`}, {302.449, 165.941}, {302.605, 
                    167.656}, {303.25, 165.94899999999998`}, {306.547, 
                    164.32800000000003`}, {305.527, 161.80100000000002`}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{305.527, 
                    161.80100000000002`}, {302.72299999999996`, 161.719}, {
                    302.449, 165.941}, {302.605, 167.656}, {303.25, 
                    165.94899999999998`}, {306.547, 164.328}, {305.527, 
                    161.80100000000002`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{312.176, 
                    166.129}, {310.78099999999995`, 161.605}, {308.805, 
                    157.07}, {306.367, 157.414}, {305.199, 
                    159.98800000000003`}, {308.68, 160.316}, {312.176, 
                    166.129}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{312.176, 
                    166.129}, {310.78099999999995`, 161.605}, {308.805, 
                    157.07}, {306.367, 157.414}, {305.199, 159.988}, {308.68, 
                    160.316}, {312.176, 166.129}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    305.48799999999994`, 158.078}, {306.512, 
                    160.05100000000002`}, {303.16400000000004`, 161.035}, {
                    302.453, 163.598}, {302.047, 159.934}, {302.387, 
                    157.52700000000002`}, {305.48799999999994`, 158.078}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    305.48799999999994`, 158.07799999999997`}, {306.512, 
                    160.05100000000002`}, {303.16400000000004`, 161.035}, {
                    302.453, 163.59799999999998`}, {302.047, 159.934}, {
                    302.387, 157.52700000000002`}, {305.48799999999994`, 
                    158.07799999999997`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{311.215, 
                    160.961}, {309.227, 156.88700000000003`}, {308.328, 
                    152.20299999999997`}, {305.59799999999996`, 152.883}, {
                    304.578, 156.05100000000002`}, {308.613, 
                    156.71499999999997`}, {311.215, 160.961}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{311.215, 
                    160.961}, {309.227, 156.88700000000003`}, {308.328, 
                    152.203}, {305.59799999999996`, 152.883}, {304.578, 
                    156.05100000000002`}, {308.613, 156.715}, {311.215, 
                    160.961}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    305.03099999999995`, 153.656}, {306.207, 155.812}, {
                    302.855, 156.57399999999998`}, {302.03499999999997`, 
                    159.547}, {301.59, 155.656}, {302.008, 152.883}, {
                    305.03099999999995`, 153.656}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    305.03099999999995`, 153.656}, {306.207, 
                    155.81199999999998`}, {302.855, 156.57399999999998`}, {
                    302.03499999999997`, 159.547}, {301.59, 155.656}, {
                    302.008, 152.883}, {305.03099999999995`, 153.656}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{299.305, 
                    181.238}, {297.34400000000005`, 180.71099999999998`}, {
                    295.28499999999997`, 182.91}, {296., 186.207}, {298.242, 
                    185.648}, {299.27, 183.61299999999997`}, {299.305, 
                    181.238}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{299.305, 
                    181.238}, {297.34400000000005`, 180.711}, {
                    295.28499999999997`, 182.91}, {296., 
                    186.20700000000002`}, {298.242, 185.64799999999997`}, {
                    299.27, 183.61299999999997`}, {299.305, 181.238}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4vJ986X0JYsdVn+85Jt0J83hgtLtn3VixQ4z
8oSaD+xLc7jv3zs9j6XYgQEE9qQ5eDysElnHWeywt2SyBMuzNIdPQG0CfFB5
jnSHDseEpxeAfP27KmyNiulw9a2vA3fI2aY7LJt9RGEDU7GDbFSK9f34dIdF
rts+/wWaXy2yzv3hrHSH497mnY5cxQ5FGRPf1mxOdwC64tRC/mIHH6Bwwtl0
B5CwvWKxA9f1xQW2+9IdtNvFbp4Duv/mue/Bj1emOwiD1AtC5SdB1QP5YDoR
6j6g/97V2JvGeaU7XK14qWYoV+wA9KVQswaUL1PsEManu2nu7zQH9PABACpY
gi4=
                    "]]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4vJ986X0JYsdVn+85Jt0J83hgtLtn3VixQ4z
8oSaD+xLc7jv3zs9j6XYgQEE9qQ5eDysElnHWeywp2SyBMuzNIdPQG0CfFB5
jnSHDseEpxeAfP27KmyNiulw9a2vA3fI2aY7LJt9RGEDU7GDbFSK9f34dIdF
rts+/wWaXy2yzv3hrHSH497mnY5cxQ5FGRPf1mxOdwC64tRC/mIHkHDC2XQH
kLC9YrED1/XFBbb70h2028VungO6/+a578GPV6Y7CIPUC0LlJ0HVA/lgOhHq
PqD/3tXYm8Z5pTtcrXipZihX7NA3HehhDShfptghjE9309zfaQ7o4QMAKQCC
LQ==
                    "], CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4gtKt3/WfSl02D9fSv+uS6rDlhNl++YzFDlk
THxbY6+Y6uBt3umYIFnkELvLk4fJPNUBrJ6tyIEBBDJSHSZLsITxfS90COfT
3TS3P9Vhkeu2z38fFELkN0D13y+EiN9IdXi8dPYRhXtQ+3jSHKpE1rk/PFfo
YAWyODoNou5AoQPX9cUFtmVpDsuAyjdsKnTYCnLXpDSHqxUv1QwXFTrMyBNq
PpCV5qB/V4WtcWOhg0xUivX9cKj6Q4UOws0HTi10THPQbhe7ee5socM3jZj+
Q09THexABgP5F0H+OJTq8OmSb5IA0H5VtsapzkD3K2woypj4vNCBG2R/FtS/
SOEDAIZxjIA=
                    "]]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4gtKt3/WfSl02DdfSv+uS6rDlhNl++YzFDlk
THxbY6+Y6uBt3umYIFnkELfLk4fJPNUBrJ6tyIEBBDJSHSZLsITxfS90COPT
3TS3P9Vhkeu2z38fFELkN0D13y90WAwSv5Hq8Hjp7CMK96D28aQ5VImsc394
rtDBCmRxdBpE/4FCB67riwtsy9IclgGVb9hUCHHXpDSHqxUv1QwXFTrMyBNq
PpCV5qB/V4WtcWOhg2xUivX9cKj6Q4UOws0HTi10THPQbhe7ee5socNXjZj+
Q09THexABgP5YH8cSnX4dMk3SQBovypb41RnoPsVNhRlTHwOtT8L6l+k8AEA
hLmMew==
                    "], CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4q0nyvbNlypy4Lq+uMC2LtVhep5Q8wG1IodL
Srd/1kWlOny65JskYFXkoMrWONU5P9Wh9XXgDjn9IodekMIVqQ6yUSnW91WL
HB4vnX1E4UKqQ7XIOveHKkUOGRPf1tgzpjkc/qoR0w8zXy7N4WrFSzVDniIH
bhDfK81Bq13s5rnPhRB9eWkOfLqb5r5/Wujgbd7pmNCZ5gB0zamF1wsdvgGN
ObQ0zcFyC9DBpwsd3tXYm8Z1pUH03Sh0UDfkWCNTlOYA1PX0wotCiH1BaRB3
/Sp0APtTK83B/WGVyDrmIoc+kPt50hyEQeaLFkH0X0p1sAKZz1vkEApyyOJU
B/TwAQAz4ogA
                    "]]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4q0nyvbNlypy4Lq+uMC2LtVhep5Q8wG1IoeL
Srd/1kWlOny65JskYFXkoMrWONU5P9Wh9XXgDjn9Ioc+kMIVqQ6yUSnW91WL
HB4vnX1E4UKqQ7XIOveHKkUOGRPf1tgzpjkc/qoR0w8zXy7N4WrFSzVDHijf
K81Bq13s5rnPhRB9eWkOfLqb5r5/WujgY97pmNCZ5gB0zamF1wsdQMYcWprm
YLkF6ODThQ7vauxN47rSIPpuFDqoG3KskSlKcwDqenrhRSHE/KA0iLt+FTqA
tM3XSnNwf1glso4Z6n6eNAdhkPmiRRD9l1IdrEAKeYscQkEOWZzqgB4+ADLS
h/4=
                    "], CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4sdLZx9ReFLkMD1PqPmAWZqD4oaijIlPixxW
fbzkm8SS5pAx8W2N/cUih+Pe5p2OP1Idrla8VDO8VAQRd0xzmCzBEsZ3ucjB
4K4KW2NvmsMnoDaBd0UOqmyNU50vp0HE70L57ukOnY4JTy9cKXJgAIGGdAeQ
9RuAfLA7XqQ78Olumvv+ZpHDhENfNWLkMxxAVP+9Igeu64sLbMMyIOZ/KnIA
2m4aZ5ThsAyk/1WRQxhII3uGw0Wl2z/rHhU5qBtyrJG5lg5x75siB5C1SuXp
Dg/8e6fnAfX3gwwGuqd833wpfdZiiP/2pDnE7fLkYXpc5NALCpCKNAf08AEA
G6SKkQ==
                    "]]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4sdLZx9ReFLkMCNPqPmAWZqD4oaijIlPixxW
fbzkm8SS5pAx8W2N/cUih+Pe5p2OP1Idrla8VDO8VAQRd0xzmCzBEsZ3uchB
/64KW2NvmsMnoDaBd0UOQN5U58tpDgYg8btFDmogvnu6Q6djwtMLV4ocGECg
Id0BZP0GIP8JiPEi3YFPd9Pc9zeLHCYc+qoRI5/hAKL67xU5cF1fXGAblgEx
/1ORw7sae9M4owyHZSD9r4ocwkAa2TMcLird/ln3qMhB3ZBjjcy1dIh73xQ5
OAGtVSpPd3jg3zs97xPUfKB7yvfNl9JnLYb4b0+aQ9wuTx6mx0UOfdOBAVKR
5oAePgAdlIqX
                    "], CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4k7HhKcX1hQ5ZEx8W2Pvm+5gueVE2b71RQ5x
uzx5mOTTHbzNgSoOFznMyBNqPiCV7uDxsEpk3d4ih+MgiZh0h9znv1d+3FEE
UTcx3eHx0tlHFHZAzduJUN87HWjAk3SHqBTr+/5HixwuKd3+WSeVATH3UJED
SPpAWYbDZAmWMD6g+tbXgTvk5mZAzNle5PBNI6b/0NEMh0+XfJMElhQ57C0B
qlyXAbEP6H6u64sLbPsyHBa5bvv8dwvUPZkZDgZ3VdgatxY53PlZl7VHJgMi
DvQfWN0PqP+WF0HMOZLuoLChKGPiSqj5dekOsPDxAakDhg8A6B2OBw==
                    
                    "]]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4k7HhKcX1hQ5ZEx8W2Pvm+5gueVE2b71RQ5x
uzx5mOTTHbzNgSoOFznMyBNqPiCV7uDxsEpk3d4ih+MgiZh0h9znv1d+3FEE
UTcx3eHx0tlHFID8TJB5OxHqe6cDDXiS7hCVYn3f/2iRwyWl2z/rpDIg5h6C
ml+W4TBZgiWMD6i+9XXgDrm5GRB3bS9y+KYR03/oaIbDp0u+SQJLihz2lABV
rsuA2Ad0P9f1xQW2fRkOi1y3ff67pcjBB+SezAwHg7sqbI1bixzu/KzL2iOT
AXEn0H+LQep+QP23vAhizpF0B4UNRRkTV0LNr0t3gIUPWB0wfADplY4I
                    
                    "], CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYCYj7dTXPfFxc7CDcfOLVwZrLDcW/zTsesYoeL
Srd/1jUlO4DlI4sdXLpznv+emOzQ6Zjw9EJGsUPGxLc19huTHRa5bvv8t6TY
4RJI/SkovwCq/1Kyw33/3ul5FVD1H5MdLLecKNtXX+wQCjJYOMUBZF0CkA8S
nq+W4nAMJNBR7ACyRsk+xeHx0tlHFCYUO1wAmReWAnHP7GKHrSD1dikODCAw
pdjBCaReO8Xh0yXfJIGuYgfZqBTr+0Dzwe7tKXaYkSfUfIApxWE6iG4rdlj9
EajwTbKDwoaijInVxQ43z30Pfnw0GWJ/XbHDN42Y/kMbof5HCh8A/bGSfA==

                    "]]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYCYj7dTXPfFxc7CDcfOLVwZrLDcW/zTsesYocL
Srd/1jUlO4DlI4sdnLtznv+emOzQ6Zjw9EJGsUPGxLc19huTHRa5bvv8t6TY
4SJI/SkovwCq/1Kyw33/3ul5FVD1H5MdLLecKNtXX+wQCjJYOMUBZF0CkL8V
KDxfLcXhGEigo9gBZI2SfYrD46WzjyhMgJoflgJxz2yoersUBwYQmAJVr53i
8OmSb5JAV7GDbFSK9X2g+WD39hQ7zMgTaj7AlOIwHUS3FTus/ghU+CbZQWFD
UcbE6mKHm+e+Bz8+mgyxv67Y4ZtGTP+hjVD/I4UPAPqZknk=
                    "], 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{294.92999999999995`, 137.11299999999997`}, {
                    292.977, 136.15200000000002`}, {291.4959999999999, 
                    133.754}, {291.39799999999997`, 131.805}, {
                    291.22999999999996`, 129.555}, {290.90999999999997`, 
                    127.66}, {289.89799999999997`, 126.062}, {291.504, 
                    126.508}, {292.27299999999997`, 129.07}, {292.504, 
                    131.523}, {292.734, 134.059}, {294.10200000000003`, 
                    135.16}, {294.92999999999995`, 137.11299999999997`}}}]}, {
                   
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{294.92999999999995`, 137.11299999999997`}, {
                    292.977, 136.152}, {291.4959999999999, 
                    133.75400000000002`}, {291.39799999999997`, 131.805}, {
                    291.22999999999996`, 129.555}, {290.90999999999997`, 
                    127.66}, {289.89799999999997`, 126.06199999999998`}, {
                    291.504, 126.50799999999998`}, {292.27299999999997`, 
                    129.07}, {292.504, 131.523}, {292.734, 134.059}, {
                    294.10200000000003`, 135.16}, {294.92999999999995`, 
                    137.11299999999997`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{290.863, 132.406}, {289.512, 129.914}, {287.625, 
                    128.965}, {287.527, 127.113}, {287.363, 
                    124.98400000000001`}, {287.203, 124.87899999999999`}, {
                    286.625, 122.785}, {288.215, 123.20700000000001`}, {
                    288.617, 123.348}, {289.047, 126.531}, {289.309, 
                    128.76999999999998`}, {291.10200000000003`, 130.348}, {
                    290.863, 132.406}}}]}, {
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Thickness[0.0008333333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{290.863, 132.406}, {289.512, 129.914}, {287.625, 
                    128.965}, {287.527, 127.11299999999997`}, {287.363, 
                    124.98400000000001`}, {287.203, 124.87899999999999`}, {
                    286.625, 122.78500000000003`}, {288.215, 
                    123.20700000000002`}, {288.617, 123.34799999999998`}, {
                    289.047, 126.531}, {289.309, 128.77}, {
                    291.10200000000003`, 130.34799999999998`}, {290.863, 
                    132.406}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{248.824, 
                    109.34400000000001`}, {248.066, 107.91400000000002`}, {
                    247.195, 105.73400000000001`}, {245.61299999999997`, 
                    106.133}, {245.59, 107.23}, {247.32000000000002`, 
                    107.988}, {248.824, 109.34400000000001`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    246.47299999999998`, 108.85499999999999`}, {
                    243.40200000000002`, 107.598}, {240.754, 
                    107.91000000000001`}, {240.42600000000002`, 105.98}, {
                    243.30100000000002`, 105.66799999999999`}, {
                    244.35500000000002`, 106.85199999999999`}, {
                    246.47299999999998`, 108.85499999999999`}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{259.32, 119.008}, {257.254, 117.316}, {255.914, 
                    115.383}, {255.289, 112.887}, {254.637, 110.559}, {
                    253.71899999999997`, 108.703}, {252.375, 106.613}, {
                    254.566, 108.10499999999999`}, {255.941, 110.141}, {
                    256.633, 112.586}, {257.23799999999994`, 114.992}, {
                    257.949, 116.793}, {259.32, 119.008}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{256.777, 119.016}, {254.562, 
                    117.24600000000001`}, {252.47299999999998`, 115.242}, {
                    251.848, 112.742}, {251.195, 110.418}, {
                    250.80100000000002`, 108.637}, {249.309, 106.324}, {
                    251.648, 107.816}, {252.578, 110.074}, {253.266, 
                    112.52}, {253.871, 114.926}, {255.258, 116.727}, {256.777,
                     119.016}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4mqRde4P9fIdmg+cWujqF+Nw+2dd1h6DfAeu
64sLbLNiHFTZGqc6q+c7zMgTaj7QFONgteVE2T7pfAfn7pznvztjHHzMOx0T
WKHys2Ic4nZ58jC9z3PonQ4UWBHjsG++lP7dG3kOC123ff67JcYhnE9309z9
eQ7S+ndV2A7GOICoxo15DotA8nNiHLxB5gH5GRPf1ti3xkBoIP+bRkz/odgY
h1UfL/kmbchzEAU6u8oGod6Lh0m7XS4G4o5NeQ5A065U/Ix2AOo2jduW5yDX
+jpwx7doB3VDjjUyh6D2f4yG2HslzwHk3AOvoiH2vc1z8EsSiLB8Eu1wHGQB
Q75DLMhfp6Mh4cGfD/HfjmiIu2TzHZ5eULr98xhUv2q+QzGI8Rxqn1Y+1JwY
hzug8NXJh9hvGOOAHv4AioCw8w==
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4hl5Qs0H5PIcmg+cWujqF+OwyHXb578yeQ5c
1xcX2GbFOKz6eMk3SSXPYSFIvCXGYeuJsn3z9fIcRNa5P6zqgfKd8hwyJ76t
sZ8b43BB6fbPurA8h4dVQBULYxyKM4AS2XkQen6MQzVIY1Oew3Fv807HBTEO
t37WZe3pyHP4phHTf2hqjMO++VL6d4H8vSWTJVjqoO4B8uVaXwfuCIuBqOvM
c+idDnS4AUI92B9CMQ5hfLqb5rbnORjcVWFrfBvtwAACQHmQ8gOvoiHitXkO
IOfYP412KLQF+jQnz0EeZP69aAerLUAP+edB7L0TDXGvXZ7Dprnvlx87HO0A
cnaCIdR/G6MdXLpznv9WzIPYcwAqrwh1z6NoB2FQwCpCzfsTDXG3Qp6DtD7Q
IYYxDujhDwA/rLai
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, {{{262.832, 
                    90.67999999999999}, {262.871, 89.73400000000001}, {
                    262.97999999999996`, 88.977}, {263.543, 88.215}, {
                    260.28099999999995`, 89.523}, {255.676, 88.824}, {
                    252.52700000000002`, 87.35499999999999}, {251.125, 
                    86.68799999999999}, {249.42600000000002`, 
                    88.12499999999999}, {251.07, 89.48400000000001}, {253.414,
                     91.383}, {258.83599999999996`, 90.309}, {262.832, 
                    90.67999999999999}}, {{216.82800000000003`, 90.73}, {
                    216.875, 89.84}, {216.76999999999998`, 89.023}, {216.441, 
                    88.24600000000001}, {219.98800000000003`, 
                    89.71100000000001}, {223.79299999999998`, 88.492}, {
                    227.375, 87.051}, {229.836, 86.031}, {230.035, 87.793}, {
                    229.602, 88.402}, {228.85200000000003`, 
                    89.48400000000001}, {227.406, 90.67199999999998}, {
                    225.578, 90.699}, {224.359, 90.715}, {219.672, 90.758}, {
                    216.82800000000003`, 90.73}}, CompressedData["
1:eJxdVGtIFFEUls0sSiTLomSxB2ZGhPlDzEr8Qq2sSKzmrrurJmbQzr7uloSZ
Wr4ICdGyKBIxs7RILKRErFRE7AGFWRZiZiYqlSWRFiZh93oGAgdmds+c13fO
991ZneLcf0Tn5uYWKW75u/BdFQ/PsOKKY3Feq86MB09PNFeYrHicVrrc3c+M
npe/DwyGWFFfPlbTMceMlgrfoD4fK3Z76jacbTZhXfD8Wn21iqPnv2VGDBkx
eLOsfZW/iqyIkKQmbyMCPHIuRT60wCL99njyX7RgIMOnbud6zbZZUKs3pW69
a0BSU4ynbolWL8SAgq9xjX4rVByUgZsMOCXSBi6oiJH93zK4yeuj5u9kOC4T
p1W8WtM7md3FUNI2EZggbJmWkcYQ1OfvkTOpYq3EZWZ4sie0cPuoquFhNO+E
SvMvY4SnV7OHFbJbVPhJYA0Kvf+gouHn3zfpJxXCM67ikIyrUhB1zjYyFWdF
XuvzyugdDF0S1xcrfgUmFLf1Kdgr2idn2cifrdA+rtmQKPOtCgxeG+vL+20o
uiwI4lp/Yc/g7pzl36zNN9eOBZLXXAZXuPint6MyWiDMZxQXb6d8zojPMw7C
b2HU/70DW+4LIZxmkGHJ3k7CW8TAZT0fJ839XSF+gp0Y7hSD1SkQ06mPopzE
X4FCfUqcIJ1p87U7MS2vGoXilnLifx6DePbHHv5vz9TP49iXsig+rFZBd/rn
gOASTnzmK8TzVU59bygQqJhXKSe9vVBoH4VavDvDLkm0sEnfDPaRqds/8jky
pV5jGK7LPaVz2v8dRvVzOZ2PNkb1i7X4ZwxSXsV6F/kXG6h+jIvOy2sD+mPF
xv1cpC9XPMUPc03fRshn0i1O+/ljhNj2UOcxTudnwIRGKbRUbR8rzagW67tn
4giT/ISaqf42rvFuJv21Omn+RBPpq9tBc3wyEq9jduK7x0jn19dO/HYb0SH5
GrdiVKy9oMyE2d+Hf6Gf21o=
                    "]}]}, {
                    FaceForm[{
                    RGBColor[0.741176, 0.41960800000000004`, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {CompressedData["
1:eJxdUl1IVGEQXZbUKJOIHiTDVCoEsdUHkUV0j0WILSn9sH73Q9Iszd3b6nct
wmR7iIooaEUi+iMMonyRkAgpoU0k/CkoH5J+VGRZLSS1B6Mo0fpm50LRhcvc
YWbOnDnnZtY17693OhyOXP1SvN604Vz/QYWKuvXCPS0hjxZNVe5V6F1cftsa
lShZ8+6e2q0w6C28VPpeIqOnpbHDo3CisWM+9EbiBs3fasan0azxnzskIp2b
XJPDTdhy4cu+JxEDNF68EOT+5wbXU4MYIrx+AxRq3cfxPbu6faBAwiqmCZNx
P0rQmKfexMaHZdE2zS92//aLDGGipq882RmT2Fk7M5rlNVFJ/Ccknp28mrqq
xGS8MQmikZ5v8j0jEorws01E2zTiU8m8XgU4/jbwePhUpLMhgK2JZ6/t8hpY
S/x/+bneJfDh9Y8DsVk/9iQ7cy6GBfOd8/P9FQKlxCcpwPhugc0k6D95mASf
COAKxbtVcNDTbbL+532s14qtV7sP+hpfSo6ydfYhb5KYKdavpwpx/77ZfrgE
XFRfUjjjKTjUp/cthPSH00IaFcoFMsm/BIv5HBasT5IFP+kcFOyvzk/Pbs9f
HRKYp/lEi/dctvv1fFzPm4J5afwZuv+B3b+i2IdegZTcR3e+Lv/N43oMKaQT
UIPB94cVdFfX4KKBddR/TPG+lxJlRPSIwjbyQ/s91qqJVSt0E9Bnif//3z91
0Dt+
                    "], CompressedData["
1:eJxTTMoPSmViYGDQBmIQ3fo6cIdcaIHD3pLJEiznohyEmg+cWhhd4NA7PU+o
+UKUw6GvGjH9CQUOIuvcH1adiXIAq0+Gqt8X5fDpkm+SQFeBQ629adyuh5EO
S2cfUdhwpMBh09z3y48FRzrslAPq+FXg4JckEGG5JMLhasVLNcN/BQ5rZKJS
rKdHODCAQSFEfXeEwwygtQeAfDDdFOGgf1eFrZGxEGJ+ZYQDUNd9fyAf5IzW
4giHHSDzgerB5udEONz3B7ocaP43oLMPxUY4dDomPL3wA2qfP9T8T1D3u0VA
3DepwCFj4tsa+6PhEPdpFTg8rAL6eGOYA9f1xQW2/3Ih6peFOVxUuv2zbl02
xJxZUPlHWRB3bg13kAU5kDvLoRhkINA+cDj+yITw4yMcuEHqf2U6xO7y5GHq
hvkvC2L+tAgInZfl4NKd8/y3ZaTDY1CAXslyeHYBaPG7SIh6w2yI+1ZGOYC8
dd88G2p/lIO6IccaGadsh+Pe5p2OB6IcDEDivtkQc49FOdz6WZe1JyIbEt6n
oxz2z5fSv5uS7XAbJA6M30JboI9yEOqBoWIaZ5YDMU8hCiIulutwDMRfEQkx
/20uxH/LIyH2n8pzAAXrjmVQ/rx8iHqJKAeFDUUZEx2h4bszChLu7gUO2z7/
vVJxMMphy4myffP9ChyApk51Pg1Nb0jpEwCygSyW
                    "]}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4gJbruuLf2Q5qLE1TnXuznGoElnn/vBblsNF
pds/69blOBjcVWFr1M12yJj4tsZ+Y46DKkiderYDUDZrTwOUL5/tcMzbvNPR
JccBRCXMzHZwSnh6QWl1tkMRSOPibIc7IPU+2Q7vauxN41ZlQ8zlzXZ4C+LX
ZTuoG3KskbmW5TAjT6j5QFC2Qyif7qa5m7McfEDmyWY7cF9fXGDbBXXn6SwH
2agU6/v9WQ7750vp312S5RAGUr88y0G4+cCphb1ZEHt2ZTn0TgcaWAHl/8py
uHnue/DjziwHyy0nyvYJZzswgMCELIfjIIfLZEPMXZ3l8E0jpv/Q1iyH1teB
O+ReZkHcty3LoQ9knk22A0j7fCAfrL8hG+LOr9Bwa4KGFzDcwOHZlg0R74P6
E+iOVR8v+SZp5Dighz8AGsWr8g==
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    223.39100000000002`, 220.84}, {223.824, 221.148}, {
                    224.512, 219.805}, {224.02700000000002`, 219.469}, {
                    223.621, 219.19899999999998`}, {222.83200000000002`, 
                    220.465}, {223.39100000000002`, 220.84}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{224.55100000000002`, 223.566}, {224.336, 
                    223.461}, {223.90200000000002`, 223.61299999999997`}, {
                    224.031, 223.797}, {224.641, 224.668}, {225.941, 
                    225.98000000000002`}, {226.883, 226.43800000000002`}, {
                    227.172, 226.578}, {227.68, 226.066}, {227.504, 
                    225.816}, {226.93800000000002`, 225.012}, {225.566, 
                    224.062}, {224.55100000000002`, 223.566}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{234.625, 231.559}, {234.86700000000002`, 
                    232.066}, {236.316, 232.637}, {236.68800000000002`, 
                    232.977}, {237.031, 233.32800000000003`}, {237.191, 
                    232.68}, {237.047, 232.375}, {236.805, 231.871}, {
                    235.55100000000002`, 231.02}, {235.004, 230.996}, {
                    234.707, 230.984}, {234.477, 231.254}, {234.625, 
                    231.559}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{238.07, 231.39800000000002`}, {
                    238.38700000000003`, 232.285}, {239.40200000000002`, 
                    233.629}, {240.098, 234.07}, {240.45700000000002`, 
                    234.297}, {241.102, 234.121}, {240.98000000000002`, 
                    233.781}, {240.71099999999998`, 233.02700000000002`}, {
                    239.47299999999998`, 231.71499999999997`}, {238.637, 
                    231.098}, {238.383, 230.871}, {238., 231.195}, {238.07, 
                    231.39800000000002`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{235.121, 229.184}, {234.91, 229.078}, {235.023, 
                    228.63299999999998`}, {235.227, 228.562}, {235.656, 
                    228.418}, {236.441, 228.39100000000002`}, {236.797, 
                    228.586}, {237.312, 228.906}, {237.078, 230.863}, {
                    236.38700000000003`, 229.816}, {235.92200000000003`, 
                    229.172}, {235.586, 229.379}, {235.121, 229.184}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{229.289, 224.68800000000002`}, {
                    228.23399999999998`, 225.508}, {229.57, 226.66}, {230.672,
                     225.85500000000002`}, {232.82000000000002`, 224.238}, {
                    227.47299999999998`, 218.035}, {224.562, 
                    215.13299999999998`}, {224.02700000000002`, 214.566}, {
                    223.562, 215.996}, {224.242, 216.61299999999997`}, {
                    226.33200000000002`, 218.383}, {228.285, 220.496}, {
                    229.641, 222.68}, {229.90200000000002`, 223.102}, {
                    230.15200000000002`, 224.008}, {229.289, 
                    224.68800000000002`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxNUl9I1EEQPq+4QqSgfBAzKbGSQlRQJEL87IiI6qHCAhERKYh2ZtSMHvII
vOgoMCSkf2QdFWdRcQ+hEVFymGD0EFIPJSVxiC+KhR0mQVG7N0v0g2V3fzP7
fTPfNxvb2g8eWxYIBHLs2mZX0K7pxM2xDZWCTz/PnniRIjxceLe/rVow+Xbp
0PQk4eTxy/ORFYLxvbUXG2x86PXpkXhIsPZc6s2dNCH3w72OOnvfFOq5Es4Q
Dq8qf3KrVnDE7X8IjxzePsFmF58jzWsXFDUd3fFlnHB+7sCz4kZBto5eQsvz
PXnBdaJ1XCAMO75ZVp4YaV03GI0OP0zYUrXycdEgY42rp4YUZ4j1fSnhR1lz
32iVYCReWDFVQLguNvOM/Itn67gvyrOVMB+pr2m5LcoX9Hgdgs9On18GfaOL
Zc1h0T6XDLrzk7vTxaJ92ni2n0XWPr8ZrHf4rxhOxvq0Ufwko6F1ZqIkbrDT
7f2MiRLrQMzg7q6nmd+9vt+oQWedPUVY6xjwfFFWHRJG311l9W/M6P9hVt6M
waVrtuGPDGdfa4736yurbrnenwFW3jwfj3r98gmVU6WhHmbVp9DPQ5fPryZ0
uXs3Y7sbDOvHy1P9BctjPr/J+/2eEXDfA6/vd4YrKzVIOierBRWOJ0GqU7ko
TtLr/998/gXD6ULx
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{245.566, 229.816}, {246.023, 
                    230.21499999999997`}, {246.254, 230.88700000000003`}, {
                    246.73, 231.29299999999998`}, {246.99200000000002`, 
                    231.555}, {247.406, 231.242}, {247.34, 
                    230.61299999999997`}, {247.281, 230.11299999999997`}, {
                    246.61299999999997`, 229.68800000000002`}, {246.164, 
                    229.312}, {245.80100000000002`, 229.039}, {245.375, 
                    229.629}, {245.566, 229.816}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{250.742, 
                    231.656}, {251.418, 231.73}, {251.586, 
                    230.42600000000002`}, {250.848, 230.21499999999997`}, {
                    250.40200000000002`, 230.066}, {250.008, 231.578}, {
                    250.742, 231.656}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIxIGYC4oyJb2vsFfMdGECgJMdhkeu2z38VoPyAHIet
J8r2zTfKd+g/9FUjJjjHoXd6nlBzSL5DgS3X9cUhOQ4+5p2OCaX5Dt80YvoP
heY4AEULbCflO1huAWoEqlc35FgjA+Q/Xjr7iALQfJfunOe/J+Y73Dz3Pfjx
1ByHYpAD6vMdVNkapzpvhqqvyndY/fGSb9IchPlVIuvcH7blOOjfVWFrLMx3
COXT3TQ3GerelHyHuF2ePEzFOQ5g/0RC7WvIgdgTC5VvznEQbj5waqFnPsTc
3BwHoGrTOLt8iLmJOQ6trwN3yNlC3VMMlTfLh/irDqrfMN9h/3wp/bstUPuA
4Qd2RwWCDwtPADINlWE=
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxNU2tIlEEU3d22LVqTLfwR0dOsllIkUiJDOrVFaRqk0A8zWaXt4f2Y2exB
UQgS/hARi5KCCCsr6EFhmJSamURFRIVE2yYisvQuwiJjiahv9l6rD4aPmbn3
3HPPuTO7QheFxjgcDqe9cuzlstf2I58PLs9W2Jk7IdLSRaj9uOHmjAzF/wZC
2JxnKfSl9ser8wl3mqdmDhQojPhLG3vzCGUdeUkuUngVr67sWktI4F2U+1bC
cTX5UM99hQfrltSteEe4NNxXWPFSoe3h3u5mj8X3IwrTS7YsG/RamL9o/JVp
HxRi50/em/WJsNngRxTmeWqaAp3Cx86/YfKLCJkDaZ6a95K/mPj8q0Jj73d/
6RxCgV02mK2xMvj6WWqAmAc0x5UQ5xVrxqmVfUBzneeEE4Zfvua+3cJvvUaD
IZ5mMS4J/kKLcXZo7n+ixX1u1axLlPi8XKPb4O0TfiHNehcSNiZnXD+1TcNh
vizCLpN4TeNAytU1Q8mid6fm/ybx667s6wnRJz+KY1ENb6QlnNsh+1sah40e
Xwi3dx+d4r4g/H2W6Ktx2fiSZDHPYcEbFD2cYfajR/gP6b/zkYiLadgqPToT
Evw30p9f/G/XMFNW5iGue0zixwq/PRpnV7d/++WWfbn4s4Bkrkb1lflLl/h0
8dOnmefvSuYfVzDHQSexjqcVqszFOMJcM0dPFVbVW29/1hH31aZY51H9mhT7
YveX8LtKIccY6f03/4k59kl9v0K/4Zki8S7B3y/zOUnuz0n9mfLeHhPzXKpY
txfyfv57j38AmbmZ6A==
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJVIGYCYh/zTseEp/kO3NcXF9h25TjcPPc9+PHOfIfb
P+uy9izJcXi8dPYRhRf5EPGXOQ5g9X/zHYSbD5xaeDHHIWPi2xp74QKHVR8v
+SYtyHFgAAGNAodikIR2jsN9/97peWYFEP2KOQ5CIH32BQ5WW06U7ZPOcSjf
N19KH8g/7g00uCLHweNhlcg61wIHLpB7FuU4yEalWN/3LHAASScczHEAaZsf
U+CgytY41Xl7jsNkCZYwvsgChwmHvmrE9Oc4aLWL3TwXXuCgbsixRqYpx+GC
EtAnDgUOcbs8eZheZzvslGt9HehU4AAkd8g9zXZ4AHJfUIEDkBRqXgLlJ0HV
J2dD9OcUOHwDmn5INtthGTA4NhQUQNz1P8sBpO1AXAHE3yLZcPeB7ZfKhvgv
sMBhNSh8bLIh9tpC3bsfwQf7b2c2xFzjAki4xmZDwsmwwMGlO+f5b8dsB17d
TXPfqxc4WILEP2c55D7/vfKjSoHDDJA7bmU5XAS5VwgaPvezHEDRt0EMah83
1P1S0PDXz4aEnyk0vB9lOyhsKMqYCLS/COSA59kOHcDUcUGuAJIeDKDxwV3g
sBXkzyxoekBKPwAl7Amg
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIxIGZigAKpAoeMiW9r7B9mOfDpbpr7XrjAYeuJsn3z
H2U5XFS6/bOOq8CB6/riAttjWQ4z8oSaD2gUODglPL2gtDvLofV14A65wAKH
vulAiTVZDt7mnY4JtQUOlluABhzPcqgWWef+sKvAIXaXJw+TeLbDA//e6Xmz
oPaVZjssnX1EYcMSqH3nsh1AxhxYU+Cw6uMl36QP2Q5VIP3bChzCQA4Tz3GQ
jUqxvn+4wKEXpFAkx2GnHNAFuwocbp77HvzYN8dBYUNRxsTNBQ6OIPeV5zjk
PP+98uMyqPlZOQ47QOqB9hXYAn0UkgNxx1yofRI5EPc1FTh804jpPxSa7fAJ
KCxQVeDg0g00yTAbYl9WgUMhSP8HaPh4FUDcfS3LAT08AU9cpAo=
                    "]], 
                    
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{262.68, 224.742}, {
                    262.40999999999997`, 225.324}, {261.777, 224.875}, {
                    261.89099999999996`, 224.242}, {261.957, 223.668}, {
                    262.42599999999993`, 223.35500000000002`}, {
                    262.89099999999996`, 223.371}, {263.445, 
                    223.39100000000002`}, {264.617, 223.35200000000003`}, {
                    264.617, 224.27299999999997`}, {264.621, 224.918}, {
                    264.113, 225.45700000000002`}, {263.734, 224.742}, {
                    263.375, 224.098}, {262.914, 224.168}, {262.68, 
                    224.742}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{263.312, 227.176}, {263.117, 
                    227.04299999999998`}, {263.29299999999995`, 226.324}, {
                    263.52299999999997`, 226.33200000000002`}, {264.348, 
                    226.359}, {265.51599999999996`, 226.621}, {
                    266.14500000000004`, 227.059}, {266.328, 227.184}, {
                    266.25, 227.617}, {265.98799999999994`, 
                    227.60899999999998`}, {265.195, 227.58200000000002`}, {
                    263.92999999999995`, 227.605}, {263.312, 227.176}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{270.32, 225.36700000000002`}, {
                    270.91799999999995`, 226.30100000000002`}, {272.566, 
                    226.395}, {271.97299999999996`, 225.062}, {271.555, 
                    224.14499999999998`}, {267.449, 216.21899999999997`}, {
                    266.89099999999996`, 215.21099999999998`}, {
                    266.28099999999995`, 214.078}, {265.78099999999995`, 
                    214.641}, {266.215, 215.523}, {266.79699999999997`, 
                    216.656}, {270.133, 225.094}, {270.32, 
                    225.36700000000002`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIlIGYC4p1yra8Dmwoc1A051shsynLQv6vC1lhf4PC2
xt407liWg0xUivX9/AKHY97mnY5PshyEmw+cWlhY4MB1fXGB7bosh+l5Qs0H
SgocjoPkfbIcPl3yTRLYUeDglPD0glJ2lsN9/97peWcKHPaWTJZg6ctyyHn+
e+XHewUO1SLr3B8C9VeB6HMFDhMOfdWIkYfa/7zAgQEEBLIcFrlu+/z3S4FD
P0iePcvhgtLtn3V8hRD7dLIcgKaG8UkXOuyfL6V/F2i/drvYzXO2hQ6OIPuX
Zznw6W6a+z640KEX5FCNbAeQtoTSQog9jdkQ9zYVOqz6CGQsyYaYn1fokDER
GAJ7sx1A1vanQdUvzIbQnoUQ9zlAzVMthLizAmrf3wKIftcsB6stJ8r23S1w
eLx09hEFmSwHUHD6A/3HDQq/qiyHqxUv1QyfFUDsnQYNzycFDmpsjVOdV2dB
9N0ocLh57nvw45NZEHOPFzh8Azrr0FpoeO2Ght/sLIfyfcCAWFngsBrkn54s
iPtnQOX7oeHfVwAJjwlZDh2ggGqDug/IR08PAAHY+B0=
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    271.656, 219.258}, {271.68, 219.43}, {270.76599999999996`,
                     219.508}, {270.812, 218.621}, {270.84400000000005`, 
                    217.969}, {271.625, 217.789}, {271.762, 217.883}, {
                    272.99199999999996`, 218.781}, {271.5, 
                    218.33200000000002`}, {271.656, 219.258}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{269.863, 215.664}, {269.621, 215.605}, {
                    269.39799999999997`, 214.83200000000002`}, {269.969, 
                    214.789}, {270.49199999999996`, 214.75}, {272.539, 
                    214.97299999999998`}, {273.105, 214.93800000000002`}, {
                    273.47299999999996`, 214.953}, {273.613, 
                    215.65200000000002`}, {272.828, 215.61299999999997`}, {
                    271.875, 215.566}, {270.625, 215.805}, {269.863, 
                    215.664}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4,
                     3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, {{{220.297, 
                    228.99200000000002`}, {220.621, 228.977}, {221.512, 
                    227.824}, {221.453, 227.461}, {221.414, 
                    227.29299999999998`}, {220.5, 227.48800000000003`}, {
                    220.22299999999998`, 227.72299999999998`}, {220.016, 
                    227.89800000000002`}, {220.098, 229.}, {220.297, 
                    228.99200000000002`}}, CompressedData["
1:eJxNU1tIVFEUncSGEPGjhCIsSrL8CQsKiZCW9LCoPsrqIyYbpYF07+ldHzVI
JgZRqb3ohYjJQEgUlA7TMM6IFJaE6UQMZhIx2IMQiqiICLpnzqrpwuWwz95n
r7XXOmd+zf6tviyXy1Xq/Ga1nyAVvPlo3mVB75FLs7Lf1dn1NPezBaNDPypT
tYIdeYvvt80UfC/2tPQfFcTbZ5eMewVNn7aE5wYFJ/LvVrwdEuyKbMjNSrJu
QnBrbejr72Vq6yYFYz/r66LbFNf2TW/sy1GUjC9wNzQpjpvzCxVdXxKba1oV
a87q+1/lavveUGwsPVPurVW09n8r9uxWVBmcRkVOsvNAWbNi0dJpdwouqsW7
rZbHgOJgmVMRUKzofnIs9oJ9riuK3A1XVqcUaRmiijk796x8M8a+zxXNVx2C
rxUD5sBn4jr5tD5uv+U/yLpcxjHF3guTgVUfFefNfph4o+wfZ/4p54+o1bGP
84cUPQ7N9gjzXezTrdhu9O9Uq+tD9mljfYz7HeT7LKNHWp+EWj/P8dxLxUih
48Qp6pJkXT31GCZfUZR7J4YL7ylmONN2VJOP40+ByVcoWowuDzjHEvo5Qr+L
GE/1W1/zFQ768qoY8fLIJ0jcD7wfJ//2ycSbjI49mTite1T++ZDWoV5w2DSM
895UCV6Z+jD5VIvFCVAvn1gcH+fzi+W1TpEw+gyKvT8ete/gsVh91/MehMT6
O0VxyOBW8r30Eue/9/UH4cqIfA==
                    "]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    197.84, 210.062}, {197.71499999999997`, 209.691}, {
                    198.21099999999998`, 208.68800000000002`}, {
                    198.72299999999998`, 208.61299999999997`}, {
                    199.22299999999998`, 208.57399999999998`}, {
                    199.48000000000002`, 209.69899999999998`}, {199.316, 
                    210.062}, {199.19899999999998`, 210.33200000000002`}, {
                    197.93, 210.32800000000003`}, {197.84, 210.062}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxdU1tIVFEUnaaS6EFZfoSIlVgaRCokQ5m4zB6kVqQQUpNMNoJ7T6Q98KMk
GKwkpKzsScX0oB8NIUmT6CFSk0TEJESFDSZaQ4hCRElE1Dl37wq6cLicc9fZ
e621111QUV1SOdHlck0wy2OW26yhm5cez59FODKyuSv5CeHti/HSocmEp0We
Y/kRwt6qU6N1sSqM1uVll7cTXM5DKDaffVcI39K9TT0zCFNf36jJPU1o+dy3
oQKE1Y27Yj+ChLSsKbeSNhLm1Hc/u3aR8CiUmBH1EZK2+nMG7hJW3OmtfZij
uEUMh08xoSbXVFzGuL6m88vPMu0LxvHzu2fXnyGU31s/3T2ifW5r3WHCdns+
TjjZ8zXd20/C+yNhle9DJGUbCy6T8TKl//uhEhZ9O1l4FLH4QCz4Rpb6Oxgd
5nOondFq9XlZ+L1hHExoWzeYzNJvZkBwbhZ9aQFkRlPjglHCAYtbG5D+z9Xv
+ADC1udh5fuLxUdzv8nuY4x8y8PDsLK7Oxn7LN88hqUbOqf8C/TdwLhgcYkM
B0aqaxojw/LYo+efdE6H1d9ekvNXer+FsNzei6nfVwkP9jfPnTSmfBp0bgPK
s5kQsX6GtZ7BOzxbWfIR1fkHtf8gwaD5vl/rG/1jdk6Fqj9Mwjee/+buz/6E
xV/+t3f89Gv+tqgPpST+1Op8CjVfRxnvbN8lmi+j3+G1mLAwLni2oFrnmkqi
c5PyWar5MT46/0c2ic73msuVuu/SOc7THJp8//9//QaSPJEf
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{197.24599999999998`, 213.016}, {
                    196.977, 212.71099999999998`}, {197.883, 
                    212.10899999999998`}, {198.062, 212.266}, {198.41, 
                    212.566}, {199.766, 214.10899999999998`}, {199.504, 
                    214.648}, {199.26999999999998`, 215.13299999999998`}, {
                    197.41, 216.184}, {197.105, 215.664}, {
                    196.54299999999998`, 214.762}, {198.859, 
                    214.35500000000002`}, {198.5, 214.09}, {
                    198.32000000000002`, 213.98800000000003`}, {197.684, 
                    213.547}, {197.24599999999998`, 213.016}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{200.586, 
                    219.785}, {200.586, 219.785}, {201.168, 
                    217.79299999999998`}, {201.641, 218.621}, {202.023, 
                    219.19899999999998`}, {200.586, 219.785}, {200.586, 
                    219.785}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4tbXgTvkDDMdLLecKNsnnO3wrsbeNE4r04EB
BASyHRwTnl5QEs90uP2zLmsPQ7ZDKJ/uprnKmQ4FtlzXF//Icug/9FUjxjzT
YZHrts9/32Q5ZEx8W2OfCzXvcZaDcPOBUwsTMx1cunOe/+bMdrikBDQpKtOh
d3qeULNCtsMMIHVgU6aDt3mnYwJQHqx/bqbDW5A73LIdwkD2Tc90UGVrnOoc
ng2xpybTIRwknp8NcWdBpoMTyJ3FUPXpmRBzSrMdJoDc553p8E0jpv9QarYD
2L+xUPnYbIi7MjMdQM6dH5btsH++lP7dCZkOViAB+2yHiyD3NkH9bwBVXwj1
L9D9YH1pUP+aZzuoG3KskQnKdHi8dPYRBZNsB5moFOv77pkQcaNsh60g9X6Z
EHtEsh1ugcz1gJrHk+2gf1eFrdEVGj4c2Q4g6oBZJoQWg7ofKb4A4TzGsw==

                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{205.92200000000003`, 224.184}, {205.57, 
                    224.012}, {204.94899999999998`, 223.066}, {
                    204.92600000000002`, 222.63299999999998`}, {204.914, 
                    222.39800000000002`}, {205.168, 222.078}, {
                    205.36700000000002`, 222.176}, {205.73399999999998`, 
                    222.359}, {206.297, 223.254}, {206.316, 223.664}, {
                    206.33200000000002`, 223.92200000000003`}, {206.137, 
                    224.29299999999998`}, {205.92200000000003`, 224.184}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{208.191, 224.434}, {207.52, 225.254}, {208.906, 
                    226.47299999999998`}, {209.52700000000002`, 
                    224.82800000000003`}, {209.906, 223.797}, {213.918, 
                    218.516}, {214.738, 216.72299999999998`}, {
                    215.32000000000002`, 215.512}, {214.71899999999997`, 
                    215.008}, {214., 215.879}, {211.969, 
                    218.47299999999998`}, {210.30100000000002`, 
                    221.70299999999997`}, {208.191, 224.434}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{212.312, 224.32000000000002`}, {
                    213.02700000000002`, 225.094}, {214.48800000000003`, 
                    226.68}, {214.094, 227.562}, {213.79299999999998`, 
                    228.324}, {212.906, 228.24599999999998`}, {212.754, 
                    228.07}, {211.88700000000003`, 227.035}, {213.371, 
                    227.29299999999998`}, {213.156, 226.941}, {
                    212.71499999999997`, 226.10899999999998`}, {
                    212.27299999999997`, 225.65200000000002`}, {212.047, 
                    224.85500000000002`}, {211.99200000000002`, 224.668}, {
                    212.184, 224.18}, {212.312, 224.32000000000002`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{274.53499999999997`, 221.727}, {
                    274.02299999999997`, 222.14499999999998`}, {275.043, 
                    224.164}, {275.72999999999996`, 223.371}, {277.625, 
                    221.18}, {278.508, 214.062}, {279.055, 
                    208.73399999999998`}, {279.055, 208.73399999999998`}, {
                    278.203, 208.02700000000002`}, {278.195, 208.137}, {
                    278.195, 210.977}, {277.055, 219.656}, {
                    274.53499999999997`, 221.727}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJ5IGYC4m8aMf2HGHMdFrlu+/x3So4D1/XFBbbvchxc
unOe/z6Y46DK1jjVWT7XYUaeUPOBSzkOF5Ru/6xTy3XYeqJs3/xNOQ4FtkAd
HlC+XI6DuiHHGplZuQ4XQerWZTsc9zbvdLyR63Dz3Pfgx57ZDnG7PHmYXuc6
vKuxN43TynZgAIE7uQ5hfLqb5opnQ/XlQsw1garvz4WY65Xt4Jjw9IJSfq7D
vvlS+ndnZDuEg/TF5zrIRqVY35+d7RAK4jvnOrS+DtwhtzDboRBkDkOuw+Ol
s48oyGQ7FGVMfFtTDnWnE9T+kBwI7ZPt8BbkrrAcB/27KmyNW7MdgL4+tTA0
B6L/STaEBqoH++cn1H85OQ5WW4AB8D8bYm8uVP4h1Ly8HIdYkD+2Z0PCGage
HO6xUPuX5EDCNyrbAej7rD0XciDmRkDlTXIh7p4O1e8Bja8T2ZBwi86FqPuT
DbFHHOr/RKg9SPELAHwZ1xg=
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{275.688, 209.297}, {276.03099999999995`, 
                    210.25}, {280.578, 217.883}, {281.176, 219.562}, {
                    281.47999999999996`, 220.375}, {282.789, 218.176}, {
                    281.512, 216.98800000000003`}, {280.395, 
                    215.98000000000002`}, {277.09, 210.562}, {
                    276.47299999999996`, 208.66}, {276.188, 207.805}, {
                    275.328, 208.21099999999998`}, {275.688, 209.297}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4g7HhKcXthU6vK2xN40TynY45m3e6Xik0AEk
rFSe7TA9T6j5wJNCh2qRde4PmbIdHi+dfUThRKGD/l0VtsaTWQ5a7WI3z82G
yhdlOVxQuv2zrq/QIWMi0MSzmRDzPAodVn285Ju0JdMhKsX6vr9pocNxkPia
TAcGEBApdPABchOOZkLM5yp0KAIZcDnTYYdc6+tAtkKHffOl9O/eyHTYcqJs
33yeQof9IP6fTIh9EoUOEw591Yh5nemgsAGoU7PQodCW6/riC5kOuc9/r/zo
U+iwFaTvFFQ+vtBhkeu2z39fZEL80V7ooMrWONXZPAvinhWFDnG7PHmY5mc5
wMLnIsgeYPgAAIpRiv0=
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIxIGYCYnVDjjUyu3IdjnubdzqeyXSw3HKibN/mXIdF
rts+/z2S6bDq4yXfpAW5DlzXFxfYHst02AqUnj8v14EBBPZkOjgmPL2gND3X
AWzONIR8tcg694dNmQ5va+xN46blQug4KL8v16E4Y+LbGutMiL4yqH4rqP3l
uQ4gan5YpoNLd87z35VQ9dVQ98zIdQjn0900d30m1J5cB1W2xqnOmzMdCmyB
Li2B6t+W6aB/V4WtMTPX4ZtGTP+hk1D9FVD1lzMdjoH8PQWq/lkmRHxxrkMo
yPzHmQ4XlG7/rNsG1X830wHkDPu9uQ5WIA23ofbvy3W4ee578OOLUP8ghScA
Tmyjwg==
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxdUksohFEUHo8skIUUeYW8IsZGEsYnC4kUitJ4JMr5uxflsfCYmkhZCHlN
iVlo2MjCa6EwSZEibCw0IRsbrChN5L/OXbl1Fvc793zn+865ye09dZ1BFosl
wIwUMwLNeB0pzW9Zl/jMtE+ffBOqCibL2pwSXbNmxkdoOagMD2yVsKhzTTh2
x1p9xRLNCt8gDEdtVTzlSoTerfWWLBLSQpwL5VbJuIP4XYaE1Zca4iTC3vng
kTtRwtUdOeatIxTumkCQrq8h9KnGfsF96wl5qu5V4NmzfJpkJzRG5GyvvAt+
P0Gs61Ew3qP13ArmbyK8KX8XAof9czHBNsKQyu/revP+59MjWJdN843r+nbt
d15gaskEOgg3KfdfjivBvAbx3C513kWYPvnItD8L9rFMaFC6/JpvVff7FqhW
cx4g9hWu5z9KiG/qKHqIljyXMe0/QSJB4TuEMKU7S7Iur+arlThS9xfCmVpg
r2S/P5rfJZGu9hJncH5TYkbpzDbY94HE3z+IMPD/P/wCd4HqJA==
                    "]], 
                    
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJVIGYCYuHmA6cW6uY56N9VYWtszHSQjUqxvs+f51Cc
MfFtTXWmwyLXbZ//iuQ5+Jh3OiaEZjqA1cvmORTacl1fHJDpwAACOnkOLt05
z397ZjoARQtsnfIcHBOeXlByz3TYeqJs33yvPIe4XZ48TMWZDheVbv+s88uD
mNuSCdEXCLVfMhNCV+Y5VIusc3/olOlw3Bto8YQ8iD0xmQ690/OEmk/kObyt
sTeNs8t0eLx09hGFB3kON899D34cC3XvB4R96oYca2S+5UHc3QiVf5HnAHRF
1p4FmQ6trwN3yD3Ng6hbBVV/DuqepZkOEw591Yg5nwfxRx/U/gt5DmpsjVOd
q6HhcTDPoR+kLjkT4q51eQ5FoPBLh9q3JM8BxLXPzHQI5dPdNHdzngPImAPT
Mh24QeG1Ks/BCRReixHqwf5ZCXXf3DwIvRIa3jOg7l2UCfEHMHzA4TQj00EV
5K750PjJyYS4qz3PoQoUnmmZDiBlCZl5kHiOh5oPDG9wOALjY/XHS75JOVD/
dmVC/OGcBwmH+ZmQdGEPTQ+tUP8jpR8ATgcJtg==
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIxIGYC4oyJb2vsRfMdZuQJNR84lekQt8uTh0k732H/
fCn9uxcyHY55m3c6qiD4QNWmcW5Q/ptMB8stJ8r2Bec7xIL0fYfKh+U76N9V
YWu8memwyHXb578h+Q7fNGL6D53NdLiodPtnXVC+w81z34Mf78x0qBZZ5/7Q
Kt+BAQROZDqE8ulummuc73ABpG5bpsM+kD0a+Q5WIHvmZzqA3aubD3FndqaD
MNDVCzWh9oVmOqiyNU51Vs93uATS75UJEQf6b8Khrxox3pkOslEp1veF8x0e
L519RCEkE+JvvnyIu/MyHfpB6sSh7unIdABbK5bvcOtnXdaeFVD/AflgczZD
+Wz5Dj7AYEo4CnUfUngCADiJmEQ=
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{244.664, 208.434}, {244.5, 207.691}, {244.512, 
                    207.08200000000002`}, {244.512, 206.57}, {
                    244.55100000000002`, 206.16}, {245.30100000000002`, 
                    206.42600000000002`}, {245.297, 206.477}, {245.262, 
                    207.129}, {245.41, 208.02700000000002`}, {
                    245.21499999999997`, 208.281}, {245.11299999999997`, 
                    208.414}, {244.70299999999997`, 208.57}, {244.664, 
                    208.434}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJlIGYC4mPe5p2OX3IdnBKeXlD6neVQLbLO/eG5XAfZ
qBTr+9lZDnG7PHmYZkP5pxF8/bsqbI2ZUL52rsPbGnvTuHdZDjfPfQ9+HAhV
H5/lkDERKPM2B6J+K9R8pVyH2z/rsvaEZDkcB9lfkOMgA1J/HKr/YQ7EPc5Q
84Oh+juzHEDKE3ZC5Y2zHML5dDfNPZ8N4XdD7duYA7FfOsvBcsuJsn3MuQ4F
tlzXF7tkQewtyXUwAJkXm+WwFSg9/xOCD9aXnwfng+19mOew6uMl3ySgfgYQ
MMmHmw8OPyDfCmSPNNR+03yHx0tnH1GQyXIQaj5waqEpQj3Q9U8vcBXA3Qvi
KunnQ8LPCOreyflw/15QArqYDarfGcovy4eHF9g9R/Lg4QnW9zMPHt7750vp
352SB48PML07Dx5fYL53nsMtkP6MLIi/ffPg8Q02RzIPnh4ACz7tng==
                    
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGI5IGYC4q0nyvbN18t1EFnn/rBqTawDjN984NRC175Y
h+Pe5p2OOrkOXNcXF9gmxTpYbgEqUM91kNa/q8KmGevQ+jpwh5wsJp8BBAKg
+mVyHfaWTJZgyYt1eFdjbxonlesQv8uTh6k51qHAFmiyRK7DfxCYHuuQMfFt
jb0o1LyNsQ6Pl84+oiAA1X8u1kE2KsX6PneuA1C3dvuzWAdVtsapzuy5EPp3
LMSdTFD/8MRBzPub4/BNI6b/kGwcxH1fcxxu/6zL2mMS56BuyLFG5lWOw7bP
f69UBMY5TDj0VSPmf44DN8icXVD1nLkOD6uAJi6MQ3VPX5zDMZD/RHIdeqfn
CTU3xDnsmy+lf1cC6v5CqP3A8DAAchtj4xxAyhMUofrd4hyEQAGtmuvgBfKP
HlS/Ri7EvaJxDk4JTy8oaec6VL5UM+T4EwsxRxcaH48Q8QWOl+MIPiw+ATDa
x/g=
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxlk19IVFEQxjcLoaiXjAhLrTDwbV8KqQi/xSSieiihKJqTWEJBo5FStJRh
i2wRaiZa0B81NSMlyHQrJZOltD8QGQsVISJSPURIRElE1Mw9xy7lhcPwu3fu
OfN9M2dZYcm2opmBQGCGrJWykmRdy4t9/ZVgdC7ZtW/tUYN/eIfB+rMHP/4c
dpxjkCZh9DmjdH/t5+NBg7cvJvPHHzvOMDb2MaIL5UuKwcPG1OBIJ+OAvM6Z
Z1D5aeu99Nsuf4IQ0KebMbgp+0zoDWGzhIIexuruJ0f6hwgXiudHBmKM9y+X
v/sRIxzW/+4yFtzaMBZu9XmN5tf4PCzp5acIoQL5cyq/jCBVrDKyX3AkM7mi
iCC7P2uW8zTkbSfc/PJqS6HU4+kOufwuRpUWkkXoVz03prP1hzCkOoT39G6c
m5RPII3tjBXJFfW5ewnfs3bXxNucP6VOfyuj68pE+2CEkKKFNDPmvG45tO48
2X40MR6U1S2a1UA2XnV8nWwdF53eONlz6lw9o2T7U+V40uWfZuSqvtnG5kdc
f9IMesTGxrDrT7bjYsZYWBzcaWBUz0nGHa23z9g+RZ3eFoNz8W+ikHFCbOut
dfNRz/itT9SgQ/29zMjQQSg3f/V7fh/z52WKvX4M+OzFp4wPOg/VPi/Wht53
+yWmc6bq7DAYb7v0aKmw977JWD+E07WeBnd+wvlb7d8HHdvKyH/3Q+7LH2aC
gDg=
                    "]], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {CompressedData["
1:eJxTTMoPSmViYGDQBGIQffPc9+DHuXkOVltOlO3rj3XQv6vC1piY5/CwSmSd
u2aswzeNmP5DkXkOBiBx3ViH/kNfNWKC8xxq7U3jdlnGOlxUuv2zzi8Pos43
1uFdDVDCK8/Bi4dJuz0Oqt49z+F14A651uJYB6HmA6cWuuY5ZE58W2PfG+sg
G5Vifd85z0GuFahiWaxD3C5PHiZnqP0HEXzRde4Pq+7EOhTYcl1fbJHn8PQC
0OJrsQ6rPl7yTTLIc/BLEoiwvAK1XwvBfwviyyH4vdPzhJpF8hxmAKkDt2Id
CkHm8eQ5rJEBOuR5rMP++VL6d1nyHNrFgCHzOdZhkeu2z38ZoHzmODi/OAPo
AXEEH+xexzgHoGkFtmxQ/6RB5QXyHP6DQHscxL/SeQ4gZ+1aGefweOnsIwoa
eQ6XQOG4Kw4SPqYIPljeAcEvAtkLDE8RUHhsiXMI49PdNNc7zyEEpHAFVH1A
nsMbUHjPjoOEHzC+gLqz9vTEOTCAQEieQ+VLNUOOGqj7QqDxkx0Hif/QPAcg
OdXZG8EHmyeN4EuDGB9jHVRB6sKh4Xkp1mErMBnNj0LEn495p2NCLNT8zbEO
lqB0lpznEA9y1+JYB/T0BwCaCyN9
                    "], {{241.98800000000003`, 
                    120.91400000000002`}, {241.92200000000003`, 121.32}, {
                    241.71099999999998`, 121.523}, {241.344, 121.523}, {
                    241.18800000000002`, 121.523}, {241.04299999999998`, 
                    121.48}, {240.914, 121.395}, {240.781, 121.309}, {
                    240.71499999999997`, 121.23400000000001`}, {
                    240.71499999999997`, 121.16799999999999`}, {
                    240.71499999999997`, 120.953}, {240.97299999999998`, 
                    120.848}, {241.484, 120.848}, {241.648, 120.848}, {
                    241.816, 120.871}, {241.98800000000003`, 
                    120.91400000000002`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJVIGYC4nA+3U1z+fMdtn3+e6ViZayD/l0VtkbOfIfb
P+uy9ujEOmRMfFtj/zfPYW/JZAkWu1gHl+6c578/5jkscgXqiIl1KAIpeJ7n
UGNvGrerM9bhDkjfnTyH3ul5Qs07Yh2+acT0H7qY5zADyD3wK9Zhy4myffOP
QeUD4iDm74Wa/y/Wwce80zFha57DwyqRde4HYx1U2RqnOq+H6p8V69D6OnCH
3Mo8B6Dsw6oSqPxiqPpIqHvnQvmeUP7MPAcvHibtdqD7q0EaJ+U5bJr7fvkx
41gHdUOONTJdeQ4hj5fOPqIR61AM0tCd58AAAgtiHUDOPDAtz0EeZPG+WIet
IPfPy3NoPnBqoes1hP2eIPOfQcNnJdS+f1DzgO7nvr64wFYqzkE2KsX6/mYo
3yrO4bg30MM78hwuKQFDPArK35MHiYdWqPr9eQ5vgN5u3R3n4JTw9ILSaQQf
7P5LeRB/AtXvmy+lf/cG1HygeRMOfdWIuY+wDxy+T/Mc/JMEIixl4hz6QB58
kweJf8Y4hwJbruuLv+Q5XAS551UsRN8vqP5bUP8yQ9PHkVgH9PQDAPNPDX8=

                    "]]}, {
                    FaceForm[{
                    RGBColor[0.74902, 0., 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}}, {{0, 2, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 
                    0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}}, {{0, 2, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}}, {{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{1, 4,
                     3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}}}, {CompressedData["
1:eJxTTMoPSmViYGBQAWIQnfv898qPRQUOLt05z38LRjq0vg7cIVde4ODFw6Td
/i/CgQEEqgocVNgapzq/jnBwf1glsq66wKF3ep5Q840IB2/zTseE2gKHvSWT
JViORTgc+qoR019X4AAypnV1hEPGxLc19vUFDtL6d1XYOqHmlUHVt0H5QPsX
um77/HdJhMPVipdqhnkFDpkgfXsjHB74A23KKnCQBznsXISDwoaijInpBQ6V
QGUcdyIc4nZ58jAlFzg8u6B0++e7CIctJ8r2zY8pcLAEMdgjHY6BHBgGda9C
JETcH8q3gPrXs8DBCiweCbHPqcChGOTw9EgHPt1Nc99bFjjMACo/0BQJsV+/
wAHo2isVC6Hy2gUOIuuAIbMm0kG4+cCphZoFDn5JAhGWWyIh7tEocAh5vHT2
kR2RDuX75kvpq0PN3x/p8OmSb5KAWoHDIpD/z0DlVaHh9TDSARiKrwNVoOHz
Bep+5QIHkDWufFEQ9yhD7dOJgrjHGereQ5GQ8AwocLgEDJ66WZEOO0HmRRU4
PAWFVxmUn1Tg8B8EwiMdQMJ1GQUOx0Hh5gB1Xx7UPZqRDujpBQAOoQIS
                    
                    "], {{256., 104.609}, {255.879, 103.121}, {
                    253.49200000000002`, 103.184}, {253.672, 104.703}, {256., 
                    104.609}}, CompressedData["
1:eJxTTMoPSmViYGBQBmIQ/bbG3jQupcDBP0kgwrImwsGW6/riAs4CB4O7KmyN
vBEO3uadjgkf8x2cu3Oe/86McIhKsb7v717gANK262SEg+WWE2X7nKHq70Y4
LHLd9vmvQ4EDkDfV+XWEw2QJljA++wKH+F2ePEyfIxwYQMCmwGGNDNCk/xEO
h75qxPRbFDiEPF46+whHpAPIuPkmBQ7FGRPf1vBHOoDdB+TvLQGa9C/C4TBI
vVGBg3zr68Ad7yIcyvfNl9LXL3AA2nql4mGEg1a72M1z2gUOfiD/XIlw0Ae5
S73AAeQt21MRDlcrXqoZKhU4bJr7fvmxw1D90gUOqiD37obKixQ4cIPU74LK
8xY4HAcFxIEIh2Mgmq3AAegb7fZjEQ4gZ8gxFjjMyBNqPnApwiGMT3fT3N/5
Drd/1mXteRLh4AIKN2D4gf0D9O8dkPibfEh4KEdCwuMNVN4/0kENHG75EPsa
Ih1unvse/BioHxyucyIdPl3yTRJgKID4a2kkxH2c0PDbEOkg3Hzg1EJRqPuW
RTqAjLVXLXB4ekHp9s+2SIdqkXXuD2Hhmw7lA+OrdzrQAw5Q9Z7Q8BKChj9S
+gAAf3fwHg==
                    "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQfeirRky/XIGDFw+TdrtdpMNxb/NOR6kCh+YDpxa6
ukU6dDgmPL0gVuAQu8uTh8k70uEYSF6kwGGR67bPf30iHay2nCjbJ1jg8OyC
0u2ffpEOtlzXFxfwI/hRKdb3/XkLHPySBCIsgeqXzT6isIGrwOFhlcg6d89I
h2og9ZCjwEGVrXGqs3OkgwxIA3uBwyWg9jqrSIec579XfmQrcKi1N43bZRjp
0Po6cIccUB5o+5UKzUgHkPXzOaDmKUY6KGwoypjIWeBQ+VLNkEMm0qF833wp
fe4Ch97peULNEpEOIOcnAN3zFOQ+sUgHd5BGoHv176qwNYpGOny65JskIAT1
vxjUfBGofZJQvhjC/Lc1QIdJFEDCQT7SQbtd7OY5yQKHjIlAGVWofdLQ8NOO
dMgF+UcG6l/jSAf08AcA2MWlpw==
                    "], {{251.82000000000002`, 
                    102.141}, {251.47299999999998`, 100.664}, {249.105, 
                    100.883}, {249.465, 102.371}, {251.82000000000002`, 
                    102.141}}, CompressedData["
1:eJxNU2tIFGEUXZaQkojQCiGzEsP+SPkjw0Q7VtLDXqY4N5PNVrMU624WJibC
IhISIZFREGIW0o8syuxJxaJhEVH2kLRVwiRDJUIqRULsuzMXbGCYGe537zn3
nDPLvbznoNvlcqWYW54Xj4ZVBxb5cFZeIggdf1bm1rl9eHrifMSsEIJdH2e0
ROYUJE1bqBnNeBg1zCg696Ny/ZSFwebLz5f1Mda1vSx7Zuqped+6ot8y3kUH
J6vcBM/jrXPdHfodSsieF9fa8IDRmb62NtXgXU27/2vq9kz/YZnbzBCYmlHL
4VXPzpyg1msZLrm6LNwYe7/DW6n8XlgIrw68ajrCTl/AcubvZqwI8V/YeNdy
9knQ+eGEunazcCYjy16EHJ5eRqLwiSX0TVYVPylhrO6PCfHHEUI/XfMllzI2
nSn5/jeeILBfTjLM1sHJBMKpBbc2D1QxjttEdf5pRozgpxNi42e3RJp6lAiZ
TRCYxjLGUvn2qB4+xn7ZN58cnCLGtFyHCEsEL58xUGGAigj3pN+j+IWEY8mG
YS47/hWq/vsYO73zKbGAMG7sbd/LMCgfyw+QoxMxhqTf4JcKb4txSXTKUX7Z
jCbhlaX8t2l/BsEsucaTwtgl8yvJ8TFJ89Gg5zcwgqJjm+JtUT6vyfHR4Nu8
+pW/2X/xKiP4MKH3zUTmYK32/yZH10b1e4Igx/x39PyY8jd5s30e0fMmjwuN
LRV9hDDJRzdDHmmdqneP+vlI+X5WPjcJEtO8Xs3HFeXfo/zrCdul3q39ft2n
i52cFJOTow8z/tgx61E9jR92TPoZEpuKAtXzK6O14ef1TuO/2DwwNFO38zWi
/M08O+9zfA6/cv1f//uf/wFpEcg1
                    "], CompressedData["
1:eJxTTMoPSmViYGCQB2IQvfrjJd+knHwHLx4m7fZ94Q6LXLd9/uuS78B1fXGB
7aZwh7hdnjxM+vkOKmyNU51XQ+Vl8h1cunOe/94Y7lAtss79IV++gydI/7Fw
B1WQuv95Dnd+1mXtuRPuINx84NTCj3kQebYIiLnP8hw2zX2//JhzBET/JSh/
dYTDRaXbP+vO5UHMORzh0Ds9T6j5RJ7DQpC9VyIg9h/Ig4g/iHDwMe90TNib
57C3ZLIEy7MIB3VDjjUy2/IcDO4CXfw2AuL+1VD7v0U4rAL5d0eew5vAHXKt
0ZEOsSD543kOr0F870iIfqB7LoHcYRUJ8efNPAdpfaCBmpEOTglPLyg9znPw
SxKIsBSJhJj/Os8h5PHS2Ud+RDh4g9wD8++1CIcZQGce+JcHCd++CIfjIAUc
+Q6bQf6NjnAAGdsomO/wsAoYEJYRDu9q7E3jpPId1shEpVirQ+UV8yH+lYDy
NfMh5gpBw8soHyIuGuFw89z34MeR0PhRjHBAj18A0DPWew==
                    "], {{
                    246.125, 100.62899999999999`}, {245.33200000000002`, 
                    99.23}, {243.08200000000002`, 99.75}, {243.883, 101.16}, {
                    246.125, 100.62899999999999`}}, {{247.434, 94.293}, {
                    241.824, 93.785}, {241.484, 95.367}, {246.19899999999998`,
                     95.793}, {246.07399999999998`, 96.051}, {245.906, 
                    96.262}, {245.695, 96.43}, {245.586, 96.523}, {245.336, 
                    96.67999999999999}, {244.95700000000002`, 96.895}, {
                    245.375, 98.34400000000001}, {245.895, 
                    98.05499999999999}, {246.27299999999997`, 97.738}, {
                    246.512, 97.395}, {246.758, 97.04700000000001}, {
                    246.95700000000002`, 96.52}, {247.10899999999998`, 
                    95.812}, {247.434, 94.293}}, CompressedData["
1:eJxFVAlIlUEQFotXeUTlI8yreiVaURqaoqKOmpSGRmXsEmpeRZa7XlHiBVES
YgcRURQiFhGUCEmFSIdE2AGFVGgm9hLNihC7y8xsd2d878HjZ5jZmW++b2aW
5hVv3eXq4uKSq/76+zM48+T9LAn947V7bxcwGLp84cGSjRIOdz5pTt7NYLQ6
fl12hIRb3yZfVhQyeLgpsj4hWEKqh+uqo5JB0NrZLX4+EgIth84klZPfQ8I5
ueBwZyXD7z8B6XnzeNQRBok577pt34TDf7fJJ2Tgg8D6+xn47yiIsdsFrG8o
ej9RyiBBx/cKKN9zarS6mEHfs1/bhh4LWFz3aUu7qn/1y/O0vHYB0TceHbir
/Dosvl7Azo4UD1eF55r2Vwtoaxy70qVst95LJbFlAjJ0oxWEZx/VO0T18wUs
1/00MEB+BLjrd+cZlMSqDFzASLetf7yVgYYRkEb9KL/pAwRYWzcMVh5jyEuY
s/8ojTNIQKHGWcMwrw/lV3zcVO4mN4HvqqifwSK4s/+098xast8VYb5hip8r
UJ9BBlW6sE2Ai/69ZfgNF6jnCOmVSHi+E38Z5Ldw1Dub+FvGkY+dAnlL5Zhf
8WdwJHPMV0b9xHLQ8ueUUv5wDqWarxIBSZrfFZx0Ir0Wc9S3mOKtHPuRAnma
RfmVna3xTBDfKr+Zs88MyjSQgwJa/BTQ9zQfNdTPGwYhA0rJOuKnj/o/IcBX
O/pI3+sCUvQ89xC/ar6ak/ULin8toEvXe8Xg+Fkl9LCTX4PnC+X/yEDDsP8S
sFn385fBRZ3nN7335ph/nPAFEJ9/BOg0dYpvo7Palyn9CyL+pwTosp0rOWyf
u7qtcQbt3xqO9edInO8wjvNppf2N43BP75eV9jfKaRt9VbyZV2VP559+b+bZ
xrFfZYdqHv05zouyjR6+hM9Lov6eHLx04fnSoZexPSXuwzBz5DP7bKf99KP4
fuIzUKKevaTnarovL+geRErUv5thPyBRx6ekXwL130P7Fy8d+2HqxFD+MQZ6
zJoiCP8k7Xe4xHmwEF/KNvfAnfheJ6FGrUnHfNJLvQ/QjoUcTt7/EZyp8Jl7
sojjPEQSfl+a52iJ90Ppb/YqTiLuQOKbS7xv6VQvi2ylp+k7R+L8hXLkJ1c6
9tXMR75EXAqPuecFZFsIXz7p+3X6vjnv/391iJxl
                    "], {{234.414, 
                    100.12899999999999`}, {232.996, 99.12499999999999}, {
                    231.93, 99.785}, {230.879, 99.}, {229.47299999999998`, 
                    99.848}, {230.812, 100.80499999999999`}, {
                    231.94899999999998`, 100.16799999999999`}, {
                    233.04299999999998`, 100.96900000000001`}, {234.414, 
                    100.12899999999999`}}, {{232.18800000000002`, 94.02}, {
                    226.695, 94.918}, {227.297, 96.46900000000001}, {231.914, 
                    95.71100000000001}, {231.94899999999998`, 95.98}, {
                    231.918, 96.21900000000001}, {231.816, 96.426}, {231.766, 
                    96.535}, {231.629, 96.742}, {231.40200000000002`, 
                    97.035}, {232.629, 98.277}, {232.945, 97.883}, {
                    233.10899999999998`, 97.49600000000001}, {
                    233.13299999999998`, 97.117}, {233.156, 96.738}, {233.035,
                     96.199}, {232.766, 95.504}, {232.18800000000002`, 
                    94.02}}, CompressedData["
1:eJxTTMoPSmViYGCQB2IQ7dKd8/x3YY7DGpmoFOv14Q4MIOCT47Dt898rFQfD
HapE1rk/NMtxeB24Q671dLjDjDyh5gNaOQ7NB04tdL0X7gDSdl89x+EhSOHP
cIdVHy/5JqlAzROPcHBKeHpBSTvHYdPc98uPOUdAzLfJcZBvBZpYF+Fw62dd
1p6IHIf4XZ48TI8jHFTZGqc6x+c41Nqbxu36GeFw89z34MeJOQ63Qep4Ih0K
bbmuL07IcdgMMk86EmJeAlS/cqTDIlegy2NyHLx4mLTb9SIh7gvPcdhbMlmC
xS7S4W0N0OC+HIf/INAe6VCUMfFtzeQch+Pe5p2OBZEO+ndVgC7IcQCHS2Qk
xD9Tchy+acT0H3KNhPhnMtQ8oPlg9/VC3SsIVd+S49A7HRhQHyIgdEGOQyzI
fasjHC4qAX2SBDW/MsJhwqGvGjHROQ5yoPAIi3CIA6mLhoanY4TD1hNl++ZH
5UD8aRABCf+4HIg7VSMc+kH606HqFSMcfIDeSAC659kFoEV8EQ7o8QsA9SzW
8A==
                    "], {{224.75, 100.67999999999999`}, {222.824, 
                    99.867}, {221.5, 101.15599999999999`}, {223.445, 
                    101.977}, {224.75, 100.67999999999999`}}, CompressedData["

1:eJxNUwtIk1EUHiOiZIXUEKtl7wfUUpMQNdtXJLWeVMa9SRlISe38lD3psYyI
MMseEpgRMpYEEiL0spBaElJRITmCitAaChllKFJS4ere/54eg3E599xzzvc4
/6SinWu3Oh0OR7b66/PbzI3nHg4S3n4vDdz7LHAlr7F/sJewzOWcVdYqcK0v
urKoi5B168n+yB0Bh/69JuR3Xr3cUieQre+fEY745hU2XRK4v/dC8pAI4fHy
zPKF5wWqd4w63txAcDcsiR2qEBAjvTdqQlx/UmBXbsKr2gpC22SF4JRAavvU
ocf2cb9KYe4L+X21MH2XEsqS3rQO1AoUNvldzgzCZn3eFFC36zqHE85cVINf
CKjuJblfAqa+l+vfB7CqKFFmuaXJRwPYs62yJ5gpDV4V22eBxOLT1oefsQAm
nPi05m6pxGFNRPXbrp77arg+HoBf69UojT6JBD2++anEes13CmGcJhaTmJE+
rN6ziBDVvH5Iox8RUnT/pA3QR4rib+sYlyjR+uQTwtqXLp63gAyuNmn4pnO+
RcL2c9ofvxiPh/Wok8ZPN8+rkritnoUSyPA/KqFlmuji+cUSkdDY1PZkQlD7
4ed5qr89xysxvmBLzrsc9tfN+hXw/sQFdFvfQfavWxj+Vdy/g/PXCUqscJ6K
z2qcz8no3cH708HzPwqDr5uMbr/Y7x5Cmt6bEcy/j7Ba++th/fvJ+D2b8185
P19ik96bAUK9RxERErs1IBXb30GQ4wzL4H30L7b3M8z6zbWgXr88UC7xQOuV
Zv2tt/F5LcOvmP2fbhk8KyRG68QYy/Cdw/j++x5/A+LsplY=
                    "]}]}}, 
                  AspectRatio -> Automatic, ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 480.}, {0., 320.}}], ",", 
                 GraphicsBox[{
                   Thickness[0.0010416666666666667`], {
                    FaceForm[{
                    RGBColor[0., 0.596078, 0.764706], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 480.}, {960., 480.}, {960., 0.}}}]}, {
                    FaceForm[{
                    RGBColor[0.8784310000000001, 0., 0.20392200000000002`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     320.}, {960., 320.}, {960., 160.}, {0., 160.}}}]}, {
                    FaceForm[{
                    RGBColor[0., 0.6823529999999999, 0.39607800000000004`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     160.}, {960., 160.}, {960., 0.}, {0., 0.}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{536.8009999999999, 240.}, {536.8009999999999, 
                    200.23399999999998`}, {504.566, 168.}, {464.801, 168.}, {
                    425.03499999999997`, 168.}, {392.801, 
                    200.23399999999998`}, {392.801, 240.}, {392.801, 
                    279.76599999999996`}, {425.03499999999997`, 312.}, {
                    464.801, 312.}, {504.566, 312.}, {536.8009999999999, 
                    279.76599999999996`}, {536.8009999999999, 240.}}}]}, {
                    FaceForm[{
                    RGBColor[0.8784310000000001, 0., 0.20392200000000002`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{540., 240.}, {540., 206.863}, {513.137, 180.}, {
                    480., 180.}, {446.863, 180.}, {420., 206.863}, {420., 
                    240.}, {420., 273.137}, {446.863, 300.}, {480., 300.}, {
                    513.137, 300.}, {540., 273.137}, {540., 240.}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, {{{573.105, 211.73399999999998`}, {
                    552.4649999999999, 221.52700000000002`}, {544.828, 
                    200.}, {537.16, 221.516}, {516.535, 211.695}, {526.328, 
                    232.33200000000002`}, {504.801, 239.97299999999998`}, {
                    526.3159999999999, 247.641}, {516.496, 
                    268.26599999999996`}, {537.133, 258.47299999999996`}, {
                    544.7730000000001, 280.}, {552.4409999999999, 258.484}, {
                    573.0619999999999, 268.305}, {563.2730000000001, 
                    247.668}, {584.8009999999999, 240.02700000000002`}, {
                    563.2810000000001, 232.359}}}]}}, AspectRatio -> 
                  Automatic, ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 960.}, {0., 480.}}], ",", 
                 GraphicsBox[{
                   Thickness[0.0025], {
                    FaceForm[{
                    RGBColor[0., 0.41568600000000006`, 0.30588200000000004`], 
                    
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 240.}, {400., 240.}, {400., 0.}}}]}, {
                    FaceForm[{
                    RGBColor[0.956863, 0.16470600000000002`, 0.254902], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{260., 120.}, {260., 75.816}, {224.184, 40.}, {
                    180., 40.}, {135.816, 40.}, {100., 75.816}, {100., 
                    120.}, {100., 164.184}, {135.816, 200.}, {180., 200.}, {
                    224.184, 200.}, {260., 164.184}, {260., 120.}}}]}}, 
                  AspectRatio -> Automatic, ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 400.}, {0., 240.}}], ",", 
                 GraphicsBox[{
                   Thickness[0.00125], {
                    FaceForm[{
                    RGBColor[0., 0.12941200000000003`, 0.6784309999999999], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     1.}, {0., 400.999847}, {799.999634, 400.999847}, {
                    799.999634, 1.}}}]}, {
                    FaceForm[{
                    RGBColor[0.109804, 0.541176, 0.25882400000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{0., 401.}, {
                    800., 1.}, {799.543, 400.703}}}]}, {
                    FaceForm[{
                    RGBColor[1., 0.776471, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4mqRde4PJ9Q6xO7y5GFSz3SA8YWbD5xaeDLN
YYdc6+tAkVoHBhAoSHE45m3e6WhXA+EfSYLwM6ohfIlEB1uu64sLrKscZuQJ
NR+QS3CYDqJ5KuH8T5d8kwTulcP5GRPf1thvLIPrB/Nvl8LNB/NZS+H2bzlR
tm9+RwncfTA+zP0w/qqPQItasuH6Xbpznv++mws3H8zvzIfbv8h12+e/swrg
7gvl0900V7wQ7n4YH+Y/GB/mf5h+WPjAzIeFH8x+WPjC3Ice/gBATahi
                    
                    "]]}, {
                    FaceForm[{
                    RGBColor[0.109804, 0.541176, 0.25882400000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJyFVWtsFFUUXleigIKI1lhSNisSpdiKqGiEVE6NxhLU+qIxtUC72e2dzu5M
iTiPvTMpj1IJNg2oKEZEYgkxPNT1UVtIrYVUKGh00ZiKpWmhaSoxBYFo0xSD
c+e7LSb7w00m2TP33nO+7zvfuXNHpPr52LWBQOAa73G9JxiQv0dNelefXtt+
r0Z1fzzXEmowaV7P7OvWLUuQc+snT56eYFHFQHpW91mVSqOLeotjFv02UqO2
FsWpt7hhm56y6OjShzcVerG/3mXRLbXtxz8siCPPaRmfVEkbHN1z4U0bdXao
ZLXtnDHv6yTq3B+nw3/NKdtscnq8PjE4mqVlxEdEnddkfLNGmwrLB9JrOfIf
0+iejbed/GEdp7+9Y4ezddRvluuTdOxv4bTwy06z7bxGLSEPSTsnX4dOjRIC
Xxunu+dP3J+zV6PGJ7669E8nB949Gk3J/3zH+V5OAi5v0YD/Cgf+kA7+2Q7N
FH9W6uSpNlITdihL7Hd18MlxoPd7OviEZNymA0eejIPV0PcZme+SDtzLHNp7
4aenI2l5vswBzwM6DbmLF6zw4kfEvo904Io49I0Hs2eLDn3qHOyL6OhHhwO9
GnTUOXY1vuiVmZZ2aJvAc0Snc+LcGYdE2fJDmbGv84hDJVM9ob6TfP906BXl
jSH3qE5zRf0rMm7W6YDQ/6IDHhs08A+5JODvNDXqE/xnuCRk7vk1gfUcF32Z
kxjPt/zgkhuDw/Hx2Of/RRw6TnTh34o4nRD9eN2lFWL/yjj8UOYCd3acdm/v
CKcedHHunEpv3T6hZOpyF3p9oIJP2KUt4s8a6edVUt/vq0jQWlws+/XA/8e+
r+505Nwp434Yi30cAYfKBf6ZChVM7tq1qpvjfaki+8Lhh9kK/NLKMY99DPtS
HP1Zwug+4ZNvOfiPVkKvHzkJGWZtrqRf7LN3ze+Q+V6sBN5m6fffYzRd6LSP
o3/Xx6DPGk5PifwDUfBKchIwC96JYj5icl4Lo+BXI+ezKUJNos/q1djHM5ik
4Rf6d29PReDr2iTliLyDcr04iXm6HAHP9Unw+TSK/ulJ6JdfOR6P8fHnpyJJ
H4uE9QxxnU2rfaIM/KM2/KYw4C2yqVvcd68y5HvIBr9GhvnKs9GfJob5mmLT
PlGvlVG/OBC00YfjDHr1W9D1BKNwylPyZwv8DzH46ZS8Lz9jmI+DFvK9z6BX
xKL9Av9GBj0WyXwLlIzYr08W+lKtyLkysZ6rQKdJJvaVKeB/ykC/cuX+Thm/
LevtMqDnBumvRgP3XAnD/ccMeX8y+O5lA3i7GObtJQM8SmX+rQb03ZoZ+/Pe
YcBvXRJfn4E5PqNAz2ED/pxWhfdBE31ZX4X5uDx2Xs5blok5yFfR/1wT/q9W
kb/IhK+eVeX9YKI/mrwPVpv0mNhfr+JecE34Z2kc3wcmz6/NjP15uMkE3nAC
7yebdIPw09wE9BoywDst77s8+X1eKO/H/3yv/wVdD4SX
                    "]]}, {
                    FaceForm[{
                    RGBColor[1., 0.776471, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxlVGtsFFUUrrUxvkB5GSoqj/BDwKYmapDK40PFitCoJQXUQkptl7Ld7kx3
trsNVmpn7s6gRolp2hqNJVYRIaQBbCuJBRvF1pBo5OGDYIMIBglQsNWA6BLv
2W9oE3eTuzNn7r3nfI9z79RSo7D8+oyMjOv0WK1Hph4t4bFOz2ACz5c9cvzp
3Ci+/Ove4k0/JfCFPK9GsWqTfhtQaFvUNZTsjiFDfvMVGidmLR99NI7mx14P
nR6nMFC34KHVY2vx3bRjf2+47ODmHz8w512Mw7vj6LeXkg7ztY6sXzL71YUl
RXEcLii9feV0hZ2RirfOZ8XxguDIU5jT8XVs32cx7J+iZ+DXf82vv1ThpfHt
+ScqYgh2RxsnFiqc3PLu/ikPp8epessU952qgc7+RssKBZne+XMN5gnQNxVG
5+x+78KLNXhb9GhSmCqAktG0+NOh5JHaToUi2eBEcX//9BsaDip0aribZ0bJ
98YEBP7mXgvFol++H9da+Er4ZCeIx41As65bMCmBlA9ZI3GK7+5qrruqON9d
TT1OKerZW828dyrE9X/uHAv3aRpbCx38ommG8yx0Cd42G0+eWD++fYuFucJ/
lY1/t/1xqKDDog/FNg6KbxELo0SHiE09CiwMHtIGDdis90SEeq5x2C+N1fTr
isM8SXPY31S9fpP65Pj67jXpS75if7Sa3FemuK7KpI4NPt+5JpokX6u//xaT
OH5V2K7hl1YYxPe7gshc3BcejkWO/j1h3C1AzyiskARGFfXcdy0OUbddComz
z+6556YQ97/j98uOIPukUsESY4z0OOX3oE0fYgH6m2Njx126sFHO/E31WPOb
PhnbAuxbux5LhffeAGZJglH1OC/npzkwvF67Eex+MEA8gVeQK/qUl1OHkw3s
k+wy5ily2C9HAuz/dgclUu+btZgvQp9x0CdC163FR4J/hs93TAXrNSrmmbCO
/s1IsN5zQfq8KIHH9ed/Xg6SZ0sC45yeA+/nVBLfBhePSsGhStb/xOW5afP1
vOjS764QLmztXTI712P8Q4j9+YBHvT+uwuJbM2d5+R6WC9FjVRizUt8EZR75
dPrz6z1cWqY7qSSMjQv1zHY/nx2mP20e5Dqp60uPU/dTs1/vGYO813nsy40G
8S/2588ZeErqZXvIE+IT/P687PLemGziQ1O/fe/y+xUDYvvxAy4E1rTTBvX8
3OV9cdigfx0u6/Wkx5PFmAaXuPpH4mt4Uutvc3leM01+n+SS558R/P8+/w+D
e6zi
                    "]]}, {
                    FaceForm[{
                    RGBColor[0.109804, 0.541176, 0.25882400000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{735.695, 245.79299999999998`}, {735.309, 
                    244.707}, {733.3549999999999, 244.21899999999997`}, {
                    731.602, 244.76899999999998`}, {729.8439999999999, 
                    245.324}, {728.602, 246.812}, {728.992, 247.894}, {
                    729.379, 248.98000000000002`}, {731.3319999999999, 
                    249.469}, {733.09, 248.914}, {734.8439999999999, 
                    248.363}, {736.086, 246.875}, {735.695, 
                    245.79299999999998`}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    150.523, 248.25}, {140.324, 257.79699999999997`}, {130., 
                    248.379}, {131.105, 262.308}, {117.309, 264.508}, {
                    128.88700000000003`, 272.328}, {122.004, 
                    284.48799999999994`}, {135.336, 280.312}, {
                    140.55100000000002`, 293.277}, {145.598, 280.246}, {
                    158.98800000000003`, 284.25}, {151.945, 272.18}, {
                    163.42600000000002`, 264.21099999999996`}, {149.598, 
                    262.191}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{186.71099999999998`, 132.57}, {
                    175.71099999999998`, 139.91}, {164.996, 132.172}, {
                    168.766, 144.63299999999998`}, {157.90200000000002`, 
                    152.16}, {171.23, 152.523}, {175.227, 164.914}, {
                    179.69899999999998`, 152.676}, {193.035, 152.805}, {
                    182.469, 144.883}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    237.266, 180.226}, {227.066, 189.777}, {216.742, 
                    180.359}, {217.848, 194.289}, {204.05100000000002`, 
                    196.48800000000003`}, {215.629, 204.30800000000002`}, {
                    208.74599999999998`, 216.469}, {222.078, 212.289}, {
                    227.29299999999998`, 225.254}, {232.34, 
                    212.22299999999998`}, {245.727, 216.23}, {
                    238.68800000000002`, 204.16}, {250.168, 196.191}, {236.34,
                     194.168}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    60.870999999999995`, 149.672}, {50.672000000000004`, 
                    159.21899999999997`}, {40.348, 149.80100000000002`}, {
                    41.452999999999996`, 163.73}, {27.656000000000002`, 
                    165.93}, {39.234, 173.75}, {32.352, 185.91}, {45.684, 
                    181.73399999999998`}, {50.898, 194.695}, {55.945, 
                    181.668}, {69.332, 185.672}, {62.293000000000006`, 
                    173.601}, {73.773, 165.63299999999998`}, {59.945, 
                    163.61299999999997`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    152.54299999999998`, 33.}, {142.34, 
                    42.550999999999995`}, {132.02, 33.133}, {133.125, 
                    47.062000000000005`}, {119.324, 49.26200000000001}, {
                    130.906, 57.082}, {124.02, 69.242}, {137.35500000000002`, 
                    65.062}, {142.57, 78.027}, {147.617, 64.99600000000001}, {
                    161.004, 69.004}, {153.965, 56.933}, {165.441, 48.965}, {
                    151.617, 46.940999999999995`}}}]}}, AspectRatio -> 
                  Automatic, ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 800.}, {0., 401.}}], ",", 
                 GraphicsBox[{
                   Thickness[0.0020833333333333333`], {
                    FaceForm[{
                    RGBColor[0., 0.686275, 0.7921569999999999], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 240.}, {480., 240.}, {480., 0.}}}]}, {
                    FaceForm[{
                    RGBColor[0.996078, 0.772549, 0.047058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}}}, CompressedData["
1:eJxlVg1MlVUYvhKhY8hMjQiwAcMRukZazhrce9/vfB8jVNJqIRTdEd3vrxUI
knPK2hwRmiEaNnNUpMYKctaaojMiBmIg2SxLc8kcMn+WWYmTZobrnPO+9zsz
2O7Ys3Pu+z7neZ73nJtWXvm0eZfP55vCP1v5J4p/HtuklV1YkQufXfuxsDzX
hAj+9ebrL3d9FIZwzrnljSsB8YowFD++f2BNPPNwicAhw8MHr0/8tHZnHtRf
eerQA+0K787rvD6RYnr4wMCa7taQCZ0Cu3mQ8hzv1GBC446KmXV/GbBfrB+d
jH3iL1WD2NN7Vvl7bYh/6MsP/swPwol0zuBNB7JKm3pvXA5A6HBBXFSrg/+H
ArB+9r78kcMKC9rdo/9bT3fB2PzKpVslgPWKXFx/XsO+xS6ew2CQPZwRs6HE
hYaEM9//reuI0xSeVddzbNeI4+HRtpYjqdsdePXSrfZruxmuVzlwbJcoqHm4
78aDpU0LFW4/unTxphHwzhfBmQum7U3pUFjy7HPgU4Hv0WCcl+k97sCSuKj5
DUUKS/7RzMOS30kNWNmFE+nNk/EPou88hv7scGCRaFTN4Oua5sTofaT3E3Se
QQfeP5L6RfVGhv5H6vcxWLaYB+tnOt8Yg/e4rT3nHfiHx6amj+r94cCQ0KOR
gbC9Z1zVl3xvqv6rnW1Xa5Nd+J23qc9hMEfwm++iD/0a+rnQhYAIyrAGnMUz
o3NdrM+x9Pl+F/ue0pBPvAtTN7yrb07RsB6vL333AawT9WIUlvw6HQ9rQi/b
ge2J0UXxw4B+ZzjIbz2Db1qTsocfJX0SSZ8sBwqEPxc19GWGg/3Pashr3Mb5
yyT9Jmyv3tXa4KLQ7clY5mApw3qX6ftTGc7PKRv9jGVQ5efC7KX1lVT/gI3z
/CGDmcLPfhuShaBTdNjay437yka+FkNcacO9XJZ1GTrqERPpl0d+WpQ/A/VP
s0kvA/0sUVj6tk1huT+P9BowQMRaCyscma8IlvOQQP6VGuj/ky6IayK2Qcfz
vabw3Bi+cTXN6ywDzor7q9bF+62C6m1xaV6Jbxv5X6bj/i4X9XxLg28Fvy7K
VyNAtcjnHhfE8RPOBHCeWlzgaW9ONPy4/pKLeTmei3zyKY9Fubif51nIO7si
B/PS73j7xdeDLuHCAN6/0Q7W/Zz8z7Dwfh3U6Twm6nw3na/CxDnIMpD/MoVl
nUyFJZ+hMOp3mqG+HYTvUzhJNFig3bmeD5Q/hSX/6aaH5bxlm3g/vEPvjWHC
RXHx3VZY+hHF7sRjGjwszjWd9nfTPP8Wxvy+SPP3b5jWKe9zTNTpY7pPgvTe
+HT8PjNhjD+LM4p1rF9o4nvziU55NPF+cnTUb62J85hM+WpQ9SPv2zyx/xfi
02VifpYwaBLzdFLxl3qcM0HYXn9Fg26x/5CJeZ/GMIdvK30i2C8fRoV14V9B
EJ4VxOtMzOPOgMdf5mtLwMvHILcpqTKA+x+xJmHUI4DzUGXh/L9B/VZZyCdE
frxg4TzGaZjfNgv9Kie/hyz0/6Af+/daqFdNAOt9Z+F/COL9dl5h9Nv2sHzP
822aEz90iN8zG21vXqS/LTb2Xa5+7/wH58Ld4w==
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{266.469, 175.172}, {268.355, 174.824}, {
                    269.29699999999997`, 175.859}, {269.578, 
                    177.26999999999998`}, {269.949, 179.15200000000002`}, {
                    269.14500000000004`, 188.63299999999998`}, {
                    269.14500000000004`, 188.63299999999998`}, {
                    269.14500000000004`, 188.63299999999998`}, {
                    264.77299999999997`, 180.184}, {264.39799999999997`, 
                    178.30100000000002`}, {264.121, 176.88700000000003`}, {
                    264.58599999999996`, 175.547}, {266.469, 175.172}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{273.348, 173.086}, {275.133, 172.375}, {276.254, 
                    173.207}, {276.805, 174.535}, {277.539, 176.309}, {
                    278.60200000000003`, 185.762}, {278.60200000000003`, 
                    185.762}, {278.60200000000003`, 185.762}, {
                    272.66400000000004`, 178.32800000000003`}, {
                    271.92999999999995`, 176.555}, {271.379, 175.227}, {
                    271.578, 173.82000000000002`}, {273.348, 173.086}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{279.691, 169.695}, {281.301, 
                    168.65200000000002`}, {282.562, 169.25}, {283.363, 
                    170.445}, {284.42999999999995`, 172.039}, {287.312, 
                    181.105}, {287.312, 181.105}, {287.312, 181.105}, {
                    280.043, 174.97299999999998`}, {278.977, 173.379}, {
                    278.176, 172.18}, {278.094, 170.762}, {279.691, 
                    169.695}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{285.25, 165.137}, {286.621, 163.797}, {
                    287.97999999999996`, 164.137}, {288.9959999999999, 
                    165.15200000000002`}, {290.355, 166.508}, {294.953, 
                    174.84}, {294.953, 174.84}, {294.953, 174.84}, {286.621, 
                    170.242}, {285.26599999999996`, 168.883}, {284.246, 
                    167.86700000000002`}, {283.89099999999996`, 
                    166.49200000000002`}, {285.25, 165.137}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{289.809, 159.578}, {290.895, 157.996}, {
                    292.29299999999995`, 158.062}, {293.49199999999996`, 
                    158.863}, {295.08599999999996`, 159.93}, {301.219, 
                    167.19899999999998`}, {301.219, 167.19899999999998`}, {
                    301.219, 167.19899999999998`}, {292.15200000000004`, 
                    164.316}, {290.559, 163.25}, {289.363, 162.453}, {288.742,
                     161.172}, {289.809, 159.578}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{293.199, 153.23399999999998`}, {293.957, 
                    151.47299999999998`}, {295.34000000000003`, 151.266}, {
                    296.668, 151.816}, {298.441, 152.55100000000002`}, {
                    305.875, 158.48800000000003`}, {305.875, 
                    158.48800000000003`}, {305.875, 158.48800000000003`}, {
                    296.42199999999997`, 157.42600000000002`}, {294.648, 
                    156.691}, {293.32, 156.141}, {292.465, 155.008}, {293.199,
                     153.23399999999998`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{295.28499999999997`, 146.35500000000002`}, {
                    295.684, 144.477}, {297., 144.008}, {298.414, 144.285}, {
                    300.29699999999997`, 144.66}, {308.746, 149.031}, {
                    308.746, 149.031}, {308.746, 149.031}, {
                    299.26599999999996`, 149.836}, {297.383, 149.465}, {
                    295.97299999999996`, 149.184}, {294.914, 148.238}, {
                    295.28499999999997`, 146.35500000000002`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{295.99199999999996`, 139.19899999999998`}, {
                    296.01599999999996`, 137.281}, {297.215, 136.562}, {
                    298.656, 136.562}, {300.574, 136.562}, {309.715, 
                    139.19899999999998`}, {309.715, 139.19899999999998`}, {
                    309.715, 139.19899999999998`}, {300.574, 141.84}, {
                    298.656, 141.84}, {297.215, 141.84}, {295.99199999999996`,
                     141.117}, {295.99199999999996`, 139.19899999999998`}}}], 
                    
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{295.28499999999997`, 132.04299999999998`}, {
                    294.93799999999993`, 130.156}, {295.97299999999996`, 
                    129.21899999999997`}, {297.383, 128.93800000000002`}, {
                    299.26599999999996`, 128.562}, {308.746, 
                    129.36700000000002`}, {308.746, 129.36700000000002`}, {
                    308.746, 129.36700000000002`}, {300.29699999999997`, 
                    133.738}, {298.414, 134.11299999999997`}, {297., 
                    134.395}, {295.66, 133.92600000000002`}, {
                    295.28499999999997`, 132.04299999999998`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{293.199, 125.164}, {292.48799999999994`, 
                    123.383}, {293.32, 122.258}, {294.648, 
                    121.70700000000001`}, {296.42199999999997`, 120.973}, {
                    305.875, 119.91400000000002`}, {305.875, 
                    119.91400000000002`}, {305.875, 119.91400000000002`}, {
                    298.441, 125.848}, {296.668, 126.582}, {
                    295.34000000000003`, 127.133}, {293.93399999999997`, 
                    126.938}, {293.199, 125.164}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{289.809, 118.824}, {288.76599999999996`, 
                    117.215}, {289.363, 115.94900000000001`}, {290.559, 
                    115.148}, {292.15200000000004`, 114.082}, {301.219, 
                    111.199}, {301.219, 111.199}, {301.219, 111.199}, {
                    295.08599999999996`, 118.473}, {293.49199999999996`, 
                    119.539}, {292.29299999999995`, 120.336}, {290.875, 
                    120.418}, {289.809, 118.824}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{285.25, 113.266}, {283.90999999999997`, 
                    111.891}, {284.246, 110.535}, {285.26599999999996`, 
                    109.516}, {286.621, 108.16}, {294.953, 103.562}, {294.953,
                     103.562}, {294.953, 103.562}, {290.355, 111.891}, {
                    288.9959999999999, 113.24600000000001`}, {
                    287.97999999999996`, 114.266}, {286.605, 114.621}, {
                    285.25, 113.266}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{279.691, 108.703}, {278.10900000000004`, 
                    107.617}, {278.176, 106.21900000000001`}, {278.977, 
                    105.023}, {280.043, 103.426}, {287.312, 97.293}, {287.312,
                     97.293}, {287.312, 97.293}, {284.42999999999995`, 
                    106.359}, {283.363, 107.953}, {282.562, 
                    109.15199999999999`}, {281.28499999999997`, 109.77}, {
                    279.691, 108.703}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{273.348, 105.312}, {271.58599999999996`, 
                    104.559}, {271.379, 103.17199999999998`}, {
                    271.92999999999995`, 101.84400000000001`}, {
                    272.66400000000004`, 100.07}, {278.60200000000003`, 
                    92.637}, {278.60200000000003`, 92.637}, {
                    278.60200000000003`, 92.637}, {277.539, 102.09}, {276.805,
                     103.863}, {276.254, 105.191}, {275.121, 
                    106.04700000000001`}, {273.348, 105.312}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{238.93800000000002`, 108.703}, {
                    237.32800000000003`, 109.75}, {236.062, 
                    109.15199999999999`}, {235.262, 107.953}, {234.195, 
                    106.359}, {231.312, 97.293}, {231.312, 97.293}, {231.312, 
                    97.293}, {238.586, 103.426}, {239.648, 105.023}, {
                    240.44899999999998`, 106.21900000000001`}, {240.531, 
                    107.637}, {238.93800000000002`, 108.703}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{233.379, 113.266}, {232.004, 
                    114.60499999999999`}, {230.648, 114.266}, {229.629, 
                    113.24600000000001`}, {228.27299999999997`, 111.891}, {
                    223.676, 103.562}, {223.676, 103.562}, {223.676, 
                    103.562}, {232.004, 108.16}, {233.359, 109.516}, {234.379,
                     110.535}, {234.73399999999998`, 111.906}, {233.379, 
                    113.266}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{228.816, 118.824}, {227.73, 120.406}, {
                    226.33200000000002`, 120.336}, {225.137, 119.539}, {
                    223.539, 118.473}, {217.406, 111.199}, {217.406, 
                    111.199}, {217.406, 111.199}, {226.47299999999998`, 
                    114.082}, {228.066, 115.148}, {229.266, 
                    115.94900000000001`}, {229.883, 117.227}, {228.816, 
                    118.824}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{225.42600000000002`, 125.164}, {224.672, 
                    126.926}, {223.285, 127.133}, {221.95700000000002`, 
                    126.582}, {220.184, 125.848}, {212.75, 
                    119.91400000000002`}, {212.75, 119.91400000000002`}, {
                    212.75, 119.91400000000002`}, {222.20299999999997`, 
                    120.973}, {223.977, 121.70700000000001`}, {225.305, 
                    122.258}, {226.16, 123.391}, {225.42600000000002`, 
                    125.164}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{223.34, 132.04299999999998`}, {222.941, 
                    133.92200000000003`}, {221.625, 134.395}, {
                    220.21499999999997`, 134.11299999999997`}, {
                    218.33200000000002`, 133.738}, {209.883, 
                    129.36700000000002`}, {209.883, 129.36700000000002`}, {
                    209.883, 129.36700000000002`}, {219.359, 128.562}, {
                    221.242, 128.93800000000002`}, {222.656, 
                    129.21899999999997`}, {223.71499999999997`, 130.164}, {
                    223.34, 132.04299999999998`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{222.63299999999998`, 139.19899999999998`}, {
                    222.60899999999998`, 141.117}, {221.41, 141.84}, {
                    219.97299999999998`, 141.84}, {218.055, 141.84}, {208.914,
                     139.19899999999998`}, {208.914, 139.19899999999998`}, {
                    208.914, 139.19899999999998`}, {218.055, 136.562}, {
                    219.97299999999998`, 136.562}, {221.41, 136.562}, {
                    222.63299999999998`, 137.281}, {222.63299999999998`, 
                    139.19899999999998`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{223.34, 146.35500000000002`}, {223.691, 
                    148.242}, {222.656, 149.184}, {221.242, 149.465}, {
                    219.359, 149.836}, {209.883, 149.031}, {209.883, 
                    149.031}, {209.883, 149.031}, {218.33200000000002`, 
                    144.66}, {220.21499999999997`, 144.285}, {221.625, 
                    144.008}, {222.965, 144.47299999999998`}, {223.34, 
                    146.35500000000002`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{225.42600000000002`, 153.23399999999998`}, {
                    226.141, 155.02}, {225.305, 156.141}, {223.977, 
                    156.691}, {222.20299999999997`, 157.42600000000002`}, {
                    212.75, 158.48800000000003`}, {212.75, 
                    158.48800000000003`}, {212.75, 158.48800000000003`}, {
                    220.184, 152.55100000000002`}, {221.95700000000002`, 
                    151.816}, {223.285, 151.266}, {224.691, 151.465}, {
                    225.42600000000002`, 153.23399999999998`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{228.816, 159.578}, {229.863, 
                    161.18800000000002`}, {229.266, 162.453}, {228.066, 
                    163.25}, {226.47299999999998`, 164.316}, {217.406, 
                    167.19899999999998`}, {217.406, 167.19899999999998`}, {
                    217.406, 167.19899999999998`}, {223.539, 159.93}, {
                    225.137, 158.863}, {226.33200000000002`, 158.062}, {
                    227.75, 157.98000000000002`}, {228.816, 159.578}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{233.379, 165.137}, {234.71899999999997`, 
                    166.508}, {234.379, 167.86700000000002`}, {233.359, 
                    168.883}, {232.004, 170.242}, {223.676, 174.84}, {223.676,
                     174.84}, {223.676, 174.84}, {228.27299999999997`, 
                    166.508}, {229.629, 165.15200000000002`}, {230.648, 
                    164.137}, {232.02, 163.777}, {233.379, 165.137}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{291.562, 139.16}, {291.562, 121.324}, {277.105, 
                    106.867}, {259.27299999999997`, 106.867}, {
                    241.43800000000002`, 106.867}, {226.98000000000002`, 
                    121.324}, {226.98000000000002`, 139.16}, {
                    226.98000000000002`, 156.99200000000002`}, {
                    241.43800000000002`, 171.44899999999998`}, {
                    259.27299999999997`, 171.44899999999998`}, {277.105, 
                    171.44899999999998`}, {291.562, 156.99200000000002`}, {
                    291.562, 139.16}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{259.312, 175.879}, {261.22999999999996`, 
                    175.90200000000002`}, {261.953, 177.102}, {261.953, 
                    178.54299999999998`}, {261.953, 180.461}, {259.312, 
                    189.602}, {259.312, 189.602}, {259.312, 189.602}, {
                    256.676, 180.461}, {256.676, 178.54299999999998`}, {
                    256.676, 177.102}, {257.395, 175.879}, {259.312, 
                    175.879}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{266.469, 103.227}, {264.59, 
                    102.82799999999999`}, {264.121, 101.512}, {
                    264.39799999999997`, 100.10199999999999`}, {
                    264.77299999999997`, 98.21900000000001}, {
                    269.14500000000004`, 89.77}, {269.14500000000004`, 
                    89.77}, {269.14500000000004`, 89.77}, {269.949, 
                    99.24600000000001}, {269.578, 101.12899999999999`}, {
                    269.29699999999997`, 102.543}, {268.35200000000003`, 
                    103.60199999999999`}, {266.469, 103.227}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{259.312, 102.52}, {257.395, 
                    102.49600000000001`}, {256.676, 101.29700000000001`}, {
                    256.676, 99.859}, {256.676, 97.94100000000002}, {259.312, 
                    88.801}, {259.312, 88.801}, {259.312, 88.801}, {261.953, 
                    97.94100000000002}, {261.953, 99.859}, {261.953, 
                    101.29700000000001`}, {261.22999999999996`, 102.52}, {
                    259.312, 102.52}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{252.156, 103.227}, {250.26999999999998`, 
                    103.57799999999999`}, {249.33200000000002`, 102.543}, {
                    249.05100000000002`, 101.12899999999999`}, {248.676, 
                    99.24600000000001}, {249.48000000000002`, 89.77}, {
                    249.48000000000002`, 89.77}, {249.48000000000002`, 
                    89.77}, {253.85200000000003`, 98.21900000000001}, {
                    254.227, 100.10199999999999`}, {254.508, 101.512}, {
                    254.039, 102.85199999999999`}, {252.156, 103.227}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{245.277, 105.312}, {243.496, 106.027}, {242.371, 
                    105.191}, {241.82000000000002`, 103.863}, {241.086, 
                    102.09}, {240.02700000000002`, 92.637}, {
                    240.02700000000002`, 92.637}, {240.02700000000002`, 
                    92.637}, {245.961, 100.07}, {246.695, 
                    101.84400000000001`}, {247.24599999999998`, 
                    103.17199999999998`}, {247.05100000000002`, 
                    104.57799999999999`}, {245.277, 105.312}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{238.93800000000002`, 169.695}, {240.52, 
                    170.785}, {240.44899999999998`, 172.18}, {239.648, 
                    173.379}, {238.586, 174.97299999999998`}, {231.312, 
                    181.105}, {231.312, 181.105}, {231.312, 181.105}, {
                    234.195, 172.039}, {235.262, 170.445}, {236.062, 
                    169.25}, {237.34, 168.63299999999998`}, {
                    238.93800000000002`, 169.695}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{245.277, 173.086}, {247.039, 173.844}, {
                    247.24599999999998`, 175.227}, {246.695, 176.555}, {
                    245.961, 178.32800000000003`}, {240.02700000000002`, 
                    185.762}, {240.02700000000002`, 185.762}, {
                    240.02700000000002`, 185.762}, {241.086, 176.309}, {
                    241.82000000000002`, 174.535}, {242.371, 173.207}, {
                    243.504, 172.35200000000003`}, {245.277, 173.086}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{252.156, 175.172}, {254.035, 175.57}, {254.508, 
                    176.88700000000003`}, {254.227, 178.30100000000002`}, {
                    253.85200000000003`, 180.184}, {249.48000000000002`, 
                    188.63299999999998`}, {249.48000000000002`, 
                    188.63299999999998`}, {249.48000000000002`, 
                    188.63299999999998`}, {248.676, 179.15200000000002`}, {
                    249.05100000000002`, 177.26999999999998`}, {
                    249.33200000000002`, 175.859}, {250.27299999999997`, 
                    174.80100000000002`}, {252.156, 175.172}}}], 
                    FilledCurveBox[CompressedData["
1:eJxTTMoPSmJmYGBgBOLNQALEZmAC80fRKBpFo2gUwRAApg0EFg==
                    
                    "], CompressedData["
1:eJxdWQu0TdUaPkjJKyLlVZFHhuqEqy6SWZJBNLL3Wmu/914ka8211z77HHSS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                    
                    "]], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, CompressedData["
1:eJxdVGlIFlEU/dSw1bTsh6SmZi4hYUqrIV1LKSudNyUmaSZiENK892GSoiWJ
aURotpnRahJW2GKERYtaiGaQmllmamWSBqZg0oYZvTf3OQN9MMx3uMs5794z
zyuZbd5pZ7FYbPgTzx9b/mxLWfVB2W+F/tb5Xb//KtB35Wy9Z5EVPgs8rMC3
tqhkpxIriLTCDolLrbBn17GhfS0m1uON/+U3yn4nZX6tAg0blx8OOyjjFQoI
mJRh4pC7z/bWRJn54rXa1ewX2LPAPreJGfzW0Gkd5XHMiK9J4sq9mVHvnFf3
vGyIQprAtxTwC5pS6VZDwSJ+lxQoPE1n5xVTEDOxFCuQPefmut5UiufIlPyR
FM7Ve95Oi5M4VOL1Un8QhYUJR59+X6Egj5/E/gpsnbnoznkPCq5C+CwZ96bI
m6SgzgBTn67X3dSnz8PR1OcuFmZn6tPzfmlGv8fpJ1wmDWuGPv28/Zqhp1EI
/qjBVbEIGwX49Kyh7zW4NzrentkZjfG3mqFX31e77A8K8NMvTWzTDP7rI/xP
q2bsbyI+sZ+J+gl/6XxvNPCxzz211pkgX7eGfvMlhj4dLyPony8aCPq6DcQ4
70sezkkl8MOfH8yBghhbRAFBf/hQCD+ye2CsjKCeYIq8xwmIqkdAsT/PDxN+
UWR9DoFYsa94CokPImfYZhMYFvXcD7p+Hn8n6jNNvtqLcwN7uH++qvfn5ccT
9EcVhRghPIngPhoovouk3iZZXyL1NVPYIfjKCe63hWLeDYJ+fkVRdz3Bc7dR
fH8y8y9HVI+O/5H6B6TfbFQQW0+wY4inqpA/yIV6MdTnoqJ+YLhff1X6iIH4
DLKWqDi3HAbRyU5xK8NVnOsZiTepqLOK4d6ICm5CT4XsByrur5hBt9DvpqJf
0hn0ZnGGEWLw6Xt7TWC64MtiUC382ESMeh0/kf44wHCeF8x6Pr2AQ7EE74MY
ZvhHj6cw2C7mG0AMfn3e3gS/jwKGfnQl0Nn8c0vfNRPr83xo5i8WOl+Y/YrF
fLsYlAp/hhDwFXWDZlz30RiDSjEYD4L3hYMVsSOBjBq+AA+JJ0t/B5v38f/3
8z9bA3i2
                    "]], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, {{{244.824, 67.52}, {245.008, 
                    67.45700000000001}, {245.195, 67.395}, {245.258, 
                    67.21100000000001}, {245.32000000000002`, 67.023}, {
                    245.258, 66.84}, {245.195, 66.65199999999999}, {245.008, 
                    66.527}, {244.578, 66.527}, {244.453, 
                    66.65199999999999}, {244.32800000000003`, 66.84}, {
                    244.266, 67.023}, {244.32800000000003`, 
                    67.21100000000001}, {244.453, 67.395}, {244.578, 
                    67.45700000000001}, {244.824, 67.52}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    244.754, 67.273}, {244.875, 67.21100000000001}, {
                    244.93800000000002`, 67.086}, {244.875, 
                    66.96100000000001}, {244.754, 66.902}, {244.629, 
                    66.96100000000001}, {244.566, 67.086}, {244.629, 
                    67.21100000000001}, {244.754, 67.273}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{244.80100000000002`, 66.422}, {
                    244.48800000000003`, 66.418}, {244.23, 
                    66.67599999999999}, {244.23, 66.988}, {244.23, 67.301}, {
                    244.48800000000003`, 67.55499999999999}, {
                    244.80100000000002`, 67.55499999999999}, {
                    245.11299999999997`, 67.55499999999999}, {
                    245.36700000000002`, 67.301}, {245.36700000000002`, 
                    66.988}, {245.36700000000002`, 66.67599999999999}, {
                    245.11299999999997`, 66.418}, {244.80100000000002`, 
                    66.422}}}], 
                    FilledCurveBox[{CompressedData["
1:eJxTTMoPSmJiYGA4A8TMQMwA5DCOolFEQwQA/LgDRQ==
                    
                    "], CompressedData["
1:eJxTTMoPSmJiYGC4yMjAwAykGYAcxlE0ikbRKBpF9EAArgAEUA==
                    
                    "]}, {CompressedData["
1:eJxdVwlQVlUUJjSHUXIpMhMkXFLCMbGSKNJOYwbyv+23VVzGjCZ1lHfvjSnE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                    "], CompressedData["
1:eJxVWXmcFNURXhFWEhZEUOKxbEARZD04FBFY8bEgiAfszHTPTM/OxYIRAs70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                    "]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{244.754, 66.848}, {244.625, 66.848}, {244.52, 
                    66.94900000000001}, {244.52, 67.07799999999999}, {244.52, 
                    67.20700000000001}, {244.625, 67.309}, {244.754, 
                    67.309}, {244.879, 67.309}, {244.984, 
                    67.20700000000001}, {244.984, 67.07799999999999}, {
                    244.984, 66.94900000000001}, {244.879, 66.848}, {244.754, 
                    66.848}}}]}, {
                    RGBColor[0., 0.686275, 0.7921569999999999], 
                    Thickness[0.00019063687500000002`], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{244.754, 66.84799999999998}, {244.625, 
                    66.84799999999998}, {244.52, 66.94899999999998}, {244.52, 
                    67.07799999999997}, {244.52, 67.20700000000002}, {244.625,
                     67.309}, {244.754, 67.309}, {244.879, 67.309}, {244.984, 
                    67.20700000000002}, {244.984, 67.07799999999997}, {
                    244.984, 66.94899999999998}, {244.879, 
                    66.84799999999998}, {244.754, 66.84799999999998}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[0.996078, 0.772549, 0.047058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxllHlIFFEcxzevxEw7bDOvDsKORXbXmTezMzuz+9sOSkQsJf/QCLMEISux
EDGKCsRERESxP8xAIygqKRErKYkOiC7KBLtLZCsRSa2IEKF97/d8YrswzHx2
3vv+ru+b1UWHc4pDLRbLvMBVELhCAldzfFhezHMDLPR30gn/85P2rT0/j+ug
dz+u6Ftph7tHm+LDejTYsLvh/u8zDij9NnV5otwF0SG2GuuKdKDLp5tN2FF/
9tCSYU1wov3j2oh2Yy43AtRY377406SDGTV4oSzNB19frnn/95PC4/uA7OnN
iC6SIfDWjLrpw/W5DoxfEsxs3XInOALyp/wAd2i+LU7U7QPU/ZIOcZ3bhqq6
AdRaX6G/jK/fBWBjgnagr+NivIJpGiF1xly+4uL5OyHnVkr16GJVcAetsztd
8Hqa33YHDF9sfbjKYQea9XDxxiBe54y8mpQg8bsNJvuziha9kflcHPj/O4mv
l3jdMlSxgiTMa1SGY5TzJX4nWOd4OtwoL2kcO0dw3yUJ85QJ+Gl/TsiwpY5O
VMa4LsLzIFjHEQKVI6nOyFICyfn73Z+zCTyjA01WMK6N8L4pqP+dQMvmgGAr
gYPUJ10KVI/uDHRK5n1Xsa5rKs7nvIJ6bRr285VLMHuf4hZ8ndbxweB9cGGc
RA+vRxXM4vYrgpmfNino20kT+z9OuK9N7jMCLpqfw4N1vyaoO+CBJFp3rMLr
9/L58f4s9YJC9TtkXNfggV/TA5UjEYTPx8Q8CmTs1wGT5yfxeCb6tUKCbHp+
Hhg8vgR021SGgedqn4x9DDeEPtNbYOD8amXsf6Qb9awEJug8K3U8d0MEdUKD
mZ2Pwlk99IkimH0PTFUwy+ORyn3pFsx0LLPM4vh07he+Xtf4PHm8TA39mTTj
Xw33+/k5ytUFs/29hmCcowf91ynDMvoQBhCb1tX2Y74KT2mchYD9StVw3lb+
Pbino4/CvYKZDwYNwU3Up2Ma+rWe9yNTEoz+dghmPjudhpzlwjnk2USfZ5j5
wW0IZnUneGAvPZC37UH8D1c2WwE=
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}}}, CompressedData["
1:eJxlVg1MlVUYvhKhY4RlZkytWbFMqhWupg7u5T3nO5d7L5ef77s2EmXMiArL
oIgxMOfGyIgcZGoLphZZRrqy32U1Yy5+lFjNrGWsqJH86MylOKNy/XznPOee
b467fffu2Tnnfd/zPM/7fvem8urYQ1f4fL4Z7rPVfRLcZ3kLWztmZ9PbC1dX
ZDU7FMd5KQm3N3fHqCLrl6LW+wm4bCWtWvHR0bpUbnCJxGXC4IMX/vmuviNI
f9xW+sIX78QM/rx2e1piv2Nwe9WcpsPcoY8lXhekI9FlLeycTa0vuwvnBNZr
pmOf/CxidOL1J/zJU2FKvfOD3b+HchB/PEhL3LQXTwWoed7Q11NNQSr7LJKS
MBig6w6ERjbM9fD8u4bTk54UBs+V67UWiS3rJy6VEOK9ybG+hiFvJ6c9Qbdi
wbGvgyOPZZElcYNlsLpXgzC4pvLFsxvfDdLjE5f2nd/Dsb4il758TQZkBvdc
dIlb6uF9/S4xI2TuF8fQxcMqzwVBb0l8DQMPR7UuxR5W9Sdyg9W5bxn9venR
Q7UfBqfhb27+8a9NGRw6dAbpXklIDafZinfNd5hD1yFBu3oXvVfzHKffnE9u
3Dyo4/dwxNkvcL9JTuratQJ5euLxBA3KhVbNc7ow8TPkb5ow+dXvNgt5sji1
yfpsi6SsjX0Met5jUSDZdcowo52yrkoL8V08ebyg/Op2C7x+z5Cv16KZjS9Z
WxYyxNtqQXcfwT+jHkZ9QYPVPR7MpR1picWpwwS9q0Oo72lOSTLuHSHwk6b5
WROiiNRnnFHD6VszZx0KIf9PDL5eHIbOizV/yWETT51Lmo6VX6Mc8Ur1+Zmc
7pa87A3rOBy8FES0j3T8jAj6+RXtz9NhWiAJnWFBtzkR5HmYA/M88JJugY/R
qM4X1Hrma/8J8F8f1XwJ6NmeZ7Dqn08jBqv9p3LBl+vTsWNugVUejvdXHKu8
XVq/UoG6ejnmRLNlfBzHqg+X6v69VkC3qzjmW5WOd4TpftU+rNRzYK2l9zPE
fZ6hvlSm/Uvap4zk9ecNBeCP7Yzkd5rwGx+rOF9lI8+vHH4szsb+lRapsVWV
RWekzmeE2Y+5pP1WECB5KvVsSM8ZTvVS//VF4GnAIleNrv6TNvrjSgF8i4M5
tkTQU/LcIx5Wur/v4Y05bsXrYuDvBCdpH/9+ja/3sJqrmezy9RBhfsc8rOoY
cwxW87/Tga+2EXxW59C45PVfDyueEvjleJJhnozq/d1al4wY7vEAp6bD7qRN
iul1TvK6OX0OfPsGx75GB3POZ9FxeX6DgzmxykL8Cgd96fpM8bXM0b7QeLaD
flyg5/9528SPv9+U73/Q9Txro848Tq7KB0Iltqlf7Sdb686wv82G32dx+k9+
JmzDTxz7FfEeVn0VyaH7Tu7d2funDT92BEz9yl9tAeOPgbruV+dXB6hLvkcy
i6Zh8BHAvZcXos+eIfQFFaKeMgbftBSiH1MY7vFYAfQqJ8zXY/nQ/6Af/TaV
D75qAyT/o/jcdcTNwRyp87CKPxA1WOk3kkebZaI+P+bYzxHTL3hfROiG1TKT
93/nfzxF5I4=
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxlVg1sU1UUHnNOssxNCS7LIIsKisKW9efdvv4wOO17Xdv99b3OYMYI0Ylh
AgLWptmAkCzLnETH0KFMCXFIcJEgoJCJOgnK3EBQcRoVVBS3MZdBBCdOXRa9
957b25g1eWm/3PvO/c53vnNu76ndEHn8lpSUlBn0aaNPKn0eWNH28c1gMRyc
u3yVp8WEBC7NTF3UciICK98PZaaOORGvrIKXtOfWjWwmEh+J1r1w7QeLxO/s
+a2r72wB/MkCvRWR+MNYe25anylxx/pZTSd9JoxMvnljoLUQ+svUbd7rBuSm
LcsqjBbhenQ6ZsfkVKvw7b6NxRkTQYgcz28eM90Y/4ofBvfv7r37iBtaci58
PtHkhzPxE6/lfeGGuw4FLm+ancR5RT/OT39Kl3g2W49pQIMdzx92Yrw3fLC2
h/4YckAK+3T6gMn0UzYBncow+YoPz7/TDkyWyQZN4u7xqa/rG3SJmUxbDvuR
V5WC664SOLfX3z2+h0jM1+2qxJzHN6rML4Epi3Drw0nM3xvXgdFNi6vwIKvj
aR3qR++3zrzqkJjzbyMSU9UfGb5O4J+ta3piR/3T8BoWUCfQuosWoFOc161A
diGtZMAPf1Cao+kE3mV8L+gY91kFrlIZm88m8lfgy3u//3vrAR1ep+lOHbMD
S3sqllzHeDoc5kIpuG++LuMvZHFzdXk+YcZ8UQOTEZtHYDvjZ2hYz2wH1lPR
4Mp5evAlAswV0TpN+JXA7wMVtXd0aNDODHaN4Hm9GsxhvnhUxXg7NFhgnXlw
7qsu9M9QEiM/v8Rcr8dK0Cc/q1jvDQHkt0+B9EbaOQUByGJ5riaoT00AGlh9
zhH87gng+ZcJ7lsQRF+FCOqXEZTxQqwR0qdj7tc0EW9FEH26jYCFhm3cH0R/
NxNYkkE7qCIk+lvUZ2EIXmYH1gh/jgaxz3bZ4dRN2tCzQrCT6fWZgthXCk7m
F8OOegyVof9yikQ9y4X/LKh/fZnQy4r17CiVmOf5Xkhivv/XEoxzmwWGWR3X
J3GivxKY90OXJvS3YL16fajD8zaRXxI/yQaPzYd+32jFvG73Yf4fiHj9XtGv
FvR1nRf5XbSJ/V6hpwP5ZXmFf53oz6gX6/mRG/3R7kX/Llss1n1Cz8XI5xef
6Ldi3F+lId+CJcCPGdPlfl63mhLEFR7h4wBsZsZ3K6j7ujAw9oO32nDuDhrY
H21WxPNMXPdb4WlGe3USc95vJ/GWpZTxE4n7wA7MPsUHIuIcIjH3i6pKzPln
unB+R5KYhW8cNiXm87/TRB/FnOjnuIn12K1KzOvRTv6PjxKcJ0Mm5p/nEPWO
YJ9/p0DTyU/3+tMjGG+OAizdpZ+YqEdYwXwbTTEX7DDA3t9kYv+M2jD+qsT9
aEO9VBP7tF/gbBPrWivm/w1Dxk/cb3z/iB35PGPIfqWX06FAtSH58/1gQJj1
9ymC+7cbYr4S+Jd9RgypTwLzeZfvkhjPd8ND7GL8y8A8Z3gkf9TfI/3B67vI
A119lIA1PA3z970e5OGsxP7Z4cS+g0rkf9Eh5k6l0FVF/66tQJ8POHG+ni8H
g+U36MF+myjHfrrPA+w/Sgpd5/223I3/L+JJzOOfKZMY52Yp+uErD1S7jp2O
XwrJfsH7IgT/ATGx0GU=
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}}}, CompressedData["
1:eJxllHlIVEEcx9ejkrIoNbvtILpEXHfddHff2/ed2ZWMiC6yA42sBCk7KAs7
ycBMJKS7KAKLLoqIEK1I/0iR6CJDEMuQMrssSKWixOjN+42zlAvD8Hkz+5vf
7/v7zkxes3lxTpjNZgsxR6Y5Qs1xfHR4xrCnGmzitz8J//PumJtz3ow14Kl4
uKNmYiI23M8/NvqdgZmZZQ++H7Jj44eea51HgcjQ+OLYMQ5aD9ew8PCpTVFt
bsXjEl9PHViu/ctHgKKORXfiBhjQBzdd3JLA4BNzFpPnM+z8NC0p4hyH+VUf
XMXovAsBOj+3P1txWQB2cypsB67Wz0spCQng/fMpr37VgOrL8kOUtasCKI5t
fvYzWu5fCrSLfc8CEMsxwwzFq+7NjQwt1f7l66mo/T4jsyw0gMV34oo6RqQo
vpBW2d1b4VA8Q+SXbqf8QtJgnrqkLWdWP96We+TrHsOP6UkRN8aPjaf1bC77
Yqf1Vi73O9H1Yv6a4ac5dlkFOUmnZZz6ttJJ+ydypJSw1e3fHFjuNhv5h5Fe
V52Un4NTXfuSKV4BpznVRX0AJ522uSj+KI4JK9d5Wxe4qG/VjPSId8Fqb72M
/9FFuv+Rfbo9G4HSvA89JTKfLSmoFvt/gPadn011/DZIz4ZUxdZ6nFfxra1m
YS0aqrp7GwvOACf9ZuBxPrhEIg6m+Pe+9ffz1wa5QPjpBkOeyKdLx0ghWyOj
PCp1XBF+6WRIFfnZfaTPW0b9bPTRXMdk/Qb5KFnqE23gi2nnot0c48V6mY90
SO/rjy7r5KTXBp3ya+PyPJ3yj/Jjgbg/tZo8n0Ok3zNXo/hnubw3mopvxRui
QWR1uJjT9wgvxeMcnVZfPRhUeMJf2sLofob1Z8tnE4LxyA9M8aNyU4CEIDcI
23wG+fWlV7HlG1uQ6V56yC86o/0eN8XrlfHmSa7u86+b/LLCT/ou8Si2/n9P
U9x26WzdpG8+iGMKt3PqazikPgyPRdyhgOhigRvU71j5bjX76D6Z71AfWz5v
0hQfE7p8dUO4vPhgX75OxeRvu2JL9wMJxJdB9yIjnuaThmIrryxdsVX/Xi+y
xYW8m9iPrffwSfB9/gsDg2Cj
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}}}, CompressedData["
1:eJxllg1MVlUYx18JlRGxFBRCBGM2P5oxm2QF78tzz70M8WNmH3wU3nvfe8lp
KzAi14yxGBCUwyxt4SwJq4HN1FqJKyILJdRVhpWhEjHmx1KnwsgRmd1z/+e9
Zwy2d/DjnPuc5/yf//Pc926r5NGnb/P5fBOczxbnE+Z8HnxNMc89kkHLFjt/
rLMpxLuyDgzdDC+iovS+lfV5RDWXVh1MeqKI8h/6vGtDNPO4gLOuedw6dPOX
l7Zn0fP+yFMf/Gt7fHqk4pm2OsnOKSdSsm06wHldFn1dtjU+PMmm+neKp1Zd
07DeZ41jH/+ZpVDp2jevlA+YFL3gs/euZmfSPZMq31aTTZpX+MZ3wxcDxB87
NMkk/cucqLDjAfp7rrPwq+Fx7fSeH29UGWPXJxqkbXr2wmgBUTK/0E4d608p
dNm5Xs0OHbpoDHk16IijquAIw+NOLmid5JiqQ8eappj03IXR3dd3MawvMulY
Ew+oeNwx7CRyv+Td/I9+8u4X4j2JTxal3zA8Tu2dPanyiEEtnKco0Gm/QUuj
wu6tzZWMujKP3fxOKvRF14b2xqnmOP455cxIxXxGzn8fG7jDpDQuSCmjh52y
t181oPcSocdBg949PGt/aR2j/o2xe7M/FfE7GD0+8NGOw+8buN8gIy5H1qsG
/ePYosxZf4HXs8Sg41yPegY/6DL+Lf6TZ3jnn+F+ijVQl3RGjguaO4d0oYOC
ep7TKeDYcH2vgnxv6YjvMLdte5yBc35TkM99Bk12ZN6UqCBejAGdfIR4fsnu
c39IdvUKmLQtPjw3ulfsrzSR38sMuq83oU88o7M8/3KTcnh9ziv0TWNCau82
E+efFfnuM9F/c4S+LTKeo8rcwubx7Pp1mYjfJp6fzNA/P4l6Ror+HRHreYw+
vt69wrpmop93Mvqe++9Pk2ZwQSeo1M2f+0vku4bRCc4PBGna3uz+jbNVnNsY
FOdlQd/WoPCfBp2qg0Ivwcslu+fHSp7p2LvPEHp1aairIjnUXyF2+yFZ1K9Q
g/6f6ORU3x9Zq8J/pmS37YpE/8Zo6PtVOuZbsYiXqot+Ffn6dPw2VeK28nev
hp6vK2Tw+59cLfxLFMt1CdeJX396TwD5T9PJcfvWeM2P9WodfvlBzNs2Hb7K
zcD+YZ34ttjidMzJbw1v/2buhwzhtxUB1LPJxFzcx+CnVyw8d1SlXD4o42zE
naiBF9u49zwN86lA8pXyzDS9QnIDn6enbeh3iqHeo4LjJCfwAxYqY9ezSfhP
MuanZHe+vGhjPrxF0MO06Tw32n+S3XqEsbE8qMCvDWJ/u0KMn/eVDf8GGbVz
PVpC66KfnPeRG+dDhnquEe8fn4rnbZsGHVvema8ifr6N902zmOeKjfm0VvAC
G/04Q4UvkmT80PttPt//u8jnooV9Sxn07ra8/N39nRbxstZcEvPhsgW/RzD4
+y6pT4j97kUkq7x+OZk0Z2HEnsQUG37cHvDyd/21OeD546gzxhJKAthfao1j
6BFAHyyy0P/V4rw0kb8u6rHEQj9GKfg+4LNQL0vUuyeI+rf6MS8GgtCrTLyP
e8Q8oEzMtw7JqLdkvC+C6IMjflrOv8/MDHr9crt7UBBzZaX8vvM/dq7buw==

                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxlVg1QVFUUXmklhkhSCQ0VirJslJZl39u37IIdUkaddBQrStP37r5Hf2ZJ
ZA4pw8QgiWNGDZpMjBExjdZYUpkxSaZZ2I+loWXgL7MRkTBqZg5DjL1zz937
xuHNvNn99t53zne+85379jZzxcLHrnO5XCPsu8a+Y+x7ypKary7PzoX7tfV5
7CkLovid/N2XhtxFoH8+JyHmXACqzhW0pD5UBJtnbFjes0aVuLnkydf7T2ZK
/PHW89vafpgGz+XGH2/6z5K4c6B8WWu1g/NY95H0WRb0DL53sX1jBnyxsna8
O9WC8e7CURklHlo/Yw7DCTFT1yUv0gDTlkUYLGxJtVMHYXJsxeYZaQwi79Z/
fWtzELY8O6ZyXyyD71btbUg5HIR/sbBfDInXJXf8dKXSuHZ9pEF1dAcgDb+8
pcPTrTax3/3QZ/9cVa/DxMVFoTOJKmzEBHU65R/tIxxnSNyGglY7eGzlvu8b
RzPK+4BC6wqDQ4220FtVifm6T5OY6/KrJuuL4h1I5IohsefUHbEV3xiAdN2r
NHDh1WxAae+d3rg+v8Scf40qMba9+4IKn35rCzGGDcPLMOBMFZB15EaRf7cC
wV32hvMG/DN0rLQ3VujRYsDd6J9qBbpWJ30466No/Qo8iI152yBf7fIBypH/
srP+PPZzhQE7eWMVyqM78a/i9bAh859APyUZUICJb1fJV5d06mein/rZrcMf
R9JPDJxWie9VXfhVhWzE4wyoRYP1q8TnHgMmoJBhjeKNNeAub9yOiW9mU7xc
B3Mepx3M9ZrOSNezGu2vYMSvSaG6ixmMyrAjP6HCSeRfxuBF7M8hFb5sSPGc
2sQof5fgu5MBjtvgHKHvdieerfKUJduGY+5Xt4jfymAmPr9epfk5zMjfVWJ+
B5iYbwXev9g+z7zA4A1M+KgCB9F/ZxkcbyrOjd/ig3ZbxvK/GGxCvX5UAGUt
94chgH5Z4KM4DWHyX7KH9P0sLPyXSbqsDQu9vITnOpjnT3LwJPSpwSAR9bo+
k/yd5+DofEUxn4c0Q+ifSfp/oJO+r2SR/5iDceyGinTye7GXdCrQqf49Ip5H
F/Mq+Lt04teZBfEoTPtSoacfDKz/6FLh3wDY7u9a7dapn/uDxP9mnXxTmEPr
a3WhZw75o1UX85ZL+y8LvtOmg716rHS/Ife/in7IEf2YFyIejQzWYOCgQn56
yaS5HZkFhWi8cRbNR42XsGbRer6XzqdFDu4vu1fVyx1ch+dppyX8Ivo9aFF/
l6sSc79omsScf0K28J+D6fx0MM/zgkU6rAzQJ7OoH/WaxLwfteq1+BOV/GrH
4/Wn+OE+zLfHgr9tW930mwJ7UY/tIt4EhfJXCz3mK9TPx8X+Oh89b1nki94s
iv9I9P2YRXrlWTTPBwXOsEDFwk0f/IzzkerEj77f+P4eH/H505TzyvVuNyV/
vr/NhPlI9IA4H/pMcb6q5O9bHH2imJ93qdkSU/4g+TbdIj+OCEn+pH9I+oP3
bWqI9peYwzB/Pi9E86CYND+vBSifKvh3+kmv2WJ/hUb/B1wmPMNf+AHqd0cY
FmB9kRCdF5Ew+XhyiOJ1iPNgcZDOtwMOpn47mN4XYfLD0RDMRWKTwnJebuDG
DMP/+LzHsw==
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxlVg9MVVUYR6KXcwRmjRkgC4LUIeP9O+8+3oP4UBy5JNEWCzNm9O6795op
qDlK1sYYoUtDh4qLOTLGmuTMlTKmZIaJGVBOy8o0QyIio7KS5ojWPed33r0r
3nb39nvnu9/3O7/v953zUivWr1DviIqKmmY+jeYTbT7zVjX23Hokj96+eaG4
IlelCP7m9strut8IUfnxJbHRN/zAJSHas+jVtSNbmIWPbNB3jV1xWvjd/b++
1du3gOpvLO9KOWjjNxd3/jGZrFr42MebT7aWqzQycfDmhR1ZlLwyFLzWoNLs
mNK4rA3ZdJSv907FsdGZDQllCs34sq0yr0ejFV0pZqkAnU8zGbyi01B7y0cP
HAmAd6tO58zXEj8L0Jb7DhcNHrdxDk849L/1NAO8h/3IV2rQc92bmmZ/76Mo
/nnSAM94RtlX0x21ZQbq3+MBTrXxvXWnPjkwqFtY8NqtU0PC15/+9bgX61U6
9R8whdnPLCzWPYqF3zfLx1xSrP1F8FzX9EPJHTYW+z2tE6cbs1mhcd7IAZ2q
Rx9yTf/ZZ2HBv5FZWNlWsHr4N0YLVw+fT2uaitfwhIUM7zXLep1efB/W6c/J
z6tHHZL/OZ3mc/9s9ULHgcj+vbSUJ/5Chw+Oemjfull1p67b6yLfLzq9w/1U
46Vmvj5u5xd8b9v1N/KwJIOW7zAjH2Q0h/PLNNDPeB/66TboBy7ct4y46kMZ
hvQro0LTxhP3G9TEDTbGwCfOoCTeyGcU5DPzC51fz6GXeD6HjQW/Tt3CBVwv
TYdPvlPQ73Qd/Nq89EFrYvZVr05xWeYEaAz6zNfpRd6ffgZdZuqoP8iwz3GN
+LhNLGHQb1Kz8o3V5LPyf6Zi4dcYme9HDfvcxjA/lzTUrWdUlWdO0CFNzrfs
zzGN9vKCT3lpFu/nGY34mM1o9tDOnlvzVp3QaDfXa8ALvF4jP/dLiQd6ODT4
LyFb9jMs/eeE/qma1MuFfpbZWMzPLhuL+MU6xXO97nJS76MmwZCNI/MVweK9
BEPq70T/HzOg73Y39veCjTMctXsWbTTg90oXXeHnV42B/Z+Q+V4z5Lw6wbdd
9v+yG/Hd8ryo99FZzs/E8K+fxFeb9NOHAcxTiwFdSnOx/qwh9cwFnyJDzlse
4jMl3wUPo84Z3Yrnr+cbEhcHcf7G6Nh3wIv+p4eh451uuR8V89HoAl6nSp1d
4L/UxoLfXBsLPn2R+8CDOh0h9Hcts7Dwi6JYWPCPzZH+s7Hgf7dqYTFv2Sp4
b5L3TaGKfrQoFhb9aGL/xe8xcnL/mPlE3UQf5vmnEP1uXmszv5Lz93cI+ZKk
3+dIPZbJ8yRfRfw+eT4tVDE/o27kL47cj27pRxXzfNYN/apVYlygCg/62WDn
j9xvIn7EAz7dqjWvjXyeLtr8hR7XVFrG5/s0o5M8vkuV5yuDz7fb+kSwOO9S
ciyM+gF6gheuU+HHaUGLP/QPWv4Q/c0MIt4TnoLF+wVBzENVGPOz0496lWHw
v+yDXk/L+FoF/m0P0/Piwvdjf31hKuH7G5L1e8KIywgiX38Yv68M4Hy7bmP0
W7OwuM+LNPjhYpA6+P+ZrZo1L6K/LRr9C1IyyJU=
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxlVQ1MlWUUviLdiEiwGXPgMEvNghv35/vud38EDkNmGArC/S73fj/XYDbK
LE0didzczKmxcuDQcDFnZM25ObR0zPk3kdJ+yB9qWkglQyIC+tGSGWl973ve
+35r3O2OPbzvPec5z3nOeWdVrSp7frLFYplkfBuMb5zxnac1nP3rmRx4ccdo
NM8mQwyfWtc0Pf52OUSOFyXFDXvgNjmQy2FXwVsrB+tEjg+veWHHaK+d44/3
/Lb/3JdZkLFleOkxa4DjRUlxmdt+NfHreWLk+KsyDI4f+KN7uw22pX53YaxT
hunxwSm2Ndl4nh+cgEmY1LAE6dnfz7Z6FSg7RjL5oP3W3W/Wd6jQ/2HLJ48e
9sHlx67d2XhThc9rTu9Nu+iDxKv7Vuc8pXFcOzTXkRA18YPk/G8NCO2MAQ/0
bZjWtrBSh5dOGkLccIOB+jYs12GGstz/Y7IIa42yo9U65p/qQjymcew9+lnN
6ddM3Htn44qTvSrWWS7g/WYVuloL22/tETmm5y6JY9qHKxKvL4YDpNAEjeNu
Uq9PA0I3vkYCC/mUarCe1Dni5pjybxA5lurznxv4XYTdrzy8+UyPOgGvIAEX
iLCkKiXkvcHytwtw/lnjZooGfxq0hqyM/0INniT+eVOAmUTIJbH6BThIEi/T
4H2j3LtHXdjPWvN8e7ORsFGDQ8RPUQEWGDYbbzXj/0s++zWef7Z1066CYQ2W
kh8+zvgl6djPZDf2M02Hny4ZwvwgIl+LzvwqwjmCf9agiRhsVEQ+lzX0VaWE
8UY0eMKRcHDGu170z1kTU36zTEz1ekNFXa9L8Ajxyz8K8tsnIO8MFabYjAmo
FqGIGNmqog+7RNh85ovWwisK5u8TUY/3FCDjNl4kYh1tZjzqz48mYurXeBZ/
q4I861l9lQr6ewub34cUNt+sPzMVeIckVJk/8xQgZSc2u0An9zIV2En0+kqA
ZQQ3hcFD/FLqwjwdIfRfajbrZ4j5z479GwsxvRyIq8Mc0/xXTUz7BSokE73u
t6NvoiaOzVcM03m4rjH97divMh31fduJ8feamNbdoqPfVzuwP2061n+Cxbuk
s3m1Y1xLBPn1OFE/W4Tp6UZ+WRHmXw+MkH+P69jPDraPftExT3A+ntfpTM/5
qGeBzuYtB+8nMr5Zubg/czV+f4D4YauKeLEf+ZxSoI4sKp+AfroXBMK+/z4n
q0fG+WhwIG6U8bzQAdfIfio28RwyX5NNTPksCjC/uNCXDwSwvytFjqlfJIlj
yj/Jy/xnYurnCyam8zZNRh3XeVCnXBn70SJxTPvRJP4fH2H752IA609zQ5Tk
qw/Aze7FVSnfMj3aAhgvXcD8xntE9SgRgLbRJeP93Ww/eWX09ZAT45fE3kcn
7vOojPN83on6fSCDSASqcmE/O2UeP/a+0fuDLuTzdJDPK9VbDXL+9P7aIJSQ
Qepk+2FukO1XEd+jLlOfGKZ1ZXg5xvw+OELe3RMy+nGSn/NH/f3cH7S/mX68
n14xAdPf5/txfpsrcH4aPZhvZwXy73GjXqvY/U0Svgf3KuBl+uB7sN/FISgl
9fX7cV94QjhPc/wYr5jtC8WH+63WxNhvE1O9CsL492s/0PX1aZjPC+3vcBj+
A+kU0+0=
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}}}, CompressedData["
1:eJxllg1MlWUUx69ISETMioyBoTayxKhZc0lw33veD0Yoft/3frwfV2GU2goM
mYXd3MyUyGEUNnJWptnMrdHn0lkyFTHNMrUmmbBi5VfYF02ZUtTzPOfc95nj
bu/ufjzvPc95/v9zzsOEypp5j4z0+Xwj2NPMniT2TGtUF56ZUwxLXv4tHigw
IcF76lqyki/Ph6qiH2c3hQEu3+28tN+cD5HCTw4tz9A8jnKOGR7v/Pvf757e
WAK5a/rm7koJejw9PWlyw++Snw1Mje1+0oRPOS8pgYYxp44OdJjQ1Fp98+o/
DVxXQ8PYxz/jVci5rycvpdCCjIKP3vijNIBx9tkwiaVx6bwCx+84fWVlvw2x
3WXpSUcUSOt6e6k/3/G4/sLEKalxyTfw9asOGOsePzcYBehdkdlWWuHiuq0C
o94VVS5sLWE7GRosW8wEW+Ri3rqOPOB4zGVpf0py95WVj33ebcMT5wZ3/LWV
ft9qw5dbeEDV445LTMj7Je84OOPBxl7wzpfg4M/vbDqQ6nh8gp/3IQfe5XyT
ijrNcVD3kGSRf7LmscjvWxVeYzLv/cEexkLHfA1mVY6OFP5iw1QuSK0GX7Bt
1NEO6v0wnafUgdcPjP+g9gUNxnH/Z1H8Dg3eG2tVFS1w8Hz9GvpZ78BVJksd
Wxc+NztwhOvRpKEPW2T8//hnu+Ptn5ey6lW9z4GLc3flrimi/NJd4GWxqlNF
P7NdULjxPSrm63MxPmMuk3rewTo/qWI+xx0YxcKuG6tivIsO6uQDrJ/9kkV+
EyQLvZ6zYUNWciijB+BWXi//WJjfMxruk2ujPlkalHFfUmz8PqvC6r2sEk5a
uH+3inq8ZWH/3aXB2WPMiDYZT9Tnh8NZ1OsMir+Wfj+K9K6w0M806t8baT1M
/oyzsJ/fJD8DFvbZCB1cHneyhXEf1WAB55YonjNPRz32RWi/EvIzQvVnoH8D
EdKLeFHUY7F/l2ThF5Behwys27jkRH8lWPTDT+SfY6Bf81zgX2kNOsbfLFno
tIn69xYD/Wlzcb5VU7xjLvWrQXnF8HuhjvoVxFDPF1XM754Y1S+gL4Mu8OOP
OUXz6FcXWLW3ZBl+8s3Fevm6GPXUXcwjVEw+ucDlzawuQh0Vx3v/DK+HtVRv
MxXMZ48Ftdy39zWsp6EQzo3DOp3HxP64js7XbKJvkww4zedTueQ7eX+NlCzy
mR5E/bo00Pnfrye+TXI232CKeu16KVD9SRb1fFSy6LdME+fDK4A6KCa+NyRZ
+JGkXcv9NC+/CeL77SrE+X6NQazfCtKjLbFO/cTuI+HbNg36uB8P0P3j0zHf
QhP6T8xkmdF8n23ifbOd5nncxPm0WEf9tpnoa46OfrL7LBE/cb/l8/e/p3zu
DZGuGupth7z8xfvLQphXH82HiSGs91QN76OvpD4J9ovClyx8KAvAxyzrg5+Z
WI8bFS9/UV/rFa8+Di9v35xdo+D7OeFhjHoo2L+tYez/52m/DWHMJ0Z+1ISx
H9NVvA+GwuhXJfldHkH/d/pR92kR1KtOwXjlNC8ggPOtXjL6LRnv2SjwbXI7
/SDGV2fU6xfUMQq3W3xCyf93/gcwRuih
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}}}, CompressedData["
1:eJxllAlIVUEUhtVsIURK27Bso03aIwlLe/+d96Rs18gyUlrJO/MyowWzMqJM
SiorsyJbLKyMiIg2QkssLNowkfaIMpVsAZOMLKOZe6Z7IR/cd993Z945//nn
nNtv8cq4ZW18fHx85bVAXn7yyu3hHx/4KBI+6lMh8D9v6HJh0rsQF0rW7O/h
H+iFKJY/Prjo+VeBFXW/ihr2AbeOh4x8Uyxo3T8ScwKHXzp6m9scOn/phLfC
4fGX7627+cpE5qfY673bupAa1fHZqcsmJspbaqJB+U+YWP9x0OgO+QzqcdQ+
k/Kd9KBpyII9ZYWtuefINwPaGR6o8MfLTZwtnzpuh68Hd+XNqDCpvkQ36a80
kdXtxeMfwR5cUfvrTdRU9H/187GH8vXmNlvrKf9xPcft7zKxn84fKmxW6RYW
OZyu8jUJ0ucbjeCtpfcLEryteHXy3i8bXW7Ir/CkGXp9ESOuFbT+lmFguy0H
3PsFvlVOX9zpEMMq5V+OgJLdcS4jP3P1/j4MssrZ1QUC8yKkM38Mqn+n1jeG
obrwyJ2+qTpeGsPJ6KuNLfMEnQMYlIwtsTp+d0b9EC+g0qSWGOTHfAHreMt1
fCZQq/yS+az6wgQ82d66Xzu0ns6C4jSB8g8T5FOzi/ys4TZb6/kOn2uQQpdy
XGtsqUo7DOw+mBK0NZIjPOlGTMAYw+bmDF68ZonDaaqfzms9BkdXGS69yoBl
ewzHGdUvDQbpi9Dn+97ANHWeAzn5cscg3d04lJz0sQyjlD+hHJ9lO2du0P6M
4AiTZXyfrM9nFic/jjHyK07rq9Z+JGj9QW7Eq/lZ/i8/g5Jfuk7HP8KQUyYX
NjvxrXgZHHLKZu7KYuT/MR2P6fO8yNFetk32awNzVfxbrdmaj1AnHvWDYfP9
AhlouMNPZDkZ9YD85sXbHKb5dbiXmv9rnPolysBLtf+5jtdi0Lw+1Vyi+7eK
U78kuKn/rjhs/T/ZYevej9O+tbr+P6b2R5//bxNXVb9EAJVKV7OJAL+h8hUw
keapD7fZei8tc9iavzKOGPVgu9abJ2y2+umjw1a9g73Ep0F+TfHSfOS5bH6g
6k2Mstmqf9ME6m//1my9Dx867+e/8LeRNg==
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxllHlIFFEcx63EImI7sTDXMjKVjt11Z2bdza1fWYRdlJGViYgpOe9ttklI
dBhiERadmv1RVhpBRkmFR4Sl2ElUyCZlipWIhoqVnXTSvPd7zkC7MOx85r35
Hd/f9014+tbEzGEBAQFDtGujdg3VruJJgUmmp3EQwH5NFP7nx2WLaz7vccHt
7UWTAk0e/K9xwq4JlUs63lPwvPtVMZATC/XnQiztdRTY9j/Fblhrmn2j9C7R
2ZycMfcNNdhV9Sj3TpsKB4JfPfte5AKve+TLC1UqdDdNa/vxWsH851WQU28l
jEqXQFv1uk+I/Wus8C0q5WjjRX9m20ZOtAELf+6BCnWs3hIbPFzmKFzQpGLc
tzFYv08F7Wlal9cG1Wx/rwozeUAL5gsjOvP17P+4l4j6bZjfTHVm6dIqDN7J
8n2j0Hnx9L2pVguML2h4XLbB48eRthFXQkPs0L97vpy60gOffCvSx7RIyN0U
11vtEBGUfzK+iEK0lvZrlgTbmH7HKDC5hvZJqGcxxT6TZWAqdZZRuJ6Tdbz/
jIzPD1IoZ/OQZKzDS2HRITZRCZ+vF/lCZLC0Tw/KX01hR88M2wiPjD5IovCE
DdSsoB7JFLSoOyeYFIy/kEJJvBbwtIz9RVPY37f6Zth+CesZK/x21YH5Z4l4
pU7Us4vozNfPGHx5QBMmg2CczFg4cip7XEEcEf04dN7C/OlTdOZ+WqhgPQsI
xv0og6bK7vkJBP1TK/Ryivk+l2E5m2cEgVDm49EK9h8s3rfKYGX6mAkoLH65
hOtzCHz507yjJ0jG+awiqMdGCfVKHKzPjvk2EPRrrh2S2PnZPJjfDqz8hlwC
qw5rd5skONb4NSplrxGfx8sjOL9CCfU/K+IFy6jLNQKT2SA7ZFjH4tf7Mz8f
aUY87q9Lis78e+B26Mzned8BbT/ySN0+g/H8Gsx1qxXzMzugle1vGZynjOf1
BUF/hgr/Nov3u2LQf9UG8/ezDOZ9hxP0X6Xo/68Ko7W2PgwXfvitol4znODT
PjN5P8X3oMGF52kK0ZnHzTSYn79Ggn49rGC9JVRn7qceg3m/kR7kFbGo11IP
zm+YS2fuh7lxOvO6Q+ahvwP9+R9CWIsK
                    "]]}}, AspectRatio -> 
                  Automatic, ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 480.}, {0., 240.}}], ",", 
                 GraphicsBox[{
                   Thickness[0.0010416666666666667`], {
                    FaceForm[{
                    RGBColor[0., 0.478431, 0.23921600000000004`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     480.}, {960., 480.}, {960., 320.}, {0., 320.}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     320.}, {960., 320.}, {960., 160.}, {0., 160.}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.8078430000000001, 0.06666670000000002, 0.14902], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     160.}, {960., 160.}, {960., 0.}, {0., 0.}}}]}, {
                    Thickness[0.0010416666666666667`], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     480.}, {240., 320.}, {240., 160.}, {0., 0.}}}]}}, 
                  AspectRatio -> Automatic, ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 960.}, {0., 480.}}], ",", 
                 GraphicsBox[{
                   Thickness[0.0016666666666666668`], {
                    FaceForm[{
                    RGBColor[0., 0.42352900000000004`, 0.20784300000000003`], 
                    
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 400.}, {600., 400.}, {600., 0.}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}, CompressedData["
1:eJxTTMoPSmJiYGBIB2JmIGZkYWZkHkqIgRHoaIaBdQMAS8ME2Q==
                    
                    "], {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, {CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQZaBQ73/Xun50kUOyxy3fb5r0qBw5YTZfvmA/nC
zQdOLZQtcNBuF7t5TrTYoXzffCl94QIHIZA4f7FDUcbEtzXf8x14dTfNff+/
yGFGHlBmVj5E/nyRA9j8GfkOny75JgnMKHJofR24Q25qvsOy2UcUNlQUOYC0
23fmO3Q6Jjy9AOQDeaZxm/IdqkXWuT9Mgeq/kO9gy3V9cYF/EcQ9b/MdFDYA
bQ4sgugTKYCYkwhVr1bgwAdyT26RgxbI3doFEPGyIog+Q6j67iKIOywKHKpA
9q0rgriTp8DhHcgdVVD3sBVAxBcVOYC8f/dHPkT9sSKIOyWg5l+D2m9SAHHn
zyJIOAL5D0Dhy1UMUQ/kP14KtBgYvujhDwBPyaXl
                    
                    "], CompressedData["
1:eJxlVQ1MlmUUZeSquWJEX2gNSawcEwtdmSWVV4uwOURpc9mIGeVGJd/33PuU
ljU2p4lm5oiVzp80FQdlStaatUnUyhqlox/GrBVJs2ZkgJmFrex93nPQLdnY
y/2477nnnnvu/fKqUuUL0tPS0hZHv+EZ/3yvcuLL0qrMbC+XL2trf7VTpebn
v5sHEl5mTl41bf5nKp1PHhs7cbiXxa1brircr9JdtmZdst+k8r17Lkl/S2XC
d9deuLTTpGHksLkZdSpvf7qodcsuk3XJrGVtO5l/n8nOjR+NbmlT5F1jcv/D
Rd1lEf6+3Gd753yuMrrFquvfV8kKPB5T8HmD9WerFIY6zSqNAedulZj/iyrV
9cefmVqg8nRid8kRp1JyZEli90WsU6qyPvDIJP5E9purkhMIjFD0Wcj3LlA5
ED64hfh/OeCnVH4MhU87WRj0OaDQ44yT6L+TKuca4j4HHo8b6nU54Oww6NLi
JOp2X26D4fOtzF/OeLaTW0NikUnHmG8Ha/Md9Il0i+tkOvCvVHltIPrjZAp5
2Qrcj1PgUUD+O1LIn6Eyff7RjjH3piTj+r2b+2o4t1LGL7H+r0n0u8BkSuBR
lsTnKziX4hTmUM+++lPIb3Zyx/Cu7W6Sk3F12YcPrXWYe4WDD4ap5AU9nhjq
V2XltIjQCierwrNJwaPBwX+7FO9tcvJDwNmg8kXoc4PDHPqdbCt+5/d/mhi3
s87XrPsynzdTl5mcYx198rwDnzX0T1Q3ntdhxt0O9X6hjwbIO81Q74SDr0Ya
+PVQjwn09UHyG2/op4n8Kg06RvrEflhpsiTg1nKuPfTNauafYv4eh/3J8tA/
4nd70PtKL5cG3frow7EeOOkq7wbfTPHy4R/5FWtz6J8KD70zz8WxThfTz/O8
zAh7MOgQF3v038t+y5nfwbk86rGPrezf+bPziONa8jlEffd4+Oro0Lw89J6j
58UPhPvSxTv0FO9Am8c+LOI+v0n8pKLPVzx4VXGvN3vsR7Qvv4V+n/OYYzn3
2VivjP3fyXgq92c844d4FxLEe4HvJ6hnO/PTqc+pc3F8xwZVPgnv9/BOFnHO
Z4z1DPPIIP5thn5vYL838b7c6OGXWbyn0z3mUm2Y22Ue7+0lXj/xuwx++cqg
658GH71u0OM07/Vy+vkb4j3CvA8Y1/DZSPxq4q9m3oP0+0KDLlWGOZSw36XM
v5r3cJPJqLAwx1QKwt04aLgjjbwX+8nvrvPjeL+2cn+y6Z8k/59DvHnsO09x
Vycb9noc8a4zzKtl6PuAfK4w4Ocb7tJ23sd/+X32k8EPJ/XsHOO8XsU+jvDy
/+/X/wAwLEGX
                    "], {{277.25, 304.707}, {276.43799999999993`,
                     304.637}, {275.53499999999997`, 303.688}, {274.801, 
                    301.855}, {274.168, 300.465}, {273.39799999999997`, 
                    293.18}, {273.52299999999997`, 293.18}, {273.02, 
                    291.012}, {275.789, 290.094}, {277.051, 292.879}, {
                    278.93799999999993`, 297.98799999999994`}, {278.949, 
                    300.16400000000004`}, {279.074, 302.332}, {
                    278.78099999999995`, 303.97999999999996`}, {278.062, 
                    304.777}, {277.25, 304.707}}, CompressedData["
1:eJxNU2tIk1EYHlNMIv1hEVZqU8JuhA21ixE9SmGxItT0RxcZo8twbvt2zvnm
yCjKZNmPTAoqRIbGgkpUokQq1ggpkRCVQuwmIpISEcOkpKK+s/cE/Rjfzjnv
+1zeS7bDW37CbDKZYPzk19LDnC1lHFPh1n6LmeNNYDbXupujfllX6aSJI/6+
neNaemJV6gJDtjwXchw+vmPi4DTDC9vWpuLNHJeK7dPDvQzVj/ctMedzimtj
aJL3RRynJZ6f4aYnrSEKjsbPZX1Zxxj6sox/JzlSNz1o+2pV8QHFn86Id4Tj
peTp8EnZJlOuoPuN6hwQKJ00GLo1yrsoyM8hjfCvCHTs6Z37/c2LL2d2FVZf
F3g04I+ESrzYK/PaBa4+n1939IkbRQ+Nh7AgX69dWNoQHWy/JYh/Ww3dRwSc
LRKphnB/KLyuGopP0Ynf7qJ6rNIxPvS9Yqqylvwl6ygxPjk2D9Jk/CIV/96D
G7I+STruxUYPONK95CdRJ367l/LNOum976V+OXRUygJylR/RSd96N/VvhZ/0
RVy4Y9D0FPmx1prcmfHRhThsvp90VripnhY/miV+0E04Y0pP1EP8TMd+mTev
9JQr/Vs0ii/VidemIUMOymodOxeP3daCGuoioZV5MYHhnHcLZ19pkOUOzah+
5vkof0JgRL5f8FH8uOpvq4/8DgpkStwERnqN+qTI+WlW8/DrH77CmxWQdpoL
GDYEl48Pdav+1av8WsX3lpGPKoG8D2uSzhvzHs8zzvG8P2o+CwTcn37ejY0y
0m8RNM9hRv2yKD/nGO2FMa/xfTnCaM4zBflwMsJJU3x1jPwmKD2XFf4Ap74+
ZTRv/ZzinzE1z5z8zqh9aeTU1zlG9T+l9juR03z+t+9/AejMx9k=
                    
                    "], CompressedData["
1:eJxlVg9MV1UUJixiVIzA1NV0/lg6I5uQ/UOETsMCV44shWSJzdH88d7v3304
3ruP5mbk0loTEkoxQnRkDCnHJMWKSJwabmSSERhDRoRgfwQV54rVu+87Qpts
7O7ee9453/nOd8/5edYHX3o9PCwsrNL5V6v795SkH+LP39g0ZtCi3gcjNidJ
rFcM+vONpx/PS5B0ZM6WSysv8z5e0hll/6tBzumROXESa5dBn+w+PvdguCR7
+mcZ/S0GmS3V9y+aJimj3zmpNnAeIWnbM68NnvGyfYykY9cWvLo90aA/lP/p
kjKV/Q2B9T6JuGOCdsy6PTt6psR6ScB+FvsfEMgjViKuc5+bn9KXdQ/bjwr4
iZI0dnbF+pirgp5/0kFSbSGffIPmHjS8ZSmS+rLe+zAQYZDLz7gFP2s53y8t
mq0OqgyKfqSx6q86iy4o+0b+3mT7bgO85VkUV9LaXjNsAEeWhfwjC2mrWp+z
gL+T+U+3YFdrACdZtPbo8rvDg8xnOttnGJSnzp39w2/P6O5IMhBnjQVeI9ne
z/ldFuD5EMffKShRxZuwKDWqa18oRTAe5qcnROes4flJ2ayHuBA1q3xyJRWr
Oh4NgB9N0t5nv7gysdBPyYdOFbVskLQzEFvS+qYPeFZIcqJrX+3REfcxSaUK
yLu37l19REvwu04nj+LzmkUnVaFKdeQzYCHvah1877Jo3Enr2BbfLXu3PoUW
8Lb7EC/XIrXEH/YBP03Zu3mPm+D7uk4qneofTcpWji5p0M9ek7YrvIs1SlO8
VZh0l7OkRmnkH/q7bjRk0ryIzRXpQwXQZ6YJP09o0Ft/EQ3UOgV6UQc/s03w
c4HxxZjAI33QQVMR8q3X8R56i+iEcrSK8YwVUZPy78R34zjfu/UqK4BeHzKR
57ICrPkm4kcWIP4uk7xlDtJmL/C1mXRW6WXEC/89jMfD+cSwnh3/Lr57LcpR
/HzOeBIs+L+oQT9Lrcl8XV16LVK0pabp8LeJ72N06HCHRauVv04NeR7g+h/Q
UP/TFutFm9Svm/+jGuqfzP0sXgOfGyXqVaghz6qbetTA02FJSxRx59n/93IS
r8vnRd7/rEMfv0gSCuieAPD/xP1wRgj7fyR1d1x/eeDbIPTnscnpDrElq4Lw
n2GDz8EA8ObYsN/mh+7W2dDPYtbzGhv5jWjAudpGHnWc72kb9Wjg99Ru4z0u
8IE3Z/+NE7a33MfvwCYFp3XcN2nv4lnpB95pxTRfxd/tQx9LKYb/fn5vwWLY
z9Ohp9Ji8JOpw/9bxZPvy+UjxPbD3A+S2V+Nn+eMje+9AfDzNeO5Lch91UZf
aQtSgupz+2zWfwj2VTZwmiHk876NPBpC6ONbbdQtTODesoGTBOq20QZPuQJ4
Nth4N/UC+eps3yiQr8H8HhfA/Y6Nvnjz/gPGc1IA734buu8RmAev2OjDn/J8
SWT7Ae7/Hq7nhIE632kD51UD/fk3no/f8fw8JdEnGwyeIxLf+bn/97F+E3n+
TPA8Lxewn2lzn2X+FjKenBD0dgfvy0Lw4+jd5aWL+d8vcf+AAO+1EvPII3Bf
w+8reWrv+lkytXf5XSowNyrZfzPfV7D/LoF+Ui7RpwZ4vpdJ5oX5/5jtB3m+
10uc97C/Bok+0y2QdxPzeU6g7m38+6FTkE/18w7GO8Lz8QT7/1eg33/E7/8F
5reQ52cl87+c7YcM+Fkmod/fDXyXxvN1lPXwv99j/wFFn1ST
                    
                    "], CompressedData["
1:eJxTTMoPSmViYGAQBmIQDQZ/kh0uKN3+WfeuyEG4+cCphWeTHcr3zZfSf1/k
8K7G3jRuVrLDjDyh5gMPihzegvjrkh2qRda5PzxSBBFflOzg8bBKZN3WIoeM
iUAVnCkOO+VaXwc2FTmosTVOdZZOcXi8dPYRhbQihwmHvmrEaKc4gO0Ngspz
p0D0CRY53PlZl7VHJ8UhKsX6vj93kYPVlhNl+7xTHEDUfJYiB67riwtsy6Dm
WUDd05bi4A6yPx1qfn8KRF9jkUOBLVBHR4pD3C5PHqbbRQ6qIPv4oea/LXJY
5Lrt818OqHuA/t8KsocpxeG+f+/0PCAfPXwAlnOEaw==
                    
                    "], CompressedData["
1:eJxdUmtIlEEU/ZSQkJCw6EXJKmEPERWKwKiOhZRFhAX+kCxZE74HbvtNUPFd
EexB7I/KJWiLCKulHwtSIhK9WCJ6SIEsRciiZraJhGxRSesSQjN7pz8NDMMw
Z84599xb6j9+sD3fMIwKudU5ceBiJNBEMNT6JnAq3ruqqpGwvXAkGkwLXAsU
n322l9Ax/Sf244sALb23exIanxA4P9P4sGQD8RkTjPMRqsbXFnS3CXxS/Bs1
vlxAsr253UbYtyVU1xoN4ue7/f7Flwjrahb2rW4OwFP8Vwlj2S77aZ+DosqB
m9/DhNrBoZNxx0GibDTb1aP1GhyY4XTnjm5CXetUoixjs+5RgrtNFnDLxqMS
iawlvFKCm2zGL9d+DBsfTn8tr5n1mP+thSXKX8xDcjhzKHXdYnzYw07Ff8LC
muZjWyd2efi9/vDl5yst1pP3XC4DJtdzxmM/901UXFiWHE57eK30h0yuu4OY
P2ky/0ti/pSFiMp7jFCteCtt5PozR2h53LAoX9aX85clyF+bjwiH/eR1so/6
AO7UP/g1P6vrPRfkPOMEX78wwyGX9Z8QrqxY0FQUdZG6e+OFr59Qqt7HXdYb
JJ6DKRcqxuA/fMZFDv5R9y/lsv8Zneeciz2TUnGeEFIBFArOo0fzRQT7t/T9
veB/fuJ8PgvmayGodvTKefx/Pv8COAIxWg==
                    "], CompressedData["
1:eJxTTMoPSmViYGCQAWIQ/emSb5LAmzIHBhB4UeQg1Hzg1MLnZQ7l++ZL6T8v
cpgswRLG97DM4b5/7/S8B0UO1SLr3B9eKXN4W2NvGnehyGF6HlDHtjIHPt1N
c9/nFjlcrXipZrimzMHgrgpbo2yRg/vDKpF126HqHxQ6LHLd9vkvSzlEn0+B
wzFv807HkHIHl+6c57935kLUu5c7CIPcsTPLYYdc6+vAnHIHILlDDsgH65tW
7gDSlpCYDXHPinKI+zlyHGaA5DeVO/iA5N/mOBwHKVwE1V+Z65AxEeiS+VD1
DHkQ8+eUO4BsfdiW55D7/PfKj0HlDoe+asT0pxU6gMPHpdxBYUNRxsSZhQ6P
l84+omBUDhH/VQhxR3c5xB/LCh08QO5vLIf4916hA1D26YUkqP2qRQ5WW06U
7RMth5jTUwRR/7cMYv7JIgeQ9PwvZRDzbxU56IPC8XMZxN0vixzQ4wsA2srK
og==
                    "], CompressedData["
1:eJxNU39ojWEUvi1JaAl/rDvmGtlKmisSWp5pmoWWH1k0WrfpfVsMZzKNbiFl
dNu0NCVuiHIzrm22tc3aLzYLXdev7q7PbEtICKFLyvt+79Hnq6+v533Pec5z
nnO+2b49G3cmuVyuxerV3+qe75lFhRIfD69csuM1IfQlut6XK1FXNvVY1ytC
7qldb397JSqn38gbeU6o0fHzJVz6GSTkFL+JpGdIZFlzxx/pJtweONAZXCSR
PfHF5b2NBJt/jkRFZ9CddZMQTY8n/G6Js5o/RDj+YUNrWkJgeZNKrOf7X8LE
33Wwvg4+IBQmL2g4/1lguCBQV/aUcGl187c/7zg+RtBls0cF1i6tyimOE35k
FlX3WMLofcn4sYNXaf29AnkjqsM46+1lPTHut13AEyZ5+glhmT5vEdhWsmK4
4CHnN3L9fgfb/F1kdNwSUN0OXmxhf0ICVdq4JjK+X+B75dc+bVyNg2fqQrUC
h7T/DYShhL+044Qwec2EDO+E6zOOcr02wid9XimM/+0Onqb5uh1sxw8Qtrfl
T06qEHh28P08b5T1lzO/mvc6rX+3QL9uZIgwduVcn6dE4J7Gyj977luZ3yLD
6xFYqM8t1p/K8+rgfZnF9cNk+nJzfj33lyJQmzJuS3I5xwv2y0cI6MWMCKzR
88onxB793DR2RqI1TW3SZjJ1A7xv1xx8VckOq3qT9H6clLDX6P4/P6XhjxDu
7FeV/dLM12J/SyW+qt9iyijr+e9/+QtnxnWn
                    "], CompressedData["
1:eJx9lG1IVEEUhi8S/giL2CIiQsxMtmDbXe2DCvGEFoZIn0SISEiBcO+M3jEs
yiJZQiNiMxGtCOmL6E9IlEmQiUVGP8RWIpbaNCQkosSiIiTozJlZZjLowmV4
7jl75j3vmdnlNXW7D2U4jlOCr1wnbl5+mvOWQU6PqG0bE7Dx3vPG/gcM5NL9
TsC++aG7VzoZFM19fb0+KYDymxh8aSpeV50Q8Fmu6xmwyZnb0z0CHh1uXzIn
n0H5hjNbDhwXcG1r77ffVQwc+VQKeJn75tfJCzpeIWBZ5cHNY0MMxnec6+QF
uv4NrWeFgMfdS8OpLAaY/WEk4cPKzOaOkpgLq1sWJ4fLfTg/+D1YVefCkX5M
LNRx5OqH27MykO/LPrgLTzAtXmCY9COTHuRXRz/mR634JmlA1DDpsTicysts
jprf17ahE1ac9CB38UBsAJl8iPgg28hFfVJ2PGL0k4/IDbIQcl/26U+7kMm3
ehe+JipqFiCTP8j0HXlIGok8D8c0FfaVX1ac9rUYq/Zl+yZ/YWzgxVXkgFyR
f6CsQV/3i1x61pucsZh0CpNP/QoTn800jwbtB3Jc9jubW1wYkT4G9f4nPHX+
glp/lwet0rg1Wv9Fw6Qfmb6n9SOn6yeHf+6ZsDgh97lkmPT+h9P5f/VnMfU3
pfOLtd5TXJ3XPPEP0/w8DmXvjy26E9Lx/RyeyTmu1fFSruoVCaU/xFW/23Q8
wtX52Gny0/eL7ustDp68j4063sqVn72a93Klf1Qo31ZxdX5TAvAWBmIOV/MY
1/nW/8MfLAnpTQ==
                    "], CompressedData["
1:eJxTTMoPSmViYGDQAGIQfUHp9s86lTKHDseEpxfuFTmU75svpS9f5nDM27zT
EcifkSfUfECizOHx0tlHFK4VOVSJrHN/yFcGUXewyKH1deAOue+lDjvlgKxZ
RQ6xuzx5mJ6XOhz6qhHTH1bkUA1S/6IUol68yGEHSJ0MVP/mAodPl3yTBHTK
HFTZGqc6f89z8HgItMG3zAHkHCX9HIf7/r3T8wLKHLivLy6wfZXtAHJWgneZ
AxeI35btAHa/SZnD2xp707i4bAetdrGb5+6XOgg3Hzi1cG2Wg9WWE2X7Uksd
ijImvq25nAlxz4MSiPn5mQ6HQe68VOIQB3K3fybEPpZSiPnHMiDqXUoh5gP5
y4DBsGFDqcMEkAfvZzjYghTylzms+gj0SESmQ1SK9X3/dKj7p2dBwrWuzEH/
rgpb48MsiH9XlDkUgjQ2ZEPUryxzYACBP9kQdRuh+s/nOUyWYAnjm14Gsbeh
AOKeBKj6tkIHO5D9sWUQd8wvdLAE+Te+zEFxA9DHewsh9qVAw/toIcS87DIH
A5A9Zwsh8dtU5rDIddvnv0cKIe7pL3NQAOm/WQiJj4XQ8H0DNS8Oyu8ocnAH
yZtD+UeKIO4ygLrnchHEPG0o/36RA3p6AwBMEhxV
                    
                    "], CompressedData["
1:eJxlVQtsFFUUXZCUAoIoTQOKda0KbdS0BcFPU7gtEILSIFaCkM3abmfezEDp
vvf8QNKKIKAhKIWA36INlhrExhDSVjBa15ZYYwguJYRUfiFVS+XTIn6iSOK8
OTctSTfZ7N6Z++6ce865d+6NxZ+xh4dCodX+1/x2N9QeDvfbdPdyK//ccU2X
q2fPiHbadGJN75S8To5bbPq9szg2/jtNrXV35pzZy/nNmkLms8emzYWlvySr
NT2Qsv7tOfU2Pd70/cutczQF9ffbtOni4oMZt3H8M+cfUPTWu5V3bPjDpgkb
Ej/sLlP0V1akpm2sQP4tik79s3bFV2mCkpn+v42SXnC3X66usulghp9xRNIx
c/01rj9GUdfRv0u6G2wyj6+LKPrsqg98l02req5/evW0om8M/mqbcs/cn7L+
hgJ+y8ZvhiYDK3M+9ztFU6epP9qmT0wbYU1XDB8/WeAnU9PUvNTGyVGLzi3y
OzmraFvbn1mRfAv4KofGAZ8ZFpm2E49wv7dblGPwDON+QxaF92t3e4cErqZy
MmVqPuJ+15Yjf5Sijqce3Vz4dDmtNsIsVdBlejkFtKdr8PZrDNd7Fe0zfCRj
wPGsoq9f3DFxREuMzO1FxRL6+M87ZPBOk6QN3z2M7z4JnQos8DOT+Wy0aLIp
4Ciau6Wi5/q3Fp67TsEvFyzw78dB/UsW8JQNxgG/aySZdkp7LapK+3z++Yck
dC22gTddQo8PbPSXIqnI6HXRpgffSO86OkrCT2GBeqncDwmKfrng1uHtcTpt
+F0ooFtLJfyyTJAsGH2yfu8q4BaCnjAGqq0YEgf9hh3ys2WBqIB+2Q5wl1VS
s/HdNAe4tsSB+4qgdqNfkUS9dAd8Ps/6TnRo3MMHPuyrkqhfyvVekVRjhN/B
+XFJS0xitwO9SyTmbaQLf+Vyvxs5niXRZ5EHfz7H/DR58NPrXP8LD/V/lPBT
o4f5TGN/7fLg9+WsVynn1/H8uh6uNyrwlO9BvyOcP5fzuxTz5sH/rTyv73v0
8byWazcSPA8Ng/kLDQ+bOH+cho4lHvQu1Mgf5sF/SzXmo9XFfL/E+ybikrHx
7DjHj7mon6fR/1QXc/0b41/pQpd3FO4fd+HDxYr96YKPmdxfqofr/jwG/vyX
888zv+0u7h+T8N+bLo01ep/keY6yXv1D4+B8hwM+s9RAHPQ3Q2Ef9rF/mnmf
JR3Mx2Hm85CDehcUjTH872M/TdK8Tx3gzWY+lziYnyc15jTHAf9RTcrMyX9i
IMY+FwP5Ac+7Bb1n7o/n/ISA/3byvugXwBfhfTWB8WQrnF/gDOy3oH7uYBzs
07sc+PcS+92vF+yvazw/Sa6fxvtuD8/vMj5fy3gTg3HQfx/vw60C748s9tur
As+vZ79M5/Nt/L64h/tL8vtvpEAfJ5ifm96v/wMD2V+O
                    
                    "], CompressedData["
1:eJxlVg1MlWUUvrNmLRXLLK9JKMyAVg6wksKxDimZYSbaLubMGNzLvd/7/d5P
+zGbm5FL1wTEkjYypiYk/ZnDFvmTkANMggvOOQtGzLVshc4xs9bPet/3OYOt
2Nh3z/ee95zzPOd5z/emlrkrIxMCgUCd/FfP6vZrmWszBG39pfiLlLM+XTxQ
f2pOUODZ79M9E7e8vegmQfe9ceeFnm990v6jBmUNzp245YxPi9+0fvrzMwP7
23z6quGurMENBm2a/smS4fc53jaD7l4TXjhk+7Qsd3tB6TmDYjtHXn20Mk6P
tHS9eELGP/fyz+k5CQ/7nxG07sulkyeccen7PzaLY6WCAurvLZfecaZVnpwv
KJQ07/CeIhf1XDfgv8olGfWhdbUG3te5yLOR67mV43fHSG2/MsVDfSti9NIJ
uSDtCz3XV11si1Jfmsxc62L9UJTyVJ1TXapRceujlKzwNDnAtSsKnnKdMf94
/i3n9w/YjC9Gj5X+mEhbbyO/F0Odm+2xeqS3l7/bJk/tCxrg6YhNzylcJQbw
Bxz6LXNtdXvcgP9le8zOyLn5o2Rp67r98fX/2kdkOQ3+//2zVT9Hxm2dX9qa
10qDdtRJ4hM27Sv8fPRvz6APr/Y/VTZgIf+UGHiYbYH3B6J4f9wk2a1v9m6t
AN5GE/xkVgDnaovriABfl4W491dQZ5EswGO8eyKoP8mB3+/lVKD47DXQL9lf
8M/PGYLU9tJhGzpNFeD/Bgd9IQHe5zqUUHhDAu+TuX9Sbxpv0AHemKD1SkiT
eN1ifY7a0EORQJ2tBvLeWwG9uAbevxABP1/zOVvKeKeb8FsYQR0dJvjLjSBO
jgWcWRHw5FvQcUqE9W2hnsnMT6MFvQ+HwXeHhXPSxLbcD/2GgfcHE/xsD1O6
4s000f+qMPgqGrcnqfjfCeixM0wdqsDXo8wT8zsaA95rAv1tMdGPchN1pdrk
qx+jgppVnx9kPoMm6g85eC9t9MUBDzNNUmlOhlgP0sa5cDB/ZnIeaeu+zDKB
W9oal7T1OZS25lvamv/VDlWpwMkmcEhb60La0KcD3lNMUuNhUNpal3NM1PUs
15M6bmu/Dzhfpw0cFRa9ovr2OOOtseC/0YF+91o4l7UO+O7hPu/j+CMW+HnN
gR5KbPRzAc+fqVznGtbzAsY55NCAmp/LOG6ZSyWKl+dZ15d4voUdak2Ryszz
oI/ZDs5tlgeeLtmwMzzU02cj7ywP57Wb50LQA49dNvLf4aEvkgcdf5oH3G02
Hd+wK3jjPy76dNSG33kX8eXc0/o85CJui4159LGLeqR9WeFvdoHrMM/ZJsb3
Kc+t/fy9aOa59x7HP8D11buIu4PnXpULHZfb4HO3Cz2U2qi71UX/ySapuoNX
05mPVotUuIZs/p7ELOTf5OK8y3Os4y/neN0m9hVy/e2st20ueO3lc3mbR7cr
3neaY3zr/XJu6PhXXPT3V0FDT0vmazzwdUogbloc/u8KxDvKdkLg/B6Lg+cA
6/dgHPVnmyS7E0rq5PW/BOwZPuqo5vtAq488K3n9NN8HigW+p9LWcYt5Hp/m
+8EKrkfamuflPBflfULr/klB+jPazfeHJwTyyvuHPvdLBPTf42OuFHL+XvZf
zPGlrXlaJPC97mX/At6fYH/5PWhU+aSt+c7nevt86lf48jh/H/s/LKCDfsY/
n/PL+5PGMU+Qos07y/enjPH1fwEq9CVv
                    "], CompressedData["
1:eJxTTMoPSmViYGAQBmIQXb5vvpS+d6mDbFSK9f2LRQ7HvM07HQ1KHZbNPqKw
4VKRw7sae9M4oVIHj4dVIusOFjkwgIBcqYMMSP38IoeMiW9r7MVLHQzuqrA1
9kLlI0odcp7/XvnRr8jhgX/v9LykUoelIPN0ihzA9pWWOjwGCfwodPh0yTdJ
IKTUgU9309z3RwsdhJoPnFqYDlW/r9BBGMSvLHU49FUjpn9bocPWE2X75k8q
dVjkuu3z3y+FEPvmQNXrFTkAXen+cFmpA8gbCbFFDoobijImtpY65ILcs6fI
4T7IPWFQ/10ocgCqenohqNRBAaQO6P/JEixhfP6lDtrtYjfPXYS6Fyl8AH3A
iKY=
                    "], {{238.277, 297.52}, {239.04299999999998`, 
                    297.59799999999996`}, {239.97299999999998`, 
                    296.89099999999996`}, {240.42600000000002`, 295.895}, {
                    240.91, 294.828}, {240.668, 293.812}, {239.875, 
                    293.617}, {239.086, 293.42599999999993`}, {238.062, 
                    294.129}, {237.578, 295.195}, {237.094, 296.258}, {
                    237.336, 297.301}, {238.125, 297.49199999999996`}, {
                    238.176, 297.508}, {238.227, 297.51599999999996`}, {
                    238.277, 297.52}}, CompressedData["
1:eJxTTMoPSmViYGAQBmIQfd+/d3rekSoH/bsqbI2eRQ5a7WI3z62ucnhXY28a
51XksMh12+e/E6oc3B9WiawzL3IQaj5wauHsKofW14E75ISLHOy4ri8umArl
/y90eLx09hGFC1UO3uadjgm7Cx2EQepvVjnskAOqmFbocLXipZrhoyoHPt1N
c99XFzpsOVG2b/6ZKoec579XflQrdAC75x7UPPlChw7HhKcX3kH1ixU6yEal
WN9nrXbQBrkzEqqerxoiP6PQoXzffCl94WqHi0q3f9btKoSo+1nlcPirRky/
URHEvHNVDrwg+92LHBQ2FGVMPF3l0AkS9yiCiB+Huh8YHujhAwAjvJH8
                    
                    "], {{323.22999999999996`, 289.99199999999996`}, {323.371,
                     289.367}, {323.512, 288.734}, {323.605, 288.094}, {
                    323.91799999999995`, 286.707}, {324.191, 285.332}, {
                    324.47999999999996`, 283.969}, {323.26599999999996`, 
                    285.641}, {322.262, 286.98799999999994`}, {321.828, 
                    287.469}, {319.082, 290.72999999999996`}, {
                    321.89099999999996`, 289.613}, {323.22999999999996`, 
                    289.99199999999996`}}, CompressedData["
1:eJxTTMoPSmViYGAwAWIQXSWyzv3htlIH/bsqbI2JhQ7e5p2OCWtLHWSiUqzv
xxc6XK14qWa4pNRBqPnAqYXhhQ7VIPULSh2WzT6isMGr0GF6HlBmXqnDcZBG
p0KH3Oe/V34Eqj/0VSOm36TQIWPi2xr7uaUOO+RaXwcaQPXPKHWQBZmvXehg
ueVE2b72Uof7/r3T8/QKIXQHVN4VwQe7y7fQIW6XJw9Tc6mD4oaijImhhQ7u
D4E+qC912AkyP6oQYk9NqcMFpds/62IKHT5d8k0SqCp1AIrukIuF8ksQfLD7
c0odgKY/vRADdR+QD6ajoPyMUoelIP+GFDqU75svpZ8Oda8fVD6l1OEYyIEe
CD7YfMdCBz7dTXPfJ5c6zADZY1HosMh12+e/CaUQcVOo+iio+cDwYgCBEAQf
HH6hUPXGUP/6Q+PLvNABKGsa5wO1zxoaXh7Q8LdB8MHx5YTgT5ZgCePzLHTo
APnbrdQBFNz+wVD3uEDND4e63xEa/tGFEHW2pZB4hoWvBTR+46Dy0qWQdAPk
C4PSjSQ0vmyh/pGGutewEEID5cHxAIx/cDoTL3XQahe7ee5zgQM4fdpB3fO4
AEIXlzq8A/n7VIEDKPnMv1bqYMd1fXHB1QKHByD/XYKmB61COF8bZJ4hNLwu
lELSkTc0PM9DwzewEKLvFDR+46DqD0Ddm1zogJ5fAElDb5M=
                    
                    "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQffPc9+DHc3MdZKJSrO/7Fzrsny+lf3dCrsOhrxox
/QGFDrIg8fpch6sVL9UM/Qodjnubdzrm5DrskGt9HehR6OCY8PSCEn+uA5C3
Q06/0MEJxH+d43Dfv3d63pMCh0Wu2z7/Vcl1WDb7iMKGHQUOamyNU52joeZN
KoDYtwFq3oICiPl7EPyijIlva8TzHLaeKNs3f1aBA9i9vnkQd30lzC+05bq+
OCDPQWED0CT+QodjIPOfQN17v8BhC8jcbbkOnSCP3CpwALpaqBnonskSLGF8
j6HuXwINn/cFDsUg98zOdRBqPnBqIXuhgzCIBoafJcgg+UKIezfnOujfVWFr
NC90MADRe3MdrEDyrgj5DpB9wPBED38AsCXAaA==
                    
                    "], CompressedData["
1:eJxTTMoPSmViYGBQBWIQ/Xjp7CMKkyocdsi1vg50KXQ45m3e6VhR4aC4oShj
omuhw/Q8oeYDMRUOnY4JTy+YFDpYbTlRti+0wkH/rgpbo2Chg3a72M1zQD7I
mA1/ChyApuyQi69wKN83X0r/Y4FDVIr1ff9YqPn3Chy2ArXPj4Lqv1wAof0r
HN7W2JvGnSlwyH3+e+VHkwqIOTcLHCZLsITxWVZAxO8UOFiC7FeGyv/G5Mfu
8uRh4q+AiLMXQuz/XO7wwL93et4vqHselkPc+67AwZbr+uKC61A+0PxPl3yT
BC6UQ/y1F6r+djnE/fOg7vlZ7gAKpoR0KB/oXwVQeHFC3dNf4bAMZB5HgQOI
O39ChcNxkAarAgc7kH1TKxzA4V5TAKFnQN2/tMAhYyIwJGZWOBz6qhHTv6XA
oVpknfvDORUOws0HTi08CjV/NTT8ThY4HAap21UBcc/ZAkj8XamAhPOuAocL
Srd/1l2BuudUAcRfF6HueQUN/9MVDjNA8SwBjd+d0PjUK4S4f0OFw9WKl2qG
NoUQdyyE+te50AE9/QAAyMoYyQ==
                    "], CompressedData["
1:eJx9mHuMVcUdx1ckykNZhK1aRWVXKgTqk5eCawfEAraGWKM0Pimi3fs458w9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                    "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQHbfLk4fJuMih9XXgDrngAgf9uypsjZpFDrZc1xcX
BBY47JADyigUOQg3Hzi10LPAYZHrts9/ZYocls4+orDBpsChWmSd+0OpIodj
3uadjiYFDpMlWML4FIscrla8VDNUK3AACSdIFjnIRqVY31eE6hcpcrADmS9b
ABFnLnL4dMk3SUChwGHLibJ981mKIO4wR/BjQe60L4C483+hQ/m++VL67gUO
Wu1iN8/9LoSY413gcN+/d3rej0KIeX5Q/d8KIe6F8T8g+BkT39bYvyx0AJKm
cX5Q970ohJjjA+U/KYSEg1uBA8ga/8eFDgwg4ACVf1DooA1yhyWCvwxkvlEB
xB1A/juQ+VpQ998thPhPvQDir+tQ84Hh9RjksAsIvhXIwRcLHRQ3FGVMVC2A
hOuZQog5mtDwPwH1jw7Uf0cKIeboIfhg80wQfLD7rKD+OVwIMccFGl8HoeYD
4/uC0u2fdfsKHXKf/1750QeaPnYWOhz6qhHT7wd1z5ZCBxmwQQWQdDO9EBIv
/lD3T4Wapw81fzrUfiVo+E+Fhj8w/i1B6icXOszIEwKmuHwHcPrcXejADTTW
dlW+A0h04Xto+FfkQ8zNhaaXqflQd0HTm3QBnA92lzKU71MECQcbaPrxhup3
hqYftyKI+QFQ/9sUOUwHuSekwAE9vwAAcUN0QQ==
                    "], {{401.562, 
                    256.668}, {401.47999999999996`, 256.684}, {401.387, 
                    256.68}, {401.289, 256.64500000000004`}, {401.289, 
                    256.64500000000004`}, {386.039, 245.797}, {
                    385.66400000000004`, 245.418}, {384.15200000000004`, 
                    244.07399999999998`}, {384.90599999999995`, 239.348}, {
                    385.66400000000004`, 239.895}, {386.758, 
                    239.47299999999998`}, {402.105, 249.875}, {401.812, 
                    251.094}, {402.484, 251.055}, {402.805, 256.445}, {
                    401.562, 256.668}}, CompressedData["
1:eJxNkl9IVGEQxReJ0r2uyNZDhoqaUC9hPoRkiJPUQ2QspXlTQmQxkCgn9hP7
t22a9BAhi/RgIiEaBUmQRIWGilioRSy79tdELFR8CBOTCpGgmd0D64XLx497
vrlzzky2l0+cSXA4HPny6pk3k7u5Oc3QodvnFte/M0V5pyGHPvNMo793nw7u
NVTXtuQvnmG6+eN4f2aRobv17paREFNV7YFZj8fQ1paRt90DTK9UX2VoKvS3
bK4D+krobzDd2b6pIkV4V37i43Thi8NdO/KEew6/WP3XFNf3rkwe8zbF9YXP
JhqHrzPNelrb608ZiuRMrwUCTP2ZckN4qEGUwmNHC24dFC6Vo+Ya0y8pkyo8
96DzdZafybXn6b1l25BRQ1eZ0tWAcEnNQjhH2K0+hH/6i/dVX0EeNvK5zFTk
/Hz/gg2/wtFchL+uBc4OXkL/NvoXDmufFYaWtF4jU3afr67tJL43MLVrLuXI
x8ex3Euh9zLtV98Fhqa1fi30udBLfw/FVp/bkJ0ixoLodwvyesIxXaKJ3RuL
c1AHO458kwy1qmAC/QtHzzfwm4R9eIf+nIaeS/muEOo5oY8wVb88kpxgIa8I
5ivs06Deoz8L/j8wZWkeFv4vnKHzsLAPwmpr2UL9j5h/MvL5hPxdmO8X6F3Q
TzHJFiyEUw39kbUclf09v7j+aGUb6n9DPxv2/z+FclwC
                    "], {{
                    172.066, 252.312}, {164.168, 252.168}, {152.598, 
                    241.953}, {152.29299999999998`, 236.285}, {160.629, 
                    240.289}, {168.816, 244.14499999999998`}, {
                    177.29299999999998`, 248.285}, {175.92600000000002`, 
                    250.32800000000003`}, {177.21099999999998`, 252.168}, {
                    172.066, 252.312}}, CompressedData["
1:eJxTTMoPSmViYGBQAmIQ7WPe6ZiwNcNh1cdLvkkS+Q7qhhxrZM5lODxeOvuI
ApB/3Buo4EWGg2xUivV9bqj8twyH1teBO+Re5jlsPVG2bz5TpgNIWcLJPIfp
eULNB4DyDCCwIs/BcgtQwfMMh6KMiW9rpuc5hPHpbpoL5Pcf+qoRA+TLgMwF
8qtE1rk/nIZQDzYHyAfrA/Lf1tibxgH5qmyNU52BfP27KkBWnkPsLk8epudQ
9wD5q0H+uAO1rz3PwTHh6QWl7VD53jyHPpDBc9D4NRkQf/TlORTacl1fnAP1
7+Q8iL8iMxz2lkyWYFmXBwmXgAyHOJC9p/Mg4ZMDte95nkMvyLwKqPl/8xwK
QOYB+eBwBvJByuwrMxy+acT0H/oLNb8Sav6/PIcZIH9XQcOPId9h/3wp/bs1
UP8z5UPsrYfGF0s+xL4OqH28+RB6JtQ+Uaj61VD3iedDzFkHNR8Yv2B3bETE
P3p6AAAFaeu5
                    "], CompressedData["
1:eJxTTMoPSmViYGAQBmIQrX9Xha3xZYWD5ZYTZfs25zlMlmAJ47tc4cB1fXGB
7bo8B4+HVSLr9kLlm/McwOqPVzhYgfj2eQ7e5p2OCQcrHGSiUqzvi+c5MIDA
swqH4yCJnlyI+vcVDuqGHGtknHIdPl3yTRL4UeHgA9LHm+twQen2z7onUPUV
OQ475FpfB36rcOidnifUnJHjAKIOsFU6xO7y5GEKz3GQBdljWOkAVLVD7iBU
vUElxHy3XIj7TSsdLoHM7cp1eLx09hEFlUoHkHPnt+VB9P2sgLh7Y57D1YqX
aoZfKiDqtuQ5gKgN7yocFrlu+/x3C9S/SOEDAHzMhuo=
                    
                    "], CompressedData["
1:eJxTTMoPSmViYGAQBmIQzXV9cYFtXY6Dj3mnY8LeXIctJ8r2zQ/LcdgKonfl
OjglPL2gZAyVXwrlO0P5ubkOt3/WZe1xyIHQLrkO/Ye+asRszoHQwrkO3CDz
d0HVb81xmJEn1HzgFNT8vhyHbxox/YcW5jhcVAKaIJTjIBuVYn3/cI5D7C5P
Hib2HAdVtsapzo9zHFy6c57//pkN0c+X63AHZF9MjoMjyD3yuQ6904ESO3Ic
jnsDLdLIdagWWef+8FWOgyXIQ9+h9s7KddC/q8LWuDTHQd2QY40M0H/75kvp
352R47AfRO/JdSjOmPi2pjvHARwu+3Id0MMHADisi5I=
                    
                    "], CompressedData["
1:eJxdk11IVFEQxy8iIn1IlA8RGq709RJmJJFhjVFYZIgGFhGySIGeezDnVhYq
QlRQhKj0YD2EmC/Rh4RERIQbPlSEhAUhYpssabqu7rZKbEsEzZwzsuKFy+F3
55w5//n/ub7aC1Xn0xzH2U0vr/OtB4tqGhG2F2Y+zfmuIffMuf0TiGC+E18Z
7NlUcDFV725Yf/3tpRQ/PPJy8d8y5uMVl1Pse+7VdS3jkfzxZNsjhM+8DmnI
4/oiwqmsnQMPAtJ/j2f3D4ieeg86h37vOPtEw8KXE7Xrbnjw/vje26WnNURZ
Z5UH5YT+Irnf58G+Fx+aBjdo+Ho1vK1wAaEguCXjWtIFviYWRyjmuuvCREV7
d8MfqW914e7G9OqsBAKWrBrtc1yrb2l/TMHNSOWrzXHRH1X2/C+Eb8k29WZO
wVruH5P9EQU5LIi4mi8mpuk+9hIf8k+N5BOb/sQ1r4+tSSM2OojvsQ+zCuq6
KAni1aN9jSXEJo+Y+Els9BIfvqOn/4YV3CqlxlGZh9j4Scx2+YlNrsTtXJhR
8I4LxI/jZCzx0VBzdv88Wt3TyuZHbPwkbsnuLwvNITTz+lNZPyMIY58SJ39M
iT5ikwex8WkWIUCfg5MyXxhhnP0iNnPOiJ5J8TeIdg0pm98wQgfnnxC/ArI/
3bV59yI4/OySPMvl/H3Xzgvib4sGHqPngOh9pu28lcJjGlb+D/8B1W5zlw==

                    "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQXWDLdX2xR7JD7/Q8oWaDHAcgr8DWKdlh1cdLvklA
vv5dFbZG02QHH/NOxwTZHAewepVkB8stJ8r2sUPV9yU5PF46+4iCRLbD/vlS
+ncbkhwuKt3+Wbcp00E2KsX6/uUkiHr3TAcGMICaJ5rpALPfMeHpBaX/GRDz
6pId4nZ58jDxZzrc+VmXtedOsoMMyBzzTIg8W4qDKlvjVOfvUPPfQ82zzYK4
+0Kyw1agdfPzshz6D33ViNme7HAB5J6yLIg505Md+kD+9cmC6AtNhvjzaKaD
cPOBUwstkx1unvse/FgxC2K+MdT83CyIvGayw2qQPX+yHIoyJr6tMU+G+L8h
2yEW5G53aHi+yHaYALLfP9lhb8lkCRa5HIi/gPzbIH8Z5Dighz8Az4+pxg==

                    "], CompressedData["
1:eJxTTMoPSmViYGDQAGIQ/bbG3jRuWbHDzXPfgx9/zXLodEx4emFBscMFpds/
675B+bOKHYC8rD1fshym5wk1H5hS7DADRL/LclDYUJQxcTKCn/P898qPccUO
QNG3NcuzHBhAwA9qfmmWA1DVqYXOxQ7qhhxrZNKg5rsUO/SCDI6Aqvcodmh9
HbhDzjbL4dMl3ySBgGKIuESWwzFv805HoPmhfLqb5ipnOYDdnwdVb5rlYLnl
RNm+5mKHuF2ePEzWWQ6Pl84+otBX7FAtss79oRxUfU+xQzHIfa8zHS6C/NlU
7DDh0FeNmNWZEH9MgLp/MoIPVt+Pxu/OdAA5J2FpMcSejEwHRVB47C2GuLMl
0wHknPkfih3U2BqnOgPNv+8P9KlAiQNIu/3FTIi/IkocVn0EevQD1PysEodF
rts+/wXyPR5WiazLLHHQv6vC1hgKDR+fEoh/I7Mg5qhCzQPKg9UxQvmBWRDz
bhVDzBfJcsgFxc+hYog8Z5ZDFShc9hU7cF1fXGCrBo3PnVD1DlDzNhc77J8v
pX+3IcuhfB+QcbwYEo7roPzD0Pi/B42fI8UOhbZAE+9kQdy5HRo+X6Dhj5Te
ANdEJCY=
                    "], CompressedData["
1:eJxTTMoPSmViYGDQAGIQ3eGY8PQCX5VDccbEtzXVWQ5RKdb3/VmrHKpF1rk/
rILyf1c6HPc273SsyHLoBKl/U+lw89z34MelWQ6trwN3yN2tdFBla5zqnJ/l
ANQksu56pYP+XRW2xkSo+iuVEPOtsxz4dDfNfX8Vqp8xy0FhQ1HGxOeVDrd/
1mXtYclyEG4+cGrhT6j820yHT5d8kwRYqhz6D33ViLmcCXEXV5WDGsi+3ZkQ
839Aze/PhNgPNO/x0tlHFAoyIe64XQnRF5fp8MC/d3reKah6+0yHdzX2pnGH
Kh0YQEAlE+LfvZVQd2RAxK9VOqz+CHTImwwHIZA4c5XD1hNl++ZfynAo3zdf
Sj+3ykEWpDE6E86fkQdUCbRvhxwwhOqqHFaB9FdkOmwB6auogoTbSqj6cgQf
7CyYefszHaaDzAmrcuC6vrjAdlMmxH73Kkj4bM10uA/yjwOCD7ZXo8phP9DY
u3syIe43qYKY8yzTARSNCbZVkPBmyIKEC1A/OH4FsiDucYe61yAL4n6/Kodw
UMT5Z0HiwwOqPyULYr9eFTw9gM1XhIZPFVS/RBUkPmqyHNDTGwAQLip9
                    
                    "], CompressedData["
1:eJxllAtIVFEQhkVKJKKiN2WWUiZZWVGEWTmZ4tpLjLLLtvfutlu4mZn5OnvN
AguREIklQilEyh5GtmpaqZhE9CIiTAqJjIoyizJ7h0jUnDNndy+2oOvnec38
88+E2fdt3hUYEBCwA3/4d/SL2UHFOxhM538kW2HVqO6abOQtb86dum2yAuuo
nhaNHNN8v6AjyQolH1NbQpHrQsw7Y5Gd7v6iuEkMrn3/88Q1qMH4IzcfnJ7C
YN3owKjSDhVaQvGEicEm+zglZqlK5+fm+Tje1tsZ3pQFj8OfDx7KUGEGXvuy
JtPHPfi7vWiPj4/d+hlp6U6neBtV2LD86BrbHT9P4O+XOyGXB5a+HbaNWXCl
qn433FuPG7+YQWtLxsj20PtvzVCZhRF/2+tjsS8jH35FWvApMwh94piPuSyz
QqU+wWaKK54BT6ukTAG+3GCR+xMV0keV+ScodF5jkFCW2Te0Ru7XpP7ISa8L
J3qsDN514sWrFdjbN3Txq43BmURUeKVC+qD+Kfw+5KeuDxGL7QyaqgYu3I1V
ANXo7bT7149PHZE2xjFs/2EGM0UhFJhXOvnZo2MyH5cCrbxeJxl08bzaZHwP
5XqtQvV874K7XKdKuT9Qp/vbFfhcFLdMM/BVtE018iKu4w0FzvP7kIU+yOKe
iTrwsiWmKWDi+c/RgVe7/cc2ij9J7h+pwKyGHKe7WIe//LNcIb/V68CPJaXK
fBt10nu++T8WaV/SqS5bpT8jdKpjuAr8mtdBOvlnrEr5e1zAZQv+ZPmPeVtU
m1zk0xAVoriefxgcRBnawlR6v4zR/UtUyu8Eo7ydKvRzvWq9ftDIb27pB7dk
PC/0OKuRnli/Ffzheo3iL2AUT51G9TVwAP8YWPgn388innzpT2Shi2FdxG9g
4cM8//4K3j/Ior6XNdInT/ofWeSHLOrr0chvuXI+eGR+uXKeYD4HuP45Mv9G
Db51bbSPQ+b/LmyW+/fL/dc14DLakIUfkIX/s6X+rRr5LdvrZ3l/huyHHo3m
Wrrst4VW0gf7hYf5e62V4nV4+9dK/kMWcSRa6dvh7Xc5Pw0s/Obwz0tvP3pZ
9LfdP19fpZRXZNn981f0l90/n8V8MjAfbwOG+e2dD14WfjTMcxG/YX34/P8H
0Cyccg==
                    "], CompressedData["
1:eJxNkm9IU2EUxseIiEiRkogyqYi4m4T4QSIjfEaIRtSoD9F7iRGjICNKCLrH
NCFsmURE+MFBiJRUSCVREWIy15SVBaajFEvR/tiaOgb9ZUTQeXcPbBcul4d7
3nN+53mfjf7TB445HQ5HGb/6m7f1UUeq3cI+f8Gh7UMmvsf2+guCFgp7qj+e
Y/2OElvKWLesnhz5M2iitziwsD+YrbdCnWtL8wi115ONlQ9M+Pp2r3A2ECqe
vDwbGjCR6Z8irCud3ry028Ss92r7KWc9dl05Gf9bK+fThPOV5b6+SQXu3luc
JNwvMo/uGFCI/DIOX1skNIdf3awKKTBVYc8CYSrddKK/X+pZezUP6zs3hjY8
nCc87kjdjT5TyNfzE9n/GuNCjm5bs+Rgfo7mLcp937LnM/zx7P/1jDXznODQ
T1j63yNojMCg6IDwv5B61l9HN31Ijyis0ouwntN6XPhZ/+Y1I9MKn2/zAo0E
dmllc42JBn0RFYSnP/69JY9p85dIfVJBt/eyztzXorLr3YTlE111O+fFD7f4
n1C2/27hi8s81pn7/CL8LsIY4zV9UqjRfruEZ1bmucT/KeFnHdP172W+QThz
nAMxodDqOTI3yjrIx8Mx4TFk/hsFHZNOQ/x7rRDds63Vw5pTVNISVXbeDOGJ
KNyqYid+WnZ+uhUu6/5RCxqzeljut82y9x1TmNH7XrRQzzFeViR5vmTZ87ok
nzn5/w8WOWkh
                    "]}]}}, AspectRatio -> Automatic, 
                  ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 600.}, {0., 400.}}], ",", 
                 GraphicsBox[{
                   Thickness[0.002352941176470588], {
                    FaceForm[{
                    RGBColor[0.662745, 0., 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}}, {{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 
                    0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}}, {{1, 4, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{146.555, 24.364}, {
                    148.90200000000002`, 24.364}, {150.805, 
                    22.461999999999996`}, {150.805, 20.114000000000004`}, {
                    150.805, 15.868}, {150.805, 13.524}, {148.90200000000002`,
                     11.622}, {146.555, 11.622}, {142.309, 11.622}, {142.309, 
                    24.364}}, {{146.555, 7.372}, {151.24599999999998`, 
                    7.372}, {155.05100000000002`, 11.177}, {
                    155.05100000000002`, 15.868}, {155.05100000000002`, 
                    20.114000000000004`}, {155.05100000000002`, 24.805}, {
                    151.24599999999998`, 28.610000000000003`}, {146.555, 
                    28.610000000000003`}, {138.059, 28.610000000000003`}, {
                    138.059, 7.372}}, {{129.562, 28.610000000000003`}, {
                    133.812, 28.610000000000003`}, {133.812, 7.372}, {129.562,
                     7.372}}, {{121.066, 28.610000000000003`}, {125.316, 
                    28.610000000000003`}, {125.316, 7.372}, {121.066, 
                    7.372}, {112.57, 20.708}, {112.57, 7.372}, {108.324, 
                    7.372}, {108.324, 28.610000000000003`}, {112.57, 
                    28.610000000000003`}, {121.066, 15.277999999999999`}}, {{
                    57.348, 28.610000000000003`}, {70.09, 
                    28.610000000000003`}, {70.09, 24.364}, {61.594, 24.364}, {
                    61.594, 20.114000000000004`}, {70.09, 
                    20.114000000000004`}, {70.09, 15.868}, {61.594, 15.868}, {
                    61.594, 11.622}, {70.09, 11.622}, {70.09, 7.372}, {57.348,
                     7.372}}, {{40.355, 28.610000000000003`}, {
                    44.602000000000004`, 28.610000000000003`}, {
                    44.602000000000004`, 11.622}, {53.098000000000006`, 
                    11.622}, {53.098000000000006`, 7.372}, {40.355, 
                    7.372}}, {{84.96100000000001, 11.622}, {89.20700000000001,
                     11.622}, {92.727, 11.622}, {95.57799999999999, 14.473}, {
                    95.57799999999999, 17.993}, {95.57799999999999, 21.509}, {
                    92.67199999999998, 24.352}, {89.20700000000001, 24.364}, {
                    84.96100000000001, 24.364}, {84.96100000000001, 
                    20.114000000000004`}, {89.20700000000001, 
                    20.114000000000004`}, {90.37899999999999, 
                    20.114000000000004`}, {91.332, 19.165}, {91.332, 
                    17.993}, {91.332, 16.820999999999998`}, {
                    90.37899999999999, 15.868}, {89.20700000000001, 15.868}, {
                    84.96100000000001, 15.868}}, {{89.20700000000001, 
                    32.86}, {97.418, 32.86}, {104.074, 26.204}, {104.074, 
                    17.993}, {104.074, 9.782}, {97.418, 3.126}, {
                    89.20700000000001, 3.126}, {80.99600000000001, 3.126}, {
                    74.34, 9.782}, {74.34, 17.993}, {74.34, 26.204}, {
                    80.99600000000001, 32.86}, {89.20700000000001, 32.86}}, {{
                    89.20700000000001, 28.610000000000003`}, {95.07, 
                    28.610000000000003`}, {99.82799999999999, 23.856}, {
                    99.82799999999999, 17.993}, {99.82799999999999, 
                    12.129999999999999`}, {95.07, 7.372}, {89.20700000000001, 
                    7.372}, {83.34400000000001, 7.372}, {78.586, 
                    12.129999999999999`}, {78.586, 17.993}, {78.586, 
                    23.856}, {83.34400000000001, 28.610000000000003`}, {
                    89.20700000000001, 28.610000000000003`}}}]}, {
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     284.2}, {424.801, 284.2}, {424.801, 
                    1.0009999999999764`}, {0., 1.0009999999999764`}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    50.977, 284.2}, {127.43800000000002`, 284.2}, {
                    127.43800000000002`, 1.0009999999999764`}, {
                    50.977000000000004`, 1.0009999999999764`}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4js/67L2xGQ5HFHYUJQxM9/hotLtn3Xvsh3M
Ox0Tnr7Jc2AAAY5ch56c579XxubC+SGPl84+0pMN5y+Q0r+rIpfpANR1QYk/
2+HflYqXaqrpDr3T84SaF2TA+d80YvoPdabD+VtPlO2b35XmkJ4GBF1Q+aOp
EPOMMhyKMya+rbFPc7h57nvw47/pDgW2XNcXH4Gqv5fucBvk/oB0B3vTuF2e
N9IdZgCtO7Av00EaqJ1tb7oDWPvZbIc3gTvkWudnQtzzItthxTFv807eHIfj
QMrxR7aDQITllhNluQ4gbynEZDucB1q3dH+eA3r4AADYT4vw
                    "]], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{183.75, 249.708}, {179.758, 
                    252.60999999999999`}, {181.281, 257.302}, {177.289, 
                    254.399}, {173.297, 257.302}, {174.824, 
                    252.60999999999999`}, {170.83200000000002`, 249.708}, {
                    175.766, 249.708}, {177.289, 245.012}, {178.816, 
                    249.708}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{183.75, 231.583}, {179.758, 234.485}, {181.281, 
                    239.177}, {177.289, 236.278}, {173.297, 239.177}, {
                    174.824, 234.485}, {170.83200000000002`, 231.583}, {
                    175.766, 231.583}, {177.289, 226.89100000000002`}, {
                    178.816, 231.583}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{183.75, 213.45800000000003`}, {179.758, 
                    216.36}, {181.281, 221.05200000000002`}, {177.289, 
                    218.153}, {173.297, 221.05200000000002`}, {174.824, 
                    216.36}, {170.83200000000002`, 213.45800000000003`}, {
                    175.766, 213.45800000000003`}, {177.289, 208.766}, {
                    178.816, 213.45800000000003`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{165.844, 222.74699999999999`}, {
                    161.85200000000003`, 225.64499999999998`}, {163.379, 
                    230.341}, {159.383, 227.43800000000002`}, {
                    155.39100000000002`, 230.341}, {156.918, 
                    225.64499999999998`}, {152.92600000000002`, 
                    222.74699999999999`}, {157.859, 222.74699999999999`}, {
                    159.383, 218.05200000000002`}, {160.91, 
                    222.74699999999999`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{188.738, 240.41899999999998`}, {192.73, 
                    243.32100000000003`}, {191.20299999999997`, 248.012}, {
                    195.195, 245.11399999999998`}, {199.18800000000002`, 
                    248.012}, {197.664, 243.32100000000003`}, {201.656, 
                    240.41899999999998`}, {196.72299999999998`, 
                    240.41899999999998`}, {195.195, 235.727}, {193.672, 
                    240.41899999999998`}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIJIGYC4t7peULNH4IdpPXvqrDtzHXInPi2xn5voMPr
wB1yreF5Dhkg/tQAOB+krNHVz+H64gJbruMIfuVLNUOOhHyHha7bPv818Xaw
N43b5XkDwQeqvr64pgCuPuTx0tlHdiD4xiDAWgi3D6ibh8m2EO4eGB/m3qsV
QAt7Ch2cu3Oe/14ZAeeD1d+NgqsHm8caA+dbbjlRtq88Fm4fjA9zDwMYxMPd
C+PD/ANTD/MvjA8LD5h9sPCCuQfGh7kXFt4ATMyf3A==
                    "]]}, {
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIJIGYCYk8eJu32ZREObwJ3yLXuz3WotTeN23UzyuHm
ue/Bj2PzIHzGGDh/ep5Q84GsWAfBCMstJ04h+CDppcn5DvG7gCZ+jnPYPPf9
8mO3EXy3bZ//XqkqgKvPef575cdtCD7HGpmoFOZCuH3fNGL6D1kWwt0D48Pc
mwvS31Ho0C4GdNnnYDg/5PHS2UcOBMLVg/kzAuD8ZxeUbv+M84PbB+PD3PMU
xPfzhrsXxof5B6Ye5l8YHxYeMPtg4QVzD4wPcy8svAEeRcV0
                    "]]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIJIGYCYr8kgQhLkRCHBVL6d1V+5TpIAym2h4EOvdPz
hJpn5DnE7fLkYdodAOeD9DIE+DuosTVOdX6N4E9z7s553pzvAOIyOPg4xPYf
+qrxB8EvtOW6vjirAK4++PHS2UeWIfgBIAs+F8Dtm31EYUORTCHcPTA+zL3M
YXy6m7ILHZoPnFro2hYB52/7/PdKxc4ouPo1MlEp1vej4XygKwpsP8XA7YPx
Ye65pHT7Z11VHNy9MD7MPzD1MP/C+LDwgNkHCy+Ye2B8mHth4Q0AqVub2A==

                    "]]}, {
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    111.43400000000001`, 244.97}, {115.586, 247.47}, {115.586,
                     252.23499999999999`}, {121.71100000000001`, 255.993}, {
                    121.71100000000001`, 259.173}, {89.309, 259.173}, {89.309,
                     240.016}, {98.043, 240.016}, {106.84400000000001`, 
                    244.97}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    62.828, 271.079}, {62.828, 266.309}, {56.703, 262.552}, {
                    56.703, 259.376}, {89.10499999999999, 259.376}, {
                    89.10499999999999, 278.52799999999996`}, {80.371, 
                    278.52799999999996`}, {71.57, 273.579}, {66.98, 
                    273.579}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    62.828, 247.47}, {66.98, 244.97}, {71.57, 244.97}, {
                    80.371, 240.016}, {89.10499999999999, 240.016}, {
                    89.10499999999999, 259.173}, {56.703, 259.173}, {56.703, 
                    255.993}, {62.828, 252.23499999999999`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    115.586, 266.309}, {115.586, 271.079}, {
                    111.43400000000001`, 273.579}, {106.84400000000001`, 
                    273.579}, {98.043, 278.52799999999996`}, {89.309, 
                    278.52799999999996`}, {89.309, 259.376}, {
                    121.71100000000001`, 259.376}, {121.71100000000001`, 
                    262.552}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{103.895, 266.227}, {102.727, 267.462}, {106.273, 
                    270.805}, {106.273, 273.079}, {108.34400000000001`, 
                    271.794}, {109.85199999999999`, 273.2}, {111.348, 
                    272.27799999999996`}, {109.836, 270.872}, {111.777, 
                    269.66900000000004`}, {107.543, 269.66900000000004`}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    109.87899999999999`, 272.95}, {108.523, 271.684}, {109.66,
                     270.98099999999994`}, {111.016, 272.247}}, {{106.477, 
                    272.71599999999995`}, {106.477, 270.71999999999997`}, {
                    103.016, 267.454}, {103.902, 266.512}, {
                    107.46100000000001`, 269.872}, {111.066, 269.872}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{96.758, 266.845}, {95.59, 268.079}, {99.137, 
                    271.42299999999994`}, {99.137, 273.69599999999997`}, {
                    101.20700000000001`, 272.41499999999996`}, {102.715, 
                    273.817}, {104.20700000000001`, 272.899}, {102.699, 
                    271.489}, {104.637, 270.28599999999994`}, {100.402, 
                    270.28599999999994`}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    102.738, 273.567}, {101.383, 272.302}, {102.52, 
                    271.59799999999996`}, {103.87499999999999`, 
                    272.86400000000003`}}, {{99.34, 273.33299999999997`}, {
                    99.34, 271.337}, {95.87499999999999, 
                    268.07099999999997`}, {96.766, 267.13}, {100.324, 
                    270.489}, {103.93, 270.489}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{104.418, 262.188}, {103.25, 
                    263.42299999999994`}, {106.79700000000001`, 266.77}, {
                    106.79700000000001`, 269.04}, {108.867, 267.759}, {
                    110.37499999999999`, 269.165}, {111.871, 268.243}, {
                    110.359, 266.83299999999997`}, {112.301, 265.63}, {
                    108.066, 265.63}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    110.402, 268.91099999999994`}, {109.04700000000001`, 
                    267.64500000000004`}, {110.184, 266.942}, {111.539, 
                    268.20799999999997`}}, {{107., 268.677}, {107., 266.68}, {
                    103.539, 263.41499999999996`}, {104.426, 262.477}, {
                    107.98400000000001`, 265.83299999999997`}, {111.59, 
                    265.83299999999997`}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{103.895, 252.317}, {102.727, 
                    251.08700000000002`}, {106.273, 247.73899999999998`}, {
                    106.273, 245.47}, {108.34400000000001`, 246.751}, {
                    109.85199999999999`, 245.345}, {111.348, 246.266}, {
                    109.836, 247.677}, {111.777, 248.876}, {107.543, 
                    248.876}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    109.87899999999999`, 245.598}, {108.523, 246.86}, {109.66,
                     247.563}, {111.016, 246.298}}, {{106.477, 245.833}, {
                    106.477, 247.82500000000002`}, {103.016, 251.095}, {
                    103.902, 252.032}, {107.46100000000001`, 248.677}, {
                    111.066, 248.677}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{96.758, 251.7}, {95.59, 250.47}, {99.137, 
                    247.122}, {99.137, 244.85200000000003`}, {
                    101.20700000000001`, 246.134}, {102.715, 244.727}, {
                    104.20700000000001`, 245.64899999999997`}, {102.699, 
                    247.055}, {104.637, 248.259}, {100.402, 248.259}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    102.738, 244.98100000000002`}, {101.383, 
                    246.24299999999997`}, {102.52, 246.946}, {
                    103.87499999999999`, 245.68}}, {{99.34, 245.212}, {99.34, 
                    247.208}, {95.87499999999999, 250.477}, {96.766, 
                    251.415}, {100.324, 248.055}, {103.93, 248.055}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{104.418, 256.356}, {103.25, 255.122}, {
                    106.79700000000001`, 251.778}, {106.79700000000001`, 
                    249.505}, {108.867, 250.79}, {110.37499999999999`, 
                    249.38400000000001`}, {111.871, 250.305}, {110.359, 
                    251.712}, {112.301, 252.915}, {108.066, 252.915}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    110.402, 249.637}, {109.04700000000001`, 250.899}, {
                    110.184, 251.602}, {111.539, 250.33700000000002`}}, {{
                    107., 249.86800000000002`}, {107., 251.864}, {103.539, 
                    255.13}, {104.426, 256.071}, {107.98400000000001`, 
                    252.712}, {111.59, 252.712}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{74.516, 252.317}, {75.684, 
                    251.08700000000002`}, {72.137, 247.73899999999998`}, {
                    72.137, 245.47}, {70.066, 246.751}, {68.559, 245.345}, {
                    67.066, 246.266}, {68.574, 247.677}, {66.637, 248.876}, {
                    70.871, 248.876}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    68.535, 245.598}, {69.891, 246.86}, {68.754, 247.563}, {
                    67.398, 246.298}}, {{71.93400000000001, 245.833}, {
                    71.93400000000001, 247.82500000000002`}, {75.398, 
                    251.095}, {74.508, 252.032}, {70.94900000000001, 
                    248.677}, {67.34400000000001, 248.677}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{81.65599999999999, 251.7}, {82.824, 250.47}, {
                    79.277, 247.122}, {79.277, 244.85200000000003`}, {
                    77.20700000000001, 246.134}, {75.699, 244.727}, {74.203, 
                    245.64899999999997`}, {75.715, 247.055}, {73.773, 
                    248.259}, {78.008, 248.259}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    75.67199999999998, 244.98100000000002`}, {77.027, 
                    246.24299999999997`}, {75.895, 246.946}, {74.535, 
                    245.68}}, {{79.074, 245.212}, {79.074, 247.208}, {82.539, 
                    250.477}, {81.648, 251.415}, {78.09, 248.055}, {
                    74.48400000000001, 248.055}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{73.992, 256.356}, {75.16, 255.122}, {71.613, 
                    251.778}, {71.613, 249.505}, {69.543, 250.79}, {68.035, 
                    249.38400000000001`}, {66.543, 250.305}, {68.051, 
                    251.712}, {66.113, 252.915}, {70.348, 252.915}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    68.012, 249.637}, {69.367, 250.899}, {68.23, 251.602}, {
                    66.87499999999999, 250.33700000000002`}}, {{
                    71.41000000000001, 249.86800000000002`}, {
                    71.41000000000001, 251.864}, {74.87499999999999, 
                    255.13}, {73.98400000000001, 256.071}, {70.426, 
                    252.712}, {66.82, 252.712}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{74.516, 266.227}, {75.684, 267.462}, {72.137, 
                    270.805}, {72.137, 273.079}, {70.066, 271.794}, {68.559, 
                    273.2}, {67.066, 272.27799999999996`}, {68.574, 
                    270.872}, {66.637, 269.66900000000004`}, {70.867, 
                    269.66900000000004`}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    68.535, 272.95}, {69.891, 271.684}, {68.754, 
                    270.98099999999994`}, {67.398, 272.247}}, {{
                    71.93400000000001, 272.71599999999995`}, {
                    71.93400000000001, 270.71999999999997`}, {75.398, 
                    267.454}, {74.508, 266.512}, {70.94900000000001, 
                    269.872}, {67.34400000000001, 269.872}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{81.65599999999999, 266.845}, {82.824, 268.079}, {
                    79.277, 271.42299999999994`}, {79.277, 
                    273.69599999999997`}, {77.20700000000001, 
                    272.41499999999996`}, {75.699, 273.817}, {74.203, 
                    272.899}, {75.715, 271.489}, {73.773, 
                    270.28599999999994`}, {78.008, 270.28599999999994`}}}]}, {
                   
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    75.67199999999998, 273.567}, {77.027, 272.302}, {75.895, 
                    271.59799999999996`}, {74.535, 272.86400000000003`}}, {{
                    79.074, 273.33299999999997`}, {79.074, 271.337}, {82.539, 
                    268.07099999999997`}, {81.648, 267.13}, {78.09, 
                    270.489}, {74.48400000000001, 270.489}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{73.992, 262.188}, {75.16, 263.42299999999994`}, {
                    71.613, 266.77}, {71.613, 269.04}, {69.543, 267.759}, {
                    68.035, 269.165}, {66.543, 268.243}, {68.051, 
                    266.83299999999997`}, {66.113, 265.63}, {70.348, 
                    265.63}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    68.012, 268.91099999999994`}, {69.367, 
                    267.64500000000004`}, {68.23, 266.942}, {
                    66.87499999999999, 268.20799999999997`}}, {{
                    71.41000000000001, 268.677}, {71.41000000000001, 
                    266.68}, {74.87499999999999, 263.41499999999996`}, {
                    73.98400000000001, 262.477}, {70.426, 
                    265.83299999999997`}, {66.82, 265.83299999999997`}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{101.12899999999999`, 
                    273.673}, {101.801, 275.309}, {98.922, 276.805}, {95.023, 
                    276.805}, {93.027, 278.73099999999994`}, {85.387, 
                    278.73099999999994`}, {83.387, 276.805}, {79.492, 
                    276.805}, {76.613, 275.309}, {77.285, 273.673}, {
                    79.85199999999999, 275.02}, {80.977, 275.02}, {
                    84.91400000000002, 270.46999999999997`}, {
                    89.20700000000001, 273.08299999999997`}, {93.5, 
                    270.46999999999997`}, {97.438, 275.02}, {98.562, 
                    275.02}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{101.12899999999999`, 
                    244.872}, {101.801, 243.23499999999999`}, {98.922, 
                    241.74299999999997`}, {95.023, 241.74299999999997`}, {
                    93.027, 239.817}, {85.387, 239.817}, {83.387, 
                    241.74299999999997`}, {79.492, 241.74299999999997`}, {
                    76.613, 243.23499999999999`}, {77.285, 244.872}, {
                    79.85199999999999, 243.524}, {80.977, 243.524}, {
                    84.91400000000002, 248.07899999999998`}, {
                    89.20700000000001, 245.46200000000002`}, {93.5, 
                    248.07899999999998`}, {97.438, 243.524}, {98.562, 
                    243.524}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{68.824, 
                    262.78999999999996`}, {66.85199999999999, 
                    262.78999999999996`}, {66.41000000000001, 
                    263.32099999999997`}, {66.41000000000001, 
                    264.71999999999997`}, {67.52, 265.45799999999997`}, {
                    65.699, 266.137}, {65.65599999999999, 266.106}, {63.305, 
                    264.47299999999996`}, {63.305, 264.03599999999994`}, {
                    59.539, 259.274}, {63.305, 254.509}, {63.305, 254.071}, {
                    65.699, 252.411}, {67.52, 253.091}, {66.41000000000001, 
                    253.82500000000002`}, {66.41000000000001, 255.227}, {
                    66.85199999999999, 255.755}, {68.824, 255.755}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{63.508, 254.177}, {63.508, 
                    254.57899999999998`}, {59.797000000000004`, 259.274}, {
                    63.508, 263.96599999999995`}, {63.508, 264.368}, {65.727, 
                    265.91099999999994`}, {67.07799999999999, 265.407}, {
                    66.20700000000001, 264.829}, {66.20700000000001, 
                    263.247}, {66.758, 262.59099999999995`}, {68.621, 
                    262.59099999999995`}, {68.621, 255.95800000000003`}, {
                    66.758, 255.95800000000003`}, {66.20700000000001, 
                    255.298}, {66.20700000000001, 253.71599999999998`}, {
                    67.07799999999999, 253.141}, {65.727, 252.634}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{109.586, 
                    262.78999999999996`}, {111.562, 262.78999999999996`}, {
                    112.004, 263.32099999999997`}, {112.004, 
                    264.71999999999997`}, {110.891, 265.45799999999997`}, {
                    112.71100000000001`, 266.137}, {112.758, 266.106}, {
                    115.109, 264.47299999999996`}, {115.109, 
                    264.03599999999994`}, {118.87499999999999`, 259.274}, {
                    115.109, 254.509}, {115.109, 254.071}, {
                    112.71100000000001`, 252.411}, {110.891, 253.091}, {
                    112.004, 253.82500000000002`}, {112.004, 255.227}, {
                    111.562, 255.755}, {109.586, 255.755}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{114.906, 254.177}, {
                    114.906, 254.57899999999998`}, {118.617, 259.274}, {
                    114.906, 263.96599999999995`}, {114.906, 264.368}, {
                    112.684, 265.91099999999994`}, {111.332, 265.407}, {
                    112.203, 264.829}, {112.203, 263.247}, {
                    111.65599999999999`, 262.59099999999995`}, {109.789, 
                    262.59099999999995`}, {109.789, 255.95800000000003`}, {
                    111.65599999999999`, 255.95800000000003`}, {112.203, 
                    255.298}, {112.203, 253.71599999999998`}, {111.332, 
                    253.141}, {112.684, 252.634}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{89.10499999999999, 278.52799999999996`}, {
                    89.10499999999999, 273.259}, {84.953, 
                    270.73099999999994`}, {81.066, 275.22299999999996`}, {
                    79.801, 275.22299999999996`}, {77.387, 273.954}, {76.867, 
                    275.21599999999995`}, {79.539, 276.60200000000003`}, {
                    83.46900000000001, 276.60200000000003`}, {
                    85.46900000000001, 278.52799999999996`}}, {{89.309, 
                    277.954}, {89.309, 273.259}, {93.46100000000001, 
                    270.73099999999994`}, {97.34400000000001, 
                    275.22299999999996`}, {98.613, 275.22299999999996`}, {
                    101.027, 273.954}, {101.543, 275.21599999999995`}, {
                    98.871, 276.60200000000003`}, {94.94500000000001, 
                    276.60200000000003`}, {92.94500000000001, 
                    278.52799999999996`}, {89.309, 278.52799999999996`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{89.10499999999999, 240.016}, {89.10499999999999, 
                    245.29}, {84.953, 247.817}, {81.066, 
                    243.32100000000003`}, {79.801, 243.32100000000003`}, {
                    77.387, 244.591}, {76.867, 243.329}, {79.539, 241.946}, {
                    83.46900000000001, 241.946}, {85.46900000000001, 
                    240.016}}, {{89.309, 240.591}, {89.309, 245.29}, {
                    93.46100000000001, 247.817}, {97.34400000000001, 
                    243.32100000000003`}, {98.613, 243.32100000000003`}, {
                    101.027, 244.591}, {101.543, 243.329}, {98.871, 
                    241.946}, {94.94500000000001, 241.946}, {
                    92.94500000000001, 240.016}, {89.309, 240.016}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxlk21IFFEUhtcRFqqlD41+lERF9kFICFJIRDfWJTSy2dWZFZs+WEzsw9mZ
kvBHKCK2RVSEhMUWtITkSj9CQiRCJMW+IEqsCOmXiIVELUKhUnbvHd5z0Rbm
xzN75573vOc9G2PxyMlsn8+XxZ8IfzT+lAW0HYnrYfZrm3Xjeb7DKsc7k0Nd
OnF5bGVVcYnOPjR+21IYcNjwwd1X9l/WWXdm5FCM8/tNYzNNOTqrEN99jbO0
OJA6zJpPP2to1xzi2Sb+YonDVhT03PuRKPe+L1L/r/n89nfFccX31+78srlW
3d+3vm0q3LCovqX0Xeuwc1otpf/Y09KAFnQY+gPn+1tuBYMR775axTNC36DD
Jt7xgv5K4oQQlmuyN6lQ73SuS6yLgttdNhXmNw0aLDm04fG5XS5b+umBs7db
8W0uayBisMm5dGZkq8vqbn6/uC9ksHrxIs9l63ib/izD66vI9XxvMzy/ddfT
nVQszxeaLNtcXtBzxmW9039GG08pPi8KzJt0fkw0sjpKLM/fiVI9qceIkp7i
Jy8v9B+Ikt4X4txPk/oRtvV9VFwq/L2k/ADDL+lvexX5+SivumZPtPo/xjx4
Oh4OLztC85J6M4pbB16nQqZF8y65enZybpVFeZgXv4RFeZHfv7IoT2DkTeo1
j1Ie8T/yCkaecT/yvqB+QOnDvkA/9gn9gdH/XeGnpljmtixO/oHhb5cYYNom
lueabZqP9KfGpvmBMV9Zv8Wm+XM3xjs7bMoH/+rERJ1N+fk7KhqyKV9g5E/6
O1tP+QQjvziPfIPlvvoMqof9gB7sD/Riv9AP9g+M/YQfYPiF/V7gL9//xYx5
/AN4GlC2
                    "]]}, {
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 
                    1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, {{{89.309, 242.985}, {90.20700000000001, 
                    242.298}, {89.309, 241.61399999999998`}}, CompressedData["

1:eJxTTMoPSmViYGBQBmIQvch12+e/c0Idzn0PfrzUPM9hjUxUivV8BD9j4tsa
e9Mwh97peULNDHkOcq2vA3e4YfLfBO6Qa9XOc/gPAt9DHVYc8zbv9ETIg81L
R/DtTeN2ee6Ami8aAjEvJd9hb8lkCZayIAy+G9CZVzgKHKy2nCjbNz/QIeTx
0tlHjAocRNe5P6yKCYDzVdgapzpzBzh81YjpPyRd4NAudvPc92J/uDyYv9kP
zge7e7e/Q33WnpLJXAg+yFgRlgIHl+6c578FAyD++Zjv8A1kbmqAQwDIgZwF
DiIghSYBDkBVKz9yIPhA3/Ew8UL1LwxwyAXJaxQ4xIPEJwfC+ceBxjoGBDns
AfmTBcGX1r+rwhaY7wAKhgNcIXA+2N0KYQ7/rlS8VFubB+dPcwZaVJ3nUAwK
0OOhDgukgBri8hyaD5xa6LoMwbcEhZ97qEMPyMG1eZBwdgh1OKKwoSijM8/h
otLtn3VCoRD3ZEH5XYj0AADYPwDm
                    "], {{64.17599999999999, 
                    260.505}, {65.17599999999999, 259.376}, {63.176, 
                    259.376}}, {{89.10499999999999, 276.93399999999997`}, {
                    88.20700000000001, 276.247}, {89.10499999999999, 
                    275.559}}, {{113.238, 259.173}, {114.238, 
                    258.04400000000004`}, {115.238, 259.173}}, CompressedData["
1:eJxTTMoPSmViYGBQAmIQrcrWONX5d5hD7vPfKz/6FDpkTHxbY58a5jD7iMKG
ooxCh01z3y8/FozJj9vlycMUXOhwUen2z7pFYQ6nF7pu++yMkK8WWef+0ATB
r8vaUzKZB2p+awTEvG0FDn5JAhGWKlEY/Bvnvgc/ji9wmJEn1HzgVxTEfNMC
h70lkyVY7GLg/DUyUSnW/TFQ9xc49E4HangQ47AHpM4MyneIhfPv/AS6ZE+M
wwIp/bsqcQh+gS3X9cUpUPUdUP0FBQ63QfImMQ7MYXy6m+Kh9qfFOHzViOk/
hMQHy0cXOBzzNu90/BENkbcvcCgGeZgdwQfaUmDrFeUQ/Hjp7CMpCD5Y34EC
B6stJ8r29UfA+ds+/71SURkGca9QIZzvBmJoFTrEg+LhcpgDC8h+y0JI+H1B
8MHhFxTucBMUnpqFDi7dOc9/R4ZD/KdS6PAfBNrDIe4zLnRgAAGBcHh6AAB7
afdG
                    "]}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1,
                     0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 
                    0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 
                    0}, {0, 1, 0}}}, {{{89.10499999999999, 
                    241.61399999999998`}, {88.20700000000001, 242.298}, {
                    89.10499999999999, 242.985}}, {{65.17599999999999, 
                    259.173}, {64.17599999999999, 258.04400000000004`}, {
                    63.176, 259.173}}, CompressedData["
1:eJxTTMoPSmViYGBQBmIQnTnxbY393zCHc9+DHy81z3NQZWuc6vwbwc8AyaeG
OfROzxNqZshz2DT3/fJjwZj8N4E75Fq18xwuKt3+WbcozGHFMW/zTk+EPNi8
dATf3jRul+cOqPmtERDzUvId/JIEIixVojD4bts+/73CUeAwAyh84FeUQ8jj
pbOPGBU47C2ZLMFiFwPnr5GJSrHuj3H4qhHTf0i6AGLOA4Q8mO8QC+ff+VmX
tWdPjEN91p6SyVwI/jr3h1UiLFD1HTEQ/3zMd7gNkjeJcQgASXBC7U+Lcch5
/nvlRw4EH+g7HibeAgeQNscf0Q65IHmNAodikIfZEXyu64sLbL2iHPaA9LEg
+NL6d1XYAvMdrLacKNvXHwHng4KhojLM4d+Vipdqa/Pg/GnO3TnPq/Mc4kH2
Xg5zWCAF1BCXBwm/Lwg+OPyCwh16QA6uzXNwAWr7HRnucERhQ1FGZ57DfxBo
D4e4JyvPgQEEBMLh6QEAP70BUg==
                    "], {{114.238, 260.505}, {
                    113.238, 259.376}, {115.238, 259.376}}, CompressedData["
1:eJxTTMoPSmViYGBQAmIQvUYmKsV6fqhD7vPfKz/6FDpkTHxbY28a5jD7iMKG
ooxCB7nW14E73DD5cbs8eZiCCx3+g8D3UIfTC123fXZGyFeLrHN/aILg12Xt
KZnMAzVfNARi3rYCh70lkyVYyoIw+DfOfQ9+HF/gYLXlRNm++YEQ800LHESB
xlbFBMD5KmyNU525A6DuL3BoF7t57nuxv8MekDlmUP5mPzj/TeAOudbd/g4L
pPTvqsQh+AW2XNcXpxQ4uHTnPP8tGABRX1Dg8E0jpv9QaoADcxif7iage0De
qjIJcPgKEkfig+WjCxyAphTYLoLK2xc4xIPCaXIgnH/c27zTMSDIIfjx0tlH
UhD8YyD6QIHD9Dyh5gNcIXB+CEidQhjEvUKFcL7bts9/r2gVOhSDAvR4qAML
yH7LQofmA6cWui5D8C1B4ece6nATFJ6ahQ69IAscQiH+Uyl0uKh0+2edUCjE
fcZQfhciPQAALpL1Zg==
                    "], {{89.309, 275.559}, {
                    90.20700000000001, 276.247}, {89.309, 
                    276.93399999999997`}}}]}, {
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, {{{89.10499999999999, 272.552}, {80.387, 
                    267.2}, {74.04700000000001, 267.2}, {74.04700000000001, 
                    261.895}, {70.824, 259.376}, {89.10499999999999, 
                    259.376}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, {{{89.309, 245.997}, {98.023, 251.345}, {
                    104.367, 251.345}, {104.367, 256.653}, {107.59, 
                    259.173}, {89.309, 259.173}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, {{{107.59, 259.376}, {104.367, 
                    261.895}, {104.367, 267.2}, {98.023, 267.2}, {89.309, 
                    272.552}, {89.309, 259.376}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, {{{70.824, 259.173}, {74.04700000000001, 
                    256.653}, {74.04700000000001, 251.345}, {80.387, 
                    251.345}, {89.10499999999999, 245.997}, {
                    89.10499999999999, 259.173}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{84.273, 260.19599999999997`}, {85.44100000000002,
                     261.42699999999996`}, {81.895, 264.774}, {81.895, 
                    267.04400000000004`}, {79.824, 265.762}, {78.316, 
                    267.16900000000004`}, {76.82, 266.247}, {78.332, 
                    264.837}, {76.391, 263.637}, {80.62499999999999, 
                    263.637}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    78.289, 266.91499999999996`}, {79.645, 265.653}, {78.512, 
                    264.94599999999997`}, {77.15199999999999, 266.212}}, {{
                    81.691, 266.68}, {81.691, 264.688}, {85.15599999999999, 
                    261.419}, {84.266, 260.48099999999994`}, {
                    80.70700000000001, 263.837}, {77.10199999999999, 
                    263.837}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{94.137, 258.35200000000003`}, {92.973, 
                    257.118}, {96.52, 253.77399999999997`}, {96.52, 
                    251.501}, {98.59, 252.786}, {100.098, 
                    251.38000000000002`}, {101.59, 252.30200000000002`}, {
                    100.07799999999999`, 253.708}, {102.02, 254.911}, {97.785,
                     254.911}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    100.121, 251.63}, {98.766, 252.895}, {99.902, 253.598}, {
                    101.258, 252.333}}, {{96.723, 251.864}, {96.723, 
                    253.86}, {93.258, 257.126}, {94.148, 258.067}, {
                    97.70700000000001, 254.708}, {101.309, 254.708}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{84.273, 258.35200000000003`}, {85.44100000000002,
                     257.118}, {81.895, 253.77399999999997`}, {81.895, 
                    251.501}, {79.824, 252.786}, {78.316, 
                    251.38000000000002`}, {76.82, 252.30200000000002`}, {
                    78.332, 253.708}, {76.391, 254.911}, {80.62499999999999, 
                    254.911}}}]}, {
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    78.289, 251.63}, {79.645, 252.895}, {78.512, 253.598}, {
                    77.15199999999999, 252.333}}, {{81.691, 251.864}, {81.691,
                     253.86}, {85.15599999999999, 257.126}, {84.266, 
                    258.067}, {80.70700000000001, 254.708}, {
                    77.10199999999999, 254.708}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{94.137, 260.19599999999997`}, {92.973, 
                    261.42699999999996`}, {96.52, 264.774}, {96.52, 
                    267.04400000000004`}, {98.59, 265.762}, {100.098, 
                    267.16900000000004`}, {101.59, 266.247}, {
                    100.07799999999999`, 264.837}, {102.02, 263.637}, {97.785,
                     263.637}}}]}, {
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    100.121, 266.91499999999996`}, {98.766, 265.653}, {99.902,
                     264.94599999999997`}, {101.258, 266.212}}, {{96.723, 
                    266.68}, {96.723, 264.688}, {93.258, 261.419}, {94.148, 
                    260.48099999999994`}, {97.70700000000001, 263.837}, {
                    101.309, 263.837}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    98.57799999999999, 259.274}, {89.20700000000001, 
                    253.024}, {79.832, 259.274}, {89.20700000000001, 
                    265.52}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1,
                     0}}, {{0, 2, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}}}, {{{
                    89.10499999999999, 265.212}, {80.348, 259.376}, {
                    89.10499999999999, 259.376}}, {{89.309, 259.376}, {98.062,
                     259.376}, {89.309, 265.212}}, {{80.348, 259.173}, {
                    89.10499999999999, 253.33700000000002`}, {
                    89.10499999999999, 259.173}}, {{89.309, 
                    253.33700000000002`}, {98.066, 259.173}, {89.309, 
                    259.173}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{91.715, 263.137}, {91.715, 
                    261.42299999999994`}, {94.95700000000001, 
                    261.42299999999994`}, {94.95700000000001, 257.126}, {
                    91.715, 257.126}, {91.715, 255.407}, {86.699, 255.407}, {
                    86.699, 257.126}, {83.45700000000001, 257.126}, {
                    83.45700000000001, 261.42299999999994`}, {86.699, 
                    261.42299999999994`}, {86.699, 263.137}}}]}, {
                    Thickness[0.00006663529411764707], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{91.715, 
                    263.13698200000005`}, {91.715, 261.42298200000005`}, {
                    94.95700000000001, 261.42298200000005`}, {
                    94.95700000000001, 257.125982}, {91.715, 257.125982}, {
                    91.715, 255.40698200000003`}, {86.699, 
                    255.40698200000003`}, {86.699, 257.125982}, {
                    83.45700000000001, 257.125982}, {83.45700000000001, 
                    261.42298200000005`}, {86.699, 261.42298200000005`}, {
                    86.699, 263.13698200000005`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgAWI2IGYC4lp707hdO0MdYnd58jDlFzjA+K8Dd8i1Bhc4
cF1fXGD7KgSDv6dksgSLWYGDXCtQxi0Mgw8zb9Pc98uPBSPkj3ubdzpuCMfg
w8wPebx09pEHYRh8dPNgfJh7wOqMEHxjEBBF+AedDzb/cz7cveh8mHkw+2Dy
KO5D4sPMh/kHnY9uHowPAG5CqjE=
                    "]]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4pDHS2cfMQhxuL64wJarOd0Bha+d7lBjbxq3
KzMCOx+o/vbPuqw9PlEYfKeEpxeUbqc7WG05UbZPPwY73zjD4aISUIdQHAb/
y98rFS/9suHq0fmfQfxl2XD70Plg9/zPRnUvOj88B9W/6Hyg+m8aMf2HfIMw
+DD7pucJNR/ICsDgw9xbnDHxbQ2/LwYf5l+Yeqx8YHjB7EPnw8IbAN9z2dI=

                    "]]}, {
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4js/67L2xEQ4rDjmbd7Zme6AwjdMd/imEdN/
yDYEOx+ofkaeUPOBqCAMfk/O898rH6Y7WG45UbavPAA73zLDYdvnv1cqNH0x
+Ks+XvJN8siGq0fn904HWrQgG24fVv6PbLh70fmFtlzXFwfkwP2LzoeptwLZ
Zx+FnQ+zTykGgw9zL9g+1jgMPsy/MPVY+cDwgtmHzoeFNwBep9jy
                    
                    "]]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4m8aMf2H9oY4rDjmbd55Mt0Bxj+isKEoozDd
4c7Puqw9d8Ix+DD1VltOlO3bH4mdr5jhMCNPqPnAomgMfk/O898rKzMg9rXG
YvB7pwMVcmTD1WPlJ2TD7UPnF9hyXV+8IxvuXnR+IYgvkAP3Lzofph5s360g
DD7MPkuQfd8DsPOB7t32+e+VCk0/DD7MvzD16HyU8ALah5UPDG8AAlTaAA==

                    "]]}, {
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGZigIIL4Q7TnLtznp9Pd4Dxp4L45ekOF5Vu/6w7
FYLBh6kvzpj4tuZ5EAa/8qWaIYdGhoPIOveHVSyB2PkNGQ6/6rL2lDj7YfD3
lEyWYGHKhqvHyo/KhtuHzl8gpX9XZVM23L1Y+Vw5cP9i5QPVx+/y5GHaHInB
h9n3TSOm/9DUaOx8oHtDHi+dfaQiFoMP8y9MPVY+MLxg9qHzYeENAGuWuLI=

                    "]]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[CompressedData["
1:eJxTTMoPSmJmYGBgBOJMIAaxGZjA/FFEOgIA9vgCgQ==
                    
                    "], CompressedData["
1:eJxtVFtIVFEUnSxEwyyloKSsRETpo/oQLYo5aUNYmY+xZpyHyJDNnblS9iA0
xBAZTFIiogdIYEoUEiYWEaE5lFj0ITkMSKkfIhYRIREmZq9ztrP2VfDC+Vh3
n/04a6+9t3vOFFesNJlMK+TxyxMlz67x1Oj6/BKR3XSgfKpKF77r32rNEnd+
D+V7unUxnDI6VxeyioeDR7KaanTxT302K9v3PH178aXE8A+p+x+LhTmz7EVe
m4EHtnWf0yy6uHM6sSHoKRaxjzY7Tm6NxJfYde3VTLpdF3tVvOkiUbV/9UhH
qi7G5ur8vbVFbN/QdWjiksTwp/yzhQv15RmY8s34xXp1v7lQHI6L2tE45BfV
X9J2x0jclrRzPDVKF6MqflyhqFH/w/6FepIK2H7wauXn+U0F7P/sx59wdcYx
0XvhxsZVvww80iErnveJ85okcG3+8rjRt/T+Ikz5r2ic72vR8+TAE43ruZUr
DZc1rpfq69L4PbDjvfAHHyWT91sHmg3ccls2IltjPhPs0uLRmO8PQ7PWyQyN
+0H8ujXuF+zoJ/zR77Oqf/sMTPcnvKyXv2FZeYLGevqZLjs87GW9UX0xGusR
dugV/vS/r0SsU/k/eRlTvoBXKPrNFcfFKfWFDEzxq72R+CdETvnU+5TXEXum
je3A8Cd+xmwcHxj52y2yo0ftXN9CfDvXT+99Y+f30XtzStlOfEoMf+K/v5T5
Awa/xGeWg/mn+BKjPypNsNPB/aM8W5xs71M6TnayP+Vvd7I+gKEfuh/vYn3R
XEgM/VH8Fhfrk96/xs126p/E8Kf7ATfrHxjzQfwkli2P5Xwtub8IYz6RD/OL
ejDfqBfz3xB8d88S72I73gt/8IH9Aoz9Az6xn8A39hf6gf2GfsGOfsIf/cb+
BMZ+hV6wf6En7GfoDfsbeoQdeoU/9Ez5Ww3sVvX91nkeeu5OPxh8bGCKH1vJ
80T96Nd53mAHhj/mFfGB06Lrb+bK/P8BIPUg9A==
                    "]]}, {
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4m2f/16p0PR1WHHM27yzN9MBxi+w5bq++Eum
w6+6rD0lzn4Y/CMKG4oy3mZB+Mb+DjfPfQ9+fDDLoV0MyALyl4PM+5rlcPsn
UAFPgEPlSzVDjjNZDr3T84SaBQIg+s9mOayRiUqxrg+Aqy/OmPi2BsiHmWe5
5UTZvu8BcPtg/ODHS2cfmZIBVx/Tf+irxoEMuHl9IHt6MuD27y2ZLMGyLQPu
Ppg8zP0w/TD/wcyH8WHhAwDBUpeK
                    "]]}, {
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    70.145, 195.454}, {68.07, 194.134}, {68.07, 217.93}, {
                    70.145, 216.61399999999998`}, {70.148, 218.305}, {
                    71.74600000000001, 216.872}, {73.34, 218.305}, {
                    73.34400000000001, 216.61399999999998`}, {75.418, 
                    217.93}, {75.418, 194.134}, {73.34400000000001, 
                    195.454}, {73.34, 193.762}, {71.74600000000001, 
                    195.192}, {70.148, 193.762}}}]}, {
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    77.57, 192.942}, {75.617, 191.466}, {75.617, 220.598}, {
                    77.57, 219.122}, {77.574, 221.059}, {79.289, 
                    219.52800000000002`}, {81.004, 221.059}, {81.008, 
                    219.122}, {82.96100000000001, 220.598}, {
                    82.96100000000001, 191.466}, {81.008, 192.942}, {81.004, 
                    191.005}, {79.289, 192.54}, {77.574, 191.005}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    89.20700000000001, 221.727}, {85.785, 
                    223.92700000000002`}, {85.785, 221.032}, {83.164, 
                    223.423}, {83.164, 188.64499999999998`}, {85.785, 
                    191.032}, {85.785, 188.137}, {89.20700000000001, 
                    190.33700000000002`}, {92.62899999999999, 188.137}, {
                    92.62899999999999, 191.032}, {95.25, 
                    188.64499999999998`}, {95.25, 223.423}, {
                    92.62899999999999, 221.032}, {92.62899999999999, 
                    223.92700000000002`}}}]}, {
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4m8aMf2HWOMcVhzzNu/szXSA8Qtsua4v/pLp
EPJ46ewjFbEY/CMKG4oy3mZB+AyxDjfPfQ9+fDDLoXd6nlAzkL8cZN7XLIh5
vTEOlS/VDDnOZDk4d+c8/90ZA9F/NstBla1xqrN0DFx93C5PHiYgH2beDKBx
BxZFw+2D8YNB9k7JgKsH2vJV40AG3Lw+kDt6MuD27y2ZLMGyLQPuPpg8zP0w
/TD/wcyH8WHhAwAmq49E
                    "]]}, {
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    108.27, 195.454}, {110.34400000000001`, 194.134}, {
                    110.34400000000001`, 217.93}, {108.27, 
                    216.61399999999998`}, {108.266, 218.305}, {
                    106.66799999999999`, 216.872}, {105.074, 218.305}, {
                    105.07, 216.61399999999998`}, {102.99600000000001`, 
                    217.93}, {102.99600000000001`, 194.134}, {105.07, 
                    195.454}, {105.074, 193.762}, {106.66799999999999`, 
                    195.192}, {108.266, 193.762}}}]}, {
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    100.84400000000001`, 192.942}, {102.79700000000001`, 
                    191.466}, {102.79700000000001`, 220.598}, {
                    100.84400000000001`, 219.122}, {100.84, 221.059}, {
                    99.12499999999999, 219.52800000000002`}, {
                    97.41000000000001, 221.059}, {97.406, 219.122}, {95.453, 
                    220.598}, {95.453, 191.466}, {97.406, 192.942}, {
                    97.41000000000001, 191.005}, {99.12499999999999, 
                    192.54}, {100.84, 191.005}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{91.504, 216.466}, {90.691, 
                    215.76999999999998`}, {90.691, 217.82100000000003`}, {
                    92.523, 219.17299999999997`}, {89.20700000000001, 
                    221.618}, {85.891, 219.17299999999997`}, {87.723, 
                    217.82100000000003`}, {87.723, 215.76999999999998`}, {
                    86.91000000000001, 216.466}, {86.91000000000001, 
                    217.595}, {84.96900000000001, 216.001}, {87.051, 
                    214.07899999999998`}, {86.238, 212.95800000000003`}, {
                    92.17199999999998, 212.95800000000003`}, {91.363, 
                    214.07899999999998`}, {93.44500000000001, 216.001}, {
                    91.504, 217.595}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{86.70700000000001, 
                    217.16899999999998`}, {86.70700000000001, 216.372}, {
                    87.926, 215.333}, {87.926, 217.923}, {86.23, 
                    219.17299999999997`}, {89.20700000000001, 
                    221.36800000000002`}, {92.184, 219.17299999999997`}, {
                    90.488, 217.923}, {90.488, 215.333}, {91.703, 216.372}, {
                    91.703, 217.16899999999998`}, {93.137, 215.993}, {
                    91.09400000000001, 214.106}, {91.777, 213.161}, {86.637, 
                    213.161}, {87.32, 214.106}, {85.277, 215.993}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{89.20700000000001, 218.055}, {90.723, 
                    219.17299999999997`}, {89.20700000000001, 220.29}, {
                    89.148, 220.24699999999999`}, {87.691, 
                    219.17299999999997`}}}]}, {
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{89.20700000000001, 220.04}, {89.309, 219.966}, {
                    90.203, 219.305}, {90.383, 219.17299999999997`}, {90.203, 
                    219.04399999999998`}, {89.309, 218.38000000000002`}, {
                    89.20700000000001, 218.305}, {89.10499999999999, 
                    218.38000000000002`}, {88.20700000000001, 
                    219.04399999999998`}, {88.031, 219.17299999999997`}, {
                    88.20700000000001, 219.305}, {89.10499999999999, 
                    219.966}, {89.20700000000001, 220.04}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIRIGYC4m8aMf2HlkY6rDjmbd5ZmOlQnDHxbY1+DAZ/
mnN3zvPZmQ5+SQIRliyxGPwFUvp3VZ4h1KPze6fnCTULZDnA7IPxt33+e6Xi
YbjDvysVL9WWZjlIA7Wx7QyB82//rMva8yUIrh5EHcgKwODD7GNrnOrcreOP
wYe5F6YenQ/zL8w+GB/mHjB9NwPuXhgfAAZzj3w=
                    "]]}, {
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIRIGYCYsstJ8r2lQc4VL5UM+SoyHSA8dNAYFGmgycP
k3a7mz8G//z34MdL7yPUo/P3lEyWYOHKcuidnifU/CMIzr/zsy5rz54QB71N
c98vn5flYHBXha3xbjic79Kd8/z3wki4+hlA7QeUYjD4MPvWyESlWH/H5MPc
C1OPzof5F2YfjA9zDwfIoMcZcPfC+DD/wNQDADpbjso=
                    "]]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, {{{109.004, 204.68}, {109.004, 
                    207.38700000000003`}, {101.766, 207.38700000000003`}, {
                    101.766, 208.02800000000002`}, {95.309, 212.266}, {
                    83.10499999999999, 212.266}, {76.648, 
                    208.02800000000002`}, {76.648, 207.38700000000003`}, {
                    69.41000000000001, 207.38700000000003`}, {
                    69.41000000000001, 204.68}, {76.648, 204.68}, {76.648, 
                    204.036}, {83.10499999999999, 199.798}, {95.309, 
                    199.798}, {101.766, 204.036}, {101.766, 204.68}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, {{{69.613, 207.184}, {76.848, 207.184}, {
                    76.848, 207.91899999999998`}, {83.164, 212.067}, {95.25, 
                    212.067}, {101.562, 207.91899999999998`}, {101.562, 
                    207.184}, {108.801, 207.184}, {108.801, 
                    204.88000000000002`}, {101.562, 204.88000000000002`}, {
                    101.562, 204.14499999999998`}, {95.25, 200.001}, {83.164, 
                    200.001}, {76.848, 204.14499999999998`}, {76.848, 
                    204.88000000000002`}, {69.613, 204.88000000000002`}}}]}, {
                   
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {CompressedData["
1:eJxTTMoPSmViYGDQAWIQfftnXdaeKWEO0vp3VdhysxwyJ76tsfcNc1ggBRQI
ynL4phHTf4gVIW+15UTZvvpQOJ/r+uICWy6ovGWWgwGQauQNhei/lelgCVLf
HuKw+uMl3ySeLIeQx0tnH9kQ4jDNuTvnuXQWRN/DEIg9nFkO7WI3z31XDnX4
8vdKxUslhPq9JZMlWPyyHGrtTeN2MSLMu6gE9MGpEIg5BzPh8kDTf68szYTr
r3ypZshhkgk3X5WtcapzfCbc/lUg8yoQ6psPnFromoZwP8w8mP+mgty/PBPV
/56ZqOEjmokafkA+LHzB/tfPdEAJf6D8jDyh5gNS4XD+cW/zTscJCPMXuW77
/LcnHG4/WL1QBNx9NSD/vwyHux+o+krFznC4/zx5mLTby8Lh/oeph4UP2P8z
EOYxgMCFcHj4wuRh4Q/TD4sfmPmw+IPZD4tfmHpY/MPcDzMP5j9Y+kHxv2UW
avgA0x8AwN0vbA==
                    "], {{89.20700000000001, 208.997}, {
                    93.15599999999999, 206.032}, {89.20700000000001, 
                    203.067}, {85.258, 206.032}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {CompressedData["
1:eJxTTMoPSmViYGDQAWIQvWnu++XHPoc56IIYaVkOl5Ru/6yrCnOQ1r+rwmaZ
5bDIddvnvz3hDntKJkuwXMp0OOZt3umoEeGw+uMl3ySeLIcae9O4XS/DHaY5
d+c8V85yAKq+UrEz3OHmue/BjwWzHCpeqhlyAPV/AQq/VEKo3wsyzy3LIX6X
Jw9TM8I87uuLC2x3hUPsP5gJlwea/ntlaSZcf2z/oa8aNplw81XZGqc6x2fC
7Qcp8yxAqF8gBTQwDuF+mHkw/1WCzNmQiep/z0wHWPi8Cdwh1yqd6fCwSmSd
+0wEP3Pi2xp73zCIfguoPCNCHuh67fZloXC+1ZYTZfvkEeYbAKlG3lC4/S4g
hxWGwN0X8njp7CMbQuDuB+t7GAL3X/OBUwtd+ULh/oeph4VPcQbQgeII8xhA
4EEIPHxh8rDwh+mHxQ/MfFj8weyHxS9MPSz+Ye6HmQfzHyz9oPgfmL5g4QNL
f7Dwg/Fh4Qv2v1cWPPxh8gBYbjeA
                    "], {{89.145, 209.208}, {
                    84.918, 206.032}, {89.20700000000001, 202.813}, {
                    93.49600000000001, 206.032}, {89.20700000000001, 
                    209.251}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    77.95700000000001, 206.032}, {79.79700000000001, 
                    204.813}, {81.633, 206.032}, {79.79700000000001, 
                    207.255}}}]}, {
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    79.79700000000001, 207.009}, {81.266, 206.032}, {
                    79.79700000000001, 205.055}, {78.324, 206.032}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    87.371, 206.032}, {89.20700000000001, 204.813}, {91.043, 
                    206.032}, {89.20700000000001, 207.255}}}]}, {
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    89.20700000000001, 207.009}, {90.67999999999999, 
                    206.032}, {89.20700000000001, 205.055}, {
                    87.73400000000001, 206.032}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    100.45700000000001`, 206.032}, {98.617, 204.813}, {96.781,
                     206.032}, {98.617, 207.255}}}]}, {
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    98.617, 207.009}, {97.148, 206.032}, {98.617, 205.055}, {
                    100.09, 206.032}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYCYin9uypsG/0d0tOAQC/LIcJyy4myc/4O1xcX
2HKpZzksP+Zt3vnR30GVrXGqs3KWw+2fdVl7eALg/N7peULNCgi+S3fO89+G
AXD9IY+Xzj7iEAA334uHSbs9LwBirmuWw3Eg5VgQ4MC5RiYqJT/LwQpo/b78
AIcjChuKMnox+TOA1h2wgvILsxykQe4H2rf64yXfpJwsh4tKQBdqBTgsAHms
COHezXPfLz/WTZh/eqHrts93/eH6+0D+u+APN3+yBEsY315/uP25z3+v/Bjk
D3cfOv/wV42YfiAf5j8DoHMbQ/3h/kcPfwC3UK7R
                    "]]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4ts/67L28AQ4fPl7peJlXZaDyDr3h1UiAQ6V
L9UMOSqyHLx4mLTb9QIcenKe/16ZSJivytY41Tk4wEFa/64KW2mWA9f1xQW2
SQEO5p2OCU9rshx6p+cJNSdA7YvKctj2GcgIhNrnkOVQnDHxbY15gANIG5dx
lsPrwB1yrdpQ/TpZDotcgTpkAhy+acT0H9LMcoC5H8affURhQ9EPfzgfbO4d
f7j+X0DlJYf94eaD7ev3h9tvGrfLk6fIH+6+UwuBFub6w90PVtfjD/efAZBq
vOoP9z86vwKk/o2/A+camaiU7CwHYOCuc2cMcPgHNF6tFOF+WPgDADdUstg=

                    "]]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    73.301, 214.52}, {71.74600000000001, 215.86}, {
                    70.18799999999999, 214.52}, {71.258, 213.602}, {71.258, 
                    211.47299999999998`}, {70.65199999999999, 
                    212.07899999999998`}, {70.65199999999999, 213.278}, {
                    69.266, 211.993}, {71.74600000000001, 209.516}, {74.223, 
                    211.993}, {72.836, 213.278}, {72.836, 
                    212.07899999999998`}, {72.23400000000001, 
                    211.47299999999998`}, {72.23400000000001, 213.602}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    71.45700000000001, 213.696}, {70.49600000000001, 
                    214.52}, {71.74600000000001, 215.591}, {72.992, 214.52}, {
                    72.031, 213.696}, {72.031, 210.985}, {73.039, 211.993}, {
                    73.039, 212.817}, {73.93, 211.989}, {71.74600000000001, 
                    209.80200000000002`}, {69.559, 211.989}, {
                    70.44900000000001, 212.817}, {70.44900000000001, 
                    211.993}, {71.45700000000001, 210.985}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    80.848, 216.911}, {79.289, 218.24699999999999`}, {
                    77.73400000000001, 216.911}, {78.801, 215.993}, {78.801, 
                    213.864}, {78.199, 214.466}, {78.199, 
                    215.66899999999998`}, {76.812, 214.38400000000001`}, {
                    79.289, 211.903}, {81.77, 214.38400000000001`}, {80.383, 
                    215.66899999999998`}, {80.383, 214.466}, {79.777, 
                    213.864}, {79.777, 215.993}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    79.004, 216.083}, {78.043, 216.911}, {79.289, 
                    217.98100000000002`}, {80.539, 216.911}, {
                    79.57799999999999, 216.083}, {79.57799999999999, 
                    213.376}, {80.586, 214.38400000000001`}, {80.586, 
                    215.20399999999998`}, {81.477, 214.376}, {79.289, 
                    212.18800000000002`}, {77.10199999999999, 214.376}, {
                    77.99600000000001, 215.20399999999998`}, {
                    77.99600000000001, 214.38400000000001`}, {79.004, 
                    213.376}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    73.301, 197.54399999999998`}, {71.74600000000001, 
                    196.208}, {70.18799999999999, 197.54399999999998`}, {
                    71.258, 198.46200000000002`}, {71.258, 200.591}, {
                    70.65199999999999, 199.989}, {70.65199999999999, 
                    198.786}, {69.266, 200.071}, {71.74600000000001, 
                    202.55200000000002`}, {74.223, 200.071}, {72.836, 
                    198.786}, {72.836, 199.989}, {72.23400000000001, 
                    200.591}, {72.23400000000001, 198.46200000000002`}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    71.45700000000001, 198.36800000000002`}, {
                    70.49600000000001, 197.54399999999998`}, {
                    71.74600000000001, 196.47299999999998`}, {72.992, 
                    197.54399999999998`}, {72.031, 198.36800000000002`}, {
                    72.031, 201.07899999999998`}, {73.039, 200.071}, {73.039, 
                    199.251}, {73.93, 200.075}, {71.74600000000001, 
                    202.262}, {69.559, 200.075}, {70.44900000000001, 
                    199.251}, {70.44900000000001, 200.071}, {
                    71.45700000000001, 201.07899999999998`}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    105.113, 214.52}, {106.66799999999999`, 215.86}, {108.227,
                     214.52}, {107.15599999999999`, 213.602}, {
                    107.15599999999999`, 211.47299999999998`}, {107.762, 
                    212.07899999999998`}, {107.762, 213.278}, {109.148, 
                    211.993}, {106.66799999999999`, 209.516}, {104.191, 
                    211.993}, {105.57799999999999`, 213.278}, {
                    105.57799999999999`, 212.07899999999998`}, {
                    106.17999999999999`, 211.47299999999998`}, {
                    106.17999999999999`, 213.602}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    106.95700000000001`, 213.696}, {107.918, 214.52}, {
                    106.66799999999999`, 215.591}, {105.422, 214.52}, {
                    106.383, 213.696}, {106.383, 210.985}, {
                    105.37499999999999`, 211.993}, {105.37499999999999`, 
                    212.817}, {104.48400000000001`, 211.989}, {
                    106.66799999999999`, 209.80200000000002`}, {
                    108.85499999999999`, 211.989}, {107.965, 212.817}, {
                    107.965, 211.993}, {106.95700000000001`, 210.985}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    105.113, 197.54399999999998`}, {106.66799999999999`, 
                    196.208}, {108.227, 197.54399999999998`}, {
                    107.15599999999999`, 198.46200000000002`}, {
                    107.15599999999999`, 200.591}, {107.762, 199.989}, {
                    107.762, 198.786}, {109.148, 200.071}, {
                    106.66799999999999`, 202.55200000000002`}, {104.191, 
                    200.071}, {105.57799999999999`, 198.786}, {
                    105.57799999999999`, 199.989}, {106.17999999999999`, 
                    200.591}, {106.17999999999999`, 198.46200000000002`}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    106.95700000000001`, 198.36800000000002`}, {107.918, 
                    197.54399999999998`}, {106.66799999999999`, 
                    196.47299999999998`}, {105.422, 197.54399999999998`}, {
                    106.383, 198.36800000000002`}, {106.383, 
                    201.07899999999998`}, {105.37499999999999`, 200.071}, {
                    105.37499999999999`, 199.251}, {104.48400000000001`, 
                    200.075}, {106.66799999999999`, 202.262}, {
                    108.85499999999999`, 200.075}, {107.965, 199.251}, {
                    107.965, 200.071}, {106.95700000000001`, 
                    201.07899999999998`}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    80.848, 195.157}, {79.289, 193.817}, {77.73400000000001, 
                    195.157}, {78.801, 196.075}, {78.801, 
                    198.20399999999998`}, {78.199, 197.598}, {78.199, 
                    196.399}, {76.812, 197.684}, {79.289, 200.161}, {81.77, 
                    197.684}, {80.383, 196.399}, {80.383, 197.598}, {79.777, 
                    198.20399999999998`}, {79.777, 196.075}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    79.004, 195.98100000000002`}, {78.043, 195.157}, {79.289, 
                    194.08700000000002`}, {80.539, 195.157}, {
                    79.57799999999999, 195.98100000000002`}, {
                    79.57799999999999, 198.692}, {80.586, 197.684}, {80.586, 
                    196.86}, {81.477, 197.68800000000002`}, {79.289, 
                    199.876}, {77.10199999999999, 197.68800000000002`}, {
                    77.99600000000001, 196.86}, {77.99600000000001, 
                    197.684}, {79.004, 198.692}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    97.566, 216.911}, {99.12499999999999, 
                    218.24699999999999`}, {100.67999999999999`, 216.911}, {
                    99.613, 215.993}, {99.613, 213.864}, {100.215, 214.466}, {
                    100.215, 215.66899999999998`}, {101.60199999999999`, 
                    214.38400000000001`}, {99.12499999999999, 211.903}, {
                    96.645, 214.38400000000001`}, {98.031, 
                    215.66899999999998`}, {98.031, 214.466}, {98.637, 
                    213.864}, {98.637, 215.993}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    99.41000000000001, 216.083}, {100.371, 216.911}, {
                    99.12499999999999, 217.98100000000002`}, {
                    97.87499999999999, 216.911}, {98.836, 216.083}, {98.836, 
                    213.376}, {97.82799999999999, 214.38400000000001`}, {
                    97.82799999999999, 215.20399999999998`}, {96.938, 
                    214.376}, {99.12499999999999, 212.18800000000002`}, {
                    101.309, 214.376}, {100.418, 215.20399999999998`}, {
                    100.418, 214.38400000000001`}, {99.41000000000001, 
                    213.376}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    97.566, 195.157}, {99.12499999999999, 193.817}, {
                    100.67999999999999`, 195.157}, {99.613, 196.075}, {99.613,
                     198.20399999999998`}, {100.215, 197.598}, {100.215, 
                    196.399}, {101.60199999999999`, 197.684}, {
                    99.12499999999999, 200.161}, {96.645, 197.684}, {98.031, 
                    196.399}, {98.031, 197.598}, {98.637, 
                    198.20399999999998`}, {98.637, 196.075}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    99.41000000000001, 195.98100000000002`}, {100.371, 
                    195.157}, {99.12499999999999, 194.08700000000002`}, {
                    97.87499999999999, 195.157}, {98.836, 
                    195.98100000000002`}, {98.836, 198.692}, {
                    97.82799999999999, 197.684}, {97.82799999999999, 
                    196.86}, {96.938, 197.68800000000002`}, {
                    99.12499999999999, 199.876}, {101.309, 
                    197.68800000000002`}, {100.418, 196.86}, {100.418, 
                    197.684}, {99.41000000000001, 198.692}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYCYin9uypsG/0dzn0Pfrw0ONMhwnLLibJz/g7X
FxfYckVnOiw/5m3e+dHfQRAkEZfpcPtnXdYengA4v3d6nlCzAoLv0p3z/Ldh
AFx/yOOls484BMDN9+Jh0m7PC3DoA+mzyXQ4DjTesQCqXyjTwQpo/b78AAeg
7uuLv2Rg8GcAtR2wCnAoBPEFMh2kQe4H2vdNI6b/kGimw0UloAu1AhwqX6oZ
cggg3Nt84NRC128ZBPmnF7pu+3zXH64f7M4L/nDzJ0uwhPHt9Yfbn/v898qP
Qf5w96HzD38Fagzyh/vPAOjcxlB/uP/Rwx8AxOmyuA==
                    "]]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4ts/67L28AQ4OCU8vaDEnOkgss79YZVIgMOe
kskSLFyZDl48TNrtegEOvdPzhJoVCPNV2RqnOgcHOPy7UvFSjTfTgev64gLb
pAAHoKHr3FkzIeoSAhwcQfapZzps+/z3SkUg1D6nTIfijIlva8yh8v6ZDq8D
d8i1akP1h2Y6LHIF6pAJcLA3jdvlGZHpAHM/jD/7iMKGoh/+cH7lSzVDjjv+
cP2/gMpLDvvDzQfb1+8Ptx+kjafIH+6+UwuBFub6w90PNq/HH+4/g7sqbI1X
/eH+R+dXgNS/8XcQiLDcckIsE2IOY4CDeSfQBh6E+2HhDwCQuaLW
                    
                    "]]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYCYpfunOe/D8Y4pKcBgV6Wgypb41TnzTEO1xcX
2HKpZznU2pvG7VoYAxFXznL4phHTf6gXwQfrr0Twe6fnCTVnoOmPRJhf8VLN
kEMnxmH5MW/zTtcsBy6QQq0YB841MlEp+VkOIO0HgPwjChuKMnox+VZbTpTt
i4fyC7McHlaJrHPPjHFY/fGSb1JOlgMDCBTEOCyQ0r+rUoRw7+a575cf6ybM
fx24Q651NUI/2H2bEOZXgty/B2G/NFAZ20eE+9D5YPd9RPgP7P73CP+jhz8A
6EisBw==
                    "]]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4m8aMf2HemMcvvy9UvGyLsthb8lkCZa2GIfK
l2qGHBVZDhUgOifGoSfn+e+ViYT5a2SiUqzdYxyk9e+qsJVmORzzNu90tIhx
AJIJT2uyHFy6gQotofZFZUHUeULtc8hyiN/lycOUHONwfXGBLZdxlsOzC0q3
f+ZB9etkORgAlTfWxjiA3a2Z5QBzP4zffODUQtd5CL7IOveHVWsQ+kMeL519
ZAfC/Bl5Qs0HLiHs3/YZ6LCHCPe9Dtwh1/oY4X6weVcQ/rPacqJs33qE/9H5
YPVLYhw4QQGTneXwsAooMjPG4R/QeLVShPth4Q8Ax0u5yQ==
                    "]]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYCYpfunOe/D8Y4nPse/HhpcKaDKlvjVOfNMQ7X
FxfYckVnOtTam8btWhjjIBhhueVEXKbDN42Y/kO9CD5YfyWC3zs9T6g5A01/
JML8ipdqhhw6MQ59IHU2mQ5cIIVaUP1CmQ4g4QNAPlD39cVfMjD4VltOlO2L
j3EoBPEFMh0eVomsc8+MgbhLNNOBAQQKYhwqQfYIINzbfODUQtdvGQT5rwN3
yLWuRugHu28Twnyw+B6E/dL6d1XYPiLch84Hu+8jwn9g979H+B89/AH14a/u

                    "]]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4m8aMf2HemMcnBKeXlBiznTYWzJZgqUtxmEP
iObKdKh4qWbIkRPj0Ds9T6hZgTB/jUxUirV7jMO/K0AZ3kyHY97mnY4WMQ4P
q0TWubNmOrh05zz/bRnj4AiyTz3TQVr/rgqbJ9Q+p0yH+F2ePEzJUHn/TIdn
F5Ru/8yD6g/NdDAAKm+sjXGwN43b5RmR6QBzP4zffODUQtd5CD5Q18OqNQj9
IY+Xzj6yA2H+DKCzD1xC2L/t898rFQ8R7nsduEOu9THC/WDzriD8Z7XlRNm+
9Qj/o/PB6pfEOAhEWG45IZYJMWdmjAMwVBKe8iDcDwt/ACC/qcc=
                    
                    "]]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{91.504, 195.598}, {90.691, 
                    196.29399999999998`}, {90.691, 194.24299999999997`}, {
                    92.523, 192.89100000000002`}, {89.20700000000001, 
                    190.446}, {85.891, 192.89100000000002`}, {87.723, 
                    194.24299999999997`}, {87.723, 196.29399999999998`}, {
                    86.91000000000001, 195.598}, {86.91000000000001, 
                    194.47}, {84.96900000000001, 196.063}, {87.051, 
                    197.985}, {86.238, 199.10999999999999`}, {
                    92.17199999999998, 199.10999999999999`}, {91.363, 
                    197.985}, {93.44500000000001, 196.063}, {91.504, 
                    194.47}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{86.70700000000001, 
                    194.895}, {86.70700000000001, 195.692}, {87.926, 
                    196.73499999999999`}, {87.926, 194.141}, {86.23, 
                    192.89100000000002`}, {89.20700000000001, 190.7}, {92.184,
                     192.89100000000002`}, {90.488, 194.141}, {90.488, 
                    196.73499999999999`}, {91.703, 195.692}, {91.703, 
                    194.895}, {93.137, 196.075}, {91.09400000000001, 
                    197.95800000000003`}, {91.777, 198.907}, {86.637, 
                    198.907}, {87.32, 197.95800000000003`}, {85.277, 
                    196.075}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{89.20700000000001, 194.009}, {90.723, 
                    192.89100000000002`}, {89.20700000000001, 
                    191.77399999999997`}, {89.148, 191.82100000000003`}, {
                    87.691, 192.89100000000002`}}}]}, {
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{89.20700000000001, 192.02800000000002`}, {89.309,
                     192.098}, {90.203, 192.762}, {90.383, 
                    192.89100000000002`}, {90.203, 193.024}, {89.309, 
                    193.684}, {89.20700000000001, 193.759}, {
                    89.10499999999999, 193.684}, {88.20700000000001, 
                    193.024}, {88.031, 192.89100000000002`}, {
                    88.20700000000001, 192.762}, {89.10499999999999, 
                    192.098}, {89.20700000000001, 192.02800000000002`}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    63.465, 154.24299999999997`}, {63.465, 156.153}, {
                    59.839999999999996`, 153.85200000000003`}, {
                    58.382999999999996`, 154.97299999999998`}, {
                    56.882999999999996`, 154.80200000000002`}, {
                    56.160000000000004`, 153.782}, {57.452999999999996`, 
                    152.79399999999998`}, {56.160000000000004`, 151.805}, {
                    56.882999999999996`, 150.782}, {58.382999999999996`, 
                    150.60999999999999`}, {59.839999999999996`, 151.731}, {
                    63.465, 149.43}, {63.465, 151.345}, {61.184, 
                    152.79399999999998`}}}]}, {
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    59.828, 153.602}, {63.26200000000001, 155.786}, {
                    63.26200000000001, 154.35200000000003`}, {60.805, 
                    152.79399999999998`}, {63.26200000000001, 151.231}, {
                    63.26200000000001, 149.798}, {59.828, 
                    151.98100000000002`}, {58.324, 150.82100000000003`}, {
                    56.996, 150.97299999999998`}, {56.438, 151.762}, {
                    57.785000000000004`, 152.79399999999998`}, {56.438, 
                    153.82100000000003`}, {56.996, 154.60999999999999`}, {
                    58.324, 154.762}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    63.465, 160.88700000000003`}, {63.465, 162.798}, {
                    59.839999999999996`, 160.497}, {58.382999999999996`, 
                    161.618}, {56.882999999999996`, 161.446}, {
                    56.160000000000004`, 160.42700000000002`}, {
                    57.452999999999996`, 159.43800000000002`}, {
                    56.160000000000004`, 158.45000000000002`}, {
                    56.882999999999996`, 157.43}, {58.382999999999996`, 
                    157.255}, {59.839999999999996`, 158.38000000000002`}, {
                    63.465, 156.075}, {63.465, 157.989}, {61.184, 
                    159.43800000000002`}}}]}, {
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    59.828, 160.251}, {63.26200000000001, 162.43}, {
                    63.26200000000001, 160.997}, {60.805, 
                    159.43800000000002`}, {63.26200000000001, 157.876}, {
                    63.26200000000001, 156.442}, {59.828, 158.626}, {58.324, 
                    157.466}, {56.996, 157.618}, {56.438, 158.407}, {
                    57.785000000000004`, 159.43800000000002`}, {56.438, 
                    160.47}, {56.996, 161.255}, {58.324, 161.411}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    63.465, 144.696}, {63.465, 142.786}, {59.839999999999996`,
                     145.08700000000002`}, {58.382999999999996`, 143.966}, {
                    56.882999999999996`, 144.137}, {56.160000000000004`, 
                    145.157}, {57.452999999999996`, 146.14499999999998`}, {
                    56.160000000000004`, 147.137}, {56.882999999999996`, 
                    148.157}, {58.382999999999996`, 148.329}, {
                    59.839999999999996`, 147.208}, {63.465, 149.509}, {63.465,
                     147.598}, {61.184, 146.14499999999998`}}}]}, {
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    59.828, 145.33700000000002`}, {63.26200000000001, 
                    143.153}, {63.26200000000001, 144.58700000000002`}, {
                    60.805, 146.14899999999997`}, {63.26200000000001, 
                    147.708}, {63.26200000000001, 149.141}, {59.828, 
                    146.95800000000003`}, {58.324, 148.118}, {56.996, 
                    147.966}, {56.438, 147.177}, {57.785000000000004`, 
                    146.14899999999997`}, {56.438, 145.118}, {56.996, 
                    144.329}, {58.324, 144.177}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    114.94900000000001`, 154.24299999999997`}, {
                    114.94900000000001`, 156.153}, {118.574, 
                    153.85200000000003`}, {120.031, 154.97299999999998`}, {
                    121.531, 154.80200000000002`}, {122.254, 153.782}, {
                    120.96100000000001`, 152.79399999999998`}, {122.254, 
                    151.805}, {121.531, 150.782}, {120.031, 
                    150.60999999999999`}, {118.574, 151.731}, {
                    114.94900000000001`, 149.43}, {114.94900000000001`, 
                    151.345}, {117.23, 152.79399999999998`}}}]}, {
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    118.586, 153.602}, {115.15199999999999`, 155.786}, {
                    115.15199999999999`, 154.35200000000003`}, {117.609, 
                    152.79399999999998`}, {115.15199999999999`, 151.231}, {
                    115.15199999999999`, 149.798}, {118.586, 
                    151.98100000000002`}, {120.09, 150.82100000000003`}, {
                    121.418, 150.97299999999998`}, {121.977, 151.762}, {
                    120.62499999999999`, 152.79399999999998`}, {121.977, 
                    153.82100000000003`}, {121.418, 154.60999999999999`}, {
                    120.09, 154.762}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    114.94900000000001`, 160.88700000000003`}, {
                    114.94900000000001`, 162.798}, {118.574, 160.497}, {
                    120.031, 161.618}, {121.531, 161.446}, {122.254, 
                    160.42700000000002`}, {120.96100000000001`, 
                    159.43800000000002`}, {122.254, 158.45000000000002`}, {
                    121.531, 157.43}, {120.031, 157.255}, {118.574, 
                    158.38000000000002`}, {114.94900000000001`, 156.075}, {
                    114.94900000000001`, 157.989}, {117.23, 
                    159.43800000000002`}}}]}, {
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    118.586, 160.251}, {115.15199999999999`, 162.43}, {
                    115.15199999999999`, 160.997}, {117.609, 
                    159.43800000000002`}, {115.15199999999999`, 157.876}, {
                    115.15199999999999`, 156.442}, {118.586, 158.626}, {
                    120.09, 157.466}, {121.418, 157.618}, {121.977, 
                    158.407}, {120.62499999999999`, 159.43800000000002`}, {
                    121.977, 160.47}, {121.418, 161.255}, {120.09, 
                    161.411}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    114.94900000000001`, 144.696}, {114.94900000000001`, 
                    142.786}, {118.574, 145.08700000000002`}, {120.031, 
                    143.966}, {121.531, 144.137}, {122.254, 145.157}, {
                    120.96100000000001`, 146.14499999999998`}, {122.254, 
                    147.137}, {121.531, 148.157}, {120.031, 148.329}, {
                    118.574, 147.208}, {114.94900000000001`, 149.509}, {
                    114.94900000000001`, 147.598}, {117.23, 
                    146.14499999999998`}}}]}, {
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    118.586, 145.33700000000002`}, {115.15199999999999`, 
                    143.153}, {115.15199999999999`, 144.58700000000002`}, {
                    117.609, 146.14899999999997`}, {115.15199999999999`, 
                    147.708}, {115.15199999999999`, 149.141}, {118.586, 
                    146.95800000000003`}, {120.09, 148.118}, {121.418, 
                    147.966}, {121.977, 147.177}, {120.62499999999999`, 
                    146.14899999999997`}, {121.977, 145.118}, {121.418, 
                    144.329}, {120.09, 144.177}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{107.016, 
                    172.934}, {107.016, 170.17299999999997`}, {109.027, 
                    170.17299999999997`}, {109.027, 168.95000000000002`}, {
                    111., 168.95000000000002`}, {111., 171.17299999999997`}, {
                    109.238, 171.17299999999997`}, {109.238, 172.934}}}]}, {
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{109.039, 
                    172.731}, {109.039, 170.97299999999998`}, {
                    110.79700000000001`, 170.97299999999998`}, {
                    110.79700000000001`, 169.153}, {109.227, 169.153}, {
                    109.227, 170.372}, {107.21900000000001`, 170.372}, {
                    107.21900000000001`, 172.731}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    112.94100000000002`, 168.575}, {112.94100000000002`, 
                    165.813}, {114.94900000000001`, 165.813}, {
                    114.94900000000001`, 164.591}, {116.926, 164.591}, {
                    116.926, 166.817}, {115.164, 166.817}, {115.164, 
                    168.575}}}]}, {
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{114.965, 
                    168.376}, {114.965, 166.61399999999998`}, {116.723, 
                    166.61399999999998`}, {116.723, 164.79399999999998`}, {
                    115.15199999999999`, 164.79399999999998`}, {
                    115.15199999999999`, 166.016}, {113.145, 166.016}, {
                    113.145, 168.376}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{71.398, 
                    172.934}, {71.398, 170.17299999999997`}, {69.387, 
                    170.17299999999997`}, {69.387, 168.95000000000002`}, {
                    67.41400000000002, 168.95000000000002`}, {
                    67.41400000000002, 171.17299999999997`}, {
                    69.17599999999999, 171.17299999999997`}, {
                    69.17599999999999, 172.934}}}]}, {
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    69.37499999999999, 172.731}, {69.37499999999999, 
                    170.97299999999998`}, {67.617, 170.97299999999998`}, {
                    67.617, 169.153}, {69.18799999999999, 169.153}, {
                    69.18799999999999, 170.372}, {71.195, 170.372}, {71.195, 
                    172.731}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{107.016, 
                    132.64899999999997`}, {107.016, 135.415}, {109.027, 
                    135.415}, {109.027, 136.634}, {111., 136.634}, {111., 
                    134.411}, {109.238, 134.411}, {109.238, 
                    132.64899999999997`}}}]}, {
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{109.039, 
                    132.85200000000003`}, {109.039, 134.61399999999998`}, {
                    110.79700000000001`, 134.61399999999998`}, {
                    110.79700000000001`, 136.43}, {109.227, 136.43}, {109.227,
                     135.212}, {107.21900000000001`, 135.212}, {
                    107.21900000000001`, 132.85200000000003`}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{71.398, 
                    132.64899999999997`}, {71.398, 135.415}, {69.387, 
                    135.415}, {69.387, 136.634}, {67.41400000000002, 
                    136.634}, {67.41400000000002, 134.411}, {
                    69.17599999999999, 134.411}, {69.17599999999999, 
                    132.64899999999997`}}}]}, {
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    69.37899999999999, 132.85200000000003`}, {
                    69.37899999999999, 134.61399999999998`}, {67.617, 
                    134.61399999999998`}, {67.617, 136.43}, {
                    69.18799999999999, 136.43}, {69.18799999999999, 
                    135.212}, {71.195, 135.212}, {71.195, 
                    132.85200000000003`}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    112.94100000000002`, 137.009}, {112.94100000000002`, 
                    139.76999999999998`}, {114.94900000000001`, 
                    139.76999999999998`}, {114.94900000000001`, 140.993}, {
                    116.926, 140.993}, {116.926, 138.76999999999998`}, {
                    115.164, 138.76999999999998`}, {115.164, 137.009}}}]}, {
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{114.965, 
                    137.212}, {114.965, 138.97}, {116.723, 138.97}, {116.723, 
                    140.79}, {115.15199999999999`, 140.79}, {
                    115.15199999999999`, 139.571}, {113.145, 139.571}, {
                    113.145, 137.212}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{65.473, 
                    168.575}, {65.473, 165.813}, {63.465, 165.813}, {63.465, 
                    164.591}, {61.488, 164.591}, {61.488, 166.817}, {63.25, 
                    166.817}, {63.25, 168.575}}}]}, {
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{63.449, 
                    168.376}, {63.449, 166.61399999999998`}, {61.691, 
                    166.61399999999998`}, {61.691, 164.79399999999998`}, {
                    63.26200000000001, 164.79399999999998`}, {
                    63.26200000000001, 166.016}, {65.27, 166.016}, {65.27, 
                    168.376}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{65.473, 
                    137.009}, {65.473, 139.76999999999998`}, {63.465, 
                    139.76999999999998`}, {63.465, 140.993}, {61.488, 
                    140.993}, {61.488, 138.76999999999998`}, {63.25, 
                    138.76999999999998`}, {63.25, 137.009}}}]}, {
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    63.452999999999996`, 137.212}, {63.452999999999996`, 
                    138.97}, {61.691, 138.97}, {61.691, 140.79}, {
                    63.26200000000001, 140.79}, {63.26200000000001, 
                    139.571}, {65.27, 139.571}, {65.27, 137.212}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4odVIuvcNSMcKl+qGXIsSHWQ1r+rwqYI5S9J
dXh6Qen2z2PhDue/Bz9eeh6T78nDpN2eFu5wfXGBLddiTL5Ld87z3xvDHZoP
nFroWpfqcAmovW5XuMMCKaBFVakOe0smS7D4hTssP+Zt3uma6rBGJirF+j2C
D3NfD9CYlYmpDqpsjVOdkyPg8n5JAhGWLJFwvuWWE2X7pkfAzT8OFHZcEAG3
f9Pc98uPvY6Auw+drwIyvzsC7r+LIPdmRUDU7U91cAb5xzPCYRqIsR7hPlj4
AQCthJsa
                    "]]}, {
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYCYrnW14E7joU7CERYbjlxLNVBHsQ/F+4gCOIf
SnV4WCWyzl0zwuH64gJbrumE+UDdcq3NEXD9YH53BNx8VbbGqc6TIxycEp5e
UDqc6tA7PU+o+QJUflmqg7T+XRW2mxEOX/5eqXi5KNXhuLd5pyNQXm/T3PfL
56U6ZEx8W2PfGuGwQAqosAqT75cENOlJhMM05+6c595Q8zMQfJh7dUHmZaU6
gIR/vwyHy+8tmSzBkofgZ4LMPxsONx+d7wLS3xgOdx/Y/MpwuPtr7U3jdjWG
w/23RiYqxXp/ONz/6OEPAFeYtek=
                    "]]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4syJb2vsfcMcKl+qGXIsSHVY6Lrt818XKH9J
qkPsLk8eptehDue/Bz9eeh6Tf1Hp9s+6rlCH64sLbLkWY/KbD5xa6HotFELX
pTrIt74O3HEv1GGBlP5dlapUBy6QwqJQh+XHvM07XVMdVNkapzoLh8H5MPf1
5Dz/vTIx1WGNTFSKdTtCHkQ5aoTD+Zvnvl9+bHcY3Hy/JIEIyyNhcPsZQEAg
HO4+dH5xBtDC9WFw/4Hd2xfmsAlk7v5Uh70lkyVY8sIcpjl35zxfj3AfLPwA
brqWLQ==
                    "]]}, {
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4thdnjxMr0MdBCIst5w4luoQD+J/DnUQBPEP
pTpkTnxbY+8b5nB9cYEt13TC/OIMoMDyMLh+qy0nyvatD4Obv0YmKsV6e5iD
U8LTC0qHUx1u/6zL2vMFKr8s1WGR67bPf/+EOXz5e6Xi5aJUB5F17g+rgPJ6
m+a+Xz4v1eFhFVBkZZjDAin9uypVmPze6XlCzRzhDtOcu3Oee0P194TB+TD3
6oLMy0p12FsyWYKFDyHvAqR+TwyF88HmfwxFtQ+JD9a/LBTuPoO7KmyNc0Ph
7v+mEdN/aGko3H+qbI1TnR+Hwv2PHv4Az+G4JA==
                    "]]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4odVIuvcC0McKl+qGXIsSHXY9vnvlYpKKH9J
qsPrwB1yrZdDHM5/D3689Dwmv13s5rnvxqEO1xcX2HItxuT3Ts8Tan4R4tB8
4NRC17pUBwYQeBDisEBK/65KVaoD0PaHVT6hDsuPeZt3uqY6qLA1TnVeHQLn
w9zXk/P898rEVIc1MlEp1uYIebC504Lh/BlA6w4wIcznBjnkVzDcfvlWoA/W
BcPdh84Hm8+P8B/YvQYhDpvmvl9+bH+qQ8jjpbOPBIQ4THPuznm+HuE+WPgB
AHmtmBI=
                    "]]}, {
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4k1z3y8/djnEQSDCcsuJY6kOYP7pEAdBEP9Q
qsPDKpF17oUhDtcXF9hyTSfMf3pB6fZPMYT+ZyA+H8L8NTJRKdbsIQ5OCUCV
h1MdnLtznv8+GQyRX5bqsO3z3ysVB4MdvgCpl4tSHbhABp8KdtADOWxeqoP+
XRW2RtEQhwVSQFYVJr/5wKmFrtuCHaaBDPZOdXABmW8YAufD3KsLMi8r1aF3
ep5Q8waEPFD2YZVOKJyfOfFtjf1ZhPnofLB+iVC4+8DmK4bC3R/yeOnsI0B5
mP9U2RqnOt9G+B89/AH5hbwF
                    "]]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4odVIuvcNSMcdDfNfb98UoKDtP5dFTbFCAfB
CMstJ/oSHJ5eULr981i4w/XFBbZcyZh8Tx4m7fa0cAeQ9mP9mHyX7pznvzeG
O6z6eMk3aUuCwyWg9rpd4Q690/OEmnckOOwtmSzB4hfuAHbH2wSHNTJRKdbv
EXyY+8DuupjgoMrWONU5OQIu75ckEGHJEgnnA11dtm96BNz8497mnY4LIuD2
g931OgLuPnS+Csj87gi4/y6C3JsV4fDl75WKl0UJDs4g/3hCw6cJ4T5Y+AEA
1rqfLA==
                    "]]}, {
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYCYrnW14E7joU7VL5UM+TISXCQB/HPhTtMc+7O
eZ6f4PCwSmSdu2aEw+a575cfm02YD9Qt19ocAdcP5ndHwM1XZWuc6jw5wuEN
SBwo3zs9T6j5AlR9d4KDtP5dFbabEQ6bQOb1Jzgc9zbvdLwA1T8lwSFj4tsa
+9YIiL4dmHy/JIEIyycRDkByy4lnUPMzEHyYe8HmnUhwAFn7+2U4XH5vyWQJ
ljwEPxNk/tlwuPnofBeQ/sZwuPvA5leGw91fa28at6sxHO6/NTJRKdb7w+H+
Rw9/AICQthA=
                    "]]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4syJb2vsfcMcdDfNfb98UoLDQtdtn/+6hDkI
RlhuOdGX4BC7y5OH6XWow/XFBbZcyZj8i0q3f9Z1hTqAtB/rx+Q3Hzi10PVa
qMOqj5d8k7YkOMi3vg7ccS/UoXd6nlDzjgQHLpBBRaEOD6tE1rm/TXBQZWuc
6iwcBufD3Cetf1eF7WKCwxqZqBTrdoT8MW/zTkeNcDh/M8je3WFw8/2SBCIs
j4TB7WcAAYFwuPvQ+cUZQAvXh8H9B3ZvX5jDl79XKl4WJTjsLZkswZIHDZ8m
hPtg4QcAl/CaPw==
                    "]]}, {
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4thdnjxMr0MdKl+qGXLkJDjEg/ifQx2mOXfn
PM9PcMic+LbG3jfMYfPc98uPzSbML84ACiwPg+u32nKibN/6MLj5a2SiUqy3
hzm8Cdwh1wqUv/2zLmvPF6j67gSHRa7bPv/9E+awCWRef4KDyDr3h1VfoPqn
JDg8rAKKrAxz6J2eJ9S8A5MPpjnCHQQiLLeceAbV3xMG58PcCzbvRILD3pLJ
Eix8CHkXoDN+TwyF88HmfwxFtQ+JD9a/LBTuPoO7KmyNc0Ph7v+mEdN/aGko
3H+qbI1TnR+Hwv2PHv4A+Nm4Sw==
                    "]]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4odVIuvcC0McdDfNfb98UoLDts9/r1RUhjgI
RlhuOdGX4PA6cIdc6+UQh+uLC2y5kjH57WI3z303DnUAaT/Wj8nvnZ4n1Pwi
xGHVx0u+SVsSHBhA4EEIRHxHggPQ9odVPqEOYHe8TXBQYWuc6rw6BM6HuU9a
/64K28UEhzUyUSnW5gj55gOnFrpOC4bzZwCNPcCEMJ8b5NBfwXD75VuBPlgX
DHcfOh9sPj/Cf2D3GoQ4fAEGy8uiBIeQx0tnHwmAhk8Twn2w8AMAouOcJA==

                    "]]}, {
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4k1z3y8/djnEofKlmiFHToIDmH86xGGac3fO
8/wEh4dVIuvcC0McNoPEZxPmP72gdPunGEL/MxCfD2H+GpmoFGv2EIc3gTvk
WoHyIGW/TwZD1HcnOGz7/PdKxcFgiDv6Exy4ri8usD0VDNE/JcFB/64KW6No
iEPv9Dyh5h2Y/OYDpxa6bgt2EIiw3HLiWYKDC8h8wxA4H+ZesHknEiD6NiDk
gbIPq3RC4fzMiW9r7M8izEfng2mJULj7wOYrhsLdH/J46ewjQHmY/1TZGqc6
30b4Hz38ASKMvCw=
                    "]]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{69.18799999999999, 
                    170.372}, {69.18799999999999, 166.016}, {
                    63.26200000000001, 166.016}, {63.26200000000001, 
                    139.571}, {69.18799999999999, 139.571}, {
                    69.18799999999999, 135.212}, {109.227, 135.212}, {109.227,
                     139.571}, {115.15199999999999`, 139.571}, {
                    115.15199999999999`, 166.016}, {109.227, 166.016}, {
                    109.227, 170.372}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{109.027, 
                    170.17299999999997`}, {109.027, 165.813}, {
                    114.94900000000001`, 165.813}, {114.94900000000001`, 
                    139.76999999999998`}, {109.027, 139.76999999999998`}, {
                    109.027, 135.415}, {69.387, 135.415}, {69.387, 
                    139.76999999999998`}, {63.465, 139.76999999999998`}, {
                    63.465, 165.813}, {69.387, 165.813}, {69.387, 
                    170.17299999999997`}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{106.46100000000001`, 
                    168.497}, {71.94900000000001, 168.497}, {
                    71.94900000000001, 163.251}, {65.137, 163.251}, {65.137, 
                    142.333}, {71.94900000000001, 142.333}, {
                    71.94900000000001, 137.08700000000002`}, {
                    106.46100000000001`, 137.08700000000002`}, {
                    106.46100000000001`, 142.333}, {113.277, 142.333}, {
                    113.277, 163.251}, {106.46100000000001`, 163.251}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{106.262, 168.298}, {
                    106.262, 163.048}, {113.074, 163.048}, {113.074, 
                    142.536}, {106.262, 142.536}, {106.262, 137.29}, {
                    72.15199999999999, 137.29}, {72.15199999999999, 
                    142.536}, {65.34, 142.536}, {65.34, 163.048}, {
                    72.15199999999999, 163.048}, {72.15199999999999, 
                    168.298}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{65.137, 
                    146.317}, {77.633, 137.08700000000002`}, {100.781, 
                    137.08700000000002`}, {113.277, 146.317}, {113.277, 
                    159.26999999999998`}, {100.781, 168.497}, {77.633, 
                    168.497}, {65.137, 159.26999999999998`}}}]}, {
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{100.715, 
                    168.298}, {100.766, 168.259}, {112.992, 159.227}, {
                    113.074, 159.165}, {113.074, 146.41899999999998`}, {
                    112.992, 146.35600000000002`}, {100.766, 137.329}, {
                    100.715, 137.29}, {77.699, 137.29}, {77.648, 137.329}, {
                    65.422, 146.35600000000002`}, {65.34, 
                    146.41899999999998`}, {65.34, 159.165}, {65.422, 
                    159.227}, {77.648, 168.259}, {77.699, 168.298}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{103.195, 
                    165.684}, {75.117, 165.684}, {75.117, 163.454}, {71.531, 
                    163.454}, {71.531, 142.13}, {75.117, 142.13}, {75.117, 
                    139.899}, {103.29700000000001`, 139.899}, {
                    103.29700000000001`, 142.13}, {106.883, 142.13}, {106.883,
                     163.454}, {103.29700000000001`, 163.454}, {
                    103.29700000000001`, 165.684}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{103.09400000000001`, 
                    165.48100000000002`}, {103.09400000000001`, 163.255}, {
                    106.67999999999999`, 163.255}, {106.67999999999999`, 
                    142.329}, {103.09400000000001`, 142.329}, {
                    103.09400000000001`, 140.102}, {75.32, 140.102}, {75.32, 
                    142.329}, {71.73400000000001, 142.329}, {
                    71.73400000000001, 163.255}, {75.32, 163.255}, {75.32, 
                    165.48100000000002`}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{72.406, 
                    145.02800000000002`}, {78.516, 139.899}, {99.898, 
                    139.899}, {106.008, 145.02800000000002`}, {106.008, 
                    160.555}, {99.898, 165.684}, {78.516, 165.684}, {72.406, 
                    160.555}}}]}, {
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{99.824, 
                    165.48100000000002`}, {99.883, 165.43800000000002`}, {
                    105.73400000000001`, 160.52}, {105.80499999999999`, 
                    160.46200000000002`}, {105.80499999999999`, 145.122}, {
                    105.73400000000001`, 145.063}, {99.883, 
                    140.14899999999997`}, {99.824, 140.102}, {78.59, 
                    140.102}, {78.531, 140.14899999999997`}, {
                    72.67999999999999, 145.063}, {72.609, 145.122}, {72.609, 
                    160.46200000000002`}, {72.67999999999999, 160.52}, {
                    78.531, 165.43800000000002`}, {78.59, 
                    165.48100000000002`}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{73.473, 
                    145.52800000000002`}, {78.902, 140.966}, {99.512, 
                    140.966}, {104.938, 145.52800000000002`}, {104.938, 
                    160.059}, {99.512, 164.618}, {78.902, 164.618}, {73.473, 
                    160.059}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{99.438, 
                    164.415}, {99.492, 164.36800000000002`}, {104.664, 
                    160.024}, {104.738, 159.96200000000002`}, {104.738, 
                    145.622}, {104.664, 145.559}, {99.492, 
                    141.21599999999998`}, {99.438, 141.16899999999998`}, {
                    78.977, 141.16899999999998`}, {78.922, 
                    141.21599999999998`}, {73.74600000000001, 145.559}, {
                    73.67599999999999, 145.622}, {73.67599999999999, 
                    159.96200000000002`}, {73.74600000000001, 160.024}, {
                    78.922, 164.36800000000002`}, {78.977, 164.415}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{81.363, 
                    165.48100000000002`}, {97.051, 165.48100000000002`}, {
                    97.051, 166.30200000000002`}, {95.398, 
                    167.72299999999998`}, {93.85199999999999, 
                    166.38700000000003`}, {92.30499999999999, 
                    167.72299999999998`}, {90.754, 166.38700000000003`}, {
                    89.20700000000001, 167.72299999999998`}, {87.66, 
                    166.38700000000003`}, {86.109, 167.72299999999998`}, {
                    84.562, 166.38700000000003`}, {83.016, 
                    167.72299999999998`}, {81.363, 166.30200000000002`}}}]}, {
                   
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{96.848, 165.684}, {93.953, 165.684}, {93.953, 
                    166.208}, {95.398, 167.454}, {96.848, 166.208}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{93.75, 165.684}, {90.85499999999999, 165.684}, {
                    90.85499999999999, 166.208}, {92.30499999999999, 
                    167.454}, {93.75, 166.208}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{90.65199999999999, 165.684}, {87.758, 165.684}, {
                    87.758, 166.208}, {89.20700000000001, 167.454}, {
                    90.65199999999999, 166.208}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{87.559, 165.684}, {84.664, 165.684}, {84.664, 
                    166.208}, {86.109, 167.454}, {87.559, 166.208}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{84.46100000000001, 165.684}, {81.566, 165.684}, {
                    81.566, 166.208}, {83.016, 167.454}, {84.46100000000001, 
                    166.208}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{66.863, 
                    149.696}, {68.195, 148.14899999999997`}, {66.863, 
                    146.598}, {68.281, 144.95000000000002`}, {
                    71.73400000000001, 144.95000000000002`}, {
                    71.73400000000001, 160.634}, {68.281, 160.634}, {66.863, 
                    158.985}, {68.195, 157.43800000000002`}, {66.863, 
                    155.88700000000003`}, {68.195, 154.341}, {66.863, 
                    152.79399999999998`}, {68.195, 151.24299999999997`}}}]}, {
                   
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{68.37499999999999, 145.153}, {67.12899999999999, 
                    146.598}, {68.37499999999999, 148.048}, {71.531, 
                    148.048}, {71.531, 145.153}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{68.37499999999999, 148.24699999999999`}, {
                    67.12899999999999, 149.696}, {68.37499999999999, 
                    151.141}, {71.531, 151.141}, {71.531, 
                    148.24699999999999`}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{68.37499999999999, 151.345}, {67.12899999999999, 
                    152.79399999999998`}, {68.37499999999999, 
                    154.23899999999998`}, {71.531, 154.23899999999998`}, {
                    71.531, 151.345}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{68.37499999999999, 154.442}, {67.12899999999999, 
                    155.88700000000003`}, {68.37499999999999, 
                    157.33700000000002`}, {71.531, 157.33700000000002`}, {
                    71.531, 154.442}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{68.37499999999999, 157.54}, {67.12899999999999, 
                    158.985}, {68.37499999999999, 160.43}, {71.531, 160.43}, {
                    71.531, 157.54}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{81.363, 
                    140.102}, {97.051, 140.102}, {97.051, 139.282}, {95.398, 
                    137.86}, {93.85199999999999, 139.196}, {92.30499999999999,
                     137.86}, {90.754, 139.196}, {89.20700000000001, 
                    137.86}, {87.66, 139.196}, {86.109, 137.86}, {84.562, 
                    139.196}, {83.016, 137.86}, {81.363, 139.282}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{96.848, 139.899}, {93.953, 139.899}, {93.953, 
                    139.376}, {95.398, 138.13}, {96.848, 139.376}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{93.75, 139.899}, {90.85499999999999, 139.899}, {
                    90.85499999999999, 139.376}, {92.30499999999999, 
                    138.13}, {93.75, 139.376}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{90.65199999999999, 139.899}, {87.758, 139.899}, {
                    87.758, 139.376}, {89.20700000000001, 138.13}, {
                    90.65199999999999, 139.376}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{87.559, 139.899}, {84.664, 139.899}, {84.664, 
                    139.376}, {86.109, 138.13}, {87.559, 139.376}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{84.46100000000001, 139.899}, {81.566, 139.899}, {
                    81.566, 139.376}, {83.016, 138.13}, {84.46100000000001, 
                    139.376}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{111.551, 
                    149.696}, {110.21900000000001`, 148.14899999999997`}, {
                    111.551, 146.598}, {110.133, 144.95000000000002`}, {
                    106.67999999999999`, 144.95000000000002`}, {
                    106.67999999999999`, 160.634}, {110.133, 160.634}, {
                    111.551, 158.985}, {110.21900000000001`, 
                    157.43800000000002`}, {111.551, 155.88700000000003`}, {
                    110.21900000000001`, 154.341}, {111.551, 
                    152.79399999999998`}, {110.21900000000001`, 
                    151.24299999999997`}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{110.039, 145.153}, {111.285, 146.598}, {110.039, 
                    148.048}, {106.883, 148.048}, {106.883, 145.153}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{110.039, 148.24699999999999`}, {111.285, 
                    149.696}, {110.039, 151.141}, {106.883, 151.141}, {
                    106.883, 148.24699999999999`}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{110.039, 151.345}, {111.285, 
                    152.79399999999998`}, {110.039, 154.23899999999998`}, {
                    106.883, 154.23899999999998`}, {106.883, 151.345}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{110.039, 154.442}, {111.285, 
                    155.88700000000003`}, {110.039, 157.33700000000002`}, {
                    106.883, 157.33700000000002`}, {106.883, 154.442}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{110.039, 157.54}, {111.285, 158.985}, {110.039, 
                    160.43}, {106.883, 160.43}, {106.883, 157.54}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{82.031, 
                    141.16899999999998`}, {83.191, 142.286}, {
                    84.35199999999999, 141.16899999999998`}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    83.191, 144.622}, {82.05499999999999, 
                    145.52800000000002`}, {80.922, 145.04}, {80.715, 
                    143.74299999999997`}, {81.79700000000001, 142.79}, {80.02,
                     141.071}, {82.223, 141.071}, {83.191, 142.005}, {
                    84.15599999999999, 141.071}, {86.363, 141.071}, {84.586, 
                    142.79}, {85.664, 143.74299999999997`}, {
                    85.46100000000001, 145.04}, {84.324, 
                    145.52800000000002`}}}]}, {
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{81.10199999999999, 144.895}, {82.023, 
                    145.29399999999998`}, {83.191, 144.364}, {83.254, 
                    144.415}, {84.35499999999999, 145.29399999999998`}, {
                    85.277, 144.895}, {85.44900000000001, 
                    143.82100000000003`}, {84.285, 142.798}, {85.973, 
                    141.16899999999998`}, {84.35199999999999, 
                    141.16899999999998`}, {83.191, 142.286}, {82.031, 
                    141.16899999999998`}, {80.406, 141.16899999999998`}, {
                    82.09400000000001, 142.798}, {80.93400000000001, 
                    143.82100000000003`}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    88.04700000000001, 141.16899999999998`}, {
                    89.20700000000001, 142.286}, {90.367, 
                    141.16899999999998`}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    89.20700000000001, 144.622}, {88.074, 
                    145.52800000000002`}, {86.938, 145.04}, {
                    86.73400000000001, 143.74299999999997`}, {87.812, 
                    142.79}, {86.035, 141.071}, {88.238, 141.071}, {
                    89.20700000000001, 142.005}, {90.17599999999999, 
                    141.071}, {92.37899999999999, 141.071}, {
                    90.60199999999999, 142.79}, {91.684, 
                    143.74299999999997`}, {91.477, 145.04}, {90.34, 
                    145.52800000000002`}}}]}, {
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{87.121, 144.895}, {88.043, 
                    145.29399999999998`}, {89.20700000000001, 144.364}, {
                    89.27, 144.415}, {90.371, 145.29399999999998`}, {91.293, 
                    144.895}, {91.465, 143.82100000000003`}, {
                    90.30499999999999, 142.798}, {91.988, 
                    141.16899999999998`}, {90.367, 141.16899999999998`}, {
                    89.20700000000001, 142.286}, {88.04700000000001, 
                    141.16899999999998`}, {86.426, 141.16899999999998`}, {
                    88.109, 142.798}, {86.94900000000001, 
                    143.82100000000003`}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{96.383, 
                    141.16899999999998`}, {95.223, 142.286}, {94.062, 
                    141.16899999999998`}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    95.223, 144.622}, {96.359, 145.52800000000002`}, {
                    97.49600000000001, 145.04}, {97.699, 
                    143.74299999999997`}, {96.617, 142.79}, {98.398, 
                    141.071}, {96.191, 141.071}, {95.223, 142.005}, {94.258, 
                    141.071}, {92.051, 141.071}, {93.82799999999999, 
                    142.79}, {92.75, 143.74299999999997`}, {92.953, 145.04}, {
                    94.09, 145.52800000000002`}}}]}, {
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{97.312, 144.895}, {96.391, 
                    145.29399999999998`}, {95.223, 144.364}, {95.16, 
                    144.415}, {94.059, 145.29399999999998`}, {93.137, 
                    144.895}, {92.96900000000001, 143.82100000000003`}, {
                    94.12899999999999, 142.798}, {92.44100000000002, 
                    141.16899999999998`}, {94.062, 141.16899999999998`}, {
                    95.223, 142.286}, {96.383, 141.16899999999998`}, {98.008, 
                    141.16899999999998`}, {96.32, 142.798}, {97.48, 
                    143.82100000000003`}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{82.031, 
                    164.415}, {83.191, 163.298}, {84.35199999999999, 
                    164.415}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    83.191, 160.96200000000002`}, {82.05499999999999, 
                    160.055}, {80.922, 160.548}, {80.715, 161.841}, {
                    81.79700000000001, 162.79399999999998`}, {79.98, 
                    164.548}, {82.184, 164.548}, {83.191, 
                    163.57899999999998`}, {84.195, 164.548}, {86.402, 
                    164.548}, {84.586, 162.79399999999998`}, {85.664, 
                    161.841}, {85.46100000000001, 160.548}, {84.324, 
                    160.055}}}]}, {
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{81.10199999999999, 160.68800000000002`}, {82.023,
                     160.29}, {83.191, 161.22}, {83.254, 
                    161.16899999999998`}, {84.35499999999999, 160.29}, {
                    85.277, 160.68800000000002`}, {85.44900000000001, 
                    161.762}, {84.285, 162.786}, {85.973, 164.415}, {
                    84.35199999999999, 164.415}, {83.191, 163.298}, {82.031, 
                    164.415}, {80.406, 164.415}, {82.09400000000001, 
                    162.786}, {80.93400000000001, 161.762}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    88.04700000000001, 164.415}, {89.20700000000001, 
                    163.298}, {90.367, 164.415}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    89.20700000000001, 160.96200000000002`}, {88.074, 
                    160.055}, {86.938, 160.548}, {86.73400000000001, 
                    161.841}, {87.812, 162.79399999999998`}, {
                    85.99600000000001, 164.548}, {88.203, 164.548}, {
                    89.20700000000001, 163.57899999999998`}, {90.215, 
                    164.548}, {92.418, 164.548}, {90.60199999999999, 
                    162.79399999999998`}, {91.684, 161.841}, {91.477, 
                    160.548}, {90.34, 160.055}}}]}, {
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{87.121, 160.68800000000002`}, {88.043, 160.29}, {
                    89.20700000000001, 161.22}, {89.27, 
                    161.16899999999998`}, {90.371, 160.29}, {91.293, 
                    160.68800000000002`}, {91.465, 161.762}, {
                    90.30499999999999, 162.786}, {91.988, 164.415}, {90.367, 
                    164.415}, {89.20700000000001, 163.298}, {
                    88.04700000000001, 164.415}, {86.426, 164.415}, {88.109, 
                    162.786}, {86.94900000000001, 161.762}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{96.383, 
                    164.415}, {95.223, 163.298}, {94.062, 164.415}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    95.223, 160.96200000000002`}, {96.359, 160.055}, {
                    97.49600000000001, 160.548}, {97.699, 161.841}, {96.617, 
                    162.79399999999998`}, {98.43400000000001, 164.548}, {
                    96.23, 164.548}, {95.223, 163.57899999999998`}, {
                    94.21900000000001, 164.548}, {92.016, 164.548}, {
                    93.82799999999999, 162.79399999999998`}, {92.75, 
                    161.841}, {92.953, 160.548}, {94.09, 160.055}}}]}, {
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{97.312, 160.68800000000002`}, {96.391, 160.29}, {
                    95.223, 161.22}, {95.16, 161.16899999999998`}, {94.059, 
                    160.29}, {93.137, 160.68800000000002`}, {
                    92.96900000000001, 161.762}, {94.12899999999999, 
                    162.786}, {92.44100000000002, 164.415}, {94.062, 
                    164.415}, {95.223, 163.298}, {96.383, 164.415}, {98.008, 
                    164.415}, {96.32, 162.786}, {97.48, 161.762}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    104.738, 158.567}, {104.738, 157.048}, {
                    104.73400000000001`, 157.048}, {103.816, 157.805}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4oWu2z7/vRLpcPPc9+DHd5MdvmnE9B86G+nw
70rFS7WHyQ6WW06U7Zse6bDimLd5509MPli9a6TDqo+XfJO+JDtkTHxbY68a
6eDJw6Tdfg2Tv0YmKsU6PBKib2+yw7MLSrd/xkH5OxHyYPdsReiX1r+rwjYX
kw+zX5WtcapzPcJ9C6SACqow+TD/gd0zKdkB5n+w+FSovGkUxP5cBN8x4ekF
peXJDr3T84SaOaLg7oXJ94HEzyD454Hal/5PdvAC2aMX5SAYAXQJU4pDyOOl
s48IRDmkgcC3ZIcZQG0HPkHd9wrhHlh8AACwN8WQ
                    "]]}, {
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4jUyUSnW+lEOC6T076pcSnbwSxKIsPwS6fBN
I6b/0M5kB5j8EYUNRRkLEXxpoHK2ymQHkXXuD6uuRDqkpwHBPEy+5ZYTZfum
RzoIRgBZTckOrwN3yLVOjnSw6HRMeNqQ7NB84NRC175Ih4dVQJ2NyQ6b5r5f
fiw40sEcJN+SDHGHL1S+NdlBha1xqrN3pMO578GPl7YnQ9xhGenQOz1PqHlG
skPGxLc19qaRDtOcu3Oez052UAWpt450+PL3SsVLoHvA5hQi/IfOh+nfCHLH
dYT5TglPLyjdRthf+VLNkOMNwn1g/75DuB/s33cI/4Gk0z4h/A+W/4QIH3B4
fECEH9hdVzH5sPDXBVn0K9kBAPEyyhI=
                    "]]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    104.738, 153.555}, {104.738, 152.032}, {
                    104.73400000000001`, 152.032}, {103.816, 152.79}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4oWu2z7/vRLpcERhQ1GGbbLDN42Y/kNnIx0K
bbmuL3ZIdrDccqJs3/RIB2n9uypskZh8sHrXSIdpzt05z4OTHTImvq2xV410
2FsyWYLFDJO/RiYqxTo80uFhlcg6d9lkh2cXlG7/jIPyJRHyYPeIIvSD3fMn
CYMPs18wAuiye0lw9/XkPP+98iYmH+a/PSD3fEpygPkfbP/XJIenIPeYRTmY
dzomPD2D4C+QAnk42aF3ep5QM0cU3L0w+T6QuA6CD7YnNdmh+cCpha5iUQ72
pnG7PCOg4fU10uHL3ysVL72SHdDDHwCGkrqO
                    "]]}, {
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGI5IGYC4jUyUSnW+lEO3zRi+g8ZJjv4JQlEWH6JdHhY
JbLOXTLZASYvrX9XhY0Rwe+dnifUfCPJAajqYdWVSIeb574HP/6LybfccqJs
3/RIh+YDpxa6PkpyeB24Q651cqTDqo+XfJMeJEHE+yIdQh4vnX0EyN809/3y
Y8FQ+SdJEHf5RjoEg+SBfBW2xqnO3pEOjglPLyg9T4K4yzLSofKlmiHHjySH
jIlva+xNIx04QQ79neSgClJvHengxcOk3f4vCeKvQoT/CPFh+u1N43Z5miTD
zQeLmyfD7dcFOdwqGe6+NyB/eifD3Q8OD99kuP/A/vZLhvsfLB+YDA8fsHhQ
Mjz8wOERkAwPX3B4mGDyYfGzQArosKhkBwC57tdw
                    "]]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    104.738, 147.016}, {104.738, 148.536}, {
                    104.73400000000001`, 148.536}, {103.816, 147.778}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4oWu2z7/vRLpEPx46ewjIUkO3zRi+g+djXRY
cczbvDMwycFyy4myfdMjHf5dqXipZonJB6t3jXRoPnBqoatdkkPGxLc19qqR
DrH9h75qxGDy18hEpViHRzpI699VYStNcnh2Qen2z7hIB/NOx4SnFQj5EJB7
ahD6u3Oe/145FZMPs58DpHEzwn0FtlzXF+/A5MP8FwNyz4IkB5j/wfbPSXJ4
CnKPWZTDwyqRde5HEXyw+3uSHHqn5wk1c0TB3QuTB7snFcG/vhhoozHUf3pR
Due/A0NYPwnib8Eoh8qXaoYcNkkO8bs8eZg+Rzqs+njJN8kD4R5YfAAAHKjI
7g==
                    "]]}, {
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4jUyUSnW+lEOvdPzhJoTkhz8kgQiLL9EOph3
OiY8rUhygMk/rBJZ5z4Rwe/Jef575c4kB6Dow6orkQ6rPl7yTZqCybfccqJs
3/RIh2nO3TnP1yc5vA7cIdc6OdLhm0ZM/6GNSQ7NB04tdO2LdFhxzNu8E8jf
NPf98mPBUPm1SRDaN9LhiMKGogwgX4Wtcaqzd6TD9cUFtlyrkxyk9e+qsFlG
OiyQAjJmJTlkTHxbY28a6QD0xZYT05IcVEHqrSMh5k5OgvijEOE/dD5MP9j8
aIT5574HP14ajrBfF2SgG8J99qZxuzxdEO4H+9cZ4T+wvAPC/2B5e0T4gM1x
RIQf2L+xmHxY+Fe+VDPksEhyAAAQD8ZG
                    "]]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    73.67999999999999, 158.567}, {73.67999999999999, 
                    157.048}, {74.598, 157.805}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYCYv27KmyNR4Mcbp77Hvz4brLD7Z91WXvOBDn8
u1LxUu1hssOMPKHmA0zBDiuOeZt3/sTkL3Td9vlvSLDDqo+XfJO+JDtkTHxb
Y18a7ODJw6Tdfg2T/zpwh1yrc7DDN42Y/kN7kx3egPjWUP5OhDzYPVsR+qVB
Dp2LyYfZr8rWONW5HuG+BVJABVWYfJj/wO6ZlOwA8z/Y/qlQ+RRoeOQi+I4J
Ty8oLU92cOnOef57YhDcvTD5vulAi84g+ODwYEhxUAG5KzvI4friAlsu5hQH
oGuvVHQGOehumvt++bdkh2KQh5YHObQcOLXQ9RXCPbD4AAA628bg
                    
                    "]]}, {
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4teBO+Ras4McFkjp31W5lOzQfODUQtdlQQ7f
NGL6D+1MdoDJH1HYUJSxEMGXBipnq0x22FsyWYLlWJBDehoQzMPkx+/y5GFi
DnYQjLDccqIp2eHpBaXbP9mCHSw6HROeNiQ7+CUJRFjyBDs8rBJZ594IlXcL
djAHybckO9z+WZe1xwcq35rssEYmKsXaP9jh3Pfgx0vbkx22ff57pSIx2KF3
ep5Q84xkh4yJb2vsU4Mdpjl35zyfDVUfH+zwBajsJdA9YHM0g+H+Q+fD9G+c
+375sesI850SQC5D2F/5Us2Q4w3CfWD/vkO4H+zfdwj/gaTTPiH8D5b/hAgf
cHh8QIQf2F1XMfmw8NfdBHTgr2QHAFQuzOI=
                    "]]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    73.67999999999999, 153.555}, {73.67999999999999, 
                    152.032}, {74.598, 152.79}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYCYv27KmyNR4McjihsKMqwTXa4/bMua8+ZIIdC
W67rix2SHWbkCTUfYAp2kAYpjMTkL3Td9vlvSLDDNOfunOfByQ4ZE9/W2JcG
O+wtmSzBYobJfx24Q67VOdjhYZXIOnfZZIc3IL41lC+JkAe7RxShH+yeP0kY
fJj9ghGWW07cS4K7ryfn+e+VNzH5MP/tAbnnU5IDzP9g+78mOQDJh1Up0PA4
i+B78jBpt7MlO7gAvfl7YhDcvTD52P5DXzV0klH1p0LDpyXIofKlmiFHBNQ/
S4McdDfNfb/cK9kBPfwBsn+wQQ==
                    "]]}, {
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGI5IGYC4teBO+Ras4McvmnE9B8yTHZoPnBqoeuyIIeH
VSLr3CWTHWDy0vp3VdgYEfze6XlCzTeSHPaWTJZgORbkcPPc9+DHfzH58bs8
eZiYgyHmPkpyeHpB6fZPtmCHVR8v+SY9SHLwSxKIsOQJdgh5vHT2kQdQeTeo
/JMkh9s/67L2+AQ7BIPkgfw1MlEp1v7BDo4JQJXPkxy2ff57pSIx2KHypZoh
x48kh4yJb2vsU4MdOEEKf0PVxwc7ePEwabf/S4L4SzMY7j9CfJh+e9O4XZ4m
yXDzVdkapzqbJ8Pt19009/1yq2S4+96Awsk7Ge5+cHj4JsP9Bw4Pv2S4/8Hy
gcnw8AHLByXDww8cHgHJ8PAFh4cJJh8WPwukgBEWlewAAIKx2k0=
                    
                    "]]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    73.67999999999999, 147.016}, {73.67999999999999, 
                    148.536}, {74.598, 147.778}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYCYv27KmyNR4Mcgh8vnX0kJMnh9s+6rD1nghxW
HPM27wxMcpiRJ9R8gCnY4d+Vipdqlpj8ha7bPv8NCXZoPnBqoatdkkPGxLc1
9qXBDrH9h75qxGDyXwfukGt1DnaQBllcmuTwBsS3DnYw73RMeFqBkA8BuacG
ob875/nvlVMx+TD7OdbIRKVsRrivwJbr+uIdmHyY/2JA7lmQ5ADzP9j+OUkO
IuvcH1alQPlHEPzz34Eh1J3k4AKyeGIQ3L0w+QVSQJPSEHzdTXPfLzdKcgBR
x7KDILR+kgPQtVcqOoMg4WGT5FAM8tDyIIfe6UCHeiDcA4sPAMpDxDI=
                    
                    "]]}, {
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4teBO+Ras4MceqfnCTUnJDk0Hzi10HVZkIN5
p2PC04okB5j8wyqRde4TEfyenOe/V+5McthbMlmC5ViQw6qPl3yTpmDy43d5
8jAxBztMc+7Oeb4+yeHpBaXbP9mCHb5pxPQf2pjk4JckEGHJE+yw4pi3eedG
qLwbVH5tksPtn3VZe3yCHY4obCjKAPLXyESlWPsHO1xfXGDLtTrJYdvnv1cq
EoMdFkjp31WZleSQMfFtjX1qsAPQ1C0npkHVxwc7bJr7fvmxyUkQf2gGw/2H
zofpB5sfjTD/3Pfgx0vDEfbrggx0Q7jP3jRul6cLwv1g/zoj/AeWd0D4Hyxv
jwgfsH8dEeEH9m8sJh8W/pUv1Qw5LJIcAHL8yRY=
                    "]]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIRIGYCYk8eJu32aeEOXiB6VZIDjL9p7vvlxx4nOci1
vg7cYRaBwf/y90rFS79kuHp0vr1p3C7PjmSHGXlCzQeUMPnXFxfYch1PdrDc
cqJsX3koBh+mvl3s5rnvzJh8mH1gdyWHYPBh7oWpR+fD/AuzD51//nvw46XZ
SXD3ovNh6gHRGpUg
                    "]]}, {
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{84.262, 154.266}, {84.262, 156.055}, {86.074, 
                    156.055}, {86.074, 158.016}, {89.10499999999999, 
                    158.016}, {89.10499999999999, 155.993}, {86.238, 
                    154.364}, {86.238, 152.89100000000002`}, {81.762, 
                    152.89100000000002`}, {81.762, 154.266}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{94.15199999999999, 151.32100000000003`}, {
                    94.15199999999999, 149.52800000000002`}, {92.34, 
                    149.52800000000002`}, {92.34, 147.567}, {89.309, 
                    147.567}, {89.309, 149.591}, {92.17599999999999, 
                    151.22}, {92.17599999999999, 152.692}, {96.65199999999999,
                     152.692}, {96.65199999999999, 151.32100000000003`}}}]}, {
                   
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{94.15199999999999, 156.055}, {94.15199999999999, 
                    154.266}, {96.65199999999999, 154.266}, {
                    96.65199999999999, 152.89100000000002`}, {
                    92.17599999999999, 152.89100000000002`}, {
                    92.17599999999999, 154.364}, {89.309, 155.993}, {89.309, 
                    158.016}, {92.34, 158.016}, {92.34, 156.055}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{86.074, 149.52800000000002`}, {84.262, 
                    149.52800000000002`}, {84.262, 151.32100000000003`}, {
                    81.762, 151.32100000000003`}, {81.762, 152.692}, {86.238, 
                    152.692}, {86.238, 151.22}, {89.10499999999999, 
                    149.591}, {89.10499999999999, 147.567}, {86.074, 
                    147.567}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    86.44100000000002, 152.692}, {86.44100000000002, 
                    151.329}, {89.10499999999999, 149.813}, {
                    89.10499999999999, 152.692}}}]}, {
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    89.10499999999999, 155.76999999999998`}, {
                    86.44100000000002, 154.259}, {86.44100000000002, 
                    152.895}, {89.10499999999999, 152.895}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    91.973, 152.895}, {91.973, 154.259}, {89.309, 
                    155.76999999999998`}, {89.309, 152.895}}}]}, {
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    89.309, 149.813}, {91.973, 151.329}, {91.973, 152.692}, {
                    89.309, 152.692}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxlk1soRFEUhseMJCkltyRFiKR48CBhF5qkCXPmOIw5o8SDEh7klmia5EGS
JEoUkhSe5FYkJHmQpDRJroUkSUhM2WfrX2XOqf3wtfblX//6T1xNk7XOZDAY
/PjK5cvI12bLcJR/bimbfJnbLy5RGdhem31Z8lzFVt+8p+0ei47zMp0bRQt2
djhVuPKWVqxj7/zriSVaof2+fN0ZtmT2yPSeLws9bTY2MNoY6g6UiQ3adyWz
h29+4bv0V2+XmSZvYFViiQGukfxdiTj9IiHANSExTV7wjcS6NKEpMnFBf8P9
97qN7b4nOwattr/zbitxX4Tn6NMtsbOZ5pwgs8Sylg9at0Zl4vqh5648Sznr
eEzKCFyW2BiXs21UqF4UbEzti6gkXojhTkba6X6h/0ohtt3Oju81K6Rvmtvp
/akgFufPKqg/oT9OIT6JP//q3ignf0R9SCH/wpfM150Oh47h/weXsbOo6hjz
eypbi+01VesY88d+X0Z+8J4vI3//9HJGP8KXY5X6FX6GOMkPMPzSxth/p5Kf
YPgtDG1RaR5gzKtO87PHSfMEY95iXqFOygPqyAsYecL9yBsYeYQ+5BWMPKM/
5B2M/wH+/PtfuH+/A1q+Rg==
                    "]]}, {
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGI7IGYC4pDHS2cfWRDrMO/98mPe86Mc5FpfB+74Foed
rx7ugKIeid984NRC12ehDsUZE9/W+Mdg8B1M43Z5toQ4ePEwabf3hcP5D6tE
1rkvDHN48Xvlx0tfgyHycuEOh75qxPSvCnbIBGq3vxsB59faAzVKRjpcX1xg
y/U+2MFqy4myff3hcP43oLJDT8MdFDcUZUx0DXGQ1r+rwvYzEpUvGOlQ+VLN
kCMk2METZB9bOJwPts83zEHs5rnvwYeDHdpBjMmhcPltn/9eqegMRuUvDIKb
f/tnXdaeLSFw/vQ8oeYDXKFw94HDqyEYzgfbtzcY7j+wuTWhcD44fH6GwsOn
AiTPEwoPv9hdQB94B2DwYeH/C+icks++GHxY/KVY3/fvdffGzgfGP4p6JP4O
UMJ4EA23D53/B+hcX6dYuHthfJh/wOFwIRbuXzAtEwcPDxgfFl5gd12PhYcn
jA8Lb3C8NsbC4wOFD4yvw6DwLIqDxyeMjxLfzHHw9ACTh6UXFD4wPcHMh6U3
GB+WHmHug6VXGB+WnmH+g6V3GB+WH2DhA8svsPCD5Sd0Piz8YfkRxgcAsCzF
DA==
                    "]]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4syJb2vsfcMcdsi1vg7UCHFw6c55/ntnuMPr
QKAIc6jDcW/zTscL0Rj8qBTr+/6pYQ7bPv+9UqEYi8H35GHSbl8W7lCcAbSg
PA6DD7ZPIQquHp3/sEpknXtiNNw+dH5A7/Q8ocMxcPfC+DD/NB84tdB1XqwD
SLj5QQhcnuv64gLbUwEYfJj5pnG7PHk++WHwYe7bUzJZgsXNB4MP8x9MPTof
Fj4w+9D5sPCFuRfGBwBbbLNz
                    "]]}, {
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYCYlW2xqnOh6Md/qz8eMm3KMwBxt8h1/o6UCDU
wZOHSbt9WzicnznxbY29b5jDvPfLj3mbhzi0i9089/1xCFz+6QWl2z+vBWDw
Yea/CQTKcPtj8EHGBG8Od2AAgQQf7HzhKFT1SHwH07hdniHRcPvQ+c0HTi10
3RYDdy+Mj+Kf/li4f2HysPBA58PMv/2zLmuPSCwGH+a+i0ogkTjsfKD/UNQj
8WHhAwAvx8Mv
                    "]]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4syJb2vsfcMcdNrFbp7rD3HY9vnvlYqF4Q4O
pnG7PGNCHYozgArKozH469wfVonsC3MIebx09pETMRj8ee+XH/P+H+4g3/o6
cIdcHHb+8UhU9Uj8+qw9JZM5ouH2ofP/rPx4yTcrBu5eGB/mH4EIyy0nzGId
pPXvqrD9DIHLx+/y5GFSDsTgw8z/VQdkLPbH4MPcl2J937/3uw92PtB/KOqR
+LDwgdmHzoeFL8y9MD4Agr3JpQ==
                    "]]}, {
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4otKt3/WZUU7+PdOzxM6HeYA40vr31Vhywx1
2FsyWYJlXjicnznxbY29b5iDYITllhPzQhxE17k/rPoTApdnAAGDQAw+zHyg
aWF8e/0x+BUv1Qw5eCIcVhzzNu8U9MXgH/6qEdO/KxKuHp3/JnCHXOvvKLh9
6HzFDUUZE2Nj4O6F8WH+0WoXu3lOPRbuX5g8LDzQ+TDzK0Hu3BODwYe5r9be
NG6XYBwGH+Y/mHp0Pix8AIvmoTA=
                    "]]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    70.738, 93.11}, {70.738, 87.759}, {79.09400000000001, 
                    87.759}, {70.738, 93.30199999999999}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    70.94100000000002, 92.923}, {78.422, 87.962}, {
                    70.94100000000002, 87.962}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4jUyUSnWy8MdpPXvqrAlhjvA+J8u+SYJCEQ4
vA7cIdeajeBnTnxbY+8b5hDQOz1P6HCEQ429adwuzzCHkMdLZx85EOHw7ILS
7Z96oXD1qmyNU50/h2DwYfZt+/z3SoUnJh/oivv+S8Pg6tH5zQdOLXT9Fgq3
D8aHuU/s5rnvwc6hcPfD5GH+Q+fDzAe7IzACgw9zHwAveoMP
                    "]]}, {
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1,
                     0}}}, {{{89.20700000000001, 98.809}, {93.29700000000001, 
                    96.251}, {85.117, 96.251}}, {{93.29700000000001, 
                    87.848}, {89.20700000000001, 85.29}, {85.117, 
                    87.848}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    94.41000000000001, 90.583}, {94.41000000000001, 
                    88.05199999999999}, {89.309, 88.05199999999999}, {89.309, 
                    90.583}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    89.10499999999999, 90.583}, {89.10499999999999, 
                    88.05199999999999}, {84.004, 88.05199999999999}, {84.004, 
                    90.583}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    97.062, 93.31700000000001}, {97.062, 90.786}, {
                    91.96100000000001, 90.786}, {91.96100000000001, 
                    93.31700000000001}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    91.758, 93.31700000000001}, {91.758, 90.786}, {
                    86.65599999999999, 90.786}, {86.65599999999999, 
                    93.31700000000001}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    86.453, 93.31700000000001}, {86.453, 90.786}, {
                    81.35199999999999, 90.786}, {81.35199999999999, 
                    93.31700000000001}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    94.41000000000001, 96.048}, {94.41000000000001, 93.516}, {
                    89.309, 93.516}, {89.309, 96.048}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    89.10499999999999, 96.048}, {89.10499999999999, 93.516}, {
                    84.004, 93.516}, {84.004, 96.048}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4odVIuvcI0McwLRjpAOMv0Ou9XXgh0gHg7sq
bI2yCP4amagU6/9BDgG90/OEFkc5VL5UM+T4E+QgrQ9UuDAKQj8MhKsHcRuX
YvJh9skDhXfIYfKBttz3b42Aq0fne/IwabdfC4fbB+PD3AcypVU5HO5+mDzM
f+h8mPl7SyZLsKiFYvBh7gMAHJ14OA==
                    "]]}, {
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1,
                     0}}}, {{{75.988, 106.309}, {80.082, 103.755}, {71.898, 
                    103.755}}, {{80.07799999999999, 95.35199999999999}, {
                    75.988, 92.79400000000001}, {71.898, 
                    95.35199999999999}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    81.191, 98.083}, {81.191, 95.55199999999999}, {76.09, 
                    95.55199999999999}, {76.09, 98.083}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    75.887, 98.083}, {75.887, 95.55199999999999}, {70.785, 
                    95.55199999999999}, {70.785, 98.083}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    84.395, 100.81700000000001`}, {84.395, 98.286}, {79.293, 
                    98.286}, {79.293, 100.81700000000001`}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    79.09, 100.81700000000001`}, {79.09, 98.286}, {73.988, 
                    98.286}, {73.988, 100.81700000000001`}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    73.785, 100.81700000000001`}, {73.785, 98.286}, {68.684, 
                    98.286}, {68.684, 100.81700000000001`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    81.191, 103.55199999999999`}, {81.191, 101.02}, {76.09, 
                    101.02}, {76.09, 103.55199999999999`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    75.887, 103.55199999999999`}, {75.887, 101.02}, {70.785, 
                    101.02}, {70.785, 103.55199999999999`}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4odVIuvcHSMcIHSkA4y/Q671deCHSIdFrts+
/61B8FXZGqc6z450COidnie0OMrBi4dJu31epIO0/l0VtoVRDkDVVyp2RsHV
LwTp/4LJh9m3ee775ceqozH4USnW9/1bI+Dq0fmeIHuvhcPtg/Fh7nsdCLRR
ORzufpg8zH/ofJj5QN7DqpJwDD7MfQD7y4xs
                    "]]}, {
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1,
                     0}}}, {{{102.426, 106.309}, {98.332, 103.755}, {106.516, 
                    103.755}}, {{98.336, 95.35199999999999}, {102.426, 
                    92.79400000000001}, {106.516, 95.35199999999999}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    97.223, 98.083}, {97.223, 95.55199999999999}, {102.324, 
                    95.55199999999999}, {102.324, 98.083}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    102.527, 98.083}, {102.527, 95.55199999999999}, {
                    107.62899999999999`, 95.55199999999999}, {
                    107.62899999999999`, 98.083}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    94.02, 100.81700000000001`}, {94.02, 98.286}, {99.121, 
                    98.286}, {99.121, 100.81700000000001`}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    99.324, 100.81700000000001`}, {99.324, 98.286}, {104.426, 
                    98.286}, {104.426, 100.81700000000001`}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    104.62899999999999`, 100.81700000000001`}, {
                    104.62899999999999`, 98.286}, {109.73, 98.286}, {109.73, 
                    100.81700000000001`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    97.223, 103.55199999999999`}, {97.223, 101.02}, {102.324, 
                    101.02}, {102.324, 103.55199999999999`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    102.527, 103.55199999999999`}, {102.527, 101.02}, {
                    107.62899999999999`, 101.02}, {107.62899999999999`, 
                    103.55199999999999`}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4jUyUSnWy8MdFDcUZUxMjXKA8T15mLTbt0U6
vA7cIdeajeBnTnxbY+8bBhFnjnSosTeN2+UZ5vDi98qPl1gjHZ5dULr9Uy8U
rl6VrXGq8+cQDD7Mvm2f/16p8MTkP6wSWeeuGA1Xj84H2v468EI03D4YH+Y+
sZvnvgc3x8DdD5OH+Q+dDzNfWv+uCltgBAYf5j4Ayk2BGA==
                    "]]}, {
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1,
                     0}}}, {{{89.20700000000001, 100.29400000000001`}, {
                    93.29700000000001, 102.85199999999999`}, {85.117, 
                    102.85199999999999`}}, {{93.29700000000001, 111.255}, {
                    89.20700000000001, 113.813}, {85.117, 111.255}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    94.41000000000001, 108.52}, {94.41000000000001, 
                    111.05199999999999`}, {89.309, 111.05199999999999`}, {
                    89.309, 108.52}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    89.10499999999999, 108.52}, {89.10499999999999, 
                    111.05199999999999`}, {84.004, 111.05199999999999`}, {
                    84.004, 108.52}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    97.062, 105.79}, {97.062, 108.321}, {91.96100000000001, 
                    108.321}, {91.96100000000001, 105.79}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    91.758, 105.79}, {91.758, 108.321}, {86.65599999999999, 
                    108.321}, {86.65599999999999, 105.79}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    86.453, 105.79}, {86.453, 108.321}, {81.35199999999999, 
                    108.321}, {81.35199999999999, 105.79}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    94.41000000000001, 103.05499999999999`}, {
                    94.41000000000001, 105.587}, {89.309, 105.587}, {89.309, 
                    103.05499999999999`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    89.10499999999999, 103.05499999999999`}, {
                    89.10499999999999, 105.587}, {84.004, 105.587}, {84.004, 
                    103.05499999999999`}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    70.738, 105.99300000000001`}, {70.738, 111.345}, {
                    79.09400000000001, 111.345}, {70.738, 
                    105.80499999999999`}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}}}, {{{
                    70.94100000000002, 106.17999999999999`}, {71.23, 
                    106.37599999999999`}, {77.91000000000001, 
                    110.80499999999999`}, {78.422, 111.141}, {
                    70.94100000000002, 111.141}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    107.67599999999999`, 93.11}, {107.67599999999999`, 
                    87.759}, {99.32, 87.759}, {107.67599999999999`, 
                    93.30199999999999}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}}}, {{{107.473, 
                    92.923}, {107.184, 92.73100000000001}, {100.504, 
                    88.298}, {99.992, 87.962}, {107.473, 87.962}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    107.67599999999999`, 105.99300000000001`}, {
                    107.67599999999999`, 111.345}, {99.32, 111.345}, {
                    107.67599999999999`, 105.80499999999999`}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}}}, {{{107.473, 
                    106.17999999999999`}, {107.184, 106.37599999999999`}, {
                    100.504, 110.80499999999999`}, {99.992, 111.141}, {
                    107.473, 111.141}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    72.37899999999999, 100.255}, {72.37899999999999, 
                    98.848}, {70.09, 98.848}, {70.09, 100.255}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    70.30499999999999, 100.04}, {72.16399999999999, 100.04}, {
                    72.16399999999999, 99.063}, {70.30499999999999, 
                    99.063}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    74.48400000000001, 102.989}, {74.48400000000001, 
                    101.583}, {72.191, 101.583}, {72.191, 102.989}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    72.406, 102.774}, {74.265, 102.774}, {74.265, 101.797}, {
                    72.406, 101.797}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    79.785, 102.989}, {79.785, 101.583}, {77.49600000000001, 
                    101.583}, {77.49600000000001, 102.989}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    77.71100000000001, 102.774}, {79.57000000000001, 
                    102.774}, {79.57000000000001, 101.797}, {
                    77.71100000000001, 101.797}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    77.684, 100.255}, {77.684, 98.848}, {75.395, 98.848}, {
                    75.395, 100.255}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    75.609, 100.04}, {77.46799999999999, 100.04}, {
                    77.46799999999999, 99.063}, {75.609, 99.063}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    82.988, 100.255}, {82.988, 98.848}, {80.695, 98.848}, {
                    80.695, 100.255}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    80.91400000000002, 100.04}, {82.77300000000001, 100.04}, {
                    82.77300000000001, 99.063}, {80.91400000000002, 
                    99.063}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    79.785, 97.52}, {79.785, 96.114}, {77.49600000000001, 
                    96.114}, {77.49600000000001, 97.52}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    77.71100000000001, 97.30499999999999}, {79.57000000000001,
                     97.30499999999999}, {79.57000000000001, 96.332}, {
                    77.71100000000001, 96.332}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    74.48400000000001, 97.52}, {74.48400000000001, 96.114}, {
                    72.191, 96.114}, {72.191, 97.52}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    72.406, 97.30499999999999}, {74.265, 97.30499999999999}, {
                    74.265, 96.332}, {72.406, 96.332}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    87.699, 110.489}, {87.699, 109.083}, {85.41000000000001, 
                    109.083}, {85.41000000000001, 110.489}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    85.62499999999999, 110.274}, {87.48399999999998, 
                    110.274}, {87.48399999999998, 109.301}, {
                    85.62499999999999, 109.301}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    93.004, 110.489}, {93.004, 109.083}, {90.715, 109.083}, {
                    90.715, 110.489}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    90.93, 110.274}, {92.789, 110.274}, {92.789, 109.301}, {
                    90.93, 109.301}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    85.051, 107.759}, {85.051, 106.35199999999999`}, {82.758, 
                    106.35199999999999`}, {82.758, 107.759}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    82.973, 107.54}, {84.832, 107.54}, {84.832, 
                    106.56700000000001`}, {82.973, 106.56700000000001`}}}]}, {
                   
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    90.35199999999999, 107.759}, {90.35199999999999, 
                    106.35199999999999`}, {88.062, 106.35199999999999`}, {
                    88.062, 107.759}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    88.277, 107.54}, {90.136, 107.54}, {90.136, 
                    106.56700000000001`}, {88.277, 106.56700000000001`}}}]}, {
                   
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    95.65599999999999, 107.759}, {95.65599999999999, 
                    106.35199999999999`}, {93.363, 106.35199999999999`}, {
                    93.363, 107.759}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    93.582, 107.54}, {95.44099999999999, 107.54}, {
                    95.44099999999999, 106.56700000000001`}, {93.582, 
                    106.56700000000001`}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    87.699, 105.024}, {87.699, 103.618}, {85.41000000000001, 
                    103.618}, {85.41000000000001, 105.024}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    85.62499999999999, 104.809}, {87.48399999999998, 
                    104.809}, {87.48399999999998, 103.832}, {
                    85.62499999999999, 103.832}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    93.004, 105.024}, {93.004, 103.618}, {90.715, 103.618}, {
                    90.715, 105.024}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    90.93, 104.809}, {92.789, 104.809}, {92.789, 103.832}, {
                    90.93, 103.832}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    100.918, 102.989}, {100.918, 101.583}, {98.62899999999999,
                     101.583}, {98.62899999999999, 102.989}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    98.84400000000001, 102.774}, {100.703, 102.774}, {100.703,
                     101.797}, {98.84400000000001, 101.797}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    106.223, 102.989}, {106.223, 101.583}, {103.93, 
                    101.583}, {103.93, 102.989}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    104.148, 102.774}, {106.00699999999999`, 102.774}, {
                    106.00699999999999`, 101.797}, {104.148, 101.797}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    97.71900000000001, 100.255}, {97.71900000000001, 
                    98.848}, {95.426, 98.848}, {95.426, 100.255}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    95.641, 100.04}, {97.5, 100.04}, {97.5, 99.063}, {95.641, 
                    99.063}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    103.02, 100.255}, {103.02, 98.848}, {100.73, 98.848}, {
                    100.73, 100.255}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    100.94500000000001`, 100.04}, {102.804, 100.04}, {102.804,
                     99.063}, {100.94500000000001`, 99.063}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    108.324, 100.255}, {108.324, 98.848}, {106.035, 98.848}, {
                    106.035, 100.255}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    106.25, 100.04}, {108.109, 100.04}, {108.109, 99.063}, {
                    106.25, 99.063}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    100.918, 97.52}, {100.918, 96.114}, {98.62899999999999, 
                    96.114}, {98.62899999999999, 97.52}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    98.84400000000001, 97.30499999999999}, {100.703, 
                    97.30499999999999}, {100.703, 96.332}, {98.84400000000001,
                     96.332}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    106.223, 97.52}, {106.223, 96.114}, {103.93, 96.114}, {
                    103.93, 97.52}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    104.148, 97.30499999999999}, {106.00699999999999`, 
                    97.30499999999999}, {106.00699999999999`, 96.332}, {
                    104.148, 96.332}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    87.699, 95.485}, {87.699, 94.079}, {85.41000000000001, 
                    94.079}, {85.41000000000001, 95.485}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    85.62499999999999, 95.27}, {87.48399999999998, 95.27}, {
                    87.48399999999998, 94.297}, {85.62499999999999, 
                    94.297}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    93.004, 95.485}, {93.004, 94.079}, {90.715, 94.079}, {
                    90.715, 95.485}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    90.93, 95.27}, {92.789, 95.27}, {92.789, 94.297}, {90.93, 
                    94.297}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    85.051, 92.755}, {85.051, 91.348}, {82.758, 91.348}, {
                    82.758, 92.755}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    82.973, 92.536}, {84.832, 92.536}, {84.832, 91.563}, {
                    82.973, 91.563}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    90.35199999999999, 92.755}, {90.35199999999999, 91.348}, {
                    88.062, 91.348}, {88.062, 92.755}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    88.277, 92.536}, {90.136, 92.536}, {90.136, 91.563}, {
                    88.277, 91.563}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    95.65599999999999, 92.755}, {95.65599999999999, 91.348}, {
                    93.363, 91.348}, {93.363, 92.755}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    93.582, 92.536}, {95.44099999999999, 92.536}, {
                    95.44099999999999, 91.563}, {93.582, 91.563}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    87.699, 90.02}, {87.699, 88.614}, {85.41000000000001, 
                    88.614}, {85.41000000000001, 90.02}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    85.62499999999999, 89.80499999999999}, {87.48399999999998,
                     89.80499999999999}, {87.48399999999998, 
                    88.82799999999999}, {85.62499999999999, 
                    88.82799999999999}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    93.004, 90.02}, {93.004, 88.614}, {90.715, 88.614}, {
                    90.715, 90.02}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    90.93, 89.80499999999999}, {92.789, 89.80499999999999}, {
                    92.789, 88.82799999999999}, {90.93, 
                    88.82799999999999}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    118.15199999999999`, 40.345}, {98.301, 29.661}, {80.113, 
                    29.661}, {60.26200000000001, 40.345}, {60.26200000000001, 
                    57.946}, {80.113, 68.62599999999999}, {98.301, 
                    68.62599999999999}, {118.15199999999999`, 57.946}}}]}, {
                    FaceForm[{
                    RGBColor[0.15686300000000003`, 0.6823529999999999, 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{98.25, 
                    29.864}, {117.94900000000001`, 40.466}, {
                    117.94900000000001`, 57.825}, {98.25, 68.423}, {80.164, 
                    68.423}, {60.465, 57.825}, {60.465, 40.466}, {80.164, 
                    29.864}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    116.54700000000001`, 41.312999999999995`}, {97.898, 
                    31.278}, {80.516, 31.278}, {61.867, 
                    41.312999999999995`}, {61.867, 56.977}, {80.516, 
                    67.012}, {97.898, 67.012}, {116.54700000000001`, 
                    56.977}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{116.34400000000001`, 41.434}, {
                    116.34400000000001`, 49.044}, {89.309, 49.044}, {89.309, 
                    31.480999999999998`}, {97.848, 31.480999999999998`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{62.07, 49.247}, {89.10499999999999, 49.247}, {
                    89.10499999999999, 66.809}, {80.566, 66.809}, {62.07, 
                    56.855999999999995`}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{80.566, 31.480999999999998`}, {89.10499999999999,
                     31.480999999999998`}, {89.10499999999999, 49.044}, {
                    62.07, 49.044}, {62.07, 41.434}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{116.34400000000001`, 56.855999999999995`}, {
                    97.848, 66.809}, {89.309, 66.809}, {89.309, 49.247}, {
                    116.34400000000001`, 49.247}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGI5IGYC4qcXlG7/LItwWCClf1eFzdUhfpcnD5NyuIPu
prnvl4c5w/n3VNgapzY7Orh05zz/zRjhAOQ5d9s4OBRnTHxbsz0Mg7/O/WGV
yDknh0wg1943zOH64gJbLncniHmPQ+HyMD5Mf+/0PKHmGSGo5pWHwu2H8WHu
UwUpVA6Bu/+bRkz/IdNgDP7Jsn3zpeR94OphfJh51vf9e6ef84Xz/12peKm2
0B/unsqXaoYcJQFw96Lzwf4L94P7V3FDUcbEu37w8IDJw/gw/bDwRDEPGN4w
+2F8mPtg8QVz/+2fdVl7UiIx+DD/AwAX3Mlr
                    "]]}, {
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{97.801, 56.04}, {92.34400000000001, 59.501}, {
                    92.34400000000001, 63.36}, {95.41400000000002, 65.61}, {
                    91.07, 65.61}, {91.07, 60.309}, {89.309, 61.427}, {89.309,
                     49.247}, {101.371, 49.247}, {101.371, 56.04}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{80.609, 42.251}, {86.07, 38.786}, {86.07, 
                    34.927}, {83., 32.67700000000001}, {87.34400000000001, 
                    32.67700000000001}, {87.34400000000001, 37.977}, {
                    89.10499999999999, 36.86}, {89.10499999999999, 49.044}, {
                    77.039, 49.044}, {77.039, 42.251}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{91.07, 32.67700000000001}, {95.41400000000002, 
                    32.67700000000001}, {92.34400000000001, 34.927}, {
                    92.34400000000001, 38.786}, {97.801, 42.251}, {101.371, 
                    42.251}, {101.371, 49.044}, {89.309, 49.044}, {89.309, 
                    36.86}, {91.07, 37.977}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{86.07, 59.501}, {80.609, 56.04}, {77.039, 
                    56.04}, {77.039, 49.247}, {89.10499999999999, 49.247}, {
                    89.10499999999999, 61.43}, {87.34400000000001, 60.309}, {
                    87.34400000000001, 65.61}, {83., 65.61}, {86.07, 
                    63.36}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, {{{97.43400000000001, 54.755}, {100.098, 
                    54.755}, {100.098, 43.532000000000004`}, {
                    97.43400000000001, 43.532000000000004`}, {
                    89.20700000000001, 38.312999999999995`}, {80.98, 
                    43.532000000000004`}, {78.316, 43.532000000000004`}, {
                    78.316, 54.755}, {80.98, 54.755}, {89.20700000000001, 
                    59.973}, {89.262, 59.942}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, {{{97.37499999999999, 54.552}, {
                    89.20700000000001, 59.73500000000001}, {81.039, 54.552}, {
                    78.52, 54.552}, {78.52, 43.73500000000001}, {81.039, 
                    43.73500000000001}, {89.20700000000001, 38.552}, {
                    97.37499999999999, 43.73500000000001}, {99.895, 
                    43.73500000000001}, {99.895, 54.552}, {97.406, 
                    54.552}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIPIGYC4uKMiW9rroc5zJoJBJreDij8k14O7WI3z30X
DsfO5/Ry+A8C5WHY+S+9HbivLy6wvRWOwT//Pfjx0tleDs0HTi10bYvA4C8/
5m3eudHDYUaeUPOBS+HY+YWeDnKtrwN3qEVg8MHm3fZ0eHpB6fbPbeFw/sMq
kXXuK8McDn/ViOmf5AGXB7vP0x2uH50f0Ds9T2izO9x+rPxiD7j70flg8zrd
UMMDie+UAHSJtSs8/LDypd3h4Y+VH+0Gjz+s/N+uEPdWhWPwIf5xc8gEKrf3
DXMwi9vlyaPk4WC15UTZPvlQuDyMDw5PoP54oDKmw5h8mP1AnnZ7GyYfrB7o
/ovA4K9TCsPgw/x/HBitjgdCMPiw8PNLEoiwFMHkw8LfEuTe4zj4wPjbNPf9
8mPFmHxY/KuyNU51fozgg9PPx1B4+oHJw9IXTD86H5Y+YfZj5QPTN8z96HxY
/oD5H50Py1+w8MPKB+ZPWPhj5QPzNyz+sPKB5QMs/tH5pqD0UuQFTz/g8GHy
hKcvmDyMD9MPAIz0HZY=
                    "]]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIPIGYCYrnW14E70kIcpkiwhPGddXeYkSfUfGAXJp+X
SbtdLNLD4WGVyDp3RUx+QO/0PKHFbg6ZE9/W2J/F5LcBrZELdXXQv6vC1iga
hsFfcczbvJPR3QEk3Do5FIMPcqZcqZuD1ZYTZfvOY/JXgtQ/dIW4VwiTDzbv
INQ9vmEOhbZc1xc7eDhYgvS3h8PlYXyY/otKt3/WnQrD4MPsf3oBKMAWjsGH
uX+h67bPf1vCMPgw/0PCJxyDDws/cPhWRmDwYeEP9v/9cAw+LP42zX2//Jhx
BAY/jE9301x9aPhuDofzjwOd6TghzOHwV42Y/kkecHmw/756wvWj8z9d8k0S
iPCE24/OP/89+PHS0x5w96PzweHT6AX3Pzo/HOS+897w8EPn3wMmo6nKXvDw
R+eD/bfeCx5/6HywemdvePxj5Sd7wdNP9p6SyRJPPODpCyaPwgfqh6VPdD7M
flj6RufD3A/LH+h8mP9h+QudDws/WP5E58PCH5a/0fmw+IOVD+h8WPyDw/cZ
gu/cnfP8Nyci/cDkYekLph/GBwDIKwPE
                    "]]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{107.613, 48.255}, {107.613,
                     46.294000000000004`}, {109.992, 46.294000000000004`}, {
                    109.992, 48.255}, {112.35499999999999`, 48.255}, {
                    112.35499999999999`, 42.704}, {109.992, 42.704}, {109.992,
                     44.665000000000006`}, {107.613, 44.665000000000006`}, {
                    107.613, 42.704}, {105.25, 42.704}, {105.25, 48.255}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{99.16, 
                    40.88399999999999}, {99.16, 38.923}, {101.539, 38.923}, {
                    101.539, 40.88399999999999}, {103.902, 
                    40.88399999999999}, {103.902, 35.333}, {101.539, 
                    35.333}, {101.539, 37.294000000000004`}, {99.16, 
                    37.294000000000004`}, {99.16, 35.333}, {96.79700000000001,
                     35.333}, {96.79700000000001, 40.88399999999999}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{107.613, 50.036}, {107.613,
                     51.997}, {109.992, 51.997}, {109.992, 50.036}, {
                    112.35499999999999`, 50.036}, {112.35499999999999`, 
                    55.586999999999996`}, {109.992, 55.586999999999996`}, {
                    109.992, 53.626000000000005`}, {107.613, 
                    53.626000000000005`}, {107.613, 55.586999999999996`}, {
                    105.25, 55.586999999999996`}, {105.25, 50.036}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{70.801, 48.255}, {70.801, 
                    46.294000000000004`}, {68.422, 46.294000000000004`}, {
                    68.422, 48.255}, {66.059, 48.255}, {66.059, 42.704}, {
                    68.422, 42.704}, {68.422, 44.665000000000006`}, {70.801, 
                    44.665000000000006`}, {70.801, 42.704}, {73.164, 
                    42.704}, {73.164, 48.255}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{70.801, 50.036}, {70.801, 
                    51.997}, {68.422, 51.997}, {68.422, 50.036}, {66.059, 
                    50.036}, {66.059, 55.586999999999996`}, {68.422, 
                    55.586999999999996`}, {68.422, 53.626000000000005`}, {
                    70.801, 53.626000000000005`}, {70.801, 
                    55.586999999999996`}, {73.164, 55.586999999999996`}, {
                    73.164, 50.036}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{99.16, 57.403}, {99.16, 
                    59.364}, {101.539, 59.364}, {101.539, 57.403}, {103.902, 
                    57.403}, {103.902, 62.958}, {101.539, 62.958}, {101.539, 
                    60.997}, {99.16, 60.997}, {99.16, 62.958}, {
                    96.79700000000001, 62.958}, {96.79700000000001, 
                    57.403}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{79.254, 
                    40.88399999999999}, {79.254, 38.923}, {76.87499999999999, 
                    38.923}, {76.87499999999999, 40.88399999999999}, {74.512, 
                    40.88399999999999}, {74.512, 35.333}, {76.87499999999999, 
                    35.333}, {76.87499999999999, 37.294000000000004`}, {
                    79.254, 37.294000000000004`}, {79.254, 35.333}, {81.617, 
                    35.333}, {81.617, 40.88399999999999}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{79.254, 57.403}, {79.254, 
                    59.364}, {76.87499999999999, 59.364}, {76.87499999999999, 
                    57.403}, {74.512, 57.403}, {74.512, 62.958}, {
                    76.87499999999999, 62.958}, {76.87499999999999, 60.997}, {
                    79.254, 60.997}, {79.254, 62.958}, {81.617, 62.958}, {
                    81.617, 57.403}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.7921569999999999, 0.21568600000000002`, 
                    0.27058800000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{105.453, 48.052}, {105.453,
                     42.907}, {107.41000000000001`, 42.907}, {
                    107.41000000000001`, 44.864}, {110.195, 44.864}, {110.195,
                     42.907}, {112.15199999999999`, 42.907}, {
                    112.15199999999999`, 48.052}, {110.195, 48.052}, {110.195,
                     46.091}, {107.41000000000001`, 46.091}, {
                    107.41000000000001`, 48.052}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{97., 40.68}, {97., 
                    35.536}, {98.95700000000001, 35.536}, {98.95700000000001, 
                    37.497}, {101.742, 37.497}, {101.742, 35.536}, {103.699, 
                    35.536}, {103.699, 40.68}, {101.742, 40.68}, {101.742, 
                    38.720000000000006`}, {98.95700000000001, 
                    38.720000000000006`}, {98.95700000000001, 40.68}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{105.453, 
                    50.23500000000001}, {105.453, 55.38399999999999}, {
                    107.41000000000001`, 55.38399999999999}, {
                    107.41000000000001`, 53.423}, {110.195, 53.423}, {110.195,
                     55.38399999999999}, {112.15199999999999`, 
                    55.38399999999999}, {112.15199999999999`, 
                    50.23500000000001}, {110.195, 50.23500000000001}, {
                    110.195, 52.196000000000005`}, {107.41000000000001`, 
                    52.196000000000005`}, {107.41000000000001`, 
                    50.23500000000001}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{72.96100000000001, 
                    48.052}, {72.96100000000001, 42.907}, {71.004, 42.907}, {
                    71.004, 44.864}, {68.21900000000001, 44.864}, {
                    68.21900000000001, 42.907}, {66.262, 42.907}, {66.262, 
                    48.052}, {68.21900000000001, 48.052}, {68.21900000000001, 
                    46.091}, {71.004, 46.091}, {71.004, 48.052}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{72.96100000000001, 
                    50.23500000000001}, {72.96100000000001, 
                    55.38399999999999}, {71.004, 55.38399999999999}, {71.004, 
                    53.423}, {68.21900000000001, 53.423}, {68.21900000000001, 
                    55.38399999999999}, {66.262, 55.38399999999999}, {66.262, 
                    50.23500000000001}, {68.21900000000001, 
                    50.23500000000001}, {68.21900000000001, 
                    52.196000000000005`}, {71.004, 52.196000000000005`}, {
                    71.004, 50.23500000000001}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{97., 57.606}, {97., 
                    62.755}, {98.95700000000001, 62.755}, {98.95700000000001, 
                    60.794000000000004`}, {101.742, 60.794000000000004`}, {
                    101.742, 62.755}, {103.699, 62.755}, {103.699, 57.606}, {
                    101.742, 57.606}, {101.742, 59.567}, {98.95700000000001, 
                    59.567}, {98.95700000000001, 57.606}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{81.41400000000002, 
                    40.68}, {81.41400000000002, 35.536}, {79.45700000000001, 
                    35.536}, {79.45700000000001, 37.497}, {76.67199999999998, 
                    37.497}, {76.67199999999998, 35.536}, {74.715, 35.536}, {
                    74.715, 40.68}, {76.67199999999998, 40.68}, {
                    76.67199999999998, 38.720000000000006`}, {
                    79.45700000000001, 38.720000000000006`}, {
                    79.45700000000001, 40.68}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{81.41400000000002, 
                    57.606}, {81.41400000000002, 62.755}, {79.45700000000001, 
                    62.755}, {79.45700000000001, 60.794000000000004`}, {
                    76.67199999999998, 60.794000000000004`}, {
                    76.67199999999998, 62.755}, {74.715, 62.755}, {74.715, 
                    57.606}, {76.67199999999998, 57.606}, {76.67199999999998, 
                    59.567}, {79.45700000000001, 59.567}, {79.45700000000001, 
                    57.606}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{113.145, 
                    57.079}, {105.312, 61.294000000000004`}, {105.312, 
                    57.079}}}]}, {
                    Thickness[0.00006663529411764707], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{65.27, 
                    41.208000000000006`}, {73.10199999999999, 36.993}, {
                    73.10199999999999, 41.208000000000006`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{65.27, 
                    57.079}, {73.10199999999999, 61.294000000000004`}, {
                    73.10199999999999, 57.079}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{113.145, 
                    41.208000000000006`}, {105.312, 36.993}, {105.312, 
                    41.208000000000006`}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{105.516, 
                    57.282000000000004`}, {105.516, 60.958}, {
                    112.34400000000001`, 57.282000000000004`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{72.898, 
                    41.009}, {72.898, 37.333}, {66.07, 41.009}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{72.898, 
                    57.282000000000004`}, {72.898, 60.958}, {66.07, 
                    57.282000000000004`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{105.516, 
                    41.009}, {105.516, 37.333}, {112.34400000000001`, 
                    41.009}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{57.18, 
                    33.649}, {57.555, 32.044}, {58.832, 30.829}, {59.137, 
                    29.161}, {59.75, 30.899}, {60.312, 32.356}, {59.891, 
                    34.259}, {59.59, 35.62200000000001}, {58.445, 36.591}, {
                    58.312, 37.989}, {57.066, 36.868}, {56.797000000000004`, 
                    35.278000000000006`}, {57.18, 33.649}}, CompressedData["
1:eJxTTMoPSmViYGCQBGIQHWG55URZno/Dh+XHvM1fWjnsLZkswfLNx6HpwKmF
rmWWDqZxuzx5Nvk68DBpt4tFWkD4TX4OTglPLyjNNnfQiuk/9DXCz+G4t3mn
4wMLiP5lfg6ZE9/W2F+1dHgTuEOu9befA5B8HXjDysEMpD/J3+Fk2b75Uvw2
Du1iN899n+wP0e9g69A7PU+o2cHfYYGU/l2VZXYO2z//vVIh6e9gD7L4ja3D
Itdtn/8+8XOQZAnj0w2ydUixvu/fuxzK32TjwN441bnbx89B3ZBjjcwua4c+
kHkCfg7lQOv071o5HP6qEdPP5OewRiYqxXq+JcT9M3wh/rG2cgA5jynb1yF7
D9AjKtYQ9Ua+DkDX75BjtXGYIgG06K6Pw5WKl2qGHrYQ+SAfhxZQeIXZOfyq
y9pTstnbAWSMNru9gx3X9cUFd70dYoHWaMyxdQCqAnrA26EC5B5ZGwf08AcA
SLunQg==
                    "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQvbdksgRLmr9D84FTC12nmTloxvQf+urh73Cl4qWa
4QlTh97peULNBv4OjglPLyj9NnEAqzfzdwgESSibOLA3TnXuvuPnkL0HKPHE
xMHgrgpbY6qfQ8bEtzX2paYObwJ3yLX+9nX4BzJQ0MwhbpcnD1O2r4O6Icca
mV9mDoe/agBt9HFYIxOVYj3fHGKej4/D++XHvM1PWjicXui67XOsj4MxCAib
Q8zb7eOwzv1hlcg6UwdbruuLC3J9Ie5ZbOKw7fPfKxWafg4gYdsuY4h5PP4Q
/Z+NHEDOZDnm76DKBpQ4bejg0p3z/PdKfwceJu12sUhjh1wg7+MnfwegLa8D
Z5g4hDxeOvuIRIDDAil9oM/MHGYAg+OAUQDEvynmEPskAxxA3tI+buEAMrZ7
j7+DJEsYn+4lS4cIyy0nyvb5Q9yzysKBERjmDBP8HaJTrO/7rzV3QA9/ADmb
pE4=
                    "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQ3Xzg1ELXtgCHzIlva+xDDR22ff57pWJmgMMuTx4m
bXUDB6stJ8r2nQ9w+LPy4yXfJD2H2z/rsvZ8CXCYL6V/V8VNx0EaSLFNDHCI
sAQqtNOF8C0DHGzu+/dOf6fnADR92+e9/hD9TgYOKdZAied+Dg6mcbs8dQwh
+v75OjysElnnftDQofKlmiGHja9DBsg9X40cpkiwhPHN9XXgur64wFbLwIG9
capzd4+fA8h57WK6DnEgh772dwAZOz1PG+KP3AAHe5D5PloQfZcCHGL6D33V
uKPlsGnu++XHkgMdFoDcz6bpEA/SHxzosBXozflSOg7fNIAqTQMd2ED25Og7
rJGJSrFmD3QAWydpCFH/OMBB3ZBjjYyUEcT+3QEO84DGeosbQ8JnSYCDJNDZ
ukYmDn5JAhGWLQEQd3gZO4CC429JgEM50Db9WCMH9PAHACGno/o=
                    
                    "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQfftnXdaeL4EOW0+U7ZsvpeXw9ILS7Z9iQQ7fgx8v
ne2i4SCyzv1hlUuQw0651teBO9QcREH8miCH3ul5Qs0Nqg7PQOrfBTrsAMlb
qDpkTnxbY18b6LBASv+uCpuGgypb41TnzwEOhhxrZKJUNByaD5xa6DovAKpe
A6LeFyqfou4wWYIljO+tP4S/RN3BAGhKYyxUfYWqw7bPf69UnAxwuO8PdMEk
ZYh73QIdVn285JskoOzAdX1xge2rQIc0MFCCujPIodAWKLNBGeIfk2AHa5AB
esoQ+QdBEH1cqg6ePEza7duCIO5vU3dw6c55/rsRqt9Ay+GbRkz/IVuYvC7E
/X8DHdJB1j3Th5hXAQsPA4j6tVD3TdBzAIf3mUCHCMstJ8rsdBzQwx8AQtmv
2g==
                    "], {{79.67599999999999, 9.384}, {75.781, 
                    8.722999999999999}, {72.051, 7.863999999999999}, {68.074, 
                    7.824999999999999}, {72.523, 6.274}, {76.71900000000001, 
                    5.993}, {81.133, 7.595}, {83.52, 8.462}, {85.348, 
                    8.927}, {87.15199999999999, 8.798}, {89.785, 8.606}, {
                    92.98400000000001, 7.566999999999999}, {96.527, 
                    3.8329999999999997`}, {97.918, 4.946}, {92.84400000000001,
                     9.47}, {86.199, 10.493}, {79.67599999999999, 9.384}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{121.254, 
                    33.649}, {120.87899999999999`, 32.044}, {
                    119.60199999999999`, 30.829}, {119.293, 29.161}, {118.684,
                     30.899}, {118.121, 32.356}, {118.543, 34.259}, {
                    118.84400000000001`, 35.62200000000001}, {119.988, 
                    36.591}, {120.121, 37.989}, {121.367, 36.868}, {121.637, 
                    35.278000000000006`}, {121.254, 33.649}}, CompressedData["

1:eJxTTMoPSmViYGCQBGIQLbLO/WFVSpzDh+XHvM1fWjmEPF46+4hCnEPTgVML
XcssHWbkCTUfOBTrwMOk3S4WaQHhR8U6OCU8vaA029xhjUxUinV+rMNxb/NO
xwcWEP0esQ6ZE9/W2F+1dNhbMlmCRS7WYYdc6+vAG1YO00H6X8U4nCzbN1+K
38ah1t40btfFGIh+B1uHN4FAlb9jHBZI6d9VWWbn8OyC0u2ffLEOIGWeb2wd
HlYBXawZ6yDJEsanG2Tr8B8E3KH8TTYOQF1sjaWxDuqGHGtkdlk7vAaZNznW
oRxonf5dK4dLQOPqZsVC3D3fEmL+Oah/rK0cmkH+fhbrkL0H6HAVa4eLIPVM
cQ6tIINYbSD+0o1zuFLxUs3QwxYiXxTn0ALSF2bn4NKd8/z3wTiHXZ7AEGO3
d1jkuu3z3zVxDrH9h75qzLF1uPOzLmvPnDiHCpB7ZG0c0MMfAB6Psig=
                    
                    "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQ3Ts9T6j5RYxD84FTC12nmTk8vaB0++e3GIcrFS/V
DE+YOrwO3CHXyhzr4JgAlPlt4hDyeOnsIwyxDoEgjcomDgZ3VdgadWMdsveU
TJZ4YuIgrQ8UyIx1yJj4tsa+1NRhL1CYZV6swz+QgYJmEHuexTqoG3Kskfll
5nAJaF2dVZzDGpmoFOv55g4g7Y2lcQ7vlx/zNj9p4QCUzdqTE+dgDALC5g7f
NGL6D9nGOaxzf1glss7UYaHrts9/n0Dds9jEQa4V6OK2WAeu64sLbLuMIeaJ
xkL0fzaCuH9HjIMqW+NU59OGEPXHYhx4mLTbxSKNHVy6c57/XhjjsAMkMcPE
IX6XJw9Tc4zDAimQSWZQ/8VA/JtiDlHfGOMAUqZ93AISHntjHCRZwvh0L1k6
iIIcuicG4p5VFg6b5gJ9djnGITrF+r7/WnMH9PAHAACeqxo=
                    
                    "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQrX9Xha1RNMYhc+LbGvtQQweX7pznvxljHHZ58jBp
qxs4VLxUM+Q4E+3wZ+XHS75Jeg5PLyjd/rks2mG+FFCnm47D9Dyh5gNcMQ4R
lltOlNnpOlwEStclxTjY3Pfvnf5Oz+HOz7qsPXtiIPqdDBz+g4B6rIODadwu
Tx1DB9F17g+r5sQ6PKwSWed+0NDhm0ZM/6G/sQ4ZIPd8NYK462ysA9f1xQW2
WgYOYPeGxjqAnNcupuvQfODUQtdlMQ7WIPvytCF8vRgHe5D5PloQc09GOwBN
/apxRwtiv3m0wwKQ+9k0HUIeL519xCPaYeuJsn3zpXQc9pZMlmBJi3Zga5zq
3J2j7yACct+UaAewdZKGEPU7oh3UDTnWyEgZQfgPoh3mvV9+zFvcGBI+36Id
JFnC+HSNTBzWyESlWIvHQNzvZewg1/o6cIdajEM50Db9WCMH9PAHAKgmrgU=

                    "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQ/fSC0u2fy6Ictp4o2zdfSstBZJ37w6qWKIfvwY+X
znbRcFgjE5ViHR7lsFOu9XXgDjUIXz7KoXd6nlBzgypE/Zoohx0geQtVBy8e
Ju12uWiHBVL6d1XYNByOeZt3Oq6IdjDkAOpU0XAwAIo2/o2GqteAqPeLgcin
qDtkTHxbY78Uyl+i7tB84NRCV7sYiPoKVQeu64sLbC9FO9z3B7pgkrLD7Z91
WXtCoh1WfbzkmySg7LDt898rFRujHNLAQMkhbpcnD5N0lEOhLVDnBmUHsH/T
Ih2sQQboKTuosjVOdd4dCTGXSxVi/9NIiPvb1B1q7U3jdklC9RtoOewtmSzB
EhcFldeFuH9elEM6yLpn+hDzlGH+M4CofxcFcd8EPYdnIPvPRTlEWG45UWan
44Ae/gAy+KYv
                    "], {{98.758, 9.384}, {102.65199999999999`, 
                    8.722999999999999}, {106.383, 7.863999999999999}, {
                    110.359, 7.824999999999999}, {105.91000000000001`, 
                    6.274}, {101.715, 5.993}, {97.301, 7.595}, {
                    94.91400000000002, 8.462}, {93.082, 8.927}, {91.281, 
                    8.798}, {88.648, 8.606}, {85.44900000000001, 
                    7.566999999999999}, {81.906, 3.8329999999999997`}, {
                    80.512, 4.946}, {85.59, 9.47}, {92.23400000000001, 
                    10.493}, {98.758, 9.384}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGItIGYC4r0lkyVY0nwcri8usOU6nO3AAAIKvg7nvgc/
Xjo92wEoG8ZX6+nw5e+Vipf7suB8jjUyUSni2Q6/6rL2lCz2hqvf9hmk0Atu
nmncLk+eIh+H5gOnFrrK5UDEj3s7gO11Q/Cl9e+qsPHmOCx0BZpQ4oXBf1gl
ss49MMfBlguoI9cXYh5TrsPrwB1yra/94PwU6/v+veL+Dpvmvl9+7HAOxD2W
fnC+S3fO89+a/g7nQe7thsofDHAw73RMeCqSC5dfIAV0wLxcuH5IOCHMh/Fh
9oNp9Vy4+2B8mPt7p+cJNd9A8EMeL519RCYP7n90Pti9j3Ph4fcGZB53Hjx8
BSIst5xIy4OHP9i9k/Lg8ZMGAkL5cD7Y3Ox8ePzC1MPiH2beKZAD3/rC7bMD
+Weuj8M/oK1qe3MdKl+qGXLU+ELiozPXYfYRhQ1FGv6Q+Hqb6wDy5oGsQHh4
wuTB/rPJgesHh8eCHLj5haCAy8mB2w9LLwCJMSw+
                    "]]}, {
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGItIGYC4uuLC2y5vvs6nP8e/HhpfK6DS3fO89+a/g6O
CU8vKC3PdciY+LbG/mqAg3knUEQEIa+7ae775U05DjD9C6T076qcgvH94Px2
sZvnvl/2c5jmDNKY46AZ03/oa4UvnN83PU+oeYKXgx7IPD8E/3XgDrlW4RwI
vdobg7/8mLd5Z2iOgxbIvBk+Ds0HTi10lYPqF/CGuONwtsNFpds/6055O5wD
+W96tsNkCZYwvlpPiHo+BH8qyD3HsyDu++EDV//sAtAAOx+4eWD6uC/cPi8e
Ju32Mh+HQluu64tzchwqX6oZctT4OqwAuW9ljsPsIwobijT8Hb5pAA12zXF4
CjIvLBAenjB5sL4nuXD99qZxuzwbcuHm/7tS8VJtby7c/jegcODOg7tPIMJy
y4m0PLj7weE/KQ/uv5sgDyXmw/lg/dL58PCBqYeFH8w8WPjC7IOFP9h9V3Lh
fHB4iOXB4w+d7wRKT7dz4fEPdo9uLjx9wPiw9ANLjwD6gjUe
                    "]]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    64.93, 232.74299999999997`}, {63.379, 231.298}, {
                    63.12500000000001, 232.74299999999997`}, {63.379, 
                    234.18800000000002`}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    63.523, 233.76999999999998`}, {63.343999999999994`, 
                    232.74299999999997`}, {63.523, 231.71599999999998`}, {
                    64.62499999999999, 232.74299999999997`}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    54.473, 231.192}, {55.93, 232.64899999999997`}, {54.473, 
                    234.11399999999998`}, {52.684, 234.11399999999998`}, {
                    52.684, 236.165}, {50.977, 237.872}, {50.977, 227.43}, {
                    52.684, 229.141}, {52.684, 231.192}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    54.391, 233.911}, {55.645, 232.64899999999997`}, {54.391, 
                    231.39100000000002`}, {52.483999999999995`, 
                    231.39100000000002`}, {52.483999999999995`, 229.227}, {
                    50.977, 227.72}, {50.977, 237.58700000000002`}, {
                    52.483999999999995`, 236.07899999999998`}, {
                    52.483999999999995`, 233.911}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGItIGYC4r0lkyVY0nwc1NgapzpLpzowgICCr0PlSzVD
jg8pDkDZML5aTwfHhKcXlMQR/PPfgx8vzU9x+FWXtadksTdc/bbPf69UvPSC
m2cat8uTp8jHwZOHSbu9LNXh+uICW67j3g7paUAwD8E/orChKCM11WGhK9CE
Ei8M/opj3uadK1MdbLmAOnJ9HXQ3zX2/PCrN4XXgDrnW135wfor1ff9ecX+I
e2TSIO6x9IPzXbpznv/WhMo/SYXIHwxw+Ad0tVouQh7kvLRvCP1g9+5DmA/j
w+wHWX+sPg3uPhgf5n6LTmAIGqTD+dL6d1XYStPh/kfng91nkw4PP7B5yenw
8AXHx/50ePiD3fMqHR4/ghGWW05kZcD5qqD4OJwBj1+Yelj8w8w7BXLgW1+4
fXYg/8z1gcSHaDrEXTW+Dj3AYFr5MM1hNkhCwx8i75ruMD1PqPlAViA8PGHy
YP9NTYXrB6ae2Ud+pMLNNweFz5FUuP2w9AIALMwnGw==
                    "]]}, {
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGItIGYC4uuLC2y5vvs6VL5UM+TYkebg0p3z/LemvwPn
GpmolP9pDhkT39bYXw1w+Hel4qVaLkIerO92qgNMfxoIKKVB+X5wfrvYzXPf
L/s52JvG7fIMSXPQjOk/9LXCF87vm54n1DzBy+HzX6AFy1Lh/M1z3y8/lp3q
8Dpwh1zram8MPtDU4MdrUx20QObN8HHw5GHSbi+D6hfwdlBja5zqLJ3qcFHp
9s+6U94Q/31IcZgswRLGV+vpoLsJaGAagg8yRkMhBeK+Hz5w9c8uAA2w84Gb
B/bfcV+4fV5g2sfBvNMx4emRVIi+Gl+I+xjTHGYfUdhQpOHvsLcEaNO8VIen
IPPCAuHhCZNf/fGSb5JNOlx/L8gfN9Lg5oOUZYimw+0HOf9YcjrcfUDbLyjt
T4e7Px0U/q/S4f5rOXBqoeuuDDgfrL84Ax4+MPWw8IOZBwtfmH2w8Aer00Hw
9UAK8tLh8YfOB6szTofH/wIp/bsqbYj0AePD0g8sPQIAa2kuwg==
                    
                    "]]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    64.93, 179.501}, {63.379, 178.059}, {63.12500000000001, 
                    179.501}, {63.379, 180.946}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    63.523, 180.52800000000002`}, {63.343999999999994`, 
                    179.501}, {63.523, 178.477}, {64.62499999999999, 
                    179.501}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    54.473, 177.95000000000002`}, {55.93, 179.411}, {54.473, 
                    180.876}, {52.684, 180.876}, {52.684, 182.923}, {50.977, 
                    184.634}, {50.977, 174.192}, {52.684, 175.903}, {52.684, 
                    177.95000000000002`}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    54.391, 180.67299999999997`}, {55.645, 179.411}, {54.391, 
                    178.153}, {52.483999999999995`, 178.153}, {
                    52.483999999999995`, 175.985}, {50.977, 174.477}, {50.977,
                     184.348}, {52.483999999999995`, 182.841}, {
                    52.483999999999995`, 180.67299999999997`}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGItIGYC4r0lkyVY0nwc5r1ffsz7eYwDAwgo+DrUZ+0p
mTwhxgEoG8ZX6+lwfXGBLdf9KDj/0yXfJIEJ0Q6/6oAKF3vD1W/7/PdKxUsv
uHmmcbs8eYp8HF78Xvnx0txYiDnHvR2iUqzv+79F8MVvnvseXB3rsNAVaEKJ
FwZ/01yggcxxDrZcQB25vg7r3B9WiaTFO7wO3CHX+toPzgcZ2yvu7xDyeOns
Iy/iIO6x9IPzXbpznv/WhMpXQOUPBjj4907PE+qOh8sLRlhuOeGXANcvAOKL
JcDNh/Fh9oPIwA3xcPfB+DD3/wOGilpnApx/RGFDUcbZBLj/0fmrPgIDeEoC
PPxi+w991diTAA9fsL3iifDwB7vXKRE1vg4j+Oe/Bz9eKp0Ej1+Yelj8w8w7
BXLgW1+4fXYg/8z1cfimEdN/KDfBofKlmiFHja8DKHoeWyY4zAY5XMPfoQcY
bCvnJjgAQ7H5QFYgPDxh8l2OCU8v3IqF6/8DTA6+i+Lg5h/+CrTAKg5uPyy9
AAAMfju0
                    "]]}, {
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGItIGYC4uuLC2y5vvs6OJjG7fIUSHBw6c55/lvT32Hj
3PfLj4UnOGRMfFtjfzXAwb93ep5Qdzxc3pOHSbs9Lc4Bpl9xQ1HGxK8wvh+c
3y5289z3y34O0vp3Vdgi4x00Y/oPfa3whfP7gMY2T/By8AKZ9y8Wzt8h1/o6
sCPW4XUgkLXaG4NvD3IvT5yDFsi8GT4OL36v/HhpLlS/gLfDPKDzvZ/HOFxU
uv2z7pS3Q33WnpLJE2IcJkuwhPHVekLU10bD+WD3fIyCuO+HD1z9swtAA+x8
4OaB/XfcF24f2N1lPg6Hv2rE9FvFOVS+VDPkqIGG55Y4h9lHFDYUafg7nD0D
BG9iHZ6CzAsLhIcnTB5o6vXFUxLg+i06HROeGiTAzf8GNP5QbgLc/ligMzX2
JMDdBw4X8US4+wUjLLeccEqE+w8cX0JJcD5Y/5lEePjA1MPCD2YeLHxh9sHC
3xzkvhYE//PfKxUvjyXA4w+dvxmUnroT4PE/BeSOvfHw9AHjw9IPLD0CAG7u
Lxc=
                    "]]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    64.93, 126.262}, {63.379, 124.81700000000001`}, {
                    63.12500000000001, 126.262}, {63.379, 127.708}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    63.523, 127.29}, {63.343999999999994`, 126.262}, {63.523, 
                    125.235}, {64.62499999999999, 126.262}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    54.473, 124.712}, {55.93, 126.17299999999999`}, {54.473, 
                    127.634}, {52.684, 127.634}, {52.684, 129.684}, {50.977, 
                    131.395}, {50.977, 120.95}, {52.684, 122.661}, {52.684, 
                    124.712}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    54.391, 127.43}, {55.645, 126.17299999999999`}, {54.391, 
                    124.915}, {52.483999999999995`, 124.915}, {
                    52.483999999999995`, 122.74700000000001`}, {50.977, 
                    121.239}, {50.977, 131.106}, {52.483999999999995`, 
                    129.598}, {52.483999999999995`, 127.43}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGItIGYC4r0lkyVY0nwcwvh0N83V93dgAAEFX4fDXzVi
+pv8HICyYXy1ng4ny/bNl5L3hvP/Xal4qdbo4/CrLmtPyWJvuPptn/8CZbzg
5pnG7fLkKfJx8OJh0m73C3C4vrjAluu4t8M694dVIvMQ/MqXaoYcOgEOC12B
JpR4YfDBBm0JcLDlAurI9XXwBJknFuTwOnCHXOtrPzg/xfq+f6+4vwPQ9HXu
MwMh7rH0g/NdunOe/9aEymtC5Q8GOGye+375MesguDzYfX7BcP1g/j2E+TA+
zP6Qx0tnH0kIgrsPxoe5P6B3ep7Q4WA4X+zmue/B3iFw/6Pzwe67GQwPP7B5
GiHw8E0FueN+CDz8we4xC4XHj0CE5ZYTZmFwvlY70IbnYfD4hamHxT/MvFMg
B771hdtnB/LPXB+HClB89ARD4qXG14Gtcapzt0qww+wjChuKNPwh8m+CHYC+
bD6QFQgPT5g82H/dAXD9XY4JTy8EBcLNB8u/DoDbD0svADOPI54=
                    
                    "]]}, {
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGItIGYC4uuLC2y5vvs6PKwSWed+McjBpTvn+W9Nf4dP
l3yTBBKCHTImvq2xvxrgsHnu++XHrBHy84Bcb/FAB5j+de5AE5bB+H5wfrvY
zXPfL/s55Ak1HzjFGeSgGdN/6GuFL5zfNx3ImuAF0bc+AM4Pebx09hGLAIfX
gTvkWld7Y/CnSLCE8e0NcNACmTfDx8GLh0m73Q+qX8DbIYxPd9NcfX+Hi0q3
f9ad8nY4/FUjpr/Jz2EySF+tJ0R/rA+cH9AL1OjsDXHfDx+4+mcXgAbY+cDN
A7vzuC/cPjBd5uMA8mbw6wCHypdqhhw1vhBzUwMdZh9R2FCk4e8QlWJ9339u
gMNTkHlhgfDwhMmbxe3y5LkVDNf/Z+XHS75CwXDzK0DiPcFw+8HhoRECd18q
0Pje+yFw94PD3ywU7r8Xv4EGXg2D88H6PcLg4QNTDws/mHmw8IXZBwv/vyD3
7QqG88HutAuBxx86H6jqdeCJYHj8K24oypiYGwRPHzA+LP3A0iMAEvclyg==

                    "]]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    64.93, 73.02}, {63.379, 71.579}, {63.12500000000001, 
                    73.02}, {63.379, 74.46600000000001}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    63.523, 74.048}, {63.343999999999994`, 73.02}, {63.523, 
                    71.99700000000001}, {64.62499999999999, 73.02}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    54.473, 71.47}, {55.93, 72.93}, {54.473, 74.395}, {52.684,
                     74.395}, {52.684, 76.44200000000001}, {50.977, 
                    78.15299999999999}, {50.977, 67.712}, {52.684, 69.423}, {
                    52.684, 71.47}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    54.391, 74.192}, {55.645, 72.93}, {54.391, 
                    71.67299999999999}, {52.483999999999995`, 
                    71.67299999999999}, {52.483999999999995`, 69.505}, {
                    50.977, 67.99700000000001}, {50.977, 77.868}, {
                    52.483999999999995`, 76.36}, {52.483999999999995`, 
                    74.192}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGItIGYC4uKMiW9r0uMcri8usOU6nO1wUen2zzquOIdz
34MfL52e7VD5Us2Q4068w5e/Vype7suC8znWyESliGc7hDxeOvvICYR6/bsq
bI2q8XDztn0GakyMc2g+cGqhq1yOw9MLQAu2xTnsLZksweKG4EuDNPLmODCA
QEI8Bv9hlcg698Ach01z3y8/9jgWYh5TrgPQtVl7VBB8+dbXgTv4YiHqDuc4
fNOI6T9Ui+CD3cca63Ae5N7uHIg9N6MdzDsdE56K5MLlF0gBWfNy4frB7k1D
mA/jw+wHisq1qufC3Qfjw9zfOz1PqPkGgg8ON5k8uP/R+RBzcuHh9wZkHnce
PHwFIiy3nEjLg4c/2L2T8uDxkwYCQvlwPjg+svPh8QtTD4t/mHlgdy+OhdsH
dod3nMM/YPSr7c11EF3n/rDqTiwkPjpzIeHOFgsJx7e5DlZbTpTt00eEJ0we
7E6bHLh+cHgsyIGbX2jLdX1xTg7cflh6AQANNjHl
                    "]]}, {
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGItIGYC4mcXlG7/nBfrcP578OOl8bkO+ndV2BpZYx0c
E55eUFqe65Ax8W2N/dFoB/NOoIgIQl5309z3y5tyHGD6F0gBZU5B+XII/nFv
oE6DWIdpzt05z3/nOOwtmSzBcg/B57q+uMA2KN5BD2SeH4L/OnCHXKtwjsPt
n3VZe47EYfCXHwMaHAo1zy/OofnAqYWucjkOLiBjBeMdQMZwHc6GuH9rnMM5
kP+mZztUvlQz5LgTD1HPh+BPBbnneBbEPDmE+rhdnjxM1XFw856C/LctFm7f
GpmoFOv4OIdCW6DLc3IcRNe5P6y6E+uwAuS+lTkQdWyxDt80YvoPueZA/OGM
CE+YPNgdT3Lh+u1NgTY35MLN/3el4qXa3ly4/W9A5nDnwd0nEGG55URaHtz9
4PCflAf3302QhxLz4Xywful8ePjA1MPCD8U8YPjC7IOFP9h9V3LhfLA/xPLg
8YfOdwKlp9u58PgHu0c3F54+YHxY+oGlRwBWgTbg
                    "]]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    113.48400000000001`, 232.74299999999997`}, {115.035, 
                    231.298}, {115.289, 232.74299999999997`}, {115.035, 
                    234.18800000000002`}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    114.891, 233.76999999999998`}, {115.07, 
                    232.74299999999997`}, {114.891, 231.71599999999998`}, {
                    113.789, 232.74299999999997`}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    123.94100000000002`, 231.192}, {122.48400000000001`, 
                    232.64899999999997`}, {123.94100000000002`, 
                    234.11399999999998`}, {125.73, 234.11399999999998`}, {
                    125.73, 236.165}, {127.438, 237.872}, {127.438, 227.43}, {
                    125.73, 229.141}, {125.73, 231.192}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    124.023, 233.911}, {122.77, 232.64899999999997`}, {
                    124.023, 231.39100000000002`}, {125.93, 
                    231.39100000000002`}, {125.93, 229.227}, {127.438, 
                    227.72}, {127.438, 237.58700000000002`}, {125.93, 
                    236.07899999999998`}, {125.93, 233.911}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGItIGYC4uKMiW9r0uMc1NgapzpLpzpcVLr9s44rzqHy
pZohx4cUCH0n3sEx4ekFJXEE//z34MdL81McQh4vnX3kBEK9/l0VtkbVeLh5
2z7/vVKRGOfgycOk3V6W6gA05fbPbXEO6WlAMA/BP6KwoSgjNdWBAQQS4jH4
K455m3euTHXYNPf98mOPYx10QYyoNAega7P2qCD48q2vA3fwxULcI5Pm8E0j
pv9QLYIPdh8rlP8k1UEaJHAz2uHflYqXarkIeZDz0r4h9IPduw9hPowPsx/s
rvo0uPtgfJj7LTqBIWiQDueD7S1Nh/sfnQ92n006PPzA5iWnw8MXHB/70+Hh
D3bPq3R4/AhGWG45kZUB56uC4uNwBjx+Yeph8Q8zD+g7udbFsXD7wLQ3NH5E
0x1E17k/rLoT69CT8/z3yodpDs0HTi10ZYuFyLumO1htOVG2Tx8RnjB5sP+m
psL1B4Pc/SMVbr45KHyOpMLth6UXALDCLMI=
                    "]]}, {
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGItIGYC4mcXlG7/nBfrUPlSzZBjR5qD/l0VtkbWWAfO
NTJRKf/THDImvq2xPxrt8O9KxUu1XIT89cUFtly3Ux1g+tNAQCkNwpdD8I97
m3c6GsQ62JvG7fIMSXPYWzJZguUegs8FMigo3uHzX6AFy1Lh/M1z3y8/lp3q
cPtnXdaeI3EY/Jvnvgc/XpsKMc8vzsGTh0m7vSzVwaU75/lvwXgHNbbGqc7S
qRD3b42D+O9DCoS+E++guwloYBqCH9N/6KuGQgrEPDmEeqAreZiq4+DmPQX5
b1ss3D5QMFnHxzkAfZnw9Eiqg+g694dVd2Ih7mNMc2g+cGqhK1ssxNx5qQ6v
A3fItTojwhMmv/rjJd8km3S4/t7peULNN9Lg5h9R2FCUIZoOtx/k/GPJ6XD3
AW2/oLQ/He7+dFD4v0qH+68FZM+uDDgfrL84Ax4+MPWw8EMxDxi+MPtg4d8H
cp8Ogq8HUpCXDo8/dD7Y38bp8PhfIAVMSW2I9AHjw9IPLD0CAMdZMIQ=
                    
                    "]]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    113.48400000000001`, 179.501}, {115.035, 178.059}, {
                    115.289, 179.501}, {115.035, 180.946}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    114.891, 180.52800000000002`}, {115.07, 179.501}, {
                    114.891, 178.477}, {113.789, 179.501}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    123.94100000000002`, 177.95000000000002`}, {
                    122.48400000000001`, 179.411}, {123.94100000000002`, 
                    180.876}, {125.73, 180.876}, {125.73, 182.923}, {127.438, 
                    184.634}, {127.438, 174.192}, {125.73, 175.903}, {125.73, 
                    177.95000000000002`}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    124.023, 180.67299999999997`}, {122.77, 179.411}, {
                    124.023, 178.153}, {125.93, 178.153}, {125.93, 175.985}, {
                    127.438, 174.477}, {127.438, 184.348}, {125.93, 
                    182.841}, {125.93, 180.67299999999997`}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGItIGYC4uKMiW9r0uMc5r1ffsz7eYzDRaXbP+u44hzq
s/aUTJ4Q41D5Us2Q4068w/XFBbZc96Pg/E+XfJMEJkQ7hDxeOvvICYR6/bsq
bI2q8XDztn3+e6UiMc7hxe+VHy/NjXV4egFowbY4h6gU6/v+bxF88ZvnvgdX
xzowgEBCPAZ/01yggcxxEPpxrMM694dVImnxDkDXZu1RQfDlW18H7uCLhbjr
RZzDN42Y/kO1CD7YfaxQfkWcgzRI4Ga0g3/v9Dyh7ni4vGCE5ZYTfglw/QIg
vlgC3HwYH2b/DjmgxIZ4uPtgfJj7/12peKnWmQDnH1HYUJRxNgHuf3T+qo/A
AJ6SAA+/2P5DXzX2JMDDF+gKuVbxRHj4g93rlIgaX4cR/PPfgx8vlU6Cxy9M
PSz+YeaB6cWxcPvA/vGGhmNugoMoKKDvxDqAouexZYJD84FTC13ZYh16cp7/
Xjk3wcFqy4myffqI8ITJdzkmPL1wKxau/w8wOfguioObf/gr0AKrOLj9sPQC
AJB0QVs=
                    "]]}, {
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGItIGYC4mcXlG7/nBfr4GAat8tTIMFB/64KWyNrrMPG
ue+XHwtPcMiY+LbG/mi0g3/v9Dyh7ni4vCcPk3Z7WpwDTL/ihqKMiV+hfDkE
/7i3eaejQayDNEhjZLzD3pLJEiz3EHyu64sLbIPiHbxA5v2LhfN3yLW+DuyI
dbj9sy5rz5E4DL49yL08cRDz/OIcXvxe+fHS3FgHl+6c578F4x3mAZ3v/TwG
4v6tcQ71WXtKJk+Icah8qWbIcSceor42Gs4Hu+djFMQ8OYR6kC1M1XFw856C
/LctFm7fGpmoFOv4OIfDXzVi+q3iHETXuT+sugMNzy1xDs0HTi10ZYt1OHsG
CN7EOrwOBPrEGRGeMPkCW6DPpyTA9Vt0OiY8NUiAm/8NaPyh3AS4/bH9h75q
7EmAuw9srngi3P2CEZZbTjglwv0Hji+hJDgfrP9MIjx8YOph4YdiHjB8YfbB
wt8c5L4WBP/z3ysVL48lwOMPnb8ZlJ66E+DxP0WCJYxvbzw8fcD4sPQDS48A
yt4w2Q==
                    "]]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    113.48400000000001`, 126.262}, {115.035, 
                    124.81700000000001`}, {115.289, 126.262}, {115.035, 
                    127.708}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    114.891, 127.29}, {115.07, 126.262}, {114.891, 125.235}, {
                    113.789, 126.262}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    123.94100000000002`, 124.712}, {122.48400000000001`, 
                    126.17299999999999`}, {123.94100000000002`, 127.634}, {
                    125.73, 127.634}, {125.73, 129.684}, {127.438, 131.395}, {
                    127.438, 120.95}, {125.73, 122.661}, {125.73, 
                    124.712}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    124.023, 127.43}, {122.77, 126.17299999999999`}, {124.023,
                     124.915}, {125.93, 124.915}, {125.93, 
                    122.74700000000001`}, {127.438, 121.239}, {127.438, 
                    131.106}, {125.93, 129.598}, {125.93, 127.43}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGItIGYC4uKMiW9r0uMcwvh0N83V93e4qHT7Zx1XnMPh
rxox/U1+DpUv1Qw57sQ7nCzbN19K3hvO/3el4qVao49DyOOls4+cQKjXv6vC
1qgaDzdv2+e/VyoS4xy8eJi02/0CHJ5eAFqwLc5hnfvDKpF5CD7YXJ0ABwYQ
SIjH4DuYxu3y3BLgsGnu++XHHsc6eILMEwtyALo2a48Kgi/f+jpwB1+sA9D0
de4zAx2+AZ11qBbBB7uPFcrXDHSQBgncjHbYDDLXOgguD3afXzBcP5h/D2E+
jA+zHxwOCUFw98H4MPcH9E7PEzocDOeL3Tz3Pdg7BO5/dD7YfTeD4eEHNk8j
BB6+qdb3/Xvvh8DDH+wes1B4/AhEWG45YRYG52u1A214HgaPX5h6WPzDzAP6
Tq51cSzcPrB/vOMcKkDm9AQ7iII03ol1YGuc6tytEuzQfODUQle2WIj8m2AH
qy0nyvbpI8ITJg/2X3cAXH+XY8LTC0GBcPPB8q8D4PbD0gsAt4UpRQ==
                    
                    "]]}, {
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGItIGYC4mcXlG7/nBfr8LBKZJ37xSAH/bsqbI2ssQ6f
LvkmCSQEO2RMfFtjfzTaYfPc98uPWSPk5wG53uKBDjD969yBJiyD8uUQ/OPe
5p2OBrEOeULNB05xBjnsLZkswXIPwee6vrjANijeAURxrQ+A80MeL519xCLA
4fbPuqw9R+Iw+FMkWML49gZAzPOLc/DiYdJu9wtwcOnOef5bMN4hjE9301x9
f4j7t8Y5HP6qEdPf5OdQ+VLNkONOPER/rA+cH9A7PU/I2RtinhxCfdwuTx6m
6ji4eU9B/tsWC7dvjUxUinV8nIPYzXPfg18HOIiCPH4n1mEyyPzUQAegLxe6
ssU6AFXd958b4PA6cIdcqzMiPGHyZiCLbgXD9f9Z+fGSr1Aw3PwKkDt7guH2
g8NDIwTuvlSg8b33Q+DuB4e/WSjcfy9+Aw28Ggbng/V7hMHDB6YeFn4o5vnF
we2Dhf9fkPt2BcP54PCwC4HHHzof6OvXgSeC4fGvuKEoY2JuEDx9wPiw9ANL
jwBu5yeM
                    "]]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    113.48400000000001`, 73.02}, {115.035, 71.579}, {115.289, 
                    73.02}, {115.035, 74.46600000000001}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    114.891, 74.048}, {115.07, 73.02}, {114.891, 
                    71.99700000000001}, {113.789, 73.02}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    123.94100000000002`, 71.47}, {122.48400000000001`, 
                    72.93}, {123.94100000000002`, 74.395}, {125.73, 74.395}, {
                    125.73, 76.44200000000001}, {127.438, 
                    78.15299999999999}, {127.438, 67.712}, {125.73, 69.423}, {
                    125.73, 71.47}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    124.023, 74.192}, {122.77, 72.93}, {124.023, 
                    71.67299999999999}, {125.93, 71.67299999999999}, {125.93, 
                    69.505}, {127.438, 67.99700000000001}, {127.438, 
                    77.868}, {125.93, 76.36}, {125.93, 74.192}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIxIGYC4uuLC2y5jns7fNWI6T8UXegA46uyNU51ti90
WOi67fPfEi8MPscamaiUxEIHWy6gjlxfh5vnvgc/3lno8Dpwh1zraz84P8X6
vn+vuL9DfdaeksmzCh2Auq9UWPrB+S7dOc9/a/o71IH4dVD5gwEOxiBwuNDh
otLtn3VZgXD+7CMKG4o0/B0CeqfnCYUXOlS+VDPkqPF1iNvlycPUWehgB3LP
XB+IfH6hwymQg9/6OtwAuce90GFvyWQJljQfh6sVQI1ShQ4MIKDgC7GfpdAB
KBvGV+vpsEBK/67KjAI4H2zvkQKHXyCFi73h6sHufekFN88U5JAiH7h9AIMo
ngA=
                    "]]}, {
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIxIGYC4otKt3/WnfJ2qMvaUzKZpdBhsgRLGF+tp8ON
c9+DH+8vgPOTBCIst8wpcNCM6T/09YcPXP2zC0AD7Hwcrla8VDOUKnS4vrjA
luu4L0S/e6GDFw+TdnuZj0NA7/Q8ofxCh0qgMo4aX4c3gTvkWnsLHWYfUdhQ
pOHvINR84NTC6EKHpyDzwgIdjEHgcKFDxsS3NfZXA+B8l+6c5781/R3WuT+s
EqmC2vfd1+HF75UfL82F8f3g/Haxm+e+X/aDuH9bIcT9Fb5wfh/QWc0TvByA
vpFgSUDwwbRTocNrkDtXe2PwwXRyoYMWyLwZPnD/gtUJeMPDAwD7p6Dc
                    
                    "]]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{64.832, 
                    284.2}, {63.379, 282.845}, {63.141, 284.2}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    63.358999999999995`, 284.2}, {63.523, 283.262}, {64.527, 
                    284.2}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{55.93, 284.2}, {50.977, 
                    284.2}, {50.977, 278.977}, {52.684, 280.688}, {52.684, 
                    282.739}, {54.473, 282.739}, {55.93, 
                    284.19599999999997`}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{50.977, 279.262}, {50.977, 
                    284.2}, {55.645, 284.2}, {55.645, 284.19599999999997`}, {
                    54.391, 282.93799999999993`}, {52.483999999999995`, 
                    282.93799999999993`}, {52.483999999999995`, 280.77}}}]}, {
                   
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIxIGYC4qcXlG7/3Bbn8FUjpv9QdKEDjK/K1jjV2b7Q
gQEEEuIx+BxrZKJSEgsdNs19v/zY41iHm+e+Bz/eWehw+2dd1h4VBF++9XXg
Dr5Yh/qsPSWTZxU6fAPZU4vg699VYWtkjXWoA/HrCh2kQQI3ox2MQeAw1D4D
BL/5wKmFrmyxDgG90/OEwgsdRNe5P6y6E+sQt8uTh6kT6h7vOIh8fqED0Ha5
1sWxDjdA7nEvdCjOmPi2Jj3O4WrFSzVDqUKHi0Dv1nHFQexnKXSoBApz3Il3
WCAFdMiMAjh/9hGFDUVHChxCHi+dfeQEQj3Y/arxcPO2ff57pSIxDm4fAAsQ
m/A=
                    "]]}, {
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIxIGYC4oyJb2vst8Y51GXtKZnMUuhQ+VLNkONOvMON
c9+DH+8vgPOTBCIst8wpcNhbMlmCRQ6hPm6XJw9TdZzD1QqgQqlCh6cXlG7/
3BYL0e9e6LBGJirFOj7OIaB3ep5QfqGD6Dr3h1V3Yh3eBO6Qa+0tdGg+cGqh
K1usgxCIEV3o8Bok7hztYAwChwsdwO47iuDr31Vha2SNdQAZI1JV6PAMZN+8
WIcXv1d+vDQXypdD8I97m3c6GsRC3L+tEOL+ewg+1/XFBbZB8Q57QOIJCH4f
0LnNToUOt38CfXokDoMPdmcy1Dy/OLh/Xbpznv8WjIeHBwDCJaEs
                    
                    "]]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{113.582, 
                    284.2}, {115.035, 282.845}, {115.273, 284.2}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    115.05499999999999`, 284.2}, {114.891, 283.262}, {113.887,
                     284.2}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.21960800000000003`, 0.21568600000000002`, 0.223529], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{122.48400000000001`, 
                    284.2}, {127.438, 284.2}, {127.438, 278.977}, {125.73, 
                    280.688}, {125.73, 282.739}, {123.94100000000002`, 
                    282.739}, {122.48400000000001`, 284.19599999999997`}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.9803919999999999, 0.6823529999999999, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{127.438, 279.262}, {
                    127.438, 284.2}, {122.77, 284.2}, {122.77, 
                    284.19599999999997`}, {124.023, 282.93799999999993`}, {
                    125.93, 282.93799999999993`}, {125.93, 280.77}}}]}}, 
                  AspectRatio -> Automatic, ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 425.}, {0., 285.}}], ",", 
                 GraphicsBox[{
                   Thickness[0.0025], {
                    FaceForm[{
                    RGBColor[0., 0.6, 0.709804], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     200.}, {400., 200.}, {400., 136.}, {0., 136.}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.8078430000000001, 0.06666670000000002, 0.14902], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     136.}, {400., 136.}, {400., 64.}, {0., 64.}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     132.}, {400., 132.}, {400., 68.}, {0., 68.}}}]}, {
                    FaceForm[{
                    RGBColor[0.117647, 0.709804, 0.22745100000000001`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     64.}, {400., 64.}, {400., 0.}, {0., 0.}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{80., 168.}, {80., 154.74599999999998`}, {69.254, 
                    144.}, {56., 144.}, {42.746, 144.}, {32., 
                    154.74599999999998`}, {32., 168.}, {32., 181.254}, {
                    42.746, 192.}, {56., 192.}, {69.254, 192.}, {80., 
                    181.254}, {80., 168.}}}]}, {
                    FaceForm[{
                    RGBColor[0., 0.6, 0.709804], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{88., 168.}, {88., 154.74599999999998`}, {77.254, 
                    144.}, {64., 144.}, {50.746, 144.}, {40., 
                    154.74599999999998`}, {40., 168.}, {40., 181.254}, {
                    50.746, 192.}, {64., 192.}, {77.254, 192.}, {88., 
                    181.254}, {88., 168.}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{70.398, 
                    153.602}, {68.918, 149.035}, {71.199, 
                    148.29299999999998`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{70.398, 
                    153.602}, {71.883, 149.035}, {69.60199999999999, 
                    148.29299999999998`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{74.965, 
                    150.285}, {70.164, 150.285}, {70.164, 147.883}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{74.965, 
                    150.285}, {71.082, 147.461}, {69.67199999999998, 
                    149.40200000000002`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{73.223, 
                    144.918}, {71.738, 149.48000000000002`}, {
                    69.45700000000001, 148.738}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{73.223, 
                    144.918}, {69.34, 147.738}, {70.75, 149.68}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    67.57799999999999, 144.918}, {71.46100000000001, 
                    147.738}, {70.051, 149.68}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    67.57799999999999, 144.918}, {69.062, 
                    149.48000000000002`}, {71.34400000000001, 148.738}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{65.836, 
                    150.285}, {69.71900000000001, 147.461}, {
                    71.12899999999999, 149.40200000000002`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{65.836, 
                    150.285}, {70.637, 150.285}, {70.637, 147.883}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    89.60199999999999, 153.602}, {88.117, 149.035}, {90.398, 
                    148.29299999999998`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    89.60199999999999, 153.602}, {91.082, 149.035}, {88.801, 
                    148.29299999999998`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{94.164, 
                    150.285}, {89.363, 150.285}, {89.363, 147.883}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{94.164, 
                    150.285}, {90.281, 147.461}, {88.871, 
                    149.40200000000002`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{92.422, 
                    144.918}, {90.938, 149.48000000000002`}, {
                    88.65599999999999, 148.738}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{92.422, 
                    144.918}, {88.539, 147.738}, {89.94900000000001, 
                    149.68}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{86.777, 
                    144.918}, {90.66, 147.738}, {89.25, 149.68}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{86.777, 
                    144.918}, {88.262, 149.48000000000002`}, {90.543, 
                    148.738}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{85.035, 
                    150.285}, {88.918, 147.461}, {90.32799999999999, 
                    149.40200000000002`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{85.035, 
                    150.285}, {89.836, 150.285}, {89.836, 147.883}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{108.801, 
                    153.602}, {107.316, 149.035}, {109.598, 
                    148.29299999999998`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{108.801, 
                    153.602}, {110.285, 149.035}, {108., 
                    148.29299999999998`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{113.363, 
                    150.285}, {108.566, 150.285}, {108.566, 147.883}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{113.363, 
                    150.285}, {109.48, 147.461}, {108.07, 
                    149.40200000000002`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{111.621, 
                    144.918}, {110.137, 149.48000000000002`}, {
                    107.85499999999999`, 148.738}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{111.621, 
                    144.918}, {107.738, 147.738}, {109.148, 149.68}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{105.98, 
                    144.918}, {109.863, 147.738}, {108.453, 149.68}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{105.98, 
                    144.918}, {107.46100000000001`, 149.48000000000002`}, {
                    109.74600000000001`, 148.738}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    104.23400000000001`, 150.285}, {108.117, 147.461}, {
                    109.527, 149.40200000000002`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    104.23400000000001`, 150.285}, {109.035, 150.285}, {
                    109.035, 147.883}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{128., 
                    153.602}, {126.516, 149.035}, {128.80100000000002`, 
                    148.29299999999998`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{128., 
                    153.602}, {129.484, 149.035}, {127.199, 
                    148.29299999999998`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{132.566, 
                    150.285}, {127.766, 150.285}, {127.766, 147.883}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{132.566, 
                    150.285}, {128.684, 147.461}, {127.27, 
                    149.40200000000002`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    130.82000000000002`, 144.918}, {129.34, 
                    149.48000000000002`}, {127.05499999999999`, 148.738}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    130.82000000000002`, 144.918}, {126.938, 147.738}, {
                    128.348, 149.68}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    125.17999999999999`, 144.918}, {129.062, 147.738}, {
                    127.65199999999999`, 149.68}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    125.17999999999999`, 144.918}, {126.66, 
                    149.48000000000002`}, {128.945, 148.738}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    123.43400000000001`, 150.285}, {127.316, 147.461}, {
                    128.73, 149.40200000000002`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    123.43400000000001`, 150.285}, {128.23399999999998`, 
                    150.285}, {128.23399999999998`, 147.883}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    147.19899999999998`, 153.602}, {145.71499999999997`, 
                    149.035}, {148., 148.29299999999998`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    147.19899999999998`, 153.602}, {148.684, 149.035}, {
                    146.40200000000002`, 148.29299999999998`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{151.766, 
                    150.285}, {146.965, 150.285}, {146.965, 147.883}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{151.766, 
                    150.285}, {147.883, 147.461}, {146.47299999999998`, 
                    149.40200000000002`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{150.02, 
                    144.918}, {148.539, 149.48000000000002`}, {146.254, 
                    148.738}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{150.02, 
                    144.918}, {146.137, 147.738}, {147.547, 149.68}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{144.379, 
                    144.918}, {148.262, 147.738}, {146.85200000000003`, 
                    149.68}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{144.379, 
                    144.918}, {145.863, 149.48000000000002`}, {
                    148.14499999999998`, 148.738}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{142.637, 
                    150.285}, {146.52, 147.461}, {147.93, 
                    149.40200000000002`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{142.637, 
                    150.285}, {147.434, 150.285}, {147.434, 147.883}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    89.60199999999999, 172.80100000000002`}, {88.117, 
                    168.23399999999998`}, {90.398, 167.49200000000002`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    89.60199999999999, 172.80100000000002`}, {91.082, 
                    168.23399999999998`}, {88.801, 167.49200000000002`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{94.164, 
                    169.484}, {89.363, 169.484}, {89.363, 
                    167.08200000000002`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{94.164, 
                    169.484}, {90.281, 166.66}, {88.871, 168.605}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{92.422, 
                    164.117}, {90.938, 168.684}, {88.65599999999999, 
                    167.941}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{92.422, 
                    164.117}, {88.539, 166.93800000000002`}, {
                    89.94900000000001, 168.879}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{86.777, 
                    164.117}, {90.66, 166.93800000000002`}, {89.25, 
                    168.879}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{86.777, 
                    164.117}, {88.262, 168.684}, {90.543, 167.941}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{85.035, 
                    169.484}, {88.918, 166.66}, {90.32799999999999, 
                    168.605}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{85.035, 
                    169.484}, {89.836, 169.484}, {89.836, 
                    167.08200000000002`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{108.801, 
                    172.80100000000002`}, {107.316, 168.23399999999998`}, {
                    109.598, 167.49200000000002`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{108.801, 
                    172.80100000000002`}, {110.285, 168.23399999999998`}, {
                    108., 167.49200000000002`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{113.363, 
                    169.484}, {108.566, 169.484}, {108.566, 
                    167.08200000000002`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{113.363, 
                    169.484}, {109.48, 166.66}, {108.07, 168.605}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{111.621, 
                    164.117}, {110.137, 168.684}, {107.85499999999999`, 
                    167.941}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{111.621, 
                    164.117}, {107.738, 166.93800000000002`}, {109.148, 
                    168.879}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{105.98, 
                    164.117}, {109.863, 166.93800000000002`}, {108.453, 
                    168.879}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{105.98, 
                    164.117}, {107.46100000000001`, 168.684}, {
                    109.74600000000001`, 167.941}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    104.23400000000001`, 169.484}, {108.117, 166.66}, {
                    109.527, 168.605}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    104.23400000000001`, 169.484}, {109.035, 169.484}, {
                    109.035, 167.08200000000002`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{128., 
                    172.80100000000002`}, {126.516, 168.23399999999998`}, {
                    128.80100000000002`, 167.49200000000002`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{128., 
                    172.80100000000002`}, {129.484, 168.23399999999998`}, {
                    127.199, 167.49200000000002`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{132.566, 
                    169.484}, {127.766, 169.484}, {127.766, 
                    167.08200000000002`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{132.566, 
                    169.484}, {128.684, 166.66}, {127.27, 168.605}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    130.82000000000002`, 164.117}, {129.34, 168.684}, {
                    127.05499999999999`, 167.941}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    130.82000000000002`, 164.117}, {126.938, 
                    166.93800000000002`}, {128.348, 168.879}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    125.17999999999999`, 164.117}, {129.062, 
                    166.93800000000002`}, {127.65199999999999`, 168.879}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    125.17999999999999`, 164.117}, {126.66, 168.684}, {
                    128.945, 167.941}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    123.43400000000001`, 169.484}, {127.316, 166.66}, {128.73,
                     168.605}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    123.43400000000001`, 169.484}, {128.23399999999998`, 
                    169.484}, {128.23399999999998`, 167.08200000000002`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    147.19899999999998`, 172.80100000000002`}, {
                    145.71499999999997`, 168.23399999999998`}, {148., 
                    167.49200000000002`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    147.19899999999998`, 172.80100000000002`}, {148.684, 
                    168.23399999999998`}, {146.40200000000002`, 
                    167.49200000000002`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{151.766, 
                    169.484}, {146.965, 169.484}, {146.965, 
                    167.08200000000002`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{151.766, 
                    169.484}, {147.883, 166.66}, {146.47299999999998`, 
                    168.605}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{150.02, 
                    164.117}, {148.539, 168.684}, {146.254, 167.941}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{150.02, 
                    164.117}, {146.137, 166.93800000000002`}, {147.547, 
                    168.879}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{144.379, 
                    164.117}, {148.262, 166.93800000000002`}, {
                    146.85200000000003`, 168.879}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{144.379, 
                    164.117}, {145.863, 168.684}, {148.14499999999998`, 
                    167.941}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{142.637, 
                    169.484}, {146.52, 166.66}, {147.93, 168.605}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{142.637, 
                    169.484}, {147.434, 169.484}, {147.434, 
                    167.08200000000002`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{108.801, 
                    192.}, {107.316, 187.434}, {109.598, 186.691}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{108.801, 
                    192.}, {110.285, 187.434}, {108., 186.691}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{113.363, 
                    188.684}, {108.566, 188.684}, {108.566, 186.285}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{113.363, 
                    188.684}, {109.48, 185.863}, {108.07, 187.805}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{111.621, 
                    183.316}, {110.137, 187.883}, {107.85499999999999`, 
                    187.141}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{111.621, 
                    183.316}, {107.738, 186.137}, {109.148, 188.078}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{105.98, 
                    183.316}, {109.863, 186.137}, {108.453, 188.078}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{105.98, 
                    183.316}, {107.46100000000001`, 187.883}, {
                    109.74600000000001`, 187.141}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    104.23400000000001`, 188.684}, {108.117, 185.863}, {
                    109.527, 187.805}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    104.23400000000001`, 188.684}, {109.035, 188.684}, {
                    109.035, 186.285}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{128., 192.}, {
                    126.516, 187.434}, {128.80100000000002`, 186.691}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{128., 192.}, {
                    129.484, 187.434}, {127.199, 186.691}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{132.566, 
                    188.684}, {127.766, 188.684}, {127.766, 186.285}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{132.566, 
                    188.684}, {128.684, 185.863}, {127.27, 187.805}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    130.82000000000002`, 183.316}, {129.34, 187.883}, {
                    127.05499999999999`, 187.141}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    130.82000000000002`, 183.316}, {126.938, 186.137}, {
                    128.348, 188.078}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    125.17999999999999`, 183.316}, {129.062, 186.137}, {
                    127.65199999999999`, 188.078}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    125.17999999999999`, 183.316}, {126.66, 187.883}, {
                    128.945, 187.141}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    123.43400000000001`, 188.684}, {127.316, 185.863}, {
                    128.73, 187.805}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    123.43400000000001`, 188.684}, {128.23399999999998`, 
                    188.684}, {128.23399999999998`, 186.285}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    147.19899999999998`, 192.}, {145.71499999999997`, 
                    187.434}, {148., 186.691}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    147.19899999999998`, 192.}, {148.684, 187.434}, {
                    146.40200000000002`, 186.691}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{151.766, 
                    188.684}, {146.965, 188.684}, {146.965, 186.285}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{151.766, 
                    188.684}, {147.883, 185.863}, {146.47299999999998`, 
                    187.805}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{150.02, 
                    183.316}, {148.539, 187.883}, {146.254, 187.141}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{150.02, 
                    183.316}, {146.137, 186.137}, {147.547, 188.078}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{144.379, 
                    183.316}, {148.262, 186.137}, {146.85200000000003`, 
                    188.078}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{144.379, 
                    183.316}, {145.863, 187.883}, {148.14499999999998`, 
                    187.141}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{142.637, 
                    188.684}, {146.52, 185.863}, {147.93, 187.805}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{142.637, 
                    188.684}, {147.434, 188.684}, {147.434, 186.285}}}]}}, 
                  AspectRatio -> Automatic, ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 400.}, {0., 200.}}], ",", 
                 GraphicsBox[{
                   Thickness[0.001893939393939394], {
                    FaceForm[{
                    RGBColor[0., 0.47058800000000006`, 0.368627], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 352.}, {528., 352.}, {528., 0.}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.9843139999999999, 0.8196080000000001, 
                    0.08627450000000002], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBWIuIGZigIKGAofHS2cfUbhV6LD1RNm++VYFDse8zTsd
WQod+g991YjZnAfnCzUfOLWQv8Dh0yXfJIEGqLop+Q4FtlzXF4fkO8DM2yHX
+jpQr8BBNirF+r5pIVz+bY29adwHhH6wumWFcPNBVMJRhP2LXLd9/iuQ5ZD7
/PfKj0lQd+ZkOaz+CDRgTr4DUPcOudxMB5funOe/X+ZB5JdkOfROzxNqfpLn
4Jjw9ILS/yyHapF17g935ULEU7Ih+h7mOYTx6W6aOzsH4s7beQ6qbI1TnRdn
O8Tu8uRhmp7vsApkD0eOwxZQuMQVQNzHmQ2hWQsc9O+qsDV+L4a7D2SMf3Ux
XF6rXezmud9FcP1g/+sVw82/WvFSzXBTEdx+K5BC32K4++77A13cUAx3P8i5
79cWw/0HCtYCzxK4/8HyJ4vh4VOUMfFtzeF0iP53OZDwcUh32D9fSv/ulWyH
CaD45U6DyP/KhqpLcwAZf0ANKp+d5lAIsogny6EYZF51OsTcxVkOcSB/xGdA
1J3PdLAEuV85w+H2z7qsPQzZDqEgBxlnQsJ5ejZE/f90Bx9Q+OzNhsSzXCnc
fReUgDoZSuHy4PBJK4HrB7v/XQncfLD6CyVw+4+DzHMqhbtvJyh9nSqFux+k
rL+jFO4/sPyvUrj/eUHhF18KDx8AMi5sNg==
                    "]]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}}, {{1, 4, 3}, {0, 1, 0}, {1, 3, 3}}, {{1, 4,
                     3}, {0, 1, 0}, {1, 3, 3}}, {{1, 4, 3}, {0, 1, 0}, {1, 3, 
                    3}}, {{1, 4, 3}, {1, 3, 3}}}, {CompressedData["
1:eJxVVWtIFFEUFosSkwiLiLCyd9nD+hFSYp2KsKwoCxSiYhzc2XF3Z3RmZ5Me
SBGSPUlKKiKkRKEyidCealJSIZQmkmmGWUSSmElFVPSYe87M2RRk+Pbee+53
vvPdc6bKuVs8kREREbvtf/HFv/15EFSL+/f1aYA4kAvR7WV5KScCDtZhlMBH
fIxrnuyqL01TGc8ccaBk9UMF+vetWLLzrYMzPSDCrriWC3kpdsQ52fCu/Hxj
fLUOrdNe/SjweWBZtR1oig6zF0dVxv1RGD9an3R4ZbXKGOO151C8LB1WSe9b
pvX56NwLHTqefd/6rscPG+xjUqGzP8nhv1aHlWJ/aYDWZzr8YzXotFnUFmlQ
Z52aMPyPn84lavBc8Kv3McZ7fDmMz+qxBxseeGHswYami3c0yBi94MaFZAWW
Cr5lOpx88G3O9r9OvjEa3XdFIf5PfVDYl357co0Xjp+xA21WGaN+C8P4sdAh
RnX08MInsf7RS/FueEnHBBV23F0XE5nv7JdUuDLYulFe5IX60omJr4tURx+F
6hrph/vi9zcK5b1co3MvPVSnNp10W5RNv2/WKJ7lgaviu91PeSYpMEvokZzD
GPlEq4wxTq9Cev30UB26nTjHPKTngEJ1qZMp/4oc0rVOorzbAowvrbn55XeU
xhj1THF82yBRXnkanWuUYKfQZZhGOl+XSIfiANWzQqL7Jocxno/zMUbeaY5+
RhbF/apAl/BNrUz7K526XpRJJ0mhup+UwRB6jlHID0dl4q15Qbi/NiKL3p3f
0W+kRHqU+RmTDzXGia9njDhQnkv39Ergvl/0S7pMPBYYvI78400+T/4KMsb6
plmM84Vh1oWYX2rPnnFV30PMP+HQ+I5nzSHOL/66qRZfDnH+k7ZlJ3cXhlgf
9Gmnxfrh/sEg63tYGOKzydh2Y8boW2HcIvIvMLl+eD7V5Pqi3bNMrj/qs9dk
fyCfkjDG++ZbjFGPohD7r3uTfdOYXexPjHssxP6lr8X+xvcoh/E8oU96kHGc
uD/T5PezVuhZYvD7Qj9LJr8/ezW1pyDI7xPzvWfx+8V4zRa/b+Tz0eL3j/lF
h7g/YP4/LO4fuN5rcX9Bnu1hjHqeCzIWbW1gt8n9C+teZXB/Q79MN7n/oZ6q
yf3RxW7/dLHbX2NFHZJN7r+C7qZ+g/sz6tRlcP/G9TqD+7v24dflwdMG93/k
32zwfEC+nw2eHy5254uL3fmD+ZYbPJ8w3lyD51eRIHLC4PmG/JoMnn8uHjIf
bTxkfqYZQ+frf/P3HzZeSso=
                    "], CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQYNBQ6WW06U7WtOdOC+vrjAdlW+g8FdFbZG2wSH
CYe+asTcznXgAom/inO4ee578OO72XD+qo+XfJNE0uB8sHkOaQ419qZxuzLj
HL5pxPQfyk1zEFnn/rDqTayDcPOBUwvnpjnMyBNqPlAUCzHPNAfO3zdfSv8u
Rx6cX2ALNHlLvsOmue+XHzsMNR/o3oyJb2vsKxMcPB5WiaxTLYTLK2woypj4
uxCuf7IESxjf0yI4vxxkwcZSOL/1deAOuZOlcPeBzX9QCne/drvYzXNfS+H+
A5snWAzn75QDmiBUBOdXgwzSKoSHH3r4AgC2fJ4U
                    "], {{186.059, 
                    111.742}, {186.969, 110.74600000000001`}, {
                    187.90200000000002`, 109.77}, {188.85200000000003`, 
                    108.809}, {339.148, 108.809}, {340.09799999999996`, 
                    109.77}, {341.03099999999995`, 110.74600000000001`}, {
                    341.941, 111.742}}, {{195.336, 102.758}, {197.195, 
                    101.16799999999999`}, {199.105, 99.637}, {201.07, 
                    98.17599999999999}, {326.92999999999995`, 
                    98.17599999999999}, {328.895, 99.637}, {330.805, 
                    101.16799999999999`}, {332.66400000000004`, 102.758}}, {{
                    207.758, 93.59}, {211.164, 91.44100000000002}, {214.695, 
                    89.48}, {218.35200000000003`, 87.727}, {309.648, 
                    87.727}, {313.305, 89.48}, {316.83599999999996`, 
                    91.44100000000002}, {320.242, 93.59}}, {{225.055, 
                    84.793}, {237.105, 80.}, {250.24599999999998`, 77.367}, {
                    264., 77.367}, {277.754, 77.367}, {290.895, 80.}, {
                    302.945, 84.793}}}]}}, AspectRatio -> Automatic, 
                  ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 528.}, {0., 352.}}], ",", 
                 GraphicsBox[{
                   Thickness[0.0020833333333333333`], {
                    FaceForm[{
                    RGBColor[0., 0.501961, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     240.}, {480., 240.}, {480., 0.}, {0., 0.}}}]}, {
                    FaceForm[{
                    RGBColor[1., 0.8784310000000001, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{134.445, 170.}, {134.445, 141.16}, {111.062, 
                    117.777}, {82.223, 117.777}, {53.379, 117.777}, {30., 
                    141.16}, {30., 170.}, {30., 198.84}, {53.379, 
                    222.22299999999998`}, {82.223, 222.22299999999998`}, {
                    111.062, 222.22299999999998`}, {134.445, 198.84}, {
                    134.445, 170.}}}]}, {
                    FaceForm[{
                    RGBColor[0.501961, 0.12549000000000002`, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIVIGYCYmn9uypsG4MdHi+dfUQhIMGh+cCpha7fwnDy
K1+qGXLIhDtcULr9s64sweGbRkz/obdhDsIghZ0JDsUZE9/W7A9z2D9fSv/u
nASH14E75Fq5wxwWuW77/HcBVL8NVP5JggMDCCwIc1j18ZJvUkGiw96SyRIs
68IcfMw7HRNcEx2AtmTteRMGoSckQczTDoe4506yQ429adwuz3AHyy0nyvY9
TsXgg/13MQwn/5g30KIXYQ7qhhxrZJxSHS6C/LUozMEKJJ+f4nAHZG9MmAPI
W/ZzkyH63MMcZuQJNR/oSnYAWsbD9DvUoRXksJdJkPBaF+pQBNLgngRRtyjU
AWRto2USJBxiQh0mHPqqEXM70WGNTFSKtXgoxPzaRIfjIPcIhDr0TgdqrEh0
iAeZvzjEASScoJgIMcc0BOLeUwkOmSB9sSEQe14lOISAAybE4S0oILYlQPzD
FAIxdw5U/d1gB1W2xqnOixMg4XESGv8TEhxE1rk/rNoSDPFPLVQeKX2g8wEC
hwLd
                    "]]}, {
                    RGBColor[0.48235300000000003`, 0.192157, 0.], 
                    Thickness[0.002314814583333333], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIVIGYCYmn9uypsG4MdipbOY1UMSHBoPnBqoeu3MJz8
ypdqhhwy4Q4JSves6ssSHL5pxPQfehvmsKjpMPeizgSH4oyJb2v2hzn4zZct
uDsnweF14A65Vu4wBwPXnSb/FkD120DlnyQ4MIDAgjAHy49X+5IKEh32lkyW
YFkX5nDbrKcpwTXR4fbPuqw9b8Icsn42rt4zIQlinnY4xD13kh1q7E3jdnmG
O5zYfHr7vsepGHyw/y6G4eQf8zbvdHwR5rDNgPutjFOqw0UloI2LoPL5KQ53
QPbHhDn8mPBhr/3cZAfLLSfK9rmHOajliR450JXsALSMh+l3qIPI65Cfci+T
IOG1LtSBKWOKXq17ksOMPKHmA4tCHfbdUXdvtExyWOS67fPfmFAHuUM/MmNu
JzqskYlKsRYPhZhfm+hwHOQegVAHmemFwc0ViQ7xIPMXhzjcAoWHYqIDyPmN
piEQ955KcMgEBrd9bAjEPa8SHEIeL519RCHEoabGqSxuWwLEP0whDmHeVqcc
50DV3w122MLacs15cQIkPE5C439CgoPIOveHVVuCIf6phcojpQ90PgBfPP92

                    "], CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 0.8784310000000001, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{360.,
                     57.145}, {363.305, 46.863}, {373.402, 50.688}, {
                    367.42999999999995`, 41.69500000000001}, {376.715, 
                    36.184}, {365.957, 35.25}, {367.43799999999993`, 
                    24.555}, {360., 32.379}, {352.562, 24.555}, {354.043, 
                    35.25}, {343.28499999999997`, 36.184}, {352.57, 
                    41.69500000000001}, {346.59799999999996`, 50.688}, {
                    356.695, 46.863}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{360.,
                     217.14499999999998`}, {363.305, 206.863}, {373.402, 
                    210.68800000000002`}, {367.42999999999995`, 201.695}, {
                    376.715, 196.184}, {365.957, 195.25}, {
                    367.43799999999993`, 184.555}, {360., 192.379}, {352.562, 
                    184.555}, {354.043, 195.25}, {343.28499999999997`, 
                    196.184}, {352.57, 201.695}, {346.59799999999996`, 
                    210.68800000000002`}, {356.695, 206.863}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{300.,
                     152.14499999999998`}, {303.305, 141.863}, {313.402, 
                    145.68800000000002`}, {307.42999999999995`, 136.695}, {
                    316.715, 131.184}, {305.957, 130.25}, {
                    307.43799999999993`, 119.55499999999999`}, {300., 
                    127.37899999999999`}, {292.562, 119.55499999999999`}, {
                    294.043, 130.25}, {283.28499999999997`, 131.184}, {292.57,
                     136.695}, {286.59799999999996`, 145.68800000000002`}, {
                    296.695, 141.863}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    413.332, 168.14499999999998`}, {416.641, 157.863}, {
                    426.734, 161.68800000000002`}, {420.762, 152.695}, {
                    430.047, 147.184}, {419.29299999999995`, 146.25}, {
                    420.77299999999997`, 135.555}, {413.332, 143.379}, {
                    405.895, 135.555}, {407.375, 146.25}, {396.621, 
                    147.184}, {405.902, 152.695}, {399.92999999999995`, 
                    161.68800000000002`}, {410.027, 157.863}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{384., 120.}, {386.613, 113.59400000000001`}, {
                    393.512, 113.09}, {388.227, 108.62499999999999`}, {
                    389.879, 101.91000000000001`}, {384., 
                    105.55499999999999`}, {378.121, 101.91000000000001`}, {
                    379.77299999999997`, 108.62499999999999`}, {
                    374.48799999999994`, 113.09}, {381.387, 
                    113.59400000000001`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJ/IGZigIE8BzDlkOpw52dd1p6eLDgfTB9Id1Bla5zq
XJwE50P0xcH52z7/vVIhGY6qvyHQAcV8IF/dkGONzLx8VPmuAoj5h4McHi+d
fURBotDhPwgcD3EQbj5waiFvocPrwB1yrZtDHIDk60CWQofijIlva6aHOChs
KMqY+LPAAcS1bw1xuFrxUs3wUoHDjDyh5gNOIQ6TJVjC+FYWODy7oHT7J1+I
wzFv807HugIHkDKON8EOIG5CcIGDtP5dFbaTwQ5VIuvcH6oVOICs2bEt2KEa
xP+UD+eD3TsDwY/b5cnDZJ8P1w8272Ue3PxQPt1Ncyfnwe0Hyzvmwd239UTZ
vvmfcuHul41Ksb6/OBfuf7D6yFyIPdKhDv2HvmrECOc61Nqbxu2qDIXoO5vj
0DsdaOCNUIcJIPnuHKj5YQ5WW4AW+OdA1O8Mg/hfJAfiXsNwh70lwBC6l+1w
GxRvW8Ih7lmXDZF3jICYV5/tsMgVGMNnIiDhE5bt4NKd8/x3YqQDSFmjaTYk
Pv5HQs2Hqp8T5fCuBmjxryxI+nCMdtg3X0r/7ossiPybaIh/rmdB9M2IceC6
vrjA9lwWhPaKhfNh6Q3G/6YR039oaxxcvyXIn+nxcPPB7uJMgNsPTl/xCXD3
geU3JsDdfxwkzpAI9x84vP0T4f4Hq5uZCA8fsH/vJ8LDTwiUTlWT4OFbBJJP
T4KHv1PC0wtKi5Pg8QM2514SPP7A7hdOhscvWL1zMjz+LwKTT11RMjx9gINj
TjI8/fiA1O1NhqcviPnJ8PQHTh8/kuHpcw/I3Vwp8PQL9o90Cjx9F9gCQ1ol
BZ7+YXxY/oDxYfkHph+Wv2Dmw/IfzH5Y/oS5D5Z/Ye6H5W+wOVuS4fkfHO/L
kuHlA8z/sPLjLSie56Wgli+w8gupfAMAErP+jA==
                    "]]}, {
                    FaceForm[{
                    RGBColor[0., 0.501961, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {CompressedData["

1:eJxdVwlsFGUUhspVJA1qQQUUVAS8KCagBSR9oFJ67uwxu7M7uwWZ+eeoFEtB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                    "], {{100., 176.39100000000002`}, {101.812, 176.695}, {
                    100.039, 173.637}, {99.16799999999999, 173.68}, {99.242, 
                    174.781}, {96.543, 174.676}, {98.21900000000001, 
                    175.63299999999998`}, {98.762, 175.984}, {99.367, 
                    176.25}, {100., 176.39100000000002`}}}]}}, AspectRatio -> 
                  Automatic, ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 480.}, {0., 241.}}], ",", 
                 GraphicsBox[{
                   Thickness[0.0010416666666666667`], {
                    Thickness[0.0010416666666666667`], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     480.}, {960., 480.}, {960., 320.}, {0., 320.}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     320.}, {960., 320.}, {960., 160.}, {0., 160.}}}]}, {
                    FaceForm[{
                    RGBColor[0., 0.478431, 0.23921600000000004`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     160.}, {960., 160.}, {960., 0.}, {0., 0.}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.8078430000000001, 0.06666670000000002, 0.14902], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{0., 480.}, {
                    320., 240.}, {0., 0.}}}]}}, AspectRatio -> Automatic, 
                  ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 960.}, {0., 480.}}], ",", 
                 GraphicsBox[{
                   Thickness[0.0010416666666666667`], {
                    Thickness[0.0010416666666666667`], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     480.}, {960., 480.}, {960., 320.}, {0., 320.}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     320.}, {960., 320.}, {960., 160.}, {0., 160.}}}]}, {
                    FaceForm[{
                    RGBColor[0., 0.478431, 0.23921600000000004`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     160.}, {960., 160.}, {960., 0.}, {0., 0.}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.8078430000000001, 0.06666670000000002, 0.14902], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{0., 480.}, {
                    320., 240.}, {0., 0.}}}]}}, AspectRatio -> Automatic, 
                  ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 960.}, {0., 480.}}]}], "}"}], ",", 
             RowBox[{"{", 
               RowBox[{
                 GraphicsBox[{
                   Thickness[0.0010416666666666667`], {
                    FaceForm[{
                    RGBColor[0.8509800000000001, 0., 0.0705882], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 480.}, {960., 480.}, {960., 0.}}}]}, {
                    FaceForm[{
                    RGBColor[0., 0.2, 0.627451], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     320.}, {960., 320.}, {960., 160.}, {0., 160.}}}]}, {
                    FaceForm[{
                    RGBColor[0.9490200000000001, 0.6588240000000001, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     160.}, {960., 160.}, {960., 0.}, {0., 0.}}}]}}, 
                  AspectRatio -> Automatic, ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 960.}, {0., 480.}}], ",", 
                 GraphicsBox[{{
                    Thickness[0.0008333333333333334], {
                    FaceForm[{
                    RGBColor[0.870588, 0.160784, 0.06274510000000001], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 800.}, {1200., 800.}, {1200., 0.}}}]}}, {
                    RGBColor[1., 0.870588, 0.], 
                    
                    PolygonBox[{{{156.4073211147477, 585.837018249545}, {
                    129.465, 502.91799999999995`}, {200., 
                    554.1649280840463}, {270.53499999999997`, 
                    502.91799999999995`}, {243.5926788852523, 
                    585.837018249545}, {243.59267888525227`, 
                    585.837018249545}, {314.125, 637.082}, {
                    226.94199026174442`, 637.082}, {226.9419902617444, 
                    637.082}, {200., 720.}, {173.0580097382556, 637.082}, {
                    85.87499999999999, 637.082}}, {{365.699, 
                    699.4219999999999}, {394.02059683525385`, 
                    705.9407992661736}, {408.97299999999996`, 681.02}, {
                    411.5242212411751, 709.96961920159}, {439.84400000000005`,
                     716.488}, {413.10086862161455`, 727.8604005035999}, {
                    415.65200000000004`, 756.809}, {396.57181807195605`, 
                    734.8893074829407}, {369.828, 746.262}, {
                    384.7797301874549, 721.3423223683757}}, {{440.402, 
                    634.3439999999999}, {469.0343335503074, 
                    629.361789846223}, {473.14500000000004`, 600.594}, {
                    486.7292087861558, 626.2827677708841}, {486.7292087861558,
                     626.2827677708842}, {515.3589999999999, 
                    621.3009999999999}, {495.1246145642034, 
                    642.1591160197714}, {508.71099999999996`, 
                    667.8519999999999}, {482.6172094551196, 
                    655.0520653855589}, {462.383, 675.91}, {466.4935753121953,
                     647.1428479638266}}, {{465.6480604418864, 
                    514.7602115466024}, {457.66400000000004`, 486.816}, {
                    480.5486352299245, 504.73064709811763`}, {504.656, 
                    488.504}, {494.6909275247808, 515.8015762641411}, {
                    517.5740000000001, 533.715}, {488.53181121238066`, 
                    532.6734000943798}, {478.566, 559.9730000000001}, {
                    470.58218157485607`, 532.0296355119963}, {441.539, 
                    530.988}}, {{366.582, 418.01599999999996`}, {
                    394.60952440391605`, 425.7048046163738}, {
                    394.60952440391605`, 425.70480461637374`}, {410.582, 
                    401.42599999999993`}, {411.9307747145386, 
                    430.4565517714337}, {411.9307747145386, 
                    430.45655177143374`}, {439.957, 438.14500000000004`}, {
                    412.7643509911082, 448.3981538726199}, {414.113, 
                    477.42599999999993`}, {395.95886570694836`, 
                    454.73476442005847`}, {368.76599999999996`, 
                    464.98799999999994`}, {384.7381266235573, 
                    440.70972583588684`}}}]}}, AspectRatio -> Automatic, 
                  ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 1200.}, {0., 800.}}], ",", 
                 GraphicsBox[{
                   Thickness[0.001388888888888889], {
                    FaceForm[{
                    RGBColor[0.870588, 0.160784, 0.06274510000000001], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 480.}, {720., 480.}, {720., 0.}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{359.97299999999996`, 240.07}, {275.762, 
                    275.66}, {313.09, 385.33599999999996`}, {393.625, 
                    379.82}, {377.33599999999996`, 371.449}, {
                    374.97299999999996`, 355.824}, {384.277, 
                    341.35200000000003`}, {394.695, 325.14500000000004`}, {
                    383.316, 299.07}, {369.234, 292.734}, {
                    346.08599999999996`, 282.316}, {341.449, 254.535}, {
                    359.97299999999996`, 240.07}}}]}, {
                    FaceForm[{
                    RGBColor[0.870588, 0.160784, 0.06274510000000001], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{355.41799999999995`, 319.26599999999996`}, {
                    350.684, 311.828}, {348.965, 320.47999999999996`}, {
                    340.42199999999997`, 322.688}, {348.125, 327.}, {
                    347.58599999999996`, 335.801}, {354.055, 329.809}, {
                    362.258, 333.043}, {358.57, 325.03499999999997`}, {
                    364.172, 318.22999999999996`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{360.449, 240.99200000000002`}, {
                    350.262, 246.21899999999997`}, {342.051, 257.117}, {
                    338.47299999999996`, 270.137}, {334.383, 285.074}, {
                    336.734, 301.133}, {344.941, 314.168}, {343.172, 
                    315.28099999999995`}, {334.66, 301.73799999999994`}, {
                    332.219, 285.09}, {336.465, 269.58599999999996`}, {
                    340.246, 255.809}, {348.637, 244.71099999999998`}, {
                    359.4959999999999, 239.137}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{360.059, 240.047}, {367.883, 331.137}, {483.727, 
                    329.52299999999997`}, {503.371, 251.227}, {490.371, 
                    264.133}, {474.78099999999995`, 261.551}, {
                    463.89099999999996`, 248.23}, {451.699, 233.312}, {
                    423.387, 236.078}, {413.008, 247.516}, {395.945, 
                    266.312}, {368.094, 262.133}, {360.059, 240.047}}}]}, {
                    FaceForm[{
                    RGBColor[0.870588, 0.160784, 0.06274510000000001], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{433.969, 268.85200000000003`}, {
                    425.43399999999997`, 271.059}, {433.133, 275.363}, {
                    432.59, 284.172}, {439.07, 278.18}, {447.27299999999997`, 
                    281.40999999999997`}, {443.574, 273.40599999999995`}, {
                    449.188, 266.60200000000003`}, {440.42999999999995`, 
                    267.637}, {435.691, 260.207}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{361.082, 239.879}, {
                    362.90599999999995`, 251.184}, {370.72999999999996`, 
                    262.35900000000004`}, {382.012, 269.78499999999997`}, {
                    394.949, 278.29299999999995`}, {410.949, 
                    281.01599999999996`}, {425.883, 277.242}, {
                    426.39799999999997`, 279.26599999999996`}, {410.887, 
                    283.176}, {394.29699999999997`, 280.355}, {380.867, 
                    271.527}, {368.93399999999997`, 263.672}, {360.969, 
                    252.262}, {359.02299999999997`, 240.21499999999997`}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{360.062, 239.961}, {449.10900000000004`, 
                    260.668}, {483.375, 149.996}, {414.97999999999996`, 
                    107.117}, {423.23799999999994`, 123.46900000000001`}, {
                    415.965, 137.496}, {399.92999999999995`, 143.738}, {
                    381.977, 150.72299999999998`}, {375.855, 178.504}, {
                    383.527, 191.91}, {396.129, 213.945}, {383.551, 
                    239.14499999999998`}, {360.062, 239.961}}}]}, {
                    FaceForm[{
                    RGBColor[0.870588, 0.160784, 0.06274510000000001], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{410.29699999999997`, 178.566}, {409.758, 
                    187.36700000000002`}, {416.22999999999996`, 181.375}, {
                    424.441, 184.60899999999998`}, {420.746, 176.598}, {
                    426.35200000000003`, 169.79299999999998`}, {
                    417.59799999999996`, 170.84}, {412.85900000000004`, 
                    163.39800000000002`}, {411.137, 172.047}, {402.605, 
                    174.258}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{360.22299999999996`, 238.934}, {
                    371.53499999999997`, 240.691}, {384.582, 
                    236.70299999999997`}, {395.129, 228.26999999999998`}, {
                    407.219, 218.594}, {414.754, 204.21899999999997`}, {
                    415.777, 188.848}, {417.863, 188.984}, {416.789, 
                    204.945}, {408.977, 219.85200000000003`}, {
                    396.43399999999997`, 229.89800000000002`}, {
                    385.27299999999997`, 238.82000000000002`}, {
                    371.96099999999996`, 242.871}, {359.902, 240.996}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{359.984, 239.92600000000002`}, {407.191, 
                    161.637}, {312.527, 94.848}, {250.60899999999998`, 
                    146.648}, {268.715, 143.844}, {279.809, 155.098}, {
                    280.789, 172.277}, {281.883, 191.512}, {306.414, 
                    205.918}, {321.53499999999997`, 202.762}, {346.387, 
                    197.586}, {366.465, 217.336}, {359.984, 
                    239.92600000000002`}}}]}, {
                    FaceForm[{
                    RGBColor[0.870588, 0.160784, 0.06274510000000001], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{317.117, 173.18}, {325.32, 176.41}, {321.621, 
                    168.40200000000002`}, {327.234, 161.598}, {
                    318.47299999999996`, 162.637}, {313.734, 
                    155.19899999999998`}, {312.02299999999997`, 163.848}, {
                    303.484, 166.055}, {311.176, 170.36700000000002`}, {
                    310.641, 179.164}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{359.055, 239.461}, {
                    364.22299999999996`, 229.24599999999998`}, {
                    364.46099999999996`, 215.602}, {359.699, 202.965}, {
                    354.22999999999996`, 188.477}, {342.89099999999996`, 
                    176.86700000000002`}, {328.59, 171.14499999999998`}, {
                    329.363, 169.20299999999997`}, {344.21099999999996`, 
                    175.156}, {355.97299999999996`, 187.191}, {361.648, 
                    202.23}, {366.688, 215.598}, {366.42599999999993`, 
                    229.512}, {360.91799999999995`, 240.40200000000002`}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{359.92599999999993`, 239.99200000000002`}, {
                    300.055, 170.90200000000002`}, {207.281, 240.297}, {
                    237.414, 315.188}, {240.34, 297.105}, {
                    254.47299999999998`, 290.03099999999995`}, {271.113, 
                    294.40599999999995`}, {289.746, 299.309}, {311.027, 
                    280.42999999999995`}, {312.699, 265.078}, {315.453, 
                    239.844}, {340.445, 226.85200000000003`}, {
                    359.92599999999993`, 239.99200000000002`}}}]}, {
                    FaceForm[{
                    RGBColor[0.870588, 0.160784, 0.06274510000000001], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{283.199, 260.137}, {288.809, 253.336}, {280.047, 
                    254.375}, {275.309, 246.934}, {273.59, 255.59}, {265.055, 
                    257.79699999999997`}, {272.75, 262.09799999999996`}, {
                    272.21099999999996`, 270.89799999999997`}, {278.688, 
                    264.91799999999995`}, {286.887, 268.141}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{359.195, 240.73399999999998`}, {
                    351.074, 232.66}, {338.176, 228.21899999999997`}, {
                    324.684, 228.84}, {309.215, 229.562}, {294.672, 
                    236.766}, {284.809, 248.598}, {283.203, 247.262}, {
                    293.453, 234.98000000000002`}, {308.53499999999997`, 
                    227.512}, {324.58599999999996`, 226.762}, {
                    338.85900000000004`, 226.098}, {352.008, 230.648}, {
                    360.66400000000004`, 239.254}}}]}}, AspectRatio -> 
                  Automatic, ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 720.}, {0., 480.}}], ",", 
                 GraphicsBox[{
                   Thickness[0.001388888888888889], {
                    FaceForm[{
                    RGBColor[0.996078, 0., 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 480.}, {720., 480.}, {720., 0.}}}]}, {
                    FaceForm[{
                    RGBColor[0., 0., 0.5843139999999999], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     480.}, {360., 480.}, {360., 240.}, {0., 240.}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}}}, {{{204., 360.}, {180., 
                    270.}, {156., 360.}, {180., 450.}}, {{180., 336.}, {270., 
                    360.}, {180., 384.}, {90., 360.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}}}, {{{200.785, 348.}, {135., 
                    282.059}, {159.21499999999997`, 372.}, {225., 
                    437.941}}, {{168., 339.215}, {257.941, 315.}, {192., 
                    380.78499999999997`}, {102.059, 405.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2,
                     0}, {0, 1, 0}, {0, 1, 0}}}, {{{192., 339.215}, {102.059, 
                    315.}, {168., 380.78499999999997`}, {257.941, 405.}}, {{
                    159.21499999999997`, 348.}, {225., 282.059}, {200.785, 
                    372.}, {135., 437.941}}}]}, {
                    FaceForm[{
                    RGBColor[0., 0., 0.5843139999999999], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{231., 360.}, {231., 331.832}, {208.168, 309.}, {
                    180., 309.}, {151.83200000000002`, 309.}, {129., 
                    331.832}, {129., 360.}, {129., 388.168}, {
                    151.83200000000002`, 411.}, {180., 411.}, {208.168, 
                    411.}, {231., 388.168}, {231., 360.}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{225., 360.}, {225., 335.148}, {
                    204.85200000000003`, 315.}, {180., 315.}, {155.148, 
                    315.}, {135., 335.148}, {135., 360.}, {135., 
                    384.85200000000003`}, {155.148, 405.}, {180., 405.}, {
                    204.85200000000003`, 405.}, {225., 384.85200000000003`}, {
                    225., 360.}}}]}}, AspectRatio -> Automatic, 
                  ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 720.}, {0., 480.}}], ",", 
                 GraphicsBox[{
                   Thickness[0.001388888888888889], {
                    FaceForm[{
                    RGBColor[
                    0.9372550000000001, 0.698039, 0.17647100000000002`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 480.}, {720., 480.}, {720., 0.}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.886275, 0.23921600000000004`, 0.15686300000000003`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{0., 0.}, {
                    720., 0.}, {720., 480.}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{385.395, 
                    329.92999999999995`}, {381.402, 331.34400000000005`}, {
                    378.828, 329.28499999999997`}, {378.957, 324.133}, {
                    379.082, 318.97999999999996`}, {381.789, 316.02}, {
                    385.78099999999995`, 317.953}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{385.395, 
                    329.93}, {381.402, 331.344}, {378.828, 329.285}, {378.957,
                     324.133}, {379.082, 318.98}, {381.789, 316.02}, {
                    385.78099999999995`, 317.953}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    388.89799999999997`, 339.574}, {385.578, 342.199}, {
                    382.477, 341.074}, {380.941, 336.15200000000004`}, {
                    379.40999999999997`, 331.234}, {381.02, 327.562}, {
                    385.41799999999995`, 328.10900000000004`}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    388.89799999999997`, 339.57399999999996`}, {385.578, 
                    342.19899999999996`}, {382.477, 341.07399999999996`}, {
                    380.941, 336.152}, {379.40999999999997`, 
                    331.23400000000004`}, {381.02, 327.562}, {
                    385.41799999999995`, 328.109}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    394.42999999999995`, 348.914}, {391.566, 
                    352.03499999999997`}, {388.328, 351.42199999999997`}, {
                    386.02299999999997`, 346.812}, {383.72299999999996`, 
                    342.203}, {384.72299999999996`, 338.32}, {389.156, 
                    338.15200000000004`}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    394.42999999999995`, 348.914}, {391.566, 
                    352.03499999999997`}, {388.328, 351.422}, {
                    386.02299999999997`, 346.812}, {383.72299999999996`, 
                    342.203}, {384.72299999999996`, 338.32}, {389.156, 
                    338.152}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{390.805, 
                    303.527}, {385.90999999999997`, 301.727}, {385.395, 
                    295.027}, {388.48799999999994`, 290.90599999999995`}, {
                    391.578, 286.78499999999997`}, {397.242, 286.012}, {
                    400.332, 290.90599999999995`}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{390.805, 
                    303.52700000000004`}, {385.90999999999997`, 
                    301.72700000000003`}, {385.395, 295.02700000000004`}, {
                    388.48799999999994`, 290.906}, {391.578, 286.785}, {
                    397.242, 286.01199999999994`}, {400.332, 290.906}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{385.137, 317.695}, {380.5, 
                    319.23799999999994`}, {376.324, 313.012}, {375.605, 
                    307.39099999999996`}, {374.707, 300.309}, {364.66, 
                    297.99199999999996`}, {370.199, 287.301}, {371.355, 
                    294.125}, {375.867, 297.85900000000004`}, {379.469, 
                    298.117}, {383.078, 298.375}, {388.48799999999994`, 
                    299.148}, {390.805, 303.527}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{385.137, 317.695}, {380.5, 319.238}, {376.324, 
                    313.01199999999994`}, {375.605, 307.391}, {374.707, 
                    300.30899999999997`}, {364.66, 297.99199999999996`}, {
                    370.199, 287.30100000000004`}, {371.355, 294.125}, {
                    375.867, 297.85900000000004`}, {379.469, 
                    298.11699999999996`}, {383.078, 298.375}, {
                    388.48799999999994`, 299.14799999999997`}, {390.805, 
                    303.52700000000004`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{399.82, 
                    290.133}, {394.40999999999997`, 288.848}, {393.637, 
                    281.633}, {397.5, 276.484}, {400.805, 272.074}, {411.148, 
                    273.137}, {410.895, 277.512}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{399.82, 
                    290.133}, {394.40999999999997`, 288.84799999999996`}, {
                    393.637, 281.633}, {397.5, 276.48400000000004`}, {400.805,
                     272.07399999999996`}, {411.148, 273.137}, {410.895, 
                    277.51199999999994`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{415.14500000000004`, 
                    246.73399999999998`}, {415.39799999999997`, 251.371}, {
                    407.93399999999997`, 253.172}, {404.328, 
                    252.27299999999997`}, {400.719, 251.371}, {393.828, 
                    252.40200000000002`}, {392.219, 256.26599999999996`}, {
                    390.93399999999997`, 253.172}, {392.801, 249.824}, {
                    398.01599999999996`, 248.15200000000002`}, {401.965, 
                    246.883}, {401.879, 244.031}, {400.719, 242.742}, {
                    403.684, 242.227}, {412.441, 242.227}, {
                    415.14500000000004`, 246.73399999999998`}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{415.14500000000004`, 246.734}, {
                    415.39799999999997`, 251.371}, {407.93399999999997`, 
                    253.17199999999997`}, {404.328, 252.273}, {400.719, 
                    251.371}, {393.828, 252.402}, {392.219, 256.266}, {
                    390.93399999999997`, 253.17199999999997`}, {392.801, 
                    249.824}, {398.01599999999996`, 248.152}, {401.965, 
                    246.883}, {401.879, 244.031}, {400.719, 242.742}, {
                    403.684, 242.22700000000003`}, {412.441, 
                    242.22700000000003`}, {415.14500000000004`, 246.734}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{410.895, 276.355}, {405.613, 278.672}, {402.484, 
                    275.141}, {400.465, 271.719}, {397.5, 266.695}, {388.355, 
                    273.137}, {385.26599999999996`, 266.43799999999993`}, {
                    389.453, 268.242}, {393.715, 264.395}, {395.695, 
                    263.09}, {401.363, 259.355}, {412.309, 
                    260.51599999999996`}, {413.855, 269.27299999999997`}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{410.895, 276.355}, {405.613, 
                    278.67199999999997`}, {402.484, 275.14099999999996`}, {
                    400.465, 271.719}, {397.5, 266.695}, {388.355, 273.137}, {
                    385.26599999999996`, 266.438}, {389.453, 
                    268.24199999999996`}, {393.715, 264.395}, {395.695, 
                    263.09000000000003`}, {401.363, 259.355}, {412.309, 
                    260.51599999999996`}, {413.855, 269.273}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    413.984, 270.172}, {408.703, 266.18}, {
                    406.64500000000004`, 261.414}, {406.77299999999997`, 
                    258.195}, {406.902, 254.977}, {411.40999999999997`, 
                    247.895}, {416.305, 247.508}, {419.137, 
                    253.30100000000002`}, {420.555, 265.53499999999997`}, {
                    413.984, 270.172}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    413.984, 270.17199999999997`}, {408.703, 
                    266.17999999999995`}, {406.64500000000004`, 261.414}, {
                    406.77299999999997`, 258.195}, {406.902, 254.977}, {
                    411.40999999999997`, 247.895}, {416.305, 
                    247.50799999999998`}, {419.137, 253.30100000000002`}, {
                    420.555, 265.53499999999997`}, {413.984, 
                    270.17199999999997`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{392.094, 
                    245.316}, {392.094, 247.25}, {394.92599999999993`, 
                    248.023}, {396.855, 247.379}, {398.789, 
                    246.73399999999998`}, {401.75, 244.805}, {400.719, 
                    242.742}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{392.094, 
                    245.316}, {392.094, 247.25}, {394.92599999999993`, 
                    248.023}, {396.855, 247.379}, {398.789, 246.734}, {401.75,
                     244.805}, {400.719, 242.742}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    362.98799999999994`, 255.879}, {362.47299999999996`, 
                    258.195}, {366.207, 262.188}, {371.22999999999996`, 
                    260.}, {376.25, 257.809}, {376.895, 253.559}, {374.832, 
                    251.88700000000003`}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    362.98799999999994`, 255.879}, {362.47299999999996`, 
                    258.195}, {366.207, 262.188}, {371.22999999999996`, 
                    260.}, {376.25, 257.80899999999997`}, {376.895, 
                    253.559}, {374.832, 251.88700000000003`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{375.219, 
                    251.629}, {374.832, 252.918}, {378.449, 
                    255.48800000000003`}, {384.621, 253.945}, {390.805, 
                    252.40200000000002`}, {392.32, 248.42200000000003`}, {
                    392.094, 245.316}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{375.219, 
                    251.629}, {374.832, 252.91799999999998`}, {378.449, 
                    255.488}, {384.621, 253.945}, {390.805, 252.402}, {392.32,
                     248.422}, {392.094, 245.316}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{362.34400000000005`, 255.879}, {
                    365.562, 258.324}, {364.34400000000005`, 
                    262.96099999999996`}, {361.441, 264.379}, {356.16, 
                    266.953}, {358.094, 273.648}, {354.742, 
                    274.93799999999993`}, {351.395, 276.227}, {348.176, 
                    278.543}, {348.047, 280.863}, {346.371, 
                    277.64500000000004`}, {347.402, 274.68}, {
                    349.72299999999996`, 272.621}, {352.039, 270.559}, {
                    347.91799999999995`, 262.188}, {350.879, 260.}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{362.34400000000005`, 255.879}, {
                    365.562, 258.324}, {364.34400000000005`, 262.961}, {
                    361.441, 264.379}, {356.16, 266.953}, {358.094, 
                    273.64799999999997`}, {354.742, 274.938}, {351.395, 
                    276.22700000000003`}, {348.176, 278.543}, {348.047, 
                    280.863}, {346.371, 277.645}, {347.402, 
                    274.67999999999995`}, {349.72299999999996`, 272.621}, {
                    352.039, 270.55899999999997`}, {347.91799999999995`, 
                    262.188}, {350.879, 260.}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{293.316, 
                    257.68}, {290.60900000000004`, 261.92999999999995`}, {
                    284.172, 261.16}, {281.469, 258.195}, {278.762, 
                    255.23399999999998`}, {279.148, 250.85500000000002`}, {
                    281.72299999999996`, 248.92600000000002`}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{293.316, 
                    257.67999999999995`}, {290.60900000000004`, 261.93}, {
                    284.172, 261.15999999999997`}, {281.469, 258.195}, {
                    278.762, 255.234}, {279.148, 250.85500000000002`}, {
                    281.72299999999996`, 248.92600000000002`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{308.77, 
                    263.99199999999996`}, {307.73799999999994`, 269.656}, {
                    300.914, 270.301}, {297.18, 268.887}, {293.445, 
                    267.469}, {290.867, 261.801}, {293.316, 257.68}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{308.77, 
                    263.99199999999996`}, {307.73799999999994`, 269.656}, {
                    300.914, 270.30100000000004`}, {297.18, 
                    268.88700000000006`}, {293.445, 267.469}, {290.867, 
                    261.80100000000004`}, {293.316, 257.67999999999995`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{319.07, 264.76599999999996`}, {321.52, 
                    269.527}, {316.754, 276.613}, {311.34400000000005`, 
                    277.64500000000004`}, {306.828, 278.5}, {
                    301.49199999999996`, 278.47999999999996`}, {299.754, 
                    282.92199999999997`}, {298.66, 279.059}, {301.559, 
                    276.613}, {304.90599999999995`, 274.42199999999997`}, {
                    308.254, 272.234}, {304.262, 266.566}, {309.672, 
                    263.348}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{319.07, 264.766}, {321.52, 
                    269.52700000000004`}, {316.754, 276.61299999999994`}, {
                    311.34400000000005`, 277.645}, {306.828, 278.5}, {
                    301.49199999999996`, 278.48}, {299.754, 282.922}, {298.66,
                     279.05899999999997`}, {301.559, 276.61299999999994`}, {
                    304.90599999999995`, 274.422}, {308.254, 
                    272.23400000000004`}, {304.262, 266.56600000000003`}, {
                    309.672, 263.34799999999996`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{318.555, 
                    264.60200000000003`}, {317.42999999999995`, 268.012}, {
                    319.715, 272.555}, {324.34400000000005`, 
                    272.23799999999994`}, {328.969, 271.91799999999995`}, {
                    331.605, 268.555}, {329.566, 264.35200000000003`}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{318.555, 
                    264.602}, {317.42999999999995`, 268.01199999999994`}, {
                    319.715, 272.555}, {324.34400000000005`, 272.238}, {
                    328.969, 271.918}, {331.605, 268.555}, {329.566, 
                    264.352}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    328.85900000000004`, 264.34400000000005`}, {
                    328.22299999999996`, 267.879}, {331.121, 272.055}, {
                    335.66, 271.09}, {340.195, 270.125}, {342.332, 
                    266.42599999999993`}, {339.727, 262.551}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    328.85900000000004`, 264.344}, {328.22299999999996`, 
                    267.879}, {331.121, 272.055}, {335.66, 
                    271.09000000000003`}, {340.195, 270.125}, {342.332, 
                    266.42600000000004`}, {339.727, 262.55100000000004`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    339.08599999999996`, 262.719}, {338.625, 
                    266.28099999999995`}, {341.734, 270.309}, {346.215, 
                    269.117}, {350.699, 267.92999999999995`}, {352.648, 
                    264.125}, {349.85200000000003`, 260.387}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    339.08599999999996`, 262.719}, {338.625, 
                    266.28100000000006`}, {341.734, 270.30899999999997`}, {
                    346.215, 269.11699999999996`}, {350.699, 267.93}, {
                    352.648, 264.125}, {349.85200000000003`, 
                    260.38700000000006`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{261.375, 
                    203.72299999999998`}, {252.75, 203.72299999999998`}, {
                    250.641, 201.668}, {249.39800000000002`, 
                    192.77299999999997`}, {247.85500000000002`, 
                    181.69899999999998`}, {262.92199999999997`, 180.41}, {
                    261.375, 203.72299999999998`}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{261.375, 
                    203.723}, {252.75, 203.723}, {250.641, 201.668}, {
                    249.39800000000002`, 192.77300000000002`}, {
                    247.85500000000002`, 181.699}, {262.92199999999997`, 
                    180.41000000000003`}, {261.375, 203.723}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    265.242, 215.312}, {251.977, 220.336}, {244.766, 
                    199.344}, {231.629, 203.078}, {236.32800000000003`, 
                    195.60899999999998`}, {247.72299999999998`, 203.062}, {
                    251.977, 202.305}, {259.188, 201.016}, {274.77, 
                    203.72299999999998`}, {265.242, 215.312}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    265.242, 215.312}, {251.977, 220.33599999999996`}, {
                    244.766, 199.344}, {231.629, 203.07800000000003`}, {
                    236.32800000000003`, 195.60900000000004`}, {
                    247.72299999999998`, 203.06200000000007`}, {251.977, 
                    202.305}, {259.188, 201.01600000000002`}, {274.77, 
                    203.723}, {265.242, 215.312}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{256.613, 
                    186.594}, {250.04299999999998`, 189.555}, {242.961, 
                    179.512}, {244.25, 175.13299999999998`}, {245.883, 
                    169.57}, {260.863, 174.102}, {256.613, 186.594}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{256.613, 
                    186.59400000000005`}, {250.04299999999998`, 189.555}, {
                    242.961, 179.51200000000006`}, {244.25, 
                    175.13299999999998`}, {245.883, 169.57000000000005`}, {
                    260.863, 174.10200000000003`}, {256.613, 
                    186.59400000000005`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxlVGlIVFEUniwqF2pS2y1arIwQkwhR0U5URGU12aAzzvbefbOmY2ISpmaI
rahZZAuUie2E9MNKSsxKBlFplUJFzGwTNQmVLIuod+cbJqiBx51z37nf+c73
nfsWst2JlvEKhWKc/GyXHx/5OZceWPgoPo382y5nxPWLtCxyclVIdRptiTq2
VmgWyY/vxzuptOFrmP6ISBFdoRMLljipvmJORNcNgR7yNcBJnWP5u+rKTFRy
Vga0p9K6orTen756SuA4gw7st+uAl2mnjy8WdY5d03nq2mgbU2qigzWUESdn
XLFSdfmX641BWpLZtVS+tiH/8N/484578w/F6pHvstP+NauNtdMMlGk/OZg3
004rOc8SA/jV2Ygf25CfQoN5cuIbqzeOudO0t/63xRu78cosVDPy61X2/WTE
B81kqN0U4DPgibMkmn5rY09OiIYU/KeRwL9YTSEp5tjuKJF6coJvbSxQUxXf
iDAh3qemuVzA5ToK5uerVPQg69SsCTVaUr+/et6lSqTRMH1pQ5ceeK5E6LDY
iLVQTW6/fATUzUiCX4dFrz5GzjNWgh+hGjrBfXsuoX5PCvLnS/BhWEu87AIV
o0/8fL72Pzx3v0cF6HFSS5Ub5H8fjOjLlASeVXr43ZyMfkYNtGRiwel1I8l4
/8STf0CD/SAB+X1azIVLgF8GHeo1iYidHr5nGHTr01HSlPDq8jaJWjndGCP8
GzBTdt/SyMkJevS9wIp5iDRhvlosdGRGx7NvhSa8V1roJT+/2UTR/LxkJj42
a04biYcVNRJwuw3Qp53BH6UJugUyb3233isY3Rxq3cqUAvr5LgHfz0SXuF6z
LMAPF+guxzda4WO/QMd5fpoNutwW0G+6HfsXBMzzJBvwLgrwM9cKnGER811s
pmSuS6mIOncl8DB77quvBH73GOqsYrSUr/4M9zyaoY8iRuu5L7MlrEMMeinM
uDd7GfTvNYP/DxF+rbeAzzsG3aba6NCAfEEfi7j/T20UxC/YJpFy+RgGOrz1
3fq8ddAeTrzI871pdJDs1s73HSLqq/7mu/1ptOOcgqHfeQ7Pd8vDb0sq8M4z
+vf79gfoVTIT
                    "]]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxlVGlIVGEUnSzalDKLsjJps4wQk4gyKU+kRWk1meiMs733vVnVMYmISrFC
s0JbJK2gjfZ+DP0wExNbGcSijSiyxbIFSs2ipJ2od98dRqiBx5v7vbuce869
3wSxOsPRV6fT9VGfFeoToj4HCiJKr87Px+BHJwrndcqYmjDQF1Wbj/TZOxZI
N2Q+n+/FnutfYs3bZMS3Te6/JcaLq0fHxLedlXCF3mFePPtRkttUbcPO/WpC
dx5Qkf/21yAz5+n2oJLOW02cb40b7+5NfPrjtAmhWl0X0kW4IXGEAYXzVI+T
TtQd/nimebgRKrqbxx662L+8136/siF6a5KZ/f1ubE6eZW0cZsEad1V38Sg3
ZhDOnRbG1+RCmRqWWpKD7mLV8bkzaM+ta1l3+Y8jaGv5qh2o6/n9YP3FbLbL
7JAal4SFdAXstQpGnFv8cmOUATr6GRTGX5mJqBx70ovZMt5sVD22ZMJHB/E2
tJO9IRNjicBpJo736XFp7d7IfvVGGF6fOujXZ+BrrHn39TYz9JTPn4Fa4mGS
lfkozYSmV4jEdQuzWK9yOciPlXAmKWgnPSYbWLe7CuN5mcP+0QrCiPfPRlDZ
8XrB8SXG//Jp/W6X0EB8VBlxLLW+5/cbK/dly8Jywukzs943srmfrxao7Ncs
7Mnm77cC/psMiKHz4RL7dxh5XvwS62Uxcb0WmW1vAO8+gUjircOErCFxtYcf
KXhAcOdaWb8uO9Z3TEkYmG7GU+p7vJPnIcHG83XTgcqRj+98K7Xx93AHxy+1
IZHiFTtobJJrVJ5V82i9gjn054WF+WkVrE+4jec3QgTra3xPF/B9ur9MhEvc
z/cAvsE2HCe+Ih3IpfxxEi5QfqsT+0jHTgm7yD/fhSnEy3mJ+y1w874cknie
B7igyXNEYj2LnKinPJ9lnu9KO/OyW+Y+Ligcbw/s6yCF8TUI5n+mYH1CBdJo
PxMF91EhkEK6jFawiN6fBPOls+MD7c06wXXe2hn/T5n1SnEwnleC9RjqQnmX
uqDXZN7/2y7e2yUyimgMIzzB+ho/7R7usyJw3zR78OTOt1WvH8tcX9/rr+nT
7OY4neB+x3kQq91bAXxpeZzvoMC/99tff9QyQQ==
                    "], 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    237.42200000000003`, 151.691}, {231.758, 156.07}, {
                    223.90200000000002`, 150.789}, {218.49200000000002`, 
                    152.85200000000003`}, {218.49200000000002`, 
                    149.24599999999998`}, {220.297, 143.836}, {
                    226.21899999999997`, 141.777}, {228.023, 143.062}, {
                    236.137, 150.148}, {237.42200000000003`, 151.691}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    237.42200000000003`, 151.69099999999997`}, {231.758, 
                    156.07000000000005`}, {223.90200000000002`, 
                    150.78900000000004`}, {218.49200000000002`, 
                    152.85199999999998`}, {218.49200000000002`, 
                    149.24599999999998`}, {220.297, 143.83599999999996`}, {
                    226.21899999999997`, 141.77700000000004`}, {228.023, 
                    143.06200000000007`}, {236.137, 150.14799999999997`}, {
                    237.42200000000003`, 151.69099999999997`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{246.309, 
                    164.184}, {237.42200000000003`, 168.691}, {235.879, 
                    157.48800000000003`}, {228.92200000000003`, 159.805}, {
                    229.18, 156.586}, {231.758, 152.594}, {
                    237.42200000000003`, 151.691}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{246.309, 
                    164.18400000000003`}, {237.42200000000003`, 
                    168.69099999999997`}, {235.879, 157.488}, {
                    228.92200000000003`, 159.805}, {229.18, 156.586}, {
                    231.758, 152.59400000000005`}, {237.42200000000003`, 
                    151.69099999999997`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{251.59, 
                    174.359}, {238.453, 179.512}, {236.777, 
                    166.89100000000002`}, {229.05100000000002`, 169.336}, {
                    230.85500000000002`, 164.95700000000002`}, {241.93, 
                    162.641}, {247.598, 164.184}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{251.59, 
                    174.35899999999998`}, {238.453, 179.51200000000006`}, {
                    236.777, 166.89099999999996`}, {229.05100000000002`, 
                    169.33599999999996`}, {230.85500000000002`, 164.957}, {
                    241.93, 162.64099999999996`}, {247.598, 
                    164.18400000000003`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{269.617, 
                    229.605}, {266.141, 234.5}, {258.801, 230.508}, {257.641, 
                    224.71099999999998`}, {256.484, 218.918}, {259.316, 
                    210.805}, {264.21099999999996`, 212.605}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{269.617, 
                    229.605}, {266.141, 234.5}, {258.801, 
                    230.50799999999998`}, {257.641, 224.711}, {256.484, 
                    218.918}, {259.316, 210.805}, {264.21099999999996`, 
                    212.60500000000002`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{278.504, 
                    245.062}, {272.453, 246.477}, {265.4959999999999, 
                    245.83200000000002`}, {266.27, 239.91}, {263.953, 
                    238.879}, {263.309, 231.281}, {269.617, 229.605}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{278.504, 
                    245.06199999999998`}, {272.453, 246.477}, {
                    265.4959999999999, 245.832}, {266.27, 239.91}, {263.953, 
                    238.879}, {263.309, 231.28100000000003`}, {269.617, 
                    229.605}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{282.4959999999999, 249.05100000000002`}, {
                    276.574, 256.008}, {269.965, 255.844}, {266.27, 
                    252.918}, {259.445, 247.508}, {252.812, 250.598}, {
                    252.621, 245.18800000000002`}, {256.742, 248.344}, {
                    260.348, 244.547}, {263.695, 245.70299999999997`}, {
                    267.043, 246.863}, {269.49199999999996`, 
                    240.42600000000002`}, {278.762, 243.129}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{282.4959999999999, 249.05100000000002`}, {
                    276.574, 256.008}, {269.965, 255.844}, {266.27, 
                    252.91799999999998`}, {259.445, 247.50799999999998`}, {
                    252.812, 250.59799999999998`}, {252.621, 245.188}, {
                    256.742, 248.344}, {260.348, 244.547}, {263.695, 
                    245.703}, {267.043, 246.863}, {269.49199999999996`, 
                    240.42600000000002`}, {278.762, 243.129}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    268.203, 145.125}, {269.105, 143.44899999999998`}, {
                    274.641, 142.676}, {277.348, 145.512}, {
                    280.92999999999995`, 149.266}, {276.96099999999996`, 
                    159.676}, {271.29299999999995`, 160.44899999999998`}, {
                    265.625, 161.22299999999998`}, {265.113, 148.73}, {
                    268.203, 145.125}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    268.203, 145.125}, {269.105, 143.449}, {274.641, 
                    142.676}, {277.348, 145.51200000000006`}, {
                    280.92999999999995`, 149.26600000000002`}, {
                    276.96099999999996`, 159.676}, {271.29299999999995`, 
                    160.449}, {265.625, 161.223}, {265.113, 
                    148.73000000000002`}, {268.203, 145.125}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{261.762, 
                    144.86700000000002`}, {269.875, 141.906}, {273.355, 
                    148.602}, {268.977, 152.85200000000003`}, {267.816, 
                    151.434}, {263.566, 146.285}, {261.762, 
                    144.86700000000002`}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{261.762, 
                    144.86700000000002`}, {269.875, 141.906}, {273.355, 
                    148.60200000000003`}, {268.977, 152.85199999999998`}, {
                    267.816, 151.43400000000003`}, {263.566, 
                    146.28500000000003`}, {261.762, 144.86700000000002`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYCYtmoFOv7r3McvM07HRN2Jji8q7E3jduV47DI
ddvnvyoJDtUi69wf7sp2OA5SwAOVn5XlYHBXha2xNsbBpTvn+e/KTAeu64sL
bB9FONw89z34cWqGwzeNmP5DqVEOVltOlO2Tz3CI3eXJw/Q6HK7+TeAOuVbp
KIi6ziyHNTJAhyyPcGAAgYhsh5DHS2cfuRDlkDHxbY39xBwHoGuuVEjGOTgl
PL2gNDkXIr8g1mH1x0u+STx5DkDTtduvxUP9kefgCFJXn+gAMvb+9QKHKpA/
yhId7vv3Ts97U+CgD3L/x2QHoCkKG3IKHOJA7lNOcRBuPnBq4cZcuHr08AEA
nyiJLw==
                    "]]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYCYtmoFOv7r3McfMw7HRN2Jji8q7E3jduV47DA
ddvnvyoJDtUi69wf7sp2OOYNVMADlZ+V5WBwV4WtsTbGwaU75/nvykwHnuuL
C2wfRTjcPPc9+HFqhsMPjZj+Q6lRDlZbTpTtk89wSNjlycP0Ohyu/k3gDrlW
6SiHbyB1nVkOa2SADlke4cAAAhHZDhGPl84+ciHKIWPi2xr7iTkOWz7/vVIh
GefglPD0gtLkXIj8gliH1R8v+Sbx5Dl48DBpt1+Ld/AG+yMPoq4+0QFk7P3r
BQ41IH+UJTrc9++dnvemAOL+j8kOQFMUNuQUQNynnOIg3Hzg1MKNuXD16OED
AKdgiUI=
                    "], CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{434.59, 328.512}, {444.895, 
                    325.16400000000004`}, {445.148, 311.77}, {
                    456.9959999999999, 307.39099999999996`}, {468.848, 
                    303.012}, {470.008, 292.453}, {479.66400000000004`, 
                    295.027}, {470.648, 297.477}, {471.29299999999995`, 
                    307.90599999999995`}, {461.895, 310.47999999999996`}, {
                    450.867, 313.504}, {446.695, 330.316}, {
                    437.93799999999993`, 332.89099999999996`}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{434.59, 328.51199999999994`}, {444.895, 
                    325.164}, {445.148, 311.77}, {456.9959999999999, 
                    307.391}, {468.848, 303.01199999999994`}, {470.008, 
                    292.453}, {479.66400000000004`, 295.02700000000004`}, {
                    470.648, 297.477}, {471.29299999999995`, 307.906}, {
                    461.895, 310.48}, {450.867, 313.504}, {446.695, 
                    330.31600000000003`}, {437.93799999999993`, 332.891}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC0c0HTi2UrXOISrG+769Z4HBR6fbPOqs6hxl5
Qs0HzuU7vK2xN40zq3OQBSl4nOfgbd7pmHC+1mFvyWQJlmV5DrG7PHmY2Osc
GEAgASofWefg0p3z/PfCPIels48obGirc3gHMscq32EZiO9U5wC2lzfP4dMl
3ySBAij/b45D+b75Uvq3oeadyHFwf1glsm55nYO6IccamVm5DkBbw/ik6x1a
XwfukPubC1H3rQ7Cb82D8K3qHSYc+qoR453nYLXlRNm+0nqHm+e+Bz+emAsx
r7ge4k+5XAegpteBZ+odVn0EOuRJLkS9Yb3DY5DD3+Q5gLjz/eod9O+qsDUu
zXcAAC1GhAA=
                    "]]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC0c0HTi2UrXOISrG+769Z4HBR6fbPOqs6hxl5
Qs0HzuU7vK2xN40zq3OQBSl4nOfgbd7pmHC+1mFPyWQJlmV5DrG7PHmY2Osc
GEAgASofWefg3J3z/PfCPIels48obGirc3gHMscq32EZiO9U5wC2lzfP4dMl
3ySBAij/b45D+b75Uvq3oeadyHFwf1glsm55nYO6IccamVm5DkBbw/ik6x1a
XwfukPubC1H3rQ7Cb82D8K3qHSYc+qoR453nYLXlRNm+0nqHm+e+Bz+emAsx
r7ge4k+5XAegpteBZ+odVn0EOuRJLkS9Yb3DY5DD3+Q5gLjz/eod9O6qsDUu
zXcAACtug/0=
                    "], CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIxIGYC4p1yra8DP1U6rP54yTeJJ8MhKsX6vn9vpYNw
84FTC/dmOBz3Nu90TKp0UDfkWCNzL93h0FeNmH6DSocJIIY2VJ6p0qEoY+Lb
muIMB6Dm6XlHKhy+AZUdqs1wmJ4n1HxgTYWDEMg8U6j5zJUOxSD1+hkOi1y3
ff57o8JB/64KW+PKdIfc579XfmyodOgFaexIh8vfPPc9+HFhugOv7qa5779X
OFSLrHN/+CsVYm57hYMP0BkJvGkOQN/skPtf4TADZK9WKsQ8m0qHfpB7r6c5
aLeL3Tw3t9IBZL39xDS4fbd/1mXtaYDqP13pcAvE/wE1fzrUf86pDpMlWML4
Xlc6hPEBHeIO5fNWOQBNM43TS3Ow5bq+uEC8CuLepWkOAJL2qh0=
                    
                    "]]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIxIGYC4p1yra8DP1U6rPp4yTeJJ8MhKsX6vn9vpYNQ
84FTC/dmOBz3Nu90TKp0UDPkWCNzL93h0FeNmH6DSoc+EEMbKs9U6VCSMfFt
TXGGA1Dz9LwjFQ7fgMoO1WY4TM8DmrSmAmKeKdR8Zqh6/QyHRa7bPv+9UeFg
cFeFrXFlukPu898rPzYAzQdp7EiHy9869z34cWG6A6/uprnvv1c4VImsc3/4
KxVibnuFgw/QGQm8aQ5A3+yQ+1/hMA1kr1YqxDybSocJIPdeT3PQbhe7eW5u
pUMW0Hr7iWlw++78rMva0wDVfxrK/wE1fzrUvc6pDpMlWML4Xlc6hPEBHeIO
5fNWObyrsTeN00tzsOW6vrhAvAri3qVpDgCTRqol
                    "], 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIlIGYC4rhdnjxMzoUOMlEp1vfbExxkQbRsoYNQ84FT
C48mOMzIA7I2FThsPVG2b/6jBAeFDUUZEzsLHFpfB+6Q25jgsEMOyEoocAjn
0900tz7BYTpIfV6Bgypb41Tn4gSHqxUv1QwXFDiA7clOcPB4WCWy7mIBxNyk
BAf9uypsjYKFELo13uFtjb1p3LICh01z3y8/VhzvkPv898qPJQUOIOtas+Md
7LiuLy5oLXAwAKnvjYWolytwEFnn/rAqJ9ZhC8idHgUOIOe7zotxKN83X0r/
YIED0HbtdrVYh/v+vdPz3hQ4SIMs5IyDuO9JgUNxxsS3Nf6xDgwgoFQIUb8s
xgEUHP6chQ7/QeB4tIMiyP+hhQ5PLyjd/rks2gGkzV6z0AHkLFujOAcrkAMW
FjqAvOkuGAcJn4JCh15QwPyIhfinpdDhDcg/1jEOtiCNtwsdnoHMWxfjwKsL
8nmhA8hZHD4xkHA6VOiwyHXb578x0RD3/4G6b1q0g7d5p2PC9UKIO1KjIeF8
utDBEuSO5VEOIGPr/hU6iILCxyYKYr5+ESS8fKIh7vtRCAkPyXgH9PQAANOF
8IM=
                    "]]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIlIGYC4rhdnjxMzoUOMlEp1vfbExxkQbRsoYNQ84FT
C48mOMzIA7I2FThsO1G2b/6jBAeFDUUZEzsLHNpeB+6Q25jgsEOu9XVgQoFD
GJ/uprn1CQ7TQerzChzU2BqnOhcnOFyteKlmuKDAAWxPdoKDx8MqkXUXCyDm
JiU46N9VYWsULHQwANGt8Q5va+xN45YVOGyZ+375seJ4h9znv1d+LClweAO0
rjU73sGO6/rigtYCiPreWIh6uQIHkXXuD6tyYh22gNzpUeDQAnS+67wYh/J9
86X0DxY4+PAwaberxTrc9++dnvemwEECZDFnHMR9TwocSjImvq3xj3VgAAGl
Qoj6ZTEOoODw5yyEiJ+IdlAE+T+00OHFBaXbP5dFO4C02WsWOvAAnWVrFOdg
BXLAwkKHJ0BvugvGQcKnoNChBxQwP2Ih/mkphPjHOsbBFuSf21Dz1sU48AKD
8f3yQgeQszh8YiDhdKjQYYHrts9/Y6Ih7v9T6OABct+0aAdv807HhOuFDjkg
d6RGQ8L5dKGDBcgdy6McQMbW/SuEhI9NFMR8/SII3yca4r4fhZDwkIx3QE8P
ACEa65k=
                    "], CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{556.676, 274.34400000000005`}, {566.535, 
                    274.34400000000005`}, {574.523, 282.33599999999996`}, {
                    574.523, 292.195}, {574.523, 302.051}, {566.535, 
                    310.043}, {556.676, 310.043}, {546.8159999999999, 
                    310.043}, {538.828, 302.051}, {538.828, 292.195}, {
                    538.828, 282.33599999999996`}, {546.8159999999999, 
                    274.34400000000005`}, {556.676, 274.34400000000005`}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{556.676, 274.344}, {566.535, 274.344}, {574.523, 
                    282.336}, {574.523, 292.195}, {574.523, 
                    302.05100000000004`}, {566.535, 310.043}, {556.676, 
                    310.043}, {546.8159999999999, 310.043}, {538.828, 
                    302.05100000000004`}, {538.828, 292.195}, {538.828, 
                    282.336}, {546.8159999999999, 274.344}, {556.676, 
                    274.344}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxdVGtIVEEUXm2RMBULDZMwrYiebAUVKtrZLNRKtASTKBHJksX23rm+3Ycz
V9IkJETIIkwkM+yHbKYmUZuViPgj1AyJFN3ETMosIySix8w9lxVcGIbZmXPm
e82NypFO564yGAw+fCTz4cvH+SfJAb5Ldsirm7cfviVBlEvJq0txgPb/Jhni
/MfuysMO6D9xqMacJMPiSEpO8G4nTKXWNlj9Zbh3uy/SVeX01keK+kcV8Lwp
3DRhlKB6/bvXS1so2ELaEz0jEkyLAiuFoc3vfznTZChx84N1FPtWybjfQSHJ
Ux7SXibDxrMXYicHKZgmtvoxkww3resqez/p9QEytMgcYSCDnogrn0/56f02
MDiSPcOPSPCGt800M+Ao0qcfSlA2t23f6kwGglacWwKD+JUxOMnpZTdKWN/M
sH+/BJanhfVhLxgIGKk7ZHj5c/u564sM+YTLcCPhWv5spAr1YcaMoFxdr/0q
cDUOZI3KyP+iCq1CpyldP4sKb0s5kAyC/ZNVmBR6thAoFffvVIGjmRlyEexv
VuHy7O+271SBV+L+YQbRnQPF7jMK4vdRcY5Q8Pw4gy6+3fRA72/U8RURELIm
zjHvOjiTd+pniDeLAHd9V7WbIc4ggjgGGPpxjOA9zxj6YCE4dzHg6vdElBC4
Ks536/q1Evgg7lMZ4g9XsF8aQz2+EfSnkGF+PDq+bAZi8lgJ+lXOgN8y2JxA
oPvHn9HSSwxzZtb1SWeYVxNBfZKW8Wt+xjKI1wwnsFbwXbPcP3BPR+PCVwpZ
or5gea3lrZJgLuap1x+tfo4in079/nGK+n3U9R6hqEeUAgv3+csZo5jPfAV1
cVNoELod1P1qo5irLwSOC/0bKfJ5TKBPEC1esR9K8T3eIYhrqAL9qSEQI3JR
VOH1V9P7qNPrh/Ze/zq8+mtzjwPzHKPgeq8D85mnIE+XHfNfq6BPPnbk06tg
Dv/ZEActwHzE23DfWAhBQs9oG9aHFiCPFrv3+7Ly+/MfbnUMuQ==
                    
                    "]]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxdVGtIFFEUXksizMSemIRpRfRkK6iwSL+lIu1BVmASJRI9TGxn7mil7q7e
O1JmESFFD8JCMsN+hJmVRC32wMQfoZskYaEmZVJZGRERPebsGVZo4TLcvXPO
+V53EnZpW/aMdDgcYdZKtdYIa+28lxo54ocX+ys+eZMvaEioM7IrNvqQSf9P
07EyovOK3u5D8/pl5a4UHUOBjbui5xeje9PJc+4IHVcvPomvO1ocqo+n+lsl
8F+Odb4O11A2+eWzHzMkPBNvrO0NaOijArdE+/Sun8VpOg7TixWS+x7V+bxe
IqW3aOKNQh1Tt+9e0d0q4Xw9c5Ry6jjvHl/a9F4iQPWROqp1C+FYhca4Ix82
j7L7TVFwZb1tm96l4bnVNsOlYKHY2ndTQ+HArEWjMxSI1kq/Bgf9ChWIXlal
xvVVivE1a8i5n3865qECwdg0R8ej77N3nBpSKCI+sTrOrjqR2x9v4kxMeHrU
HluvxSYGvclLMjt05r/XRA3p1GPrl2PiRYEFJF1w/1QTPaRntUABzZ9r4jgR
qBPc32Uit/9X7Vdp4DHNb1dY3tByyL/NYPxhJj/jDH7/lQIdX75u9w+38R0U
IFnXDqjQPjojsaGlWTHeTAHL9XllfsU4owTKCUeLYj/WCJ7zQOEc+ZAj2I/b
Cpb6jXGHBY7R+3ds/WoE3tA8UzH+WIP7pSnW44tgf/IVsik/vTa+LMV5cQv2
q0hhQmlTa9UqgTvffncU7FOcM5etz1bFeXUK1idlGH/QzxUKSUHDBcYR3zHD
/ccuqK/8PCi5Pm94H8xbqcAGysUnGfInWD8gmU+DPf+VZP3e2XoHJOuRYODz
NevmdErOZ66BNtLFL1m3pbZftZJxfxRYR/pX2njuCjwhoof+O58k8ZQCe0nw
PWwrYX/KBefiYEnI36Deq4tDfgTv6x9fSP/gs9HHeV5u8H6hDx2Uz2wDB4hn
nZfzf9Jgn8K8zKfJQCLN++thfWQe5yPJw+fh+YgiPRM9XD8pj+9PtTf0ffn/
+/MPmF0Mzg==
                    "], CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{337.22999999999996`, 138.945}, {346.758, 
                    138.945}, {354.48799999999994`, 146.672}, {
                    354.48799999999994`, 156.19899999999998`}, {
                    354.48799999999994`, 165.73}, {346.758, 
                    173.45700000000002`}, {337.22999999999996`, 
                    173.45700000000002`}, {327.699, 173.45700000000002`}, {
                    319.97299999999996`, 165.73}, {319.97299999999996`, 
                    156.19899999999998`}, {319.97299999999996`, 146.672}, {
                    327.699, 138.945}, {337.22999999999996`, 138.945}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{337.22999999999996`, 138.945}, {346.758, 
                    138.945}, {354.48799999999994`, 146.67200000000003`}, {
                    354.48799999999994`, 156.199}, {354.48799999999994`, 
                    165.73000000000002`}, {346.758, 173.457}, {
                    337.22999999999996`, 173.457}, {327.699, 173.457}, {
                    319.97299999999996`, 165.73000000000002`}, {
                    319.97299999999996`, 156.199}, {319.97299999999996`, 
                    146.67200000000003`}, {327.699, 138.945}, {
                    337.22999999999996`, 138.945}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxFUw1IFEEUvqykX4kKKSkpMZHLyIIQrcMvKiQsLAOJLGv3bnYv0bKdOY0K
SU6RECupSCiRCosiQsxMKs0yUgKlhAopM7Myy35UJESFdu4NtjAsb2bf976f
2eX64VQ21eFwTLGXy15B9qoPL/qx86SF2tbcxspgN+auqqn4fd/CzxOJ6zJy
dVw8NN/fFMpxT57n61i6x7O+28WR8WDrnKASHccW3knqyeBoEOcWTfugUX8L
x+aSrL6xHg3eMhtphGNFcMGFTX6NcCIESiVwpAZ7en14g8D70fzMRzEaPqbY
J98FzddV/xNBfZkaknrsiSUCDvlc1vD6aH/Umt3qfEij/TBB/NJ15DVWhq2O
E0iQAle66T1doLP9765enxunNh748tIpcGuwY7ve6sbVLXXDE7Gq3uFBudQf
rb4v8pC+FEF67nrInyyBbXE20oQHx6UfOQKvIt6N5kcwqmsF4TgZ+fxH4LFN
qyuHIVn2zfSR3usM3VJ/jI/88TDiU+gjPQ/Vea2PdCQzVF16tqy6UdXpBs3b
4CMfBgwE8v0qyMcyAzK+lGblb52BpyPRe88YAgv8TS+uVBjolYBpAi2SWJZB
ffGKb6HC/8ZJ31oDzuLQzvZmTufjiu8Ax+y313JcToP8H+aYJesag3z4xBEv
+fYak3kE9DpMwo8ROCuJ7Tcn8wj4W2XSXF3xOW+Sn7cF3cM3JuloU/qemxiy
Y5xXrvJI9cIliSQKusd+L+X3mSMtxA42z4t90udiTrqzvZP3O5BTv5qfyhEl
809XfMPU94tN8nsGJ50JBrL7xm4OLuE4LQcNMKrHLcL5xWD/NWkh3RaOSGLV
jPo6LNJRyojvDYv2axjtH7QQ2xUZXNDGKE/X//ofZNLBEA==
                    "]]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxFUw1IFEEUvqykwiQqpMSkREQuIwtCsg6/iJKwsAwksqzdu929RE125jRK
pFCRMCvpR6FEKiwCETEzKRPLMAkUEyoqzMzKLDN/kBAV2udbbGFY3sy89/3t
rlNPJmnzHQ7HPGu5rOVnrcbQwl8HzppoaM9urvR3Y+mGuoo/j0wM58ZtSc1W
UZa5PL8lSKCezvNUrDns2dbrEkh9vCfAr1jF6ZU18X2pAk3yyqoFnxTufymw
uzh9YKpPgbf0d27chECE/7lrO/MVPKQ5YRIXaHC4Agu9MfSpxIfJvLSmKAWf
E0vKMn9KjBC+avc/k4yfpiC+z0IslnDQc1PBm1ODEZsOSeY/pvB+sGR+KSpy
miuDN8ZIxNKA9W5+L7TwOv8e7Pe5cX7H8W9dTonq0e59arsbt3c1jM9E2/V+
D8pJf6R9v9DD+hIl63ngYX/SJfbGWJNmPDhDfmRJdId9nMwL07iul7hO95wa
6xiRaLFo9WRpSKC+xT72+66GXtIf5WN/PBrzKfCxnif2eb2PdSRoqLrxYm1t
s12n6Iy33cc+DOmYzfe7RBr5WKqD4ktslYzXoOP5ROSRS7qExe7VrQod/TQw
WaKNiKXr7P9WCbKxp8Ce/0Owvs06nEVB7ztbBeuZtvkOCSx5dyfL5dTZ/3GB
AKrrdPbzi2C+/fpcHhdJr8Pg+VESl4nYMWMuj1l/qwy8JlzV5nPVYD+rJXKp
762BFaSjw9bXZmDMinFZuZ1HkhcuIhYnEUJG5Hs5v68CyYFWsDleHCWfiwT7
leGd+75n8Qdt/CSBcMo/xeYbbN9fbbDfiwTnHasjY2Dq/miI4DyHNK6nTXTR
nGEN1l+THNhrwiRitRr7021yHiUa871n8n6dxvpOmIjusRh0aJyn63/9D4+S
wSA=
                    "], CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    293.059, 181.441}, {291.89799999999997`, 184.789}, {
                    293.43399999999997`, 187.805}, {294.215, 
                    190.45700000000002`}, {296.21099999999996`, 
                    197.21899999999997`}, {294.98799999999994`, 
                    198.95700000000002`}, {288.93799999999993`, 198.055}, {
                    288.42199999999997`, 194.836}, {291.512, 
                    184.27299999999997`}, {293.059, 181.441}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    293.059, 181.44099999999997`}, {291.89799999999997`, 
                    184.78900000000004`}, {293.43399999999997`, 187.805}, {
                    294.215, 190.457}, {296.21099999999996`, 
                    197.21900000000005`}, {294.98799999999994`, 198.957}, {
                    288.93799999999993`, 198.055}, {288.42199999999997`, 
                    194.83599999999996`}, {291.512, 184.27300000000002`}, {
                    293.059, 181.44099999999997`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    288.613, 197.668}, {290.16, 196.121}, {295.633, 
                    195.414}, {296.21099999999996`, 200.309}, {296.879, 
                    205.92600000000002`}, {294.60200000000003`, 208.102}, {
                    289.707, 205.91}, {289.324, 204.621}, {288.871, 
                    199.344}, {288.613, 197.668}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    288.613, 197.668}, {290.16, 196.12099999999998`}, {
                    295.633, 195.41400000000004`}, {296.21099999999996`, 
                    200.30900000000003`}, {296.879, 205.926}, {
                    294.60200000000003`, 208.10200000000003`}, {289.707, 
                    205.91000000000003`}, {289.324, 204.62099999999998`}, {
                    288.871, 199.344}, {288.613, 197.668}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    289.77299999999997`, 206.102}, {291.832, 205.266}, {
                    296.277, 203.594}, {298.72299999999996`, 
                    208.35500000000002`}, {300.777, 212.35500000000002`}, {
                    298.078, 215.441}, {293.832, 215.184}, {292.801, 
                    214.023}, {290.73799999999994`, 209.90200000000002`}, {
                    289.77299999999997`, 206.102}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    289.77299999999997`, 206.10200000000003`}, {291.832, 
                    205.26600000000002`}, {296.277, 203.59400000000005`}, {
                    298.72299999999996`, 208.35499999999996`}, {300.777, 
                    212.35499999999996`}, {298.078, 215.44099999999997`}, {
                    293.832, 215.18400000000003`}, {292.801, 
                    214.02300000000002`}, {290.73799999999994`, 
                    209.90200000000004`}, {289.77299999999997`, 
                    206.10200000000003`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    293.574, 215.57}, {294.08599999999996`, 214.023}, {
                    299.367, 208.871}, {303.22999999999996`, 212.605}, {
                    307.094, 216.344}, {307.094, 221.879}, {301.301, 
                    223.941}, {299.754, 223.684}, {295.117, 
                    218.27299999999997`}, {293.574, 215.57}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    293.574, 215.57000000000005`}, {294.08599999999996`, 
                    214.02300000000002`}, {299.367, 208.87099999999998`}, {
                    303.22999999999996`, 212.60500000000002`}, {307.094, 
                    216.344}, {307.094, 221.87900000000002`}, {301.301, 
                    223.94099999999997`}, {299.754, 223.68400000000003`}, {
                    295.117, 218.27300000000002`}, {293.574, 
                    215.57000000000005`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    301.301, 223.941}, {302.457, 220.71899999999997`}, {
                    306.062, 215.184}, {312.762, 217.758}, {319.457, 
                    220.336}, {316.625, 228.70299999999997`}, {
                    313.53499999999997`, 230.379}, {311.72999999999996`, 
                    230.25}, {304.39099999999996`, 226.90200000000002`}, {
                    301.301, 223.941}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    301.301, 223.94099999999997`}, {302.457, 
                    220.71900000000005`}, {306.062, 215.18400000000003`}, {
                    312.762, 217.75799999999998`}, {319.457, 
                    220.33599999999996`}, {316.625, 228.703}, {
                    313.53499999999997`, 230.379}, {311.72999999999996`, 
                    230.25}, {304.39099999999996`, 226.902}, {301.301, 
                    223.94099999999997`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    313.53499999999997`, 230.379}, {313.02, 227.547}, {
                    313.53499999999997`, 219.82000000000002`}, {322.676, 
                    219.94899999999998`}, {331.82, 220.078}, {329.246, 
                    230.766}, {326.92599999999993`, 232.312}, {323.191, 
                    232.312}, {316.883, 232.184}, {313.53499999999997`, 
                    230.379}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    313.53499999999997`, 230.379}, {313.02, 227.547}, {
                    313.53499999999997`, 219.82}, {322.676, 219.949}, {331.82,
                     220.07800000000003`}, {329.246, 230.76600000000002`}, {
                    326.92599999999993`, 232.31199999999998`}, {323.191, 
                    232.31199999999998`}, {316.883, 232.184}, {
                    313.53499999999997`, 230.379}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{327.312, 
                    231.92600000000002`}, {326.28499999999997`, 
                    229.73399999999998`}, {323.96099999999996`, 215.324}, {
                    341.867, 219.305}, {344.184, 219.82000000000002`}, {
                    350.234, 233.08200000000002`}, {327.312, 
                    231.92600000000002`}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{327.312, 
                    231.92600000000002`}, {326.28499999999997`, 229.734}, {
                    323.96099999999996`, 215.324}, {341.867, 219.305}, {
                    344.184, 219.82}, {350.234, 233.082}, {327.312, 
                    231.92600000000002`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    337.10200000000003`, 230.637}, {335.301, 
                    228.83200000000002`}, {339.93399999999997`, 214.281}, {
                    352.039, 216.727}, {364.14500000000004`, 219.176}, {
                    353.97299999999996`, 232.953}, {337.10200000000003`, 
                    230.637}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    337.10200000000003`, 230.637}, {335.301, 228.832}, {
                    339.93399999999997`, 214.281}, {352.039, 
                    216.72700000000003`}, {364.14500000000004`, 219.176}, {
                    353.97299999999996`, 232.953}, {337.10200000000003`, 
                    230.637}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{347.402, 
                    228.44899999999998`}, {345.47299999999996`, 
                    224.45700000000002`}, {348.371, 212.605}, {363.309, 
                    212.605}, {376.848, 212.605}, {362.60200000000003`, 
                    228.191}, {347.402, 228.44899999999998`}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{347.402, 
                    228.44899999999998`}, {345.47299999999996`, 
                    224.45700000000002`}, {348.371, 212.60500000000002`}, {
                    363.309, 212.60500000000002`}, {376.848, 
                    212.60500000000002`}, {362.60200000000003`, 228.191}, {
                    347.402, 228.44899999999998`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{359.121, 
                    224.969}, {358.15200000000004`, 222.758}, {356.965, 
                    210.195}, {374.578, 209.129}, {387.328, 
                    208.35500000000002`}, {384.23799999999994`, 
                    226.38700000000003`}, {359.121, 224.969}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{359.121, 
                    224.969}, {358.15200000000004`, 222.75799999999998`}, {
                    356.965, 210.195}, {374.578, 209.12900000000002`}, {
                    387.328, 208.35499999999996`}, {384.23799999999994`, 
                    226.38700000000003`}, {359.121, 224.969}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{378.055, 
                    219.691}, {375.867, 215.82800000000003`}, {373.547, 
                    206.168}, {392.863, 205.395}, {405.23799999999994`, 
                    204.89800000000002`}, {397.629, 219.434}, {378.055, 
                    219.691}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{378.055, 
                    219.69099999999997`}, {375.867, 215.82799999999997`}, {
                    373.547, 206.168}, {392.863, 205.39499999999998`}, {
                    405.23799999999994`, 204.89799999999997`}, {397.629, 
                    219.43400000000003`}, {378.055, 219.69099999999997`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    394.15200000000004`, 216.727}, {391.32, 212.863}, {
                    393.40599999999995`, 205.285}, {400.59, 
                    203.85200000000003`}, {409.605, 202.047}, {410.895, 
                    210.547}, {404.715, 214.668}, {398.53099999999995`, 
                    218.789}, {394.15200000000004`, 216.727}, {
                    394.15200000000004`, 216.727}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    394.15200000000004`, 216.72700000000003`}, {391.32, 
                    212.863}, {393.40599999999995`, 205.28500000000003`}, {
                    400.59, 203.85199999999998`}, {409.605, 
                    202.04700000000003`}, {410.895, 210.54700000000003`}, {
                    404.715, 214.668}, {398.53099999999995`, 
                    218.78900000000004`}, {394.15200000000004`, 
                    216.72700000000003`}, {394.15200000000004`, 
                    216.72700000000003`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    402.90999999999997`, 214.92600000000002`}, {
                    400.85200000000003`, 211.32000000000002`}, {402.125, 
                    202.562}, {415.78499999999997`, 202.562}, {418.621, 
                    202.562}, {429.441, 213.637}, {402.90999999999997`, 
                    214.92600000000002`}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    402.90999999999997`, 214.926}, {400.85200000000003`, 
                    211.32}, {402.125, 202.56200000000007`}, {
                    415.78499999999997`, 202.56200000000007`}, {418.621, 
                    202.56200000000007`}, {429.441, 213.637}, {
                    402.90999999999997`, 214.926}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{297.184, 46.98}, {308.246, 46.98}, {317.219, 
                    55.949}, {317.219, 67.012}, {317.219, 
                    78.07799999999999}, {308.246, 87.051}, {297.184, 
                    87.051}, {286.117, 87.051}, {277.148, 
                    78.07799999999999}, {277.148, 67.012}, {277.148, 
                    55.949}, {286.117, 46.98}, {297.184, 46.98}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{297.184, 46.98000000000002}, {308.246, 
                    46.98000000000002}, {317.219, 55.94900000000001}, {
                    317.219, 67.01200000000006}, {317.219, 
                    78.07800000000003}, {308.246, 87.05099999999999}, {
                    297.184, 87.05099999999999}, {286.117, 
                    87.05099999999999}, {277.148, 78.07800000000003}, {
                    277.148, 67.01200000000006}, {277.148, 
                    55.94900000000001}, {286.117, 46.98000000000002}, {
                    297.184, 46.98000000000002}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxdVwtQVFUYRjGnFJ0syyegZNb4ptREI38lI80H8lriJexe7j4k3Lv3LrLs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                    "]]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxdVwlsVFUULRSNYjGiKIiUTYIGRUBB22rlAiKLIKXb1G5MZ37/LNQ6f5nS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                    "], 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{515.8549999999999, 121.215}, {528.031, 
                    121.215}, {537.898, 131.08200000000002`}, {537.898, 
                    143.254}, {537.898, 155.42600000000002`}, {528.031, 
                    165.297}, {515.8549999999999, 165.297}, {503.684, 
                    165.297}, {493.812, 155.42600000000002`}, {493.812, 
                    143.254}, {493.812, 131.08200000000002`}, {503.684, 
                    121.215}, {515.8549999999999, 121.215}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{515.8549999999999, 121.21500000000003`}, {
                    528.031, 121.21500000000003`}, {537.898, 
                    131.08200000000005`}, {537.898, 143.25400000000002`}, {
                    537.898, 155.426}, {528.031, 165.29700000000003`}, {
                    515.8549999999999, 165.29700000000003`}, {503.684, 
                    165.29700000000003`}, {493.812, 155.426}, {493.812, 
                    143.25400000000002`}, {493.812, 131.08200000000005`}, {
                    503.684, 121.21500000000003`}, {515.8549999999999, 
                    121.21500000000003`}}}, CurveClosed -> {1}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{431.758, 
                    337.27}, {426.863, 315.633}, {430.984, 
                    305.84799999999996`}, {438.195, 296.31600000000003`}, {
                    453.10200000000003`, 276.621}, {464.984, 
                    231.66799999999998`}, {447.984, 202.305}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{457.512, 227.676}, {
                    459.574, 228.44899999999998`}, {463.43799999999993`, 
                    230.895}, {464.34000000000003`, 235.14499999999998`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{459.059, 
                    237.07399999999998`}, {459.703, 240.81199999999998`}, {
                    465.4959999999999, 242.41799999999998`}, {465.625, 
                    246.414}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{459.188, 251.629}, {
                    458.801, 255.492}, {464.984, 258.969}, {464.078, 
                    262.832}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{455.84000000000003`, 
                    265.53499999999997`}, {455.324, 267.72700000000003`}, {
                    460.98799999999994`, 271.84799999999996`}, {459.445, 
                    275.324}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{451.59, 
                    279.05899999999997`}, {450.42999999999995`, 281.508}, {
                    454.29299999999995`, 284.34000000000003`}, {452.621, 
                    286.914}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{445.40599999999995`, 
                    289.875}, {445.02, 291.55100000000004`}, {447.402, 
                    295.223}, {446.117, 297.40999999999997`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{439.227, 302.625}, {
                    439.73799999999994`, 303.27}, {441.805, 
                    304.81600000000003`}, {440.965, 306.746}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{434.977, 311.961}, {
                    435.812, 312.414}, {438.324, 313.188}, {438.004, 
                    315.055}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{306.062, 
                    69.14499999999998}, {300.914, 70.945}, {
                    294.47299999999996`, 68.37099999999998}, {293.188, 
                    63.988}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{297.051, 
                    60.}, {297.695, 64.375}, {304.39099999999996`, 
                    66.30900000000003}, {306.449, 64.25}, {302.199, 
                    66.56600000000003}, {300.141, 58.327999999999975`}, {
                    303.875, 58.06600000000003}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{338.51599999999996`, 
                    161.86700000000002`}, {335.42599999999993`, 160.32}, {
                    334.527, 154.65599999999995`}, {338.51599999999996`, 
                    150.40200000000004`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    343.15200000000004`, 160.57800000000003`}, {340.965, 
                    158.77700000000004`}, {341.094, 153.36700000000002`}, {
                    344.312, 152.07800000000003`}, {341.60900000000004`, 
                    154.01200000000006`}, {344.312, 157.35899999999998`}, {
                    346.246, 157.488}, {348.176, 157.61700000000002`}, {
                    349.465, 155.29700000000003`}, {347.14500000000004`, 
                    152.98000000000002`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{524.094, 
                    147.832}, {516.883, 149.76200000000006`}, {
                    511.08599999999996`, 141.39099999999996`}, {
                    517.6519999999999, 133.92200000000003`}, {
                    517.5269999999999, 141.13299999999998`}, {522.676, 
                    145.89799999999997`}, {528.988, 144.60900000000004`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    526.09, 139.62099999999998`}, {524.3159999999999, 
                    139.62099999999998`}, {523.3199999999999, 
                    138.23400000000004`}, {523.3199999999999, 
                    136.88299999999998`}, {523.3199999999999, 
                    135.46500000000003`}, {524.543, 134.113}, {526.539, 
                    134.113}, {527.828, 134.113}, {528.8589999999999, 
                    135.59400000000005`}, {528.8589999999999, 
                    136.75400000000002`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{551.523, 
                    297.73400000000004`}, {552.6840000000001, 293.355}, {
                    558.738, 291.55100000000004`}, {563.5, 292.582}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{563.5, 
                    295.414}, {559.766, 295.285}, {556.676, 298.762}, {
                    556.934, 301.72700000000003`}, {556.934, 
                    299.53499999999997`}, {561.9569999999999, 298.504}, {
                    563.5, 299.922}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{307.867, 
                    148.344}, {306.83599999999996`, 150.92200000000003`}, {
                    310.957, 153.49599999999998`}, {311.08599999999996`, 
                    155.94099999999997`}, {311.215, 158.39099999999996`}, {
                    315.72299999999996`, 160.32}, {320.35900000000004`, 
                    155.68400000000003`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{318.172, 
                    183.11700000000002`}, {317.27, 182.73000000000002`}, {
                    316.4959999999999, 182.21500000000003`}, {
                    315.72299999999996`, 181.957}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{327.055, 
                    169.07800000000003`}, {325.96099999999996`, 
                    169.01200000000006`}, {323.707, 169.14099999999996`}, {
                    322.484, 169.98000000000002`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{322.547, 
                    164.18400000000003`}, {321.648, 163.73400000000004`}, {
                    319.648, 162.961}, {318.49199999999996`, 
                    162.70300000000003`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{278.375, 
                    86.39799999999997}, {278.246, 84.07800000000003}, {
                    280.566, 80.73400000000004}, {281.85200000000003`, 
                    79.70300000000003}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{288.42199999999997`, 
                    91.93799999999999}, {287.133, 90.00800000000004}, {
                    286.35900000000004`, 86.65599999999995}, {287.133, 
                    84.33999999999997}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    307.60900000000004`, 84.21100000000001}, {
                    305.29299999999995`, 85.75799999999998}, {
                    306.83599999999996`, 89.75}, {306.578, 
                    92.32400000000001}, {306.32, 94.89799999999997}, {
                    309.28499999999997`, 99.02000000000004}, {315.078, 
                    95.543}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{285.97299999999996`, 
                    98.89099999999996}, {288.29299999999995`, 
                    99.27700000000004}, {290.73799999999994`, 
                    99.14799999999997}, {292.28499999999997`, 
                    98.50800000000004}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{315.33599999999996`, 
                    106.23400000000004`}, {314.305, 104.81599999999997`}, {
                    314.051, 103.27000000000004`}, {313.92199999999997`, 
                    102.238}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{326.156, 106.488}, {
                    324.35200000000003`, 106.488}, {322.805, 
                    105.20300000000003`}, {322.03499999999997`, 
                    103.91400000000004`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{301.172, 172.426}, {
                    303.22999999999996`, 171.71900000000005`}, {308.574, 
                    168.43400000000003`}, {308.77, 165.02000000000004`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{323.062, 189.168}, {
                    316.754, 189.29700000000003`}, {314.305, 195.738}, {
                    319.07, 195.738}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{334.395, 
                    180.53900000000004`}, {331.949, 179.51200000000006`}, {
                    333.10900000000004`, 175.26200000000006`}, {
                    336.58599999999996`, 173.199}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{319.328, 
                    140.10200000000003`}, {318.105, 141.64799999999997`}, {
                    319.715, 146.152}, {323.707, 144.805}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{328.72999999999996`, 
                    93.09800000000001}, {328.984, 97.02300000000002}, {
                    333.945, 99.344}, {335.941, 94.89799999999997}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{310.441, 
                    81.89499999999998}, {310.121, 86.20700000000005}, {
                    312.309, 87.625}, {314.242, 87.87900000000002}, {316.172, 
                    88.137}, {318.941, 86.531}, {320.22999999999996`, 
                    83.695}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{272.066, 
                    78.67200000000003}, {272.324, 81.25}, {274.512, 
                    83.95299999999997}, {276.832, 83.56600000000003}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{507.73799999999994`, 
                    193.031}, {506.062, 191.80900000000003`}, {504.969, 
                    186.33599999999996`}, {511.34400000000005`, 185.82}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{497.949, 
                    184.01600000000002`}, {497.949, 183.375}, {
                    498.78499999999997`, 182.473}, {499.305, 182.086}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{528.3439999999999, 
                    173.71500000000003`}, {526.668, 175.00400000000008`}, {
                    522.3519999999999, 169.78500000000003`}, {
                    526.2810000000001, 165.988}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{487.39099999999996`, 
                    130.445}, {486.42199999999997`, 134.113}, {
                    489.83599999999996`, 135.08200000000005`}, {493.055, 
                    134.30900000000003`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{479.148, 156.457}, {
                    481.078, 157.74599999999998`}, {483.012, 
                    159.16400000000004`}, {485.46099999999996`, 159.805}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{478.121, 142.293}, {
                    478.121, 145.38299999999998`}, {479.66400000000004`, 
                    147.957}, {481.078, 148.73000000000002`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{489.449, 
                    177.83599999999996`}, {489.191, 174.10200000000003`}, {
                    490.73799999999994`, 170.49599999999998`}, {
                    491.89799999999997`, 168.56200000000007`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{520.102, 
                    177.57800000000003`}, {518.234, 177.}, {516.559, 
                    176.28900000000004`}, {515.8519999999999, 
                    174.74599999999998`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{518.039, 
                    167.02000000000004`}, {518.9409999999999, 
                    167.78900000000004`}, {519.9730000000001, 
                    168.69099999999997`}, {520.4219999999999, 
                    169.33599999999996`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{566.719, 279.445}, {
                    566.719, 275.84000000000003`}, {562.215, 273.906}, {
                    559.254, 276.22700000000003`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{576.512, 
                    279.31600000000003`}, {578.504, 277.77}, {585.395, 
                    279.25}, {583.7850000000001, 283.24199999999996`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{568.137, 258.582}, {
                    566.719, 258.84000000000003`}, {564.2730000000001, 
                    260.38700000000006`}, {563.242, 261.67199999999997`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{582.305, 269.273}, {
                    579.988, 268.75800000000004`}, {578.4409999999999, 
                    269.273}, {577.2810000000001, 269.785}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{545.73, 256.395}, {
                    547.016, 256.395}, {550.105, 256.90999999999997`}, {
                    552.234, 258.004}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{541.8669999999998, 
                    279.188}, {540.191, 279.379}, {538.9649999999999, 
                    279.05899999999997`}, {538.004, 278.414}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{567.8159999999999, 
                    272.879}, {567.3669999999998, 271.266}, {566.207, 
                    268.75800000000004`}, {564.7890000000001, 
                    267.65999999999997`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{537.488, 267.211}, {
                    540.707, 268.629}, {544.6990000000001, 
                    257.67999999999995`}, {552.4259999999999, 261.543}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{553.07, 272.879}, {
                    552.039, 271.461}, {551.398, 269.273}, {551.266, 
                    267.34000000000003`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{399.047, 289.621}, {
                    400.078, 289.746}, {401.879, 290.133}, {
                    402.26599999999996`, 291.422}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{266.527, 169.723}, {
                    270.39099999999996`, 167.531}, {273.09799999999996`, 
                    163.79700000000003`}, {271.42199999999997`, 
                    158.26200000000006`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{443.60200000000003`, 
                    301.469}, {444.762, 300.695}, {449.14500000000004`, 
                    300.695}, {451.59, 301.59799999999996`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{454.68, 298.891}, {
                    454.551, 297.09000000000003`}, {455.066, 290.262}, {
                    451.59, 288.84799999999996`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{452.875, 289.746}, {
                    456.09799999999996`, 288.719}, {462.53499999999997`, 
                    289.105}, {464.59799999999996`, 295.02700000000004`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{460.09, 290.004}, {
                    461.762, 287.43}, {462.277, 282.406}, {457.258, 
                    279.703}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{461.375, 285.754}, {
                    465.10900000000004`, 284.469}, {473.73799999999994`, 
                    284.34000000000003`}, {472.83599999999996`, 
                    291.67999999999995`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{469.875, 285.754}, {
                    472.453, 282.14799999999997`}, {483.78499999999997`, 
                    277.898}, {481.984, 285.371}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{459.445, 275.324}, {
                    463.824, 274.293}, {470.008, 277.25800000000004`}, {
                    467.42999999999995`, 284.98400000000004`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{479.79299999999995`, 
                    281.121}, {480.43799999999993`, 278.156}, {
                    494.85900000000004`, 275.06600000000003`}, {
                    492.92999999999995`, 281.762}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{490.22299999999996`, 
                    277.898}, {492.92999999999995`, 271.719}, {
                    507.22299999999996`, 272.23400000000004`}, {502.715, 
                    280.477}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{500.39799999999997`, 
                    274.03499999999997`}, {503.22999999999996`, 
                    270.55899999999997`}, {515.8519999999999, 272.621}, {
                    510.828, 280.99199999999996`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{510.699, 274.164}, {
                    518.555, 268.24199999999996`}, {527.6990000000001, 
                    276.74199999999996`}, {517.7810000000001, 282.922}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{522.2890000000001, 
                    276.09799999999996`}, {529.246, 270.55899999999997`}, {
                    537.746, 280.605}, {531.691, 283.438}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{467.301, 278.414}, {
                    469.48799999999994`, 277.77}, {474.125, 
                    278.02700000000004`}, {475.156, 282.02}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{473.41799999999995`, 
                    279.31600000000003`}, {473.16, 273.457}, {483.012, 
                    271.203}, {485.52299999999997`, 277.96500000000003`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{482.23799999999994`, 
                    274.293}, {484.043, 270.43}, {492.668, 
                    268.88700000000006`}, {494.08599999999996`, 274.422}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{492.668, 
                    271.84799999999996`}, {494.08599999999996`, 
                    267.98400000000004`}, {501.555, 268.371}, {503.617, 
                    272.363}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{500.914, 269.785}, {
                    503.22999999999996`, 264.766}, {512.762, 264.766}, {
                    514.949, 272.105}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{513.277, 
                    268.88700000000006`}, {517.012, 266.56600000000003`}, {
                    524.996, 267.469}, {524.3519999999999, 
                    274.67999999999995`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{522.805, 
                    269.52700000000004`}, {528.3439999999999, 265.023}, {
                    536.1990000000001, 269.398}, {532.3359999999999, 277.}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{531.949, 263.605}, {
                    534.914, 264.121}, {536.4569999999999, 270.043}, {
                    533.3669999999998, 271.59000000000003`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{463.309, 
                    262.57399999999996`}, {469.48799999999994`, 265.922}, {
                    470.648, 271.59000000000003`}, {466.39799999999997`, 
                    277.129}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{468.59, 
                    268.24199999999996`}, {472.453, 265.922}, {
                    479.79299999999995`, 268.371}, {481.078, 
                    274.03499999999997`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{473.871, 
                    267.59799999999996`}, {476.055, 264.766}, {476.441, 
                    261.285}, {473.60900000000004`, 258.06600000000003`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{475.672, 
                    263.99199999999996`}, {482.4959999999999, 
                    268.24199999999996`}, {490.9959999999999, 
                    260.38700000000006`}, {484.688, 255.621}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{483.527, 264.379}, {
                    485.074, 264.766}, {487.777, 267.59799999999996`}, {
                    488.03099999999995`, 270.81600000000003`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{486.617, 261.414}, {
                    489.449, 264.379}, {508.77, 258.324}, {
                    496.53099999999995`, 252.14499999999998`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{495.633, 
                    269.52700000000004`}, {499.367, 268.11299999999994`}, {
                    501.301, 262.832}, {495.633, 261.031}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{500.527, 256.652}, {
                    504.648, 260.902}, {517.5269999999999, 258.195}, {512.891,
                     252.78900000000002`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{509.801, 258.324}, {
                    512.117, 266.17999999999995`}, {525.898, 261.285}, {
                    521.391, 258.06600000000003`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{506.965, 
                    266.17999999999995`}, {507.35200000000003`, 264.637}, {
                    507.47999999999996`, 260.773}, {504.90599999999995`, 
                    258.711}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{518.555, 
                    267.72700000000003`}, {519.07, 266.438}, {
                    518.9409999999999, 263.99199999999996`}, {
                    517.7810000000001, 262.445}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{527.3119999999999, 
                    267.59799999999996`}, {528.086, 266.17999999999995`}, {
                    529.375, 263.477}, {526.539, 261.285}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{417.078, 326.836}, {
                    417.203, 319.496}, {419.78099999999995`, 314.602}, {
                    429.695, 319.238}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{420.168, 318.082}, {
                    415.27299999999997`, 311.51199999999994`}, {420.809, 
                    304.43}, {430.469, 311.51199999999994`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{405.10200000000003`, 
                    314.85900000000004`}, {411.79699999999997`, 
                    307.64799999999997`}, {423.77299999999997`, 312.93}, {
                    416.047, 323.875}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{424.16, 
                    308.67999999999995`}, {422.871, 301.59799999999996`}, {
                    428.668, 300.17999999999995`}, {433.42999999999995`, 
                    303.398}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{399.172, 313.703}, {
                    400.395, 306.582}, {407.672, 300.953}, {414.758, 
                    305.332}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{407.93399999999997`, 
                    303.914}, {407.93399999999997`, 293.74199999999996`}, {
                    421.969, 292.582}, {425.191, 303.14099999999996`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{420.168, 296.703}, {
                    424.672, 287.43}, {434.46099999999996`, 291.164}, {437.68,
                     296.832}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{410.25, 
                    311.51199999999994`}, {412.055, 307.004}, {415.66, 
                    301.98}, {424.03099999999995`, 305.719}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{384.49199999999996`, 
                    313.703}, {385.65200000000004`, 309.969}, {
                    392.35200000000003`, 305.461}, {400.078, 310.609}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{389.258, 308.938}, {
                    385.137, 302.88300000000004`}, {393.379, 297.219}, {
                    403.29699999999997`, 306.23}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{394.15200000000004`, 
                    301.469}, {395.828, 292.969}, {399.172, 
                    286.14099999999996`}, {411.28099999999995`, 
                    297.09000000000003`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{405.227, 292.711}, {
                    409.605, 287.30100000000004`}, {416.305, 283.953}, {
                    422.613, 293.09799999999996`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{427.25, 
                    291.164}, {426.863, 284.72700000000003`}, {428.148, 
                    281.508}, {433.172, 281.762}, {437.133, 
                    281.96500000000003`}, {440.89799999999997`, 
                    285.11299999999994`}, {443.09, 288.461}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{432.27299999999997`, 
                    281.762}, {432.14500000000004`, 274.422}, {
                    437.93799999999993`, 268.629}, {448.758, 
                    276.09799999999996`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{436.78099999999995`, 
                    273.137}, {434.719, 267.59799999999996`}, {
                    440.89799999999997`, 258.582}, {453.008, 263.219}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{411.148, 
                    287.81600000000003`}, {410.379, 280.73400000000004`}, {
                    416.945, 275.969}, {427.508, 285.11299999999994`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{416.305, 279.961}, {
                    416.691, 274.164}, {423.258, 267.211}, {
                    432.91799999999995`, 277.25800000000004`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{420.941, 272.621}, {
                    420.168, 262.703}, {429.309, 259.871}, {
                    437.03499999999997`, 267.469}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{407.16, 279.961}, {
                    409.219, 279.832}, {410.895, 281.633}, {
                    411.92199999999997`, 282.922}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{411.53499999999997`, 
                    272.75}, {413.34000000000003`, 272.363}, {
                    416.43399999999997`, 274.03499999999997`}, {417.465, 
                    276.09799999999996`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{416.047, 261.031}, {
                    418.105, 258.84000000000003`}, {425.059, 
                    260.38700000000006`}, {425.96099999999996`, 
                    263.34799999999996`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{423.77299999999997`, 
                    261.15999999999997`}, {427.637, 252.14499999999998`}, {
                    437.93799999999993`, 252.531}, {442.188, 262.703}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{440.258, 
                    259.09799999999996`}, {442.188, 253.816}, {447.082, 
                    250.469}, {455.066, 252.273}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{444.121, 253.688}, {
                    439.613, 246.34799999999998`}, {445.53499999999997`, 
                    237.719}, {455.578, 246.219}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{446.566, 242.742}, {
                    446.055, 238.105}, {450.305, 232.824}, {
                    456.09799999999996`, 232.184}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{427.508, 256.266}, {
                    425.96099999999996`, 245.832}, {433.42999999999995`, 
                    240.81199999999998`}, {442.832, 246.34799999999998`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{416.559, 251.242}, {
                    419.008, 249.309}, {423.387, 249.05100000000002`}, {
                    427.508, 250.59799999999998`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{432.53099999999995`, 
                    244.547}, {430.21099999999996`, 235.78900000000002`}, {
                    439.227, 229.477}, {446.953, 239.26600000000002`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{420.03499999999997`, 
                    249.824}, {420.168, 245.316}, {424.547, 
                    240.42600000000002`}, {432.14500000000004`, 241.84}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{453.395, 232.824}, {
                    448.23799999999994`, 229.34799999999998`}, {
                    447.21099999999996`, 223.168}, {454.42199999999997`, 
                    219.176}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{440.77, 234.629}, {
                    441.03099999999995`, 229.34799999999998`}, {443.477, 
                    226.38700000000003`}, {449.27, 225.871}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{433.172, 237.332}, {
                    425.445, 230.25}, {433.043, 222.00800000000004`}, {
                    442.188, 228.961}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{438.582, 226.773}, {
                    436.008, 218.65999999999997`}, {445.668, 
                    213.76600000000002`}, {450.816, 222.00800000000004`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{422.613, 244.031}, {
                    419.78099999999995`, 236.047}, {423.387, 
                    230.76600000000002`}, {429.953, 231.28100000000003`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{412.441, 
                    245.57399999999998`}, {412.828, 240.81199999999998`}, {
                    416.945, 239.137}, {421.582, 240.16799999999998`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{415.39799999999997`, 
                    240.555}, {411.92199999999997`, 233.85500000000002`}, {
                    417.203, 230.25}, {424.16, 232.824}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{445.28099999999995`, 
                    217.887}, {444.121, 213.637}, {444.762, 
                    210.54700000000003`}, {451.074, 209.12900000000002`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{445.668, 
                    211.83599999999996`}, {438.066, 208.35499999999996`}, {
                    437.42199999999997`, 201.01600000000002`}, {443.348, 
                    196.25}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{439.547, 
                    220.01200000000006`}, {435.555, 216.406}, {436.328, 
                    210.15999999999997`}, {440.707, 207.71500000000003`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{405.742, 243.516}, {
                    401.363, 239.19899999999998`}, {405.551, 
                    227.28900000000002`}, {415.207, 233.793}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{430.855, 
                    228.44899999999998`}, {424.92999999999995`, 223.555}, {
                    427.637, 214.668}, {437.42199999999997`, 217.113}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{421.066, 232.184}, {
                    417.977, 223.426}, {420.941, 220.33599999999996`}, {
                    427.895, 220.20700000000005`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{399.305, 
                    243.902}, {394.02299999999997`, 239.91}, {395.441, 
                    234.242}, {397.758, 231.66799999999998`}, {400.078, 
                    229.09}, {404.453, 230.25}, {405.871, 
                    233.59799999999998`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{388.227, 247.379}, {
                    382.305, 239.78100000000003`}, {388.227, 
                    230.76600000000002`}, {396.60200000000003`, 233.469}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    419.90999999999997`, 224.84}, {413.855, 222.652}, {
                    409.23799999999994`, 217.15599999999995`}, {412.953, 
                    212.34799999999996`}, {415.14500000000004`, 
                    209.51600000000002`}, {424.672, 209.12900000000002`}, {
                    427.375, 220.07800000000003`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{408.965, 
                    231.92600000000002`}, {405.48799999999994`, 226.902}, {
                    406.64500000000004`, 222.137}, {413.082, 
                    219.69099999999997`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{408.578, 
                    222.52300000000002`}, {404.84000000000003`, 220.461}, {
                    402.395, 218.01600000000002`}, {403.29699999999997`, 
                    213.50800000000004`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{400.207, 230.379}, {
                    398.789, 224.328}, {400.465, 220.59000000000003`}, {
                    404.195, 218.78900000000004`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{400.078, 223.168}, {
                    394.28099999999995`, 223.555}, {391.32, 
                    221.10500000000002`}, {393.25, 215.44099999999997`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{393.76599999999996`, 
                    221.75}, {388.10200000000003`, 223.812}, {387.195, 
                    228.703}, {389.64500000000004`, 233.85500000000002`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{388.871, 226.258}, {
                    382.691, 226.}, {379.98799999999994`, 
                    222.91000000000003`}, {379.98799999999994`, 
                    218.65999999999997`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{380.5, 
                    250.34}, {375.99199999999996`, 248.41}, {374.578, 
                    242.35500000000002`}, {376.25, 239.00799999999998`}, {
                    377.92599999999993`, 235.66}, {383.207, 235.402}, {
                    386.42599999999993`, 237.59}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{367.879, 255.105}, {
                    363.758, 250.469}, {368.52299999999997`, 241.453}, {
                    375.867, 243.64499999999998`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{357.32, 258.711}, {
                    353.457, 253.30100000000002`}, {357.707, 
                    244.28900000000002`}, {367.621, 246.863}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{368.137, 221.75}, {
                    367.105, 228.191}, {373.805, 232.441}, {382.047, 
                    224.07}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{378.055, 
                    237.07399999999998`}, {375.605, 234.88700000000003`}, {
                    374.449, 231.41}, {374.832, 228.57799999999997`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{346.758, 
                    261.80100000000004`}, {342.508, 254.59}, {
                    347.66400000000004`, 248.023}, {356.805, 
                    250.59799999999998`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{370.58599999999996`, 
                    243.902}, {364.53099999999995`, 237.84799999999998`}, {
                    366.594, 231.79700000000003`}, {371.10200000000003`, 
                    228.32}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{366.719, 236.816}, {
                    357.578, 236.691}, {357.062, 226.129}, {
                    364.53099999999995`, 222.781}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{359.76599999999996`, 
                    247.379}, {356.03099999999995`, 244.805}, {354.871, 
                    237.719}, {361.312, 234.88700000000003`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{359.508, 231.539}, {
                    355.64500000000004`, 233.34}, {351.008, 231.152}, {
                    351.395, 226.64499999999998`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{353.715, 231.41}, {
                    350.234, 239.652}, {340.062, 238.234}, {340.965, 
                    229.734}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{356.547, 241.582}, {
                    354.35900000000004`, 241.195}, {349.97999999999996`, 
                    239.91}, {348.305, 236.559}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{348.949, 
                    250.85500000000002`}, {344.828, 246.219}, {348.047, 
                    240.684}, {351.395, 239.523}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{336.715, 263.863}, {
                    335.941, 258.324}, {338.133, 255.621}, {
                    345.08599999999996`, 256.137}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{339.16400000000004`, 
                    256.78100000000006`}, {336.457, 250.082}, {340.062, 
                    247.121}, {347.01599999999996`, 247.50799999999998`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{340.707, 248.539}, {
                    336.58599999999996`, 243.64499999999998`}, {
                    339.41799999999995`, 238.363}, {343.40999999999997`, 
                    236.176}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{338.777, 
                    242.35500000000002`}, {331.43799999999993`, 243.258}, {
                    330.277, 234.758}, {332.72299999999996`, 
                    230.76600000000002`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    332.85200000000003`, 264.508}, {328.34400000000005`, 
                    262.57399999999996`}, {325.77, 256.90999999999997`}, {
                    328.215, 253.43}, {330.66400000000004`, 249.953}, {
                    335.555, 251.11299999999997`}, {338.258, 
                    252.91799999999998`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{329.758, 
                    251.88700000000003`}, {326.027, 246.219}, {329.371, 
                    241.969}, {333.367, 240.29700000000003`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    315.33599999999996`, 265.152}, {312.375, 
                    262.05899999999997`}, {314.176, 255.75}, {
                    321.39099999999996`, 255.621}, {327.195, 255.516}, {
                    330.14500000000004`, 261.031}, {328.34400000000005`, 
                    264.895}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{320.35900000000004`, 
                    255.621}, {318.043, 250.469}, {319.457, 244.93}, {328.215,
                     245.832}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{331.949, 237.719}, {
                    326.539, 240.16799999999998`}, {319.328, 237.719}, {
                    322.42199999999997`, 231.28100000000003`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{321.648, 246.863}, {
                    319.457, 243.773}, {320.22999999999996`, 239.395}, {
                    322.676, 236.691}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{321.262, 238.621}, {
                    317.656, 237.977}, {314.176, 236.047}, {316.367, 
                    230.379}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{315.85200000000003`, 
                    235.016}, {311.215, 236.434}, {305.29299999999995`, 
                    233.082}, {308.89799999999997`, 228.32}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{308.125, 232.824}, {
                    304.133, 233.469}, {299.367, 229.219}, {
                    303.22999999999996`, 224.969}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{301.688, 
                    228.44899999999998`}, {298.078, 227.547}, {293.832, 
                    223.426}, {297.566, 220.20700000000005`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{319.84400000000005`, 
                    248.66799999999998`}, {314.691, 246.34799999999998`}, {
                    314.176, 240.555}, {316.625, 236.305}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{314.43399999999997`, 
                    259.355}, {306.707, 256.395}, {306.83599999999996`, 
                    246.09}, {315.33599999999996`, 242.871}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{311.72999999999996`, 
                    245.188}, {307.094, 242.484}, {306.191, 237.332}, {
                    309.28499999999997`, 233.984}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{303.617, 263.219}, {
                    300.527, 262.188}, {300.78499999999997`, 252.66}, {
                    309.027, 252.91799999999998`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{295.117, 260.}, {
                    288.93799999999993`, 255.879}, {296.40599999999995`, 
                    245.445}, {306.449, 252.91799999999998`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{300.914, 250.34}, {
                    300.012, 246.09}, {301.172, 241.453}, {307.9959999999999, 
                    240.938}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{301.301, 244.676}, {
                    296.40599999999995`, 242.871}, {295.504, 232.824}, {
                    304.39099999999996`, 232.055}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{285.715, 253.816}, {
                    279.40599999999995`, 248.023}, {290.867, 243.}, {295.117, 
                    251.371}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{276.96099999999996`, 
                    244.16}, {273.867, 240.42600000000002`}, {284.688, 
                    230.637}, {289.453, 246.992}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{290.60900000000004`, 
                    247.25}, {290.867, 243.38700000000003`}, {293.188, 
                    241.066}, {297.949, 240.81199999999998`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{297.824, 
                    237.07399999999998`}, {290.22299999999996`, 
                    235.91799999999998`}, {287.777, 226.38700000000003`}, {
                    296.277, 224.328}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{283.78499999999997`, 
                    238.363}, {283.527, 234.758}, {287.262, 
                    231.79700000000003`}, {291.512, 232.441}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{295.375, 224.582}, {
                    288.42199999999997`, 223.03900000000004`}, {287.52, 
                    214.02300000000002`}, {293.703, 214.53900000000004`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{290.47999999999996`, 
                    206.168}, {284.688, 207.906}, {284.559, 
                    214.79700000000003`}, {289.707, 217.37099999999998`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{285.715, 
                    212.223}, {280.824, 209.25799999999998`}, {282.754, 
                    202.176}, {285.332, 201.14499999999998`}, {
                    287.90599999999995`, 200.113}, {289.965, 
                    201.40200000000004`}, {290.22299999999996`, 
                    203.59400000000005`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{289.83599999999996`, 
                    193.676}, {290.35200000000003`, 190.32799999999997`}, {
                    277.92599999999993`, 191.61700000000002`}, {284.301, 
                    202.04700000000003`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{284.234, 193.098}, {
                    280.051, 186.52700000000004`}, {286.875, 
                    181.18400000000003`}, {291.191, 186.78500000000003`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{284.816, 185.176}, {
                    283.141, 179.89499999999998`}, {289.51599999999996`, 
                    176.098}, {293.637, 180.21900000000005`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{270.90599999999995`, 
                    234.629}, {268.59, 229.863}, {280.18, 
                    228.06199999999998`}, {280.953, 237.84799999999998`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{267.688, 227.547}, {
                    265.371, 218.27300000000002`}, {282.883, 
                    220.20700000000005`}, {278.375, 232.184}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{278.762, 226.}, {
                    281.21099999999996`, 224.582}, {288.551, 
                    224.45700000000002`}, {290.35200000000003`, 
                    232.31199999999998`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{285.074, 225.742}, {
                    285.59, 223.29700000000003`}, {287.777, 
                    220.33599999999996`}, {289.83599999999996`, 
                    219.43400000000003`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{276.703, 
                    223.29700000000003`}, {275.92999999999995`, 
                    218.27300000000002`}, {280.953, 214.152}, {286.746, 
                    214.53900000000004`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{277.60200000000003`, 
                    218.40200000000004`}, {274.77, 214.53900000000004`}, {
                    273.867, 207.07000000000005`}, {282.754, 206.555}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{264.082, 217.113}, {
                    262.66400000000004`, 213.12099999999998`}, {
                    271.03499999999997`, 209.}, {275.92999999999995`, 
                    215.57000000000005`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{261.504, 
                    206.94099999999997`}, {260.79699999999997`, 
                    203.91400000000004`}, {268.332, 199.85899999999998`}, {
                    272.582, 212.73400000000004`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{269.234, 206.168}, {
                    271.03499999999997`, 202.949}, {277.09, 
                    200.37099999999998`}, {280.824, 206.68400000000003`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{274.77, 202.82}, {
                    273.227, 198.312}, {277.477, 194.06200000000007`}, {
                    282.625, 195.35199999999998`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{265.113, 
                    203.85199999999998`}, {264.082, 197.41000000000003`}, {
                    271.551, 193.676}, {276.188, 197.02300000000002`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{260.219, 
                    201.01600000000002`}, {258.027, 192.77300000000002`}, {
                    268.59, 189.68400000000003`}, {272.582, 
                    195.86700000000002`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{269.875, 193.418}, {
                    270.262, 188.781}, {277.477, 184.78900000000004`}, {
                    283.141, 188.652}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{257., 189.555}, {256.484,
                     187.49599999999998`}, {265.113, 185.43400000000003`}, {
                    266.39799999999997`, 192.64499999999998`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{262.02, 
                    187.75400000000002`}, {264.082, 182.473}, {
                    271.03499999999997`, 181.18400000000003`}, {275.027, 
                    187.625}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{272.71099999999996`, 
                    185.04700000000003`}, {273.60900000000004`, 180.152}, {
                    279.92199999999997`, 177.449}, {285.46099999999996`, 
                    180.79700000000003`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{287.777, 
                    178.86700000000002`}, {286.35900000000004`, 
                    172.29700000000003`}, {293.188, 167.02000000000004`}, {
                    297.43799999999993`, 170.625}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{276.832, 
                    180.02300000000002`}, {274.77, 172.812}, {
                    283.78499999999997`, 168.69099999999997`}, {288.809, 
                    172.68400000000003`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{266.012, 
                    183.62900000000002`}, {265.4959999999999, 
                    176.93400000000003`}, {270.777, 172.94099999999997`}, {
                    276.832, 175.90200000000004`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{254.55100000000002`, 
                    182.988}, {252.75, 178.60900000000004`}, {262.277, 
                    175.00400000000008`}, {266.78499999999997`, 178.738}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{248.629, 
                    171.01200000000006`}, {251.07399999999998`, 168.176}, {
                    259.574, 171.01200000000006`}, {260.348, 177.32}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{258.027, 
                    172.68400000000003`}, {261.121, 169.07800000000003`}, {
                    268.46099999999996`, 167.14799999999997`}, {
                    271.42199999999997`, 174.875}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{268.848, 
                    170.88299999999998`}, {268.719, 165.344}, {278.633, 
                    161.35199999999998`}, {281.85200000000003`, 
                    171.52700000000004`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{293.508, 
                    169.52700000000004`}, {292.605, 166.824}, {
                    294.72999999999996`, 162.51200000000006`}, {299.176, 
                    161.99599999999998`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{285.332, 
                    171.20300000000003`}, {284.688, 168.113}, {289.195, 
                    163.79700000000003`}, {293.957, 165.53500000000003`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{294.85900000000004`, 
                    164.25}, {293.574, 160.89799999999997`}, {294.668, 
                    156.07000000000005`}, {299.176, 156.137}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{295.312, 
                    158.00400000000008`}, {291.96099999999996`, 
                    155.17200000000003`}, {293.379, 150.14799999999997`}, {
                    298.207, 149.95299999999997`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{293.574, 153.238}, {
                    288.809, 150.02000000000004`}, {290.47999999999996`, 
                    142.938}, {296.79299999999995`, 143.32}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{279.148, 
                    166.89099999999996`}, {279.148, 159.93400000000003`}, {
                    287.777, 158.906}, {289.453, 165.344}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{286.10200000000003`, 
                    161.223}, {284.816, 157.10200000000003`}, {
                    288.16400000000004`, 153.10900000000004`}, {293.445, 
                    154.27000000000004`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{287.133, 
                    111.51200000000006`}, {288.29299999999995`, 
                    109.83599999999996`}, {293.059, 112.67200000000003`}, {
                    291.77, 115.50400000000008`}, {290.47999999999996`, 
                    118.33599999999996`}, {285.43399999999997`, 
                    116.79700000000003`}, {285.97299999999996`, 113.832}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{290.60900000000004`, 
                    116.66400000000004`}, {291.254, 122.332}, {284.559, 
                    123.23000000000002`}, {282.883, 118.33599999999996`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{285.332, 
                    121.17200000000003`}, {287.004, 124.00400000000008`}, {
                    281.34000000000003`, 127.86700000000002`}, {279.02, 
                    123.74599999999998`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{281.082, 
                    125.42200000000003`}, {282.625, 129.543}, {276.188, 
                    131.344}, {275.672, 127.60900000000004`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{274.254, 
                    133.02000000000004`}, {275.027, 135.08200000000005`}, {
                    282.23799999999994`, 133.793}, {279.148, 129.543}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{284.688, 
                    124.39099999999996`}, {287.52, 126.96500000000003`}, {
                    282.754, 132.24599999999998`}, {279.79299999999995`, 
                    130.312}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{303.746, 
                    116.53500000000003`}, {301.49199999999996`, 
                    116.27700000000004`}, {299.176, 114.79700000000003`}, {
                    300.848, 110.031}, {302.008, 106.72300000000001`}, {
                    306.965, 106.555}, {307.672, 108.55099999999999`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    300.46099999999996`, 114.15199999999999`}, {
                    298.27299999999997`, 115.57000000000005`}, {293.508, 
                    113.18799999999999`}, {295.695, 108.55099999999999`}, {
                    297.34400000000005`, 105.05900000000003`}, {
                    301.49199999999996`, 106.488}, {302.137, 108.293}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{288.16400000000004`, 
                    107.52000000000004`}, {289.258, 105.59000000000003`}, {
                    294.72999999999996`, 106.42200000000003`}, {295.695, 
                    108.55099999999999`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{291.89799999999997`, 
                    113.89499999999998`}, {293.059, 114.668}, {295.18, 
                    113.70300000000003`}, {295.633, 112.738}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{291.512, 
                    145.64099999999996`}, {287.777, 143.195}, {290.094, 
                    135.723}, {295.89099999999996`, 137.65599999999995`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{290.35200000000003`, 
                    139.586}, {287.39099999999996`, 137.27000000000004`}, {
                    290.094, 130.05900000000003`}, {295.633, 
                    132.76200000000006`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{291.254, 
                    132.76200000000006`}, {289.195, 130.699}, {291.191, 
                    124.96900000000005`}, {296.53499999999997`, 
                    126.06200000000007`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{290.47999999999996`, 
                    129.926}, {289.324, 130.445}, {286.29699999999997`, 
                    130.05900000000003`}, {285.008, 128.125}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{287.133, 
                    156.00800000000004`}, {284.301, 153.301}, {
                    285.65200000000004`, 147.76200000000006`}, {
                    290.93399999999997`, 147.312}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{286.10200000000003`, 
                    150.33999999999997`}, {282.047, 148.344}, {282.047, 
                    140.29700000000003`}, {290.16, 139.973}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{285.78099999999995`, 
                    141.26200000000006`}, {283.527, 139.457}, {284.621, 
                    132.50400000000008`}, {290.41799999999995`, 133.406}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{287.648, 
                    133.66400000000004`}, {286.812, 132.82799999999997`}, {
                    286.684, 130.699}, {287.39099999999996`, 129.801}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{285.074, 136.305}, {
                    283.012, 136.238}, {280.309, 134.75799999999998`}, {
                    279.59799999999996`, 132.63299999999998`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{275.863, 
                    140.10200000000003`}, {276.637, 142.16400000000004`}, {
                    283.012, 142.03500000000003`}, {283.46099999999996`, 
                    135.98000000000002`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{284.105, 143.195}, {
                    283.203, 143.}, {281.469, 142.16400000000004`}, {
                    281.01599999999996`, 140.42200000000003`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{281.34000000000003`, 
                    162.05900000000003`}, {278.57, 159.54700000000003`}, {
                    277.219, 151.62900000000002`}, {285.65200000000004`, 
                    150.08200000000005`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{275.734, 
                    145.70300000000003`}, {275.734, 147.832}, {281.469, 
                    149.63299999999998`}, {283.46099999999996`, 
                    146.47700000000003`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{272.066, 
                    157.23000000000002`}, {272.902, 155.62099999999998`}, {
                    276.895, 153.43}, {279.34000000000003`, 
                    155.23400000000004`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    251.33200000000002`, 169.85199999999998`}, {
                    251.20299999999997`, 166.11700000000002`}, {
                    254.29299999999998`, 162.77000000000004`}, {258.543, 
                    163.281}, {262.79299999999995`, 163.79700000000003`}, {
                    263.695, 167.531}, {262.40599999999995`, 
                    169.98000000000002`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{259.188, 
                    163.15599999999995`}, {256.355, 159.676}, {259.832, 
                    154.78500000000003`}, {263.051, 156.199}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{262.40599999999995`, 
                    165.60200000000003`}, {264.082, 166.24599999999998`}, {
                    269.617, 167.02000000000004`}, {271.29299999999995`, 
                    164.44099999999997`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{244.508, 
                    164.57000000000005`}, {243.21899999999997`, 
                    162.64099999999996`}, {251.20299999999997`, 
                    160.70700000000005`}, {253.906, 164.44099999999997`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{251.20299999999997`, 
                    162.51200000000006`}, {250.945, 159.93400000000003`}, {
                    252.23399999999998`, 155.555}, {258.801, 
                    157.35899999999998`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{259.832, 
                    153.36700000000002`}, {260.863, 155.555}, {255.969, 
                    159.16400000000004`}, {252.23399999999998`, 
                    155.17200000000003`}, {248.5, 151.18}, {252.75, 
                    146.67200000000003`}, {255.066, 148.21500000000003`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{242.70299999999997`, 
                    161.99599999999998`}, {240.77299999999997`, 
                    158.64799999999997`}, {248.242, 152.531}, {
                    252.49200000000002`, 158.195}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    237.74599999999998`, 156.199}, {235.039, 153.43}, {
                    238.38700000000003`, 148.344}, {242.445, 
                    149.89099999999996`}, {246.5, 151.43400000000003`}, {
                    246.117, 155.68400000000003`}, {245.148, 
                    156.77700000000004`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{232.531, 
                    151.04700000000003`}, {230.34, 149.055}, {232.465, 
                    144.35199999999998`}, {235.49200000000002`, 
                    144.35199999999998`}, {238.516, 144.35199999999998`}, {
                    240.38700000000003`, 146.73400000000004`}, {239.805, 
                    149.76200000000006`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{244.82800000000003`, 
                    151.43400000000003`}, {244.441, 148.473}, {
                    248.82000000000002`, 146.41400000000004`}, {
                    251.65200000000002`, 149.18}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{251.781, 
                    154.59000000000003`}, {252.168, 155.23400000000004`}, {
                    251.848, 156.32799999999997`}, {251.20299999999997`, 
                    156.844}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{227.82800000000003`, 
                    147.05900000000003`}, {225.316, 145.05900000000003`}, {
                    230.727, 139.52300000000002`}, {234.137, 
                    144.60900000000004`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{247.21099999999998`, 
                    148.14799999999997`}, {245.602, 146.60500000000002`}, {
                    248.176, 142.551}, {250.75, 143.77300000000002`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{238.38700000000003`, 
                    145.31599999999997`}, {238.77299999999997`, 142.551}, {
                    244.184, 140.488}, {247.598, 144.738}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{241.35200000000003`, 
                    142.551}, {240.516, 140.80900000000003`}, {
                    242.18800000000002`, 138.03900000000004`}, {244.25, 
                    138.426}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{292.605, 
                    126.64499999999998`}, {290.60900000000004`, 
                    122.71500000000003`}, {296.984, 118.14499999999998`}, {
                    301.621, 122.91000000000003`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{297.242, 
                    120.78500000000003`}, {296.277, 118.65999999999997`}, {
                    297.43799999999993`, 115.695}, {299.176, 
                    114.60200000000003`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{291.191, 
                    116.33999999999997`}, {291.641, 118.27300000000002`}, {
                    294.40999999999997`, 120.07800000000003`}, {
                    296.92199999999997`, 119.17200000000003`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{287.84000000000003`, 
                    121.43}, {288.227, 123.168}, {290.547, 124.906}, {
                    292.28499999999997`, 124.45299999999997`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{439.484, 
                    201.78900000000004`}, {430.34000000000003`, 
                    201.65999999999997`}, {434.203, 186.98000000000002`}, {
                    442.059, 189.94099999999997`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{436.52299999999997`, 
                    190.973}, {434.719, 188.00800000000004`}, {438.195, 
                    183.30900000000003`}, {442.059, 186.07800000000003`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{441.03099999999995`, 
                    185.49599999999998`}, {438.324, 180.99200000000002`}, {
                    447.984, 174.10200000000003`}, {451.848, 
                    181.18400000000003`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{448.758, 
                    178.48000000000002`}, {448.883, 174.23000000000002`}, {
                    461.246, 171.52700000000004`}, {459.445, 
                    180.02300000000002`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{458.28499999999997`, 
                    175.39099999999996`}, {461.246, 170.36700000000002`}, {
                    472.324, 169.85199999999998`}, {471.16400000000004`, 
                    177.32}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{468.715, 172.168}, {
                    471.03499999999997`, 168.82}, {481.85200000000003`, 
                    166.76200000000006`}, {481.465, 173.71500000000003`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{424.805, 
                    214.53900000000004`}, {426.348, 210.54700000000003`}, {
                    431.625, 209.12900000000002`}, {437.42199999999997`, 
                    211.449}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{421.453, 
                    211.70700000000005`}, {425.059, 209.387}, {
                    419.78099999999995`, 198.82799999999997`}, {414.242, 
                    203.07800000000003`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{421.453, 205.137}, {
                    425.445, 203.20700000000005`}, {430.34000000000003`, 
                    204.62099999999998`}, {431.758, 210.28900000000004`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{429.309, 
                    205.91000000000003`}, {429.695, 202.949}, {433.945, 
                    200.62900000000002`}, {439.484, 201.78900000000004`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{419.395, 202.82}, {
                    424.547, 198.44099999999997`}, {417.078, 189.426}, {
                    413.727, 193.54700000000003`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{421.328, 199.473}, {
                    423.77299999999997`, 197.668}, {430.082, 198.699}, {
                    430.727, 203.46500000000003`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{427.895, 199.473}, {
                    428.40999999999997`, 196.37900000000002`}, {430.855, 
                    195.223}, {434.332, 195.09400000000005`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{419.90999999999997`, 
                    195.223}, {422.484, 191.61700000000002`}, {
                    428.92199999999997`, 190.586}, {431.758, 
                    195.35199999999998`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{428.92199999999997`, 
                    192.64499999999998`}, {428.668, 189.168}, {
                    432.53099999999995`, 186.33599999999996`}, {
                    436.52299999999997`, 187.10900000000004`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{414.887, 184.918}, {
                    418.234, 183.24599999999998`}, {421.84000000000003`, 
                    189.555}, {419.008, 193.93400000000003`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{418.75, 178.223}, {
                    422.742, 177.96500000000003`}, {423.258, 
                    184.01600000000002`}, {419.52299999999997`, 
                    187.36700000000002`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{427.895, 
                    172.68400000000003`}, {431.242, 173.457}, {
                    430.21099999999996`, 180.79700000000003`}, {
                    422.09799999999996`, 181.44099999999997`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{438.066, 
                    167.27700000000004`}, {441.28499999999997`, 168.176}, {
                    438.71099999999996`, 176.28900000000004`}, {429.828, 
                    175.77300000000002`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{450.305, 
                    164.44099999999997`}, {452.48799999999994`, 
                    167.78900000000004`}, {445.28099999999995`, 173.457}, {
                    439.355, 170.49599999999998`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{456.35200000000003`, 
                    159.805}, {460.348, 158.64799999999997`}, {463.051, 
                    169.20700000000005`}, {450.42999999999995`, 167.531}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{463.691, 159.805}, {
                    467.172, 160.70700000000005`}, {469.621, 
                    167.02000000000004`}, {459.445, 164.957}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{471.42199999999997`, 
                    159.293}, {474.512, 157.74599999999998`}, {
                    475.92999999999995`, 166.76200000000006`}, {466.527, 
                    164.312}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{419.52299999999997`, 
                    187.36700000000002`}, {423.387, 185.176}, {429.441, 
                    187.75400000000002`}, {428.92199999999997`, 
                    192.64499999999998`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{427.375, 
                    188.39499999999998`}, {428.668, 186.07800000000003`}, {
                    428.148, 181.57000000000005`}, {425.703, 
                    180.41000000000003`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{427.762, 182.988}, {
                    430.34000000000003`, 181.957}, {433.816, 
                    182.85899999999998`}, {435.875, 186.98000000000002`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{432.27299999999997`, 
                    182.988}, {433.043, 181.18400000000003`}, {433.305, 
                    177.57800000000003`}, {431.625, 175.77300000000002`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{432.91799999999995`, 
                    179.89499999999998`}, {435.75, 178.35199999999998`}, {
                    439.09799999999996`, 180.41000000000003`}, {440.512, 
                    183.375}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{438.71099999999996`, 
                    180.79700000000003`}, {440.77, 179.51200000000006`}, {
                    442.574, 173.457}, {439.09799999999996`, 
                    171.01200000000006`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{441.03099999999995`, 
                    173.844}, {443.477, 173.71500000000003`}, {447.082, 
                    173.71500000000003`}, {449.39799999999997`, 176.805}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{447.727, 
                    175.13299999999998`}, {449.91799999999995`, 174.488}, {
                    452.48799999999994`, 170.88299999999998`}, {451.59, 
                    167.65999999999997`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{451.715, 168.82}, {
                    454.168, 169.07800000000003`}, {458.414, 
                    170.75400000000002`}, {459.574, 173.71500000000003`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{458.414, 171.781}, {
                    460.477, 170.625}, {461.895, 168.176}, {461.633, 
                    165.344}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{461.633, 167.406}, {
                    464.078, 167.531}, {466.27, 168.82}, {466.914, 
                    171.52700000000004`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{466.27, 169.723}, {
                    468.074, 169.07800000000003`}, {470.262, 
                    167.02000000000004`}, {470.395, 164.57000000000005`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{470.133, 
                    166.11700000000002`}, {471.93799999999993`, 166.375}, {
                    473.22299999999996`, 167.531}, {474.383, 
                    169.33599999999996`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{479.277, 
                    169.59400000000005`}, {481.59799999999996`, 
                    167.27700000000004`}, {478.508, 159.54700000000003`}, {
                    473.73799999999994`, 160.96500000000003`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{429.828, 
                    325.67999999999995`}, {425.059, 322.844}, {
                    411.53499999999997`, 323.746}, {418.234, 
                    334.94899999999996`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{431.113, 
                    333.27700000000004`}, {421.715, 329.543}, {410.121, 
                    336.754}, {422.227, 344.609}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{419.008, 
                    347.18399999999997`}, {411.148, 347.18399999999997`}, {
                    405.871, 334.562}, {416.43399999999997`, 330.188}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    388.48799999999994`, 341.906}, {386.42599999999993`, 
                    337.914}, {393.76599999999996`, 333.53499999999997`}, {
                    398.789, 337.52700000000004`}, {402.68, 340.621}, {
                    402.395, 348.988}, {400.078, 352.207}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{384.49199999999996`, 
                    332.375}, {381.91799999999995`, 323.875}, {
                    400.85200000000003`, 323.35900000000004`}, {397.887, 
                    336.88300000000004`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{383.465, 319.754}, {
                    384.105, 313.31600000000003`}, {401.625, 315.375}, {
                    395.953, 328.38300000000004`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{398.01599999999996`, 
                    331.988}, {399.43399999999997`, 330.05899999999997`}, {
                    403.29699999999997`, 326.707}, {409.863, 327.352}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{401.105, 341.133}, {
                    401.688, 338.812}, {405.613, 337.01199999999994`}, {
                    410.637, 338.75}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{225.383, 
                    145.19099999999997`}, {220.93800000000002`, 
                    142.03500000000003`}, {227.766, 137.07800000000003`}, {
                    230.27299999999997`, 142.551}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{221.90200000000002`, 
                    142.738}, {217.461, 139.586}, {224.289, 
                    134.62900000000002`}, {226.797, 140.10200000000003`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{218.23399999999998`, 
                    140.35899999999998`}, {213.789, 137.20300000000003`}, {
                    220.617, 132.24599999999998`}, {223.129, 
                    137.71900000000005`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{214.371, 
                    138.17200000000003`}, {210.121, 135.918}, {215.078, 
                    130.37900000000002`}, {219.395, 135.27300000000002`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{210.184, 136.043}, {
                    205.934, 133.793}, {210.895, 128.25400000000002`}, {
                    215.207, 133.14799999999997`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{231.758, 142.676}, {
                    231.691, 139.39499999999998`}, {237.93800000000002`, 
                    138.03900000000004`}, {240.191, 142.938}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{235.684, 
                    139.64799999999997`}, {233.754, 137.20300000000003`}, {
                    237.29299999999998`, 134.176}, {239.227, 
                    135.27300000000002`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{227.379, 
                    140.10200000000003`}, {227.184, 137.332}, {232.594, 
                    135.723}, {235.23399999999998`, 138.75}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{230.34, 
                    137.20300000000003`}, {228.602, 134.949}, {232.016, 
                    131.92200000000003`}, {234.20299999999997`, 
                    132.82799999999997`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{223.77299999999997`, 
                    137.59000000000003`}, {223.965, 135.39799999999997`}, {
                    227.055, 132.89099999999996`}, {230.40200000000002`, 
                    134.30900000000003`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{225.76999999999998`, 
                    134.62900000000002`}, {224.48000000000002`, 
                    133.46900000000005`}, {225.125, 130.76200000000006`}, {
                    226.92600000000002`, 129.926}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{219.07, 134.824}, {
                    218.555, 132.82799999999997`}, {221.969, 
                    129.28500000000003`}, {225.445, 131.60200000000003`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{219.781, 
                    132.50400000000008`}, {217.71899999999997`, 
                    130.89499999999998`}, {217.977, 128.445}, {220.617, 
                    128.125}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{214.82000000000002`, 
                    132.76200000000006`}, {214.562, 131.41000000000003`}, {
                    216.305, 129.21900000000005`}, {218.49200000000002`, 
                    129.47700000000003`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{203.812, 
                    132.89099999999996`}, {201.75, 131.79700000000003`}, {
                    207.031, 126.195}, {210.312, 131.41000000000003`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{198.72299999999998`, 
                    130.57400000000007`}, {196.148, 129.34799999999996`}, {
                    202.523, 123.168}, {205.35500000000002`, 
                    129.47700000000003`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{215.40200000000002`, 
                    130.832}, {213.406, 130.37900000000002`}, {212.117, 
                    127.48000000000002`}, {213.789, 126.32400000000001`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{208.89800000000002`, 
                    129.801}, {208.641, 128.64099999999996`}, {211.086, 
                    126.71100000000001`}, {213.08200000000002`, 127.418}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{207.22299999999998`, 
                    129.28500000000003`}, {205.29299999999998`, 
                    128.05900000000003`}, {206.32000000000002`, 
                    124.64799999999997`}, {208.57399999999998`, 
                    125.16400000000004`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{200.33200000000002`, 
                    127.031}, {198.531, 125.68}, {199.754, 
                    122.97300000000001`}, {202.266, 123.61700000000002`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{203.617, 
                    127.22300000000001`}, {203.684, 126.51600000000002`}, {
                    205.29299999999998`, 125.42200000000003`}, {
                    206.64499999999998`, 125.87099999999998`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{194.086, 
                    128.38299999999998`}, {191.836, 127.418}, {191.961, 
                    121.75}, {199.562, 124.83999999999997`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{189., 
                    126.12900000000002`}, {185.844, 124.58200000000005`}, {
                    186.875, 120.332}, {193.766, 124.39099999999996`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{194.344, 
                    124.06600000000003`}, {193.508, 123.42200000000003`}, {
                    192.605, 120.59000000000003`}, {195.762, 
                    121.68799999999999`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{188.55100000000002`, 
                    122.71500000000003`}, {187.262, 121.55900000000003`}, {
                    188.098, 119.17200000000003`}, {190.934, 
                    120.07800000000003`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{181.918, 122.332}, {
                    179.602, 120.97700000000003`}, {184.68800000000002`, 
                    119.17200000000003`}, {188.098, 122.781}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{183.465, 
                    120.65599999999995`}, {182.434, 119.625}, {182.434, 
                    116.60200000000003`}, {185.137, 117.695}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{176.895, 
                    119.43400000000003`}, {175.35200000000003`, 
                    118.27300000000002`}, {177.98800000000003`, 
                    116.72700000000003`}, {182.82000000000002`, 
                    118.85199999999998`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{178.82800000000003`, 
                    117.75799999999998`}, {177.023, 116.27700000000004`}, {
                    177.21899999999997`, 114.41000000000003`}, {
                    179.85500000000002`, 114.988}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{173.48000000000002`, 
                    116.92200000000003`}, {171.48800000000003`, 
                    115.11700000000002`}, {174.383, 113.89499999999998`}, {
                    177.859, 115.375}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{173.547, 
                    114.92200000000003`}, {170.13299999999998`, 
                    113.37900000000002`}, {171.61299999999997`, 
                    110.54700000000003`}, {173.738, 111.64099999999996`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{287.52, 
                    105.07400000000007`}, {286.727, 103.37099999999998`}, {
                    289.324, 101.98400000000004`}, {291.77, 
                    102.37099999999998`}, {294.121, 102.738}, {296.367, 
                    104.67599999999999`}, {294.60200000000003`, 
                    107.39099999999996`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{294.72999999999996`, 
                    104.043}, {297.051, 102.238}, {301.172, 
                    104.30099999999999`}, {301.172, 107.00800000000004`}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    436.78099999999995`, 376.93399999999997`}, {426.477, 
                    382.08599999999996`}, {405.10200000000003`, 391.617}, {
                    399.047, 383.887}, {404.582, 386.207}, {420.809, 
                    383.758}, {434.203, 371.395}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    436.78099999999995`, 376.93399999999997`}, {426.477, 
                    382.086}, {405.10200000000003`, 391.617}, {399.047, 
                    383.887}, {404.582, 386.207}, {420.809, 383.758}, {
                    434.203, 371.395}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{443.027, 377.47999999999996`}, {431.113, 
                    391.35900000000004`}, {424.09799999999996`, 388.25}, {
                    415.53099999999995`, 393.03099999999995`}, {407.484, 
                    397.52299999999997`}, {394.668, 398.441}, {392.184, 
                    391.29699999999997`}, {403.941, 397.02299999999997`}, {
                    414.734, 388.219}, {421.363, 387.15200000000004`}, {
                    430.469, 385.691}, {435.60900000000004`, 
                    378.65200000000004`}, {438.27299999999997`, 375.414}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{443.027, 377.48}, {431.113, 391.359}, {
                    424.09799999999996`, 388.25}, {415.53099999999995`, 
                    393.031}, {407.484, 397.523}, {394.668, 
                    398.44100000000003`}, {392.184, 391.297}, {403.941, 
                    397.023}, {414.734, 388.219}, {421.363, 387.152}, {
                    430.469, 385.69100000000003`}, {435.60900000000004`, 
                    378.652}, {438.27299999999997`, 375.414}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{487.90599999999995`, 379.254}, {
                    481.72299999999996`, 393.41799999999995`}, {468.504, 
                    389.719}, {462.66400000000004`, 395.73799999999994`}, {
                    454.168, 404.49199999999996`}, {432.66, 412.605}, {
                    423.77299999999997`, 406.555}, {443.348, 
                    407.58599999999996`}, {451.684, 393.062}, {462.148, 
                    388.008}, {469.621, 384.402}, {477.60200000000003`, 
                    376.676}, {487.90599999999995`, 379.254}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{487.90599999999995`, 379.254}, {
                    481.72299999999996`, 393.418}, {468.504, 389.719}, {
                    462.66400000000004`, 395.738}, {454.168, 404.492}, {
                    432.66, 412.605}, {423.77299999999997`, 406.555}, {
                    443.348, 407.586}, {451.684, 393.062}, {462.148, 
                    388.008}, {469.621, 384.402}, {477.60200000000003`, 
                    376.676}, {487.90599999999995`, 379.254}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    464.727, 380.79699999999997`}, {454.168, 
                    393.93399999999997`}, {437.93799999999993`, 
                    405.52299999999997`}, {430.469, 401.14500000000004`}, {
                    440.258, 400.629}, {443.348, 393.805}, {450.305, 
                    389.42599999999993`}, {457.258, 385.047}, {454.168, 
                    378.73799999999994`}, {464.727, 380.79699999999997`}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    464.727, 380.797}, {454.168, 393.93399999999997`}, {
                    437.93799999999993`, 405.523}, {430.469, 401.145}, {
                    440.258, 400.629}, {443.348, 393.805}, {450.305, 
                    389.426}, {457.258, 385.047}, {454.168, 378.738}, {
                    464.727, 380.797}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{414.5, 
                    357.617}, {403.42199999999997`, 361.73799999999994`}, {
                    381.789, 363.79699999999997`}, {371.742, 351.176}, {
                    388.48799999999994`, 348.34400000000005`}, {413.727, 
                    349.89099999999996`}, {414.5, 357.617}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{414.5, 
                    357.617}, {403.42199999999997`, 361.738}, {381.789, 
                    363.797}, {371.742, 351.176}, {388.48799999999994`, 
                    348.344}, {413.727, 349.891}, {414.5, 357.617}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{412.441, 352.72299999999996`}, {
                    401.363, 357.875}, {392.715, 350.68}, {382.305, 
                    351.691}, {362.47299999999996`, 353.625}, {348.305, 
                    352.465}, {346.504, 342.93399999999997`}, {
                    357.83599999999996`, 353.10900000000004`}, {376.895, 
                    344.73799999999994`}, {384.621, 346.79699999999997`}, {
                    392.35200000000003`, 348.85900000000004`}, {420.941, 
                    347.055}, {429.953, 343.191}, {425.316, 
                    348.85900000000004`}, {418.105, 350.40599999999995`}, {
                    412.441, 352.72299999999996`}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{412.441, 352.723}, {401.363, 
                    357.875}, {392.715, 350.67999999999995`}, {382.305, 
                    351.69100000000003`}, {362.47299999999996`, 353.625}, {
                    348.305, 352.46500000000003`}, {346.504, 
                    342.93399999999997`}, {357.83599999999996`, 353.109}, {
                    376.895, 344.738}, {384.621, 346.797}, {
                    392.35200000000003`, 348.85900000000004`}, {420.941, 
                    347.055}, {429.953, 343.19100000000003`}, {425.316, 
                    348.85900000000004`}, {418.105, 350.406}, {412.441, 
                    352.723}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{447.21099999999996`, 382.215}, {
                    444.637, 390.715}, {444.762, 399.72999999999996`}, {
                    457.512, 399.08599999999996`}, {454.29299999999995`, 
                    403.078}, {442.445, 405.137}, {440.512, 390.199}, {
                    426.477, 400.5}, {411.148, 402.305}, {408.32, 
                    393.41799999999995`}, {415.53099999999995`, 
                    399.60200000000003`}, {426.734, 395.094}, {440.125, 
                    379.895}, {441.28499999999997`, 380.539}, {444.375, 
                    381.828}, {447.21099999999996`, 382.215}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{447.21099999999996`, 
                    382.21500000000003`}, {444.637, 390.71500000000003`}, {
                    444.762, 399.73}, {457.512, 399.086}, {
                    454.29299999999995`, 403.078}, {442.445, 405.137}, {
                    440.512, 390.199}, {426.477, 400.5}, {411.148, 402.305}, {
                    408.32, 393.418}, {415.53099999999995`, 399.602}, {
                    426.734, 395.094}, {440.125, 379.895}, {
                    441.28499999999997`, 380.539}, {444.375, 
                    381.82800000000003`}, {447.21099999999996`, 
                    382.21500000000003`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIxIGYC4h1yra8D91U58Opumvtevdzh0FeNmH67Koed
IPGqcgdbruuLCyZWOhzzNu90ZKhweFtjbxp3oMpBNirF+r5pBVw9mF9d4ZD7
/PfKjw2VDotct33+G1PhINx84NTCqZUODCCQBzXPusLh0yXfJIFf5Q6djglP
LzhB6VNQ+/nKHbacKNs336HcoVpknfvDK2UOVyteqhmuKHMo3zdfSn91uYP7
wyqRdcFlEHddKHe4oHT7Z92WMgegq3fIrSyHmL8Eql653AGkLOFimUPGRKAP
Msvh/gU52399ucN9/97peXXlDuDwEKt0MLirwtZoWw7xV3YVRF13mcOy2UcU
NpyC+jcS6i6BGofHS4ESSWUO6OEJADBhoUo=
                    "]]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIxIGYC4h1yra8D91U58Olumvtevdzh0FeNmH67Kgew
eFW5gy3X9cUFEysdjnmbdzoyVDi8rbE3jTtQ5SAblWJ937QCrh7Mr65wyH3+
e+XHhkqHRa7bPv+NqXAQbj5wauHUSgcGEMiDmmdd4fDpkm+SwK9yh07HhKcX
nKD0Kaj9fOUOW06U7ZvvUO5QLbLO/eGVMoerFS/VDFeUOZTvmy+lv7rcweNh
lci64DKIuy6UO1xUuv2zbkuZA9DVO+RWlkPMXwJVr1zu4ANUlnCxzCFjItAH
meVw/4Kc7b++3OG+f+/0vLpyiL/FKh3076qwNdqWQ/yVXQVR113msGz2EYUN
p6D+jYS6S6DG4fFSoERSmQN6eAIAMlGhTg==
                    "], 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{422.227, 
                    356.328}, {416.066, 368.90599999999995`}, {396.082, 
                    357.48799999999994`}, {392.055, 369.672}, {386.555, 
                    351.82}, {420.47299999999996`, 361.699}, {422.227, 
                    356.328}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{422.227, 
                    356.32800000000003`}, {416.066, 368.906}, {396.082, 
                    357.488}, {392.055, 369.672}, {386.555, 351.82}, {
                    420.47299999999996`, 361.699}, {422.227, 
                    356.32800000000003`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{549.3359999999999, 342.676}, {553.5269999999999, 
                    340.594}, {557.148, 343.867}, {550.738, 
                    346.43799999999993`}, {554.934, 344.355}, {558.59, 
                    347.551}, {552.1800000000001, 350.117}, {556.375, 
                    348.039}, {560.031, 351.22999999999996`}, {553.621, 
                    353.801}, {551.91, 352.078}, {549.4649999999999, 
                    345.77}, {549.3359999999999, 342.676}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{549.3359999999999, 342.676}, {553.5269999999999, 
                    340.594}, {557.148, 343.867}, {550.738, 346.438}, {
                    554.934, 344.355}, {558.59, 347.55100000000004`}, {
                    552.1800000000001, 350.11699999999996`}, {556.375, 
                    348.039}, {560.031, 351.23}, {553.621, 353.801}, {551.91, 
                    352.078}, {549.4649999999999, 345.77}, {549.3359999999999,
                     342.676}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4vJ986X0bRodjnmbdzq+K3PwAVIJbY0OQPLp
ha5yh8qXaoYcZo0Ob2vsTeMOlDvobpr7fvmERofW14E75BIrHBYX2HJdv9Xo
sOVE2b75TyocOkD65kHNs6l0AJv/tNHh8FeNmP5FlQ5LQOp/Nzro31Vhazxc
6fCwSmSdu26Tgx3X9cUFrFUORxU2FGUYNjmAtCe4V0Hk/ZscJkuwhPFtroTY
f6XR4b5/7/S8eZUO05y7c57faXSwBelfX+EQ23/oq8ajRoeMiUAXi1c4yIEc
uq7R4YLS7Z91KhUODCAwu9FBq13s5jnlcoj7pyH8H5Vifd+/pdFh6ewjChvK
yhzQwwcAOMWKPA==
                    "]]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4vJ986X0bRodjnubdzq+K3PwAVIJbY0OQPLp
ha5yh8qXaoYcZo0O72rsTeMOlDvobpr7fvmERofW14E75BIrHBYX2HJdv9Xo
sOVE2b75TyocOkD65jU6HAOZZ1PpADb/aaPDoa8aMf2LKh2WgNT/bnTQv6vC
1ni40uFhlcg6d90mB6Do4gLWKoejChuKMgybIO5wr4LI+zc5TJFgCePbXAmx
/0qjw33/3ul58yodpjl35zy/0+hgB9K/vsIhth9o06NGh4yJb2vsxSsc5EAO
XdfocFHp9s86lQoHBhCY3eig3S5285xyOcT90xD+j0qxvu/f0uiwbPYRhQ1l
ZQ7o4QMAO9WKRA==
                    "], CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{555.648, 362.512}, {560.797, 
                    373.58599999999996`}, {566.711, 373.371}, {569.555, 
                    377.707}, {574.9649999999999, 385.949}, {
                    586.4219999999999, 376.289}, {596.082, 383.629}, {594.41, 
                    373.199}, {581.4019999999999, 376.93399999999997`}, {
                    575.738, 370.23799999999994`}, {570.07, 363.539}, {
                    565.434, 360.449}, {555.648, 362.512}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{555.648, 362.512}, {560.797, 373.586}, {566.711, 
                    373.371}, {569.555, 377.707}, {574.9649999999999, 
                    385.949}, {586.4219999999999, 376.289}, {596.082, 
                    383.629}, {594.41, 373.199}, {581.4019999999999, 
                    376.93399999999997`}, {575.738, 370.238}, {570.07, 
                    363.539}, {565.434, 360.449}, {555.648, 362.512}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{556.934, 358.90599999999995`}, {565.949, 
                    366.117}, {572.594, 361.305}, {578.828, 
                    365.08599999999996`}, {594.535, 374.617}, {
                    600.8519999999999, 363.156}, {614.887, 367.66}, {611.148, 
                    358.648}, {590.418, 366.375}, {581.4019999999999, 
                    359.676}, {572.387, 352.97999999999996`}, {540.707, 
                    346.543}, {556.934, 358.90599999999995`}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{556.934, 358.906}, {565.949, 366.117}, {572.594, 
                    361.305}, {578.828, 365.086}, {594.535, 374.617}, {
                    600.8519999999999, 363.156}, {614.887, 
                    367.65999999999997`}, {611.148, 358.648}, {590.418, 
                    366.375}, {581.4019999999999, 359.676}, {572.387, 
                    352.98}, {540.707, 346.543}, {556.934, 358.906}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{530.664, 307.52}, {530.531, 
                    311.641}, {526.668, 316.92199999999997`}, {521.262, 
                    317.566}, {515.8519999999999, 318.207}, {513.531, 
                    323.875}, {509.414, 324.133}, {505.29299999999995`, 
                    324.39099999999996`}, {502.58599999999996`, 332.633}, {
                    496.91799999999995`, 332.504}, {491.254, 332.375}, {
                    488.93799999999993`, 325.03499999999997`}, {502.199, 
                    318.34000000000003`}, {515.4649999999999, 311.641}, {
                    530.148, 303.914}, {530.664, 307.52}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{530.664, 307.52}, {530.531, 
                    311.64099999999996`}, {526.668, 316.922}, {521.262, 
                    317.56600000000003`}, {515.8519999999999, 318.207}, {
                    513.531, 323.875}, {509.414, 324.133}, {
                    505.29299999999995`, 324.391}, {502.58599999999996`, 
                    332.633}, {496.91799999999995`, 332.504}, {491.254, 
                    332.375}, {488.93799999999993`, 325.03499999999997`}, {
                    502.199, 318.34000000000003`}, {515.4649999999999, 
                    311.64099999999996`}, {530.148, 303.914}, {530.664, 
                    307.52}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{513.918, 
                    304.043}, {508.254, 303.78499999999997`}, {
                    507.47999999999996`, 295.543}, {502.074, 
                    295.28499999999997`}, {509.539, 291.29299999999995`}, {
                    514.949, 297.09}, {518.8119999999999, 
                    302.23799999999994`}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{513.918, 
                    304.043}, {508.254, 303.785}, {507.47999999999996`, 
                    295.543}, {502.074, 295.285}, {509.539, 291.293}, {
                    514.949, 297.09000000000003`}, {518.8119999999999, 
                    302.238}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{518.555, 
                    303.012}, {513.664, 298.89099999999996`}, {512.246, 
                    290.262}, {519.328, 287.816}, {515.0780000000001, 
                    293.676}, {526.8009999999999, 296.316}, {523.191, 
                    301.727}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{518.555, 
                    303.01199999999994`}, {513.664, 298.891}, {512.246, 
                    290.262}, {519.328, 287.81600000000003`}, {
                    515.0780000000001, 293.676}, {526.8009999999999, 
                    296.31600000000003`}, {523.191, 301.72700000000003`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{523.449, 
                    302.754}, {519.586, 295.28499999999997`}, {529.504, 
                    294.383}, {526.9259999999999, 288.719}, {532.594, 
                    290.004}, {533.496, 300.695}, {528.3439999999999, 
                    303.527}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{523.449, 
                    302.754}, {519.586, 295.285}, {529.504, 
                    294.38300000000004`}, {526.9259999999999, 288.719}, {
                    532.594, 290.004}, {533.496, 300.695}, {528.3439999999999,
                     303.52700000000004`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{485.58599999999996`, 
                    318.72299999999996`}, {494.85900000000004`, 
                    319.23799999999994`}, {503.34000000000003`, 
                    314.22299999999996`}, {509.027, 306.10200000000003`}, {
                    512.633, 300.953}, {524.738, 298.89099999999996`}, {
                    528.8589999999999, 303.012}, {532.98, 307.133}, {530.664, 
                    315.89099999999996`}, {520.3589999999999, 313.059}, {
                    517.7810000000001, 317.43799999999993`}, {510.312, 
                    315.89099999999996`}, {506.71099999999996`, 
                    319.4959999999999}, {503.10200000000003`, 
                    323.10200000000003`}, {489.191, 333.40599999999995`}, {
                    485.58599999999996`, 318.72299999999996`}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{485.58599999999996`, 318.723}, {
                    494.85900000000004`, 319.238}, {503.34000000000003`, 
                    314.223}, {509.027, 306.102}, {512.633, 300.953}, {
                    524.738, 298.891}, {528.8589999999999, 
                    303.01199999999994`}, {532.98, 307.133}, {530.664, 
                    315.891}, {520.3589999999999, 313.05899999999997`}, {
                    517.7810000000001, 317.438}, {510.312, 315.891}, {
                    506.71099999999996`, 319.496}, {503.10200000000003`, 
                    323.102}, {489.191, 333.406}, {485.58599999999996`, 
                    318.723}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}}}, {{{520.3589999999999, 
                    313.059}, {517.914, 312.543}, {517.141, 
                    308.29299999999995`}, {518.6840000000001, 
                    306.10200000000003`}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{520.3589999999999, 
                    313.05899999999997`}, {517.914, 312.543}, {517.141, 
                    308.293}, {518.6840000000001, 306.102}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}}}, {{{525.641, 
                    310.47999999999996`}, {526.414, 309.195}, {525.898, 
                    307.39099999999996`}, {525.512, 306.48799999999994`}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{525.641, 310.48}, {
                    526.414, 309.195}, {525.898, 307.391}, {525.512, 
                    306.488}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}}}, {{{500.27, 
                    318.34000000000003`}, {505.03099999999995`, 318.082}, {
                    505.93799999999993`, 314.60200000000003`}, {
                    511.08599999999996`, 313.316}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{500.27, 
                    318.34000000000003`}, {505.03099999999995`, 318.082}, {
                    505.93799999999993`, 314.602}, {511.08599999999996`, 
                    313.31600000000003`}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJ5IGZigAKheofc579XflxQ4rD1RNm++TwNDrG7PHmY
4kscsvaUTJYobXDImPi2xl61xEE2KsX6/tYGh9bXgTvkbhc7bAGp/9YA0T+h
2IFXd9Pc91GNDjvkgCpqih2Wzj6isGFTo4MVSOHaYgdbruuLC7iaIObdh8pv
bnI49FUjpp+nxOGyb5JAxOomh8cgCaNiCP9mk4O3eadjwvxihw7HhKcX5jU5
dIJokRIHwQjLLSc0ofKaJQ7TnLtznmtDzZtSAqE/NULkv0LNP9noYHBXha1x
a4nDts9/r1S8b3TQahe7eW5/CUSdQJODcPOBUwsNSxzK982X0j/aCPHX92KI
fZcbIf5PLnG4oHT7Z928Rgc+kPzhEoeYfqCN6Y1w+3WAwsu7oPrrSxys7/v3
Tl/XCHE/RwnEn/GN8PAEOeO7TqPDMZBD9hU7LCkAhtjjBgdQsPs/Lnbw4mHS
bl+LiA+w+8qh/PQSiL6eOggdVuqAHr8AWwfnhw==
                    "]]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJ5IGZigAKheoec579XflxQ4rD1RNm++TwNDnG7PHmY
4kscsvaUTJYobXDImPi2xl61xEE2KsX6/tYGh9bXgTvkbhc7bAGp/9YA0T+h
2IFXd9Pc91GNDjvkgCpqih2Wzj6isGFTo4MVSOHaYgdbruuLC7iaIObdh8pv
bnI4/FUjpp+nxOGyb5JAxOomh8cgCaNiCP9mk4OPeadjwvxihw7HhKcX5jU5
dIFokRIHwQjLLSc0ofKaJQ7TnLtznmtDzZtS4nAIRH9qhMh/hZp/stFB/64K
W+PWEodtn/9eqXjf6KDdLnbz3P4SB2+QOoEmB6HmA6cWGpY4lO+bL6V/tNGB
D+Sv78UQ+y43QvyfXOJwQen2z7p5UPnDJQ4x/UAb0xvh9usAhZd3QeXrSxys
7/v3Tl/XCHE/RwnEn/GN8PAEOeO7TqPDcZBD9hU7LCkAhtjjBgdQsPs/Lnbw
4mHSbl+LiA+w+8qh/PQSh2MgfT11EP1hpQ7o8QsAYl/nkA==
                    "], 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{538.648, 336.754}, {533.496, 
                    334.43799999999993`}, {536.8439999999999, 329.027}, {
                    528.8589999999999, 325.93799999999993`}, {520.875, 
                    322.84400000000005`}, {515.3359999999999, 315.762}, {
                    517.141, 309.71099999999996`}, {522.5509999999999, 
                    321.559}, {532.0780000000001, 321.043}, {
                    535.4259999999999, 325.68}, {538.777, 330.316}, {543.668, 
                    337.141}, {538.648, 336.754}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{538.648, 336.754}, {533.496, 334.438}, {
                    536.8439999999999, 329.02700000000004`}, {
                    528.8589999999999, 325.938}, {520.875, 322.844}, {
                    515.3359999999999, 315.762}, {517.141, 309.711}, {
                    522.5509999999999, 321.55899999999997`}, {
                    532.0780000000001, 321.043}, {535.4259999999999, 
                    325.67999999999995`}, {538.777, 330.31600000000003`}, {
                    543.668, 337.14099999999996`}, {538.648, 336.754}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIxIGYC4gtKt3/WPWhwcH9YJbLuf4mDLdf1xQX3Ghwy
Jr6tsc8sgdCLGxw+XfJNElhQ4uBj3umYsKvBYensIwobzhQ72Nz3751+sMFh
Rp5Q84GuYgcGEDjf4ADknVooX+wQlWJ9339HgwNIWd6WIgeBCMstJ341QMRF
ix0qX6oZclyA6n9Q7DDNuTvn+dsGB4O7KmyNuiUQdX8aHLaeKNs3P6jEYXEB
0IV8jQ475FpfB/aUOGTtKZksIdboYLUFqGBviQOIms/WCHF3eomDzqa575ez
NzqA/XkMar5hI8TcuVA+fyPE3XYlEP/0NjrIghQcLIG4zxyqvroU4m8tqHq/
UgdPHibtduZGB2GQf/+WOKCHJwBBqZ8M
                    "]]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIxIGYC4gtKt3/WPWhw8HhYJbLuf4mDLdf1xQX3Ghwy
Jr6tsc8sgdCLGxw+XfJNElhQ4uBj3umYsKvBYdnsIwobzhQ72Nz3751+sMFh
ep5Q84GuYgcGEDjf4ADknVooX+wQlWJ9339Hg8MDoLK8LUUOAhGWW078aoCI
ixY7VL5UM+S40OAwA6T/QbHDNOfunOdvGxz076qwNeqWQNT9aXDYcqJs3/yg
EofFBUAX8jU67JBrfR3YU+KQtadksoRYo4MVSMHeEog6tkaIu9NLHHQ2zX2/
nL3R4SLIn8eg5hs2QsydC+XzN0LcbVcC8U9vo4MMSMHBEoj7zKHqq0sdloL8
rQVV71fq4MnDpN3O3Ajx798SB/TwBABCqZ8M
                    "], 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{513.7890000000001, 345.383}, {
                    515.0780000000001, 343.449}, {516.3669999999998, 
                    338.559}, {515.207, 335.85200000000003`}, {
                    517.7810000000001, 337.39799999999997`}, {521.52, 
                    341.39099999999996`}, {522.676, 344.094}, {
                    527.9569999999999, 343.32}, {530.016, 336.754}, {524.996, 
                    333.92199999999997`}, {528.086, 333.92199999999997`}, {
                    533.3669999999998, 333.92199999999997`}, {536.328, 
                    337.39799999999997`}, {532.7230000000001, 
                    341.39099999999996`}, {521.52, 347.57}, {
                    513.7890000000001, 345.383}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{513.7890000000001, 
                    345.38300000000004`}, {515.0780000000001, 
                    343.44899999999996`}, {516.3669999999998, 
                    338.55899999999997`}, {515.207, 335.852}, {
                    517.7810000000001, 337.398}, {521.52, 341.391}, {522.676, 
                    344.094}, {527.9569999999999, 343.32}, {530.016, 
                    336.754}, {524.996, 333.922}, {528.086, 333.922}, {
                    533.3669999999998, 333.922}, {536.328, 337.398}, {
                    532.7230000000001, 341.391}, {521.52, 347.57}, {
                    513.7890000000001, 345.38300000000004`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxdlAtIFVEQhm8aYaESZWVFZlFiRphgRfZwCsQyohKSkhKRSimy8Ozr7u69
dxeJXkiYhVSEpVkJJVoWFhVa9jIQsfIWYmYikvZAJaSH1R7/g1ALy2H3zMz5
/29md07WgdTdgS6Xa4xzpzp3gHNn3F0fHDDToISaZ8qD+wpNzq9rvBhi0Kz0
XSs6nit0qG9LbcSQTqsn+MsOvlaoOHdSfl2Tjvh2hVz8StWJh28aUuj9poLi
3JM6Lef72SrxpeSXjrw9KuUUfjYTOwwaaNmYNTFDo+a5bd+9GSat4vVLVLrF
4/M8qP9ZxL/0QMd4DfqmeKk06fbgsEujpxuWHV2T4sXaq0L3Yy+Vn2uIrFqp
kR5WmdyZ5kPefA1663x0dE1md3ODSsmdTsQLH/H0TL+Ktc1Hc6rycgq7xXO/
D3F9Ku29JxWFL7Do4bfoHSfGadC32ULdGqF/p0UGP3edSi8dm9vyLaFDhc9K
i2Lb542z41Q6wnU0ivzfCrgMWFQb4TiOEueF2NTFDUWr5P4YFRc0zQZXJ35k
P8GmSdzfbJUcKq+0bBv58SryvDZ4NSjwfcoG360KPeI+1tngpSikPiiZEbvS
ppjDU982HZexH2/Dzw+JnC4XFHdZ4FwvET+mtswi/jo3XKaU4ICFh1cJ/6Uy
RXKON33o3x0Zujf7aCefux5J9NkLXWESPeHAL3jpMtdzlqFulUfMDaPQRTfO
f93uoRC+DjHw7jVRz8/Ql0smvdYcUBr7d76mM/Rz0ADvPAZuzEB/sxm4hZk4
12KY21YDfq4y6Moy4b+a0RczcUnGBxOc7zKcU29i3uIkcJzswf5aCfEt4ryv
ov47A/6yJSoKH5sW6tdHeYzEpxjoS4WE7+qPgbw0sZ9uIv+6BH/7DKzVEvy7
DMzzRhn1T+uYs2AZuj658b5c8F+qQ5+P4bv2aDj/DEPcFZUW8/ktF8/O3I1w
OSLiSxTa3/Ozoj+IgZNHhY5WCf25pmH/jchPdCNvnwRup92j8zXynfjd4Bgo
ow9jdehMkwUnHf6ZDB4xOuLzZXBI0vF/OCbmr1X8R4Zl9LnGLXgp9P//8C8A
IlPh
                    "]]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxdVAlIFFEY3lSiQiXMym6Nig5CBCsyy98gNCsyoaWiRKRSKix8c+3M7O4M
EmoRYRZ2EFZmJVRYWVhUWNllIJ1uER0mImklKiHdzdvvIZQwDOP7j+96G5e7
PWtTqMvlGuQ8Wc4T4jzZ15aGh4wzaH7dA+XmDYVGFDU0HY8waMK6jQvePVRo
Z9eq+on9Oi0aFqja8UKhioKoooZmHfVvFHLxvyydePnKfoXer9xTUbBPnOep
xF+VP3U6yPs2q5Rf9tlMeWdQ79MVucOzNXo8+fU3X7aJ+ZUqXeb1hV70fxb1
z7zAMVQDvpE+OrHkSt8vl0b3l80rTc3w4d2pAvddH5060hhbm6yRHn0+rdXt
pyjeN1UD3gY/labmtD9uVCmt1al45KflTntOQCU+Jue1n+JqC/PL2sV3j5/S
eV2XSluuS+UxMyy6/XX6+r2DNeDLtDC3TuDfYJHB96ar9MyhuaZIfLtVWsh5
nrco/s2UwXaCSiUcR5Po/61Al16L6ic6jKeJfRE2tVU7hKar5Pk4LWHIaBu6
OvXB8yQb/Cap5KjyXMuz0Z+oos9nQ69GBbz329B3tUJ3OI90G3opCqk3K8fG
J9s0q3jUq+bdMs4Tbej4XSLH5T0VbRaN5zrfkoivqa+y4HuMTBnhIbOKF1qo
PyFTLNfxkh/+XZWBO9NPwdx1SJQU9NlHuziuaInuccGPCf8OM+LrCmq9IjeM
ImdfPNq91ot3P4PenSbmBRh8OWnSc80RSmP/5msMg599BvQuZNCNGfA3j0G3
aBN8LIa8txjw7wwDrlwT/C8w+mKmzMn+YELnawz+3jIxN0GimVzHEV6cL5ZQ
/1Ts6xbz3xrglydReUyYOzKgD+gRrM8wSOG+1Ejw7Y+B++QW5+tM9J+TwG+r
gTxfkMDfZcCHFTLmH9CRs3AZuD55aD//f7XQf64OfH6Ge+3VsP8QQ/9pFfmt
Ft9O7oK6lIj6SoW2dfyo6RnCcB+9Kj3hOFok+HNWw/lL0Z/iQd9WCff7gGcg
X8E9AQ/yGCrDhzAd990tI8/ROvgzGXrM1FFfJEOPJTp47RL5a9Hgzy8Z+arz
CL0U+v/38C8RUlPn
                    "], CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{546.875, 367.90999999999997`}, {
                    547.2230000000001, 367.188}, {547.4019999999999, 
                    366.246}, {547.4019999999999, 365.08599999999996`}, {
                    547.4019999999999, 359.41799999999995`}, {
                    538.9019999999999, 359.16}, {538.391, 350.789}, {538.121, 
                    346.414}, {537.617, 343.965}, {534.6519999999999, 
                    344.47999999999996`}, {531.691, 344.9959999999999}, {
                    529.117, 349.633}, {531.949, 355.039}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{546.875, 367.90999999999997`}, {
                    547.2230000000001, 367.188}, {547.4019999999999, 
                    366.246}, {547.4019999999999, 365.086}, {
                    547.4019999999999, 359.418}, {538.9019999999999, 
                    359.15999999999997`}, {538.391, 350.789}, {538.121, 
                    346.414}, {537.617, 343.96500000000003`}, {
                    534.6519999999999, 344.48}, {531.691, 344.996}, {529.117, 
                    349.633}, {531.949, 355.039}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}}}, {{{437.93799999999993`, 
                    372.29699999999997`}, {435.805, 373.79699999999997`}, {
                    433.668, 374.40599999999995`}, {431.758, 
                    374.42199999999997`}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{437.93799999999993`, 
                    372.297}, {435.805, 373.797}, {433.668, 374.406}, {
                    431.758, 374.422}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    484.594, 382.684}, {491.414, 379.72999999999996`}, {
                    494.73799999999994`, 372.64500000000004`}, {504.648, 
                    372.29699999999997`}, {514.1840000000001, 371.965}, {
                    520.102, 358.133}, {536.07, 367.148}, {536.504, 
                    367.39099999999996`}, {536.9259999999999, 367.617}, {
                    537.3359999999999, 367.828}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    484.594, 382.68399999999997`}, {491.414, 379.73}, {
                    494.73799999999994`, 372.645}, {504.648, 372.297}, {
                    514.1840000000001, 371.96500000000003`}, {520.102, 
                    358.133}, {536.07, 367.148}, {536.504, 367.391}, {
                    536.9259999999999, 367.617}, {537.3359999999999, 
                    367.82800000000003`}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}}}, {{{508., 380.301}, {506.578,
                     378.03499999999997`}, {506.254, 374.879}, {
                    506.64500000000004`, 372.105}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{508., 380.301}, {506.578,
                     378.03499999999997`}, {506.254, 374.879}, {
                    506.64500000000004`, 372.105}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{476.828, 351.176}, {464.727, 351.176}, {461.633, 
                    344.9959999999999}, {461.633, 339.07}, {461.633, 
                    333.148}, {467.301, 325.42199999999997`}, {477.348, 
                    325.42199999999997`}, {487.39099999999996`, 
                    325.42199999999997`}, {492.801, 331.60200000000003`}, {
                    492.801, 338.301}, {492.801, 344.9959999999999}, {486.617,
                     351.176}, {476.828, 351.176}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{476.828, 351.176}, {464.727, 351.176}, {461.633, 
                    344.996}, {461.633, 339.07}, {461.633, 
                    333.14799999999997`}, {467.301, 325.422}, {477.348, 
                    325.422}, {487.39099999999996`, 325.422}, {492.801, 
                    331.602}, {492.801, 338.30100000000004`}, {492.801, 
                    344.996}, {486.617, 351.176}, {476.828, 351.176}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{479.02, 325.68}, {478.762, 329.027}, {
                    472.71099999999996`, 328.512}, {472.965, 
                    331.08599999999996`}, {473.22299999999996`, 
                    333.66400000000004`}, {476.316, 334.691}, {476.316, 
                    338.301}, {476.316, 341.90599999999995`}, {
                    481.72299999999996`, 342.16400000000004`}, {483.527, 
                    339.328}, {485.328, 336.4959999999999}, {
                    490.73799999999994`, 330.957}, {491.89799999999997`, 
                    333.79299999999995`}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{479.02, 325.67999999999995`}, {478.762, 
                    329.02700000000004`}, {472.71099999999996`, 
                    328.51199999999994`}, {472.965, 331.086}, {
                    473.22299999999996`, 333.664}, {476.316, 
                    334.69100000000003`}, {476.316, 338.30100000000004`}, {
                    476.316, 341.906}, {481.72299999999996`, 342.164}, {
                    483.527, 339.328}, {485.328, 336.496}, {
                    490.73799999999994`, 330.957}, {491.89799999999997`, 
                    333.793}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}}}, {{{483.527, 339.328}, {
                    480.691, 336.4959999999999}, {479.40599999999995`, 
                    330.699}, {483.141, 326.195}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{483.527, 339.328}, {
                    480.691, 336.496}, {479.40599999999995`, 
                    330.69899999999996`}, {483.141, 326.195}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}}}, {{{487.39099999999996`, 
                    334.949}, {486.48799999999994`, 333.02}, {486.234, 
                    330.059}, {487.262, 328.254}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{487.39099999999996`, 
                    334.94899999999996`}, {486.48799999999994`, 333.02}, {
                    486.234, 330.05899999999997`}, {487.262, 328.254}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{535.488, 344.414}, {
                    544.9569999999999, 343.645}, {546.5659999999999, 
                    354.074}, {539.484, 354.719}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{523.8359999999999, 
                    372.555}, {520.555, 376.742}, {513.02, 378.156}, {512.891,
                     369.27}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    511.98799999999994`, 359.16}, {508.77, 367.148}, {500.527,
                     368.305}, {496.14500000000004`, 364.312}, {492.504, 
                    360.99199999999996`}, {492.414, 352.33599999999996`}, {
                    500.27, 350.53499999999997`}, {502.97299999999996`, 
                    353.754}, {508.254, 358.004}, {511.98799999999994`, 
                    359.16}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    511.98799999999994`, 359.15999999999997`}, {508.77, 
                    367.148}, {500.527, 368.305}, {496.14500000000004`, 
                    364.312}, {492.504, 360.992}, {492.414, 352.336}, {500.27,
                     350.53499999999997`}, {502.97299999999996`, 353.754}, {
                    508.254, 358.004}, {511.98799999999994`, 
                    359.15999999999997`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}}}, {{{508.445, 364.184}, {
                    503.809, 368.305}, {496.984, 360.51599999999996`}, {
                    503.168, 353.367}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{508.445, 
                    364.18399999999997`}, {503.809, 368.305}, {496.984, 
                    360.51599999999996`}, {503.168, 353.367}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    523.8359999999999, 372.555}, {521.004, 375.582}, {514.824,
                     373.199}, {516.559, 367.082}, {517.914, 369.914}, {
                    520.809, 372.29699999999997`}, {523.8359999999999, 
                    372.555}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    506.328, 356.059}, {508.28099999999995`, 
                    357.47299999999996`}, {510.29299999999995`, 358.637}, {
                    511.98799999999994`, 359.16}, {511.062, 361.453}, {
                    509.727, 363.184}, {508.184, 364.39099999999996`}, {
                    506.71099999999996`, 365.40599999999995`}, {502.477, 
                    359.715}, {506.328, 356.059}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    498.72299999999996`, 366.504}, {494.08599999999996`, 
                    369.594}, {489.83599999999996`, 369.336}, {
                    488.41799999999995`, 366.762}, {485.074, 366.891}, {
                    482.305, 364.44100000000003`}, {482.172, 359.547}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{489.324, 357.488}, {
                    483.78499999999997`, 361.28499999999997`}, {476.188, 
                    359.871}, {476.703, 351.371}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{473.35200000000003`, 
                    346.543}, {476.055, 348.73}, {479.91799999999995`, 
                    350.27700000000004`}, {482.883, 346.414}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{514.691, 
                    354.90999999999997`}, {513.664, 353.496}, {512.891, 
                    351.305}, {514.5619999999999, 347.957}, {512.504, 
                    350.664}, {507.35200000000003`, 350.664}, {501.812, 
                    343.44899999999996`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{526.9259999999999, 
                    355.297}, {520.23, 354.527}, {520.3589999999999, 
                    350.14799999999997`}, {525.766, 348.21500000000003`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{479.277, 371.652}, {
                    473.60900000000004`, 372.812}, {469.48799999999994`, 
                    369.46500000000003`}, {477.348, 366.633}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{490.09799999999996`, 
                    375.51599999999996`}, {482.10900000000004`, 377.449}, {
                    478.89099999999996`, 375.391}, {482.4959999999999, 
                    373.586}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{467.043, 
                    343.44899999999996`}, {466.78499999999997`, 
                    340.61699999999996`}, {468.328, 336.88300000000004`}, {
                    472.965, 341.133}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{468.59, 
                    334.94899999999996`}, {468.59, 334.17999999999995`}, {
                    468.46099999999996`, 333.27700000000004`}, {467.941, 
                    332.633}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{450.043, 
                    372.68399999999997`}, {445.148, 374.102}, {444.25, 
                    378.609}, {449.91799999999995`, 378.223}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{448.371, 362.254}, {
                    442.96099999999996`, 364.055}, {442.96099999999996`, 
                    369.336}, {447.465, 368.82}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{458.414, 364.957}, {
                    452.10200000000003`, 366.504}, {451.848, 370.883}, {
                    456.613, 370.238}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{459.188, 378.352}, {
                    455.84000000000003`, 378.609}, {450.688, 374.875}, {
                    459.316, 372.68399999999997`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{468.59, 370.883}, {
                    460.734, 372.039}, {460.863, 368.82}, {465.4959999999999, 
                    366.762}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{474.512, 378.352}, {
                    468.46099999999996`, 379.508}, {466.39799999999997`, 
                    375.902}, {470.52, 374.359}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{455.453, 356.07}, {
                    453.969, 357.293}, {452.75, 363.156}, {459.828, 
                    361.414}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{470.133, 357.875}, {
                    465.371, 359.15999999999997`}, {460.863, 354.527}, {
                    465.23799999999994`, 351.82}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{476.441, 
                    363.40999999999997`}, {471.42199999999997`, 364.312}, {
                    467.172, 362.898}, {469.875, 361.094}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGZigAKXKocZeULNB7pKHYSbD5xaWFrlcEHp9s+6
aaUOx7zNOx33VUHoulIHxQ1FGRN1qx1ko1Ks73uWOgiB1BdXO+Q+/73yo0ap
g3a72M1zrjUO1SLr3B8+KoGYd7IGLg/mO9Y42HJdX1zwvcRh2ewjChtuVTsY
3FVhazyKMG86yD1rSh0OfdWI6eepdvh0yTdJYEophA6ocuDT3TT3fW4pxN0M
VQ6trwN3yO0sdXhXY28ad6gKrv8wSL9WNcT9bmUOvCB97DUOIG7CQYR7d8gB
TZhT6vB4KdBBU2ocFED+bIbyb9U4uD+sElnXXgrxl0oNRDypDKLftNoBHI7X
Sh0mS7CE8clWO5Tvmy+l317msBNkble1g9WWE2X7BMsg7pxaA1G/CMqXrYX7
HwCZTbJg
                    "]]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGZigAKXKofpeULNB7pKHYSbD5xaWFrlcFHp9s+6
aaUOx7zNOx33VTkcB9F1pQ6KG4oyJupWO8hEpVjf9yx1EAKpL652yHn+e+VH
jVIH7Xaxm+dcaxyqRNa5P3xUAjHvZA1cHsx3rHGw47q+uOB7icOy2UcUNtyq
dtC/q8LWeBRh3gyQe9aUOhz6qhHTz1Pt8OmSb5LAlFIIHVDlwKe7ae773FKI
OoYqh9bXgTvkdpY6vKuxN407VAXXfxikX6sa4n63MgdekD72GgcfIDfhIMK9
O+SAJswpdXi8FOigKTUQfzZD+bdqHDweAn3UXupQDfKXSg1EPKkMot+02gEc
jtdKHSZLsITxyVY7lO+bL6XfXuawE2RuV7WD5ZYTZfsEyyDunFoDUb8Iypet
hfsfAJlVsmE=
                    "], CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}}}, {{{523.57, 372.555}, {
                    520.738, 372.027}, {518.2030000000001, 370.367}, {516.559,
                     367.082}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{523.57, 372.555}, {
                    520.738, 372.027}, {518.2030000000001, 370.367}, {516.559,
                     367.082}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}}}, {{{436.26599999999996`, 
                    358.395}, {434.672, 360.379}, {435.395, 362.355}, {
                    433.684, 363.91799999999995`}}}]}, {
                    Thickness[0.0005555555555555556], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{436.26599999999996`, 
                    358.395}, {434.672, 360.379}, {435.395, 362.355}, {
                    433.684, 363.918}}}, CurveClosed -> {0}]}}, AspectRatio -> 
                  Automatic, ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 720.}, {0., 480.}}], ",", 
                 GraphicsBox[{
                   Thickness[0.0008680555555555555], {
                    FaceForm[{
                    RGBColor[
                    0.968627, 0.8784310000000001, 0.09019610000000002], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 576.}, {1152., 576.}, {1152., 0.}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    1152., 296.}, {1152., 160.}, {0., 400.}, {0., 536.}}}]}, {
                   
                    Thickness[0.0008680555555555555], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    1152., 160.}, {1152., 40.}, {0., 280.}, {0., 400.}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.8117650000000001, 0.06666670000000002, 0.14902], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxdVn9QVFUUJiMW0RwSJjPUUScUB0r4wzADPMokg0BOUWoSu++9fbtLZGpR
aex7yy77HtoPKjKTqRxGQdEgYjSVzIgRA2vS8WdYiMg4hZrlGEEy2tS977ux
k8y8Yb+9957znfN997ydpqx+0nVnWFjYHezZwJ5R7KleNT7YpgZo8dhRievH
2en1BdLPxy/5SZ8/x36gyk7X6jtyUtf6KbnngYjAUQetUB/tXZLgJ29sU1Zf
q0Rh/G+in34a9hUfvCRR0u4t1+qj/GQ/kD121BiZclJZxMgQLj748sb7IkK4
qOo3bX64n97ezIick0awFX+bhPwMN05imf9xEGP73db+MoqPCGzKLHDQ2taa
+2dvKqOhhGffOXSXg1qmmL8+saiM1t/747G/9tjpj5N5SvQxH8XNZgU846Dj
07uHfSt9xLLMsT8u0dTml4qqbD76itEKH5Lohf6bu66/pxM7nX/xFZk6eAHJ
OnjtkmklXz+v0dPjHty95ZRM7NTScSUafc1o9HwvE8veMiVeo0peT7WMeGEa
dfI4fhn8u7yIXyj6860X67ki3pde2nvk1daaeSJeg1hPktHvHSF8cftHh6dW
34Y/9NK8z1mAbpn4v5qdXvCNUZCfxbfqKVRoB9vefMWL77cr4DNNE3ortO2x
fQN/p2kUw9f7FMrqK41tytdoKY93M4QtPWzOEWz5aryTfud9Xiz6k+ZE/zI0
6uZ+UZ2UyIWaqIHnL07UP0ujNelRXbWqivXnRL5Olc6suzwjpVEDryQXdJyk
0wmua4YLdZTp8NeAirjVOvp2QSVuo97PdOhzXIWf94Sw5Z+2ELbit+jg/6cK
/7yvw2+FLuhbrBO/NtO7XKhbEflj3MhbpKM/tW46NMgOrtJpTFftmvQVHuj7
hU7LeH3XPMgX60O+Wx4q5ffA7kP9tiLoVulDnWfE+Zs+5An3IP80P/hVqdh/
2k/8mvTMdRJv65q6AL3LiXQruCdnA/QIb1S7Qtw+zQvLRf3CH/5yxBtU6DXW
/si0IPrqdtI9y9nJG0HE61VxH98ywCPKA157DehZ54GvjxiUy3121AO/XjFw
Hxi2+NpM4jTTj3mQJ87EfNnpQf+TTWq4zi52roey+dzKNBHnhhv1ZJvQud5N
H2S+ubI/y0R9M92It8gkPg4CZ1zIx85bffzUhfpSTfif6Wvxjxfx+lXMkwQT
/junEm9TW46J+mLFec2Eng4XsV2n1+0X+9Nc0L/LpIXcL+0q+jcg4i9Toc+Q
SS/yD1edqO+C2F8g8FkT/Yp3ot4TJk3m5weUEWzxvhrCVr97FPBn560+/qDQ
KQaXD5qYD//pH1eBfA1C/5QK8J8bwtZ8fkMewZZPl4r5nlwxMo8s/FDF/+dT
UghbfphcAT0WyFTHG3l3BZVwYQrE/j4TOm2XiV/Plk6TPuH6t8jo50aTCvl9
2y+jn8+bNDMlsnHSPhn12k3MhyaZDvOBv9Ckkxwz/pY/Jpi4r/kiHvOj1T/2
Pmvn+BuBVQnvx48NwcdB/FYkBA3onO2AfgUG8XaU5jqITZfKzQ8beH8tcUCH
yQZt5f2sc4BftAEfzZCgV6QBv+ZLZI0Fm4H5sVoiDutHG5gPpyWK5vVGifUJ
MvIxbPk3T8Z9HB3CFn9bCGdwvsNB+H+WTHx8Z10O4n18S6INfH9rEPNnvQR/
1AbhvzwJ/EuC4BMm1s+XE6fZkWgH38hyeooLKRXS7b83/gUIKM2n
                    
                    "]]}, {
                    FaceForm[{
                    RGBColor[1., 0.8, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIlIGYC4qMKG4oyBFscLijd/lnHluTQ6Zjw9IJ2i8Pq
j5d8k2ySHI6A5P1aHDImvq2xP5nkYHPfv3d6TItDgS3X9cUWyQ6yUSnW99Nb
HLzNgTonJjts//z3SkVmiwMDCGxIdugAmZfV4qDG1jjV2TvF4RPQWIGcFodL
IPtupUDUZUPNY0l14NPdNPd9SovDKpD9JqkOj5fOPqIQ1+LwTSOm/1BmqkO7
2M1z36NbHLaeKNs3Py/VgRek3gvB3way3wrBBznP37zF4TjIgRmpDotBFum1
OOwtmSzBYpbqoAPUvlwJav7bFAc7oDMKFFschJsPnFoYmAIxR6fF4V2NvWmc
VIqDNcj/xi0OMiCDvyc7HP4K1GjS4tB/CMgA8sHh4NwCcbdACsS94S0OF0H+
NUpxAHmzAOj+/fOl9O8apEDUA/m90/OEmllSIOEM5BeBGJOTHQQiLLecMGpx
AJoS/HhnksPDKpF17hxQvmuSwxKQf/40O2wBuVMtCeK+T80OliAB5iQHg7sq
bI0fmyH+/5EIic93zZBwv5HokLUHGBD/mh1A0aR0P9EBPT0AAPiN+JY=
                    
                    "]]}, {
                    FaceForm[{
                    RGBColor[1., 0.831373, 0.16470600000000002`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4qWzjyhsONboILrO/WGVTbxDxsS3NfYPGh0Y
QKAh3kEgwnLLiXeNDpvnvl9+7He8A5D0Nv/Z6ND6OnCHXGmCgy3X9cUF/xod
CkGMDQkOfLqb5r5nbHK4qHT7Z927BIfKl2qGHDD+vwQHmagU6/tA9QUg9SqJ
DrIg/udGh60nyvbNV0p0ALvneaODS3fO898/Exwu+yYJRNxvdABZY3svweEK
iH8P6r4LCQ7yIIcA3dt/6KtGzPQEiHufNULsYU9w+HQJqOFWo0Pv9Dyh5hPx
DhX75kvpT2t08OJh0m7vi3fQv6vC1tjf6BDyGGhzRzzE3JpGh1p707hdE+Mh
5mQ1OswAaj+wKN5hC8idXo0O8bs8eZgOxzuAtCnYNzps+/z3SsXKeIcOx4Sn
F7yg4RUdD3GvX6ODH5CydIl3ABnnH97oIAIKb5V4B5CzDsQ1QsJdNN6hE6S/
oNHhuLd5p+OHOIj6zY0OD6uAOjjjHdDjCwB5h8qs
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJ5IGYC4qgU6/v+wU0OFS/VDDly4h1i+g991QhvcvgP
Au3xDpd9kwQiUpocQh4vnX1kR7zD1hNl++YXNDkc8zbvdLwR78AAAo1NDhkT
39bYMyY4bP/890pFZ5ODDMhg8QQHkLKECU0O++dL6d91SHB4WCWyzn1Jk0MR
SMP2BAeb+/690xc0OQg3Hzi1UDbRAeyeZqj88kQHW67riwuKmxxAlO2nRIcj
ChuKMnKaHI6DDP6Q6DA9T6j5QHyTQ+vrwB1ycxMdgLY9vRDS5OADsjc00eHT
JaAHQqH2B0Dlgf4pBBnsAJXPbYL4wyLRoV3s5rnvJU0OVluAHpVPhPi/Euo+
xkSHC0q3f9Z1NTnE7fLkYepOcLADOay1yUH/rgpbo2MCxDyg+4CqsvYA/Qs2
NxRqPpCvs2nu++V+TQ7VwGB4aJQA8Z9Hk4MXD5N2+7t4h/fLgSHrCg3vDfEO
wNiI6XdqcpAHeTAPwd8MNOZYNIK/DRTumvGQ8PVucnDpznn+2zDeAT1+AaDz
25I=
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4vfLj3mbqzY5PF46+4iCTYLD4a8aMf2aTQ4T
DgEZ2QkOny75JgloNzkwgMCBBAfr+/6907WaHO78rMvak5PokDnxbY09kL/q
I1Dhh0QHPt1Nc99rQM1LSHIAURvUmxxaXwfukEtNcpCNSrG+rwxVX5LkMM25
O+e5QJOD5ZYTZfuckxyAqosy+KD6VZIcsvaUTJbghcoLJzmU75svpc/f5HDz
3Pfgx28TIe4ThrrvQqJDuxhQRqLJAegq07hFiQ7yIIslmxzCQA4rT4TYJw41
/0iCw1agsfNFmxwuKt3+WXco3uEy0LgIoPrmA6cWupbFO6CHDwDaDYs8
                    
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4mnO3TnPdzQ6HPc273RckeBQvm++lP7uRoeL
Srd/1l1KcIjtP/RVY1+jA0j4rkaig/5dFbbG/Y0Oj5fOPqKQkeiwpMCW6/qB
RgeQspjliQ6fLvkmCRyB8r8nOmw5UbZv/rFGBxegNb8lkyDmn210eFtjbxpX
lORgfd+/dzpQ/ptGTP+hziSHGJDGrVDzI5IcsvaUTJZY0egQt8uTh8k4yWEx
yL5VjQ6WIIM3Jzo8rBJZ57620aH1deAOOcdEB8EIoAxQvVPC0wtK2VD3L4L6
TyLB4YjChqKMBVD7mRIc2sVunvsOlGcAAY4EhwqQ+1ZB3aOZ4FD5Us2QY0Oj
wyLXbZ//uiRA/LOt0QGoK/hxbYIDevgBAAJ8n60=
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxdVQ9MlVUUf6IjYvJUaIRmSFhpmqJsCaXU79Ws/IOumI41dPfe77W9LA2V
JMn47p2pUWPkmFpzRQqGERUrYq0RGhC2aoWwxaohQ5blnBG2MtfKvvPOKbbe
9u3b+e495/zO75zfeTeZJx9+dGIoFJoQPKXBkxA8Nz4SXTpU7NCX/f2Vyk0K
m9rLajNiDskD9aUFRxVGG3tW5T3ucHR5269/dSuE6LfVIaJ+6M0u19iX/u1X
l7c7vLwldffJPo2lQ2urD5U7fByEmbTE4FJfoZm60+HO1s92dBQZrMqriqhd
Dhd33XPHxoMGVRToKYeNH62YnHDYcP6o5DcGvYQrwBfbH3gUSLzArun8bW5J
nkF3Vsu2WInDB0H4ur81nu6om5Fj5Px9jZ3nb12ctEH8ryjQ55oih+304YRi
PKsd1oUXvPdqreI4BQ5pu09+fqRK4RDVlSPxGhWCW6ONtzlU00Gr4vxzpb4u
hbMV173zwDyH34M0necVGkoLkgcWOGwNXvWLNG4n/9nCZ75mPNc4zFmc1Dwz
UWOY/C9aULi6bxRKKPGIZX6/U8jcc+GhD89Zxpum+fwny/2bp9kvOI/XG9Go
p/xnLeMp1MzfoMWJgKZBpUGwSgcs16Okny2W8azUCLoyf1+T5X7dr7n+44Jn
zbj9TAB7eMu4Hc+3R6Of2tVo0TQWJH5dY1pxwNQxid+kMXLscHdWg+V3q0YX
8bFf8LVL/grJ36GxgepdY7lvn2iQW8tCwXNGIz7PGRY5gzcnuumG5zFB7HWG
+xuS+M8Zjj9F6v/DMB/pgm+hx/3MtCB1tJd5INpHsyxSaT4OeNy/2YKvzQOl
Xztf+nfO47pyxT8UZf984WtGlPPfbXFLojtwX964HdcZxu24ntZHWQ/ZUn8k
iudJP+lSf3aU+x22CLpYNJISxSKqO8WyXq963I8pwsdpj/maZrGNBqbWY70k
/YvHA2UNX/DZHjL4mers9JnHStHnXp/1+obBEz/++ebYEp91s97DZrIzfJ7H
Vzw8SAOe4oNg1h/3eB4TfdZbcB7X0eVKxv2sx3thoo+XiOgbPK57us/4xwxO
U/5cn9+dBuWk/1qJHzOcv9nHKXKMCb4en/mNyf2vxS6R8zM+7iIcs2Q/XfJZ
//2a7XyZj70yfzuknxUaj1GdL1i+Xy778EWLHspfprGM7GrR53LNeq6xXHea
6K9G+E+TeX5b5iuseX6+kP5dqzlOr8SboHn+Tlnmb1BhFsXvtriX+t8v+6zL
Ml8dsl8+tVzvu+o/f+6HYn6+lHk+qHjOhmXeXlPcv19Evw2yX6/K/DZL/EmO
9d+ieF6SZf+3iX9Y9v9bClNpP6Q6nl8n8a53HL9Y9u1MByorc4VifueIHVF8
b5nEz1VYSfoplH0Lhf//3/0DDjwhTA==
                    "]]}, {
                    FaceForm[{
                    RGBColor[1., 0.8, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxdUwtIVEEU3SwspL8iESXmD8NEIiopwmMfTKzEjTKiZGZeoUn00SgrseQa
YlKb9DFYRFwNrajMNCzUxCwkQqwUy1jKJCJEQvuIZNDMztCDFoad8979nHPu
fUvEYef+qQ6HY4o8CfL4ydMT9n6ioIjQeuzygmnPGWbHNlR8u0lIV5c5HA71
ayc0dR1vqxQceW2VC+O6CdcPzaf2AY5rG0oPfukl7FDxgQKdofU5WQOEQGp/
UZVsY1++08aujp/RezKFrt9FeNc9vn2oRKA4WN5abOyrf9/GyyS92nuEoRvu
ztA6gZTVJYmskXB79PVWMWnqPSK8Urq2WXj4/U9v3gNCnDfCv7DJ4Fs2PqH0
1Np4i6pXRRjJT1iZ4bHwVNJ0VRDWs889YaWW7l9O2Ps4eaZfpqX7S7xT6U+3
oGjVuwkZ6n24hewWaayHcG44rTmkT2BM0pxbYd67BRqVL6Wk6xwwesjoTROo
PrIuoL+AUK78XmXji+rBIhsH9Mubv4Cy1XWGtA8/uPb7rI0HTwXdTSq0sU/v
eVNf5vvmdIXwS5bpWCx0vPQnJ6tsJD9J4JPCDYQn0jZvhMAbKWdXs+E7z8S3
Ek7Lv8Ex/g/7+n20sWeTnEQR1/n5hDXKiGGmeaSS5uVlOPk1avmMeMOnj+n9
WGHy3zKEKGNjCBvlmvyeMPGRBDn97JYgrv0OJ1xSxsRwvbcRZp4pZr+jzD5a
HLv3rf2QGk3IVXpdHDXK36UEBRPucN0/lnBUPq6e5Him/I00+ke55hNs4q9y
Pd8AwoDis9n0m05IVP3Hma4/y/jzkul5BRp9dQbHG/+LmZ6v0/hxgek8y+Ay
pvvmmno1DP9/338BdlTBuQ==
                    "]]}, {
                    FaceForm[{
                    RGBColor[
                    0.8117650000000001, 0.06666670000000002, 0.14902], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{647.48, 164.172}, {646.242, 166.059}, {646.984, 
                    168.336}, {648.8399999999999, 168.336}, {649.938, 
                    168.336}, {650.1519999999999, 168.066}, {
                    650.2810000000001, 166.48800000000003`}, {650.395, 
                    165.172}, {650.145, 164.375}, {649.414, 
                    163.71499999999997`}, {648.4219999999999, 162.816}, {
                    648.3589999999999, 162.83200000000002`}, {647.48, 
                    164.172}}}]}, {
                    FaceForm[{
                    RGBColor[1., 0.8, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGYC4iu+SQIRdS0O/Ye+asR8TnKQjUqxvj+1xcHb
vNMxITDZYUmBLdf1+S0Q8cPJDgwgsKDFASS8uCTFIWtPyWQJIF+4+cCphT9T
HDx5mLTbN7c4XFS6/bNOLtUBaMrTC2egfL9Uhxl5Qs0HnkD56xB8yy0nyvY9
RvDf1dibxkmlOSydfURhw70Wh6KMiW9rxNMcdDbNfb/8MtQ9t1Mh/NMtDoUg
92xIdeDTBQocaHG4ADJ/WirE/TNbHLYCjZ8PtL9d7Oa57/0tDn3TgRbZpDpc
BvkfyAfba5QK8U9vi4MPyP+9KRBzuqDuPQf1f0uLA8hbSu3JDkcVNhRlZLY4
LHLd9vkvS7LDY5CDI6H6tyZB9Ee0ODiB1K+Ghm8ygg+Wz0Dwj4DMK2lxCAN5
5HSSA3r8AABNAMog
                    "]]}, {
                    FaceForm[{
                    RGBColor[1., 0.831373, 0.16470600000000002`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIxIGYC4ul5Qs0HttQ76N9VYWssTHbIff575cdD9Q4+
5p2OCVOTHa5WvFQzvFHv8LbG3jTuXrIDn+6mue8f1zvIRqVY3xdOcXB/WCWy
7n29Q8ZEoArPFIfDXzVi+hkaHG6e+x78uDUFYg5rg8PWE2X75s9KcQBpXy7Q
4OCU8PSC0ukUhyu+SQIRXA0Ora8Dd8i9TIHY86Eewr+ZAqHv1jvc/lmXtedC
ioMd1/XFBVfrHS4qAUUOpTg8Xjr7iMKlegdvkD0LUyDuOA5Vb5LioLChKGPi
5nqHb0BnHTqaDFG/qN7BpTvn+e+JyQ7vQPY11UPETZIh6hvrHY6DDDRIdtgC
cncfgg+2ZyqCfwjk32X1DsLNB04t9E12QA9PAEFxqOI=
                    "]]}, {
                    FaceForm[{
                    RGBColor[1., 0.8, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    623.727, 154.941}, {624.012, 155.79299999999998`}, {
                    622.383, 156.40200000000002`}, {621.6840000000001, 
                    155.70299999999997`}, {621.383, 155.406}, {621.305, 
                    154.895}, {621.508, 154.566}, {621.9649999999999, 
                    153.824}, {623.438, 154.07}, {623.727, 154.941}}}]}, {
                    FaceForm[{
                    RGBColor[1., 0.831373, 0.16470600000000002`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJFIGYC4ul5Qs0H2OodMia+rbEXTHEo3zdfSt+w3uG4
t3mno02Kg9WWE2X7Iusdbv+sy9qzAMGvFlnn/vAegl8EMoA91QFo2qmF5vUO
qz5e8k0ySXVYNvuIwgYJBD9ulycPEzeCD7bvY53DzXPfgx/Lpjoc+qoR03+n
zoEBDFIh9Jw6h4tKQBcsSnGIBekPr4PYsxXm3jqHCSCN+qkOj5cCLRSqcwjl
0900d3Kqg8fDKpF1H2sd1A051sicSnWYLMESxncVwY9Ksb7vvxHBlwEJrK+F
hMfcVIdOx4SnFy7VOuwHWnO3JdXBEuTfx7UOra8Dd8hVpjpot4vdPAc0vw8U
kDGpDnZc1xcX/K11AOo2jdNLdbAF8eXrHKpA4bUsBWKfcZ3DDFC496VA9PfW
QcKlPsXhEzBYBE7UQewrSXHYCrRu/qk6iPv0oPJn6hxU2RqnOrOnQOLhQp1D
P8j/z5Mh5l9F8MHm30TwweH5oc6BG+gs21/JDujxDwBgU+hd
                    "]]}, {
                    FaceForm[{
                    RGBColor[
                    0.8117650000000001, 0.06666670000000002, 0.14902], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    495.555, 164.176}, {495.09, 165.383}, {495.746, 
                    166.516}, {496.90999999999997`, 166.516}, {497.977, 
                    166.516}, {498.22999999999996`, 165.727}, {
                    497.65200000000004`, 164.21499999999997`}, {497.25, 
                    163.176}, {495.949, 163.148}, {495.555, 164.176}}}]}, {
                    FaceForm[{
                    RGBColor[1., 0.8, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    667.9449999999999, 166.383}, {668.23, 167.238}, {
                    666.5980000000001, 167.848}, {665.9019999999999, 
                    167.148}, {665.602, 166.85200000000003`}, {665.523, 
                    166.34}, {665.7230000000001, 166.012}, {666.1840000000001,
                     165.266}, {667.656, 165.516}, {667.9449999999999, 
                    166.383}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.8117650000000001, 0.06666670000000002, 0.14902], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxdVH1MTWEcvtKaUaY7i1HkM1tr5Q8jiYc7U0hj8zHS0ilOt9x76x4k9x6d
e8+RRtJExtJizcfMWopUYkiGJWQ0a/lqrRn5nJls3p/f3WzO9u7de97fx/P8
nuecKen2NZnDTSbTMLEsYvmJtaA3uaTinIb59fd2tu6RkFJ66/usGg0fXIvm
pKoSYnqmB2hlGqJpL5ZwzHIgp9+l4e6KucWLyyXsX5zW12n25T+Q0CC2qvJC
zAzQjlr2ZOBtzck74fMKsW50VF3l+kxU2Mzemx0qTi+98vV3wjYsHPn8jKPS
DRM956ygsmnxbkTMHnExNN0GEX2/+pELHwnPmlxEFoV0d4S5GU+EE/GUP1nF
xoy43mS3wrhXqQivzZPLmhWE0sVeFZubEgP9BhUQnNqdKvd7oYBgDTpV7Gqt
mhD92JefpnL9agVymXizQsWXJ0npY2wKnuUPzJzd5eb4JCfjbXMjlvhPzON6
YSrjbncwT6jY3v/r/Gc4+H6Lipc/VWtLlx1BdK5SceGzaPDOxvH5ezFK0Io/
kY1imm9RIYz3qxsnRWXB2qIcGS9reDxVVFBl3CGiBRraCYhDxm4Bb0SlT6+1
MuNu0JBK/C0yBs8K5b758s0y4kj/EA9I9pRxMs8lx8M4UmQEbxDMmj24Ltr6
n5K5/5AHhyn+vQyS48ccL+ufnIXb4nVpn5f5FFoZxy6d59GWg02k0y0dT6h/
gR3LA/0ii77reCVg2C442D9BBjrpPiCPdf2ts/5mJwSqrvyvOvuv3sn9u3X2
UaYCglXa5Kv3xqfvZZ19N6TgqRjHhlod1yaJiZp3cHzdv/NVqn/t3/nv/AZ0
hBGQSoX972+wngkKssgfSwwkvC4Ye6nECUprzDbYNzV5SCR+Bb77hlzGsc/A
cdo/OdhHLoPnYbUzX8lALhl7aDvrFWPghgjrCcxmv93UsUTYYqrFp0esznod
3Mp1z3s5viWD5xvsxSFq/FDiea30MB+vxHimeeCgfooEgrmsUcMM+n7tEv7/
P/wBILPrVg==
                    "]]}, {
                    FaceForm[{
                    RGBColor[1., 0.8, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxdk3tIVEEUxjcLW6REtBehm4nlRklJyEZm+5WhiG5mQYaUiNxZLxJmDyLN
FpyTSPlHRERBlMgmgURYRPbYNtGtrEDMDULKYrUHIj62sLAImtkZErow93Lu
3HPO9/3O3JUVh3azuRaLZY5YG8WKEutu73F/SwLBIi+fge5p+/5zSwk/xKP7
hYHa0dUZ1kTCyUW38kITBjYMpUY3JBHG652ZZbEMTUsG+37aCOK+ZySdYbhO
fJhC2NF88OvvfIakUiPrYyrh/YynylfIkB3z1luTRjhqnh+vL2Lo/P7nzYkM
woSsV8ow0nYlkJxFeNKyfP2QwbAw/c7VyVyt5zBDSNbfpfWcZYjoLyEUOM5s
K7/NINsVmQS/zLe6YWscK77v1vm1blT5jl1YVkxoDw+4Kk5X4p7sn6fr/arE
1I1nBY6thNcp72Y81SZ6JI8thEJZv1HHmwibZeNHpuKTqf0/MJVfu65XZ8Jb
IxwLPpeq46kr11T61xCkLNtiU/l1EFZFN1zMCVYqHi69/1Tr3UnYGytAlLgV
PxFLfM4kN4SraXshIYG6XraGmYqFn+3ln/tTgpqnU8+jlam8HELZw/wFUV6G
Sel3PindPXpeM1zlv2LKd5ireQQYLksfnzgGJJ92BlFlbVMfx3M5gHqGfvk+
wJGWYb2Z6NHz8XOlT8wn6KqI29fJ/+m9Lvl0cKVrcDaO8Dw1G0fO5zqGQHLH
EfPDbPxNjDEuxJXuMUP1H+aQad5eAwckjy8c8bJfm6F4jHJIjNnXDKyQoKe4
4ttsqPMWQ3gssM8T+///H38BLhp1tg==
                    "]]}, {
                    FaceForm[{
                    RGBColor[0.831373, 0., 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    606.387, 168.33200000000002`}, {605.305, 169.984}, {
                    605.762, 171.195}, {607.4689999999999, 171.195}, {608.406,
                     171.195}, {608.9409999999999, 170.816}, {
                    609.2890000000001, 169.90200000000002`}, {
                    610.3359999999999, 167.14499999999998`}, {607.992, 
                    165.879}, {606.387, 168.33200000000002`}}}]}, {
                    FaceForm[{
                    RGBColor[1., 0.8, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxdVQ1IllcUth9E1pBmK9yW2d9KaKLRRitzPmXRmko/o6byuZp1rxphTjN1
uXrvdSExnPthVph89DdxcylOo8CZq2i1KMK2RdMIaRElzdmoLcbY7nnPoRcm
vMjh3nvO8zznOeeblr91jRoTERExyn3F7hvtvoz5exZv+NXD7LlRrZPXKSTf
mBlpRjwMPN65uXuLwububZ/FjjL4ni4eUKjsCT+fFG2QSe9+UnjQl5U/fobB
u6lPXTucrFFB5ykGp9y/GzM1qu7OmhuVY3Blev/jnZM03nh69JxaFxd+cr86
bWIQ+/kH1JN4x7PHlg8eUyiie7lS72uFrvPbe8LlBks23L4y/bDU3y35mhRe
czBK9ht8OeIO9ilMzt2UcvNQEEfQX5vUc/G+4pia3i6p95HCM9kLOs+flPuV
CqH60w8TThn8Vp32ytu5gue0wYSa3h8O5ihQ+pXDBtcv//nmrSKp/5zFoWXH
//jHvY/fPbT6xDSLddGJHU0VEr9s8SjBZc5T+L35XMb8JRYfuzKhDOGz2qKU
CKVL/pBF3V4H9HWFM+5afbXFYuL/luBrscz/O4VO0qfNMq9ojbNT20sL2y1u
HW08OzVWcz+7LUqoXwkai26urNt7wYLShOZp7u89yz7I0qBn7UMWvk+KNAbf
c0JdkveVkq9X8OyS81ap/6lmXActzlGCI5r5NljEkH5d8r7WIo6InpF6u4L4
qpMje2sQTyH91otejUHs+60kiP26a4VPvuBZo1m/css+ytXYQ8Bd/aUfbrnz
9zuCv07452n2T4PwSxN/N1n23xy57/gtIOEnaNROck4Iy/k4jZc6moabGwXv
sMIXxK9c6rUoHCEhN1m8GGk+Tw8r7keOZZ86f5LMJassiNYU529KU7/coowI
tinG/6rFt07GsZdlXmcI3z7xe7xlv59QrEuc6NUq8xQr+n4j/o6R+KLcj7JI
8veCzOeIeXLu4/nFsJ+Pip/7DOvRHMS+n68GsT8PdxTclPxYeVHm567gaTHM
d1Cxvh/I+2uih2fYj9dlX1UZno+/ZH7K5P1E8UOpYf3jNc9TheH9tkgz/h2G
dcrWPD8u9udho5y7+2sJb5nGCuJfJvxqNOMpFj1qxL/rDc/bNo0U6udCg69o
n2RqNKS7xicZ3Kd9kh/ElCb15yBeSPlTCthvLxj2X0EB79FI4ZdYwPq5/e3r
d0n81u/x/glpkCy9DyROlniM6DVe8P/rYRzVvyf7yeXrJ306FfPt8XgfFirG
d0B+L0rFvyGP+Q6I/7I85vNI8f5f4TGfIYVEwpcp5x2K+a3y2D9V0r88j/3r
9u0w+eV9j/d/quJ+hoVvnPT/gsdzOlvh/79n/wGN1yE9
                    "]]}, {
                    FaceForm[{
                    RGBColor[
                    0.8117650000000001, 0.06666670000000002, 0.14902], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{544.4259999999999, 180.895}, {544.2230000000001, 
                    181.42200000000003`}, {544.4730000000001, 
                    182.02700000000002`}, {545.0659999999999, 182.461}, {
                    545.891, 183.062}, {546.1519999999999, 183.059}, {
                    546.7850000000001, 182.42600000000002`}, {547.195, 
                    182.016}, {547.387, 181.312}, {547.215, 180.859}, {
                    546.8009999999999, 179.781}, {544.8439999999999, 
                    179.805}, {544.4259999999999, 180.895}}}]}, {
                    FaceForm[{
                    RGBColor[1., 0.8, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxdVAtIFUEUfRmIRJhURIhFRWaQphJlZeJJrQhTy0BF/GU2s0/r+emnJHbF
wkTMTEyhREJMCpOorBBTs8yICglN+oiI/SRK+lhIBc28mRhwYdg9O3f2nnPu
vbs0PTt230ybzTZDrDCxXMTqXXItz3pKyA2ZNdSYw1AwviLQ7S0honz/h9+X
GfyHl7sWj5G6NzHUOuaWdL8ndDV4+g9HcBU/TrCqPheGtnH4Xa+faP5ImFfS
/fjiXQ6bvEYNLl3w8tmvQYOPdooP9RNOftp1Z3GFwVe+Po9KD5i2P8mwKDEj
eETw/VIYujblFVPf6yXUSV7tDEmVPZMrbxDi3QWTbIYHUt8JraeKQewmVRYR
vF2La8InGLbPdllVWkg4KAXM4cjsOFS98DihLzKobLMvx7lwcfAUKR0ZHDJ9
TD3BSz4McVw6LzLUEcaaxMMPDl+p///5Cxy3vv8dyHeQ4p3KIV+nZRF8At1a
vFJ0vEPjs9q/XM33Hlf8s7T+QY4d8nwyIbldMO/jyJf+xBE23nx0pLOLYyAq
3SMhlvBTyOy5yrFpJKaidichRcaXc9RIPdEEeWzY0vWJ1PnjOCaaH0YGRRDO
SKNiuOK9XvMP57gv/fMmHJvfum3UYXCe9K/a4DZBp6FV6w/T/IItpZfrfC8s
pfew9svDrnwsJsjwhq0GO+sbbbBTf7xd5SnQepPtKl+Owd9EG3nsNVi4964/
lbBBJog32OlPqMFOfqvtqh+idP2fWMrvdbr/MyyVz5UgunD3mOjf/mWvp4pc
dL32cMXXkxAn+9GHq/700/tTDAFyrrYQ3kwVZXb8YUpPgp7HAB1vab8TDZbT
GuJu8Gk5mC1M8TxAqs/KmJof0nzTmOrfOs3Xj+G25N+m67uGYfr/4B9wp97J

                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxdVX9ollUU/pwwhooMlTAx54bNzRrmLD5Jp4+JmDmzFFF0Wzbme+99v9S2
ZGm6Uu6VjxGyrEzZsGHLH6T5K1uy1lwr8lfKmqL9kmk6rKlME5X+CLvnPQcH
ffDyfYdz33Oe57nPOV9m6Yq5S/vGYrE+/lnqnxT/fPp6Qb8Lay0G29aT208H
eGxR2cROHz+eun7ztLjCd3dzimqqLI7NildPhUJRTdvdnA0WW5cPsq3PKlRP
XdLVftji13/eDpuHKjRQvZMW/S74X/kKBfSjU+o1KOyo+37kgW6LT6Y33vn3
ksKTh7b17Lpu8Ru9f0thVUv9sLHdEr+kMXNAyhPJPy36U70mzecfSL39mvHl
OjznYWTVaaz+K3tc2hiH0ePS9g6v1bhCDUc7DCJ+8zXjz3CMv1b4pTvmPV7i
G8LnSACiveSs8C0NmI+PiWbDhAA7ic8NiXWAvztml6anOGy4/vKREZsCDKe6
wxxIpqz7AXp2/TArnuOgN91cO6VYIUaffMf67lbYQn3GO9zzMNpOKHw07d3X
rvn4s9u+MDTC5pUfDH1a3v9G4meEzxnN3wUSd2uuP93xfaQY1me2Y/3TDAzV
KRG9Ug02U78Kh5+y/A3485F+lQ5vDdk347LPj704KnX9O5LPN3yfSYeNBHyh
QSHpVS39lhvWLyn8thrmZ4Vfl0HkP58/6q/9YixkvB9LPi9E8pFfztz/2qGD
+oUhDh+vbKk/5pBN97+nN474DEk8jKP+lQnG3+qwYGDeoW37E3iK8H/p2D/1
CUymg587rCF+7ydY170ST07AVz236gvhly71Gh3eoIMPQo6/cqxLV8h+8PUj
HOdDno+Dou++EGe9PRbWOdapSvgm5T7LQ5Bd5iwT/q+G7P/FgmeM9HtR+n1r
uP4EB6/SvCuPGvbxRMfznGm4bq7oW2YY3wDHdX407Oc7lvMHJO/nLfJrhmF/
XZX8JQ2frdC/W7znx6jI5yd1ztm45ZzMR4lh/Kcs41lm8AcZp80yn5kGt8j/
TZbx58r7zRbtdL/3NPvhhOyb3Rp5NO/tlnVap9mv52V/FPbGEd54b1xOxNoV
+71F+lcpnsed8v6HivvWWvbpdsW4aiyKm7zy13rj6HyOfhhH816mma+zKKHz
r2iQzXrWyT7N1LhM/NdY9m+TwghaDCss++mqYp+EluepQuNN2n9K9OzQ7L8S
4f+z5vmZJ/p4PaL9UCjx8xoZVL9Q+BZoFNO+myv7dJTGC+SnYunv922E3+OJ
9stIxfNQbrlPY8B+XSn3kx0wLv//QGWL4gH+///xHxEf4Jk=
                    "]]}, {
                    FaceForm[{
                    RGBColor[
                    0.8117650000000001, 0.06666670000000002, 0.14902], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    640.777, 199.99200000000002`}, {639.508, 
                    200.92200000000003`}, {640.09, 202.41}, {
                    641.7230000000001, 202.41}, {643.211, 202.41}, {644.387, 
                    201.184}, {643.9609999999999, 200.07399999999998`}, {
                    643.586, 199.098}, {642.059, 199.059}, {640.777, 
                    199.99200000000002`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    652.1990000000001, 203.47299999999998`}, {
                    651.7930000000001, 204.754}, {652.746, 
                    206.05100000000002`}, {654.094, 206.05100000000002`}, {
                    655.094, 206.05100000000002`}, {655.375, 204.848}, {
                    654.754, 203.23}, {654.3009999999999, 202.055}, {652.602, 
                    202.21499999999997`}, {652.1990000000001, 
                    203.47299999999998`}}}]}, {
                    FaceForm[{
                    RGBColor[1., 0.8, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    516.082, 182.812}, {516.1800000000001, 183.316}, {515.918,
                     183.684}, {515.4609999999999, 183.684}, {514.496, 
                    183.684}, {513.914, 182.83200000000002`}, {514.371, 
                    182.094}, {514.8399999999999, 181.33200000000002`}, {
                    515.879, 181.76999999999998`}, {516.082, 182.812}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    556.75, 187.359}, {556.75, 188.105}, {556.4689999999999, 
                    188.38700000000003`}, {555.848, 188.266}, {554.488, 
                    188.004}, {554.3399999999999, 186.281}, {555.672, 
                    186.281}, {556.418, 186.281}, {556.75, 186.617}, {556.75, 
                    187.359}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxdVGlIVUEYfWWJWZaVhJipbRaPwgyyjVef2mZloUGCaYkUzlzS1CJtm7ll
YhphWVEQJmkJhYlIi4k+xYXCH2pFqYmFWEhEheWCWNHM/QYHfHAZzn13vu98
55yZhYnHoo+42Gy2SeKJEc9k8WQ4i3yCtnLYcvlo/9hoErzL/BoYHMfh+9nN
aw6GEGgcWh6XX8nhdsqcrHo7gfupDvcODxPSxFLiS6DvwZ2mAC8THg28iUxc
TsCoOXHde6MJXa0j+/p6CWwSn6VGmFArXk8JpNAg68WYMCyWhngK7Yu6R1ms
xs0BFekkXuPc0IQv7YdMuHJLEEjVOF8WytF4/ZNXJ52NFPyzv0VVRZpQvPXZ
77/1FE6Jcdy2mLDU9fzN8CyKfENMmC5oOewUek97lW+fZYKk6bhAwCZ/U014
KsoVpRPk+4/jPJTAp72CyWcOvrGHN35KIuCxsrLwZxvH+VIInBHleis49ssg
QK4JJR9zrHuWwAK57wWHZcFuZb55BOu0KX2LlX42E/V3peP4YHXEjMnzNbb4
rKHoV6fyaw8FOb5fHUceYRRX4Z/Fw0FhblZ9y72bHNLli8VKD8bx/TQKG6SO
URykzSWdyt9V6vsOjaUd9a50HNeJGPV4UbDnzOtqDVf9dyp8QGFGcf7jat5K
tb+Ao1+Din+RyuNsA36JWHmWcZw/yMDvq1X/bQZU+YkdTo1fyzw1aDxT+tOs
6kVpbM15SOOgniWu59MMSO4fezhQw+HDKDNqMg2Q7SpKNbb0ztPYqpPNMT/p
BkjZUo8rvVcamBfCMZ8uBryQfKPV/C0UcRjHvJVTKJX97Bx1yKY4f4DC5xR2
53jeLlKQ8e39yND/AorzNDLMo3MCHta4W/L3NDDfTob97UrvKgYx8kOht3U+
Sxn2dxiYk1wGL3etzQ311tjiM0jHsZX/5xTk2EU3GOb9LkU9mhjmN1nx/8HQ
33Dl/xDDviEUZJuEEYZ1RN52yAM7qv5/T9CfPwzvo3YCMl57Z6u8viXo12qO
uRF5tupv5rBb1i0kmJMVHOvtJ7j6cbgqhfEn6IePOh+1SXBJ3jeBGlv3j11j
a/86lY/OJJh4v/4H4LaNtA==
                    "]]}, {
                    FaceForm[{
                    RGBColor[1., 0., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    502.648, 195.906}, {502.648, 196.754}, {503.125, 
                    196.871}, {504.469, 196.35500000000002`}, {505.16, 
                    196.09}, {505.195, 195.934}, {504.64500000000004`, 
                    195.58200000000002`}, {503.566, 194.89800000000002`}, {
                    502.648, 195.047}, {502.648, 195.906}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.8117650000000001, 0.06666670000000002, 0.14902], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    504.72999999999996`, 198.164}, {504.72999999999996`, 
                    198.617}, {507.008, 199.809}, {507.875, 199.809}, {
                    508.887, 199.809}, {508.328, 198.359}, {507.199, 
                    198.055}, {505.562, 197.617}, {504.72999999999996`, 
                    197.65200000000002`}, {504.72999999999996`, 198.164}}}]}, {
                    FaceForm[{
                    RGBColor[1., 0.8, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    539.324, 194.605}, {539.324, 195.73399999999998`}, {
                    537.2930000000001, 195.578}, {537.0740000000001, 
                    194.434}, {536.93, 193.695}, {537.164, 193.52}, {538.105, 
                    193.65200000000002`}, {538.777, 193.75}, {539.324, 
                    194.176}, {539.324, 194.605}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    628.9609999999999, 202.547}, {629.168, 203.621}, {627.668,
                     204.348}, {626.875, 203.555}, {626.082, 202.762}, {
                    626.805, 201.258}, {627.883, 201.465}, {628.379, 
                    201.562}, {628.8669999999998, 202.047}, {
                    628.9609999999999, 202.547}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxdUltIVFEUHZVEwspS/BhM7KVSyDQfERXmEpGKiqigDymLwYk4Z66lQfTw
7ptJhD+9oEaI0J4Q1DRUyiAymZSFhFYQojXkMEhEWVRkmESdM/vQQBcO96z9
XvusBb792/wZLpcrTR2vOunqbFzZWrknSHjY7vbEwgLLTuWPDN4hNO47N9E0
LPDt1WZfTohQ4s26XTAqECk8+XHrdUJt94bsdI9E34/SnWcuGv9NifKZw9cO
BI3/vkTixqXHRSp/oqliRW1UQnUbfzFAeDtFoue5RFFYdcp10PnsULSdJFY9
UJdFDudB4vXhD8Xe5Q7m19SteTdHokD/PQ5OB+vntWRLznM7UFNFCscF52c4
aFPu3m7BeQonebYKtrtTeH38aF6oLIWTfH2m/qcUfqoDcuQ/7IktzmyulJhV
du/ylxIHmnZ5l4RLf7+I54lL5Lb0DlyJEXbMVoHTku2PiOOyAujXdTuI+Sqc
nMNP3E/htbrwLsKxvNC6+GfJfoswMvhze8Jv+h0nbNL2JwK6THgvYbXew13B
/mLCqN53qYmftPFy4ZspOmHmSdhsH5PQ69qi8JLM5gtVBwPMU2Eth4q5Fu8r
jXBWP/xug6uJeTZYsN5P3/raSJhUsuizLdZTg5n/vMX1q4zeOiyu/8fmOTot
3kO/ze9aY7FuwjaiOj4SYD202cx3RoD1M2Til5p9e40e1ftfre76/ruOmI8j
WJ9HzL5sgf/1/xc+N1Nd
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIlIGYC4vfLj3mbt7Q4fNOI6T9Umu3QLnbz3Pe2Fofb
P+uy9jRkO4DlO1sc9O+qsDXORPDvgOTXIPiPl84+onAg20E2KsX6fm+LQ8bE
tzX2L7Mdtpwo2zd/covDcaAqR44ch8u+SQIRM1scVNkapzqr5zgwgMC8Focq
kXXuD90Q/K0gfX4IvrohxxqZvByHT5eABkxscVjkuu3z35wch+l5Qs0HgO4t
tOW6vtgnx+EhyKCaFocwPt1Nc7VzHI4obCjKKGlxqAaZr4XG90Lw43Z58jAF
5zgcBfErWxyKQB5IznEAimq317c4TDj0VSMmP8ehwzHh6YW+FofW14E75Hpz
HLL2lEyWmNDicEkJGGKrchyAofhVo7nFwaU75/nvgzkOOpvmvl9eBA2fB1D1
SdDwWQm1P6HFYQbIH35Q98e3OABlTeOEoPYD5cHhwAE1Pwfq3zfZEPeUQd17
ORtiTgU0vI5B47MMyl+U7TDNGeiwYqh7UrIdfIDRklAFtc8PGp9I6QEAyt/y
gg==
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxdU2tIVEEYXa3UXhIWEVpmoiWYmFFJmewxkQiLrSSLEgnRsO7cW27Qg0QQ
Z5AIswepJCG9kCIkpIdEmJiERqTmUkiamIqYbivKmv4ImrkzONCF4XJm5jvf
d873zYa8s4cLFjgcjgC+wFcgX+uO56cMBDC8bL/QXNdg4PLYxqSQpQy7XvCN
TgP7lgXGl4cxsPFDTZF+jWficipbA8g89hY7t+eGEnRFf58rCWc4GprQeC+R
wFf/ITM5huF84U1vcSbB1bSTI11OhiurGvYO3iWw82cw5L7hTOME7/2ceCfD
km8Pz6WeMrFeJN7GJG+Vid0DrorqWIbMZM7Ua0q+hSqfy0KriB+nqLHCylqe
WvKeh2K/+Pst9BzIW3GsW2P7vF3j8tW9n/90UCT2xwSVFlmY+sIDeij4btZQ
gYVX0389l4Yo3tWFJ/YftGScl2JTUsiztTssDD2ubYsKVn7x+mzM6+2bKznz
lphYzsv0bWXIFvUGm2iLeu4ujGeIDSq9k95JwF31x3G/mgV/jfI3XPn9hEg+
B8MeLjs6wsSk8HeKolrozTalT8MUgian3JR9HdQ4Rfj3g8p8HKcKo/soVpa1
fLxfpLFb9CtLYzt/gonXQj/ns31bbMp6fRTXRQGfiDxfxCDCnacJNnO59dyP
LcLPBCL1z1Cpb9ZAVfo1Mjqp/B0xECmM+0Vl/78auCgujmls841qbOv+SeUc
TRs4wX8urs8hvjUEwmafR+F8NX+1VPbniCn5b2ssaFyVGtv9rVD60zS+IfyM
0PhBBp+MCaWXx9v97lPzXaPiO4j05ZGqv1G9jxYq99PIvN82X5Mh8bC6f8uQ
8zJB0S367DbkPPzW2Nbn09h+P7NU+l9h4P/3/g+ufdx1
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4mnO3TnPLVsdeqfnCTUb5DlU7JsvpW/W6nDc
27zTMSHPwYuHSbv9ZYuDbFSK9f3Z+Q66m+a+X/4QwQfL30XwQZT/nRaIeR35
DhkT39bYA+XVDTnWyITlO1zxTRKIuNfiADZeMt+h8qWaIceDFodqkXXuD/ny
HbZ9/nul4hXUPOZ8h0+XgBo+tjjsBzrr7p88iHmsrQ4Gd1XYGvfmOVwGmSfe
6uCY8PSCUnmegx3X9cUFmq0OhbZABtA/D6uABgP9p8bWONX5d67Doa8aMf1W
rQ6rPgINZsiD2GPd6iDUfODUQtY8iLw1VL10ngN6+AAAnyeB0w==
                    
                    "]]}, {
                    FaceForm[{
                    RGBColor[0.8117650000000001, 0.06666670000000002, 0.14902]
                    , 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGI1IGYC4k+XfJMEjNsdLird/lnHlOnQ6Zjw9IJzu4Nw
84FTCzkzHZbNPqKwIaTd4ZtGTP+hixkO7WI3z333a3fgvr64wLYrw+HwV6CE
b7uDjzlQZ22GwzTn7pzn7u0Oqz4CDU7JcLgAMteu3aFaZJ37Q68MBz7dTXPf
m7Q77J8vpX/XIMPBk4dJu1293aH1deAOOdEMh8qXaoYc4u0Ox72BBv5Jh/C/
tUHsO5XuYHPfv3f6iTYHyy0nyvYtTnfQARq3fHKbA0h5wsp0B6Arv2rMRvDt
uIAaU9scQMrnL4Pq92hzuARy1y6o+cptDo+XAj36Jt3hYRXQocxtDkIg/wPd
IxuVYn3/eatDxsS3NfamUP8/bXXQv6vC1rgUwd8H8s+ODAdgaBVlANWDzTuS
4bCkwJbr+stWSPiczYCY/6YV4p5rGQ7g8P/QCgnfu1D1X1odXIDB+PthBkTf
v1aI/19lOBwFmc/Z5nAM5MErUPuF2hzCQAF7HGq/epvDnZ91WXvWZEDCJ6jN
IRQkn5wBDx+wfYlQ8w+2OQBNCX4cC43Pu20OoGCzbcpwkANFzK82SPyszHDY
CnK3bDvEvuvQ+FVqd1jkuu3z3x9Q/yClJwDhcCPP
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxdVg9MVlUU/zQKpSA0Y6wQBUwoKHJNnRZxnMs/aX/dypp/mGUjHsL37nsp
uaSR416ck09yiVszVhqIMiMjZWbYAoFyKRnZyAiRlJBEhIwpMbv3/Q7i+ra3
t/Pdc8/9nd/5nXNfzKrsF1ff5vP5Runnff2M1k9vWf2imf8oejLkl13+VpeK
s8Zv/Ebbr77+eNtz2l4W+PZqwoCibZFBL4VpW/+7pVjbm+aknW/6zaWfnlkV
vvSaollVjWtrzri0rqbkvuRBhXeLS293TZ02ZkhRw6KZm+acGrHDHj6w8/KP
LplX2RDvP+lS+/oJ++ffUFRv/OsYj7aro/O7X6hy6bLB6yugS++kTl+x2yWf
9ysg7fX9xwEXuLV/epH2WOfS9rmbMzt1/KbYM9dy57m0WIdNu67oIRXRciKY
8V5VtKZzsPxKnUPhSzWSi4w/1QHOFsazR1DHpx/WTW5U1HdKJ/6sIGNWHlT0
pYZfct3GOVs5n89s8GMx/kyblhs+5zF/CTbixyjk0eOniSaBCXz+535KMXUZ
z/tL/eBnnCJtVUcX+8FnuIJfnh/4wxTNN46Wn3b79Uoo432e/UM5/2Q/mbTS
7mT8v2eDnxDmb1Y2cGlbmD9UFh2bXCnSxyr65KmD/UOZa8BHCPM7I/NmPK/e
ZCHuWI6XYiHvYEXx08ZURM22UJ/bFRm6SmZY4ONfifWpFvD0STqq6WgNt+B3
QdJWTeOywQzo86SkLUYoTRnQywGJd2kG9PCBpB6jl73sf4s9zvD1ikQeFeyf
Kukeo6crGdBbIsfX53s83mJ76/ES+UdY4CtO0orDC+8afb8FfURLajkxsKRj
ooU6TZI02yRyw4L+pzDeMJtqdVoBbXt5bh+xTdnbte3xFcd4j/D6dEnJrVPu
yOu2SVelOWexhI7uFVRn6vWapJ9zdOFJkEaVqHIlJZr6rxbgt1BSjHYr2sDr
hbxf2wWmXoV8Xq5AvjsYTyHH3yfB2yFBT5v9XzOeNkGmTIF6ScatqF/AT9fL
69dgB/1wWoK3SAfvVklmzGQlODTJCL1dQq+POeD/D4n+SOF1bUeZwLpfvfz/
5PotdOgJE+gSn7/EIdNG1VpPjxp8yx2eXxL9nc77fQr4bQd10HotNXVc7wD/
3azv9xzKOOJui4zg+ZnvgLco1nMBx4vleaAc9F+8Ap/D+xN5vm5woIcktt/i
/Unc/2846KMkxveyg/o/qJDfXM7nAQXdPeJAL1E834Ic1FfPB4/f0wLnB/H8
OSxoh9HhEOtPzztvfgxwvTbz/Otjfbwp0O9/sb4WcLxO7q9YrneHRF+PYn21
SfRBuw0+Wvm8Rtaztj0c1TZ417Y3N6rsm/rwzqu04XdWoh57bcQ5x3os4345
PzwPbPDSyXreY9Mhw28X67Xchp4vSuS1z8a86JaYdxU2nTPC72H/L3i+93J+
X9mYJ/2sz+Mjtud/nOd9P+tZ2x4OrT/vPrtgY76Gcj2CBM6P5/syRuBNikLN
O1Ug35V8X68UwJOjgD9fAG8u6ykggOdd9t8pwHeeAp/7uV4b+X45KlCffF5v
FtBnwfB9JcBvQKHfYhzaZfTykUJd0lmvxzherYP50aCgpwbur3pFC8x99YND
3vdIDfdLnAt83ynMkbUu+l/fx978LHehi7OcT60LvXYp1LuZv096uX9/dXE/
9nE/6O8Xb378zefr75v/fw/9B6bsL9Y=
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxdU21IVFEQ3SwUKhaxEOnDTCSiDyTIzKw8UiGxlNQPsbAQMTQh3b3vaktt
QSy9SSJD9oeVlJSGFCKLX6mYLCnrIiRWRkiESERU6GIpFhZ0b3N/9eDymHfP
zJxzZt7mkqqT55Y7HI5l6mSoE6NOQ2WCP9RDmPXlZJwdldjZcT/a2kcYcWXW
5qo42hp2ZQ4Qvr8+VhIfkeiK1Aw2DRJ6k69/OzEs8UZ9LhwiBJJWFDifS8aN
EGZ0vXaJ+MKsrkiYcOHz0pO5exLewaZ16f3EdUolHjcOpwQ7CHnTl9a2r5d4
9uPPhFf1V1He9JgFTaM4QPiogdKCUxP0E7p1/jYLKluU+0z9eYH9U/m3GryE
Nf7Q6MNJgRu5xZ/GawgaVj8kUHT7xcLWakKCvu8UOLo6ZjtZxHWbTb6HkP4h
LfZao8Dp0uypfDcxj7sCDv2cIhxc+a7ZXW3ibIJOqywQqNX9Uoi/7xU4oHGr
CMqt3uRNAlpm3k+b68cJ3NH+z9js21cPJrSfszY26MZRDyhxcmxRxRt1vOBh
v6I23nq/bNn128P95myENUGn0TNvo0/PJ1WwP4sGv0dgh57vks36XYJ1xxHO
9KvMMoGKARlISiSU16sJXhH8TjN+BEy93YTLej4tAhf1PHOM3qeCeR4y82oz
94eNX93GryPEuJeC9R03+FiL9RQR+7LPYr0VxD5WWYz3mf18ZPbjpuHTZfah
jrhOr4Xzmn+d2d+Q2R+F/zfXMonx1Pe/rj4w/YKS79sIWXpBhyT7GSTGqf1v
cSsmnYRXOlb/x///z1+Qv4VC
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxdUmtIlEEU3VbIUFlSJMooH6gsVqyCtWVEJwzFR8UGgYSpSIFEm8vMlGVP
seUiq8gaqCChuOWyFSGhsESIiIq/QouIiCiLkIhQg9Doj3eY+eUHF74zc++5
55472Y3NZy8lOByOLRxuDidHZvCXL95GaAr/vn38mUJvaejKUjuh7lVFipNx
ZYpzHwUJWaOiKRxTOJb0IRIgwq30F+WLj5Wp6yDM53z6d3dIoWViMMMTsrjf
5ncS+q6mtU92KnScaPgx/4BwZGzu+kS9wrQmvk/wfM7d2papMKMx6/n+ZGA6
a1YitYYzmwnc5WDdc4nLr9XDnfWEBc3fKlGo63yEVq2nTOLdqcbtNScJ/qX/
sdV0afhLCOPcbvCbgOvAy0fLXss3KRAJsMICwvsbP/OL4vZ+N0G3Hx0RWInO
VnldZOYKCxz9cqarL8nqDQnc5LJtiYRs7U9QYD+XRxMIVV6e9J5AhfYv0frV
I4wfyRYPC1TrPJfFTy3eZfGcwJ+3PJCbEN/Li1oXqO2e+usuIpy/yErypPG/
mMCntd3F0vh8iEyfUuvXYUKJ9tsnQTs+vlkrI7OHgDR85+x8MQk9fpT97Nc8
X6XRf5rg0J9bmb4XyPjkt9hP2KN/wgqLehHXCAW6UcTe37H75ve0+b1tADk1
HF8=
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJZIGYC4qMKG4oyXNsdGEBgVonDp0u+SQLu7Q7a7WI3
z80sceDT3TT3vUe7w9sae9O4GSUOD6tE1rl7tztUA6mHU0ocrgCVR/hB5SeU
OFS+VDPkCGp34AXpay9xkI1Ksb4f2u5Qvm++lH51icPjpbOPKHi1O+Q+/73y
YwBUvxPUPAmofS7tDjvkWl8H3iuG8z1AFt8thrsPZMyGPcUOtlzXFxc4tDsA
Ve+Qmw5Vb94OEa8udogGWu9v1u4wWYIljK+9GOI+43aHjIlAF08sdgApX67b
7iADcidMv3q7Qw7IffOKHQzuqrA1KrY7LHLd9vnvgmKHrD0lkyWkoe5bADVP
rt3hagWQ8aPYIab/0FcNoH59kD7PEocOx4SnF4zaIe4uK3GY5tyd89yi3cHb
vNMxobfE4Qgo/O2h/geG7/Q8oeYDzoj4AIe3C9R8IH9JAdBnQD44HIF89PgD
AJqJyQQ=
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    733.2810000000001, 283.699}, {733.3629999999999, 
                    283.58599999999996`}, {733.2890000000001, 283.574}, {
                    733.2810000000001, 283.641}, {733.2810000000001, 
                    283.656}, {733.2810000000001, 283.68}, {733.2810000000001,
                     283.699}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{707.8159999999999, 215.309}, {708.172, 
                    215.23399999999998`}, {708.512, 215.141}, {
                    708.8159999999999, 215.023}, {710.133, 214.52}, {
                    712.0780000000001, 213.465}, {715.109, 212.684}, {707.777,
                     212.758}, {707.777, 212.758}, {707.8119999999999, 
                    215.11299999999997`}, {707.8159999999999, 215.309}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGI1IGZigALudoe4XZ48TNzZDrZc1xcXiLc7qBtyrJER
ynbg0900971yuwM3UNj2VpbD0tlHFDbItzvMyBNqPjApy0EHKL1crt3h5rnv
wY9bsxy2ff57pUKq3WH/fCn9uzlZDvp3Vdgahdsd+g991YgJznLwNu90TOBp
h9CWWRD7mNodvmnE9B+SzXL4sPyYt/m3NofbP+uy9rBkQey52+ZQLbLO/eGl
TIdPl3yTBPa0ORwHGbAm0wFoytMLU9og9m/MdPABmTsLwQf6Sru9qM0BpExp
faZDDMghsW0Q/x7OdIhKsb7v79jmUAByyJdMiH2abRD/y2U52IHcJ9oGcZ9t
lkPlSzVDDpE2h70lkyVY1iH4YP8czHJ4DAogoPpCkHlnshymOnfnPBeDuudq
loN86+vAHRJQ99zPgrhPus0BZI3tsyyI/+TbHC4pAUPgFdQ8tTaIuz5lOUSD
3KvX5nAHFD53shyOKmwoyjBtg6i7kOVwGBjM/S5tDhkT39bYb81y2HqibN/8
FKg8MD5g4QOOz6wsBzmQe7a1OQBVm8alZTkATe+dfhpqX1eWw3tQfDxscxBu
PnBq4cYsh6w9QI//hpr3AKr/XxsknhmzHdDTEwBJJQ8N
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGI1IGYC4qw9JZMlFNsdjnubdzryZDnobJr7frl+u4Mq
W+NUZ+Esh+gU6/v+du0OEw591Yi5nelw2TdJIMKy3YEBBKZkOjxeOvuIgkW7
Q+wuTx6m9kyH98uPeZsbtzvsBRrLkpfp8OkSUIN2u0Pv9Dyh5pBMBxB1QKnd
4ZLS7Z91VpkOYPvF2x2qRda5P5TLdJgBkudod7h57nvwY1ao/jdtEPuuZDhs
PVG2b/6RNgcfoHMT1mY4AF3XO31am4NTwtMLSpszHGL6gQ6di+Bv+/z3SkVe
G8R/GzIcjipsKMoIbYO4+0gGxD6TNodvGiCdUP2SbRD/ymdC7GFsg7jPLtNB
rvV14I7/rQ6OIPPXI/gXQf45lOnQLgZ0OUMbxP1nof5jboOovw4NH1aoex5k
QtzH0eZQlDHxbc3zTIj/eNocwvh0N819nekwzbk757kI1P9fMh0ugOyRg5p/
N9OhA2SwWpsDSLv9xUyHw0Bn91u0QdRty3SIBfknDiqfC42vuVD/ZWc6XAHF
5z6o/elQ8661OchGASO+OxMSHh/aIOG0CepevnaIeQ+h/hdqh8gzZTmgpycA
OWwazA==
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGI1IGYCYtmoFOv7MysdLird/lnHlOnwtsbeNK6i0kG4
+cCphZyZDltOlO2bH1bp8E0jpv/QxQyHT5d8kwSSKh24ry8usO3KcKgWWef+
MKXSwce80zGhNsPhasVLNcOCSodVH4EKUzIc4nZ58jA1V0LUeWU4PF46+4jC
tEqH/fOl9O8aZDjkPv+98uOGSofW14E75EQzHPh0N819f7HS4bg30MA/6RC+
cBXEvlPpDh2OCU8v5FU5WIIctjjdYRnQuA03qhxAyhNWpjt4PKwSWXcSwQeb
a1oN8ccymP5qh0sg/+6Cmr+zGuKuN+kOtlxAi35WOwiB/A90zzGQQQY1DhkT
QSED9b9JjYP+XRW2xqUI/j6Qf3ZkOJSDGIY1EPOOZDjskAO6QKcGEj5nMyDm
q9dA3HMtw0EGFP7yNZDwvQtVL1bj4NKd8/z3wwyIvcw1EP+/gpr/thriritQ
+29VO4SBPHIcKr+x2uHOz7qsPWsyIOETVe0QCpJPzoCHD9i+RKj5tVUON899
D34cC41PlyoHkDNtmzIcDn8FKuSqgoTjygyH6XnAkDlSCbHvOjR+d1c6LHLd
9vnvjwwH9PQEADfzHaQ=
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxNVg1MllUU/kDS/iTSZAz8Q52iZkg/OCjguPJvaVZstbU0c1nEh/C9P8q9
9003MkauGWotWs2x/sDPmEGhETotYOpyKZraiAiRqDmUMnPOrNG99zkJ3/bt
7tz3nnOe85zn3PdNXV3y5JoRoVAoRv+363+s/k+udwu2jRWUe+sPH0W6fDox
pfPaxjGCnnnhwe7l2l7co+7afaegt5LinorX9ub5q/raEwTWn3ycGy0oq/HI
+gOdPo3d9PW3H9wiqPRAdXJ6h0/xcz7f8ftNgg4/Om/z/JNDtl1P+PTJ+22T
6+PY/7hPOQZHjKBD5nybT+0GT0hQ08Ty/icafbJ4B0vp4it5D6z82KeQ/Qka
Y/JW+mTcVmn/gm36RKlPp8X56Rk6vo2z0Mf+bYJmVSR2HBvFeMcJWvvb9eil
No/OLt9SVTyL8ed51GsALmU8O13gLBH058llqxMec2mPNqu3C6x/O7Siecnt
sd1cz2cO+Jkpgb/IoUWGT0+CvzQH8fdL1DEQQZ4zEvkbIqS9miZ2sn9NhPsk
sV8VodGGx24J3soiwH9OIk84Ar9fJPA+HgHvfRL1p0fAx3kJ/D+XwO6XWLNK
gOuCJNdsVBQD10VJHy7Ye/nforWoU5+3/GYW3Yhn+01hqirWnbnA8XLC6Nsf
kmZk3Fw3PjuM/vwlyYSpzgyDj5EKz6eH4Zei6KBO25UQpndNvHsVbW25kvbs
9ULo83lFW0yi9kLo9z2FvDWF0MNpRQMm7y4+P8zuNnwtDZC3js+XBdDFpULo
LRogvs4/wTR0mG2fNwSoPzEMvpoDWml0kBIGry0BdRy7mt87IYy+fRNQtil4
MAz97w2AN94hjW5Rj7YtH+8M2XbVtuWrifHudygw+28HlN41bWRZv4M5fSkA
znEu+pUVwI9c6Dw2oNmm/2tc8NurKNXUsYGfn1Pw17blSds230YX9R5XwPMm
x48q6PxL9n9NAU+3C3yugt9lF/zqftl5HeVBp/kKvCV5WBcq9CXNI9PmyocU
9HqfR+NNonkKeXP4eabCvp5XW3+6Qv+WeJizaZw/36NWcz5Z0VyDb4XH95fC
3BWw/6AEfseD3rRea0yflAf8PazvVz3g+l5iLss9xDnEen6d4+2TmJMKD/PX
IMGn9rd9iEqc2+BBDzVsr2P/Wp7/Fz3gqmV8T3vgt06ivoe5nj0Sce7x0HeN
x/YlzuP+SvB7xgX+q3z/NLvQcZwCfn3f2bwJ3K83+P5LYX28zPqZoZBnsYt6
Mni+pnC/sxTqjmF9kMJ91eNgfwHnO8J6fkSB9yYH+9q2fWx0bujD5qt3gDdX
oR+7HPhlsx5reV7u//8+4HhzWc87eV7msF6jDnQ1WwH3pw7ui5kK912dA9xT
+fwXfL9P4vr2OeA1ifV5dMi254/yfZ/Eeta2vQe0/uy9+Cvn7+N+xLnIr/Vi
46e6PIcS936ei3pJAsdzLtY7JPCXu8A7gvVU6QJPiM/v4Pn8R4Cn3dyvawL3
1EEXea/w81MudDUg+H3lYv+swLylevSV0UuLAC49T3bO1nG8Vg86dfh9fZjn
yxWo8zt+vonfn1N94CsSmPP1PnS3TIC3qA/ecvl7pdWHXu8W6Pcp/j6ZJDC/
P/p4Pybz+15/v9i4iZy/i78vhn0P/QeJPxcd
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxdk01IVFEUxyeLMSKmshKpSadJWgghLeyT6u8mCymphYsgkcHQRWlz3k3P
fX2ARZiVC3OhKSVlCUXIUEpT0CCMqAiJFRFDhMkQNUVZUVDUonc9d9XA5bx7
556P/++cuzbScPDIfJ/PN89bJd7K8taz8OvfZ64wvpzaVVI1oXC7ZyQUu8wY
K9/cWurtQzGqa29hfH++L7J0XKGrPufc8FlGPP/8pwMjCodqtk9XaEZH3oLK
wBOFNeYgyvhs4g0ovK1o66wnxrH3f+5861bwvCduXGIMjjcmemsUhoztZpTN
uCsGViuJ08bwdmUzkw7q2r1IKUbaFKYcsb9Y/IocNCV6VxVna4n/g3ChtPrd
VEBjucmTItGVo0VHkrDH5FmppY4HJH55GoEN96/N9hFajX9Qo/hNob+5h2Aw
VBdosVcJPvPbr7Fz0au+4yfs/qLGtNFZSaI7oeV8C8GjFM/PaLEFhB3Gb4kr
8bMJU4Z/oSt8P0aF5zoXQfMxG5XzsCtcf0aFW8jFS86s3/g3KvmCLkZNgQHC
UaMn18Uj058wCZ9l9v4mQr/p70JX9JeT8Pyqcfjx3sVZtYSiltzU5Ast3E+T
1PnQ8uiw8To1Tpr+3CLh3Gz13iWpg7XEvUeSp8nyGrK8GrXoeUqiL2Lv+x3R
s1vLnG1zbJ+1cGtw5L5fy3zetPORYaln0M5DmqWPcUfqTtv5Hbbz84GFc61C
ldGdZMkXU/J/P2OrAZ1UwvM6S5+8+Z+b+y7G3Lvx3sf/7+cf+nSByQ==
                    
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGINIGYC4kNfNWL6/1Q4ZEx8W2O/usThasVLNcMfFQ5x
uzx5mID83Oe/V378UuGgsKEoY+LKEofW14E75D5WOFSLrHN/uKTEweCuClvj
2wqHC0q3f9YtKHEQbj5wauFLKH8GVP3zCofpeULNB3pKHIC2mMZ9q3Cw3HKi
bF98iUP5vvlS+v8rHPRB5shD+X8rHB4vnX1E4Vixw33/3ul5CpUQfWuKHbTb
xW6ec6x0uAgyv6rYYZHrts9/YyodqkDucSt2iEqxvu9fXglxt0gxxLzuSoet
QOvmPyqCmDsBat6BIoedckAXrqqE+HsHVP5EpQOI2rCsCOLvx5UQcyYWOXQ6
Jjy98KoS4t7uIgc+3U1z33+sdFAEqWstclgG0vej0sHbHKiyvgjijg+VkPCa
VAQJj5dQ/qIiSLg/hvJXQflnofwTRQ4yIA+tr3TYAXLnjyIHj4dAn86thPhT
tRjijumVDuB4NCmGhMukSgdbruuLC5yLHbRA4dVf6WAFCu/AYodPl3yTBIoq
If4oKIaYFwr138piiL+B4TkDFF8PiiHuT6p0YAABjRKIv1wrIf7OhfJVKx1k
QQ6aWOJgB7JXtBJi72KoPGslJL6B6Qk9vQEAyQEzcw==
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJZIGYC4vJ986X0SysdGEBgVomDbFSK9f3CSgftdrGb
52aWODxeOvuIQl6lw9sae9O4GSUOtlzXFxdkVjpUi6xzfzilxAGk3D8ZKj+h
xIFPd9Pc99GVDrwgur3E4Zi3eadjSKUD2J7qEgfLLSfK9mVXOuQ+/73yYwBU
fzXUPAmofWWVDjvkWl8H3iuG8z0eVomsu1sMdx9IeMOeYgegqh1y9ZUQejpU
/YRKiDurix1A1idMrnSYLMESxtdeDHHfzEqHjIlAF08shpizpNJBBmQuTP+G
SocckPvmFTssct32+e+eSgi9oBgSLieh7lsANe9wpcPVipdqhj+KIe7cWOmg
f1eFrdGzxOEdKFxmVTp8uuSbJFBWAlHXVwlxV28JJFwaof4Hhu8Fpds/6yoQ
8QH2RznUfCAfbC8wPMDunAXVjxR/AKgq1GU=
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{418.719, 
                    283.699}, {418.637, 283.58599999999996`}, {
                    418.71099999999996`, 283.574}, {418.719, 283.641}, {
                    418.719, 283.656}, {418.719, 283.68}, {418.719, 
                    283.699}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{444.184, 215.309}, {443.828, 
                    215.23399999999998`}, {443.48799999999994`, 215.141}, {
                    443.184, 215.023}, {441.867, 214.52}, {
                    439.92199999999997`, 213.465}, {436.89099999999996`, 
                    212.684}, {444.22299999999996`, 212.758}, {
                    444.22299999999996`, 212.758}, {444.188, 
                    215.11299999999997`}, {444.184, 215.309}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGI1IGZigIJXlQ5xuzx5mLizHVpfB+6Qu1jpoG7IsUZG
KNvh8dLZRxR2VDpwX19cYHsry2HLibJ98w9UOszIE2o+MCnLYRlQesOhSoeb
574HP27NcpgswRLGd7rSYf98Kf27OVkOi1y3ff57o9Kh/9BXjZjgLIeMiW9r
7J9XOnibdzomWGZB7Ptd6fBNI6b/kGyWg8KGooyJwlUOt3/WZe1hyXK4oARk
uVQ5VIusc394KdNBJirF+n57lcNxkAFrMh2AppnGXauC2L8xE2L+aQQ/9/nv
lR+lqh0cE55eUFqf6eDxsEpknWs1xL+HMyHuqK12KLDlur74SybEvjXVEP/L
Qd13tRriPtssB17dTXPfX6922FsC9Ok6BB9szsEsBytQAAHVF4LMO5PlcLXi
pZrhpWqIe65mOYCCof8c1D33syDuO1HtwAUK32dZDrIg/x2sdrgEcserLAdL
kHmbqyHh/SkLYs/iaoc7oPC5k+VQvg8Y0FOrIfF0IcuhChROZdWQcNia5TAd
pM8MKp+TBQ8fcHxmZTkcBrlnUhUkHNOyHDpBDsuogtjXleWgCIoP2yoH4eYD
pxZuzHLQbhe7eY6zCmLeA6h+pioH/bsqbI2M2Q7o6QkAI9Mfpg==
                    "]], 
                    
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGI1IGYCYu12sZvn9lY6HPc273TkyXJYNvuIwoYFlQ6q
bI1TnYWzHEDCCc2VDhMOfdWIuZ3pEJVifd+/t9KBAQSmZDpYbjlRtq+/0iF2
lycPU3umg8KGooyJMysd9pZMlmDJy3SQBWlYWenQOz1PqDkk0+Gi0u2fdbsq
HS6BaKtMB7D9FysdqkXWuT+Uy3S4ABJ/V+lw89z34MesmQ4yIP3qVRD7rmQ4
gIw5UFbl4ANy19oMByD59MKlKgcnIKW0OcPB42GVyLqjCD7QFWF8ytUQ/23I
cCjfN19KP7Ta4fFSoEePZEDsm1bt8E0jpv/QV6j+s9UQ/8pnOmRMfFtj/7ca
4j67TAeQcD9DjQPIWqX1CD7YX4cyHT5d8k0S+FcNcf9ZqP9+VkPUX890UASF
z1eoex5kQtz3vtqhCGTR80yI/55VO4Tx6W6a+zrT4WrFSzXDa9UQ/3/JdIgD
hfNhqPl3Mx3e1dibxm2qhrjzYqZDFcidfdUQf23LdHAH+ccZKp+b6WAFii9g
+ID9lw2Nz+YqiP3pUPOCqiDx1g3VL1/lMAPkrk1Q9z6uhJj3MNPhMMj/tyoh
8kxZDujpCQCbLRZr
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxdU1tIVFEUHZUsQiRL+gi1mYFISosgkwp1pUWY2WsQLNSmsce9Z8LUj2lI
Ec6ZRKOPyZ6GiFSEESIS0YswsWka+ojRJAkTG0z6CLGQXkTQ2e1bQhcOh3Xu
PnuvtfY+Ds+JfUcSbDZbnF7r9YrXK3YqtXf7ewnaYkcNhOx99cZFidq8haM3
Wg20bnFPRXdJFOrN6TJRERz8kpktkX7g8OaJBsG7Q2JForxUNCHg7+9attYp
cX3bvdlf3y28RmK6sSCn6rVA1Dn2o6lQYtPdiK+/Q0BHjfgPSkze7AjZDYHk
7DudM945/Kk7XJLrm8MZzR/3PmiSqHpUnBTvEszvvEQa8Zgv0F6zODDwUGLl
ugU9aT4TO3PP6AiJ25+HSz17TNY3LPFE0xqPmpz3mUQD6V8lQNHRiMRG4ndM
gNLu1ve1G7V5iV7QcdesxJuX31yTZV6cJH1xCvVG23TjFS/rSVCct92LlHKd
aZ4ChY1r/KrUs6g8RbFf1db9dAWSleHwgq71bVCs74KAdrsimK9goy9TsP85
Cs9LtLC3JvuVpfBVhw1eNbEjKX51S7Ziv2vMf/n+4uVUCHOY0rirLRw2uY5f
IUw/UgVmyP+AwhD1Ld/qV1BhSWDgxbX9AvcJdypUEl/t1+Wis8c/3FLsT53A
n/l6rLhOm0Ax8Yso9r9HsD8jlp6IQJaW0z2hcI6Ejwnm+06B2uIctfCU4nl8
as1TSIHsL4iZaFmqK/cqnr/TJvvbrLBV0/o5ZLC+SgtLg3nZrXjD4HlNtvQd
Mthv3e86eg9uA/+/l983MH9T
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxdVAtIVEEUtU1MzNI+RNiWupWZGmIQ9mH1mkR+sk0lUFtFrKB9T3eHkhQV
YyZMLULKxCJD+mFa2RZmImYhYRIk9jUVMRURCbO0EoOimXcHH7TweJydmTvn
nHvu889yJB1d6OLisoA/Fv4Y+FMelTnWE8vga1HktozfNugxDcwVxzBwET93
BZpn/rzP53hTmPs9o48Cy1J2NHXx/Y+7TrbXmhQoE+f3M9jNX6ZoBZZseXRt
KoLBsQuTRZGDCgwXrGzcG8ygkL+G41Ss68fgV6C1oqNchWr78tPPVzDw6L1J
zN0qTL9NyPL2ZnBZ/D+iwjsOUzwZVHT8DLTOyvOLGLyMDy+Pcs+G0dtXX/i5
6lg7/5fO4xBOp+4jRf5bVVDacitXd1IQtE1PFND0P6PQ8J0fLFNwfytF/rE6
1vgH6fiu2O+pgJBb10LhuDgwY4NvdZ3x4c061vQ16DivvdYn9BKFjW60KjpZ
AUHfWUqhf65YaWtRkH8hhRNiv68K6UJ4AUV/OP99XFYmx5p/r1VoEn3g+I3o
28VsWJt2ZNcQpZDRGutp8MpBH2so3NjDO2m0o3+NFBaLeq/sqP+BrDch150U
+rpnk0dtDpgSejjWeBkILBWC71D4bDlfbQ8i6EclhQ/5EwFhSQRKV/GTZyjy
sBG4RcwevWUUJkW+cgnm54qO4zwNwaX1OrYJ3zso+nRI1u+mMCTuiyCYx34K
JV8SW9atJ8hrhCLvEAK+YmGMQujgBjeaSrDf4xTzqsj1SQoxIpglst4Piavk
fTw/wULIfVnfwEDIsTwkIGKV6c7Qh3oyn1+tjzUE3yaGflh1rOnbrmMtX14E
rKK/mxkYxQVe0l8zw77sJHjvATkPmdI/KwM/J0+UQ+ohDP3Ik3yYnN9iAmYR
HCbX+X6troNhPuIJ5Auf0+S6v9RnYfjuc+B8WSTfVAdURZ/LHufzruVj0I7+
Jst5vm6XfWeY5085WOcUgwCR9zU5yO8sg4NC6OHsefyUl3HtVOexNl9GFeeJ
8x8Q9ZwK5iJH8kmU35cU+X2alvOVwCBd6Ou1wf/ft3+czzj7
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxdlGtIVEEUxzeNCBF7ECJlZhEhLCFCtqxWeyJKzEp6ED1URHusljZ7R0vF
ghkrDSvZRA2k1B6KH4oILbGyJyWLREoPREIjRKS0LPpgD2jmnmMDLQzL796Z
8/if/9zFWUe27Q92OBzT1EpWK0itb32bs2Y7JZxZmzn86iSDVYOp5+qiJSzc
sy9x8AaD6/XPom+FSHjyIyataoiBIssbbPgaWx3y7rf4x2HLb1/6MiBgbtmj
QFOd4Svr73z/U2E4xaUyljHYpP/7BQyptPklDL62PE9xvRVwrKthfmwhg4v5
KlKvAGd5eP/LPAb6eEuPgGZdF2Ogsl9lDwU49E9S/FYBH3Xhlxl4/WOlnkYB
vUsGJk/0MUgODXKWK7b7jfHBnF3utu5G2l/ggwr9vFmAbtPf4oO27qNdDfcE
xL5fOkPMsqBO1xMQkNGpIu21MG8P1XvQgkStX4C4ycL43QL1HLOw3y4BeSO/
WiciOdbXJFDnNA7Fo8viZtZO9c/x3Fmqp9JwR9SpT1vPG1bUEeXn8FTPoUag
LtUc0qrUZBoN2/NtN2znf0EsKH8/5dtN7weJUzjqOyzgTZHaCMQjhmvXVR4e
GTVs6/yZ+t/Osf9x4kMcNup5TAiMU89xDj8FVEdM3xn2gINyzesi5bcp/lAy
72ZSqGHbL+HEfsN2vBzD46We+IwEDlG2UBL956L+4iTqmUn6uSX6zuLohw0S
7HtymuOctkjQ5aeqedzV9aVT/hrSg0uI1BuqOO4rkpCgjaT0tX1bTOePc/QP
p3xeDmv0HHIkPt/B0a8eij9pQe79guoIl8Q4FyzsJ1WCW8dfQH7LpvedPjyf
K/H+FPrw/nolpGv/LvKh3gck+ucxw3PplL+W7lOSRJ2KGT73kH7qPtr3YSXl
z6bvR7xh21crDNv1xkpo1/fKYvD/9+cvJcQFmA==
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxlVwtwVsUVDtZSxiJoKkgQIUErWmxAGQZFIQdioVZtpqIOtYAMJTMIqOi/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                    "]], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{581.3359999999999, 389.578}, {577.234, 
                    386.332}, {573.5509999999999, 389.105}, {
                    573.5509999999999, 366.90999999999997`}, {
                    581.3359999999999, 366.812}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJxIGYC4gtKt3/WvWl0KN83X0pfvsqhXezmue/nGx2u
VrxUM5SrclhSYMt1fWOjg7d5p2OCbJVDh2PC0wvTGh1m5Ak1HxCqcqgEKuNo
gcpzVzkwgEBxo0NUivV9//+VDoIRlltOpEDNf13p8Hjp7CMK6Y0QdXWVEPHs
Jof7/r3T8wIqIeIbmxwmS7CE8b2sdHhUJbLOfVGTA9id/yodjihsKMqY0OTQ
+jpwhxzQvmVA4zbUNMHdo7Np7vvlSU0O1UBtD2Wg7ndtgpgL9M+2z3+vVGg1
OYCMfQjke/IwabdrQdUzVDlsOVG2bz6Q3wny56NKVP6RSgdYeIHtP4rga4EC
7jGCD6ZZqhzQwxcAkzSlgA==
                    "]], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{579.914, 451.809}, {577.98, 
                    432.89799999999997`}, {597.4409999999999, 423.395}, {
                    587.59, 436.562}, {601.043, 440.91799999999995`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{577.746, 456.734}, {574.7890000000001, 
                    456.734}, {572.605, 455.633}, {572.605, 454.32}, {572.605,
                     453.012}, {574.7890000000001, 451.89799999999997`}, {
                    577.746, 451.89799999999997`}, {580.6990000000001, 
                    451.89799999999997`}, {582.8669999999998, 453.012}, {
                    582.8669999999998, 454.32}, {582.8669999999998, 
                    455.633}, {580.6990000000001, 456.734}, {577.746, 
                    456.734}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    579.9219999999999, 452.824}, {574.871, 
                    452.78499999999997`}, {574.871, 413.277}, {580.02, 
                    413.258}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}}}, {{{555.91, 
                    412.60200000000003`}, {555.094, 402.10900000000004`}, {
                    552.434, 394.789}, {548.73, 386.715}, {557.605, 
                    394.949}, {563.7810000000001, 387.617}, {
                    570.4730000000001, 395.078}, {577.2930000000001, 
                    388.77299999999997`}, {583.8549999999999, 
                    395.33599999999996`}, {590.672, 387.35900000000004`}, {
                    596.59, 393.92199999999997`}, {606.629, 386.715}, {
                    602.984, 394.79299999999995`}, {598.055, 401.637}, {
                    598.676, 412.98799999999994`}, {588.953, 405.77}, {
                    565.8519999999999, 404.469}, {555.91, 
                    412.60200000000003`}}}]}, {
                    FaceForm[{
                    RGBColor[1., 0.8, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{621.996, 130.48800000000003`}, {622., 
                    129.80100000000002`}, {621.3199999999999, 129.176}, {
                    620.5740000000001, 129.176}, {619.824, 129.176}, {619.145,
                     129.80100000000002`}, {619.148, 130.48800000000003`}, {
                    619.145, 131.172}, {619.824, 131.797}, {620.5740000000001,
                     131.797}, {621.3199999999999, 131.797}, {622., 
                    131.172}, {621.996, 130.48800000000003`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{627.031, 132.164}, {627.035, 
                    131.48000000000002`}, {626.3549999999999, 
                    130.85500000000002`}, {625.609, 130.85500000000002`}, {
                    624.8589999999999, 130.85500000000002`}, {
                    624.1800000000001, 131.48000000000002`}, {
                    624.1840000000001, 132.164}, {624.1800000000001, 
                    132.85200000000003`}, {624.8589999999999, 133.477}, {
                    625.609, 133.477}, {626.3549999999999, 133.477}, {627.035,
                     132.85200000000003`}, {627.031, 132.164}}}]}}, 
                  AspectRatio -> Automatic, ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 1152.}, {0., 576.}}], ",", 
                 GraphicsBox[{
                   Thickness[0.001388888888888889], {
                    FaceForm[{
                    RGBColor[
                    0.8627450000000002, 0.141176, 0.12156900000000001`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 360.}, {720., 360.}, {720., 0.}}}]}, {
                    FaceForm[{
                    RGBColor[1., 0.7803919999999999, 0.14902], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{0., 360.}, {
                    0., 0.}, {360., 180.}}}]}, {
                    Thickness[0.001388888888888889], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{0., 360.}, {
                    0., 0.}, {240., 180.}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{61.824, 
                    236.348}, {71.20700000000001, 174.05100000000002`}, {
                    100.87499999999999`, 178.52}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{61.824, 
                    236.348}, {106.035, 191.465}, {84.66, 170.414}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{134.883, 
                    224.207}, {78.535, 196.035}, {91.953, 
                    169.19899999999998`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{134.883, 
                    224.207}, {105.859, 168.29299999999998`}, {79.23, 
                    182.117}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{27.703, 
                    170.617}, {89.85199999999999, 160.289}, {94.77, 
                    189.883}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{27.703, 
                    170.617}, {84.051, 198.79299999999998`}, {
                    97.46900000000001, 171.95700000000002`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{145.914, 
                    150.97299999999998`}, {101.70700000000001`, 195.859}, {
                    80.332, 174.805}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{145.914, 
                    150.97299999999998`}, {83.766, 161.30100000000002`}, {
                    88.684, 190.895}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    79.67199999999998, 117.85199999999999`}, {108.699, 
                    173.766}, {82.074, 187.59}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    79.67199999999998, 117.85199999999999`}, {70.289, 
                    180.148}, {99.95700000000001, 184.617}}}]}}, AspectRatio -> 
                  Automatic, ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 720.}, {0., 360.}}], ",", 
                 GraphicsBox[{
                   Thickness[0.00125], {
                    FaceForm[{
                    RGBColor[
                    0.9098040000000001, 0.06666670000000002, 
                    0.17647100000000002`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 480.}, {800., 480.}, {800., 0.}}}]}, {
                    FaceForm[{
                    RGBColor[1., 0.9372550000000001, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    407.26599999999996`, 325.914}, {400.543, 
                    343.51599999999996`}, {414.945, 370.715}, {400.543, 
                    383.51599999999996`}, {405.34400000000005`, 364.316}, {
                    389.34400000000005`, 343.51599999999996`}, {393.824, 
                    325.914}, {398.305, 308.316}, {413.984, 308.316}, {
                    407.26599999999996`, 325.914}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    420.695, 323.801}, {416.812, 342.234}, {435.289, 
                    366.848}, {423.07, 381.742}, {424.809, 362.027}, {405.75, 
                    343.98799999999994`}, {407.42199999999997`, 325.902}, {
                    409.094, 307.82}, {424.582, 305.367}, {420.695, 
                    323.801}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    433.633, 319.60900000000004`}, {432.684, 
                    338.42599999999993`}, {454.78099999999995`, 
                    359.84400000000005`}, {445.043, 376.469}, {443.676, 
                    356.72299999999996`}, {422.03099999999995`, 341.887}, {
                    420.85200000000003`, 323.76599999999996`}, {419.676, 
                    305.641}, {434.58599999999996`, 300.79699999999997`}, {
                    433.633, 319.60900000000004`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    445.758, 313.449}, {447.758, 332.18}, {
                    472.93799999999993`, 349.879}, {465.91799999999995`, 
                    367.82}, {461.47999999999996`, 348.53499999999997`}, {
                    437.78099999999995`, 337.26599999999996`}, {
                    433.78099999999995`, 319.551}, {429.78099999999995`, 
                    301.83599999999996`}, {443.754, 294.715}, {445.758, 
                    313.449}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    456.76599999999996`, 305.465}, {461.672, 
                    323.65200000000004`}, {489.312, 337.195}, {485.184, 
                    356.01599999999996`}, {477.78099999999995`, 337.66}, {
                    452.613, 330.23799999999994`}, {445.89099999999996`, 
                    313.363}, {439.172, 296.49199999999996`}, {451.855, 
                    287.277}, {456.76599999999996`, 305.465}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    466.39099999999996`, 295.85900000000004`}, {474.082, 
                    313.055}, {503.5, 322.105}, {502.367, 
                    341.34000000000003`}, {492.184, 324.367}, {
                    466.16400000000004`, 320.97299999999996`}, {456.887, 
                    305.363}, {447.60900000000004`, 289.75}, {458.695, 
                    278.66}, {466.39099999999996`, 295.85900000000004`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    474.395, 284.863}, {484.684, 300.64500000000004`}, {
                    515.1519999999999, 304.984}, {517.043, 324.156}, {504.332,
                     308.98799999999994`}, {478.09799999999996`, 309.707}, {
                    466.49199999999996`, 295.73799999999994`}, {454.887, 
                    281.77}, {464.105, 269.082}, {474.395, 284.863}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    480.578, 272.754}, {493.207, 286.72999999999996`}, {
                    523.98, 286.25}, {528.848, 304.89099999999996`}, {
                    513.9219999999999, 291.89799999999997`}, {488.125, 
                    296.71099999999996`}, {474.477, 284.727}, {460.828, 
                    272.746}, {467.945, 258.77299999999997`}, {480.578, 
                    272.754}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    484.79299999999995`, 259.824}, {499.453, 
                    271.65200000000004`}, {529.7730000000001, 266.363}, {
                    537.496, 284.01599999999996`}, {520.719, 
                    273.51599999999996`}, {495.99199999999996`, 282.305}, {
                    480.637, 272.605}, {465.28499999999997`, 
                    262.90599999999995`}, {470.129, 247.99200000000002`}, {
                    484.79299999999995`, 259.824}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    486.92999999999995`, 246.395}, {503.262, 255.785}, {
                    532.383, 245.816}, {542.7700000000001, 262.043}, {524.559,
                     254.297}, {501.512, 266.848}, {484.828, 259.668}, {
                    468.14500000000004`, 252.49200000000002`}, {
                    470.59799999999996`, 237.004}, {486.92999999999995`, 
                    246.395}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    486.945, 232.797}, {504.543, 239.516}, {531.742, 
                    225.117}, {544.543, 239.516}, {525.3439999999999, 
                    234.71499999999997`}, {504.543, 250.71499999999997`}, {
                    486.945, 246.23399999999998`}, {469.34400000000005`, 
                    241.754}, {469.34400000000005`, 226.07399999999998`}, {
                    486.945, 232.797}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    484.828, 219.363}, {503.262, 223.24599999999998`}, {
                    527.875, 204.76999999999998`}, {542.7700000000001, 
                    216.98800000000003`}, {523.055, 215.25}, {
                    505.01599999999996`, 234.309}, {486.92999999999995`, 
                    232.637}, {468.848, 230.965}, {466.395, 
                    215.48000000000002`}, {484.828, 219.363}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    480.637, 206.42600000000002`}, {499.453, 207.379}, {
                    520.871, 185.277}, {537.496, 195.016}, {517.754, 
                    196.38700000000003`}, {502.914, 218.031}, {
                    484.79299999999995`, 219.207}, {466.668, 
                    220.38700000000003`}, {461.824, 205.47299999999998`}, {
                    480.637, 206.42600000000002`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    474.477, 194.305}, {493.207, 192.30100000000002`}, {
                    510.90599999999995`, 167.121}, {528.848, 174.141}, {
                    509.562, 178.58200000000002`}, {498.29299999999995`, 
                    202.281}, {480.578, 206.277}, {462.863, 210.277}, {
                    455.742, 196.305}, {474.477, 194.305}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    466.49199999999996`, 183.29299999999998`}, {484.684, 
                    178.38700000000003`}, {498.22299999999996`, 150.75}, {
                    517.043, 154.875}, {498.688, 162.277}, {
                    491.26599999999996`, 187.445}, {474.395, 194.168}, {
                    457.52, 200.88700000000003`}, {448.305, 
                    188.20299999999997`}, {466.49199999999996`, 
                    183.29299999999998`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    456.887, 173.672}, {474.082, 165.977}, {483.133, 
                    136.562}, {502.367, 137.691}, {485.39799999999997`, 
                    147.875}, {482.004, 173.895}, {466.39099999999996`, 
                    183.172}, {450.777, 192.44899999999998`}, {439.688, 
                    181.363}, {456.887, 173.672}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    445.89099999999996`, 165.668}, {461.672, 155.379}, {
                    466.012, 124.91000000000001`}, {485.184, 123.016}, {
                    470.01599999999996`, 135.73}, {470.734, 161.961}, {
                    456.76599999999996`, 173.566}, {442.79699999999997`, 
                    185.172}, {430.10900000000004`, 175.95700000000002`}, {
                    445.89099999999996`, 165.668}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    433.78099999999995`, 159.48000000000002`}, {447.758, 
                    146.85200000000003`}, {447.277, 116.07799999999999`}, {
                    465.91799999999995`, 111.21100000000001`}, {
                    452.92599999999993`, 126.141}, {457.73799999999994`, 
                    151.93800000000002`}, {445.758, 165.58200000000002`}, {
                    433.77299999999997`, 179.23}, {419.805, 
                    172.11299999999997`}, {433.78099999999995`, 
                    159.48000000000002`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    420.85200000000003`, 155.26999999999998`}, {432.684, 
                    140.605}, {427.39099999999996`, 110.289}, {445.043, 
                    102.562}, {434.543, 119.34}, {443.332, 144.066}, {433.633,
                     159.42200000000003`}, {423.93399999999997`, 
                    174.77299999999997`}, {409.02299999999997`, 169.93}, {
                    420.85200000000003`, 155.26999999999998`}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    407.42199999999997`, 153.129}, {416.812, 136.797}, {
                    406.84400000000005`, 107.67999999999999`}, {423.07, 
                    97.289}, {415.324, 115.5}, {427.875, 138.547}, {420.695, 
                    155.23}, {413.52, 171.914}, {398.03099999999995`, 
                    169.461}, {407.42199999999997`, 153.129}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    393.824, 153.117}, {400.543, 135.516}, {
                    386.14500000000004`, 108.316}, {400.543, 95.516}, {
                    395.742, 114.715}, {411.742, 135.516}, {
                    407.26599999999996`, 153.117}, {402.78499999999997`, 
                    170.71499999999997`}, {387.105, 170.71499999999997`}, {
                    393.824, 153.117}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    380.39099999999996`, 155.23}, {384.27299999999997`, 
                    136.797}, {365.79699999999997`, 112.184}, {
                    378.01599999999996`, 97.289}, {376.28099999999995`, 
                    117.004}, {395.33599999999996`, 135.04299999999998`}, {
                    393.66400000000004`, 153.129}, {391.99199999999996`, 
                    171.21099999999998`}, {376.508, 173.664}, {
                    380.39099999999996`, 155.23}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    367.453, 159.42200000000003`}, {368.40599999999995`, 
                    140.605}, {346.305, 119.18799999999999`}, {356.047, 
                    102.562}, {357.414, 122.309}, {379.059, 
                    137.14499999999998`}, {380.234, 155.26999999999998`}, {
                    381.414, 173.39100000000002`}, {366.5, 
                    178.23399999999998`}, {367.453, 159.42200000000003`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    355.332, 165.58200000000002`}, {353.328, 
                    146.85200000000003`}, {328.148, 129.15200000000002`}, {
                    335.168, 111.21100000000001`}, {339.60900000000004`, 
                    130.496}, {363.309, 141.766}, {367.309, 
                    159.48000000000002`}, {371.305, 177.19899999999998`}, {
                    357.33599999999996`, 184.316}, {355.332, 
                    165.58200000000002`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    344.324, 173.566}, {339.414, 155.379}, {311.777, 
                    141.836}, {315.902, 123.016}, {323.305, 141.371}, {
                    348.477, 148.79299999999998`}, {355.195, 165.668}, {
                    361.91799999999995`, 182.539}, {349.22999999999996`, 
                    191.754}, {344.324, 173.566}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    334.699, 183.172}, {327.004, 165.977}, {297.59, 
                    156.92600000000002`}, {298.719, 137.691}, {308.902, 
                    154.664}, {334.92599999999993`, 158.059}, {344.203, 
                    173.672}, {353.47999999999996`, 189.281}, {
                    342.39099999999996`, 200.371}, {334.699, 183.172}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    326.695, 194.168}, {316.40599999999995`, 
                    178.38700000000003`}, {285.93799999999993`, 174.047}, {
                    284.047, 154.875}, {296.758, 170.04299999999998`}, {
                    322.98799999999994`, 169.324}, {334.594, 
                    183.29299999999998`}, {346.199, 197.266}, {336.984, 
                    209.94899999999998`}, {326.695, 194.168}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    320.512, 206.277}, {307.879, 192.30100000000002`}, {
                    277.105, 192.781}, {272.23799999999994`, 174.141}, {
                    287.168, 187.13299999999998`}, {312.965, 
                    182.32000000000002`}, {326.613, 194.305}, {340.258, 
                    206.285}, {333.141, 220.258}, {320.512, 206.277}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    316.29699999999997`, 219.207}, {301.633, 207.379}, {
                    271.316, 212.668}, {263.594, 195.016}, {280.367, 
                    205.516}, {305.094, 196.727}, {320.449, 
                    206.42600000000002`}, {335.805, 216.125}, {330.957, 
                    231.039}, {316.29699999999997`, 219.207}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    314.156, 232.637}, {297.824, 223.24599999999998`}, {
                    268.707, 233.21499999999997`}, {258.316, 
                    216.98800000000003`}, {276.53099999999995`, 
                    224.73399999999998`}, {299.578, 212.184}, {316.258, 
                    219.363}, {332.941, 226.539}, {330.48799999999994`, 
                    242.02700000000002`}, {314.156, 232.637}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    314.14500000000004`, 246.23399999999998`}, {296.543, 
                    239.516}, {269.34400000000005`, 253.914}, {256.543, 
                    239.516}, {275.742, 244.316}, {296.543, 228.316}, {
                    314.14500000000004`, 232.797}, {331.742, 237.277}, {
                    331.742, 252.95700000000002`}, {314.14500000000004`, 
                    246.23399999999998`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    316.258, 259.668}, {297.824, 255.785}, {
                    273.21099999999996`, 274.262}, {258.316, 262.043}, {
                    278.03099999999995`, 263.78099999999995`}, {296.074, 
                    244.72299999999998`}, {314.156, 246.395}, {332.242, 
                    248.066}, {334.695, 263.555}, {316.258, 259.668}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    320.449, 272.605}, {301.633, 271.65200000000004`}, {
                    280.215, 293.754}, {263.594, 284.01599999999996`}, {
                    283.33599999999996`, 282.64500000000004`}, {298.172, 
                    261.}, {316.29699999999997`, 259.824}, {
                    334.41799999999995`, 258.64500000000004`}, {
                    339.26599999999996`, 273.559}, {320.449, 272.605}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    326.613, 284.727}, {307.879, 286.72999999999996`}, {
                    290.18, 311.90999999999997`}, {272.23799999999994`, 
                    304.89099999999996`}, {291.527, 300.449}, {
                    302.79299999999995`, 276.75}, {320.512, 272.754}, {
                    338.227, 268.754}, {345.34400000000005`, 282.727}, {
                    326.613, 284.727}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    334.594, 295.73799999999994`}, {316.40599999999995`, 
                    300.64500000000004`}, {302.863, 328.28099999999995`}, {
                    284.047, 324.156}, {302.39799999999997`, 316.754}, {
                    309.824, 291.58599999999996`}, {326.695, 284.863}, {
                    343.566, 278.14500000000004`}, {352.78499999999997`, 
                    290.828}, {334.594, 295.73799999999994`}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    344.203, 305.363}, {327.004, 313.055}, {317.953, 
                    342.469}, {298.719, 341.34000000000003`}, {315.691, 
                    331.156}, {319.08599999999996`, 305.137}, {334.699, 
                    295.85900000000004`}, {350.312, 286.582}, {
                    361.39799999999997`, 297.668}, {344.203, 305.363}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    355.195, 313.363}, {339.414, 323.65200000000004`}, {
                    335.078, 354.121}, {315.902, 356.01599999999996`}, {
                    331.07, 343.301}, {330.35200000000003`, 317.07}, {344.324,
                     305.465}, {358.29299999999995`, 293.85900000000004`}, {
                    370.977, 303.074}, {355.195, 313.363}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    367.309, 319.551}, {353.328, 332.18}, {353.812, 
                    362.953}, {335.168, 367.82}, {348.16400000000004`, 
                    352.895}, {343.35200000000003`, 327.09799999999996`}, {
                    355.332, 313.449}, {367.312, 299.801}, {
                    381.28499999999997`, 306.91799999999995`}, {367.309, 
                    319.551}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    380.234, 323.76599999999996`}, {368.40599999999995`, 
                    338.42599999999993`}, {373.695, 368.746}, {356.047, 
                    376.469}, {366.543, 359.691}, {357.754, 334.965}, {
                    367.453, 319.60900000000004`}, {377.15200000000004`, 
                    304.258}, {392.066, 309.10200000000003`}, {380.234, 
                    323.76599999999996`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    393.66400000000004`, 325.902}, {384.27299999999997`, 
                    342.234}, {394.242, 371.35200000000003`}, {
                    378.01599999999996`, 381.742}, {385.762, 
                    363.53099999999995`}, {373.21099999999996`, 340.484}, {
                    380.39099999999996`, 323.801}, {387.57, 307.117}, {
                    403.055, 309.57}, {393.66400000000004`, 325.902}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.9098040000000001, 0.06666670000000002, 
                    0.17647100000000002`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{486.945, 239.516}, {486.945, 191.797}, {448.262, 
                    153.117}, {400.543, 153.117}, {352.828, 153.117}, {
                    314.14500000000004`, 191.797}, {314.14500000000004`, 
                    239.516}, {314.14500000000004`, 287.234}, {352.828, 
                    325.914}, {400.543, 325.914}, {448.262, 325.914}, {
                    486.945, 287.234}, {486.945, 239.516}}}]}, {
                    RGBColor[1., 0.9372550000000001, 0.], 
                    Thickness[0.021882977499999998`], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{485.59799999999996`, 240.81199999999998`}, {
                    485.59799999999996`, 193.89099999999996`}, {447.559, 
                    155.85199999999998`}, {400.637, 155.85199999999998`}, {
                    353.715, 155.85199999999998`}, {315.676, 
                    193.89099999999996`}, {315.676, 240.81199999999998`}, {
                    315.676, 287.73400000000004`}, {353.715, 325.773}, {
                    400.637, 325.773}, {447.559, 325.773}, {
                    485.59799999999996`, 287.73400000000004`}, {
                    485.59799999999996`, 240.81199999999998`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 0.9372550000000001, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{464.621, 244.23399999999998`}, {464.621, 
                    208.45700000000002`}, {435.93399999999997`, 179.453}, {
                    400.543, 179.453}, {365.156, 179.453}, {336.469, 
                    208.45700000000002`}, {336.469, 244.23399999999998`}, {
                    336.469, 280.012}, {365.156, 309.01599999999996`}, {
                    400.543, 309.01599999999996`}, {435.93399999999997`, 
                    309.01599999999996`}, {464.621, 280.012}, {464.621, 
                    244.23399999999998`}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.9098040000000001, 0.06666670000000002, 
                    0.17647100000000002`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{464.621, 279.707}, {414.574, 
                    279.707}, {374.004, 238.68800000000002`}, {374.004, 
                    188.094}, {374.004, 137.496}, {414.574, 96.477}, {464.621,
                     96.477}, {459.4959999999999, 92.93}, {407.508, 92.93}, {
                    365.367, 135.535}, {365.367, 188.094}, {365.367, 
                    240.648}, {407.508, 283.254}, {459.4959999999999, 
                    283.254}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{456.078, 285.76599999999996`}, {
                    402.719, 285.76599999999996`}, {359.465, 242.035}, {
                    359.465, 188.094}, {359.465, 134.148}, {402.719, 
                    90.418}, {456.078, 90.418}, {450.949, 86.453}, {
                    395.42999999999995`, 86.453}, {350.41799999999995`, 
                    131.961}, {350.41799999999995`, 188.094}, {
                    350.41799999999995`, 244.227}, {395.42999999999995`, 
                    289.72999999999996`}, {450.949, 289.72999999999996`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{447.53499999999997`, 
                    292.49199999999996`}, {390.504, 292.49199999999996`}, {
                    344.27, 245.75}, {344.27, 188.094}, {344.27, 130.434}, {
                    390.504, 83.691}, {447.53499999999997`, 83.691}, {
                    442.40599999999995`, 79.391}, {383.02299999999997`, 
                    79.391}, {334.887, 128.059}, {334.887, 188.094}, {334.887,
                     248.129}, {383.02299999999997`, 296.79699999999997`}, {
                    442.40599999999995`, 296.79699999999997`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{336.469, 279.707}, {
                    386.51599999999996`, 279.707}, {427.08599999999996`, 
                    238.68800000000002`}, {427.08599999999996`, 188.094}, {
                    427.08599999999996`, 137.496}, {386.51599999999996`, 
                    96.477}, {336.469, 96.477}, {341.594, 92.93}, {393.578, 
                    92.93}, {435.72299999999996`, 135.535}, {
                    435.72299999999996`, 188.094}, {435.72299999999996`, 
                    240.648}, {393.578, 283.254}, {341.594, 283.254}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{345.012, 285.76599999999996`}, {
                    398.367, 285.76599999999996`}, {441.621, 242.035}, {
                    441.621, 188.094}, {441.621, 134.148}, {398.367, 
                    90.418}, {345.012, 90.418}, {350.137, 86.453}, {405.66, 
                    86.453}, {450.668, 131.961}, {450.668, 188.094}, {450.668,
                     244.227}, {405.66, 289.72999999999996`}, {350.137, 
                    289.72999999999996`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{353.555, 292.49199999999996`}, {
                    410.58599999999996`, 292.49199999999996`}, {456.82, 
                    245.75}, {456.82, 188.094}, {456.82, 130.434}, {
                    410.58599999999996`, 83.691}, {353.555, 83.691}, {358.68, 
                    79.391}, {418.062, 79.391}, {466.203, 128.059}, {466.203, 
                    188.094}, {466.203, 248.129}, {418.062, 
                    296.79699999999997`}, {358.68, 296.79699999999997`}}}]}}, 
                  AspectRatio -> Automatic, ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 800.}, {0., 480.}}], ",", 
                 GraphicsBox[{
                   Thickness[0.0020833333333333333`], {
                    FaceForm[{
                    RGBColor[
                    0.8078430000000001, 0.06666670000000002, 0.14902], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 320.}, {480., 320.}, {480., 0.}}}]}, {
                    FaceForm[{
                    RGBColor[0., 0.15686300000000003`, 0.407843], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     240.}, {480., 240.}, {480., 80.}, {0., 80.}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{304., 160.}, {304., 124.65199999999999`}, {
                    275.348, 96.}, {240., 96.}, {204.65200000000002`, 96.}, {
                    176., 124.65199999999999`}, {176., 160.}, {176., 
                    195.348}, {204.65200000000002`, 224.}, {240., 224.}, {
                    275.348, 224.}, {304., 195.348}, {304., 160.}}}]}}, 
                  AspectRatio -> Automatic, ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 480.}, {0., 320.}}], ",", 
                 GraphicsBox[{
                   Thickness[0.0004464285714285714], {
                    FaceForm[{
                    RGBColor[0.8, 0., 0.003921569999999999], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 1120.}, {2240., 1120.}, {2240., 0.}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     80.}, {2240., 80.}, {2240., 0.}, {0., 0.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     240.}, {2240., 240.}, {2240., 160.}, {0., 160.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     400.}, {2240., 400.}, {2240., 320.}, {0., 320.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     560.}, {2240., 560.}, {2240., 480.}, {0., 480.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     720.}, {2240., 720.}, {2240., 640.}, {0., 640.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     880.}, {2240., 880.}, {2240., 800.}, {0., 800.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     1040.}, {2240., 1040.}, {2240., 960.}, {0., 960.}}}]}, {
                    FaceForm[{
                    RGBColor[0.003921569999999999, 0., 0.4], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     1120.}, {1120., 1120.}, {1120., 480.}, {0., 480.}}}]}, {
                    FaceForm[{
                    RGBColor[1., 0.8, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4k7HhKcXztQ4MICAwwSHx0tnH1GoK4HzwXRD
tgNYnXIvnA+mGTrh/PJ986X077Sg6m9odEAxH8hvfR24Q+5sPZx/Qen2zzqf
RocjChuKMj40QvRXNkH0bWxy+HTJN0ngVKPDUZB8aZNDBcgevkaHy0DhiJAm
B+v7/r3TvRrgfFuu64sLzCvh/Nznv1d+tCmGmOPfCud3gMz/1QHng81Z1gPX
/7BKZJ37wn64+TB+u9jNc9+lGuH8Q181YvofNULMr+l3yJj4tsZ+dpPDNOfu
nOfm/Q6CEZZbTqQ3OoC41cwTHHbKAUPgVT08fNHDHwDvCqa9
                    "]], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4k+XfJMEHnY5XFC6/bNOotVh64myffO3tjvI
RqVY39/f5uDFw6TdvrTDwce80zEhttlBIMJyy4m2NoeKffOl9I3aHLZ//nul
4m6rAwMIHGhy4NXdNPe9WauDXOvrwB1A+WnO3TnPRZsdPEHmxDc7HP6qEdPP
0eLwsEpknfvBNgdBkHm3GxwuA50RIdPqcAgkb97ssGz2EYUNB9sh5jrUQ+yf
1w5R97bJ4fFSoALGTofj3kAJp3oHW67riwvSuhxs7vv3TrdodgAJJzh0Qdxz
r8FB/64KW+PzHog5XC0Q/Q7dDttA7pdqdtgC8veiPof3y495m1u2OgBVPb1w
thvi7kdQ/zn0O4DDq7MN4n6gfNaekskSqzog5izog7hjezvE/3bdEPOedDno
AJ2x/HEPRL6jwyEaGLz+dl0QcxV6IOGeCFV3qcNBBhT+/6C0XA8k3Ga2OwBD
pSijvQPi3v3tDgDqbsmS
                    "]]}}, AspectRatio -> Automatic, 
                  ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 2240.}, {0., 1120.}}], ",", 
                 GraphicsBox[{
                   Thickness[0.001736111111111111], {
                    FaceForm[{
                    RGBColor[
                    0.8235290000000001, 0.06274510000000001, 
                    0.20392200000000002`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 384.}, {576., 384.}, {576., 0.}}}]}, {
                    FaceForm[{
                    RGBColor[0., 0.494118, 0.22745100000000001`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    96., 288.}, {480., 288.}, {480., 96.}, {96., 96.}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{376., 192.}, {376., 156.65200000000002`}, {
                    347.348, 128.}, {312., 128.}, {276.65200000000004`, 
                    128.}, {248., 156.65200000000002`}, {248., 192.}, {248., 
                    227.348}, {276.65200000000004`, 256.}, {312., 256.}, {
                    347.348, 256.}, {376., 227.348}, {376., 192.}}}]}, {
                    FaceForm[{
                    RGBColor[0., 0.494118, 0.22745100000000001`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{400., 192.}, {400., 156.65200000000002`}, {
                    371.348, 128.}, {336., 128.}, {300.65200000000004`, 
                    128.}, {272., 156.65200000000002`}, {272., 192.}, {272., 
                    227.348}, {300.65200000000004`, 256.}, {336., 256.}, {
                    371.348, 256.}, {400., 227.348}, {400., 192.}}}]}}, 
                  AspectRatio -> Automatic, ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 576.}, {0., 384.}}], ",", 
                 GraphicsBox[{
                   Thickness[0.00026041666666666666`], {
                    FaceForm[{
                    RGBColor[
                    0.7686270000000001, 0.15294100000000005`, 0.184314], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 1920.}, {3840., 1920.}, {3840., 0.}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.003921569999999999, 0.31764699999999996`, 
                    0.5921569999999999], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    1280., 1920.}, {2560., 1920.}, {2560., 0.}, {1280., 
                    0.}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.976471, 0.8117650000000001, 0.007843139999999998], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{816., 1264.}, {816., 1166.797}, {
                    737.2030000000001, 1088.}, {640., 1088.}, {542.797, 
                    1088.}, {464., 1166.797}, {464., 1264.}, {464., 
                    1361.203}, {542.797, 1440.}, {640., 1440.}, {
                    737.2030000000001, 1440.}, {816., 1361.203}, {816., 
                    1264.}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.7686270000000001, 0.15294100000000005`, 0.184314], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{832., 1344.}, {832., 1237.961}, {746.039, 
                    1152.}, {640., 1152.}, {533.9609999999999, 1152.}, {448., 
                    1237.961}, {448., 1344.}, {448., 1450.039}, {
                    533.9609999999999, 1536.}, {640., 1536.}, {746.039, 
                    1536.}, {832., 1450.039}, {832., 1344.}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.976471, 0.8117650000000001, 0.007843139999999998], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{768., 1312.}, {768., 1241.309}, {710.691, 
                    1184.}, {640., 1184.}, {569.309, 1184.}, {512., 
                    1241.309}, {512., 1312.}, {512., 1382.6909999999998`}, {
                    569.309, 1440.}, {640., 1440.}, {710.691, 1440.}, {768., 
                    1382.6909999999998`}, {768., 1312.}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGZigIKGRgcw7TDDAcaXb30daPFmukO72M1z3480
QugZ0x1sua4vLrBuAsvviJ3uwKe7ae77jU0Ozt05z6uVoPIRzRBzGKZD6RY4
/9BXjZj+5Qj+p0u+SQJ+rXD9h0HyR1rh5le+VDPksG6D2w9xXxvcfTA+qvuh
/ANQ/oNWCH0Bjc8wE5VvAOU7QPUXQPkNUPkDaOph8g5QfgIaXwCND3NPAw5+
wwwHAN8kadg=
                    "]], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    288., 1056.}, {448., 1056.}, {448., 288.}, {288., 
                    288.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    832., 1056.}, {992., 1056.}, {992., 288.}, {832., 
                    288.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    480., 928.}, {800., 928.}, {800., 864.}, {480., 864.}}}], 
                    
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    480., 480.}, {800., 480.}, {800., 416.}, {480., 416.}}}], 
                    
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1,
                     0}}}, {{{480., 1056.}, {800., 1056.}, {640., 960.}}, {{
                    480., 384.}, {800., 384.}, {640., 288.}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{809.602, 672.}, {809.602, 578.3319999999999}, {
                    733.668, 502.39799999999997`}, {640., 
                    502.39799999999997`}, {546.3319999999999, 
                    502.39799999999997`}, {470.39799999999997`, 
                    578.3319999999999}, {470.39799999999997`, 672.}, {
                    470.39799999999997`, 765.668}, {546.3319999999999, 
                    841.602}, {640., 841.602}, {733.668, 841.602}, {809.602, 
                    765.668}, {809.602, 672.}}}]}, {
                    RGBColor[
                    0.7686270000000001, 0.15294100000000005`, 0.184314], 
                    Thickness[0.005], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{809.602, 672.}, {809.602, 578.3320000000001}, {
                    733.668, 502.39800000000014`}, {640., 
                    502.39800000000014`}, {546.3319999999999, 
                    502.39800000000014`}, {470.39799999999997`, 
                    578.3320000000001}, {470.39799999999997`, 672.}, {
                    470.39799999999997`, 765.6680000000001}, {
                    546.3319999999999, 841.6020000000001}, {640., 
                    841.6020000000001}, {733.668, 841.6020000000001}, {
                    809.602, 765.6680000000001}, {809.602, 672.}}}, 
                    CurveClosed -> {1}]}, {
                    RGBColor[
                    0.7686270000000001, 0.15294100000000005`, 0.184314], 
                    Thickness[0.005], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGZigIEWhy7HhKcXfLocbO77907fiOA/Xjr7iEJS
q8MyILWBucsBxN1wv9Uha0/JZIm2ToeHVSLr3GPbHLx4mLTbOTodgLJFGcva
HMDGRnTA+cfAdDucLxBhueXElza4/gcg2qUNbv4KEH2sFW7/ExDt2Qp3H8Td
rQ4w98P4YPP9muF82agU6/tzmxzkQPS2FgcQ5a/QBKEtWxzkWl8H7ljUCKF3
N0PMj2x0+LD8mLc5N4IPoZvgfLDxKxrh+rd9/nul4nsD3Pxpzt05zysb4PZv
OVG2b/6Perj7PtTYm8al1cPdD+MDANeSp3k=
                    "], 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[
                    0.7686270000000001, 0.15294100000000005`, 0.184314], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{672., 756.8009999999999}, {672., 739.125}, {
                    657.672, 724.8009999999999}, {640., 724.8009999999999}, {
                    622.328, 724.8009999999999}, {608., 739.125}, {608., 
                    756.8009999999999}, {608., 774.4730000000001}, {622.328, 
                    788.8009999999999}, {640., 788.8009999999999}, {657.672, 
                    788.8009999999999}, {672., 774.4730000000001}, {672., 
                    756.8009999999999}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{672., 587.1990000000001}, {672., 
                    569.5269999999999}, {657.672, 555.1990000000001}, {640., 
                    555.1990000000001}, {622.328, 555.1990000000001}, {608., 
                    569.5269999999999}, {608., 587.1990000000001}, {608., 
                    604.875}, {622.328, 619.1990000000001}, {640., 
                    619.1990000000001}, {657.672, 619.1990000000001}, {672., 
                    604.875}, {672., 587.1990000000001}}}]}}, AspectRatio -> 
                  Automatic, ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 3840.}, {0., 1920.}}], ",", 
                 GraphicsBox[{
                   Thickness[0.0006944444444444445], {
                    FaceForm[{
                    RGBColor[0.996078, 0.796078, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     960.}, {1440., 960.}, {1440., 480.}, {0., 480.}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.9176470000000001, 0.15686300000000003`, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     480.}, {1440., 480.}, {1440., 0.}, {0., 0.}}}]}, {
                    FaceForm[{
                    RGBColor[0.20392200000000002`, 0.698039, 0.2], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     640.}, {1440., 640.}, {1440., 320.}, {0., 320.}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{812.992, 
                    378.68}, {512.0659999999999, 160.04299999999998`}, {
                    627.008, 513.8009999999999}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{684.48, 
                    336.92199999999997`}, {383.555, 555.559}, {755.52, 
                    555.559}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{605.055, 
                    446.23799999999994`}, {720., 800.}, {834.9449999999999, 
                    446.23799999999994`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{684.48, 
                    555.559}, {1056.4450000000002`, 555.559}, {755.52, 
                    336.92199999999997`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{812.992, 
                    513.8009999999999}, {927.934, 160.04299999999998`}, {
                    627.008, 378.68}}}]}}, AspectRatio -> Automatic, 
                  ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 1440.}, {0., 960.}}], ",", 
                 GraphicsBox[{
                   Thickness[0.0020833333333333333`], {
                    FaceForm[{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 240.}, {480., 240.}, {480., 0.}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    120., 240.}, {480., 240.}, {480., 160.}, {120., 
                    160.}}}]}, {
                    FaceForm[{
                    RGBColor[0., 0.501961, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    120., 80.}, {480., 80.}, {480., 0.}, {120., 0.}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    27.629, 198.945}, {40.523, 198.945}, {41.234, 198.945}, {
                    41.809, 198.406}, {41.809, 197.738}, {41.809, 191.664}, {
                    41.809, 190.996}, {41.234, 190.45700000000002`}, {40.523, 
                    190.45700000000002`}, {27.629, 190.45700000000002`}, {
                    26.914, 190.45700000000002`}, {26.34, 190.996}, {26.34, 
                    191.664}, {26.34, 197.738}, {26.34, 198.406}, {26.914, 
                    198.945}, {27.629, 198.945}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002951354166666667], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    27.629, 198.945}, {40.523, 198.945}, {41.234, 198.945}, {
                    41.809, 198.406}, {41.809, 197.738}, {41.809, 191.664}, {
                    41.809, 190.996}, {41.234, 190.457}, {40.523, 190.457}, {
                    27.629, 190.457}, {26.914, 190.457}, {26.34, 190.996}, {
                    26.34, 191.664}, {26.34, 197.738}, {26.34, 198.406}, {
                    26.914, 198.945}, {27.629, 198.945}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    27.957, 198.594}, {40.191, 198.594}, {40.867, 198.594}, {
                    41.413999999999994`, 198.098}, {41.413999999999994`, 
                    197.48800000000003`}, {41.413999999999994`, 191.918}, {
                    41.413999999999994`, 191.305}, {40.867, 190.812}, {40.191,
                     190.812}, {27.957, 190.812}, {27.281, 190.812}, {26.738, 
                    191.305}, {26.738, 191.918}, {26.738, 
                    197.48800000000003`}, {26.738, 198.098}, {27.281, 
                    198.594}, {27.957, 198.594}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752291666666667], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    27.957, 198.594}, {40.191, 198.594}, {40.867, 198.594}, {
                    41.413999999999994`, 198.098}, {41.413999999999994`, 
                    197.488}, {41.413999999999994`, 191.918}, {
                    41.413999999999994`, 191.305}, {40.867, 190.812}, {40.191,
                     190.812}, {27.957, 190.812}, {27.281, 190.812}, {26.738, 
                    191.305}, {26.738, 191.918}, {26.738, 197.488}, {26.738, 
                    198.098}, {27.281, 198.594}, {27.957, 198.594}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIFIGYCYn7dTXPfH3dwiNvlycPUn+FwfXGBLZe6owMX
iNGXARHXdnQoypj4tqY5w2H2EYUNRRWODsLNB04trMxwWOi67fPfLY4ON899
D37cmuEQYbnlRNk/RwcGEKjJcADKXqnY6egA0m5fmOFwUen2z7pTjg5Anmlc
UoaDtP5dFTZFJwdVtsapzskI/oRDXzVi/DMcKl+qGXLccXQ47m3e6RiAME82
KsX6vjPUvexODt80YvoPmSLM5wZJaGU4uHTnPP/d6egAdNW++WYI/4Ddb5gB
8Ze+o0MxiJbPcICFB9g/slD1ux0g7tPPcBBd5/6wKsXBYdXHS75JFlD/mzhA
3KOd4fAJKCxww95hEVgc6j5xBwenhKcXlIDu/QJ0/stj9g6PlwJD0ifDoV0M
aJMxgg9xnz3EP6kZDqdAFuyFyqdkOBwGBku/EDS+ijMcpkiwhPGttYf4uw5q
nrKDgxXIw93Q8ItxgLinAeGfY6DwbMlwAADQteMG
                    "]]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.00017376208333333334`], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIFIGYCYn7dTXPfH3dwiNvlycPUn+FwfXGBLZe6owMX
iNGXARHXdnQozpj4tqY5w2H2EYUNRRWODkLNB04trMxwWOi67fPfLY4ON899
D37cmuEQYbnlRNk/RwcGEKjJcADKXqnY6egA0m5fmOFwUen2z7pTjg7vauxN
45IyHKT176qwKTo5qLI1TnVORvD7D33ViPHPcKh8qWbIccfR4Zi3eadjAMI8
2agU6/vOUPeyOzl804jpP2SKMB/sfq0MB5funOe/Ox0dgK7aN98M4R+w+w0z
HIpADtOH+k8+wwEWHmD/yELV73aAuE8/w0F0nfvDqhQHh1UfL/kmWUD9b+Lg
IANyj3aGwyegsMANe4dFYHGo+8QdHJwSnl5QArr3C9D5L4/ZOzxeCgxJnwyH
djGgTcYIPsR99hD/pGY4nAJZsNfe4QlIPiXD4TAwWPqFoPFVnOEwRYIljG+t
PcTfdVDzlB0cQNGwrxsafjEOEPc0IPxzHBSeLRkOAMzd4wM=
                    "], 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{34.602000000000004`, 194.79299999999998`}, {
                    34.602000000000004`, 194.406}, {34.234, 194.094}, {
                    33.785000000000004`, 194.094}, {33.336, 194.094}, {32.973,
                     194.406}, {32.973, 194.79299999999998`}, {32.973, 
                    195.176}, {33.336, 195.48800000000003`}, {
                    33.785000000000004`, 195.48800000000003`}, {34.234, 
                    195.48800000000003`}, {34.602000000000004`, 195.176}, {
                    34.602000000000004`, 194.79299999999998`}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.00018712128065294733`], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{34.602000000000004`, 194.79308092799997`}, {
                    34.602000000000004`, 194.40591648}, {34.234, 
                    194.093901888}, {33.785000000000004`, 194.093901888}, {
                    33.336, 194.093901888}, {32.973, 194.40591648}, {32.973, 
                    194.79308092799997`}, {32.973, 195.175489056}, {33.336, 
                    195.488454912}, {33.785000000000004`, 195.488454912}, {
                    34.234, 195.488454912}, {34.602000000000004`, 
                    195.175489056}, {34.602000000000004`, 
                    194.79308092799997`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{28.723, 
                    198.23399999999998`}, {27.531000000000002`, 197.176}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{28.723, 
                    198.23399999999998`}, {27.531000000000002`, 197.176}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{29.516000000000002`, 
                    198.23399999999998`}, {28.324, 197.176}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{29.516000000000002`, 
                    198.23399999999998`}, {28.324, 197.176}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{30.309, 
                    198.23399999999998`}, {29.117000000000004`, 197.176}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{30.309, 
                    198.23399999999998`}, {29.117000000000004`, 197.176}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{31.102, 
                    198.23399999999998`}, {29.91, 197.176}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{31.102, 
                    198.23399999999998`}, {29.91, 197.176}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{31.895, 
                    198.23399999999998`}, {30.703, 197.176}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{31.895, 
                    198.23399999999998`}, {30.703, 197.176}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{32.688, 
                    198.23399999999998`}, {31.496, 197.176}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{32.688, 
                    198.23399999999998`}, {31.496, 197.176}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{33.48, 
                    198.23399999999998`}, {32.289, 197.176}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{33.48, 
                    198.23399999999998`}, {32.289, 197.176}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{34.273, 
                    198.23399999999998`}, {33.086, 197.176}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{34.273, 
                    198.23399999999998`}, {33.086, 197.176}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{35.066, 
                    198.23399999999998`}, {33.879, 197.176}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{35.066, 
                    198.23399999999998`}, {33.879, 197.176}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{35.858999999999995`, 
                    198.23399999999998`}, {34.672000000000004`, 197.176}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{35.858999999999995`, 
                    198.23399999999998`}, {34.672000000000004`, 197.176}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{36.652, 
                    198.23399999999998`}, {35.465, 197.176}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{36.652, 
                    198.23399999999998`}, {35.465, 197.176}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{37.445, 
                    198.23399999999998`}, {36.258, 197.176}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{37.445, 
                    198.23399999999998`}, {36.258, 197.176}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{34.273, 
                    198.23399999999998`}, {33.086, 197.176}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{34.273, 
                    198.23399999999998`}, {33.086, 197.176}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{38.23800000000001, 
                    198.23399999999998`}, {37.050999999999995`, 197.176}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{38.23800000000001, 
                    198.23399999999998`}, {37.050999999999995`, 197.176}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{39.031, 
                    198.23399999999998`}, {37.843999999999994`, 197.176}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{39.031, 
                    198.23399999999998`}, {37.843999999999994`, 197.176}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{39.828, 
                    198.23399999999998`}, {38.637, 197.176}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{39.828, 
                    198.23399999999998`}, {38.637, 197.176}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{40.621, 
                    198.23399999999998`}, {39.43, 197.176}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{40.621, 
                    198.23399999999998`}, {39.43, 197.176}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{39.43, 
                    198.23399999999998`}, {40.621, 197.176}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{39.43, 
                    198.23399999999998`}, {40.621, 197.176}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{38.637, 
                    198.23399999999998`}, {39.828, 197.176}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{38.637, 
                    198.23399999999998`}, {39.828, 197.176}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{37.843999999999994`, 
                    198.23399999999998`}, {39.031, 197.176}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{37.843999999999994`, 
                    198.23399999999998`}, {39.031, 197.176}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{37.050999999999995`, 
                    198.23399999999998`}, {38.23800000000001, 197.176}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{37.050999999999995`, 
                    198.23399999999998`}, {38.23800000000001, 197.176}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{36.258, 
                    198.23399999999998`}, {37.445, 197.176}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{36.258, 
                    198.23399999999998`}, {37.445, 197.176}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{35.465, 
                    198.23399999999998`}, {36.652, 197.176}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{35.465, 
                    198.23399999999998`}, {36.652, 197.176}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{34.672000000000004`, 
                    198.23399999999998`}, {35.858999999999995`, 197.176}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{34.672000000000004`, 
                    198.23399999999998`}, {35.858999999999995`, 197.176}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{33.879, 
                    198.23399999999998`}, {35.066, 197.176}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{33.879, 
                    198.23399999999998`}, {35.066, 197.176}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{33.086, 
                    198.23399999999998`}, {34.273, 197.176}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{33.086, 
                    198.23399999999998`}, {34.273, 197.176}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{32.289, 
                    198.23399999999998`}, {33.48, 197.176}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{32.289, 
                    198.23399999999998`}, {33.48, 197.176}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{31.496, 
                    198.23399999999998`}, {32.688, 197.176}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{31.496, 
                    198.23399999999998`}, {32.688, 197.176}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{30.703, 
                    198.23399999999998`}, {31.895, 197.176}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{30.703, 
                    198.23399999999998`}, {31.895, 197.176}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{33.879, 
                    198.23399999999998`}, {35.066, 197.176}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{33.879, 
                    198.23399999999998`}, {35.066, 197.176}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{29.91, 
                    198.23399999999998`}, {31.102, 197.176}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{29.91, 
                    198.23399999999998`}, {31.102, 197.176}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{29.117000000000004`, 
                    198.23399999999998`}, {30.309, 197.176}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{29.117000000000004`, 
                    198.23399999999998`}, {30.309, 197.176}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{28.324, 
                    198.23399999999998`}, {29.516000000000002`, 197.176}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{28.324, 
                    198.23399999999998`}, {29.516000000000002`, 197.176}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{27.531000000000002`, 
                    198.23399999999998`}, {28.723, 197.176}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{27.531000000000002`, 
                    198.23399999999998`}, {28.723, 197.176}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{28.723, 192.227}, {
                    27.531000000000002`, 191.164}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{28.723, 192.227}, {
                    27.531000000000002`, 191.164}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{29.516000000000002`, 
                    192.227}, {28.324, 191.164}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{29.516000000000002`, 
                    192.227}, {28.324, 191.164}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{30.309, 192.227}, {
                    29.117000000000004`, 191.164}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{30.309, 192.227}, {
                    29.117000000000004`, 191.164}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{31.102, 192.227}, {29.91,
                     191.164}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{31.102, 192.227}, {29.91,
                     191.164}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{31.895, 192.227}, {
                    30.703, 191.164}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{31.895, 192.227}, {
                    30.703, 191.164}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{32.688, 192.227}, {
                    31.496, 191.164}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{32.688, 192.227}, {
                    31.496, 191.164}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{33.48, 192.227}, {32.289,
                     191.164}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{33.48, 192.227}, {32.289,
                     191.164}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{34.273, 192.227}, {
                    33.086, 191.164}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{34.273, 192.227}, {
                    33.086, 191.164}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{35.066, 192.227}, {
                    33.879, 191.164}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{35.066, 192.227}, {
                    33.879, 191.164}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{35.858999999999995`, 
                    192.227}, {34.672000000000004`, 191.164}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{35.858999999999995`, 
                    192.227}, {34.672000000000004`, 191.164}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{36.652, 192.227}, {
                    35.465, 191.164}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{36.652, 192.227}, {
                    35.465, 191.164}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{37.445, 192.227}, {
                    36.258, 191.164}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{37.445, 192.227}, {
                    36.258, 191.164}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{34.273, 192.227}, {
                    33.086, 191.164}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{34.273, 192.227}, {
                    33.086, 191.164}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{38.23800000000001, 
                    192.227}, {37.050999999999995`, 191.164}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{38.23800000000001, 
                    192.227}, {37.050999999999995`, 191.164}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{39.031, 192.227}, {
                    37.843999999999994`, 191.164}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{39.031, 192.227}, {
                    37.843999999999994`, 191.164}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{39.828, 192.227}, {
                    38.637, 191.164}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{39.828, 192.227}, {
                    38.637, 191.164}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{40.621, 192.227}, {39.43,
                     191.164}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{40.621, 192.227}, {39.43,
                     191.164}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{39.43, 192.227}, {40.621,
                     191.164}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{39.43, 192.227}, {40.621,
                     191.164}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{38.637, 192.227}, {
                    39.828, 191.164}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{38.637, 192.227}, {
                    39.828, 191.164}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{37.843999999999994`, 
                    192.227}, {39.031, 191.164}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{37.843999999999994`, 
                    192.227}, {39.031, 191.164}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{37.050999999999995`, 
                    192.227}, {38.23800000000001, 191.164}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{37.050999999999995`, 
                    192.227}, {38.23800000000001, 191.164}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{36.258, 192.227}, {
                    37.445, 191.164}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{36.258, 192.227}, {
                    37.445, 191.164}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{35.465, 192.227}, {
                    36.652, 191.164}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{35.465, 192.227}, {
                    36.652, 191.164}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{34.672000000000004`, 
                    192.227}, {35.858999999999995`, 191.164}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{34.672000000000004`, 
                    192.227}, {35.858999999999995`, 191.164}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{33.879, 192.227}, {
                    35.066, 191.164}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{33.879, 192.227}, {
                    35.066, 191.164}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{33.086, 192.227}, {
                    34.273, 191.164}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{33.086, 192.227}, {
                    34.273, 191.164}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{32.289, 192.227}, {33.48,
                     191.164}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{32.289, 192.227}, {33.48,
                     191.164}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{31.496, 192.227}, {
                    32.688, 191.164}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{31.496, 192.227}, {
                    32.688, 191.164}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{30.703, 192.227}, {
                    31.895, 191.164}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{30.703, 192.227}, {
                    31.895, 191.164}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{33.879, 192.227}, {
                    35.066, 191.164}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{33.879, 192.227}, {
                    35.066, 191.164}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{29.91, 192.227}, {31.102,
                     191.164}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{29.91, 192.227}, {31.102,
                     191.164}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{29.117000000000004`, 
                    192.227}, {30.309, 191.164}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{29.117000000000004`, 
                    192.227}, {30.309, 191.164}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{28.324, 192.227}, {
                    29.516000000000002`, 191.164}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{28.324, 192.227}, {
                    29.516000000000002`, 191.164}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{27.531000000000002`, 
                    192.227}, {28.723, 191.164}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{27.531000000000002`, 
                    192.227}, {28.723, 191.164}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    92.371, 198.945}, {79.477, 198.945}, {78.766, 198.945}, {
                    78.191, 198.406}, {78.191, 197.738}, {78.191, 191.664}, {
                    78.191, 190.996}, {78.766, 190.45700000000002`}, {79.477, 
                    190.45700000000002`}, {92.371, 190.45700000000002`}, {
                    93.086, 190.45700000000002`}, {93.66, 190.996}, {93.66, 
                    191.664}, {93.66, 197.738}, {93.66, 198.406}, {93.086, 
                    198.945}, {92.371, 198.945}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002951354166666667], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    92.371, 198.945}, {79.477, 198.945}, {78.766, 198.945}, {
                    78.191, 198.406}, {78.191, 197.738}, {78.191, 191.664}, {
                    78.191, 190.996}, {78.766, 190.457}, {79.477, 190.457}, {
                    92.371, 190.457}, {93.086, 190.457}, {93.66, 190.996}, {
                    93.66, 191.664}, {93.66, 197.738}, {93.66, 198.406}, {
                    93.086, 198.945}, {92.371, 198.945}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    92.043, 198.594}, {79.809, 198.594}, {79.133, 198.594}, {
                    78.586, 198.098}, {78.586, 197.48800000000003`}, {78.586, 
                    191.918}, {78.586, 191.305}, {79.133, 190.812}, {79.809, 
                    190.812}, {92.043, 190.812}, {92.71900000000001, 
                    190.812}, {93.262, 191.305}, {93.262, 191.918}, {93.262, 
                    197.48800000000003`}, {93.262, 198.098}, {
                    92.71900000000001, 198.594}, {92.043, 198.594}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752291666666667], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    92.043, 198.594}, {79.809, 198.594}, {79.133, 198.594}, {
                    78.586, 198.098}, {78.586, 197.488}, {78.586, 191.918}, {
                    78.586, 191.305}, {79.133, 190.812}, {79.809, 190.812}, {
                    92.043, 190.812}, {92.71900000000001, 190.812}, {93.262, 
                    191.305}, {93.262, 191.918}, {93.262, 197.488}, {93.262, 
                    198.098}, {92.71900000000001, 198.594}, {92.043, 
                    198.594}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIFIGYC4sqXaoYcc0Id4nZ58jD1ZziIrHN/WJUT6sB1
fXGBbV+Gw0Wl2z/rskIdijImvq1pznDYNPf98mPOoQ7CzQdOLazMcNC/q8LW
qBrqcPPc9+DHrRkOIY+Xzj7CEOrAAAI1GQ6qbI1TnZVDHUDa7QszHGbkCTUf
kAp1APJM45IyHIpBEu9DIOqSEfwJh75qxPhnOLh05zz/LRjqcNzbvNMxAGGe
bFSK9X3nDAdRkHv/hDh804jpP2SKMJ8b5H6tDIi/rEMdtpwo2zffDOEfsPsN
MxyOgczNCIXYK5/hAAsPsH9koeoXhULs1c+A2HM21GHVx0u+SRZQ/z+Fukc7
w8EZ5F7OMIdFrts+/zWBhueXUAenhKcXlIDuBVnryhfmAAomBZ8Mh3iQ+4wR
fHA4mYZB7EnNcOidDvSQAFQ+JcNBrvV14I5v0PgqznAA+WaPSBjEnXUZDntL
JkuwvAt1sAJ5uBsafhdDIe5pQPgH7O+WDAcAOIfkoA==
                    "]]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.00017376208333333334`], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIFIGYC4sqXaoYcc0Id4nZ58jD1ZziIrHN/WJUT6sB1
fXGBbV+Gw0Wl2z/rskIdijMmvq1pznDYNPf98mPOoQ5CzQdOLazMcNC/q8LW
qBrqcPPc9+DHrRkOIY+Xzj7CEOrAAAI1GQ6qbI1TnZVDHUDa7QszHGbkAXVK
hTq8q7E3jUvKgJj7PgSiLhnB7z/0VSPGP8PBpTvn+W/BUIdj3uadjgEI82Sj
UqzvO2c4iILc+yfE4ZtGTP8hU4T5YPdrZUD8ZR3qsOVE2b75Zgj/gN1vmAEx
NwPqP/kMB1h4gP0jC1W/KBRir34GxJ6zoQ6rPl7yTbKA+v9pqIMMyD3aGQ7O
IPdyhjksct32+a8JNDy/hDo4JTy9oAR0L8haV74wB1AwKfhkOMSD3GeM4IPD
yTQMYk9qhkPvdKCHBMIcnoDkUzIc5FpfB+74Bo2v4gwHkG/2iIRB3FmX4bC3
ZLIEy7tQB0uQh7uh4XcxFOKeBoR/joP83ZLhAAA0r+Sd
                    "], 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{85.398, 194.79299999999998`}, {85.398, 
                    194.406}, {85.766, 194.094}, {86.215, 194.094}, {86.664, 
                    194.094}, {87.027, 194.406}, {87.027, 
                    194.79299999999998`}, {87.027, 195.176}, {86.664, 
                    195.48800000000003`}, {86.215, 195.48800000000003`}, {
                    85.766, 195.48800000000003`}, {85.398, 195.176}, {85.398, 
                    194.79299999999998`}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.00018712128065294733`], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{85.398, 194.79308092799997`}, {85.398, 
                    194.40591648}, {85.766, 194.093901888}, {86.215, 
                    194.093901888}, {86.664, 194.093901888}, {87.027, 
                    194.40591648}, {87.027, 194.79308092799997`}, {87.027, 
                    195.175489056}, {86.664, 195.488454912}, {86.215, 
                    195.488454912}, {85.766, 195.488454912}, {85.398, 
                    195.175489056}, {85.398, 194.79308092799997`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{91.277, 
                    198.23399999999998`}, {92.46900000000001, 197.176}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{91.277, 
                    198.23399999999998`}, {92.46900000000001, 197.176}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{90.48400000000001, 
                    198.23399999999998`}, {91.67599999999999, 197.176}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{90.48400000000001, 
                    198.23399999999998`}, {91.67599999999999, 197.176}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{89.691, 
                    198.23399999999998`}, {90.883, 197.176}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{89.691, 
                    198.23399999999998`}, {90.883, 197.176}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{88.898, 
                    198.23399999999998`}, {90.09, 197.176}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{88.898, 
                    198.23399999999998`}, {90.09, 197.176}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{88.10499999999999, 
                    198.23399999999998`}, {89.29700000000001, 197.176}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{88.10499999999999, 
                    198.23399999999998`}, {89.29700000000001, 197.176}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{87.312, 
                    198.23399999999998`}, {88.504, 197.176}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{87.312, 
                    198.23399999999998`}, {88.504, 197.176}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{86.52, 
                    198.23399999999998`}, {87.71100000000001, 197.176}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{86.52, 
                    198.23399999999998`}, {87.71100000000001, 197.176}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{85.727, 
                    198.23399999999998`}, {86.91400000000002, 197.176}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{85.727, 
                    198.23399999999998`}, {86.91400000000002, 197.176}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{84.93400000000001, 
                    198.23399999999998`}, {86.121, 197.176}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{84.93400000000001, 
                    198.23399999999998`}, {86.121, 197.176}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{84.141, 
                    198.23399999999998`}, {85.32799999999999, 197.176}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{84.141, 
                    198.23399999999998`}, {85.32799999999999, 197.176}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{83.348, 
                    198.23399999999998`}, {84.535, 197.176}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{83.348, 
                    198.23399999999998`}, {84.535, 197.176}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{82.55499999999999, 
                    198.23399999999998`}, {83.742, 197.176}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{82.55499999999999, 
                    198.23399999999998`}, {83.742, 197.176}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{85.727, 
                    198.23399999999998`}, {86.91400000000002, 197.176}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{85.727, 
                    198.23399999999998`}, {86.91400000000002, 197.176}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{81.762, 
                    198.23399999999998`}, {82.94900000000001, 197.176}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{81.762, 
                    198.23399999999998`}, {82.94900000000001, 197.176}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{80.96900000000001, 
                    198.23399999999998`}, {82.15599999999999, 197.176}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{80.96900000000001, 
                    198.23399999999998`}, {82.15599999999999, 197.176}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{80.17199999999998, 
                    198.23399999999998`}, {81.363, 197.176}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{80.17199999999998, 
                    198.23399999999998`}, {81.363, 197.176}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{79.37899999999999, 
                    198.23399999999998`}, {80.57, 197.176}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{79.37899999999999, 
                    198.23399999999998`}, {80.57, 197.176}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{80.57, 
                    198.23399999999998`}, {79.37899999999999, 197.176}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{80.57, 
                    198.23399999999998`}, {79.37899999999999, 197.176}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{81.363, 
                    198.23399999999998`}, {80.17199999999998, 197.176}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{81.363, 
                    198.23399999999998`}, {80.17199999999998, 197.176}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{82.15599999999999, 
                    198.23399999999998`}, {80.96900000000001, 197.176}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{82.15599999999999, 
                    198.23399999999998`}, {80.96900000000001, 197.176}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{82.94900000000001, 
                    198.23399999999998`}, {81.762, 197.176}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{82.94900000000001, 
                    198.23399999999998`}, {81.762, 197.176}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{83.742, 
                    198.23399999999998`}, {82.55499999999999, 197.176}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{83.742, 
                    198.23399999999998`}, {82.55499999999999, 197.176}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{84.535, 
                    198.23399999999998`}, {83.348, 197.176}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{84.535, 
                    198.23399999999998`}, {83.348, 197.176}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{85.32799999999999, 
                    198.23399999999998`}, {84.141, 197.176}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{85.32799999999999, 
                    198.23399999999998`}, {84.141, 197.176}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{86.121, 
                    198.23399999999998`}, {84.93400000000001, 197.176}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{86.121, 
                    198.23399999999998`}, {84.93400000000001, 197.176}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{86.91400000000002, 
                    198.23399999999998`}, {85.727, 197.176}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{86.91400000000002, 
                    198.23399999999998`}, {85.727, 197.176}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{87.71100000000001, 
                    198.23399999999998`}, {86.52, 197.176}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{87.71100000000001, 
                    198.23399999999998`}, {86.52, 197.176}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{88.504, 
                    198.23399999999998`}, {87.312, 197.176}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{88.504, 
                    198.23399999999998`}, {87.312, 197.176}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{89.29700000000001, 
                    198.23399999999998`}, {88.10499999999999, 197.176}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{89.29700000000001, 
                    198.23399999999998`}, {88.10499999999999, 197.176}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{86.121, 
                    198.23399999999998`}, {84.93400000000001, 197.176}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{86.121, 
                    198.23399999999998`}, {84.93400000000001, 197.176}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{90.09, 
                    198.23399999999998`}, {88.898, 197.176}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{90.09, 
                    198.23399999999998`}, {88.898, 197.176}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{90.883, 
                    198.23399999999998`}, {89.691, 197.176}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{90.883, 
                    198.23399999999998`}, {89.691, 197.176}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{91.67599999999999, 
                    198.23399999999998`}, {90.48400000000001, 197.176}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{91.67599999999999, 
                    198.23399999999998`}, {90.48400000000001, 197.176}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{92.46900000000001, 
                    198.23399999999998`}, {91.277, 197.176}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{92.46900000000001, 
                    198.23399999999998`}, {91.277, 197.176}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{91.277, 192.227}, {
                    92.46900000000001, 191.164}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{91.277, 192.227}, {
                    92.46900000000001, 191.164}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{90.48400000000001, 
                    192.227}, {91.67599999999999, 191.164}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{90.48400000000001, 
                    192.227}, {91.67599999999999, 191.164}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{89.691, 192.227}, {
                    90.883, 191.164}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{89.691, 192.227}, {
                    90.883, 191.164}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{88.898, 192.227}, {90.09,
                     191.164}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{88.898, 192.227}, {90.09,
                     191.164}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{88.10499999999999, 
                    192.227}, {89.29700000000001, 191.164}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{88.10499999999999, 
                    192.227}, {89.29700000000001, 191.164}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{87.312, 192.227}, {
                    88.504, 191.164}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{87.312, 192.227}, {
                    88.504, 191.164}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{86.52, 192.227}, {
                    87.71100000000001, 191.164}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{86.52, 192.227}, {
                    87.71100000000001, 191.164}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{85.727, 192.227}, {
                    86.91400000000002, 191.164}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{85.727, 192.227}, {
                    86.91400000000002, 191.164}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{84.93400000000001, 
                    192.227}, {86.121, 191.164}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{84.93400000000001, 
                    192.227}, {86.121, 191.164}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{84.141, 192.227}, {
                    85.32799999999999, 191.164}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{84.141, 192.227}, {
                    85.32799999999999, 191.164}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{83.348, 192.227}, {
                    84.535, 191.164}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{83.348, 192.227}, {
                    84.535, 191.164}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{82.55499999999999, 
                    192.227}, {83.742, 191.164}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{82.55499999999999, 
                    192.227}, {83.742, 191.164}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{85.727, 192.227}, {
                    86.91400000000002, 191.164}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{85.727, 192.227}, {
                    86.91400000000002, 191.164}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{81.762, 192.227}, {
                    82.94900000000001, 191.164}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{81.762, 192.227}, {
                    82.94900000000001, 191.164}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{80.96900000000001, 
                    192.227}, {82.15599999999999, 191.164}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{80.96900000000001, 
                    192.227}, {82.15599999999999, 191.164}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{80.17199999999998, 
                    192.227}, {81.363, 191.164}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{80.17199999999998, 
                    192.227}, {81.363, 191.164}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{79.37899999999999, 
                    192.227}, {80.57, 191.164}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{79.37899999999999, 
                    192.227}, {80.57, 191.164}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{80.57, 192.227}, {
                    79.37899999999999, 191.164}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{80.57, 192.227}, {
                    79.37899999999999, 191.164}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{81.363, 192.227}, {
                    80.17199999999998, 191.164}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{81.363, 192.227}, {
                    80.17199999999998, 191.164}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{82.15599999999999, 
                    192.227}, {80.96900000000001, 191.164}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{82.15599999999999, 
                    192.227}, {80.96900000000001, 191.164}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{82.94900000000001, 
                    192.227}, {81.762, 191.164}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{82.94900000000001, 
                    192.227}, {81.762, 191.164}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{83.742, 192.227}, {
                    82.55499999999999, 191.164}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{83.742, 192.227}, {
                    82.55499999999999, 191.164}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{84.535, 192.227}, {
                    83.348, 191.164}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{84.535, 192.227}, {
                    83.348, 191.164}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{85.32799999999999, 
                    192.227}, {84.141, 191.164}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{85.32799999999999, 
                    192.227}, {84.141, 191.164}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{86.121, 192.227}, {
                    84.93400000000001, 191.164}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{86.121, 192.227}, {
                    84.93400000000001, 191.164}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{86.91400000000002, 
                    192.227}, {85.727, 191.164}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{86.91400000000002, 
                    192.227}, {85.727, 191.164}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{87.71100000000001, 
                    192.227}, {86.52, 191.164}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{87.71100000000001, 
                    192.227}, {86.52, 191.164}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{88.504, 192.227}, {
                    87.312, 191.164}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{88.504, 192.227}, {
                    87.312, 191.164}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{89.29700000000001, 
                    192.227}, {88.10499999999999, 191.164}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{89.29700000000001, 
                    192.227}, {88.10499999999999, 191.164}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{86.121, 192.227}, {
                    84.93400000000001, 191.164}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{86.121, 192.227}, {
                    84.93400000000001, 191.164}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{90.09, 192.227}, {88.898,
                     191.164}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{90.09, 192.227}, {88.898,
                     191.164}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{90.883, 192.227}, {
                    89.691, 191.164}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{90.883, 192.227}, {
                    89.691, 191.164}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{91.67599999999999, 
                    192.227}, {90.48400000000001, 191.164}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{91.67599999999999, 
                    192.227}, {90.48400000000001, 191.164}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{92.46900000000001, 
                    192.227}, {91.277, 191.164}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{92.46900000000001, 
                    192.227}, {91.277, 191.164}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{50.605000000000004`, 181.15200000000002`}, {
                    31.359, 162.33200000000002`}, {23.148, 159.953}, {27., 
                    158.43800000000002`}, {30.855, 156.92200000000003`}, {
                    43.246, 166.63299999999998`}, {56.145, 179.535}, {69.039, 
                    192.43800000000002`}, {76.938, 203.918}, {73.086, 
                    205.434}, {69.23, 206.953}, {71.07, 201.172}, {
                    50.605000000000004`, 181.15200000000002`}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0004413333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{50.605000000000004`, 181.152}, {31.359, 
                    162.332}, {23.148, 159.95299999999997`}, {27., 158.438}, {
                    30.855, 156.92200000000003`}, {43.246, 
                    166.63299999999998`}, {56.145, 179.535}, {69.039, 
                    192.438}, {76.938, 203.918}, {73.086, 205.434}, {69.23, 
                    206.953}, {71.07, 201.172}, {50.605000000000004`, 
                    181.152}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    34.402, 167.477}, {41.145, 165.707}, {34.800999999999995`,
                     159.695}, {27.66, 157.21899999999997`}, {25.68, 
                    158.281}, {23.695, 159.34}, {29.246, 161.816}, {34.402, 
                    167.477}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    34.402, 167.477}, {41.145, 165.707}, {34.800999999999995`,
                     159.695}, {27.66, 157.219}, {25.68, 158.281}, {23.695, 
                    159.34}, {29.246, 161.816}, {34.402, 167.477}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    34.402, 166.76999999999998`}, {39.956999999999994`, 
                    165.35200000000003`}, {33.773, 159.57}, {27.66, 157.93}, {
                    26.078, 158.63299999999998`}, {24.487999999999996`, 
                    159.34}, {29.379, 161.32800000000003`}, {34.402, 
                    166.76999999999998`}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    34.402, 166.76999999999998`}, {39.956999999999994`, 
                    165.352}, {33.773, 159.57}, {27.66, 157.93}, {26.078, 
                    158.63299999999998`}, {24.487999999999996`, 159.34}, {
                    29.379, 161.32800000000003`}, {34.402, 
                    166.76999999999998`}}}, CurveClosed -> {1}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJ5IGYC4qcXlG7/7PN2UGVrnOq8P81higRLGF+vt8Nx
b/NOxz1pDtcXF9hytXs79B/6qhGzPs3BNG6XJ0+TtwMXSGIVgu+UADRpcZrD
M5B5dd4O3zRi+g/NTXOofKlmyFHj7fB46ewjCjPSHH7VZe0pKYbaNznNYaHr
ts9/S7wdZuQJNR/og6qP8XbYN19K/25PmsObwB1yrd7eDiBrmNrTHHqnAxU6
eDvo31Vha2xNc3Dpznn+WxNqf3Oaw0WQ9VJQ+xrSHHKf/175kcnbofU10KBa
qPwrL4h9VWkOK44BPXrRy2HVx0u+SRVpDmDn7/KC6K+A+meel4MPMDgSKtMc
5hxR2FDU4eUAVJW1pybNQRPoza8VXg4gYxyB9gFdqd2e5gV3jxnI4UleDkUZ
E9/WAN1/GuThWC8HdUOONTJA/27//PdKRaSXw7sae9O4SVD/JXg57CmZLMEC
lDcA+TMV6t42hPlg9wLtaxe7ee57MsJ9MPPA8VOW5mAHYvh6OSwChXNBmgMA
EdfgEA==
                    "], CurveClosed -> {0}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJNIGYCYoO7KmyNS70chJoPnFqYmObwqy5rT8liLweX
7pznv4H8lce8zTsXejlcVLr9sy4pzeHZBSBjnpeDU8LTC0rJaQ6nFrpu+7zW
y8Fyy4myffFpDny6m+a+X+7lkDHxbY09UL8+yPxWL4dvGjH9h1LTHGy5ri8u
yPVyKAAxMqD2BXs5qBtyrJHJgvKNvRz6D33ViMlOc3gTuEOu9bYnnL/t898r
FTsR/MNAqn+RpwPIWNssqHynJ9z8T5d8kwQqPB0KQfyUNIcpEixhfLGeDu9q
7E3jgP6J2+XJw+Tt6VAtss79YVyaQ4r1ff9ec08HmSggKzrN4SnIv3qeDr3T
84SaI9IcFgG9+1fF08EK5N9gqHuFPR1kQer90xz4Qf5n94SEn2eaw+wjChuK
fnhA7HFPc1gOCs+PHhD3OKQ55D7/vfLjIw+HffOl9O8C+VrAYPp6wwNiv3Wa
A8hbXN89IP61hrqHzxMSH1ZpDqdB4S8L9Y9ZmoMmSL8FNHyMEe7xMe90TLCE
xt8/hPlgd770gMSXLdR/TzwcZgC9e8AuzWFPyWQJlmMIPjh8V3o4AG3P2uMA
Dd8ZHhB9NmkOIOPrqhDmg9VnekDiH2i/KDCYq1I8HFpfAyMWyI8AJRw/BB8A
wZYvwA==
                    "], CurveClosed -> {0}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJVIGYCYmn9uypsgZ4OlltOlO2TTnNoF7t57ruzp0MY
n+6muUC+Zkz/oa8cng4ZE9/W2EumOZjG7fLk+eQBVz/niMKGohseEHlZqPoT
Hg6rPl7yTVJIc9j2+e+Vip0eDkLNB04tVE1zWH7M27xzo4eDj3mnY4ImQr5a
ZJ37QzkE/12NvWmcVJrD9cUFtlzbPRzUDTnWyAilObwO3CHXutrDwaU75/lv
wTQIPRNqH0+aQ4r1ff/edg8HoC+CH3NC/VMM1c+W5rASZH+ih8OTpbOPKLCk
OawA8QM9HBa5Am1mSHM4tRDIsPVwAHmT6X+qw2yQ/zSg8n9SHQyAwdUo6uHg
lPD0gtLvVIdnF5Ru//zn7tAKctjPVIciUEC8d4fY9y3V4SJQuu6Wu0MVyH+f
Uh3YG6c6d99xd5iRBwyRd6kOfdOBjAvukPB5mepw+KtGTP8ldweQ8IFHqRD/
XHeHhM+9VEj4vHSH2HM71aEXpPADVP5aKsQ/jB4OaiD7L6U6FIPU8UP9cz7V
IRIUcXIeDsBQvb74RKoDAwgYQOPnaCokPjk8HGSjgDYfTnXIff575cdP7g7f
gM46dBDqnudQ+w8j3A9TDwDzNBH1
                    "], CurveClosed -> {0}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4l91WXtKDrs7qBtyrJHZlerQLnbz3PfN7g7V
IuvcHwL5kyVYwvhq3R3idnnyMO1PdVjkuu3z3xR3CH0g1WEKSJ4Xwb+odPtn
3Ss3h97peULNB6DmPXZz4Lq+uMB2X6oDiOI67uZQlDHxbc3uVAeQNVVb3BxU
2RqnOm9PdeDT3TT3/XI3h1UfL/kmbUl1iLDccqKsz80BaNiphRtTHaT176qw
Nbo5AE0Nfrw21QHoKu32NKj+5akOlS/VDDlioPYtSnUQBZkfAtU/N9WhGGSv
v5uDU8LTC0rTEfzHS2cfUZiQ6gAKG4YAKL8j1WH7579XKiLdHICu2De/DWH+
hENfNWLqUx3A4Zfs5gB2ViXUvXluDiBjGEpSHUxBAdfk5jADFBx5UPe0uDns
my+lfzcH6v42qH9zEP6VjUqxvp+d6gAAl/y3aw==
                    "], 
                    CurveClosed -> {0}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752354166666667], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxVU2lIVUEUfmqYiFlIRYU/TErFFn1Zlpr1lTO3LMVKEgspE0+JmVsSFSJI
gYhoRYZChKhECyEhYRBPkQjbKEwMWwgJNQsSM8EWM5p5c56XfgzcM+dw5tvu
8pyifeTjcDi81IE63uoMtBYn+jdYCDrX/az5AGFR246PZ+vtOjPu3pNTdRZc
ZZeXzMkgtMiOyZnzFg49SA7wTicsi/qwwrfEwtuXP9KHUnm+0EK0uq5U9cm8
S2PlaXb9uyLfVRZjYSoi68JDVe8K8F5VFWth6PrVRyF7CCdGp29NhFp4o/ft
JdyfnOk/vdRCysbqbdn7Cc+bFYB5Fnp2q4tM3udjoatJIcki+FZeSar5IxGv
YHQdJnRq3FPSzOcSNIvAMYnGQsXwKPMZlgh3+t0Jzie8Cn3/q+KdRF2DGigg
bNBE+yQyAte0XysidGg8TyVqdb+YkKzx90iDr4Rw5kuY088lDT9Vu3m/llBb
811qPjdhMK12QELDayokKNZ3Sz9LrNTAj5O2xeH4Jo0eedz/KQ0/hf9TrwL4
V0LLuvUI4aYm5mUZvFm8fy7rkWnXHr/+66fYtUrBQOtOe7+bbxKharFydpLx
g/X9Kk0etrC/g6x3AuvZz3rEEearNeOPeT6W+XVLbM8e6Q2NYX3bmV80QT87
foP7UYTvfak5Cxolbk+oj9UEUVMwOl0t0ad9imS9y9mPCII7z8ckgg8qZuGE
uRpvit1351tI+OvBSM6v097vnguRKNW8ojiPQczHyXr4SAxrf9Z7/BEmP7Ee
fbiO9+RLGH6bCfU6fy8EtMwVSj8te3GnMP9PImFEN9qEyWc8v98ijP6bPHqI
WT31v+y4KGb1dOtdJRCm31/HeMrFLJ+Fmn+ZMPlbS/gHDmu4cA==
                    "], 
                    CurveClosed -> {0}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752354166666667], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}}}, CompressedData["
1:eJxFUltIlEEU/t1i28JCwkRCukhaaiE+SFSYX81EdCMqkIJlEzkDRTeziK0k
sDCrZdWIqKiIsh6KiAqpEJHYpEJBTMLoIiVma7lrubZa2EIz/wz+A+fh48zM
dzlnftmBrWKSZVlJsvJluWTxwN7w+F0OS53FArPzexa4H3FkuasusjwBX9O6
ZFc7x+X9M089zxZYn+zKq+nmqB7c8mxOlsDKae8ayns46kPxRd65AjneulB8
gOPrnaut8zIE1DeBCEfz4Qvpk9MEXshrdTHDlyJQqAgkVrRVUx18SfG5BPzf
sws88n3JjCWPr48TgqrxhaMz8+PfE6M0oaflhlT+izDrwdreY60c7zvGtvVF
CUfV+2aO5Y2vj7QMmv5tjvIiKXyAsH2ZbNSafpggVT+s8HOsLu3vzAyb914H
23ls4BiVNkL9BDu/HJOHxLnKf7pz39ZrcfSpPCRf2801T0aiDF1K/w/z/yeG
g0pPhEArPm8OvmLa70/SPpsYVMxFMUJNmnTWwHBLfpP4TXg6knjrv2LwH8I1
pf8MQ63i/UeIdW0qS/EzbFx6dlVpktB6dzM9D7fAoV3no5U7mc7DY+ZbwrS/
6QI7VD4+pvOZYvZhD5uYjz2vCqb9JwjfbMFM78MYaZ7TDIqmOO7oW1jguZ8x
RFC7aNUz3BuWQmU+7SqfoNHb6+DjqXJwHwgRSVMdYBiqLC70dRPeKLpzxk8H
YZ/c5uGTpt/mYJvvJeE/RYpP9g==
                    "], CurveClosed -> {0}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxdVHtoTmEc/nxmtJbksuQWso1iNrlkvvN9zznuNmS0ZmPW/NyHz8h1PsaW
2zbGhkJjYrls5pJcRnJLQojELBZCriMkrbzv+f22E3+cTr/z/t7n97zP87yn
W/rChBlNXS5XE/Wkq8etnvlv/xypyzRxM27QJrOS0FCHPDnoNyqcOrFln1P7
ThMGpF4YHarqyyUd+tao/hXvI2JaZEn/YULz7OKhW/JM9K3pEZx9gNC2YmTt
yjOCv58Qrb8/lv5SwrUfPads/WYic3bhp6wyQplurJN5xwiXluxoHxRhNfLZ
e71rZWaSxTjlhOV6foaFyJgWxzsdlfWNViOfYVsy1AksPOhe/Tug5p39Xv9o
+XkLfkN1KD5aC9d9C0frHo5N303Qx3NXW8y/kHBE86m1+Lx5hNsHhp/9fsnC
5yzfgNTNhIF6Q6mFp/d+TXyVS+hob7T4POsJHyec65KbInzWiX79nLqd1qet
02+vuwU/IHq9MRF75tbSy8sIelvIWxOdk2nIi8VOnb9rQev1swleDVwj/pD4
89xkvGRHf7tOJARrv6oEb6Kcr1zWE4RfjlPb9FaZrF8S8Vy/8Jsues+R/rmS
n3TJwyLpTxO/VxHe3FfGjDNZ/7WEpMEKyGvip4rFVaVnL/X60dOEhi9Rehfo
/a0Ev4AYt5n0Fwr+V2CR5ldE7PszsN47Cfqzv17q7ZI/t4kqnTOFp1QYn99c
+OQQ9ug8vQPrqfjpuLheApp2INCgFxr94vsAhGth10i/H6xLNqGofVBiy6lg
/I2i12Rnv52XOIjOws8SvpmCFw2+TxkEfU2+RILzP1P8bSf8UiUPnYHnvwNz
qyaJvlEyf5LopfDs9yjh7wH7C/F7CKDt8g0mbAjTSQf70J+wWC9MA+IVnbQY
4TMLqNbzohvug+BHy/nHOrXtv+Jj+xcj/49Q4T+QME8b89rH54sl7ByqBLvo
w261/YpX9NvkY/0s4Rvn43yNJBTr/j9e1ite8njKy/jjRM80p879oAwI9/L+
8bLu8uKhXh8j/O8aPG+EzDtmcL9P9Nlh/Ms/x8DrQypJvSUvqw3WM5z4v3HI
4Hx3kfk3DD5fmPhxx+D72ea//hDCCXuw4AeJnl4D29StmdJU9K/1sJ8uwknd
v9eDUkWj3iV6pnig7bjiJti/oygP3x+F9xdVCpwI
                    "], 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{72.562, 
                    198.137}, {81.10499999999999, 212.879}, {86.773, 
                    225.42600000000002`}, {85.21100000000001, 226.141}, {
                    83.65599999999999, 226.859}, {75.465, 215.477}, {66.926, 
                    200.73399999999998`}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.00034917708333333334`], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{72.562, 
                    198.137}, {81.10499999999999, 212.879}, {86.773, 
                    225.426}, {85.21100000000001, 226.141}, {
                    83.65599999999999, 226.859}, {75.465, 215.477}, {66.926, 
                    200.73399999999998`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{72., 
                    198.395}, {80.23400000000001, 212.617}, {
                    85.91000000000001, 224.625}, {84.66799999999999, 
                    225.19899999999998`}, {83.426, 225.77299999999997`}, {
                    75.727, 214.695}, {67.488, 200.477}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.00030675208333333343`], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{72., 
                    198.39499999999998`}, {80.23400000000001, 212.617}, {
                    85.91000000000001, 224.625}, {84.66799999999999, 
                    225.199}, {83.426, 225.773}, {75.727, 214.695}, {67.488, 
                    200.477}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    70.586, 205.816}, {69.57799999999999, 
                    204.15200000000002`}, {68.52, 202.254}, {67.488, 
                    200.477}, {72., 198.395}, {73.027, 200.176}, {
                    74.15199999999999, 202.047}, {75.09400000000001, 
                    203.738}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0003481479166666667], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    70.586, 205.816}, {69.57799999999999, 204.152}, {68.52, 
                    202.254}, {67.488, 200.477}, {72., 198.39499999999998`}, {
                    73.027, 200.176}, {74.15199999999999, 202.047}, {
                    75.09400000000001, 203.738}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    70.965, 205.242}, {69.965, 203.578}, {69.266, 202.309}, {
                    68.23400000000001, 200.52700000000002`}, {71.617, 
                    198.97299999999998`}, {72.648, 200.75}, {73.406, 
                    201.99200000000002`}, {74.348, 203.684}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0003481479166666667], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    70.965, 205.242}, {69.965, 203.578}, {69.266, 202.309}, {
                    68.23400000000001, 200.527}, {71.617, 198.973}, {72.648, 
                    200.75}, {73.406, 201.992}, {74.348, 203.684}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    73.418, 203.316}, {71.164, 204.35500000000002`}, {69.16, 
                    200.89800000000002`}, {71.41400000000002, 199.859}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002769611943733424], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    73.417948599, 203.315917393}, {71.16350044599997, 
                    204.35527949000002`}, {69.15984768300001, 
                    200.898620309}, {71.414295836, 199.859258212}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{73.422, 203.316}, {
                    69.164, 200.89800000000002`}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0003481479166666667], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{73.422, 203.316}, {
                    69.164, 200.898}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{71.41400000000002, 
                    199.859}, {71.164, 204.35500000000002`}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0003481479166666667], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{71.41400000000002, 
                    199.859}, {71.164, 204.355}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{83.613, 220.91}, {
                    81.35499999999999, 221.94899999999998`}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0003481479166666667], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{83.613, 220.91}, {
                    81.35499999999999, 221.949}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{82.836, 222.934}, {82.91400000000002, 222.625}, {
                    83.262, 222.44899999999998`}, {83.613, 222.539}, {83.965, 
                    222.625}, {84.18799999999999, 222.94899999999998`}, {
                    84.10499999999999, 223.258}, {84.027, 223.562}, {
                    83.67999999999999, 223.742}, {83.32799999999999, 
                    223.65200000000002`}, {82.977, 223.566}, {82.754, 
                    223.242}, {82.836, 222.934}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0004373646025411586], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{82.83573959999997, 222.933795676}, {
                    82.91418599999999, 222.62476281}, {83.26183340000001, 
                    222.448992254}, {83.61338199999999, 222.53949645}, {
                    83.96505909999999, 222.62536242599998`}, {
                    84.18728319999998, 222.94948530200003`}, {84.1058368, 
                    223.25776177800003`}, {84.0275189, 223.56215642400002`}, {
                    83.67974299999999, 223.7425652}, {83.32819439999999, 
                    223.65206100400002`}, {82.97651729999998, 
                    223.566195028}, {82.7542932, 223.24207215200002`}, {
                    82.83573959999997, 222.933795676}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{69.395, 181.15200000000002`}, {88.641, 
                    162.33200000000002`}, {96.85199999999999, 159.953}, {93., 
                    158.43800000000002`}, {89.145, 156.92200000000003`}, {
                    76.754, 166.63299999999998`}, {63.855, 179.535}, {50.961, 
                    192.43800000000002`}, {43.062000000000005`, 203.918}, {
                    46.913999999999994`, 205.434}, {50.77, 206.953}, {48.93, 
                    201.172}, {69.395, 181.15200000000002`}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0004413333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{69.395, 181.152}, {88.641, 162.332}, {
                    96.85199999999999, 159.95299999999997`}, {93., 158.438}, {
                    89.145, 156.92200000000003`}, {76.754, 
                    166.63299999999998`}, {63.855, 179.535}, {50.961, 
                    192.438}, {43.062000000000005`, 203.918}, {
                    46.913999999999994`, 205.434}, {50.77, 206.953}, {48.93, 
                    201.172}, {69.395, 181.152}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    85.598, 167.477}, {78.85499999999999, 165.707}, {85.199, 
                    159.695}, {92.34, 157.21899999999997`}, {94.32, 
                    158.281}, {96.30499999999999, 159.34}, {90.754, 
                    161.816}, {85.598, 167.477}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    85.598, 167.477}, {78.85499999999999, 165.707}, {85.199, 
                    159.695}, {92.34, 157.219}, {94.32, 158.281}, {
                    96.30499999999999, 159.34}, {90.754, 161.816}, {85.598, 
                    167.477}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    85.598, 166.76999999999998`}, {80.043, 
                    165.35200000000003`}, {86.227, 159.57}, {92.34, 157.93}, {
                    93.922, 158.63299999999998`}, {95.512, 159.34}, {90.621, 
                    161.32800000000003`}, {85.598, 166.76999999999998`}}}]}, {
                   
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}}}, {{{
                    85.598, 166.76999999999998`}, {80.043, 165.352}, {86.227, 
                    159.57}, {92.34, 157.93}, {93.922, 158.63299999999998`}, {
                    95.512, 159.34}, {90.621, 161.32800000000003`}, {85.598, 
                    166.76999999999998`}}}, CurveClosed -> {1}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJ5IGYC4t7peULNFgEOqmyNU533pzls+/z3SoVlgMNx
b/NOxz1pDqLr3B9W2QQ49B/6qhGzPs3h2QWl2z/tAhy4ri8usF2F4DslPL2g
tDjNAWyeQ4DDN42Y/kNz0xxcunOe/3YMcHi8dPYRhRlpDs0HTi10dYPaNznN
Qf+uCluja4DDDKC2A31Q9YEBDvvmS+nf7Ulz4AbZExXgELfLk4epPc3BasuJ
sn3xARB9rWkOsSDxbKj9zWkQc4qg9jWkOXjxMGm31wU4tL4O3CFXm+YAct6B
Lqh9VWkOa2SiUqynBzis+njJN6kCqn8RVH8F1D8bAhx8gMGRUJnmsHnu++XH
dgc43P5Zl7WnJs0BZGzr4QCHY6DwAtoHFj+DcA84fM4FOBRlTHxbA3S/NMjh
FwMc1A051sgA/QsOh8sBDu9q7E3jJkH9dz7AYU/JZAkWoHwmUJv9Wah72xDm
g90LtG8vSN05hPtg5oHjpyzN4WGVyDr3mwEOi1yBMVuQ5gAAXi7g/Q==
                    
                    "], CurveClosed -> {0}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJNIGYC4syJb2vs1wY4CDUfOLUwMc0BRLmuC3Bw6c55
/hvIXyMTlWK9PsDhotLtn3VJaQ690/OEmjcEODglPL2glJzmIK1/V4VtZYCD
5ZYTZfvi0xwqXqoZcqwJcMgAmQvUDzZ/b4DDN42Y/kOpaQ4Pq0TWuZ8McCiw
5bq+OANq37UAB3WgLpksKP9ZgEP/oa8aMdlpDkBVBbZCgXC+KlvjVGdlBF++
9XXgDr1AiLosqLx1INz8drGb5747BzoUgvgpaQ7bPv+9UhEY6PCuxt40Duif
SyB/RQU6VAOd9TAuzcEvSSDCMiXQAeTt+9FQ/2YEQuiINAcDoHcbcwMdrED+
DYa6tyzQQRak3j/NoRLk/5pASPh5pjlsmvt++bHmQIe4XZ48TO7Q8GyHusch
zcGLh0m7vS/QYd98Kf27QD7QN3Ktk6H2W6c5gJxV1QL1rzXUPRWBkPiwgoZ/
IdQ/ZlD9yVD1xgj3+Jh3OiZYQvU3IMyPBbmrOxASX7ZQ//UGOswAKjtgl+aw
yBUYYnMQfBVQ+K4OdADanrXHARq+mwMh6mzSIOoOIcwHqz8dCIl/oP1g+myg
Ayja5ID8kMdLZx+5geADAA+pGxs=
                    "], CurveClosed -> {0}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJVIGYC4uKMiW9rwgMdLLecKNsnneawt2SyBEtcoEMY
n+6muUD+m8Adcq3VgQ4gZfaSaQ5PLyjd/tmGUL9p7vvlxyZD5WWh6mcHOqz6
eMk3SSHNQZWtcarz4kAHoeYDpxaqpjmskYlKsV4e6OBj3umYoImQrxZZ5/5Q
DsF/V2NvGieV5gASrloS6KBuyLFGRijNgev64gLbVYEOLt05z38LpjnE7/Lk
YdoMtY8nzcE/SSDCck+gw81z34Mfc0L9cwyqnw1q//lAhydLZx9RYIHyrwc6
LHLd9vkvQ5qDtP5dFbaHgQ5xIHP/p0L89xoq/ycV4s+vgQ5OCcCQ+J3q0Ds9
T6iZIcih9TXQ4z9THY55Az3GEQSx71uqwwyg9AGhIIcqkEc+pTrUAr21SzAI
Iv4uFRKO4kGQ8HmZ6iAHMkgsyAFk7IFHqQ5+IP+IBEHC516qgwoofLiDHIpA
DrkN1c8Olb+WCvHP/0AHNZD9l6Du+QH1z/lUh5DHQI9/CHQosAWG5IlUh/8g
8BwaP0dTHTaD/Ps70EEWaMz9w6kOQF3a7WxBDt80YvoPHYS6hwdq/2GE+2Hq
AZ/jAt4=
                    "], CurveClosed -> {0}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4uYDpxa6ygU5qBtyrJHZleqwt2SyBItakEO1
yDr3h0D+ts9/r1Q4BjnE7fLkYdqf6mBwV4Wt0TfIYZErUOYAVL4SwZ+eJ9R8
oCvIoRfMgJrXF+TAdX1xge2+VAdRoLFVc4IcijImvq3ZnerwTSOm/9DSIAdV
tsapzttTHSpeqgFdEuSw6uMl36QtqQ4hj5fOPrIjyEEI5NCNqQ7FIH37gxxu
nvse/HhtqsPtn3VZe85A9S9PdXDpznn++yLUvkVQ869C9c9NdTjmbd7peCPI
wSnh6QWl6Qg+yBqFCakO/0HgOpTfkQox93KQw5YTZfvmtyHMn3Doq0ZMfaoD
OPzOBTnog8KlEureE0EODCBQkurw7ILS7Z/7ghxmgIIjD+qevUEO++ZL6d/N
SXW4A3L/Hqh/cxD+lY1Ksb6fneoAABBoy4o=
                    "], 
                    CurveClosed -> {0}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752354166666667], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxVk1tIVVEQho8XzMpCRCXyPGiUillHsyyPmb+ZlKVd9pRomNnBKTFRuyAm
dkB8EAmLiKgIEYkoQnwwuyAqFaXSQ4QEGSYhWtFDRQiFdLG19prYdGDBmT2z
Z83/zb/jfLUWB7lcrgB1oE6gOpE926ca+yxEtDx63lXC+J5YeuHJPSfeP33z
+tOHFgZOX1oWXMRImVwZ0jxooaw/PyyQGKcqL35uGrHw5sUPmi6U+lHL1Kl4
eNfGtpxxJ9Zt8z5Y5h4VT8z5qwZmLOjXYvcydoYFrm79YmFc99vHWBXSfDl3
1kKBalN+gBHjUY3mLNO3WPr9sTDUudwzWco4m72hrD+A4O0brR86zOjKuz/7
O5hMfQVDRa8aFhKu1iiFR0XPEkJCami3u4rN8wjC+SvqTzXj/csVE3PRhKKl
a3o7amWeGEK7ztcx3ur53WTmO8HYdq764884MvpUrPFkR5HRqep3+8KLMyIJ
erzOGkZvx9dbw4vJ9D3OmNe/BWR4VEo+iIw+Nb99r4tM3yOMbvfBisx5y8yr
9O/R/X8Jj2In/rev//IFTlyXtej1jR1Of1tvLmNQ7z1E5gejSfNV/Gw/bGGM
aK7hwjuTodfTHCU8MhhnPsWnhrqlPp217VyuWMLWckU2TfjGi74URoOuT5a8
h9EarZyVRrjzbazQl8xGRyZhTL3mTxLeObKPRIbt5wKCxvIuQfxQ4uTtvRwi
KLV1WUni32NOf1tHLeGkfq7uz9d+rBc9qcLDT5jR+1kv+2kR/6QLnzaJveKv
dtG3Wfx3jaBl+xW/qUY1cReZ7ydL+N8Wf3rle+gR/puEx12Hp+2XBw5Pm/cA
IV7fv070P3b02Pqfif/WMv4C+lG0GA==
                    "], 
                    CurveClosed -> {0}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752354166666667], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}}}, CompressedData["
1:eJxFUl1IlEEUXbfYNC0sQqIWM8kSrJaIEDfNU9sPaZE5Q/RgIcsdiIgyih5K
BBEVkTKpKIolKkLo78EiRExCw6IHSR+KDB8Wk402tTK1MLG530x+A/Nw5sy9
99xz7+rwqVI1z+PxJOgb0Ner75H2vSnehwIePusVzhxrHqlsEcjyVV8L5Sj0
Z376U3VT4MbJpTUv1ypodLzjqkBt/GBbepZC9PyyJ3uaBS53TWSXrVLg59pG
gc/3b73K8CtUFm452t4g0HH2yvL5aQrpHFhn66UqDL/TBTQODK7xVSe5+DrX
8yqEGk/EpnX8ocUbWiPThOCzN+c6mwT4W9UkzenpvL0iMPidMJld1tQVEfjY
OyWGRgg7Of6OMHFxyz8WqChY+OHeF4Ic0kLbLB8jtEbGWnq6BXaUayUxG9/n
YsePAWHyDBMc/+LWD42d/sfd/07eWQEuk6HrreRGk6TJ89XmXyJxmvV8IxwI
px7O80vT7xgZ3zMlNFtR8JPwgn3cKHF31/PxmV9k5rTZ4t+Ep6x/q8QlNvAv
oT5NOxGS2JfbsL08QRm9xdLMw6fwulgTJdL4kWjnK6Xpb5Ey/mje6WOBQh/r
LpJz83HmtVua/mcIF5mANPswRUZXvgSvVeGEq2/dpsRH/lHCLJ9ciQc/+veH
//uTZ/VGXXxBr1l0gJDMPgQlRnmx3lt/grafXkJRijenfpvl37rYqddD+AcX
9FjD
                    "], CurveClosed -> {0}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxdVAtMjlEY/qXFiLnPXCKTy7Bqc1lZeisKUaPvnDUjlte9UTEZ+UlaVKLc
2loqhiGtyczcNRObGWXulyXE3NaINXM55ztPfZtv+/bt/c57nvd5n+c9xzdx
zdwlHV0uVwf1JqrXQ70zvD3GZEcKuhk9aWdYFVNb3OXRkeSQSieW3cedKalm
entv2LNWFV8pHeD/QuVPzU1q+hWG/GNMm0MnJFwIEuT/YrhXRjnTj1Hzd9f4
Ab+MaXnB5/TQvsg/zOST9XHOeS9BqXrhOFPFoHk8uRPqnWI6PO3ct9+frHY+
Z0q+Hr9Zb1GAxj/NFKHr37ZoZGDnikEnmar1+kWrnc+CC6qDUxbdV7Tdqp6f
V8b+iCMWJYeoDMXnr34OWnSyuW52YhGbvELL8C8An92W6TePaaBeKLfoS7pq
NIfpndaj0qInd3/GNWYxrdV9XLVMP5lseNSBzzbo986JbX1anHwb7w/w3Uwr
tF7dBAWfvbX+ShpTn8qoho3eggYrWq/WOvGug6t7ZS5natio/vSEPwx/VGzj
zXP0t2MJv3yBF4f+RmN9LviFOLGtT7gw+sUzBWleUeC3GHpHI38l00w9PzGY
hxQ2ebHwexMb3vHC6L+VyWo8WnxjkTB1lZ5qOnyyVgnS20pzUC8N+PnQZzPy
C7CeLShF89vHVKTgrxVi3g5AnwzEhUxD9Py5BV1at7e/p8KLTewRH5QOPtsx
b7nQU/Fz6WePIG2T2w29Toh2v2y9rwszZ1swX7XC/M9gUtP8YMN94O9gWqj1
qnf2d9W8ngpK0P83gd9L8E0FXhPOUxLThg8jAjt/Emb+l8LfFvBLQL/Ngp63
uldesqDve9S3oFcT5mc6+DfAX4Lfr4XBDWK6rHV6KChf549nqtU87gmapT6L
AsHnjqBnul5A23kAfgD6f+LE9vc9/AvEPLaC/0ScFy9p+guG3j2l8XUKm3tg
sDT6hWMexkkzX1HID5NGr1k4/3HS4MdAz2VObN9H67E/Fn5vlVSn12ey6SsP
9SKh937kh7LxrVi287fP8yFJb5TsQ8ei3zJp9vnhfj0gzXz7wO989NcP95+q
Z5/P3v/ld4GfZcD3hB9VkvbUtIya3xH+1krjpwv5j6XBdUGfD5I0rWseuE++
S3N+FN4/DLG/mg==
                    "], CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{47.438, 
                    198.137}, {38.895, 212.879}, {33.227000000000004`, 
                    225.42600000000002`}, {34.789, 226.141}, {
                    36.343999999999994`, 226.859}, {44.535000000000004`, 
                    215.477}, {53.074, 200.73399999999998`}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.00034917708333333334`], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{47.438, 
                    198.137}, {38.895, 212.879}, {33.227000000000004`, 
                    225.426}, {34.789, 226.141}, {36.343999999999994`, 
                    226.859}, {44.535000000000004`, 215.477}, {53.074, 
                    200.73399999999998`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{48., 
                    198.395}, {39.766000000000005`, 212.617}, {34.09, 
                    224.625}, {35.332, 225.19899999999998`}, {36.574, 
                    225.77299999999997`}, {44.273, 214.695}, {52.512, 
                    200.477}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.00030675208333333343`], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{48., 
                    198.39499999999998`}, {39.766000000000005`, 212.617}, {
                    34.09, 224.625}, {35.332, 225.199}, {36.574, 225.773}, {
                    44.273, 214.695}, {52.512, 200.477}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    49.413999999999994`, 205.816}, {50.422000000000004`, 
                    204.15200000000002`}, {51.48, 202.254}, {52.512, 
                    200.477}, {48., 198.395}, {46.973, 200.176}, {45.848, 
                    202.047}, {44.906, 203.738}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0003481479166666667], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    49.413999999999994`, 205.816}, {50.422000000000004`, 
                    204.152}, {51.48, 202.254}, {52.512, 200.477}, {48., 
                    198.39499999999998`}, {46.973, 200.176}, {45.848, 
                    202.047}, {44.906, 203.738}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    49.035000000000004`, 205.242}, {50.035000000000004`, 
                    203.578}, {50.734, 202.309}, {51.766000000000005`, 
                    200.52700000000002`}, {48.382999999999996`, 
                    198.97299999999998`}, {47.352, 200.75}, {46.594, 
                    201.99200000000002`}, {45.652, 203.684}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0003481479166666667], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    49.035000000000004`, 205.242}, {50.035000000000004`, 
                    203.578}, {50.734, 202.309}, {51.766000000000005`, 
                    200.527}, {48.382999999999996`, 198.973}, {47.352, 
                    200.75}, {46.594, 201.992}, {45.652, 203.684}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    46.582, 203.316}, {48.836, 204.35500000000002`}, {
                    50.839999999999996`, 200.89800000000002`}, {48.586, 
                    199.859}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002769611943733424], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    46.58167737800001, 203.316123686}, {48.83612553100003, 
                    204.355485783}, {50.839778294, 200.898826602}, {
                    48.58533014099999, 199.85946450500003`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{46.578, 203.316}, {
                    50.836, 200.89800000000002`}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0003481479166666667], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{46.578, 203.316}, {
                    50.836, 200.898}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{48.586, 199.859}, {
                    48.836, 204.35500000000002`}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0003481479166666667], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{48.586, 199.859}, {
                    48.836, 204.355}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{36.38699999999999, 
                    220.91}, {38.645, 221.94899999999998`}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0003481479166666667], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{36.38699999999999, 
                    220.91}, {38.645, 221.949}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{37.164, 222.934}, {37.086, 222.625}, {
                    36.73800000000001, 222.44899999999998`}, {
                    36.38699999999999, 222.539}, {36.035000000000004`, 
                    222.625}, {35.812, 222.94899999999998`}, {35.895, 
                    223.258}, {35.973, 223.562}, {36.32, 223.742}, {
                    36.672000000000004`, 223.65200000000002`}, {37.023, 
                    223.566}, {37.246, 223.242}, {37.164, 222.934}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0004373646025411586], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{37.16445770000001, 222.933479778}, {
                    37.08623700000002, 222.62532413000002`}, {36.7385896, 
                    222.449553574}, {36.3868153, 222.539180552}, {
                    36.03513820000002, 222.625046528}, {35.8129141, 
                    222.949169404}, {35.894360500000005`, 223.25744588}, {
                    35.9729041, 223.562717744}, {36.320454300000016`, 
                    223.74224930200003`}, {36.672228600000004`, 
                    223.652622324}, {37.02390570000001, 223.566756348}, {
                    37.24612980000001, 223.242633472}, {37.16445770000001, 
                    222.933479778}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}}}, {{{54.105000000000004`, 206.016}, {
                    54.105000000000004`, 193.641}, {54.176, 188.977}, {
                    53.266000000000005`, 188.336}, {52.398, 
                    187.65200000000002`}, {28.324, 188.336}, {28.324, 
                    184.80100000000002`}, {28.324, 181.266}, {48.156, 
                    177.727}, {54.105000000000004`, 177.727}, {
                    62.035000000000004`, 177.727}, {66.004, 181.266}, {66.004,
                     188.336}, {66.004, 206.016}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0003178145833333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}}}, {{{54.105000000000004`, 
                    206.01600000000002`}, {54.105000000000004`, 
                    193.64100000000002`}, {54.176, 188.977}, {
                    53.266000000000005`, 188.336}, {52.398, 187.652}, {28.324,
                     188.336}, {28.324, 184.801}, {28.324, 181.266}, {48.156, 
                    177.727}, {54.105000000000004`, 177.727}, {
                    62.035000000000004`, 177.727}, {66.004, 181.266}, {66.004,
                     188.336}, {66.004, 206.01600000000002`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{54.105000000000004`, 202.48000000000002`}, {
                    54.105000000000004`, 200.71099999999998`}, {58.07, 
                    200.125}, {62.035000000000004`, 200.125}, {66.004, 
                    200.71099999999998`}, {66.004, 202.48000000000002`}, {
                    62.035000000000004`, 201.89100000000002`}, {58.07, 
                    201.89100000000002`}, {54.105000000000004`, 
                    202.48000000000002`}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{54.105000000000004`, 202.48}, {
                    54.105000000000004`, 200.711}, {58.07, 200.125}, {
                    62.035000000000004`, 200.125}, {66.004, 200.711}, {66.004,
                     202.48}, {62.035000000000004`, 201.891}, {58.07, 
                    201.891}, {54.105000000000004`, 202.48}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{54.105000000000004`, 206.016}, {
                    54.105000000000004`, 204.25}, {58.07, 203.66}, {
                    62.035000000000004`, 203.66}, {66.004, 204.25}, {66.004, 
                    206.016}, {62.035000000000004`, 205.42600000000002`}, {
                    58.07, 205.42600000000002`}, {54.105000000000004`, 
                    206.016}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{54.105000000000004`, 206.01600000000002`}, {
                    54.105000000000004`, 204.25}, {58.07, 203.66}, {
                    62.035000000000004`, 203.66}, {66.004, 204.25}, {66.004, 
                    206.01600000000002`}, {62.035000000000004`, 205.426}, {
                    58.07, 205.426}, {54.105000000000004`, 
                    206.01600000000002`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{54.105000000000004`, 204.25}, {
                    54.105000000000004`, 202.48000000000002`}, {58.07, 
                    201.89100000000002`}, {62.035000000000004`, 
                    201.89100000000002`}, {66.004, 202.48000000000002`}, {
                    66.004, 204.25}, {62.035000000000004`, 203.66}, {58.07, 
                    203.66}, {54.105000000000004`, 204.25}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{54.105000000000004`, 204.25}, {
                    54.105000000000004`, 202.48}, {58.07, 201.891}, {
                    62.035000000000004`, 201.891}, {66.004, 202.48}, {66.004, 
                    204.25}, {62.035000000000004`, 203.66}, {58.07, 203.66}, {
                    54.105000000000004`, 204.25}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{54.105000000000004`, 200.71099999999998`}, {
                    54.105000000000004`, 198.945}, {58.07, 
                    198.35500000000002`}, {62.035000000000004`, 
                    198.35500000000002`}, {66.004, 198.945}, {66.004, 
                    200.71099999999998`}, {62.035000000000004`, 200.125}, {
                    58.07, 200.125}, {54.105000000000004`, 
                    200.71099999999998`}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{54.105000000000004`, 200.711}, {
                    54.105000000000004`, 198.945}, {58.07, 198.355}, {
                    62.035000000000004`, 198.355}, {66.004, 198.945}, {66.004,
                     200.711}, {62.035000000000004`, 200.125}, {58.07, 
                    200.125}, {54.105000000000004`, 200.711}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{55.188, 203.242}, {55.188, 203.031}, {54.945, 
                    202.863}, {54.645, 202.863}, {54.348, 202.863}, {
                    54.105000000000004`, 203.031}, {54.105000000000004`, 
                    203.242}, {54.105000000000004`, 203.453}, {54.348, 
                    203.625}, {54.645, 203.625}, {54.945, 203.625}, {55.188, 
                    203.453}, {55.188, 203.242}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.00027523230299006575`], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{55.188, 203.24234895299998`}, {55.188, 
                    203.03123184700002`}, {54.945, 202.863372589}, {54.645, 
                    202.863372589}, {54.348, 202.863372589}, {
                    54.105000000000004`, 203.03123184700002`}, {
                    54.105000000000004`, 203.24234895299998`}, {
                    54.105000000000004`, 203.45323096200002`}, {54.348, 
                    203.625086869}, {54.645, 203.625086869}, {54.945, 
                    203.625086869}, {55.188, 203.45323096200002`}, {55.188, 
                    203.24234895299998`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{57.348, 203.055}, {57.348, 202.844}, {
                    57.105000000000004`, 202.672}, {56.809, 202.672}, {56.508,
                     202.672}, {56.266000000000005`, 202.844}, {
                    56.266000000000005`, 203.055}, {56.266000000000005`, 
                    203.262}, {56.508, 203.434}, {56.809, 203.434}, {
                    57.105000000000004`, 203.434}, {57.348, 203.262}, {57.348,
                     203.055}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.00027523230299006575`], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{57.348, 203.054741547}, {57.348, 
                    202.843859538}, {57.105000000000004`, 202.672003631}, {
                    56.809, 202.672003631}, {56.508, 202.672003631}, {
                    56.266000000000005`, 202.843859538}, {56.266000000000005`,
                     203.054741547}, {56.266000000000005`, 203.261862004}, {
                    56.508, 203.43371791100003`}, {56.809, 
                    203.43371791100003`}, {57.105000000000004`, 
                    203.43371791100003`}, {57.348, 203.261862004}, {57.348, 
                    203.054741547}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{59.512, 202.863}, {59.512, 
                    202.65200000000002`}, {59.27, 202.48000000000002`}, {
                    58.973, 202.48000000000002`}, {58.672000000000004`, 
                    202.48000000000002`}, {58.43, 202.65200000000002`}, {
                    58.43, 202.863}, {58.43, 203.07399999999998`}, {
                    58.672000000000004`, 203.242}, {58.973, 203.242}, {59.27, 
                    203.242}, {59.512, 203.07399999999998`}, {59.512, 
                    202.863}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752377784678158], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{59.512, 202.863295456}, {59.512, 
                    202.652414344}, {59.27, 202.48032407200003`}, {58.973, 
                    202.48032407200003`}, {58.672000000000004`, 
                    202.48032407200003`}, {58.43, 202.652414344}, {58.43, 
                    202.863295456}, {58.43, 203.07417656799998`}, {
                    58.672000000000004`, 203.242035112}, {58.973, 
                    203.242035112}, {59.27, 203.242035112}, {59.512, 
                    203.07417656799998`}, {59.512, 202.863295456}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{61.676, 202.863}, {61.676, 
                    202.65200000000002`}, {61.434, 202.48000000000002`}, {
                    61.137, 202.48000000000002`}, {60.836, 
                    202.48000000000002`}, {60.594, 202.65200000000002`}, {
                    60.594, 202.863}, {60.594, 203.07399999999998`}, {60.836, 
                    203.242}, {61.137, 203.242}, {61.434, 203.242}, {61.676, 
                    203.07399999999998`}, {61.676, 202.863}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752377784678158], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{61.676, 202.863295456}, {61.676, 
                    202.652414344}, {61.434, 202.48032407200003`}, {61.137, 
                    202.48032407200003`}, {60.836, 202.48032407200003`}, {
                    60.594, 202.652414344}, {60.594, 202.863295456}, {60.594, 
                    203.07417656799998`}, {60.836, 203.242035112}, {61.137, 
                    203.242035112}, {61.434, 203.242035112}, {61.676, 
                    203.07417656799998`}, {61.676, 202.863295456}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{63.839999999999996`, 203.055}, {
                    63.839999999999996`, 202.844}, {63.598000000000006`, 
                    202.672}, {63.297000000000004`, 202.672}, {63., 202.672}, 
                    {62.758, 202.844}, {62.758, 203.055}, {62.758, 203.262}, {
                    63., 203.434}, {63.297000000000004`, 203.434}, {
                    63.598000000000006`, 203.434}, {63.839999999999996`, 
                    203.262}, {63.839999999999996`, 203.055}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.00027523230299006575`], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{63.839999999999996`, 203.054741547}, {
                    63.839999999999996`, 202.843859538}, {63.598000000000006`,
                     202.672003631}, {63.297000000000004`, 202.672003631}, {
                    63., 202.672003631}, {62.758, 202.843859538}, {62.758, 
                    203.054741547}, {62.758, 203.261862004}, {63., 
                    203.43371791100003`}, {63.297000000000004`, 
                    203.43371791100003`}, {63.598000000000006`, 
                    203.43371791100003`}, {63.839999999999996`, 
                    203.261862004}, {63.839999999999996`, 203.054741547}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{66.004, 203.242}, {66.004, 203.031}, {65.762, 
                    202.863}, {65.46100000000001, 202.863}, {65.164, 
                    202.863}, {64.922, 203.031}, {64.922, 203.242}, {64.922, 
                    203.453}, {65.164, 203.625}, {65.46100000000001, 
                    203.625}, {65.762, 203.625}, {66.004, 203.453}, {66.004, 
                    203.242}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.00027523230299006575`], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{66.004, 203.24234895299998`}, {66.004, 
                    203.03123184700002`}, {65.762, 202.863372589}, {
                    65.46100000000001, 202.863372589}, {65.164, 
                    202.863372589}, {64.922, 203.03123184700002`}, {64.922, 
                    203.24234895299998`}, {64.922, 203.45323096200002`}, {
                    65.164, 203.625086869}, {65.46100000000001, 
                    203.625086869}, {65.762, 203.625086869}, {66.004, 
                    203.45323096200002`}, {66.004, 203.24234895299998`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{54.105000000000004`, 
                    197.176}, {66.004, 187.629}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{54.105000000000004`, 
                    197.176}, {66.004, 187.62900000000002`}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{55.293000000000006`, 
                    197.176}, {66.004, 188.691}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{55.293000000000006`, 
                    197.176}, {66.004, 188.691}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{56.879, 196.824}, {
                    66.004, 189.754}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{56.879, 196.824}, {
                    66.004, 189.754}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{58.07, 196.824}, {66.004,
                     190.812}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{58.07, 196.824}, {66.004,
                     190.812}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{59.26200000000001, 
                    196.824}, {66.004, 191.871}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{59.26200000000001, 
                    196.824}, {66.004, 191.87099999999998`}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{60.449, 196.824}, {
                    66.004, 192.934}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{60.449, 196.824}, {
                    66.004, 192.934}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{61.641, 196.824}, {
                    66.004, 193.996}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{61.641, 196.824}, {
                    66.004, 193.996}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{62.828, 196.824}, {
                    66.004, 194.69899999999998`}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{62.828, 196.824}, {
                    66.004, 194.699}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{64.02, 196.824}, {66.004,
                     195.406}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{64.02, 196.824}, {66.004,
                     195.406}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{65.20700000000001, 
                    196.824}, {66.004, 196.117}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{65.20700000000001, 
                    196.824}, {66.004, 196.11700000000002`}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{54.105000000000004`, 
                    196.117}, {66.004, 186.566}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{54.105000000000004`, 
                    196.11700000000002`}, {66.004, 186.566}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{66.004, 197.176}, {
                    52.913999999999994`, 186.566}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{66.004, 197.176}, {
                    52.913999999999994`, 186.566}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{64.812, 197.176}, {
                    53.312, 187.984}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{64.812, 197.176}, {
                    53.312, 187.984}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{63.227000000000004`, 
                    196.824}, {54.105000000000004`, 189.754}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{63.227000000000004`, 
                    196.824}, {54.105000000000004`, 189.754}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{62.035000000000004`, 
                    196.824}, {54.105000000000004`, 190.812}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{62.035000000000004`, 
                    196.824}, {54.105000000000004`, 190.812}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{60.848, 196.824}, {
                    54.105000000000004`, 191.871}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{60.848, 196.824}, {
                    54.105000000000004`, 191.87099999999998`}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{59.656, 196.824}, {
                    54.105000000000004`, 192.934}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{59.656, 196.824}, {
                    54.105000000000004`, 192.934}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{58.469, 196.824}, {
                    54.105000000000004`, 193.996}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{58.469, 196.824}, {
                    54.105000000000004`, 193.996}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{57.277, 196.824}, {
                    54.105000000000004`, 194.69899999999998`}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{57.277, 196.824}, {
                    54.105000000000004`, 194.699}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{56.09, 196.824}, {
                    54.105000000000004`, 195.406}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{56.09, 196.824}, {
                    54.105000000000004`, 195.406}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{54.895, 196.824}, {
                    54.105000000000004`, 196.117}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{54.895, 196.824}, {
                    54.105000000000004`, 196.11700000000002`}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{66.004, 196.117}, {
                    52.913999999999994`, 185.508}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{66.004, 
                    196.11700000000002`}, {52.913999999999994`, 
                    185.50799999999998`}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{66.004, 195.055}, {
                    52.913999999999994`, 184.44899999999998`}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{66.004, 195.055}, {
                    52.913999999999994`, 184.449}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{66.004, 193.996}, {
                    52.913999999999994`, 183.383}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{66.004, 193.996}, {
                    52.913999999999994`, 183.383}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{66.004, 192.934}, {
                    52.913999999999994`, 182.324}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{66.004, 192.934}, {
                    52.913999999999994`, 182.324}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{66.004, 191.871}, {
                    52.913999999999994`, 181.266}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{66.004, 
                    191.87099999999998`}, {52.913999999999994`, 181.266}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{66.004, 190.812}, {
                    52.913999999999994`, 180.20299999999997`}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{66.004, 190.812}, {
                    52.913999999999994`, 180.203}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{66.004, 189.754}, {
                    52.913999999999994`, 179.14499999999998`}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{66.004, 189.754}, {
                    52.913999999999994`, 179.145}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{66.004, 
                    188.68800000000002`}, {52.913999999999994`, 178.078}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{66.004, 188.688}, {
                    52.913999999999994`, 178.078}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{66.004, 187.629}, {
                    53.707, 177.727}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{66.004, 
                    187.62900000000002`}, {53.707, 177.727}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{66.004, 186.566}, {
                    54.895, 177.727}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{66.004, 186.566}, {
                    54.895, 177.727}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{65.60499999999999, 
                    185.15200000000002`}, {56.879, 178.078}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{65.60499999999999, 
                    185.152}, {56.879, 178.078}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{65.20700000000001, 
                    183.738}, {58.07, 178.078}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{65.20700000000001, 
                    183.738}, {58.07, 178.078}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{64.41400000000002, 
                    181.97299999999998`}, {60.848, 179.14499999999998`}}}]}, {
                   
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{64.41400000000002, 
                    181.973}, {60.848, 179.145}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{54.105000000000004`, 
                    195.055}, {65.60499999999999, 185.859}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{54.105000000000004`, 
                    195.055}, {65.60499999999999, 185.859}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{54.105000000000004`, 
                    193.996}, {65.60499999999999, 184.80100000000002`}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{54.105000000000004`, 
                    193.996}, {65.60499999999999, 184.801}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{54.105000000000004`, 
                    192.934}, {65.20700000000001, 184.094}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{54.105000000000004`, 
                    192.934}, {65.20700000000001, 184.094}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{54.105000000000004`, 
                    191.871}, {65.20700000000001, 183.031}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{54.105000000000004`, 
                    191.87099999999998`}, {65.20700000000001, 183.031}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{54.105000000000004`, 
                    190.812}, {64.812, 182.324}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{54.105000000000004`, 
                    190.812}, {64.812, 182.324}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{53.707, 190.105}, {
                    64.41400000000002, 181.617}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{53.707, 190.105}, {
                    64.41400000000002, 181.61700000000002`}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{53.707, 
                    189.04299999999998`}, {63.62500000000001, 181.266}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{53.707, 189.043}, {
                    63.62500000000001, 181.266}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{53.312, 188.336}, {
                    63.227000000000004`, 180.555}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{53.312, 188.336}, {
                    63.227000000000004`, 180.555}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
                    187.629}, {62.434, 180.20299999999997`}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
                    187.62900000000002`}, {62.434, 180.203}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
                    186.566}, {62.035000000000004`, 179.496}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
                    186.566}, {62.035000000000004`, 179.496}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
                    185.508}, {60.848, 179.14499999999998`}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
                    185.50799999999998`}, {60.848, 179.145}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{54.105000000000004`, 198.945}, {
                    54.105000000000004`, 197.176}, {58.07, 196.59}, {
                    62.035000000000004`, 196.59}, {66.004, 197.176}, {66.004, 
                    198.945}, {62.035000000000004`, 198.35500000000002`}, {
                    58.07, 198.35500000000002`}, {54.105000000000004`, 
                    198.945}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{54.105000000000004`, 198.945}, {
                    54.105000000000004`, 197.176}, {58.07, 196.59}, {
                    62.035000000000004`, 196.59}, {66.004, 197.176}, {66.004, 
                    198.945}, {62.035000000000004`, 198.355}, {58.07, 
                    198.355}, {54.105000000000004`, 198.945}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
                    184.44899999999998`}, {60.050999999999995`, 178.789}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
                    184.449}, {60.050999999999995`, 178.789}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
                    183.383}, {59.26200000000001, 178.43800000000002`}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
                    183.383}, {59.26200000000001, 178.438}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
                    182.324}, {58.469, 178.078}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
                    182.324}, {58.469, 178.078}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
                    181.266}, {56.879, 178.078}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
                    181.266}, {56.879, 178.078}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
                    180.20299999999997`}, {56.09, 177.727}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
                    180.203}, {56.09, 177.727}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
                    179.14499999999998`}, {54.895, 177.727}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{52.913999999999994`, 
                    179.145}, {54.895, 177.727}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{55.188, 197.941}, {55.188, 197.73}, {54.945, 
                    197.559}, {54.645, 197.559}, {54.348, 197.559}, {
                    54.105000000000004`, 197.73}, {54.105000000000004`, 
                    197.941}, {54.105000000000004`, 198.148}, {54.348, 
                    198.32000000000002`}, {54.645, 198.32000000000002`}, {
                    54.945, 198.32000000000002`}, {55.188, 198.148}, {55.188, 
                    197.941}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.00027523230299006575`], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{55.188, 197.941381797}, {55.188, 
                    197.730499788}, {54.945, 197.55864388100002`}, {54.645, 
                    197.55864388100002`}, {54.348, 197.55864388100002`}, {
                    54.105000000000004`, 197.730499788}, {54.105000000000004`,
                     197.941381797}, {54.105000000000004`, 198.148502254}, {
                    54.348, 198.320358161}, {54.645, 198.320358161}, {54.945, 
                    198.320358161}, {55.188, 198.148502254}, {55.188, 
                    197.941381797}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{57.348, 197.75}, {57.348, 197.539}, {
                    57.105000000000004`, 197.36700000000002`}, {56.809, 
                    197.36700000000002`}, {56.508, 197.36700000000002`}, {
                    56.266000000000005`, 197.539}, {56.266000000000005`, 
                    197.75}, {56.266000000000005`, 197.961}, {56.508, 
                    198.129}, {56.809, 198.129}, {57.105000000000004`, 
                    198.129}, {57.348, 197.961}, {57.348, 197.75}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.00027523230299006575`], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{57.348, 197.750012839}, {57.348, 
                    197.53913083000003`}, {57.105000000000004`, 
                    197.367274923}, {56.809, 197.367274923}, {56.508, 
                    197.367274923}, {56.266000000000005`, 
                    197.53913083000003`}, {56.266000000000005`, 
                    197.750012839}, {56.266000000000005`, 197.960894848}, {
                    56.508, 198.12898920300003`}, {56.809, 
                    198.12898920300003`}, {57.105000000000004`, 
                    198.12898920300003`}, {57.348, 197.960894848}, {57.348, 
                    197.750012839}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{59.512, 197.559}, {59.512, 197.348}, {59.27, 
                    197.176}, {58.973, 197.176}, {58.672000000000004`, 
                    197.176}, {58.43, 197.348}, {58.43, 197.559}, {58.43, 
                    197.76999999999998`}, {58.672000000000004`, 197.941}, {
                    58.973, 197.941}, {59.27, 197.941}, {59.512, 
                    197.76999999999998`}, {59.512, 197.559}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752377784678158], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{59.512, 197.55858931199998`}, {59.512, 
                    197.3477082}, {59.27, 197.17561792800004`}, {58.973, 
                    197.17561792800004`}, {58.672000000000004`, 
                    197.17561792800004`}, {58.43, 197.3477082}, {58.43, 
                    197.55858931199998`}, {58.43, 197.76947042400002`}, {
                    58.672000000000004`, 197.94132560000003`}, {58.973, 
                    197.94132560000003`}, {59.27, 197.94132560000003`}, {
                    59.512, 197.76947042400002`}, {59.512, 
                    197.55858931199998`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{61.676, 197.559}, {61.676, 197.348}, {61.434, 
                    197.176}, {61.137, 197.176}, {60.836, 197.176}, {60.594, 
                    197.348}, {60.594, 197.559}, {60.594, 
                    197.76999999999998`}, {60.836, 197.941}, {61.137, 
                    197.941}, {61.434, 197.941}, {61.676, 
                    197.76999999999998`}, {61.676, 197.559}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752377784678158], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{61.676, 197.55858931199998`}, {61.676, 
                    197.3477082}, {61.434, 197.17561792800004`}, {61.137, 
                    197.17561792800004`}, {60.836, 197.17561792800004`}, {
                    60.594, 197.3477082}, {60.594, 197.55858931199998`}, {
                    60.594, 197.76947042400002`}, {60.836, 
                    197.94132560000003`}, {61.137, 197.94132560000003`}, {
                    61.434, 197.94132560000003`}, {61.676, 
                    197.76947042400002`}, {61.676, 197.55858931199998`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{63.839999999999996`, 197.75}, {
                    63.839999999999996`, 197.539}, {63.598000000000006`, 
                    197.36700000000002`}, {63.297000000000004`, 
                    197.36700000000002`}, {63., 197.36700000000002`}, {62.758,
                     197.539}, {62.758, 197.75}, {62.758, 197.961}, {63., 
                    198.129}, {63.297000000000004`, 198.129}, {
                    63.598000000000006`, 198.129}, {63.839999999999996`, 
                    197.961}, {63.839999999999996`, 197.75}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.00027523230299006575`], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{63.839999999999996`, 197.750012839}, {
                    63.839999999999996`, 197.53913083000003`}, {
                    63.598000000000006`, 197.367274923}, {63.297000000000004`,
                     197.367274923}, {63., 197.367274923}, {62.758, 
                    197.53913083000003`}, {62.758, 197.750012839}, {62.758, 
                    197.960894848}, {63., 198.12898920300003`}, {
                    63.297000000000004`, 198.12898920300003`}, {
                    63.598000000000006`, 198.12898920300003`}, {
                    63.839999999999996`, 197.960894848}, {63.839999999999996`,
                     197.750012839}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{66.004, 197.941}, {66.004, 197.73}, {65.762, 
                    197.559}, {65.46100000000001, 197.559}, {65.164, 
                    197.559}, {64.922, 197.73}, {64.922, 197.941}, {64.922, 
                    198.148}, {65.164, 198.32000000000002`}, {
                    65.46100000000001, 198.32000000000002`}, {65.762, 
                    198.32000000000002`}, {66.004, 198.148}, {66.004, 
                    197.941}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.00027523230299006575`], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{66.004, 197.941381797}, {66.004, 
                    197.730499788}, {65.762, 197.55864388100002`}, {
                    65.46100000000001, 197.55864388100002`}, {65.164, 
                    197.55864388100002`}, {64.922, 197.730499788}, {64.922, 
                    197.941381797}, {64.922, 198.148502254}, {65.164, 
                    198.320358161}, {65.46100000000001, 198.320358161}, {
                    65.762, 198.320358161}, {66.004, 198.148502254}, {66.004, 
                    197.941381797}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{37.050999999999995`, 
                    180.555}, {51.328, 187.984}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{37.050999999999995`, 
                    180.555}, {51.328, 187.984}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{36.258, 180.91}, {
                    49.73800000000001, 187.984}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{36.258, 180.91}, {
                    49.73800000000001, 187.984}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{35.858999999999995`, 
                    181.617}, {48.156, 187.984}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{35.858999999999995`, 
                    181.61700000000002`}, {48.156, 187.984}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{35.465, 182.324}, {
                    46.172000000000004`, 187.984}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{35.465, 182.324}, {
                    46.172000000000004`, 187.984}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{34.672000000000004`, 
                    183.031}, {44.586, 187.984}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{34.672000000000004`, 
                    183.031}, {44.586, 187.984}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{35.066, 184.094}, {
                    41.809, 187.629}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{35.066, 184.094}, {
                    41.809, 187.62900000000002`}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{34.672000000000004`, 
                    184.80100000000002`}, {39.828, 187.629}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{34.672000000000004`, 
                    184.801}, {39.828, 187.62900000000002`}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{34.672000000000004`, 
                    185.859}, {38.23800000000001, 187.629}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{34.672000000000004`, 
                    185.859}, {38.23800000000001, 187.62900000000002`}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{38.23800000000001, 
                    180.20299999999997`}, {51.723000000000006`, 187.277}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{38.23800000000001, 
                    180.203}, {51.723000000000006`, 187.277}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{39.43, 179.848}, {52.121,
                     186.566}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{39.43, 179.848}, {52.121,
                     186.566}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{40.621, 179.496}, {
                    52.516, 185.859}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{40.621, 179.496}, {
                    52.516, 185.859}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{41.809, 
                    179.14499999999998`}, {51.723000000000006`, 
                    184.44899999999998`}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{41.809, 179.145}, {
                    51.723000000000006`, 184.449}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{43.395, 
                    179.14499999999998`}, {52.121, 183.738}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{43.395, 179.145}, {
                    52.121, 183.738}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{44.586, 178.789}, {
                    52.121, 182.68}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{44.586, 178.789}, {
                    52.121, 182.68}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}}}, {{{45.777, 
                    178.43800000000002`}, {51.723000000000006`, 181.617}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{45.777, 178.438}, {
                    51.723000000000006`, 181.61700000000002`}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{47.358999999999995`, 
                    178.43800000000002`}, {52.121, 180.91}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{47.358999999999995`, 
                    178.438}, {52.121, 180.91}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{48.949, 178.078}, {
                    52.121, 179.848}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{48.949, 178.078}, {
                    52.121, 179.848}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{50.535000000000004`, 
                    178.078}, {52.516, 179.14499999999998`}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{50.535000000000004`, 
                    178.078}, {52.516, 179.145}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{53.312, 188.336}, {51.328, 188.336}, {
                    50.668000000000006`, 184.80100000000002`}, {
                    50.668000000000006`, 181.266}, {51.328, 177.727}, {53.312,
                     177.727}, {52.648, 181.266}, {52.648, 
                    184.80100000000002`}, {53.312, 188.336}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{53.312, 188.336}, {51.328, 188.336}, {
                    50.668000000000006`, 184.801}, {50.668000000000006`, 
                    181.266}, {51.328, 177.727}, {53.312, 177.727}, {52.648, 
                    181.266}, {52.648, 184.801}, {53.312, 188.336}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{29.91, 183.383}, {
                    34.672000000000004`, 186.92200000000003`}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{29.91, 183.383}, {
                    34.672000000000004`, 186.922}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}}}, {{{29.91, 185.859}, {
                    34.672000000000004`, 181.617}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{29.91, 185.859}, {
                    34.672000000000004`, 181.61700000000002`}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{37.050999999999995`, 187.629}, {
                    34.672000000000004`, 187.277}, {34.141, 185.035}, {34.141,
                     183.15200000000002`}, {34.672000000000004`, 180.91}, {
                    37.050999999999995`, 180.20299999999997`}, {36.52, 
                    182.445}, {36.52, 185.38700000000003`}, {
                    37.050999999999995`, 187.629}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.00019591270833333333`], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{37.050999999999995`, 187.62900000000002`}, {
                    34.672000000000004`, 187.277}, {34.141, 185.035}, {34.141,
                     183.152}, {34.672000000000004`, 180.91}, {
                    37.050999999999995`, 180.203}, {36.52, 182.445}, {36.52, 
                    185.387}, {37.050999999999995`, 187.62900000000002`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}}}, {{{65.988, 205.309}, {65.988, 207.094}, {
                    64.20700000000001, 207.078}, {63.016, 208.137}, {63.016, 
                    209.21499999999997`}, {57.074, 209.19899999999998`}, {
                    57.074, 208.137}, {55.88699999999999, 207.078}, {
                    54.105000000000004`, 207.078}, {54.105000000000004`, 
                    205.309}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0003369062500000001], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}}}, {{{65.988, 205.309}, {65.988, 207.094}, {
                    64.20700000000001, 207.078}, {63.016, 208.137}, {63.016, 
                    209.215}, {57.074, 209.199}, {57.074, 208.137}, {
                    55.88699999999999, 207.078}, {54.105000000000004`, 
                    207.078}, {54.105000000000004`, 205.309}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    57.5, 211.32000000000002`}, {62.594, 
                    211.32000000000002`}, {62.594, 209.199}, {57.5, 
                    209.199}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002847395833333333], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    57.5, 211.32}, {62.594, 211.32}, {62.594, 
                    209.19899999999998`}, {57.5, 209.19899999999998`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    57.926, 213.441}, {62.168, 213.441}, {62.168, 211.32}, {
                    57.926, 211.32}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002847395833333333], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    57.926, 213.441}, {62.168, 213.441}, {62.168, 211.32}, {
                    57.926, 211.32}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    57.926, 215.562}, {62.168, 215.562}, {62.168, 213.441}, {
                    57.926, 213.441}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002847395833333333], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    57.926, 215.562}, {62.168, 215.562}, {62.168, 213.441}, {
                    57.926, 213.441}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    58.348, 218.395}, {61.742999999999995`, 218.395}, {
                    61.742999999999995`, 215.56300000000002`}, {58.348, 
                    215.56300000000002`}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002847395833333333], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    58.348, 218.395}, {61.742999999999995`, 218.395}, {
                    61.742999999999995`, 215.56300000000002`}, {58.348, 
                    215.56300000000002`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    58.203, 220.86700000000002`}, {61.891000000000005`, 
                    220.86700000000002`}, {61.891000000000005`, 218.394}, {
                    58.203, 218.394}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002967500000000001], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    58.203, 220.867}, {61.891000000000005`, 220.867}, {
                    61.891000000000005`, 218.394}, {58.203, 218.394}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{65.16799999999999, 223.168}, {65.16799999999999, 
                    221.312}, {62.969, 219.809}, {60.25, 219.809}, {
                    57.535000000000004`, 219.809}, {55.332, 221.312}, {55.332,
                     223.168}, {55.332, 225.023}, {57.535000000000004`, 
                    226.52700000000002`}, {60.25, 226.52700000000002`}, {
                    62.969, 226.52700000000002`}, {65.16799999999999, 
                    225.023}, {65.16799999999999, 223.168}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002797843009704614], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{65.16799999999999, 223.167931868}, {
                    65.16799999999999, 221.31284951800004`}, {62.969, 
                    219.808938571}, {60.25, 219.808938571}, {
                    57.535000000000004`, 219.808938571}, {55.332, 
                    221.31284951800004`}, {55.332, 223.167931868}, {55.332, 
                    225.023014218}, {57.535000000000004`, 
                    226.52692516500005`}, {60.25, 226.52692516500005`}, {
                    62.969, 226.52692516500005`}, {65.16799999999999, 
                    225.023014218}, {65.16799999999999, 223.167931868}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4rhdnjxM0f4OYPp1tgOM72Pe6ZhwNtth9hGF
DUU//B2stpwo2zcbk7+nZLIES5u/w6qPl3yTOrIdTi903fb5rJ/DzXPfgx9X
Zjv0Ts8TalZA8A9/1YjpL/KF8126c57/nukD4TdmO/Drbpr73t0Hbj463+Cu
ClvjUx+4+2B8mPth/AJbruuLOXLg+qtF1rk/1MPkO4Ps3+nj8LbG3jTOKQfu
vv3zpfTvBuTA3Q/jw/wH48P8D9MPCx+Y+eh8WPjC3Ice/gCXa7OX
                    
                    "]]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002797833333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4rhdnjxM0f4OYPp1tgOM72Pe6ZhwNtth9hGF
DUU//B0st5wo2zcbk7+nZLIES5u/w6qPl3yTOrIdTi903fb5rJ/DzXPfgx9X
Zjv0Ts8TalZA8A9/1YjpL/KF8126c57/nukD4TdmO/Drbpr73t0Hbj463+Cu
ClvjUx+4+2B8mPth/EJbruuLOXLg+qtF1rk/1MPkO4Ps3+nj8K7G3jTOKQfu
vn3zpfTvBuTA3Q/jw/wH48P8D9MPCx+Y+eh8WPjC3Ice/gCTM7OU
                    "], 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYCYtO4XZ48n/wcQBTT62wHGN/HvNMx4Wy2Q3HG
xLc1/f4OvdPzhJonYPLtuK4vLpD1d1jkuu3z35psh9MLgYyzfg43z30PflyZ
DVGngOAf/qoR01/kC+fnPv+98iOTr8OWE2X75pdlO0jp31Vh2+gDNx+dH2EJ
VOnnC3cfjA9zP4xfYAt0GEcOXD830Jm2Vph8sP1Kvg7CzQdOLfTNgbtv/3yg
yoAcuPthfJj/YHyY/2H6YeEDMx+dDwtfmPvQwx8ALlew6g==
                    "]]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002797833333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYCYtO4XZ48n/wcQBTT62wHGN/HvNMx4Wy2Q3HG
xLc1/f4OvdPzhJonYPLtuK4vLpD1d1jkuu3z35psh9MLgYyzfg43z30PflyZ
DVGngOAf/qoR01/kC+fnPv+98iOTr8OWE2X75pdlO0jp31Vh2+gDNx+dH2EJ
VOnnC3cfjA9zP4xfaAt0GEcOXD/ImbZWmHyw/Uq+DkLNB04t9M2Bu2/ffKDK
gBy4+2F8mP9gfJj/Yfph4QMzH50PC1+Y+9DDHwArf7Dj
                    "], 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{56.562000000000005`, 222.98800000000003`}, {
                    56.562000000000005`, 222.40200000000002`}, {56.012, 
                    221.93}, {55.332, 221.93}, {54.656, 221.93}, {
                    54.105000000000004`, 222.40200000000002`}, {
                    54.105000000000004`, 222.98800000000003`}, {
                    54.105000000000004`, 223.57399999999998`}, {54.656, 
                    224.05100000000002`}, {55.332, 224.05100000000002`}, {
                    56.012, 224.05100000000002`}, {56.562000000000005`, 
                    223.57399999999998`}, {56.562000000000005`, 
                    222.98800000000003`}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002797843009704614], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{56.562000000000005`, 222.988463436}, {
                    56.562000000000005`, 222.402602545}, {56.012, 
                    221.929772253}, {55.332, 221.929772253}, {54.656, 
                    221.929772253}, {54.105000000000004`, 222.402602545}, {
                    54.105000000000004`, 222.988463436}, {54.105000000000004`,
                     223.57432432700003`}, {54.656, 224.05060593500002`}, {
                    55.332, 224.05060593500002`}, {56.012, 
                    224.05060593500002`}, {56.562000000000005`, 
                    223.57432432700003`}, {56.562000000000005`, 
                    222.988463436}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{66.398, 222.98800000000003`}, {66.398, 
                    222.40200000000002`}, {65.848, 221.93}, {
                    65.16799999999999, 221.93}, {64.488, 221.93}, {
                    63.940999999999995`, 222.40200000000002`}, {
                    63.940999999999995`, 222.98800000000003`}, {
                    63.940999999999995`, 223.57399999999998`}, {64.488, 
                    224.05100000000002`}, {65.16799999999999, 
                    224.05100000000002`}, {65.848, 224.05100000000002`}, {
                    66.398, 223.57399999999998`}, {66.398, 
                    222.98800000000003`}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002797843009704614], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{66.398, 222.988463436}, {66.398, 
                    222.402602545}, {65.848, 221.929772253}, {
                    65.16799999999999, 221.929772253}, {64.488, 
                    221.929772253}, {63.940999999999995`, 222.402602545}, {
                    63.940999999999995`, 222.988463436}, {63.940999999999995`,
                     223.57432432700003`}, {64.488, 224.05060593500002`}, {
                    65.16799999999999, 224.05060593500002`}, {65.848, 
                    224.05060593500002`}, {66.398, 223.57432432700003`}, {
                    66.398, 222.988463436}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{61.48, 222.98800000000003`}, {61.48, 
                    222.40200000000002`}, {60.93, 221.93}, {60.25, 221.93}, {
                    59.574, 221.93}, {59.023, 222.40200000000002`}, {59.023, 
                    222.98800000000003`}, {59.023, 223.57399999999998`}, {
                    59.574, 224.05100000000002`}, {60.25, 
                    224.05100000000002`}, {60.93, 224.05100000000002`}, {
                    61.48, 223.57399999999998`}, {61.48, 
                    222.98800000000003`}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002797843009704614], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{61.48, 222.988463436}, {61.48, 222.402602545}, {
                    60.93, 221.929772253}, {60.25, 221.929772253}, {59.574, 
                    221.929772253}, {59.023, 222.402602545}, {59.023, 
                    222.988463436}, {59.023, 223.57432432700003`}, {59.574, 
                    224.05060593500002`}, {60.25, 224.05060593500002`}, {
                    60.93, 224.05060593500002`}, {61.48, 
                    223.57432432700003`}, {61.48, 222.988463436}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{61.48, 226.52700000000002`}, {61.48, 225.941}, {
                    60.93, 225.465}, {60.25, 225.465}, {59.574, 225.465}, {
                    59.023, 225.941}, {59.023, 226.52700000000002`}, {59.023, 
                    227.11299999999997`}, {59.574, 227.586}, {60.25, 
                    227.586}, {60.93, 227.586}, {61.48, 
                    227.11299999999997`}, {61.48, 226.52700000000002`}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002797843009704614], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{61.48, 226.52692516500005`}, {61.48, 
                    225.941064274}, {60.93, 225.464782666}, {60.25, 
                    225.464782666}, {59.574, 225.464782666}, {59.023, 
                    225.941064274}, {59.023, 226.52692516500005`}, {59.023, 
                    227.11364888500003`}, {59.574, 227.58561634800003`}, {
                    60.25, 227.58561634800003`}, {60.93, 
                    227.58561634800003`}, {61.48, 227.11364888500003`}, {
                    61.48, 226.52692516500005`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{57.926, 206.371}, {57.926, 205.785}, {57.355, 
                    205.309}, {56.652, 205.309}, {55.949, 205.309}, {55.379, 
                    205.785}, {55.379, 206.371}, {55.379, 
                    206.95700000000002`}, {55.949, 207.43}, {56.652, 
                    207.43}, {57.355, 207.43}, {57.926, 
                    206.95700000000002`}, {57.926, 206.371}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002847359638519521], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{57.926, 206.37114037400002`}, {57.926, 
                    205.78548654000002`}, {57.355, 205.308965924}, {56.652, 
                    205.308965924}, {55.949, 205.308965924}, {55.379, 
                    205.78548654000002`}, {55.379, 206.37114037400002`}, {
                    55.379, 206.95679420800002`}, {55.949, 207.429982512}, {
                    56.652, 207.429982512}, {57.355, 207.429982512}, {57.926, 
                    206.95679420800002`}, {57.926, 206.37114037400002`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{64.715, 206.371}, {64.715, 205.785}, {64.145, 
                    205.309}, {63.440999999999995`, 205.309}, {
                    62.73800000000001, 205.309}, {62.168000000000006`, 
                    205.785}, {62.168000000000006`, 206.371}, {
                    62.168000000000006`, 206.95700000000002`}, {
                    62.73800000000001, 207.43}, {63.440999999999995`, 
                    207.43}, {64.145, 207.43}, {64.715, 
                    206.95700000000002`}, {64.715, 206.371}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002847359638519521], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{64.715, 206.37114037400002`}, {64.715, 
                    205.78548654000002`}, {64.145, 205.308965924}, {
                    63.440999999999995`, 205.308965924}, {62.73800000000001, 
                    205.308965924}, {62.168000000000006`, 
                    205.78548654000002`}, {62.168000000000006`, 
                    206.37114037400002`}, {62.168000000000006`, 
                    206.95679420800002`}, {62.73800000000001, 
                    207.429982512}, {63.440999999999995`, 207.429982512}, {
                    64.145, 207.429982512}, {64.715, 206.95679420800002`}, {
                    64.715, 206.37114037400002`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{57.074, 
                    209.19899999999998`}, {63.016, 209.19899999999998`}, {
                    60.047, 206.016}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.00028473541666666665`], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{57.074, 
                    209.199}, {63.016, 209.199}, {60.047, 
                    206.01600000000002`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{61.746, 206.72299999999998`}, {61.746, 
                    205.941}, {60.983999999999995`, 205.309}, {60.047, 
                    205.309}, {59.109, 205.309}, {58.348, 205.941}, {58.348, 
                    206.72299999999998`}, {58.348, 207.504}, {59.109, 
                    208.137}, {60.047, 208.137}, {60.983999999999995`, 
                    208.137}, {61.746, 207.504}, {61.746, 
                    206.72299999999998`}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0003796485856436213], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{61.746, 206.72269929}, {61.746, 
                    205.94127212600003`}, {60.983999999999995`, 
                    205.308965924}, {60.047, 205.308965924}, {59.109, 
                    205.308965924}, {58.348, 205.94127212600003`}, {58.348, 
                    206.72269929}, {58.348, 207.50412645400004`}, {59.109, 
                    208.136432656}, {60.047, 208.136432656}, {
                    60.983999999999995`, 208.136432656}, {61.746, 
                    207.50412645400004`}, {61.746, 206.72269929}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    54.004, 196.11299999999997`}, {62.137, 
                    196.11299999999997`}, {62.41, 196.11299999999997`}, {
                    62.629000000000005`, 195.945}, {62.629000000000005`, 
                    195.738}, {62.629000000000005`, 194.36700000000002`}, {
                    62.629000000000005`, 194.156}, {62.41, 
                    193.99200000000002`}, {62.137, 193.99200000000002`}, {
                    54.004, 193.99200000000002`}, {53.730000000000004`, 
                    193.99200000000002`}, {53.508, 194.156}, {53.508, 
                    194.36700000000002`}, {53.508, 195.738}, {53.508, 
                    195.945}, {53.730000000000004`, 196.11299999999997`}, {
                    54.004, 196.11299999999997`}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    54.004, 196.113}, {62.137, 196.113}, {62.41, 196.113}, {
                    62.629000000000005`, 195.945}, {62.629000000000005`, 
                    195.738}, {62.629000000000005`, 194.367}, {
                    62.629000000000005`, 194.156}, {62.41, 193.992}, {62.137, 
                    193.992}, {54.004, 193.992}, {53.730000000000004`, 
                    193.992}, {53.508, 194.156}, {53.508, 194.367}, {53.508, 
                    195.738}, {53.508, 195.945}, {53.730000000000004`, 
                    196.113}, {54.004, 196.113}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}}, {{1, 4, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgAmJ+KO3SnfP8d2SAw+Ols48o7Mlw2DT3/fJjwgi+Fw+T
dvs2f4dvGjH9hxYi+Itct33+24DgCzcfOLXQF8G/87Mua48Owry3NfamcUIZ
DjD7YPze6XlCzQsQfGn9uypsNwPg+mF8mPkwPsx+GB/mPph5MPej+w/GB2lr
XJrhYLXlRNk+fQQfbA5vgMOqj5d8kyYg+OqGHGtkytDkI9Dk7RDmtb4O3CGn
ibAPxvdLEoiwbEHwQd5yXYbQD+PDzEeRL0OTn4AwD+Z+dP8BAFDw06U=
                    
                    "]]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}}, {{1, 4, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgAmJ+KO3SnfP8d2SAw+Ols48o7Mlw2DT3/fJjwgi+Fw+T
dvs2f4dvGjH9hxYi+Itct33+24DgCzUfOLXQF8G//bMua48Owrx3NfamcUIZ
DjD7YPze6XlCzQsQfGn9uypsNwPg+mF8mPkwPsx+GB/mPph5MPej+w/GB2lr
XJrhYLXlRNk+fQQfbA5vgMOqj5d8kyYg+OqGHGtkytDkI9Dk7RDmtb4O3CGn
ibAPxvdLEoiwbEHwQd5yXYbQD+PDzEeRL0OTn4AwD+Z+dP8BAE+I06Q=
                    
                    "], CurveClosed -> {1, 1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}}, {{1, 4, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgAmJ+KM3eONW5u8fb4fbPuqw9GzIcPl3yTRKwQPDbxW6e
+/7Zy8Fqy4myfbMRfP27KmyNjQj+Itdtn//6IPjVIuvcHxohzPumEdN/SDbD
AWYfjC8NMughgi8K1Fal4gPXD+PDzIfxYfbD+DD3wcyDuR/dfzB+/6GvGjHH
MxyKMya+rfnvBedHWAIN6oP6Zw2Cf9zbvNOxB8FXN+RYI+OE4IOkExQR5sXu
8uRhYkfYB+NrAb35VcIHznfpznn+u9MHrh/Gh5kP48Psh/Fh7oOZB3M/uv8A
zm7Z+Q==
                    "]]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}}, {{1, 4, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgAmJ+KM3eONW5u8fb4fbPuqw9GzIcPl3yTRKwQPDbxW6e
+/7Zy8Fyy4myfbMRfP27KmyNjQj+Itdtn//6IPjVIuvcHxohzPumEdN/SDbD
AWYfjC8NMughgi8K1Fal4gPXD+PDzIfxYfbD+DD3wcyDuR/dfzB+/6GvGjHH
MxyKMya+rfnvBedHgAzqg/pnDYJ/3Nu807EHwVc35Fgj44Tg+wClExQR5sXt
8uRhYkfYB+NrAb35VcIHznfpznn+u9MHrh/Gh5kP48Psh/Fh7oOZB3M/uv8A
zfbZ/A==
                    "], CurveClosed -> {1, 1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}}, {{1, 4, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgAmJ+KO3Fw6Td/s3Tgfv64gLbWRkOZnG7PHkWIfh2XEBG
rKdD6+vAHXKtCH61yDr3h1kI/tYTZfvmxyH4qz5e8k1yQZinytY41Vk/wwFm
H4wPkmby9oLzIyy3nCjr84Lrh/Fh5sP4MPthfJj7YObB3I/uPxj/9s+6rD0b
Mhy2ff57pSITwZ99RGFD0Q8Ph7c19qZx0xB8oeYDpxaWIvgga/cFI/hge40R
5hXYAgNCAmEfjH/4q0ZMf5MXnN8udvPc989ecP0wPsx8GB9mP4wPcx/MPJj7
0f0HAM/n1e4=
                    "]]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}}, {{1, 4, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgAmJ+KO3Fw6Td/s3Tgev64gLbWRkOZnG7PHkWIfh2IEas
p0Pr68Adcq0IfrXIOveHWQj+lhNl++bHIfirPl7yTXJBmKfK1jjVWT/DAWYf
jA+SZvL2gvMjLIEm9XnB9cP4MPNhfJj9MD7MfTDzYO5H9x+Mf/tnXdaeDRkO
2z7/vVKRieDPPqKwoeiHh8O7GnvTuGkIvlDzgVMLSxF8K5CDghF8sL3GCPMK
bIE2SiDsg/EPf9WI6W/ygvPbxW6e+/7ZC64fxoeZD+PD7IfxYe6DmQdzP7r/
AMlX1ew=
                    "], CurveClosed -> {1, 1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}}, {{1, 4, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgAmJ+KL3Iddvnv1PcHfTvqrA17sxwmCzBEsb31w3Oz33+
e+XHJjeHm+e+Bz9eiOAX2HJdX9yC4Lt05zz/7YngF4LkdRDmtb4O3CEnmuEA
sw/GB8vresD51xcDTV7uAdcP48PMh/Fh9sP4MPfBzIO5H91/MH61yDr3h5cy
HD5d8k0SmOEG57M3TnXuPuPqkDHxbY39VgQf7J4JCD7YPls09ZII86y2nCjb
9zsdbh+Mbxq3y5Nnkgecbwc0tiDWE64fxoeZD+PD7EdRD3QfzDyY+9H9BwDC
Ud9Y
                    "]]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}}, {{1, 4, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgAmJ+KL3Iddvnv1PcHfTvqrA17sxwmCzBEsb31w3Oz33+
e+XHJjeHm+e+Bz9eiOAX2nJdX9yC4Lt05zz/7YngF4DkdRDmtb4O3CEnmuEA
sw/GB8vresD51xcDdS73gOuH8WHmw/gw+2F8mPtg5sHcj+4/GL9aZJ37w0sZ
Dp8u+SYJzHCD89kbpzp3n3F1yJj4tsZ+K4IPtm8Cgg+2zxZNvSTCPMstJ8r2
/U6H2wfjm8bt8uSZ5AHn2wGNLYj1hOuH8WHmw/gw+1HUA90HMw/mfnT/AQDA
6d9V
                    "], CurveClosed -> {1, 1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}}, {{1, 4, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgAmJ+KC26zv1hlU2QA9f1xQW26zIceqfnCTV/CITzVdka
pzpvDnS4oHT7Z900BD9j4tsa+0oEf+uJsn3z7dDkFRHmfdOI6T/EmeEAsw/G
P+Zt3unYgeDr31VhazwaBNcP48PMR5GvRPBh7oOZB3M/uv9g/P5DXzVijmdA
7N0bCOdbbgFaFB7o4NKd8/z3SgTfB2hsQiuCfxFknxGCv7dksgQLH8I8iL/T
4fbB+HG7PHmYdiP4IY+Xzj6iEAzXD+PDzIfxYfbD+DD3wcyDuR/dfwDn09cI

                    "]]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}}, {{1, 4, 3}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgAmJ+KC26zv1hlU2QA9f1xQW26zIceqfnCTV/CITzVdka
pzpvDnS4qHT7Z900BD9j4tsa+0oEf8uJsn3z7dDkFRHmfdOI6T/EmeEAsw/G
P+Zt3unYgeDr31VhazwaBNcP48PMR5GvRPBh7oOZB3M/uv9g/P5DXzVijmdA
7N0bCOdbgiwKD3Rw6c55/nslgu8DNDahFcEH22eE4O8pmSzBwocwrw/s73S4
fTB+3C5PHqbdCH7I46WzjygEw/XD+DDzYXyY/TA+zH0w82DuR/cfAOhL1wk=

                    "], CurveClosed -> {1, 1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    66.45700000000001, 196.11299999999997`}, {70.699, 
                    196.11299999999997`}, {70.84400000000001, 
                    196.11299999999997`}, {70.96100000000001, 195.945}, {
                    70.96100000000001, 195.738}, {70.96100000000001, 
                    194.36700000000002`}, {70.96100000000001, 194.156}, {
                    70.84400000000001, 193.99200000000002`}, {70.699, 
                    193.99200000000002`}, {66.45700000000001, 
                    193.99200000000002`}, {66.316, 193.99200000000002`}, {
                    66.199, 194.156}, {66.199, 194.36700000000002`}, {66.199, 
                    195.738}, {66.199, 195.945}, {66.316, 
                    196.11299999999997`}, {66.45700000000001, 
                    196.11299999999997`}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    66.45700000000001, 196.113}, {70.699, 196.113}, {
                    70.84400000000001, 196.113}, {70.96100000000001, 
                    195.945}, {70.96100000000001, 195.738}, {
                    70.96100000000001, 194.367}, {70.96100000000001, 
                    194.156}, {70.84400000000001, 193.992}, {70.699, 
                    193.992}, {66.45700000000001, 193.992}, {66.316, 
                    193.992}, {66.199, 194.156}, {66.199, 194.367}, {66.199, 
                    195.738}, {66.199, 195.945}, {66.316, 196.113}, {
                    66.45700000000001, 196.113}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    61.992000000000004`, 196.465}, {64.465, 196.465}, {64.551,
                     196.465}, {64.617, 196.242}, {64.617, 195.965}, {64.617, 
                    194.137}, {64.617, 193.859}, {64.551, 193.637}, {64.465, 
                    193.637}, {61.992000000000004`, 193.637}, {61.906, 
                    193.637}, {61.839999999999996`, 193.859}, {
                    61.839999999999996`, 194.137}, {61.839999999999996`, 
                    195.965}, {61.839999999999996`, 196.242}, {61.906, 
                    196.465}, {61.992000000000004`, 196.465}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    61.992000000000004`, 196.465}, {64.465, 196.465}, {64.551,
                     196.465}, {64.617, 196.242}, {64.617, 195.965}, {64.617, 
                    194.137}, {64.617, 193.859}, {64.551, 193.637}, {64.465, 
                    193.637}, {61.992000000000004`, 193.637}, {61.906, 
                    193.637}, {61.839999999999996`, 193.859}, {
                    61.839999999999996`, 194.137}, {61.839999999999996`, 
                    195.965}, {61.839999999999996`, 196.242}, {61.906, 
                    196.465}, {61.992000000000004`, 196.465}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    48.902, 196.465}, {51.379, 196.465}, {51.461, 196.465}, {
                    51.527, 196.242}, {51.527, 195.965}, {51.527, 194.137}, {
                    51.527, 193.859}, {51.461, 193.637}, {51.379, 193.637}, {
                    48.902, 193.637}, {48.82, 193.637}, {48.754, 193.859}, {
                    48.754, 194.137}, {48.754, 195.965}, {48.754, 196.242}, {
                    48.82, 196.465}, {48.902, 196.465}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    48.902, 196.465}, {51.379, 196.465}, {51.461, 196.465}, {
                    51.527, 196.242}, {51.527, 195.965}, {51.527, 194.137}, {
                    51.527, 193.859}, {51.461, 193.637}, {51.379, 193.637}, {
                    48.902, 193.637}, {48.82, 193.637}, {48.754, 193.859}, {
                    48.754, 194.137}, {48.754, 195.965}, {48.754, 196.242}, {
                    48.82, 196.465}, {48.902, 196.465}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    40.324, 196.82000000000002`}, {45.273, 
                    196.82000000000002`}, {45.440999999999995`, 
                    196.82000000000002`}, {45.578, 196.54299999999998`}, {
                    45.578, 196.195}, {45.578, 193.91}, {45.578, 193.562}, {
                    45.440999999999995`, 193.285}, {45.273, 193.285}, {40.324,
                     193.285}, {40.160000000000004`, 193.285}, {40.023, 
                    193.562}, {40.023, 193.91}, {40.023, 196.195}, {40.023, 
                    196.54299999999998`}, {40.160000000000004`, 
                    196.82000000000002`}, {40.324, 196.82000000000002`}}}]}, {
                   
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    40.324, 196.82}, {45.273, 196.82}, {45.440999999999995`, 
                    196.82}, {45.578, 196.543}, {45.578, 196.195}, {45.578, 
                    193.91}, {45.578, 193.562}, {45.440999999999995`, 
                    193.285}, {45.273, 193.285}, {40.324, 193.285}, {
                    40.160000000000004`, 193.285}, {40.023, 193.562}, {40.023,
                     193.91}, {40.023, 196.195}, {40.023, 196.543}, {
                    40.160000000000004`, 196.82}, {40.324, 196.82}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    74.809, 196.465}, {79.402, 196.465}, {79.559, 196.465}, {
                    79.684, 196.184}, {79.684, 195.84}, {79.684, 193.555}, {
                    79.684, 193.207}, {79.559, 192.93}, {79.402, 192.93}, {
                    74.809, 192.93}, {74.65199999999999, 192.93}, {74.527, 
                    193.207}, {74.527, 193.555}, {74.527, 195.84}, {74.527, 
                    196.184}, {74.65199999999999, 196.465}, {74.809, 
                    196.465}}}]}, {
                    RGBColor[
                    0.8588240000000001, 0.08627450000000002, 0.105882], 
                    Thickness[0.0002752333333333334], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    74.809, 196.465}, {79.402, 196.465}, {79.559, 196.465}, {
                    79.684, 196.184}, {79.684, 195.84}, {79.684, 193.555}, {
                    79.684, 193.207}, {79.559, 192.93}, {79.402, 192.93}, {
                    74.809, 192.93}, {74.65199999999999, 192.93}, {74.527, 
                    193.207}, {74.527, 193.555}, {74.527, 195.84}, {74.527, 
                    196.184}, {74.65199999999999, 196.465}, {74.809, 
                    196.465}}}, CurveClosed -> {1}]}}, AspectRatio -> 
                  Automatic, ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 480.}, {0., 240.}}], ",", 
                 GraphicsBox[{
                   Thickness[0.0010416666666666667`], {
                    FaceForm[{
                    RGBColor[1., 0.717647, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 480.}, {960., 480.}, {960., 0.}}}]}, {
                    FaceForm[{
                    RGBColor[1., 0.356863, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    172., 440.}, {304., 440.}, {304., 40.}, {172., 40.}}}]}, {
                   
                    FaceForm[{
                    RGBColor[0., 0.3372549999999999, 0.254902], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    40., 440.}, {172., 440.}, {172., 40.}, {40., 40.}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.5529410000000001, 0.12549000000000002`, 0.160784], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    344., 440.}, {924., 440.}, {924., 40.}, {344., 40.}}}]}, {
                   
                    FaceForm[{
                    RGBColor[1., 0.717647, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4g7HhKcX1Lodtn3+e6XiZJQDOj86xfq+f1C3
w0JXoAhLhIOPeadjQlO3g1+SQITlkzAHm/v+vdNPdjv0Ts8TarYIddhyomzf
/OgehzUyUSnW4aEQ+Zk9EPUpwQ6yQOH7j3scLEEKxQMdlhTYcl2f3ONQ+VLN
kEPGx+GC0u2fdVN6HBaB7JviDdE/o8eBAQQSPDD4YPVpPQ57SyZLsIR5OBxV
2FCUEdjjsPKYt3mnooeDfOvrwB2GPQ6Hv2rE9F9yd7jsC3SIao+D/l0VtkZT
N4j/XnU75D7/vfJjkZvDNOfunOeh3Q5TgKbx8bpD+NHdDrOPgAz2h+gL7nZo
PnBqoatbsMOnS0ADfbodLoLcsSgEEn5W3Q4g6x0zwiDuNISG15FwiPs1uh28
eJi0299FYIQ3Oh8AZG64MA==
                    "]]}, {
                    Thickness[0.0017714645833333332`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4g7HhKcX1Lodtnz+e6XiZJQDOj86xfq+f1C3
wxLXbZ//skQ4+Jh3OiY0dTsEJAlEWD4Jc7C57987/WS3Q8/0PKFmi1CHLSfK
9s2P7nFYIxOVYh0eCpGf2QNRnxLsIAsUvv+4x8ECpFA80GFJgS3X9ck9Dg0v
1Qw5ZHwcLijd/lk3pcdhBci+Kd4Q/TN6HBhAIMEDgw9Wn9bjcKBksgRLmIfD
UYUNRRmBPQ4bjnmbdyp6OMi3vg7cYQiU/6oR03/J3eGyL9Ahqj0OBndV2BpN
3SD+e9XtkPH898qPRW4O05y7c56HdjvMAJrGx+sO4UcD+UdABvs76IP0BXc7
tBw4tdDVLdjh0yWggT7dDldA7lgUAgk/q26HE0DrHTPCIO40hIbXkXCI+zW6
HXx4mLTb30VghDc6HwB57rhI
                    "], CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 0.717647, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4nc19qZxnyochJsPnFroW+6Azvc273RMmF3h
MD1PqPnAv3KHjIlva+ytKxxynv9e+dGtwgEo+/TCmnIH2agU6/sbKxxmgNR1
lDlcrXipZrgKKs9TBlGvVulwDGRgRanDp0u+SQK7Kh12yLW+DpQoc7igdPtn
XU2VQ+wuTx4m8TKIvb1VDh0g/XxlDgwg8AWTHwdSX1wGcdfXKofyffOl9OeW
OWi1i90897vK4dBXjZj+O2UOHg+rRNaxVjuAnOn/tQxCW1ZD7Mkuh/jXsBri
7ikVDm9B4SAH5XdUOOSC3C9U5bDIddvnvzMqHO77907P06t0kAEZtLwCYs71
Ckj4napw4NPdNPd9agXEnfeg4cVXAXH/O6j5RzDDG50PALzvvic=
                    
                    "]]}, {
                    Thickness[0.0017714645833333332`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4nc19qZxnyochJoPnFroW+6Azvc273RMmF3h
MCMPKPKv3CFj4tsae+sKh5znv1d+dKtwAMo+vbCm3EE2KsX6/kaouo4yh6sV
L9UMV0Hlecog6tUqHY6BDKwodfh0yTdJYFelww651teBEmUOF5Vu/6yrqXKI
3eXJwyRe5uADsre3yqEDpJ+vzIEBBL5g8uNA6ovLIO76WuVQvm++lP7cMgft
drGb535XORz6qhHTf6fMweNhlcg61moHkDP9v5ZBaMtqiP+yyyH+NayGuHtK
BSQc5KD8jgqHXJD7haocFrlu+/x3RoXDff/e6Xl6lQ4yIIOWV0Dcex2q71SF
A5/uprnvUysg7rwHDS++Coj730HVHcEMb3Q+AL5/vik=
                    "], 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 0.717647, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4g7HhKcX1LodhJsPnFroW+6Azo9Osb7vH9Tt
MD1PqPnAv3IHH/NOx4Smboec579XfnSrcLC57987/WS3g2wUUOHGCoctJ8r2
zY/ucbha8VLNcBVUfmYPRL1aJUTd4x6HT5d8kwR2VTosKbDluj65x+GC0u2f
dTVVEHpKj4M3yJ7eKoj+GT0ODCDwBZMPVp/W45Ax8W2N/dcqh6MKG4oyAnsc
tNrFbp77XeUg3/o6cIdhj4PHwyqRdazVDpeB1kao9jiAnOFvWQ3x3yuofw2r
HaY5d+c8D+12AJpmGicH5Ud3O+SC3C9U5aB/V4WtMbjbAeSMPL1KiD98uiHu
vV4BCT+rbgc+3U1z36dWQNxpCA0vPmh4aEDNP4IZ3uh8ADOCwEA=
                    
                    "]]}, {
                    Thickness[0.0017714645833333332`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4g7HhKcX1LodhJoPnFroW+6Azo9Osb7vH9Tt
MCMPKPKv3MHHvNMxoanbIef575Uf3SocbO77904/2e0gGwVUuLHCYcuJsn3z
o3scrla8VDNcBZWf2QNRr1YJUfe4x+HTJd8kgV2VDksKbLmuT+5xuKh0+2dd
TZXDBRA9pQdiT28VRP+MHgcGEPiCyQerT+txyJj4tsb+a5XDUYUNRRmBPQ7a
7WI3z/2ucpBvfR24w7DHweNhlcg61mqHy0BrI1R7HEDO8LeshvjvFdS/htUO
05y7c56Hdju8q7E3jZOD8qO7HXJB7heqctC/q8LWGNztAHJGnl4lxB8+3RD3
Xq+AhJ9VtwOf7qa571MrIO40hIYXHzQ8NKDmH8EMb3Q+ADUSwEI=
                    "], 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 0.717647, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4nc19qZxnyoctn3+e6XiZJQDOt/bvNMxYXaF
w0JXoAhLhEPGxLc19tYVDn5JAhGWT8IcgLJPL6wpd+idnifUbBHqMANIHego
c1gjE5ViHR4Kkecpg6hPCXY4BjKwotTBcsuJsn3igQ475FpfB0qUOVS+VDPk
kPFxiN3lycMkXuawCGTfFG+HDpB+vjIHBhBI8MDgx4HUF5c57C2ZLMES5uFQ
vm++lP7cMoeVIIsUPRwOfdWI6b9T5nAYRF9ydwC66r7/1zIH/bsqbI2mbhD/
ZZc75D7/vfJjkZvD1QqgQ6ZUOEwBmsbH6w7hd1Q4zD6isKEowx/irhkVDs0H
Ti10dQt2AHnz/vIKh4tKt3/WLQqBhN+pCog/M8Ig7rwHDa8j4RD3v6tw8OJh
0m5/F4ER3uh8AO3bthc=
                    "]]}, {
                    Thickness[0.0017714645833333332`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4nc19qZxnyoctnz+e6XiZJQDOt/bvNMxYXaF
wxLXbZ//skQ4ZEx8W2NvXeEQkCQQYfkkzAEo+/TCmnKHnul5Qs0WoQ4zgNSB
jjKHNTJRKdbhoRB5njKI+pRgh2MgAytKHSy2nCjbJx7osEOu9XWgRJlDw0s1
Qw4ZH4fYXZ48TOJlDitA9k3xdugA6ecrc2AAgQQPDH4cSH1xmcOBkskSLGEe
DuX75kvpzy1z2ACySNHD4dBXjZj+O0B5EH3J3QHoqvv+X8scDO6qsDWaukH8
l13ukPH898qPRW4OVyuADplS4TADaBofrzuE3wHkH1HYUJTh77AI5K4ZFQ4t
B04tdHULdgB58/7yCocrSrd/1i0KgYTfqQqHEyCDM8Ig7rwHDa8j4RD3v6tw
8OFh0m5/F4ER3uh8AANqti8=
                    "], CurveClosed -> {1}]}, {
                    Thickness[0.004633204166666667], 
                    FilledCurveBox[{CompressedData["
1:eJxTTMoPSmJiYGDQZ2RgYAbSDEAOIwMjMzOQhDCIRPjVw2WJN5ZIlQSVUa6A
bPVoKqnud2JMINsNBGONoMn4FVArXkhyJIWxQKqbKYxHAMnLCKY=
                    
                    "], {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0},
                     {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4,
                     3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}}}, {CompressedData["
1:eJxdW3mcT+UaH0v2O8mSJblZwkXkhgm58wppoYT8fsxqFmMs8zu/ddDiLL/l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                    "], CompressedData["
1:eJxdVn9MlVUYvlErhsQynQNaJmSNQoP+YGry4yUqRswRtgxDrkYQrtn1O59O
r2XZPae7m2tpyIxWmXlTzDBWJkiuQQNDsVYUmBVzIv1gXQrQrOUs1znnfeRr
sbFvz33PeX887/O+35dWvXpxbZzP56vX/+Z57utF1deVKdrz+pFZ7x9x6DJe
cPDYuo5Bh1bW/7axYK6iH8yBVEE+8zdF0djGghz/3YLPT0hKmntgx/ijgsy1
naOSnhy5uO9staCuPzKWbdU4PFrePrNEUNvv/wwENbb30gU98fHahuTvJd0e
mfHdF52I1+9hnZW78ksP32Qc9UryHy5JjOt3aOHpspcaeyQN6Ucg5lDWqdlX
h7qRzxWI1ybpRPCXW+/MFtRq8tsnOU65oOGnprcUb5P0SI3xJLjO5yRNU58c
3/WQoPUdO1OzVku6yxSWJmi3k5dwslySuXZmzKHNhSt+6rvHw02Gx0IP2/o0
Plo6b3NhAvIpknS98Z8paINOK/4+SdeafMuAtb/GgD6xSpCuMjOSLzmPNYLy
E06+7SwAnxsEnTGBciQ1JF+1JGm9h20fAv+zV8JfouS+XHLolaIXV41c6WGT
5gqfhy3/F0N8P0XQjYaov0KUZ/MQNKDbWPFniDJNf5ZCD+dwXvNpeR0PMd/N
gnJNv34NcZ96BfvX56P3amYOChrf21M67+8Q8/0M/CWhXynoX5qkvvTBC88u
wf056G8Q93OgvzcE39O4xxT2jofNtfoPBdc/H/W2C+o39eRJ5kHbXzV9KIT/
FsG6KoYewuhXqWQ+dP3GvPcBSU+b/scLCpq+PS5ZV/Nx3oX+F8PfJsk6Wgt7
GPHDuL8F/qKC53QLzkehx7ckz+XzuN8sOW8X5w8jvxLMZzf4yEA/PpdUZebp
GszjCUntM7XCtH4tL99gPs467P9b2M87/Psg+jED+jiF/PPQnyHEq0E+w5J1
rOvbbvgfhr4jmLcfUd/LgqZW6E10s2L+86GnhYrjTxdc1/2K411w+HyF4vkY
cVgPldhnow73p0qRUYF/wqE5Bi9X3I9kMYltX4o8bPl9AfwuUzzPr0FvxYrz
6MS8ZcEeA993KPrK8BNDPbcorvMzQZWmnlRF3YbnKOyJiPcfbPVz3MO23hHM
82nsj4ddtvd72O7LPg/bfI+C7wKX8+uQPH+zXK6vDfqJg7/90GsM+ngXeo5h
n70pJ+s1bWn3SzKyCgRd3mN+3N/mYauXJpd/fwzzvculCZNfAPltctnfOthr
XdZPBPst3+U+NcB+G+rdj3m4JBi3Il68y/3plKzTStTbhX28Bvn1YB4iLuuw
18NWzwMetvtjCvQ2FflOU5N82fm5QbGfLkHZZu+lob9j2C8Zip/pLj+zFecx
2+V9lKvYz3nMR6FifofQj6WK+WgTdMj0Qyjeb43Qyw7obTnmr0mxHrTdvj+b
kf8h7NsDivVwDP5bMT+d2L8fKebvA9hbMC8PCvrUBN6jqNgQXQD7bnxf5KIf
2xXP/yLkG1a832qwD+uQ/1bBvNUh/yLoqw75puB9WKv4ffuzw3GqMY/92E9V
iPee931jeY56+PL3z7/RviXx
                    "], CompressedData["
1:eJxNVGtIFVEQvghJSJaZRNjLykyysJISNXO0h5SaFP2w0BRLEjG7OItdNQrP
wVRCzIJUTMxXIkRImNrLxExFKKSMKLKLRNjLTEVIQuqMMz9aWA6ze84332N2
16WeO5rmYrPZDpib1tyvftsXZiuYehWX6uGHEBtcEpkSrsBG10Wpdyr41FTd
63MN4eAil4CiXQo2Fy1/9/IRwtKEkLaBYAVvHAboC8JEc19McJiCGDr3RGqD
17mm8PuRRoT08vELETEKiiNTPg8Z/MVb79VMJCo431XrHXhK9ucrfh6EUEL7
ShUkPTSdk5F5ViogOq05CM9m/BPLbinI97obPWr4rTVtOk29THcP1tUgJJb1
zPjXKQggvg+QzzUoCHd722DvQHht4BL6Ffi0ZqeX5yLM+zGmGDdK9Jq6nwRF
Cf8fwi8NYdWJ02HOnwpC2wZyunJFz7joqUVw0PpNQf3+9um5TtHjFL9tFjTa
DZNRBZVZnrrbzYJD1G9SgTvhOIXfrPAZFPwFGpzxpRVZdxA6pueGHe6a9d9E
CKMX3pr1FiD0krCVmvNRCEQ33kdDBfUzeWQ8tq6v2KChh/ANvz3ky0YNZ8f+
tEx+QNg24utaYOr5dQbhvpFZa+r5eVhvwS/KK0pz3qMIN/ZeyRxL1KyzUfgn
az5XjxBIOGc0+/8UYTTPEM8UPUNS2zX7PCvn7cLf2+JzduG/z+I8szXjxlus
x6FZZ4TFPAs09BFBXwsayO88zX6+R0ii+cjQEEL5VUteJzXjZiG0k7+HNUQT
MZPnMPEJ1TzPHxG2mDiag6TfCDIvP83zUIXsq8ljNW04jkCPaz01z8Mx2e8q
fl6W+f6reH8Twm4yZk6+x3qZ59+K/UmW/KZkvryQ5+iF4hzjEJ5T/i0y/4WC
X6XgNulLkfqqYn9ipV+xvN+B7HexzOMmZJ6mntflgZz7JfkfLBG8//4n/wAn
LwFL
                    "], {{648.8359999999999, 326.855}, {646.438, 
                    329.01599999999996`}, {644.7850000000001, 331.074}, {
                    645.164, 331.43399999999997`}, {645.543, 
                    331.79299999999995`}, {645.9689999999999, 331.895}, {
                    646.113, 331.66}, {646.254, 331.42999999999995`}, {
                    648.215, 329.367}, {650.4649999999999, 327.082}, {
                    655.6519999999999, 321.82}, {654.586, 321.672}, {
                    648.8359999999999, 326.855}}, CompressedData["
1:eJxdVGtIVEEY3RYTMZNNIkVcsyWyB6VFYGLSMRWTCKkfISolS8JSZEvcqS2k
mLmEKISIhVGE1VaSREhtJhEWPVT6IZI9aM2sNOxBmaaklNTMnW9bcGG5fHNn
znfO+c7cJe4DOyrsNpstX/7Vs+3nzHPfS44r5x6ntH43YFO/JxzOkj1Zg06G
H82dWzM6OU583d6enM2QHf3K7+3nkKs1OV4GR3FmoPsLx+GOpsS00ww1OeUf
e8c4utT7swwbB4tONsYIfa6BYYHa7xRoSIjYGVvH0FgZZz7YLHBV9Q/h7RKY
v/rm+dEihiFF7LjQz5WEd0HgjDrnYCiMsa+qvivwTi5XRjNUL3rd86tX4FK+
VBbB0LfN7SgeEtg/8vvamD1cW/rmhmuLdxTT+oNC60llCHQf6mjqIf6FDA8n
l5fV3RK4rdalPsu/gICCK/LT+T7Sc5ChVK2PE1+QP/Gm1rOO8PaZ8NR/q9qU
QXinTGx5f3ThjUyGxcr4KlPz8JDeUlP728I0bgXhtTKorp5aE72u/uljXvL7
uqn7ric9LYSXzvBBtilwm3jh+7xsrYvwc02MP5PGJNG8XYSXQv5GUr2G4bJX
7hgQUHTKc5nW8YbmK+sjEjZqWCBtYGkkTyX8TwKS9dOL8eTHKPkp52f5PhGu
rXlPzXr/R+CR8s0eri0fpoz/tZWHoKF5+YnPpIFYlSuf0PpCeuKF9lNQHucR
Xi3Tc5zg2p8q0jvCtd8GnQ9yKJqVZaQvdJ/yyP8ujnSlP9T/L9f5vmNg7z2j
IUH2t9ZnDO2HvB9WvzjyM4nyn0LzcFBeNzComBTYyJ8S6jeH8rqbIUsRk/gq
FvXyPln9UgXak2Ww8si/FdR/2tD3L1Fo/m8NnY9owrtvQG1rHqb7321g9vfj
H3Wl+0g=
                    "], CompressedData["
1:eJxTTMoPSmViYGAQBmIQbct1fXFBSLPDTrnW14GbSh2iUqzv+3s0Q+iTpQ6d
jglPLwQ2O+Q8/73y47lSh/J986X0O5odckH8C6UOYP2nmx3076qwNV4udXhY
JbLO/UuzgyzIgJelDts+/71SodLiMD1PqPmAWplD1p6SyRLeLRD14WUOh79q
xPSHtkDU+5Y5THPuznlu0AKxX7oMop+/xSFj4tsa+7dQ991udrDacqJsH9B9
7WI3z31fAXXfvlIHm/v+vdMnNDt4gByyE+r+kmaHB0DhPKD/3i8/5m2e3Qxx
z7pSB91Nc98vT2x2APp+h9zqUocjChuKMsKh8mug/kMKHwAzJJYO
                    
                    "], CompressedData["
1:eJxdVGtIFFEU3raIkpAeIpFWJoE9FNMyk7Q9lmJlKho5s45uu+O+lDJ7kFEm
Rtw7SYlJ5QMpMzMpRCKWEPOFlmlBiAYSi4hZ9qMiI7IkpO7dc3GhgdmZs/fc
73znO9+dDeqJDJtep9MlsZs/8zvO3FhdRUDHr20yFHXVrwl3EaguWHm555UM
seNp5dUD3vWRFHW5PEkgfGzj4ks2CZrqngc91lPYd/XYpz95ErDolDOQQhpL
i4mVwTVwtqs+hMJfflXLsJ58Tm+LoHDaWfm1eFSGK/Hmj0ORFJ7+mHt7blCG
Kg60ncKX9LZ15JmId4n8Ihl8w57c/hZHwWe0sTAuUoaJ836tSQkUTO0Hlund
EvJLpzA1FOyebZUw30nhoiHK1N4gwaHosngzEfUqJeyrXOA3S5Bl3T2eViPw
t8iwQo5xDTRR6GQyLeqXIZnv76Mwsym7ojdMRhw/DdyzJfkd1zIhlJVrNmi4
f68McfwlQIMALthDBest1UDzf/fmV24OTHIBV2lwL5EhZZuAdbFVS9XgJS+0
3wy9P1khhwZcpuBuM3jmVawhnz2W+TgkYklLoOqN1/JG6izIr0iDI1yIRgvk
VDDETFHvrgXyWNuGnRqw3yjTHQvqHaohrxYLPgNFvRkLlHEiOtFfgYr96TXs
67eKfQUJPa7n4jxiNLjAxjThY0V+vqK/UisoXO8ZCt3MdmM9VvTPawqrmPsa
jDb0YSvFfkZsuF4g5jNlR37hFB59H05RnQ70o5sAY3F4kjhwfyNBvFoH3C/k
jAnmT9uRL4s9eP52OMj17yRQzjcm2HDeCylwexgmchEvg6KPUlT0i0yhhv/v
q+K5UIQ/5o7CdHN/crSJIl5pNuIkCf7DCnCbljD/e/TaoWA/m0V+kILzmiLo
3wUK1n1AIJXL+iELda8leP4Gs+A9Pw+UYJ3ELHjB9TpOoIHP+6YR8+1iPcqI
+psIJPD98TLqYxT4Lgn9rIjzfkvCeTu9sQfvpDfu434lZP48/v99+Qe+3O82

                    "], CompressedData["
1:eJxdVGtIlEEU3SKyLKWHRQ8TszJ7qohEmXmzRDPDHuqPqNhvx91ZNEsyCuyb
AemlQpmFJGlIWdFDxR5GVFZU9ISwB2RYbGbij7DSUjExmpk77RctLLuHuXPP
PefeudMd29c7h9psts3iK383ZsZ4Ut8ymB05oibwhB0iPswcXtDO4NDxbeP2
3rPDsUnDMvy7GHSacdFbflt48bUnu+7MMLz48epFRcs3GZDUmh9QN8ggdHhB
2YpsA+NiONytmhL+wTQwzwGOfEcNuN8TtqkkjUO45G01INb3bXXuZA5L5L04
B9jkJ4CDTG8vckDb2YqHwUk6vkifmxb2X3Dl5LfXHFJkfI8DlL5WDvu/rLsR
lEAwroPDKEETm0VAiHx2qk3zVRBoCmnp5806voEg7y0OGTJxHwEZVrWPw3h5
r5PASxmfz7GOMwSC63e4S7drvWkE3KVC8WYOuVKYwHMPTnz3IopDvL29KaSa
wDKpt4chz+RMzPOTwbsXfRva/JyQ0zFwoSuCw6WuV2sclU7kXcMhTyb2OPGe
wNOk0DYnlMu2hen657jQzyEc0mX9eS70Q/R3luyPD8V6+hj6MZd6+6f8i6ag
xiCQw2H5Zz6FPQF1ia1LOfo0kcID2b8sjvn6XNhP0Q91r9eF9ZVwuCjrD6Bw
I0hU9oSjvhwKDdLPYg6nE67/GPxI0a9w7fdjiv766n42Uqx/gHnPu0XaMb0M
egXt/U6Nuxnm9XWjLy8Z8ke4UV8tQ5/i3ejvVgY7JDFxoy6Bt9xcNXroP1jV
O9LCag7PU9S7luEclVHs/1TN94Zi/HcTSmSgjxt9eWTivHmoF6u+77Ow0r2Q
YlyXCY+kkcMo5Ev/l+n36q/15mv9EyjGmRo3uvB8JYMjkj/OBYlS/9/6PjsR
x2hc6MT3nK3fs82Jc0QZNO4UJ0GZ6H8UwzmsJXBO2FDvy/BdpRPkE3qVP5UE
8z03QY5h7G8CnlSxWcpN3AviPan5KTbR7xKC81pgwle5J5IJ9qdQn88j+L6v
6nyfHCCmor2pycQ5u+zA+F+mdx+ofoxlXqzqXmVhxZfIcO4iHbD7jni4flp/
s4F99Zg4T2JfKX2hDN7386zbYp8p/hQGLRLnGt75UP3ZaOFX8jfZwiqfv4F+
ntT+p9nxHdRYWPFdt7Dy86nev3l2+H9//wHKOZ9v
                    
                    "], CompressedData["
1:eJxNVWtsFFUYbRpDGi0E26YhgstDRSwh5WVMRfCIBVQkaAlo5BHS3YGZO1Mo
FUoVvDMbIg8JtBUNAsHyEBOThodKKWhaUgoFf/CQWm1lgaaxlSglUG1jGhLv
d7/LLJtsJmfn3u873znn3h1ZuLLASk1JSSlUX3o6lbfXv1wT4OO/3q6NHI9C
45YACwaN+3ZvVxSvp6eO3TQ0jkd/PVg89edYiDsO7WkckW6FWO16fknEQuOI
oyV2WhxXRv3+nyyx8MGt0RPS7gZYfEqtbLLw5HuxKTfqAxyYUdNzv2wZ3nxh
yytLPwlQPFV1+Go511sf8Lp5Nugxd02AZwbEP3/1iM31Cwy/2Q7zuOkz/wsC
3cSjTaK+6oncRKMHr6v/m7vbJY6fL62r+tLDNBrEksjccPqn/Vs8qO5/XJ4o
MYwarfVwY+62nSsikvsprPv3f8Tzl3qgtncUfnZCWvWwEo/r5ki0Xuyb1/Gc
x7wXmvoJl+fcJ/EY7c8x+zskz7vaQ21EMe+UzH+Nh4Z/xywq75awyYc8D7NJ
nx7J/bM9FNE8f5r6rS7zbZHcp9rFZdK9UaJXlWmIuzhJ9U9JqF/Fj2+5yPte
Ea6XrBtcrK1TQp2VqKDGuS7z+05i+84VGRvSXRDN4l2S/bwnmK8t2e8GgV/K
lMEzJc/9lGB+XhJrXcuTWOt9zfBrF9zvqkT+VuXUSJfnvSSxLuvwrPbpLsju
yiuGf8zl/b8ZvYpcEM3TvRJNtLHC5X3/SExXy0b1i1Af7c8xEepDMlRtFKE+
GaTnfBHqo/OTL0J9zlH9ySLUR/N8XIT6lJN+fQ7XVfqUkIFNJp9KnzbiP8a8
95JY8/40iXX9hOR8XXc4D80P9BGY1f5h1uFLhu8MEeqTm3h6QNwRoT56/SrB
ufj7Qd6NH30SKfTJEthM6ztNPtscvEb1EyYPPzgYuym79WLC5LHSwY4hjywY
1CXxIg2y0kEOve8z52WSE9bTPtTZGEjzNEl8QT7ttvG1kuOo0ns0rd9q8zxn
JK7R/J7N+ncYP1+y+Znhsx69y9n3TJ/rdSexnrN2WYj1+hqLczrEZ37vW5zX
8T6fp5kW83zDx3wSPtNiv+f47N9DWOuVn8T0SJRZ7MM6n/U9abF++5NY169O
4iV0D/b4Jt8WIppwwOfhWAyLKEj5Ad4hPsNjuDqncPC7bsD5OhjlvJUG7M+e
KE703G8uiwfMd0cUZykQ2wKjbxTanoqA+W429/lnAZ+DjVG+3w4FfG/uNvf/
Q/8H/wPhWdiy
                    "], {{484.76599999999996`, 196.805}, {
                    484.76599999999996`, 199.41}, {479.387, 202.195}, {
                    472.953, 202.918}, {467.758, 203.5}, {467.672, 203.465}, {
                    467.672, 200.871}, {467.672, 198.72299999999998`}, {
                    468.48799999999994`, 197.879}, {472.074, 196.316}, {
                    477.83599999999996`, 193.809}, {484.76599999999996`, 
                    194.07399999999998`}, {484.76599999999996`, 196.805}}, {{
                    490.66400000000004`, 197.04299999999998`}, {493.289, 
                    199.42200000000003`}, {494.53099999999995`, 202.254}, {
                    492.953, 202.254}, {491.137, 202.254}, {486.32, 197.93}, {
                    486.32, 196.30100000000002`}, {486.32, 193.758}, {487.215,
                     193.91}, {490.66400000000004`, 197.04299999999998`}}, {{
                    485.07, 204.75}, {485.29299999999995`, 
                    206.22299999999998`}, {484.383, 207.20299999999997`}, {
                    481.65200000000004`, 208.43800000000002`}, {475.77, 
                    211.094}, {468.734, 212.324}, {467.039, 
                    210.99200000000002`}, {463.91799999999995`, 208.539}, {
                    465.9959999999999, 205.24599999999998`}, {471.039, 
                    204.65200000000002`}, {473.07, 204.414}, {475.824, 
                    203.797}, {477.16, 203.277}, {481.03499999999997`, 
                    201.77299999999997`}, {484.72299999999996`, 
                    202.45700000000002`}, {485.07, 204.75}}, {{485.07, 
                    212.63299999999998`}, {485.387, 214.73}, {484.043, 
                    215.48000000000002`}, {473.08599999999996`, 219.34}, {
                    464.90599999999995`, 222.21899999999997`}, {
                    461.28499999999997`, 220.859}, {463.89799999999997`, 
                    215.895}, {464.809, 214.164}, {466.34000000000003`, 
                    213.375}, {469.76599999999996`, 212.859}, {472.316, 
                    212.477}, {475.801, 211.73}, {477.508, 
                    211.19899999999998`}, {482.074, 209.781}, {484.715, 
                    210.281}, {485.07, 212.63299999999998`}}, {{490.562, 
                    220.02}, {492.215, 221.695}, {493.566, 223.672}, {493.566,
                     224.414}, {493.566, 226.816}, {487.039, 222.562}, {
                    486.207, 219.617}, {485.207, 216.08200000000002`}, {
                    486.824, 216.23}, {490.562, 220.02}}, {{485.074, 
                    220.516}, {485.43399999999997`, 222.906}, {481.457, 
                    225.062}, {473.637, 226.72299999999998`}, {467.902, 
                    227.941}, {465.371, 227.25}, {465.801, 224.586}, {
                    466.03499999999997`, 223.129}, {467.945, 222.066}, {
                    473.367, 220.375}, {482.039, 217.668}, {484.648, 
                    217.69899999999998`}, {485.074, 220.516}}, CompressedData["
1:eJxTTMoPSmViYGCQB2IQrX9Xha3xdJ1DgS3X9cVfchy02sVunsuud+g/9FUj
pjnXweNhlci6ynoHNbbGqc6v8xwuKt3+WfeozuGbRkz/Ic98B8stJ8r2La5z
WOS67fPfgnwHd5D66joH2agU6/vRUH5ynQOQdH/Ilu+QMfFtjX0gVP/RPAfF
DUUZE2PrHCaA7PPPc5ieJ9R8oAzBB6uvR/CvVrxUM2yrc/A273RMsETwtwKd
MV8OwRduPnBq4cJcB5C3CibWQtyXkeswWYIljE+31mEGyJ5zuQ5WIPdz1kL8
9SnX4YF/7/S8XzVw+8D+E6+F88HhoYvgV4P8ZVPrcPPc9+DHa6HyhrUOQNOy
9nzIc3hXY28ap1QLCQ/vfIcLIHu+1DgUgzyWnQ8R31gDCX+PfAchkLulaxxc
unOe//6ZB4kP+RqHffOl9O/OyHUA+vrphR01DnG7PHmYmHMdjoECwqzW4fHS
2UcUOnIcQMb5e9Y5FILMa8hxQI9fAIGY6Mg=
                    "], CompressedData["
1:eJxTTMoPSmViYGBQAmIQbbnlRNm+9DqH1teBO+Q48xwmS7CE8RXWOczIE2o+
IJXnsMh12+e/OXUO3zRi+g+Z5jnYcV1fXBBb5wCibP3yHLzNOx0TrOscwOY0
5zmU75svpW9b51CUMfFtzeU8h8NfgRqToObp5TuAlM2vq3NQZWuc6lyc73C1
4qWaYRPU/Jv5DlrtYjfPddc5yEalWN//WOhwQen2z7o5dQ65z3+v/JhT6jAd
ZM49qHu5Kxw+XfJNEjCrd+DT3TT3/eoKB6Brnl6IgPJfV0Do4HqIPW8qHB4v
nX1E4VcdxJ/rKxze1tibxrXVOeyQA5qYUOFwDOQhvToHK5BDf5ZD9D2odYjd
5cnDlF4Osd+n1kEb5M7AMgeFDUCfStZCwulOCZwPdt/BQjj/Esgfv6D+l6mF
2NOSD7HfrBYSHvr5Dh0g9/vVOlwEqb+XB3FvQK0DkJe150CeQw4oHOyg5mXl
QcLLuBYSvkZ5EPfp1TqAgt/+b66D+8MqkXVAeXB4fs6F2B9S6wBUdWrh1lyI
/S51DuqGHGtkjuU6oKcHAMJ3/wg=
                    "], CompressedData["
1:eJxTTMoPSmViYGCQA2IQfVRhQ1HG1UaHY97mnY5hRQ7TnLtznl9vdODT3TT3
fWyRwxXfJIGIS40O0/OEmg+0FDl8ugQUONnocOirRkz/miIIvavRYeuJsn3z
XxU5zACp29LoUC2yzv3hlyKHrD0lkyUWIPi2XNcXF8Qj+J48TNrt3xscls4+
orBBr9gB5IyEngaHqxUv1Qz7ih0uKN3+WefXABE/WuzwGKTQsgHijkvFDvKt
rwN3GDY4MIDAkWIHgQjLLSfkGiDqFhQ7ZE58W2Nv1+AQtwtok3exQ7vYzXPf
8xog/pUrdqjYN19Kf1YDxB/fihwqgdZyCDc6aIMUHi1yiO0Hyngh+GBzsxB8
magU6/tAfu7z3ys/HipyWAbyR0Sjww45oMP6ihxA0v7ejQ7AUDm1ML3IYdvn
v1cq8hsdrLYAAyy1COKvZmj4phQ5LC4AhtC8Roi/44og9JpGB15QfIRD3Xeh
0aHDMeHpBTeofiQ+enwCAHk04P4=
                    "]}]}, {
                    Thickness[0.004633204166666667], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{CompressedData["
1:eJxTTMoPSmJiYGDQZ2RgYAbSDEAOIwMjMzOQhDCIRPjVw2WJN5ZIlQSVUa6A
bPVoKqnud2JMINsNBGONoMn4FVArXkhyJIWxQKqbKYxHAMnLCKY=
                    
                    "], {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4,
                     3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}}}, {CompressedData["
1:eJxdW3mcTlUfH0v2d5IlS/LawovIGybkdWRJRQl5HmY1Zox1nvusgxbPvffZ
poWRQmWNF2OLbENCSBpEdpGyRWQdKdHrved8vzP3U/6Zz+85957zW76/7+93
zrkaprv6Z5aOi4uLLxMXJ/8u0LpUOlpRF/XCl18ueNgpZmRXM7c+pgvfiClX
XpvuFI9/Ouvaora66F2ldMuoNb791+ZJk7vp4lCjE3feGOWAPFYXNVY8e3rC
GIeo6uy4ZtebHK/rFKM2+abWnsf55jjFQ3J8tT3+QkJut7Q9uvjl5YL64dEO
MdJ6rOsfumhSTn+/uyVvk/PXMkSwa/uUjXU4XytDxB4+/s1vU53iH1LB1gb0
m+YUz8m/TxtiTdGfh8Z1dIqnf3jpnek9DNHjrTEX7pZyiiEZnX94KckQaRut
J7c7xLVFO19IcBtijFx3uUPUkw9MM0Roa+G8nhGHsLwzX5tuiF1S0ZhDrJfz
LjeE8+x/P9qR5xTxcv0ththqqVU2e7CIdUs7v3+bIZ5asyuw+avBYkeDlZ4R
mw3RR+o1e4ho871l2WeGOGl5b1OrRHGwb3pVZwH1eygJ66239LfcvvOjJMRj
rSHm9lxX9Od7yVhvbbG9yXj/LMdrpGC9ewbeG5IivpRyHVO8Pd36oSBF5Er9
GptigXz+XArma2/CH0+mQs7i86G0ElnN96ktq+e3pGG9gab47pvfBpz9No3+
5/sn0+D/7w3xjLVso/JDxfNyfC/9f3CokLDoWtkUt60wb+s7TDwq/e8ygZf1
mWKt5cY5y0zxsdS36ggx/uembSssN8VPlvsb5I1E/CzZI5/vPEq0knj9xIQ/
fKOENeuvzdeaopOMx0ujhPwzZ3fx/CPhv/mmGCX16JglEiU+htM+Vybs7muK
q69ZAFyXIXI2z6nbJtMUcfLfngzg0WMCN0czxLTuViA/p+zIFAstNVf+IySW
3TjQN/1iJt67GMK4Nwvyk2HRR+bBF1nA59awsFYtnJefJaSZKztEIL+fhfVG
RkTEStf6lr5q/k0RsV/m03eZIirz4mIE+GqQCXurR2H/RxnI56FR6HOM/i4f
Ezslvp9KB37jY+KcXLhGuqiveCGGeVqkQa4fE60kjv1JQoZ5a90Y/Nk1Cetv
iiJfP0gE3sZERR/LzR2rJCKfO0XFuQmSMQbDnsejwH83J/R5LCr6yeczHIh3
+6j4XeIj2SH+I/MjOSqekOs/7hQ3LTOqvsrxL53AQ8weV3j7IIr8znSIQzLe
m6OituQra34Vr5NR5FtLJ/Qviooq1jJdtjmhb+VYybgy84kY9XUgfkNjwMkE
B/yRHRMXZUBmO5F/7phYJgN+1CnWSf4YF4M+lr7q+UgM/hpKfefRn4scYpzE
208x8InDgXy4EhMVpH6XyE/XqU9D+uNyTIyTfltG/j4dAx7qDRb/lPHbwPF7
Q5g/MZEnFfkxEePLqN95xnNpDPzXLwV+3UB77qcgfpY+Kr+rp8GelrnIl51p
QtJkg665wO/yobD/QVtW+t6MlciqHhyiXDMdfPsF59+SDjx8FAOea2UgPh/H
hLS23oeZ4rTE1cmY+E7ZOwJ59jDXyx+FPHs0V/RS/hoNf1rytzJ/jowBXi3Z
K/2fkC06S/56JFfIMjnflw3+Lp8rmsn1Orjgv7sxMUkavswF/jgTEwUyUVpr
4J/9MfGmnDdFgz8+iYkUyS/rNcT7eAx5/6cG+xJzofdBN/hU5Ir3apcdFP+k
F/FcwPk3ehEfH/1x1ov3R8Zg5wUv/FczJr6Sjv3Jy3oRFRKWU857We+iiNcx
L/w52sqXC3fzb+zyAl9doyIgcbjBC765FREHpL+WeZGPX0TAF5as8kGL4Pel
XpEs7U+n/IkX/cEzEfGqTP/9XsS/UUT0loEr4nr1ItC3rA/2PBxBfg30AZ81
IvBXpg/1Pz4iWkpH+H3g54pcb7wP8/8vjPgGfagPhWHkcTOObw/Df/e9mHdL
GOv/4sVzm8Lw1xXKqyiX98H/+WHYU9sH/M/hesIH/HzI+VN9wNs7YcRvhQ/9
06ww/PuzD/y6m/rV9CP+18LAXYIf9fa7MPz1sl/Ml8BcEYb9UT/8lBEGjtP9
qNfPUd+KfuDimTDifd2H/O3E+U5Q34SwqC7z5QT90z4sGsr3T9B/TTle5GN/
FhaqLDzkh/9+CAGvE/14/mYI8zcMgG+7sN4NCCC+w6n/2ADyIZf1b3AA+ueF
kTdNAsi3mWEh1cw+4Ee+b+H7XQKIRwHtnx3A3zVh6hUALtbSn6cDiNfuv8mX
bFn1q60i8EMe1+8WQT3sR/2cEeRLOY47IkKVt3f98G+XiPhR6vu0H/1Q8wjw
8bsP8eweQbzL+LH+qAj4oTrjl0d8d/fjuQWREv+qfCxgf/C5H/m8MYJ4JVD/
xRH4ezz1mx5BvDZQ/oDrbw8gf1YzH5cH6LeImCrXyw2I92X8btP+tADwXCGK
+R8JAM+1o+jXTvrh7zpR+HOvH/GoGsVzb/vxe+Uo+CSDeLlPe9v40ddY66nn
atF+q79ReL7BfLsQQf5cJp6LbFk9XyFaIit+aRfF75Z/Fa56RGFPOz/w2If6
9vQjHxxR+Nvlhz+TyY95fuBiJN//xg/+C0QRjznMB6sfUX5N9gP/S+mvhhw/
GhWHZUG+58P75dh/HfLRfzHE9VvyYSnWi9/IH9ejyMOqfnFdxvMA5W3kixNR
zHvIL9R+78co+O2UH3o1iAFHr/kx34gY4vQH9VnO9SdSPsb67PD9tb46yL9Z
tqzw+34u7Djrw/ruXOAri3hIygVvrSHeH+fzWxj/apRfp/8eYD1M9SOepXMR
j15+1JtyucB3M+KpUi7iHMf3K+QiPy371O+/xUpkFd8f/iavYv/bgfFOY/3e
wvWteqrkyYES/Ch8dc1B/36K+TkxB3w+I4L8WJyDeUsX52MO4vpZGPPNyYF+
2WH4x8hBf16N/N0iB/qcDiFfdpNfYyHgyeJLtV40hLhYeFb1//sQ3pvA+PzK
/UhXH/j0PN+vQv7fG4K+W73oZ/aFUM8SWa8vhZBfD1G+HWJ98QCHpcmnhz1Y
/wFbVvNVYH2yZMVHlcPwyyUP9K4SBn+W9SIf41mvenrBp/VYT9xe8FG7MPBs
eHGe8HwY+5t3Wb+dYeDlTfZDn7F+dOb8jSPQ+6IH8dxHPj9D/cPkq1Zexpf5
388L/ukdA7+/SH8EYtC3GeXdMdjzowfxtfCm/NfMg/5ubgzrf+iGPWG+n8x+
cHQM+vdwo95VZ39Zww38fBuFvdfZX34RhX1XNOjXIop+xRpXflrMfqlIw35j
AuvTVQ1+7cn6dYz9aRWOb9WAy4th4GSzhvVFGPrv1MAnrxMP+9kPTw3BX8s4
35wQ7JmhgQ8+CWHeoAZ/FYRgX4D981ch4DZTQ37vZH8xjO+vDAFfAzT4Z34I
vPW8ht+jxPcz9I/blpW+z9mywl+PEPr7ey7gp1tIHJfnHatc6K+70Z4hLviz
B/XvxPHnmC+VXcDLs8ynsi7kW+cQ8r2WC3n475CQZjRq7MJ+6ZGQeEyeh3Xm
8+VDYqncv/dxwe9FJuxKdmH/fNQU+XI86EJ/WGgKSQt3P3DBb2tMIc36focL
/PqpKTpK/ba7UC+WmLDnTe5v5ptikHzR4QL+Uk3sfyZlI/9esWXl54G2rPjo
Za63huOWvETqdy4b+vczoXd17p96mdh/TXYBT51N7P9+o/1PmMBlGw383ITn
LVnEY0MTfDqeeHvURH5NJf4fMZG/7zHeNXm+ZOFN6fGQCb18GuytYiKu/TTk
Z0UT+P+3hv1MORP1tIYGf9wzxBW1/3XB3iID+Wb5U6132sD79V3A9xED8X6V
8Sjk+CniZZ0BXDcifj+xZWXPcltWeF9sgK+qaTjvWGgAX/eJj7kG8LucsttA
fPZkI/7DbVnxQbotq/1JigH8VXGVyCreQ2xZzbuI9icaIk8SwgXaO8iW1XMv
27Kq3y8aOP89aMsqrhttWdkz0QX+aGrrh/7TlpX/qtmyyt+KBvC8Phs8VcbA
+eOsbODpli6kml2GZCPeF3Xkx7Bs4OyqLqTby67Iht9v6EKehm/aT7xf05Fv
DRm/Szrimu4Cz57Xof982v+DDn0uEP+nOH7XhXpzUge/VdSQv3t17H/KFeNB
RzzP8/03dOBtoQv91ljqY/GV4s+ojvyO03DekqcjXx4k387WyXPk/4U63tOI
pxU6+Hq2hjzZqAOvu/j+Vh31Yg/f/1oHDg5o8M8uHfm4m+ObdeTXCg18tU7H
/vhD5ttK2vOGhnq4kv5w2zL2DxrOA5ZQ/57Ub4GO/GxFPpjF9atr8M8MHfz+
O/H5IeN1k/iaqQPvv7iw31hB+8qyfu3QUZ9qayXxVnHqogEvlqzwW4/6XaK/
KmmIg4UXdb60hnz7q47z7GHk4/s6cLIvG/PUMVDf41zwTzvit62dHyofz9iy
wl17rURW/nHQfocBP/Unn1r5qvYfrcknSQb2k41p7zAD8fyd/DySfLCM9c9H
vmtEPohQv/EuxCvPwDliPuvXLM5fhvj62AC+mhDfSzlfCvl5g4F6mmPLCg99
bbm4Pig7zxrAeZj+vUz9Z7jAn9cM8P9cxve2gbjcZL2x+FzZ1ZT+Kc96EaK+
dVlvvmR/0tSEX9Zr4JcWJn7/VMN8rVhfFtO//zJh71zioRnr2QfEa1vWqyTO
35X1qDb5vy/vT/KZ34nUx+KfM3K9FBP8UIp4GsZ6vo/1eIQJ/x7JBm7DJvAo
WK9mmMgHg/1MPu3Z42J8iuu5C/3zCupr5Yfyp9VfqP6zDO3ZYQIvJ9lPnOR9
ylzmX+sQ8uM/Lvi7HeVBtC8hhP4glfp1DInWUo+1xHunEOpfJcbf6q8Un6Rr
2D/153xO6pfK/YvVLyo9XrX7R8W/k0OYZzD72zXs54aRP6eyn8vjejr3U/ka
zkuyud8qZHxHcf1jjN9w9rMXiIdXON8t8kn3EOz+XQO/V+P7cW7Ys5F4SLdl
lQ9TbFk9b+0nlD472S++5cZ56mET/tHciN9t4rOdG/Y0CYE/493Qo48tK31H
2rKa1xFC/nV1g++t51V+J7p53sXzQUs/hYdulD93o3/qQn+X8eD9jtw/xHuQ
PzVDiEM3yvdN+C+V+7VzvO97xwP7jrH/W+QpwV/x/lPx5wYTeTqb662mP4Ie
8OMyE/v3LA/wscSW1XyLbFn5baYJ/cd74IcpzK9JHuxXIibqxwIP8Pcq8b+O
+8HxtGetB3kXYP6spX1jeR87g+tlkG/8nG8A12tH/Z7l/EO4vxYm+ods2teG
9r/rQT/biPYvof9qEg/bPKjP8bb/1N/q5l/387VtWenVnPpu8iBfEohHy9+q
PvQ3sf+3/Kf4O5n2TvZg/5PBeFrxU3gbTv/toTyMfHTJA/ymcn9Q0wt708in
tbzw5wjqc88DfrH8qerjZcqvm+jfCz3Iz7eJn9WUF5L/Y4xHAfOvkPp/baJ+
VuF9SCH3B5as9DxgYl95nvqfJP+vpP4tyRdPeMCP2dxPnnMjXuPIV8fdsMfH
/CnlgR1DQ4h/Ev2dxPMfCx84/yC/zLVlpd9mW1Z4/pl478/9ueUvdZ7Sges3
82J/EB+CvRk8XylF/pzM+6I79P8NL/jvNvmpjo/9D/HZi+dxl4i/gTyfOk18
jPSBH37k+8k+4PUM8VGd573nuN5p+v8082k+77dOcL03qd+39P8Q3p9Z8VL7
f8MLf3/J+afTvtXM78+9iMtc6nfYi/PXSdzPXiH+dOL5AR9+N03sGyr5EL8I
xx/08b6afHKH/l1B+Tjv//aa6DcXe1H/DjHfLPuUnceIzwLer50y0S8esMcP
SfsEz5P38fm3eX5eyPxZ7QP+Covx74M+Z+hfk/dBRfRfGs8P/+T7CTw/LUv8
XuV5XDzr17vUr3oI/YrpBd9Y/I/vEXgf52A9qMzzvrHE70XymYv58gvzTyM+
rzFffcTjMC/qT4DnNVd5/zmB9eoOz6f9zJ+n/NDnFa7/lh/r9WR+rPWD71Ip
X+H5v875O/D8NY/2uQPwz/Ti81Tez8xk/S+VAz0n0j+FAchZzO9ZAdiZRHkq
5xO2jPMQW1bP16U/Z1Kf8iGe9/D9G+wXi3h+/DX5rEEO7FnAetKB8jQ+3zWn
pL4pPTvbssqz5ras5qubg/4/l/JN3jcFTfQH+wKY31XM/5RfIL6O8L6tHc+n
SuegftTlek1yEKfyzK/WOeDDw+zve+egPh4wUP962TLuXwIlsornWwHMv5H9
fyCAejTZgL1fBJC/2Tyv+SMAPAzg/qVcDvK1hgE77wTAx+d06HuV8bnC/f52
3rfd4vjsAPq/m9zPTub8Z7kfzKQ/rP01zn84ns/zigf4fsCWVX+dastq//KM
Dv6+x/uvDjrP74n/f/G84BzxXlkHvo7yPuRmkPxC/B8Pltz3qf3H5iD8scPP
86wg7NniR3+6JMjvq/zgv/wg+P1z3lcsp1zE+6rVfL5XAP3wtCD8Zgbw/Ehb
VvW1tS0r+2oEgee6AeR/iyDwPIX3yW2CsDdAf7QPgm/7UP+EIOplO96vdQoS
3/TXwCDieZT1yxdEPKfxe4GpQfQvTh/0WhXk9yysf+uoXzl+37AxCL/eJl8V
0p/febGPPs71C3k/cysIPy3nfcj1IOL7kxf88EsQfNyE9/1FtLc162dZni+V
9qGeVWL8b/K+pA7jb9UjfK/F85ivuV5HHXm/ivXqaZ7frLRlZc9OW1bPH2Q9
Fjry8Sb5vmfxeQm/N3iR50UdeD+Vwnz5g/3FcB34s/RT8xo8T5rkRX5/pINv
BrDe7+Xzp9lPX6Z+6by/OkH7e3C/cZjnOU9R3kH7O3pKvndV/PUs+8kw87M/
+8UM6uvkeoNoz0AP8N+R8/fh/AnMz4Hs13vreC/I+6hExmuFB3h0cnwd12tn
ywqPFW1Z7efnBfH+Kc43PiiOSP//zwN+6B9EvB9l/J8LlvTXKv5dKO/mfuGp
IOZfwn6yDfE9lvo3Zz72ZP1+NAh/3XWDn54NQk9r/6f8nsJ8r8D9wGvMp2oe
+Ck3CHzUpb3TaU8jxmM+86OpB/3SgiDyqDGfX8j8b8j911yuV5b+nE57znF/
HCV/5XN/O4/5ucYNfl/J+Tdwv7wzCPztcoMPD3C+Q9wPX6D+F93Q92fyxwU3
7LsTRH+5yo18jNfhT5cb/qnP/PC40V810tHfFbihV1PiP479UVsd9e1XN3ii
N/E1jfeNyTr4vJMbcfDqooWMTx034jWO4/3cyN/xOvZL6RwPE/8T6Z8pesl5
hPLfUtavtW7w22bWv6VunpMw/y17VD4cJj8kcL7PdOTxHzw/drNezeV5ykny
2xGeT4aDqHcXxqL/GRPE95DaaPSzg4L43jJhJPw1MygmSYBdHg65uY7viXvw
+93ROs6XJmSwv9DBw/8dhvrwjS5ek+O3h8F/q3ThkcDul4nzl0/pv3NZyO/9
PP8fMAI4PcTxjBHg84P8fv6fI2D/HvLRxizw41od3yt3H45+ZQvxUSsTvHa3
+D4jHc+35ffpW1KBzxaGKFA8kIz8+J7zdeb3nzvIh7sS+T01/bEmEfHy8nv9
zxLh75Y6v59NxPqN+f8L1iUif6vo4m05b+NEnNfdDopb8vzyfX6PatWz4u9v
i2X1/elFx1/HPfwe1soX9f2s7hB///8M/wf2G1El
                    
                    "], CompressedData["
1:eJxdVn9MlVUYvlErhoxlOgdU5iVrFBr0B0uTHy9REZojbBmGohGEawy/8+nw
2i+753R3s1aGZrTKzJtihjEzQXINGhiKtbIuacWcQD9YlwI0aznLdc55H/la
bOzb+51z3vO8z/O87/38lasWVcf5fL4G/W+eZ75eWHlliaKmNw7N2HvIoYvx
7fuP1Hf0O7Sy4bcn82cr+mGn3pAqyGf+JinSb7Mr7hC8f1xS0ux9W8ceFmSO
bRuRVDt8fvfpSkFdf6Qv3ajj0Ehp+/RiQW2//9MX0LE9lybosY/XbE7+XlJG
eNp3X3TivqgXa1Tuyi+9+DqTqFdSxcHixLioQ/NOlbzY2CPJPOpiDmWenHl5
sBt4LsF9bZL6Ar/ceGuWoFaDb7fke0oFDT0+taVok6SHqkwmwXU+I+kq9cnR
7Q8IWtuxLTVzlaS5pjC/oB1ObsKJUklP6GODow5tKFjx07E7vdjyWODFtj4d
9yy4bUNBAvAUSppi8mcIWqdhxd8NvCWIdb7X6jSCWkG6yoxwnqR6g2O1oLyE
E+84c8HnOkGDBn+2pFeSL1uctNaLrQ51/1svR75EybpccOjVwhdqhy/1YgNz
hc+LLf/ng3w+RdC1hqi/gsAhqE/LWPZnkG42+iyBH85gv+bT8joWZL6bBeUY
oX4Nsk69gvPr/ZG7NDP7BY3t0kz9HWT/PYV8SdArBfr5JX2V1n/u6cU4Pwv6
BnA+G/57U/C5bPD/rhf79bGGDwXXPwf1tguKmnpyJd1reNDrVget33GTv0Ww
TkWS8YWg1wLJfOj6zfKu+6B/vKCA0e1Ryb6ag/0u/L8I+dZLet74aA3WQ7g/
hPMvSTIyDkYEmTR7dWx9F4Ef35bcl8/ifLOkRoPbxf6DwFeM/uwGH+nQ43P0
0xXox28ktU/XDtP+tbwcR3+cdjj/t1g/6/D7fugxDf44Cfy50GdA0mFzXxXw
DAGPrm+L4X8I/g6j334EHy8LmlymO+96xfznwU/zFN8/VVCuyTNf8X3nHN5f
prg/hh32Qznm2YjD+ixTNGrm17hDs0y8XLEeyWIitroUerHl9znwu1Qxf6/D
b0WK6+lEv2ViPQa+b1HMTwz13KC43s8ElZt6UhXzHMF6Iu77T2z9c9SLbb3D
6OdTmB8Purwe9WI7L495scV7GHznu4yvQ3L/zXC5vjb4Jw759sCvMfjjPfg5
hnn2lpyo18jSXiFpwMzjgMt5KnB+kxdbPppcfv8I+nu7S+MGXx3wrXc5Xz3W
q132TxjzLc/lujZj/SbUuwf9cEFw3Ir74l3Wp1PSNcZI5ai3C/N4NfD1oB/C
LvdZrxdbP/d5sZ0fk+C3ycA7RU3wZXW9WnGeLkFZZu75oe8o5ku64nvTXI6z
FD9nujyPchR1mzxn0R8FivkdgB5LFPPRJuiA0UMoMjAbGuGXrfDbcvRfE/yt
1+3vZzPwH8C83afYD0eQvxX904n5+5Fi/j7Aegvy3S/oU3PxTkX3GKLzsb4D
3xc50GML+mUh8IYUz8sqzMMa4N8omLca4C+Ev2qANwW/h9U4/7PD9VUifxTz
aRni973vG8t3xIsvfv/8C0mFJgw=
                    "], CompressedData["
1:eJxNVGtIVEEUXoQkpIeJRNjLykyysJKSNPPT3plJ0Q+LTRdLEhFbPBfxEYUz
mFqIWZCKiflKhAiJUntZmGUIhZQhRbYtFfYyUxGSkJrZOT+6cBnO3plzvtfs
stSTB9O8bDbbTvXqNe9r8PqZ2QLjLxNSfYMJ+yJKYx3RAjb9nOZ6o8DH5pqe
wIuEPbO8Qos3CYQWz3/z4h5hXtLmW88iBAZyVaMvhNGWp/ERUcKce8C16te5
pOj7gSZCesXIqZh4gXOxjs/9qv+ctTdrR+0COV11AWHHeH+BML+HE0r1vjKB
5LtqcgoZnFUC1xScthzC48kQe/lVgXz/G7vcCt9SNaZT1X7yUV99LcFe3j0Z
Ui+wWuO9Q9A02hoFtvoMNjo7CK9Uu6RegcC27PSKPIJHj2GBbt03jvmqWqEq
jY1j/D8YXxph0ZHjUa6fAkqFnK485jPCfOoIuXr9JtCwo31iupP5uFhvm4Um
Z7TPoFugMksh9rGwV88b4/4uxjfFePq4/wyJD4lllVnXCR0T0wO5syUKNP8r
hCiX+hAgDd9CQo8mtlDitfZHEDTcxECJKj1P+ZFx37q0YIU0/RU+jy4rJTKH
/7SOvSOsGwryLlR1mF4nCbcVzTpVe/Kw3MIv7VecNH67CZe3nc8ctkvjbxPj
T5HQ8tQ1kOlzQpo5DwlubVwm8+nn2imNzlN83sn4AyxE63NOxr/dMn5mM75E
y/DJlYZnjGVwFkr0av+CLDRqvfOZ71vCUZ2PDIlIDbCG/UqWJl9ZhHat736J
3RqY8nNA44mUJs/vCWuUHS3hPG+IjI/B0uShmswc5YcnJ4fJ6OAnTR4O8X5v
iU8a51nO91+BxXp/M2GL9nOa72MD5/m3MPqksH/jnC9/Mro853wnEJ5o/1v5
vhZx/2q+Pw6uLwijzz6eV8LfN5DRu4TzuIqMniWcR1+CPuY4w/3ncr///k/+
ASkHAVA=
                    "], {{648.8359999999999, 326.855}, {646.438, 
                    329.01599999999996`}, {644.7850000000001, 
                    331.07399999999996`}, {645.164, 331.43399999999997`}, {
                    645.543, 331.793}, {645.9689999999999, 331.895}, {646.113,
                     331.65999999999997`}, {646.254, 331.43}, {648.215, 
                    329.367}, {650.4649999999999, 327.082}, {
                    655.6519999999999, 321.82}, {654.586, 
                    321.67199999999997`}, {648.8359999999999, 
                    326.855}}, CompressedData["
1:eJxdVG1Ik1EUXsNETGRJNBG1JdH6oKwITMx6TMWkQupHiEoNSRgVNuLespDi
vS8hDkJEwyiij1WSREiNkoiKKBv9EMs+aGZWGvZBmaaklNS97z1r4GDcnfvx
nPM85zmbX7lvW5XdZrMVyq9ab/6cel7z0sDl0w9d7d8ZbOrzyEBa2a6c/jSO
H62dm7I6DRz7urUjPZcjN/5VwNdrQO7W5/k4HKXZwdAXAwfvnk3JPMFRn+f5
2D1C56c41vaXHG9JEFin3jVxzFb30wSak2O2JzZwtFQnmfc3CJ0/grdDIHHZ
9TPDJRwDl+TBUaHXJYR3TuCkeufgKE6wL627LaC2q+M56ua+7vrVLXChUDKL
4ejZUukoHRDYO/T7yog9Glv8ZkZjv6o7jmv+YYEDio+bIxiSv7qo/mKOB+OL
KhpuCL0v+Vn6BQUUXEmA3vcQn/0c5Wp/lOoF6eM0NZ9VhLfHhLfxW+36LMJr
NrHx/eE517I55inha02dz0t8y02tbxvXuFWE186hsnr9Jp5m9E4e8ZHeV03N
bzXxaSO8FRwfZJqiShMvaj4vXJlB+PkmRp9JYVKp3xmE5yJ9YyleznHRJ2/0
CWyW5Xjyuebxhvor40MSNm5QILNvQazhJvxPArLqJ+edpMcw6Sn7Z/loLBpb
/Z6Ydv5HaN3s0djSYYL9jy0/hBmUTJ4A1TPOtK9qhOYX4eMUWk9Bfpwl9Orn
uo9jhtanlvgOGRhUejN6HzbwTuWrIH6ReSog/R8bmn8k/19Dr7cYdt9hTclO
8vsU03rI+bDyJZGeqeR/F/XDQX5dw6FsUmQjfcoo3wzy606OHCWExFe2aJTz
ZOVzC3SkS2MVkH6LKf8k0/OXQv59y7Q/4gnvHoO61jpI8x1imP7/8Q9/zftP

                    "], CompressedData["
1:eJxTTMoPSmViYGAQBmIQbct1fXFBSLPDDrnW14GbSh2iUqzv+3s0Q+iTpQ6d
jglPLwQ2O+Q8/73y47lSh/J986X0O6D8C6UOYP2nmx3076qwNV4udXhYJbLO
/UuzgwzIgJelDts+/71SodLiMCNPqPmAWplD1p6SyRLeLRD14WUOh79qxPSH
tjjIgtT7ljlMc+7OeW7QArFfugyin7/FIWPi2xr7t1D33W52sNxyomwf0H3t
YjfPfV8Bdc++Ugeb+/690yc0O3iAHLIT6v6SZgeQcB7Qf++XH/M2z26GuGdd
qYPuprnvlyc2OwB9v0NudanDEYUNRRnhUPk1UP8hhQ8AMHyWCw==
                    
                    "], CompressedData["
1:eJxdVAlIVFEUnUzCQqRFJGookyArRbNVyjyaYpuZBv4/M2ozozNOUrYgGSFh
xHsvyaiozIhSM5NAJGIIsU3asIIIC6JMxLQF2ozIkgh61zso9OHz/+Xf5Zxz
z/tz3DtzPEEWiyVD3/QsuVl2cnqNgIWueBPlt+tmxPkFakunHup4bGJVb9bR
M51j359nuieb/QLxPXMnHPQYaDp3P/JqkASObP/wZ5sBHe3xWSU26rTEVSb8
nXtv182TXF9rYrb4lN22SKLMd+JLxUsTh1Oc754lSPh//H2x75GJmjW60WKJ
z9lts8SNQLwikF9uIiz22vlvSRKhLxt3JSWY6Nsf3pqRJuFsXxca1G0wvmyJ
j8+iuodbDc73SVQmLy1obzCwcXlVilNItNG8EwbjOhro32zAXrSyN6tWIoT6
LzAxxUz0dzZJdGiZgh+a2ED19yR+R+cduxtr4jr1CVd4M3yg5GZ1LmL0uOZk
xfhSTSRN0i8zFabHacGuOHjeRIXqiFdPfxXmo58EnKZQn6475RVAs1ioNik8
pEFrnbj7Uw8qVkjVMkXdcWJkXxUK9Ahe7RqNoxeFtFjdY7GViJxzMb5yhVwS
otGF/GO6Y67CRZpX78I2TTt5mcLXCi3QBRfrHaMwQLhaXIzPGpg35EIV7cui
QLSSSt3ML0gxr99uKOIVGdDjeCHvI1GB1tQ3qYjxhSl0Er/KIjhI7yGtr7Zd
T0cR++eJBLmvwebBGfJhq2Q+zz38vVTy/Pdexhcn0fK9K9PtK2Y/dgu8fvpr
S78o5vpGwf3OFuPSLkIsOH/Qy3h1PNIvwov1pP8tgWoqTPPwvsdLlJBOfYXc
L0eyjzLd7BdT8nkJc4PWfNAR8MffrRhs1psskDhOhZV5IJslZwT82+UA2fSA
9v+IXksczGd+ID/Swft6L9i/4xw897LAZpJ1wM66nxV8/h7Z8ZaElgLbaU66
HQ9Irx2C/XXKxvlewTiW2lj/AoE0qk8xWR+b4PPrN9jPDoEY4nXa4H37xuKR
frvH4nvkVyFGz+P//5d/+0nqVw==
                    "], CompressedData["
1:eJxdVH9MlVUYvjmWxYT1A10qMqPGCDVwzjUl4MlyoMHUQv5wwu53D/eeO0xg
6Wqj75zNhSauImtOlzpnVrOGTk2YU2CMGqFtDq1N+8FuhMw/GBoUMHO6znve
4/1ad7v7vmfn/d73eZ73fc/TkYbXojNCoVC1+dNzU21hYt01hZylj7RlfhpG
weCzD+8YUfhwf/0T7/aE8clTKVXp4wq3/JLlNfcDvPJs/1vdz3hJ3PfqCy0v
bfZQNtSUcfKegsmy7+UtHlZQXKFGz5F5+YO+hzHKs0sjl+p97KF3Mndza6Xm
ukMeilKvHWucqzl/SQQh+mVolJv04ZYIhr84+N3CMhff4s79AKcvOXP49o8u
fjICq29Io3l0w7ms1QL5FHdTg8oU1QkYkZeODrt6BwUGsn+9o6+7+HYBkhW+
oFFFiacFKOxIs+bvxgSuUHyTZh6fCyw89WZ8b4NGN+mtFIjvNYqrNRpJmMF5
7835+fIyjVXhkYHsYwLFRGRSMd+5tZznb4VfLk+/PpwWxdabd78aL9D4evxq
ReRQFE9S3QqN7ZQ4EWV+BmeS0OEoDlDbcjV2Ef/nYuznQ47/thj7YfqbQ/2Z
KZnPtGI/8mSyf5bPcgk7Bpka79PLYol3Mk6WDr2ocZV0z5H4lvpXpznfdIz7
afpheUzFmF+r458hcS5r5+iGfs36tkq0k597ND5b3fHXvd8l+5Xv+H4v2d9U
188uyfzvquT5hEn72JTClCnbO+bwhOI+pcaxgD64otBG9QvirO+EYn6r4uzv
G4r9FHHuv8Hh82tmzfgPtnwfDfANmsPjkvWuVzwP+yT3f75ivT9Jjv/Tx0cU
ODPOfvb5PG8JmcS2780Btt89Lzlu3Of9SpFoIv+L3b6mO71NTv9syXG+w10x
Pn9Fcf2SGEpJ/wN+N6KMC50/u6O8z1sU+ilPKIqdNEdSoXO7OcmqZf+XOb0n
BL40NpxKVbx/GwXXM3qtP4cE5/vB5/m6L5BY98H++gNOv9knOz97fPa7VfC8
7vD5vlkruD+7fdTQ+SLB+/2Nj1mU748IzFSMDAz4PB+nIxz/j5+8D2w/HldJ
bPdnTYBtvVKFOpq7pRG8TYub5u6z6x7rTPjooHky95XVl2Pm4Y6u6zT3ma1f
rvAb4UYvOR+2P5sCbJ9rA2znM91jPw+7flSGeQ/aAmzrdQTY+nnR3b/bwvj/
/f0vArCfhA==
                    "], CompressedData["
1:eJxNVX9sTWcYbmSRZulkaxuRza4fE7qKYJuI0Xm2VW1+xBCyjIj03sM53zmo
ooruO+cGpTO0bLMRis6SJY2xTVe2VFO1sj8wjLUUTbd2C2rWaSONxPd+77dz
3eTekzfn/fG8z/N83x2Uu2yW1SspKSlXfenplN0tmlgVYMPtmdWRY1Ho+EqA
uX1GfLu3PYp3U3oN3/RCHClXK/KyLsbC+I9De+oHplhh3FE0ccyCiIX6gUfy
7eQ4Lg6+9lDmW1jz99DRyfcDLDyhMhssvPhBbPzNkwEOTqrqfFS4CNPGlry5
8KMAeVlPX634cjH3KwrQn/Jm26DHjFUBhvaOf/r2Nzb3n2XwTXXQSjhu+Sgm
/GcF42iSqCl/fmRzvQevvefr+9skjp0pqCnf5+ENNSbPkkhbX/vLgRIPavqf
F16RjGu1h5sztu5aGpE8T8V6fs+HoLKsAg809p6Kh41Oruyf73HfTInGc92z
W1/2uM88iVTq3+zynvsl12ea+lbJ+670UB3ZeHtmm8RGwr/KQ92DjPnbOyTr
MM7DVOKn09T39bCE9vnL9G90Ge8VyXMqXVwg3uslulSburiL49T/hMT1h1L8
9J6Lcd8rwCcl2og3uFhNRJ2WKKXBI13G953Ex7uWpq5PcUEw876QrOe/gvHa
Ev8Qz3UCvxUqgXMk6/WSYHxeItbP7YlY833d4GsRPO+SRM4WpdQgl/c9L1GU
fnhyy1suSO6yXyWaCH/M5frfJeu9xAXBrO2SOEOFpS7WUd1/ElBpg3tEyE8T
6XNUhPxUkW7FIuRH8zlHhPxo/2SLkJ+fqf9rIuRH+/Y5EfKj+et2QOXlip+V
thKwwfgzx/CfYd57ibiB+u5IxLp/s/If+euGw364/D8/ApNb1qYfPm/wThIh
P6Oah/SOOyLkR+cvF+yLOya/xOjRLZFEn3SBzZTfZvzV5OAd6q/mb6PBPzoY
vqlv4zkVC/JjmYOd/Z6a26dd4nVaZJmDTHrfbc7Lq07YT+tXY+MZ2qdB4jPS
abeNrxQdRxTfQyh/i837nDL6ejbz32r4nmAzP6k+89G1mM9Jmo/PqV9HItZ7
Vi8KY51fZeEu+bSfz/hWWOzXUT7vm2OxX6b4fJ+kWaz3dJ/1eyLWfGUn4lry
R6HFvK7z+XncYv4OJGLdvzIRL6B7sNM3/rYQ0YADPg9HY1C/DzKyzf02IIZL
03Offd8N2F8VUfZbQcD67Inih85HlwvjAePdGcVpMsTWwPAbhZanNGC8m819
/knA57k4yvfboYDvzd3m/n/i/+AxP5jYyg==
                    "], {{
                    484.76599999999996`, 196.805}, {484.76599999999996`, 
                    199.41000000000003`}, {479.387, 202.195}, {472.953, 
                    202.918}, {467.758, 203.5}, {467.672, 
                    203.46500000000003`}, {467.672, 200.87099999999998`}, {
                    467.672, 198.723}, {468.48799999999994`, 
                    197.87900000000002`}, {472.074, 196.31599999999997`}, {
                    477.83599999999996`, 193.80900000000003`}, {
                    484.76599999999996`, 194.07400000000007`}, {
                    484.76599999999996`, 196.805}}, {{490.66400000000004`, 
                    197.043}, {493.289, 199.42200000000003`}, {
                    494.53099999999995`, 202.25400000000002`}, {492.953, 
                    202.25400000000002`}, {491.137, 202.25400000000002`}, {
                    486.32, 197.93}, {486.32, 196.301}, {486.32, 
                    193.75799999999998`}, {487.215, 193.91000000000003`}, {
                    490.66400000000004`, 197.043}}, {{485.07, 204.75}, {
                    485.29299999999995`, 206.223}, {484.383, 
                    207.20300000000003`}, {481.65200000000004`, 208.438}, {
                    475.77, 211.09400000000005`}, {468.734, 212.324}, {
                    467.039, 210.99200000000002`}, {463.91799999999995`, 
                    208.53900000000004`}, {465.9959999999999, 
                    205.24599999999998`}, {471.039, 204.652}, {473.07, 
                    204.41400000000004`}, {475.824, 203.79700000000003`}, {
                    477.16, 203.27700000000004`}, {481.03499999999997`, 
                    201.77300000000002`}, {484.72299999999996`, 202.457}, {
                    485.07, 204.75}}, {{485.07, 212.63299999999998`}, {
                    485.387, 214.73000000000002`}, {484.043, 
                    215.48000000000002`}, {473.08599999999996`, 
                    219.33999999999997`}, {464.90599999999995`, 
                    222.21900000000005`}, {461.28499999999997`, 
                    220.85899999999998`}, {463.89799999999997`, 
                    215.89499999999998`}, {464.809, 214.16400000000004`}, {
                    466.34000000000003`, 213.375}, {469.76599999999996`, 
                    212.85899999999998`}, {472.316, 212.47700000000003`}, {
                    475.801, 211.73000000000002`}, {477.508, 211.199}, {
                    482.074, 209.781}, {484.715, 210.281}, {485.07, 
                    212.63299999999998`}}, {{490.562, 220.02000000000004`}, {
                    492.215, 221.695}, {493.566, 223.67200000000003`}, {
                    493.566, 224.414}, {493.566, 226.816}, {487.039, 
                    222.56200000000007`}, {486.207, 219.61700000000002`}, {
                    485.207, 216.08200000000005`}, {486.824, 
                    216.23000000000002`}, {490.562, 220.02000000000004`}}, {{
                    485.074, 220.51600000000002`}, {485.43399999999997`, 
                    222.906}, {481.457, 225.06199999999998`}, {473.637, 
                    226.723}, {467.902, 227.941}, {465.371, 227.25}, {465.801,
                     224.586}, {466.03499999999997`, 223.12900000000002`}, {
                    467.945, 222.06600000000003`}, {473.367, 220.375}, {
                    482.039, 217.668}, {484.648, 217.699}, {485.074, 
                    220.51600000000002`}}, CompressedData["
1:eJxTTMoPSmViYGCQB2IQrX9Xha3xdJ1DgS3X9cVfchy02sVunsuud+g/9FUj
pjnXweNhlci6ynoHVbbGqc6v8xwuKt3+WfeozuGbRkz/Ic98B8stJ8r2La5z
WOS67fPfgnwHd5D66joH2agU6/vRUH5ynUO1yDr3h2z5DhkT39bYB9Y5fAXp
P5rnoLihKGNibB3EPv88h+l5Qs0HyhB8sPp6BP9qxUs1w7Y6Bx/zTscESwR/
K9AZ8+UQfOHmA6cWLsx1AHmrYGKtw2KQ+zJyHSZLsITx6dY6zADZcy7XwQrk
fs5ahwsgf33KdXjg3zs971cN3D6w/8Rr4XxweOgi+GB/2dQ63Dz3PfjxWqi8
Ya0D0LSsPR/yHN7V2JvGKdVCwsM7H2LPlxqHYpDHsvMh4htrHApBDvXIdxAC
uVu6xsG5O+f57595kPiQr3HYP19K/+6MXAegr59e2FHjELfLk4eJOdfhmDcw
IMxqHZ4snX1EoSPHAWScvyc0PhtyHNDjFwB7QOjD
                    
                    "], CompressedData["
1:eJxTTMoPSmViYGBQAmIQbbnlRNm+9DqHtteBO+Q48xwmS7CE8RXWOczIE2o+
IJXnsMh12+e/OXUOXzVi+g+Z5jnYcV1fXBBb5wCibP3yHLzNOx0TrOscwOY0
5zmU75svpW9b51CUMfFtzeU8h8MgjUlQ8/TyHUDK5tfVOaiwNU51Ls53uFrx
Us2wqc7hG8j8m/kOWu1iN8911znIRKVY3/9Y6HBB6fbPujl1DjnPf6/8mFPq
MB1kzr06h1aQe7krHD5d8k0SMKt34NPdNPf96goHoGueXoiA8l9XQOjgeog9
byocHi+dfUThV53DFJA/11c4vK2xN41rq3PYIQc0MaHC4RjIQ3pQ//wsh+h7
UOsQt8uThym9HGK/T62DNsidgWUOChuAPpWshYTTnRI4H+y+g4Vw/kWQP35B
/S9TC7GnJR9iv1mtgyooPPTzHTpA7veDqr+XB3FvQK0DkJe150AeJBzsoPJZ
eZDwMq6FhK9RHsR9erUOoOC3/5vr4P6wSmQdUF4WFJ6fcyH2h9Q6AFWdWrg1
F2K/S52DuiHHGpljuQ7o6QEAve//BQ==
                    "], CompressedData["
1:eJxTTMoPSmViYGCQA2IQfVRhQ1HG1UaH497mnY5hRQ7TnLtznl9vdODT3TT3
fWyRwxXfJIGIS40OM/KEmg+0FDl8ugQUONnocPirRkz/miKHQyB6V6PDlhNl
++a/KoKo29LoUC2yzv3hlyKHrD0lkyUWIPi2XNcXF8Qj+J48TNrt3xscls0+
orBBr9gB5IyEngaHaxUv1Qz7ih0uKN3+WefX4OADEj9a7PB4KVChZQPEHZeK
HeRbXwfuMGxwYACBI8UOAhGWW07INUDULSh2yJz4tsbersEhbhfQJu9ih3ax
m+e+5zVA/CtX7FCxb76U/qwGiD++FTlUAq3lEG500AYpPFrkENsPlPFC8MHm
ZiH4MlEp1veB/Jznv1d+PFQE8UdEo8MOOaDD+oocQNL+3o0OwFA5tTC9yGHb
579XKvIbHaxAAZZaBPFvMzR8U4ocFhcAQ2heo8NFkL/jiiD+XwONj3Co+y40
OnQ5Jjy94AbVj8RHj08AglzhCw==
                    "]}, 
                    CurveClosed -> {1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
                    1, 1, 1, 1}]}, {
                    FaceForm[{
                    RGBColor[1., 0.717647, 0.], 
                    Opacity[1.]}], 
                    FilledCurveBox[{CompressedData["
1:eJxTTMoPSmJiYGDQZ2RgYAbSDEAOIwMjMzOQhDCIRPjVw2WJN5ZIlQSVUa6A
bPVoKqnud2JMINsNBGONoMn4FVArXkhyJIWxQKqbKYxHAMnLCKY=
                    
                    "], {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4,
                     3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}}}, {CompressedData["
1:eJxdW3mcT+UaH0v2O8mSJblZwkXkhgm58wppoYT8fsxqFmMs8zu/ddDiLL/l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                    "], CompressedData["
1:eJxdVn9MlVUYvlErhsQynQNaJmSNQoP+YGry4yUqRswRtgxDrkYQrtn1O59O
r2XZPae7m2tpyIxWmXlTzDBWJkiuQQNDsVYUmBVzIv1gXQrQrOUs1znnfeRr
sbFvz33PeX887/O+35dWvXpxbZzP56vX/+Z57utF1deVKdrz+pFZ7x9x6DJe
cPDYuo5Bh1bW/7axYK6iH8yBVEE+8zdF0djGghz/3YLPT0hKmntgx/ijgsy1
naOSnhy5uO9staCuPzKWbdU4PFrePrNEUNvv/wwENbb30gU98fHahuTvJd0e
mfHdF52I1+9hnZW78ksP32Qc9UryHy5JjOt3aOHpspcaeyQN6Ucg5lDWqdlX
h7qRzxWI1ybpRPCXW+/MFtRq8tsnOU65oOGnprcUb5P0SI3xJLjO5yRNU58c
3/WQoPUdO1OzVku6yxSWJmi3k5dwslySuXZmzKHNhSt+6rvHw02Gx0IP2/o0
Plo6b3NhAvIpknS98Z8paINOK/4+SdeafMuAtb/GgD6xSpCuMjOSLzmPNYLy
E06+7SwAnxsEnTGBciQ1JF+1JGm9h20fAv+zV8JfouS+XHLolaIXV41c6WGT
5gqfhy3/F0N8P0XQjYaov0KUZ/MQNKDbWPFniDJNf5ZCD+dwXvNpeR0PMd/N
gnJNv34NcZ96BfvX56P3amYOChrf21M67+8Q8/0M/CWhXynoX5qkvvTBC88u
wf056G8Q93OgvzcE39O4xxT2jofNtfoPBdc/H/W2C+o39eRJ5kHbXzV9KIT/
FsG6KoYewuhXqWQ+dP3GvPcBSU+b/scLCpq+PS5ZV/Nx3oX+F8PfJsk6Wgt7
GPHDuL8F/qKC53QLzkehx7ckz+XzuN8sOW8X5w8jvxLMZzf4yEA/PpdUZebp
GszjCUntM7XCtH4tL99gPs467P9b2M87/Psg+jED+jiF/PPQnyHEq0E+w5J1
rOvbbvgfhr4jmLcfUd/LgqZW6E10s2L+86GnhYrjTxdc1/2K411w+HyF4vkY
cVgPldhnow73p0qRUYF/wqE5Bi9X3I9kMYltX4o8bPl9AfwuUzzPr0FvxYrz
6MS8ZcEeA993KPrK8BNDPbcorvMzQZWmnlRF3YbnKOyJiPcfbPVz3MO23hHM
82nsj4ddtvd72O7LPg/bfI+C7wKX8+uQPH+zXK6vDfqJg7/90GsM+ngXeo5h
n70pJ+s1bWn3SzKyCgRd3mN+3N/mYauXJpd/fwzzvculCZNfAPltctnfOthr
XdZPBPst3+U+NcB+G+rdj3m4JBi3Il68y/3plKzTStTbhX28Bvn1YB4iLuuw
18NWzwMetvtjCvQ2FflOU5N82fm5QbGfLkHZZu+lob9j2C8Zip/pLj+zFecx
2+V9lKvYz3nMR6FifofQj6WK+WgTdMj0Qyjeb43Qyw7obTnmr0mxHrTdvj+b
kf8h7NsDivVwDP5bMT+d2L8fKebvA9hbMC8PCvrUBN6jqNgQXQD7bnxf5KIf
2xXP/yLkG1a832qwD+uQ/1bBvNUh/yLoqw75puB9WKv4ffuzw3GqMY/92E9V
iPee931jeY56+PL3z7/RviXx
                    "], CompressedData["
1:eJxNVGtIFVEQvghJSJaZRNjLykyysJISNXO0h5SaFP2w0BRLEjG7OItdNQrP
wVRCzIJUTMxXIkRImNrLxExFKKSMKLKLRNjLTEVIQuqMMz9aWA6ze84332N2
16WeO5rmYrPZDpib1tyvftsXZiuYehWX6uGHEBtcEpkSrsBG10Wpdyr41FTd
63MN4eAil4CiXQo2Fy1/9/IRwtKEkLaBYAVvHAboC8JEc19McJiCGDr3RGqD
17mm8PuRRoT08vELETEKiiNTPg8Z/MVb79VMJCo431XrHXhK9ucrfh6EUEL7
ShUkPTSdk5F5ViogOq05CM9m/BPLbinI97obPWr4rTVtOk29THcP1tUgJJb1
zPjXKQggvg+QzzUoCHd722DvQHht4BL6Ffi0ZqeX5yLM+zGmGDdK9Jq6nwRF
Cf8fwi8NYdWJ02HOnwpC2wZyunJFz7joqUVw0PpNQf3+9um5TtHjFL9tFjTa
DZNRBZVZnrrbzYJD1G9SgTvhOIXfrPAZFPwFGpzxpRVZdxA6pueGHe6a9d9E
CKMX3pr1FiD0krCVmvNRCEQ33kdDBfUzeWQ8tq6v2KChh/ANvz3ky0YNZ8f+
tEx+QNg24utaYOr5dQbhvpFZa+r5eVhvwS/KK0pz3qMIN/ZeyRxL1KyzUfgn
az5XjxBIOGc0+/8UYTTPEM8UPUNS2zX7PCvn7cLf2+JzduG/z+I8szXjxlus
x6FZZ4TFPAs09BFBXwsayO88zX6+R0ii+cjQEEL5VUteJzXjZiG0k7+HNUQT
MZPnMPEJ1TzPHxG2mDiag6TfCDIvP83zUIXsq8ljNW04jkCPaz01z8Mx2e8q
fl6W+f6reH8Twm4yZk6+x3qZ59+K/UmW/KZkvryQ5+iF4hzjEJ5T/i0y/4WC
X6XgNulLkfqqYn9ipV+xvN+B7HexzOMmZJ6mntflgZz7JfkfLBG8//4n/wAn
LwFL
                    "], {{648.8359999999999, 326.855}, {646.438, 
                    329.01599999999996`}, {644.7850000000001, 331.074}, {
                    645.164, 331.43399999999997`}, {645.543, 
                    331.79299999999995`}, {645.9689999999999, 331.895}, {
                    646.113, 331.66}, {646.254, 331.42999999999995`}, {
                    648.215, 329.367}, {650.4649999999999, 327.082}, {
                    655.6519999999999, 321.82}, {654.586, 321.672}, {
                    648.8359999999999, 326.855}}, CompressedData["
1:eJxdVGtIVEEY3RYTMZNNIkVcsyWyB6VFYGLSMRWTCKkfISolS8JSZEvcqS2k
mLmEKISIhVGE1VaSREhtJhEWPVT6IZI9aM2sNOxBmaaklNTMnW9bcGG5fHNn
znfO+c7cJe4DOyrsNpstX/7Vs+3nzHPfS44r5x6ntH43YFO/JxzOkj1Zg06G
H82dWzM6OU583d6enM2QHf3K7+3nkKs1OV4GR3FmoPsLx+GOpsS00ww1OeUf
e8c4utT7swwbB4tONsYIfa6BYYHa7xRoSIjYGVvH0FgZZz7YLHBV9Q/h7RKY
v/rm+dEihiFF7LjQz5WEd0HgjDrnYCiMsa+qvivwTi5XRjNUL3rd86tX4FK+
VBbB0LfN7SgeEtg/8vvamD1cW/rmhmuLdxTT+oNC60llCHQf6mjqIf6FDA8n
l5fV3RK4rdalPsu/gICCK/LT+T7Sc5ChVK2PE1+QP/Gm1rOO8PaZ8NR/q9qU
QXinTGx5f3ThjUyGxcr4KlPz8JDeUlP728I0bgXhtTKorp5aE72u/uljXvL7
uqn7ric9LYSXzvBBtilwm3jh+7xsrYvwc02MP5PGJNG8XYSXQv5GUr2G4bJX
7hgQUHTKc5nW8YbmK+sjEjZqWCBtYGkkTyX8TwKS9dOL8eTHKPkp52f5PhGu
rXlPzXr/R+CR8s0eri0fpoz/tZWHoKF5+YnPpIFYlSuf0PpCeuKF9lNQHucR
Xi3Tc5zg2p8q0jvCtd8GnQ9yKJqVZaQvdJ/yyP8ujnSlP9T/L9f5vmNg7z2j
IUH2t9ZnDO2HvB9WvzjyM4nyn0LzcFBeNzComBTYyJ8S6jeH8rqbIUsRk/gq
FvXyPln9UgXak2Ww8si/FdR/2tD3L1Fo/m8NnY9owrtvQG1rHqb7321g9vfj
H3Wl+0g=
                    "], CompressedData["
1:eJxTTMoPSmViYGAQBmIQbct1fXFBSLPDTrnW14GbSh2iUqzv+3s0Q+iTpQ6d
jglPLwQ2O+Q8/73y47lSh/J986X0O5odckH8C6UOYP2nmx3076qwNV4udXhY
JbLO/UuzgyzIgJelDts+/71SodLiMD1PqPmAWplD1p6SyRLeLRD14WUOh79q
xPSHtkDU+5Y5THPuznlu0AKxX7oMop+/xSFj4tsa+7dQ991udrDacqJsH9B9
7WI3z31fAXXfvlIHm/v+vdMnNDt4gByyE+r+kmaHB0DhPKD/3i8/5m2e3Qxx
z7pSB91Nc98vT2x2APp+h9zqUocjChuKMsKh8mug/kMKHwAzJJYO
                    
                    "], CompressedData["
1:eJxdVGtIFFEU3raIkpAeIpFWJoE9FNMyk7Q9lmJlKho5s45uu+O+lDJ7kFEm
Rtw7SYlJ5QMpMzMpRCKWEPOFlmlBiAYSi4hZ9qMiI7IkpO7dc3GhgdmZs/fc
73znO9+dDeqJDJtep9MlsZs/8zvO3FhdRUDHr20yFHXVrwl3EaguWHm555UM
seNp5dUD3vWRFHW5PEkgfGzj4ks2CZrqngc91lPYd/XYpz95ErDolDOQQhpL
i4mVwTVwtqs+hMJfflXLsJ58Tm+LoHDaWfm1eFSGK/Hmj0ORFJ7+mHt7blCG
Kg60ncKX9LZ15JmId4n8Ihl8w57c/hZHwWe0sTAuUoaJ836tSQkUTO0Hlund
EvJLpzA1FOyebZUw30nhoiHK1N4gwaHosngzEfUqJeyrXOA3S5Bl3T2eViPw
t8iwQo5xDTRR6GQyLeqXIZnv76Mwsym7ojdMRhw/DdyzJfkd1zIhlJVrNmi4
f68McfwlQIMALthDBest1UDzf/fmV24OTHIBV2lwL5EhZZuAdbFVS9XgJS+0
3wy9P1khhwZcpuBuM3jmVawhnz2W+TgkYklLoOqN1/JG6izIr0iDI1yIRgvk
VDDETFHvrgXyWNuGnRqw3yjTHQvqHaohrxYLPgNFvRkLlHEiOtFfgYr96TXs
67eKfQUJPa7n4jxiNLjAxjThY0V+vqK/UisoXO8ZCt3MdmM9VvTPawqrmPsa
jDb0YSvFfkZsuF4g5jNlR37hFB59H05RnQ70o5sAY3F4kjhwfyNBvFoH3C/k
jAnmT9uRL4s9eP52OMj17yRQzjcm2HDeCylwexgmchEvg6KPUlT0i0yhhv/v
q+K5UIQ/5o7CdHN/crSJIl5pNuIkCf7DCnCbljD/e/TaoWA/m0V+kILzmiLo
3wUK1n1AIJXL+iELda8leP4Gs+A9Pw+UYJ3ELHjB9TpOoIHP+6YR8+1iPcqI
+psIJPD98TLqYxT4Lgn9rIjzfkvCeTu9sQfvpDfu434lZP48/v99+Qe+3O82

                    "], CompressedData["
1:eJxdVGtIlEEU3SKyLKWHRQ8TszJ7qohEmXmzRDPDHuqPqNhvx91ZNEsyCuyb
AemlQpmFJGlIWdFDxR5GVFZU9ISwB2RYbGbij7DSUjExmpk77RctLLuHuXPP
PefeudMd29c7h9psts3iK383ZsZ4Ut8ymB05oibwhB0iPswcXtDO4NDxbeP2
3rPDsUnDMvy7GHSacdFbflt48bUnu+7MMLz48epFRcs3GZDUmh9QN8ggdHhB
2YpsA+NiONytmhL+wTQwzwGOfEcNuN8TtqkkjUO45G01INb3bXXuZA5L5L04
B9jkJ4CDTG8vckDb2YqHwUk6vkifmxb2X3Dl5LfXHFJkfI8DlL5WDvu/rLsR
lEAwroPDKEETm0VAiHx2qk3zVRBoCmnp5806voEg7y0OGTJxHwEZVrWPw3h5
r5PASxmfz7GOMwSC63e4S7drvWkE3KVC8WYOuVKYwHMPTnz3IopDvL29KaSa
wDKpt4chz+RMzPOTwbsXfRva/JyQ0zFwoSuCw6WuV2sclU7kXcMhTyb2OPGe
wNOk0DYnlMu2hen657jQzyEc0mX9eS70Q/R3luyPD8V6+hj6MZd6+6f8i6ag
xiCQw2H5Zz6FPQF1ia1LOfo0kcID2b8sjvn6XNhP0Q91r9eF9ZVwuCjrD6Bw
I0hU9oSjvhwKDdLPYg6nE67/GPxI0a9w7fdjiv766n42Uqx/gHnPu0XaMb0M
egXt/U6Nuxnm9XWjLy8Z8ke4UV8tQ5/i3ejvVgY7JDFxoy6Bt9xcNXroP1jV
O9LCag7PU9S7luEclVHs/1TN94Zi/HcTSmSgjxt9eWTivHmoF6u+77Ow0r2Q
YlyXCY+kkcMo5Ev/l+n36q/15mv9EyjGmRo3uvB8JYMjkj/OBYlS/9/6PjsR
x2hc6MT3nK3fs82Jc0QZNO4UJ0GZ6H8UwzmsJXBO2FDvy/BdpRPkE3qVP5UE
8z03QY5h7G8CnlSxWcpN3AviPan5KTbR7xKC81pgwle5J5IJ9qdQn88j+L6v
6nyfHCCmor2pycQ5u+zA+F+mdx+ofoxlXqzqXmVhxZfIcO4iHbD7jni4flp/
s4F99Zg4T2JfKX2hDN7386zbYp8p/hQGLRLnGt75UP3ZaOFX8jfZwiqfv4F+
ntT+p9nxHdRYWPFdt7Dy86nev3l2+H9//wHKOZ9v
                    
                    "], CompressedData["
1:eJxNVWtsFFUYbRpDGi0E26YhgstDRSwh5WVMRfCIBVQkaAlo5BHS3YGZO1Mo
FUoVvDMbIg8JtBUNAsHyEBOThodKKWhaUgoFf/CQWm1lgaaxlSglUG1jGhLv
d7/LLJtsJmfn3u873znn3h1ZuLLASk1JSSlUX3o6lbfXv1wT4OO/3q6NHI9C
45YACwaN+3ZvVxSvp6eO3TQ0jkd/PVg89edYiDsO7WkckW6FWO16fknEQuOI
oyV2WhxXRv3+nyyx8MGt0RPS7gZYfEqtbLLw5HuxKTfqAxyYUdNzv2wZ3nxh
yytLPwlQPFV1+Go511sf8Lp5Nugxd02AZwbEP3/1iM31Cwy/2Q7zuOkz/wsC
3cSjTaK+6oncRKMHr6v/m7vbJY6fL62r+tLDNBrEksjccPqn/Vs8qO5/XJ4o
MYwarfVwY+62nSsikvsprPv3f8Tzl3qgtncUfnZCWvWwEo/r5ki0Xuyb1/Gc
x7wXmvoJl+fcJ/EY7c8x+zskz7vaQ21EMe+UzH+Nh4Z/xywq75awyYc8D7NJ
nx7J/bM9FNE8f5r6rS7zbZHcp9rFZdK9UaJXlWmIuzhJ9U9JqF/Fj2+5yPte
Ea6XrBtcrK1TQp2VqKDGuS7z+05i+84VGRvSXRDN4l2S/bwnmK8t2e8GgV/K
lMEzJc/9lGB+XhJrXcuTWOt9zfBrF9zvqkT+VuXUSJfnvSSxLuvwrPbpLsju
yiuGf8zl/b8ZvYpcEM3TvRJNtLHC5X3/SExXy0b1i1Af7c8xEepDMlRtFKE+
GaTnfBHqo/OTL0J9zlH9ySLUR/N8XIT6lJN+fQ7XVfqUkIFNJp9KnzbiP8a8
95JY8/40iXX9hOR8XXc4D80P9BGY1f5h1uFLhu8MEeqTm3h6QNwRoT56/SrB
ufj7Qd6NH30SKfTJEthM6ztNPtscvEb1EyYPPzgYuym79WLC5LHSwY4hjywY
1CXxIg2y0kEOve8z52WSE9bTPtTZGEjzNEl8QT7ttvG1kuOo0ns0rd9q8zxn
JK7R/J7N+ncYP1+y+Znhsx69y9n3TJ/rdSexnrN2WYj1+hqLczrEZ37vW5zX
8T6fp5kW83zDx3wSPtNiv+f47N9DWOuVn8T0SJRZ7MM6n/U9abF++5NY169O
4iV0D/b4Jt8WIppwwOfhWAyLKEj5Ad4hPsNjuDqncPC7bsD5OhjlvJUG7M+e
KE703G8uiwfMd0cUZykQ2wKjbxTanoqA+W429/lnAZ+DjVG+3w4FfG/uNvf/
Q/8H/wPhWdiy
                    "], {{484.76599999999996`, 196.805}, {
                    484.76599999999996`, 199.41}, {479.387, 202.195}, {
                    472.953, 202.918}, {467.758, 203.5}, {467.672, 203.465}, {
                    467.672, 200.871}, {467.672, 198.72299999999998`}, {
                    468.48799999999994`, 197.879}, {472.074, 196.316}, {
                    477.83599999999996`, 193.809}, {484.76599999999996`, 
                    194.07399999999998`}, {484.76599999999996`, 196.805}}, {{
                    490.66400000000004`, 197.04299999999998`}, {493.289, 
                    199.42200000000003`}, {494.53099999999995`, 202.254}, {
                    492.953, 202.254}, {491.137, 202.254}, {486.32, 197.93}, {
                    486.32, 196.30100000000002`}, {486.32, 193.758}, {487.215,
                     193.91}, {490.66400000000004`, 197.04299999999998`}}, {{
                    485.07, 204.75}, {485.29299999999995`, 
                    206.22299999999998`}, {484.383, 207.20299999999997`}, {
                    481.65200000000004`, 208.43800000000002`}, {475.77, 
                    211.094}, {468.734, 212.324}, {467.039, 
                    210.99200000000002`}, {463.91799999999995`, 208.539}, {
                    465.9959999999999, 205.24599999999998`}, {471.039, 
                    204.65200000000002`}, {473.07, 204.414}, {475.824, 
                    203.797}, {477.16, 203.277}, {481.03499999999997`, 
                    201.77299999999997`}, {484.72299999999996`, 
                    202.45700000000002`}, {485.07, 204.75}}, {{485.07, 
                    212.63299999999998`}, {485.387, 214.73}, {484.043, 
                    215.48000000000002`}, {473.08599999999996`, 219.34}, {
                    464.90599999999995`, 222.21899999999997`}, {
                    461.28499999999997`, 220.859}, {463.89799999999997`, 
                    215.895}, {464.809, 214.164}, {466.34000000000003`, 
                    213.375}, {469.76599999999996`, 212.859}, {472.316, 
                    212.477}, {475.801, 211.73}, {477.508, 
                    211.19899999999998`}, {482.074, 209.781}, {484.715, 
                    210.281}, {485.07, 212.63299999999998`}}, {{490.562, 
                    220.02}, {492.215, 221.695}, {493.566, 223.672}, {493.566,
                     224.414}, {493.566, 226.816}, {487.039, 222.562}, {
                    486.207, 219.617}, {485.207, 216.08200000000002`}, {
                    486.824, 216.23}, {490.562, 220.02}}, {{485.074, 
                    220.516}, {485.43399999999997`, 222.906}, {481.457, 
                    225.062}, {473.637, 226.72299999999998`}, {467.902, 
                    227.941}, {465.371, 227.25}, {465.801, 224.586}, {
                    466.03499999999997`, 223.129}, {467.945, 222.066}, {
                    473.367, 220.375}, {482.039, 217.668}, {484.648, 
                    217.69899999999998`}, {485.074, 220.516}}, CompressedData["
1:eJxTTMoPSmViYGCQB2IQrX9Xha3xdJ1DgS3X9cVfchy02sVunsuud+g/9FUj
pjnXweNhlci6ynoHNbbGqc6v8xwuKt3+WfeozuGbRkz/Ic98B8stJ8r2La5z
WOS67fPfgnwHd5D66joH2agU6/vRUH5ynQOQdH/Ilu+QMfFtjX0gVP/RPAfF
DUUZE2PrHCaA7PPPc5ieJ9R8oAzBB6uvR/CvVrxUM2yrc/A273RMsETwtwKd
MV8OwRduPnBq4cJcB5C3CibWQtyXkeswWYIljE+31mEGyJ5zuQ5WIPdz1kL8
9SnX4YF/7/S8XzVw+8D+E6+F88HhoYvgV4P8ZVPrcPPc9+DHa6HyhrUOQNOy
9nzIc3hXY28ap1QLCQ/vfIcLIHu+1DgUgzyWnQ8R31gDCX+PfAchkLulaxxc
unOe//6ZB4kP+RqHffOl9O/OyHUA+vrphR01DnG7PHmYmHMdjoECwqzW4fHS
2UcUOnIcQMb5e9Y5FILMa8hxQI9fAIGY6Mg=
                    "], CompressedData["
1:eJxTTMoPSmViYGBQAmIQbbnlRNm+9DqH1teBO+Q48xwmS7CE8RXWOczIE2o+
IJXnsMh12+e/OXUO3zRi+g+Z5jnYcV1fXBBb5wCibP3yHLzNOx0TrOscwOY0
5zmU75svpW9b51CUMfFtzeU8h8NfgRqToObp5TuAlM2vq3NQZWuc6lyc73C1
4qWaYRPU/Jv5DlrtYjfPddc5yEalWN//WOhwQen2z7o5dQ65z3+v/JhT6jAd
ZM49qHu5Kxw+XfJNEjCrd+DT3TT3/eoKB6Brnl6IgPJfV0Do4HqIPW8qHB4v
nX1E4VcdxJ/rKxze1tibxrXVOeyQA5qYUOFwDOQhvToHK5BDf5ZD9D2odYjd
5cnDlF4Osd+n1kEb5M7AMgeFDUCfStZCwulOCZwPdt/BQjj/Esgfv6D+l6mF
2NOSD7HfrBYSHvr5Dh0g9/vVOlwEqb+XB3FvQK0DkJe150CeQw4oHOyg5mXl
QcLLuBYSvkZ5EPfp1TqAgt/+b66D+8MqkXVAeXB4fs6F2B9S6wBUdWrh1lyI
/S51DuqGHGtkjuU6oKcHAMJ3/wg=
                    "], CompressedData["
1:eJxTTMoPSmViYGCQA2IQfVRhQ1HG1UaHY97mnY5hRQ7TnLtznl9vdODT3TT3
fWyRwxXfJIGIS40O0/OEmg+0FDl8ugQUONnocOirRkz/miIIvavRYeuJsn3z
XxU5zACp29LoUC2yzv3hlyKHrD0lkyUWIPi2XNcXF8Qj+J48TNrt3xscls4+
orBBr9gB5IyEngaHqxUv1Qz7ih0uKN3+WefXABE/WuzwGKTQsgHijkvFDvKt
rwN3GDY4MIDAkWIHgQjLLSfkGiDqFhQ7ZE58W2Nv1+AQtwtok3exQ7vYzXPf
8xog/pUrdqjYN19Kf1YDxB/fihwqgdZyCDc6aIMUHi1yiO0Hyngh+GBzsxB8
magU6/tAfu7z3ys/HipyWAbyR0Sjww45oMP6ihxA0v7ejQ7AUDm1ML3IYdvn
v1cq8hsdrLYAAyy1COKvZmj4phQ5LC4AhtC8Roi/44og9JpGB15QfIRD3Xeh
0aHDMeHpBTeofiQ+enwCAHk04P4=
                    "]}]}}, AspectRatio -> 
                  Automatic, ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 960.}, {0., 480.}}], ",", 
                 GraphicsBox[{{
                    Thickness[0.0010416666666666667`], {
                    FaceForm[{
                    RGBColor[0.890196, 0.0392157, 0.09019610000000002], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 640.}, {960., 640.}, {960., 0.}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{500., 320.}, {500., 231.63299999999998`}, {
                    428.367, 160.}, {340., 160.}, {251.63299999999998`, 
                    160.}, {180., 231.63299999999998`}, {180., 320.}, {180., 
                    408.367}, {251.63299999999998`, 480.}, {340., 480.}, {
                    428.367, 480.}, {500., 408.367}, {500., 320.}}}]}, {
                    FaceForm[{
                    RGBColor[0.890196, 0.0392157, 0.09019610000000002], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{508., 320.}, {508., 249.309}, {450.691, 192.}, {
                    380., 192.}, {309.309, 192.}, {252., 249.309}, {252., 
                    320.}, {252., 390.691}, {309.309, 448.}, {380., 448.}, {
                    450.691, 448.}, {508., 390.691}, {508., 320.}}}]}}, {
                    RGBColor[1., 1., 1.], 
                    
                    PolygonBox[{{521.9449999999999, 302.03905243264535`}, {
                    521.9449999999999, 243.914}, {556.1093226919377, 
                    290.9381676425142}, {611.387, 272.977}, {
                    577.2235256317572, 320.}, {611.387, 
                    367.02299999999997`}, {556.1093226919377, 
                    349.06183235748574`}, {521.9449999999999, 
                    396.08599999999996`}, {521.9449999999999, 
                    337.96094756735465`}, {466.668, 320.}}]}}, AspectRatio -> 
                  Automatic, ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 960.}, {0., 640.}}], ",", 
                 GraphicsBox[{
                   Thickness[0.0010416666666666667`], {
                    FaceForm[{
                    RGBColor[
                    0.854902, 0.14509800000000003`, 0.11372500000000002`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 720.}, {960., 720.}, {960., 0.}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{480., 504.}, {
                    435.5, 367.047}, {526.805, 337.383}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{480., 504.}, {
                    524.5, 367.047}, {433.195, 337.383}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{616.953, 
                    404.5}, {472.953, 404.5}, {472.953, 308.5}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{616.953, 
                    404.5}, {500.453, 319.855}, {444.027, 
                    397.52299999999997`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{564.641, 
                    243.5}, {520.145, 380.453}, {428.84000000000003`, 
                    350.789}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{564.641, 
                    243.5}, {448.14500000000004`, 328.14500000000004`}, {
                    504.57, 405.809}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{343.047, 
                    404.5}, {487.047, 404.5}, {487.047, 308.5}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{343.047, 
                    404.5}, {459.547, 319.855}, {515.9730000000001, 
                    397.52299999999997`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    395.35900000000004`, 243.5}, {439.855, 380.453}, {531.16, 
                    350.789}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    395.35900000000004`, 243.5}, {511.855, 
                    328.14500000000004`}, {455.42999999999995`, 405.809}}}]}},
                   AspectRatio -> Automatic, ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 960.}, {0., 720.}}], ",", 
                 GraphicsBox[{
                   Thickness[0.00078125], {
                    FaceForm[{
                    RGBColor[0.007843139999999998, 0.309804, 0.635294], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 640.}, {1280., 640.}, {1280., 0.}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     533.3319999999999}, {1280., 533.3319999999999}, {1280., 
                    106.66799999999984`}, {0., 106.66799999999984`}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.9294119999999999, 0.109804, 0.15294100000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     515.555}, {1280., 515.555}, {1280., 
                    124.44599999999991`}, {0., 124.44599999999991`}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{568.891, 320.}, {568.891, 241.453}, {505.215, 
                    177.777}, {426.668, 177.777}, {348.121, 177.777}, {
                    284.445, 241.453}, {284.445, 320.}, {284.445, 398.547}, {
                    348.121, 462.22299999999996`}, {426.668, 
                    462.22299999999996`}, {505.215, 462.22299999999996`}, {
                    568.891, 398.547}, {568.891, 320.}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.9294119999999999, 0.109804, 0.15294100000000005`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{426.668, 
                    457.777}, {384.09, 326.742}, {449.60900000000004`, 
                    305.457}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{426.668, 
                    457.777}, {469.242, 326.742}, {403.727, 305.457}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    557.6990000000001, 362.574}, {419.92199999999997`, 
                    362.574}, {419.92199999999997`, 293.688}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    557.6990000000001, 362.574}, {446.23799999999994`, 
                    281.594}, {405.746, 337.324}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{295.633, 
                    362.574}, {407.09799999999996`, 281.594}, {447.59, 
                    337.324}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{295.633, 
                    362.574}, {433.40999999999997`, 362.574}, {
                    433.40999999999997`, 293.688}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    507.65200000000004`, 208.535}, {465.074, 339.57}, {
                    399.559, 318.28099999999995`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    507.65200000000004`, 208.535}, {396.188, 289.52}, {
                    436.676, 345.25}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{345.684, 
                    208.535}, {457.148, 289.52}, {416.656, 345.25}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{345.684, 
                    208.535}, {388.258, 339.57}, {453.777, 
                    318.28099999999995`}}}]}}, AspectRatio -> Automatic, 
                  ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 1280.}, {0., 640.}}]}], "}"}], ",", 
             RowBox[{"{", 
               RowBox[{
                 GraphicsBox[{
                   Thickness[0.0011111111111111111`], {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {900., 0.}, {900., 600.}, {0., 600.}}}]}, {
                    FaceForm[{
                    RGBColor[0.91, 0.067, 0.17600000000000002`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{389.99969999999996`, 
                    600.0003}, {389.99969999999996`, 
                    360.00030000000004`}, {-0.0003000000000383807, 
                    360.00030000000004`}, {-0.0003000000000383807, 
                    240.00030000000004`}, {389.99969999999996`, 
                    240.00030000000004`}, {389.99969999999996`, 
                    0.0003000000000383807}, {510.00069999999994`, 
                    0.0003000000000383807}, {510.00069999999994`, 
                    240.00030000000004`}, {899.9997, 240.00030000000004`}, {
                    899.9997, 360.00030000000004`}, {510.00069999999994`, 
                    360.00030000000004`}, {510.00069999999994`, 600.0003}}}], 
                    
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{172.9215, 539.9021999999999}, {180.2365, 
                    501.41219999999987`}, {180.2365, 461.88819999999987`}, {
                    172.9215, 423.39819999999986`}, {186.4875, 
                    425.09019999999987`}, {200.2125, 425.09019999999987`}, {
                    213.7785, 423.39819999999986`}, {206.4635, 
                    461.88819999999987`}, {206.4635, 501.41219999999987`}, {
                    213.7785, 539.9021999999999}, {200.2125, 
                    538.2091999999999}, {186.4875, 538.2091999999999}, {
                    172.9215, 539.9021999999999}}}], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{251.6022, 502.07849999999996`}, {213.1122, 
                    494.76349999999996`}, {173.5882, 494.76349999999996`}, {
                    135.09820000000002`, 502.07849999999996`}, {
                    136.79020000000003`, 488.5125}, {136.79020000000003`, 
                    474.78749999999997`}, {135.09820000000002`, 461.2215}, {
                    173.5882, 468.53649999999993`}, {213.1122, 
                    468.53649999999993`}, {251.6022, 461.2215}, {249.9092, 
                    474.78749999999997`}, {249.9092, 488.5125}, {251.6022, 
                    502.07849999999996`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{686.2215, 176.6022}, {693.5365, 138.1122}, {
                    693.5365, 98.5882}, {686.2215, 60.098200000000006`}, {
                    699.7875, 61.79020000000001}, {713.5125, 
                    61.79020000000001}, {727.0785, 60.098200000000006`}, {
                    719.7635, 98.5882}, {719.7635, 138.1122}, {727.0785, 
                    176.6022}, {713.5125, 174.9092}, {699.7875, 174.9092}, {
                    686.2215, 176.6022}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{764.9021999999999, 138.77849999999998`}, {
                    726.4121999999999, 131.46349999999998`}, {
                    686.8881999999999, 131.46349999999998`}, {
                    648.3981999999999, 138.77849999999998`}, {
                    650.0901999999999, 125.21249999999998`}, {
                    650.0901999999999, 111.48749999999998`}, {
                    648.3981999999999, 97.92149999999998}, {686.8881999999999,
                     105.23649999999998`}, {726.4121999999999, 
                    105.23649999999998`}, {764.9021999999999, 
                    97.92149999999998}, {763.2091999999999, 
                    111.48749999999998`}, {763.2091999999999, 
                    125.21249999999998`}, {764.9021999999999, 
                    138.77849999999998`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{686.2215, 539.9021999999999}, {693.5365, 
                    501.41219999999987`}, {693.5365, 461.88819999999987`}, {
                    686.2215, 423.39819999999986`}, {699.7875, 
                    425.09019999999987`}, {713.5125, 425.09019999999987`}, {
                    727.0785, 423.39819999999986`}, {719.7635, 
                    461.88819999999987`}, {719.7635, 501.41219999999987`}, {
                    727.0785, 539.9021999999999}, {713.5125, 
                    538.2091999999999}, {699.7875, 538.2091999999999}, {
                    686.2215, 539.9021999999999}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{764.9021999999999, 502.07849999999996`}, {
                    726.4121999999999, 494.76349999999996`}, {
                    686.8881999999999, 494.76349999999996`}, {
                    648.3981999999999, 502.07849999999996`}, {
                    650.0901999999999, 488.5125}, {650.0901999999999, 
                    474.78749999999997`}, {648.3981999999999, 461.2215}, {
                    686.8881999999999, 468.53649999999993`}, {
                    726.4121999999999, 468.53649999999993`}, {
                    764.9021999999999, 461.2215}, {763.2091999999999, 
                    474.78749999999997`}, {763.2091999999999, 488.5125}, {
                    764.9021999999999, 502.07849999999996`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{172.9215, 176.6022}, {180.2365, 138.1122}, {
                    180.2365, 98.5882}, {172.9215, 60.098200000000006`}, {
                    186.4875, 61.79020000000001}, {200.2125, 
                    61.79020000000001}, {213.7785, 60.098200000000006`}, {
                    206.4635, 98.5882}, {206.4635, 138.1122}, {213.7785, 
                    176.6022}, {200.2125, 174.9092}, {186.4875, 174.9092}, {
                    172.9215, 176.6022}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{251.6022, 138.77849999999998`}, {213.1122, 
                    131.46349999999998`}, {173.5882, 131.46349999999998`}, {
                    135.09820000000002`, 138.77849999999998`}, {
                    136.79020000000003`, 125.21249999999998`}, {
                    136.79020000000003`, 111.48749999999998`}, {
                    135.09820000000002`, 97.92149999999998}, {173.5882, 
                    105.23649999999998`}, {213.1122, 105.23649999999998`}, {
                    251.6022, 97.92149999999998}, {249.9092, 
                    111.48749999999998`}, {249.9092, 125.21249999999998`}, {
                    251.6022, 138.77849999999998`}}}]}}, AspectRatio -> 
                  Automatic, ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 900.}, {0., 600.}}], ",", 
                 GraphicsBox[{
                   Thickness[0.001388888888888889], {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     480.}, {720., 480.}, {720., 240.}, {0., 240.}}}]}, {
                    FaceForm[{
                    RGBColor[0.8352940000000001, 0.168627, 0.117647], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     240.}, {720., 240.}, {720., 0.}, {0., 0.}}}]}, {
                    FaceForm[{
                    RGBColor[0., 0.223529, 0.65098], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     320.}, {720., 320.}, {720., 160.}, {0., 160.}}}]}}, 
                  AspectRatio -> Automatic, ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 720.}, {0., 480.}}], ",", 
                 GraphicsBox[{
                   Thickness[0.001893939393939394], {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 384.}, {528., 384.}, {528., 0.}}}]}, {
                    FaceForm[{
                    RGBColor[0., 0.21960800000000003`, 0.7215689999999999], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     348.}, {528., 348.}, {528., 288.}, {0., 288.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     96.}, {528., 96.}, {528., 36.}, {0., 36.}}}]}, {
                    RGBColor[0., 0.21960800000000003`, 0.7215689999999999], 
                    Thickness[0.024999999999999998`], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{264., 
                    261.938}, {203.43, 157.031}, {324.57, 157.031}}}, 
                    CurveClosed -> {1}]}, {
                    RGBColor[0., 0.21960800000000003`, 0.7215689999999999], 
                    Thickness[0.024999999999999998`], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    264.00000000000006`, 122.06200000000018`}, {
                    324.56999999999994`, 226.96900000000002`}, {
                    203.43000000000004`, 226.96900000000002`}}}, 
                    CurveClosed -> {1}]}}, ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0, 528}, {36, 348}}], ",", 
                 GraphicsBox[{
                   Thickness[0.0008333333333333334], {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 720.}, {1200., 720.}, {1200., 0.}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.8078430000000001, 0.06666670000000002, 0.14902], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{1200., 720.}, {
                    296., 720.}, {480., 648.}, {296., 576.}, {480., 504.}, {
                    296., 432.}, {480., 360.}, {296., 288.}, {480., 216.}, {
                    296., 144.}, {480., 72.}, {296., 0.}, {1200., 0.}}}]}}, 
                  AspectRatio -> Automatic, ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 1200.}, {0., 720.}}], ",", 
                 GraphicsBox[{
                   Thickness[0.0015625], {
                    FaceForm[{
                    RGBColor[0.8784310000000001, 0., 0.14509800000000003`], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     308.202}, {640., 308.202}, {640., 103.40099999999998`}, {
                    0., 103.40099999999998`}}}]}, {
                    FaceForm[{
                    RGBColor[0.011764699999999998`, 0.180392, 0.631373], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     410.6}, {640., 410.6}, {640., 308.202}, {0., 308.202}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     103.40100000000001`}, {640., 103.40100000000001`}, {640.,
                     0.9990000000000094}, {0., 0.9990000000000094}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{317.59, 
                    285.811}, {317.59, 285.811}, {317.441, 290.022}, {319.895,
                     290.069}, {322.348, 290.022}, {322.199, 285.811}, {
                    322.199, 285.811}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{317.59, 
                    285.811006}, {317.59, 285.811006}, {317.441, 
                    290.02200600000003`}, {319.895, 290.069006}, {322.348, 
                    290.02200600000003`}, {322.199, 285.811006}, {322.199, 
                    285.811006}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}}}, {{{418.93399999999997`, 
                    175.721}, {418.93399999999997`, 196.73299999999998`}, {
                    419.617, 199.39700000000002`}, {421.879, 201.756}, {
                    423.582, 202.225}, {423.582, 221.93200000000002`}, {
                    421.012, 221.93200000000002`}, {419.75, 218.58}, {419.75, 
                    218.58}, {415.375, 199.319}, {415.375, 
                    175.88100000000003`}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}}}, {{{418.93399999999997`, 
                    175.72100600000002`}, {418.93399999999997`, 196.733006}, {
                    419.617, 199.39700600000003`}, {421.879, 201.756006}, {
                    423.582, 202.225006}, {423.582, 221.932006}, {421.012, 
                    221.932006}, {419.75, 218.580006}, {419.75, 218.580006}, {
                    415.375, 199.319006}, {415.375, 175.88100600000004`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    374.449, 217.545}, {380.75800000000004`, 217.545}, {
                    380.75800000000004`, 204.178}, {374.449, 204.178}}}]}, {
                    Thickness[0.001292146875], 
                    CapForm["Round"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    374.449, 217.545006}, {380.75800000000004`, 217.545006}, {
                    380.75800000000004`, 204.178006}, {374.449, 204.178006}}},
                     CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    262.316, 217.545}, {378.847, 217.545}, {378.847, 
                    172.70499999999998`}, {262.316, 172.70499999999998`}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    262.316, 217.545006}, {378.847, 217.545006}, {378.847, 
                    172.705006}, {262.316, 172.705006}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{221.262, 
                    175.79899999999998`}, {221.262, 196.73299999999998`}, {
                    220.578, 199.39700000000002`}, {218.316, 201.756}, {
                    216.61299999999997`, 202.225}, {216.61299999999997`, 
                    220.651}, {220.445, 218.58}, {224.82000000000002`, 
                    199.319}, {224.82000000000002`, 175.79899999999998`}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{221.262, 175.799006}, {
                    221.262, 196.733006}, {220.578, 199.39700600000003`}, {
                    218.316, 201.756006}, {216.61299999999997`, 202.225006}, {
                    216.61299999999997`, 220.65100600000002`}, {220.445, 
                    218.580006}, {224.82000000000002`, 199.319006}, {
                    224.82000000000002`, 175.799006}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}}}, {{{221.262, 175.721}, {
                    221.262, 196.73299999999998`}, {220.578, 
                    199.39700000000002`}, {218.316, 201.756}, {
                    216.61299999999997`, 202.225}, {216.61299999999997`, 
                    221.93200000000002`}, {219.18800000000002`, 
                    221.93200000000002`}, {220.445, 218.58}, {220.445, 
                    218.58}, {224.82000000000002`, 199.319}, {
                    224.82000000000002`, 175.88100000000003`}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}}}, {{{221.262, 
                    175.72100600000002`}, {221.262, 196.733006}, {220.578, 
                    199.39700600000003`}, {218.316, 201.756006}, {
                    216.61299999999997`, 202.225006}, {216.61299999999997`, 
                    221.932006}, {219.18800000000002`, 221.932006}, {220.445, 
                    218.580006}, {220.445, 218.580006}, {224.82000000000002`, 
                    199.319006}, {224.82000000000002`, 175.88100600000004`}}},
                     CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    216.73, 170.354}, {218.535, 171.272}, {220.59, 173.409}, {
                    221.262, 175.79899999999998`}, {418.97299999999996`, 
                    175.79899999999998`}, {419.64500000000004`, 173.409}, {
                    421.699, 171.272}, {423.504, 170.354}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    216.73, 170.35400600000003`}, {218.535, 
                    171.27200599999998`}, {220.59, 173.409006}, {221.262, 
                    175.799006}, {418.97299999999996`, 175.799006}, {
                    419.64500000000004`, 173.409006}, {421.699, 
                    171.27200599999998`}, {423.504, 170.35400600000003`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    372.828, 192.791}, {376.5, 192.791}, {376.5, 175.9}, {
                    372.828, 175.9}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Round"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    372.828, 192.791006}, {376.5, 192.791006}, {376.5, 
                    175.90000600000002`}, {372.828, 175.90000600000002`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    262.316, 201.135}, {378.847, 201.135}, {378.847, 
                    195.92399999999998`}, {262.316, 195.92399999999998`}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    262.316, 201.135006}, {378.847, 201.135006}, {378.847, 
                    195.924006}, {262.316, 195.924006}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    262.316, 208.202}, {378.847, 208.202}, {378.847, 
                    203.60399999999998`}, {262.316, 203.60399999999998`}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    262.316, 208.20200599999998`}, {378.847, 
                    208.20200599999998`}, {378.847, 203.60400599999997`}, {
                    262.316, 203.60400599999997`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    262.316, 215.256}, {378.847, 215.256}, {378.847, 
                    210.799}, {262.316, 210.799}}}]}, {
                    Thickness[0.0011818156249999998`], 
                    CapForm["Butt"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    262.316, 215.256006}, {378.847, 215.256006}, {378.847, 
                    210.79900600000002`}, {262.316, 210.79900600000002`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    374.449, 217.545}, {380.75800000000004`, 217.545}, {
                    380.75800000000004`, 204.178}, {374.449, 204.178}}}]}, {
                    Thickness[0.001292146875], 
                    CapForm["Round"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    374.449, 217.545006}, {380.75800000000004`, 217.545006}, {
                    380.75800000000004`, 204.178006}, {374.449, 204.178006}}},
                     CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{421.484, 
                    170.354}, {419.715, 171.155}, {417.137, 173.342}, {
                    417.137, 175.545}, {417.137, 201.70499999999998`}, {
                    418.348, 203.866}, {373.78099999999995`, 203.866}, {
                    375.52, 201.70499999999998`}, {375.52, 175.545}, {375.52, 
                    173.342}, {373.75, 171.155}, {371.97999999999996`, 
                    170.354}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{421.484, 
                    170.35400600000003`}, {419.715, 171.15500600000001`}, {
                    417.137, 173.342006}, {417.137, 175.545006}, {417.137, 
                    201.705006}, {418.348, 203.86600600000003`}, {
                    373.78099999999995`, 203.86600600000003`}, {375.52, 
                    201.705006}, {375.52, 175.545006}, {375.52, 173.342006}, {
                    373.75, 171.15500600000001`}, {371.97999999999996`, 
                    170.35400600000003`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    292.98799999999994`, 192.791}, {296.65999999999997`, 
                    192.791}, {296.65999999999997`, 175.9}, {
                    292.98799999999994`, 175.9}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Round"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    292.98799999999994`, 192.791006}, {296.65999999999997`, 
                    192.791006}, {296.65999999999997`, 175.90000600000002`}, {
                    292.98799999999994`, 175.90000600000002`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    343.156, 192.791}, {346.82800000000003`, 192.791}, {
                    346.82800000000003`, 175.9}, {343.156, 175.9}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Round"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    343.156, 192.791006}, {346.82800000000003`, 192.791006}, {
                    346.82800000000003`, 175.90000600000002`}, {343.156, 
                    175.90000600000002`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{349.301, 
                    170.354}, {347.22299999999996`, 171.155}, {344.203, 
                    173.342}, {344.203, 175.545}, {344.203, 
                    200.42800000000003`}, {346.90599999999995`, 203.866}, {
                    292.863, 203.866}, {295.453, 200.42800000000003`}, {
                    295.453, 175.545}, {295.453, 173.342}, {293.379, 
                    171.155}, {291.301, 170.354}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{349.301, 
                    170.35400600000003`}, {347.22299999999996`, 
                    171.15500600000001`}, {344.203, 173.342006}, {344.203, 
                    175.545006}, {344.203, 200.428006}, {346.90599999999995`, 
                    203.86600600000003`}, {292.863, 203.86600600000003`}, {
                    295.453, 200.428006}, {295.453, 175.545006}, {295.453, 
                    173.342006}, {293.379, 171.15500600000001`}, {291.301, 
                    170.35400600000003`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    302.47299999999996`, 192.791}, {306.145, 192.791}, {
                    306.145, 175.9}, {302.47299999999996`, 175.9}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Round"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    302.47299999999996`, 192.791006}, {306.145, 192.791006}, {
                    306.145, 175.90000600000002`}, {302.47299999999996`, 
                    175.90000600000002`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    333.51599999999996`, 192.791}, {337.188, 192.791}, {
                    337.188, 175.9}, {333.51599999999996`, 175.9}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Round"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    333.51599999999996`, 192.791006}, {337.188, 192.791006}, {
                    337.188, 175.90000600000002`}, {333.51599999999996`, 
                    175.90000600000002`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{291.895, 232.178}, {291.895, 
                    203.86200000000002`}, {347.215, 203.86200000000002`}, {
                    347.215, 209.959}, {347.29299999999995`, 232.178}, {
                    345.03099999999995`, 231.291}, {344.633, 
                    229.24099999999999`}, {344.633, 229.24099999999999`}, {
                    344.633, 217.178}, {294.715, 217.178}, {294.715, 
                    229.24099999999999`}, {294.715, 229.24099999999999`}, {
                    294.156, 231.291}, {291.895, 232.178}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{291.895, 232.17800599999998`}, {291.895, 
                    203.862006}, {347.215, 203.862006}, {347.215, 
                    209.95900600000002`}, {347.29299999999995`, 
                    232.17800599999998`}, {345.03099999999995`, 231.291006}, {
                    344.633, 229.241006}, {344.633, 229.241006}, {344.633, 
                    217.17800599999998`}, {294.715, 217.17800599999998`}, {
                    294.715, 229.241006}, {294.715, 229.241006}, {294.156, 
                    231.291006}, {291.895, 232.17800599999998`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{339.707, 
                    170.354}, {337.89799999999997`, 171.155}, {
                    333.96099999999996`, 173.342}, {333.96099999999996`, 
                    175.545}, {333.96099999999996`, 203.389}, {334.348, 
                    204.944}, {336.457, 205.86200000000002`}, {337.812, 
                    206.83}, {301.129, 206.83}, {302.875, 205.905}, {304.82, 
                    205.13899999999998`}, {305.52, 203.389}, {305.52, 
                    175.545}, {305.52, 173.342}, {302.402, 171.155}, {
                    300.59799999999996`, 170.354}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{339.707, 
                    170.35400600000003`}, {337.89799999999997`, 
                    171.15500600000001`}, {333.96099999999996`, 173.342006}, {
                    333.96099999999996`, 175.545006}, {333.96099999999996`, 
                    203.38900600000002`}, {334.348, 204.944006}, {336.457, 
                    205.862006}, {337.812, 206.83000600000003`}, {301.129, 
                    206.83000600000003`}, {302.875, 205.90500600000001`}, {
                    304.82, 205.139006}, {305.52, 203.38900600000002`}, {
                    305.52, 175.545006}, {305.52, 173.342006}, {302.402, 
                    171.15500600000001`}, {300.59799999999996`, 
                    170.35400600000003`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{344.629, 
                    206.53}, {344.629, 226.58800000000002`}, {
                    339.60200000000003`, 226.58800000000002`}, {
                    339.60200000000003`, 228.541}, {299.828, 228.541}, {
                    299.828, 226.58800000000002`}, {294.801, 
                    226.58800000000002`}, {294.801, 206.53}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{344.629, 
                    206.53000600000001`}, {344.629, 226.588006}, {
                    339.60200000000003`, 226.588006}, {339.60200000000003`, 
                    228.541006}, {299.828, 228.541006}, {299.828, 
                    226.588006}, {294.801, 226.588006}, {294.801, 
                    206.53000600000001`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    263.234, 192.791}, {266.90999999999997`, 192.791}, {
                    266.90999999999997`, 175.9}, {263.234, 175.9}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Round"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    263.234, 192.791006}, {266.90999999999997`, 192.791006}, {
                    266.90999999999997`, 175.90000600000002`}, {263.234, 
                    175.90000600000002`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{218.539, 
                    170.354}, {220.312, 171.155}, {222.89100000000002`, 
                    173.342}, {222.89100000000002`, 175.545}, {
                    222.89100000000002`, 201.70499999999998`}, {221.676, 
                    203.866}, {266.246, 203.866}, {264.504, 
                    201.70499999999998`}, {264.504, 175.545}, {264.504, 
                    173.342}, {266.277, 171.155}, {268.047, 170.354}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{218.539, 
                    170.35400600000003`}, {220.312, 171.15500600000001`}, {
                    222.89100000000002`, 173.342006}, {222.89100000000002`, 
                    175.545006}, {222.89100000000002`, 201.705006}, {221.676, 
                    203.86600600000003`}, {266.246, 203.86600600000003`}, {
                    264.504, 201.705006}, {264.504, 175.545006}, {264.504, 
                    173.342006}, {266.277, 171.15500600000001`}, {268.047, 
                    170.35400600000003`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    223.312, 221.27599999999998`}, {227.429, 
                    221.27599999999998`}, {227.429, 206.01799999999997`}, {
                    223.312, 206.01799999999997`}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Round"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    223.312, 221.276006}, {227.429, 221.276006}, {227.429, 
                    206.01800599999999`}, {223.312, 206.01800599999999`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    223.289, 224.538}, {227.402, 224.538}, {227.402, 
                    221.323}, {223.289, 221.323}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Round"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    223.289, 224.538006}, {227.402, 224.538006}, {227.402, 
                    221.323006}, {223.289, 221.323006}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{259.051, 
                    170.354}, {257.28099999999995`, 171.155}, {
                    254.69899999999998`, 173.342}, {254.69899999999998`, 
                    175.545}, {254.69899999999998`, 200.424}, {
                    258.40599999999995`, 203.866}, {228.10899999999998`, 
                    203.866}, {231.812, 200.424}, {231.812, 175.545}, {
                    231.812, 173.342}, {229.23399999999998`, 171.155}, {
                    227.465, 170.354}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{259.051, 
                    170.35400600000003`}, {257.28099999999995`, 
                    171.15500600000001`}, {254.69899999999998`, 173.342006}, {
                    254.69899999999998`, 175.545006}, {254.69899999999998`, 
                    200.42400600000002`}, {258.40599999999995`, 
                    203.86600600000003`}, {228.10899999999998`, 
                    203.86600600000003`}, {231.812, 200.42400600000002`}, {
                    231.812, 175.545006}, {231.812, 173.342006}, {
                    229.23399999999998`, 171.15500600000001`}, {227.465, 
                    170.35400600000003`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{254.809, 
                    170.354}, {253.035, 171.155}, {250.45700000000002`, 
                    173.342}, {250.45700000000002`, 175.545}, {
                    250.45700000000002`, 198.038}, {252.883, 
                    201.47899999999998`}, {233.63299999999998`, 
                    201.47899999999998`}, {236.059, 198.038}, {236.059, 
                    175.545}, {236.059, 173.342}, {233.48000000000002`, 
                    171.155}, {231.707, 170.354}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{254.809, 
                    170.35400600000003`}, {253.035, 171.15500600000001`}, {
                    250.45700000000002`, 173.342006}, {250.45700000000002`, 
                    175.545006}, {250.45700000000002`, 198.038006}, {252.883, 
                    201.479006}, {233.63299999999998`, 201.479006}, {236.059, 
                    198.038006}, {236.059, 175.545006}, {236.059, 
                    173.342006}, {233.48000000000002`, 171.15500600000001`}, {
                    231.707, 170.35400600000003`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    412.42199999999997`, 170.354}, {410.65200000000004`, 
                    171.155}, {408.074, 173.342}, {408.074, 175.545}, {
                    408.074, 200.424}, {411.777, 203.866}, {
                    381.47999999999996`, 203.866}, {385.188, 200.424}, {
                    385.188, 175.545}, {385.188, 173.342}, {382.605, 
                    171.155}, {380.83599999999996`, 170.354}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    412.42199999999997`, 170.35400600000003`}, {
                    410.65200000000004`, 171.15500600000001`}, {408.074, 
                    173.342006}, {408.074, 175.545006}, {408.074, 
                    200.42400600000002`}, {411.777, 203.86600600000003`}, {
                    381.47999999999996`, 203.86600600000003`}, {385.188, 
                    200.42400600000002`}, {385.188, 175.545006}, {385.188, 
                    173.342006}, {382.605, 171.15500600000001`}, {
                    380.83599999999996`, 170.35400600000003`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{408.18, 
                    170.354}, {406.40599999999995`, 171.155}, {403.828, 
                    173.342}, {403.828, 175.545}, {403.828, 198.038}, {
                    406.254, 201.47899999999998`}, {387.004, 
                    201.47899999999998`}, {389.42999999999995`, 198.038}, {
                    389.42999999999995`, 175.545}, {389.42999999999995`, 
                    173.342}, {386.85200000000003`, 171.155}, {385.078, 
                    170.354}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{408.18, 
                    170.35400600000003`}, {406.40599999999995`, 
                    171.15500600000001`}, {403.828, 173.342006}, {403.828, 
                    175.545006}, {403.828, 198.038006}, {406.254, 
                    201.479006}, {387.004, 201.479006}, {389.42999999999995`, 
                    198.038006}, {389.42999999999995`, 175.545006}, {
                    389.42999999999995`, 173.342006}, {386.85200000000003`, 
                    171.15500600000001`}, {385.078, 170.35400600000003`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    238.66, 201.47899999999998`}, {247.855, 
                    201.47899999999998`}, {247.855, 170.35399999999998`}, {
                    238.66, 170.35399999999998`}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    238.66, 201.479006}, {247.855, 201.479006}, {247.855, 
                    170.354006}, {238.66, 170.354006}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    331.78099999999995`, 170.354}, {330.012, 171.155}, {
                    327.42999999999995`, 173.342}, {327.42999999999995`, 
                    175.545}, {327.42999999999995`, 199.319}, {328.887, 
                    201.47899999999998`}, {310.77, 201.47899999999998`}, {
                    312.227, 199.319}, {312.227, 175.545}, {312.227, 
                    173.342}, {309.64500000000004`, 171.155}, {307.875, 
                    170.354}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    331.78099999999995`, 170.35400600000003`}, {330.012, 
                    171.15500600000001`}, {327.42999999999995`, 173.342006}, {
                    327.42999999999995`, 175.545006}, {327.42999999999995`, 
                    199.319006}, {328.887, 201.479006}, {310.77, 
                    201.479006}, {312.227, 199.319006}, {312.227, 
                    175.545006}, {312.227, 173.342006}, {309.64500000000004`, 
                    171.15500600000001`}, {307.875, 170.35400600000003`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    315.23799999999994`, 201.467}, {324.41799999999995`, 
                    201.467}, {324.41799999999995`, 170.36200000000002`}, {
                    315.23799999999994`, 170.36200000000002`}}}]}, {
                    Thickness[0.0012262218749999998`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    315.23799999999994`, 201.46700600000003`}, {
                    324.41799999999995`, 201.46700600000003`}, {
                    324.41799999999995`, 170.36200600000004`}, {
                    315.23799999999994`, 170.36200600000004`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    392.03099999999995`, 201.47899999999998`}, {
                    401.22599999999994`, 201.47899999999998`}, {
                    401.22599999999994`, 170.35399999999998`}, {
                    392.03099999999995`, 170.35399999999998`}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    392.03099999999995`, 201.479006}, {401.22599999999994`, 
                    201.479006}, {401.22599999999994`, 170.354006}, {
                    392.03099999999995`, 170.354006}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    310.617, 213.29899999999998`}, {329.043, 
                    213.29899999999998`}, {329.043, 206.51}, {310.617, 
                    206.51}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    310.617, 213.299006}, {329.043, 213.299006}, {329.043, 
                    206.510006}, {310.617, 206.510006}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}}}, {{{329.242, 208.315}, {
                    329.26599999999996`, 210.36200000000002`}, {335.219, 
                    210.455}, {338.28499999999997`, 212.202}, {301.469, 
                    212.202}, {304.53499999999997`, 210.455}, {310.355, 
                    210.311}, {310.355, 208.315}, {311.60200000000003`, 
                    204.33800000000002`}, {326.84000000000003`, 
                    203.72899999999998`}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}}}, {{{329.242, 208.315006}, {
                    329.26599999999996`, 210.362006}, {335.219, 
                    210.45500600000003`}, {338.28499999999997`, 
                    212.20200599999998`}, {301.469, 212.20200599999998`}, {
                    304.53499999999997`, 210.45500600000003`}, {310.355, 
                    210.31100600000002`}, {310.355, 208.315006}, {
                    311.60200000000003`, 204.338006}, {326.84000000000003`, 
                    203.729006}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    336.43799999999993`, 229.959}, {336.43799999999993`, 
                    234.975}, {336.648, 236.909}, {338.191, 236.909}, {
                    338.191, 220.955}, {334.40999999999997`, 219.584}, {
                    331.715, 214.76}, {331.715, 214.76}, {307.945, 214.76}, {
                    307.945, 214.76}, {305.246, 219.584}, {301.469, 
                    220.955}, {301.469, 236.909}, {303.367, 236.909}, {
                    303.379, 234.889}, {303.379, 229.959}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 
                    0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    336.43799999999993`, 229.95900600000002`}, {
                    336.43799999999993`, 234.975006}, {336.648, 236.909006}, {
                    338.191, 236.909006}, {338.191, 220.95500600000003`}, {
                    334.40999999999997`, 219.58400600000002`}, {331.715, 
                    214.760006}, {331.715, 214.760006}, {307.945, 
                    214.760006}, {307.945, 214.760006}, {305.246, 
                    219.58400600000002`}, {301.469, 220.95500600000003`}, {
                    301.469, 236.909006}, {303.367, 236.909006}, {303.379, 
                    234.88900600000002`}, {303.379, 229.95900600000002`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    308.29699999999997`, 226.98700000000002`}, {
                    311.35900000000004`, 223.311}, {311.074, 217.077}, {
                    311.039, 213.401}, {328.801, 213.401}, {
                    328.76599999999996`, 217.077}, {328.47999999999996`, 
                    223.311}, {331.543, 226.98700000000002`}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    308.29699999999997`, 226.98700600000004`}, {
                    311.35900000000004`, 223.31100600000002`}, {311.074, 
                    217.077006}, {311.039, 213.40100600000002`}, {328.801, 
                    213.40100600000002`}, {328.76599999999996`, 217.077006}, {
                    328.47999999999996`, 223.31100600000002`}, {331.543, 
                    226.98700600000004`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    226.14499999999998`, 192.791}, {229.81699999999998`, 
                    192.791}, {229.81699999999998`, 175.9}, {
                    226.14499999999998`, 175.9}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Round"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    226.14499999999998`, 192.791006}, {229.81699999999998`, 
                    192.791006}, {229.81699999999998`, 175.90000600000002`}, {
                    226.14499999999998`, 175.90000600000002`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    412.719, 221.27599999999998`}, {416.832, 
                    221.27599999999998`}, {416.832, 206.01799999999997`}, {
                    412.719, 206.01799999999997`}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Round"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    412.719, 221.276006}, {416.832, 221.276006}, {416.832, 
                    206.01800599999999`}, {412.719, 206.01800599999999`}}}, 
                    CurveClosed -> {1}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    216.73, 170.35400600000003`}, {218.535, 
                    171.27200599999998`}, {220.59, 173.409006}, {221.262, 
                    175.799006}, {418.97299999999996`, 175.799006}, {
                    419.64500000000004`, 173.409006}, {421.699, 
                    171.27200599999998`}, {423.504, 170.35400600000003`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    257.633, 192.791}, {261.305, 192.791}, {261.305, 175.9}, {
                    257.633, 175.9}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Round"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    257.633, 192.791006}, {261.305, 192.791006}, {261.305, 
                    175.90000600000002`}, {257.633, 175.90000600000002`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{220.434, 226.475}, {220.434, 203.866}, {223.004, 
                    203.866}, {223.004, 226.53}, {222.078, 
                    226.99800000000002`}, {221.207, 227.07299999999998`}, {
                    220.434, 226.475}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{220.434, 226.475006}, {220.434, 
                    203.86600600000003`}, {223.004, 203.86600600000003`}, {
                    223.004, 226.53000600000001`}, {222.078, 226.998006}, {
                    221.207, 227.073006}, {220.434, 226.475006}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}}}, {{{220.516, 
                    211.846}, {223.70299999999997`, 210.21699999999998`}, {
                    226.859, 208.33}, {227.656, 203.866}, {220.516, 
                    203.866}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}}}, {{{220.516, 
                    211.84600600000002`}, {223.70299999999997`, 210.217006}, {
                    226.859, 208.33000600000003`}, {227.656, 
                    203.86600600000003`}, {220.516, 203.86600600000003`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    259.39099999999996`, 217.545}, {265.7, 217.545}, {265.7, 
                    204.178}, {259.39099999999996`, 204.178}}}]}, {
                    Thickness[0.001292146875], 
                    CapForm["Round"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    259.39099999999996`, 217.545006}, {265.7, 217.545006}, {
                    265.7, 204.178006}, {259.39099999999996`, 204.178006}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{264.719, 218.62}, {264.719, 203.866}, {266.801, 
                    203.866}, {266.801, 218.655}, {266.15200000000004`, 
                    218.959}, {265.262, 219.006}, {264.719, 218.62}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{264.719, 218.620006}, {264.719, 
                    203.86600600000003`}, {266.801, 203.86600600000003`}, {
                    266.801, 218.65500600000001`}, {266.15200000000004`, 
                    218.95900600000002`}, {265.262, 219.006006}, {264.719, 
                    218.620006}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}}}, CompressedData["
1:eJxlVWtIFFEU3t20l2WmoRK2aoVFFhIUsUl1/BEmZQ8LiwoRKYtyZ69z75Rp
SiEhEWFSUBARS5nUD1nEFokISwnzx6KlVIpJpPQyou2xWATdx8wZ1gbmx8e9
c875vvOdM5llvqLD0xwOh5O/5fx18feqlljfOYfCnevdGYFHFWDh8PPCsgTm
hQ2zX94icRTO55WO94W8kBHQjzaN6rD/UO7ojkEvPN267nzeGx0m6449ZCna
f/jJz+UHG1/pKn61Bkn1nb3+cR3iV7Xd+NqiqfgRHZJfhyK7l2iQ/7Z6QWsK
hce9/s3BXBs3fTm9aa1u4w9/7n577tdgo/g+lkKrOAhpkCYK4/XFFPMMeT5Y
JPALXdVR7lN1D+tgXE6NKR7ywbtmXtiEDpzd4mEngfs9Jx7dDOuw8yJX4qZ5
/lsH73ueUPOp/PMo4poFPHOajRMFv2Wmfmds3CXyt03BYZ/SYT6F4Pe/A1Wz
CBwVRGdQWCnkySJKd54//dznXR1bCAh5S6dR6BaNOE5UnlQKCfs87T11RNWR
QeFBwRxXdiGBDjf/0G3e95h4jY1l/FIzfz4BIXMJPxc26G0git8KCqc+Zq2e
eY3AXFFvOgUh1+Q9ovzgoaq+vv+x1Cvf5HObwGAVD7SNwjMu80I/Uf0/YNbb
TEDIHdAowNqSBwX3zPsVFJzZDcmvnxLlzz0UigSREaL020xBlFk9QSBnZOn0
szzfwUbecVel0msvhRZhzCQTH6GwScT/QWAFDxuqobC9jCv4i4BIE6o1659Z
qfQkJt5Zqfp3gSGWfq5lik+ciU8xxSdCQMhUd4WBSwQOEzjJr+U0M6xHhHHf
Z1iv5B9kyEf6uYUhX9mfSwz1kPwvMtRLxvMz1FPeDzDUW/JpZ9gPMQbxXQz7
NRVLfw0xGBNEggTWt/MB6WfoBznvPQz9IvW8ztBP1nmU/97YWPpjmKFf5ZyO
MfSznIdJhn6X/XEa0fPwk+G8yD3zieE8Sb4DDOctCrfZ2JpXj+A3yqLne8LG
/aKfLgOx1H+WgftC9jvBwH0i902mgftG1rfcwH0k/Zxm4L6S/ogw3GcyP9fD
2ncWtvahha19Kb+PNXCfVog6kw3ctw7xLDVwH0t/uA3c11Ox9MMiA/e99Nc3
hv8D6c+vDP8XFrb+J/8ApYz8HQ==
                    "]]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}}}, CompressedData["
1:eJxlVWtIFFEUVrPSnrZKRW2mFWb2kCCz7XkMYnsYVpQ9MelhRu7sde6dMrei
shKJMC0qiLKlzDIqWUokSKRCRdBWS3osKdI7DVMysaKae2fmLNrA/PiYmXvO
953vfBO+zb5mZz8fHx9f9U5Rbz/1Pi+ZsiqGUNjauHF6SXkaGPjWkLdSELPB
gkEvrpLBFBY7ujrcdTYIK5FT85plCL7sbk1otEHliticuCYZXGV/q9ko6T/8
qCtyS+5LWTs/U4LgrIoa53sZKlOsxe1FknZ+twxPTTv8106UwNqSGXJnFIVM
/9g1pfO8ePlkU3yM7MXOmEV/GpwSLOTf96ew68je7JA6CcybdsxrVvt7mHvV
4oqzwziOn8ngiC5PzU2xA4cJHhlm1N4OSnxth7eFF5+Etckw/+jYKR5fAver
95YXdMoQWDXNYSrQn/+UISI8r7RDsmv1h1PEjpA71hazF5s4v8kUirl+h71Y
1Hf1wZ12GDbddal9BIX800s9GYEEUvO+Hlg0kMKghE9dRREEcuKS37vV+r/C
Z28oW0qAy5vcj8KVhz8zUvcQ6GxYuS1oNIWv37MeVB8iYPv462ZHGIXzHxID
pq4kUBZ6vHV1qKoXf9+i41leLM5PpnCG17cSUKvHJKnP4+/WVtZkE41fFIV1
J9JjAy4QGMr7HU/hkc3W0lNMND9YqNaf+38s9LLqfK4RaMz4HDEznkJhcOD1
MU6izX+z3m8hAS53iUTB3HCjYlmx/n4ahaaqevOrSqL5cy2FGet2n2x9QzT9
llD4tjz/Y2Ybgeg3kwYcUevNmTb0d6RfuqbXegrHtp9bkBOs4136+d8JRGWP
fFXnoBD1d1OS5QeBqRwf1PsPSNf0JDpela7N7yRDLPx8kGl8But4P4NznE83
AfcET8+hs0zrv5PAvvKCMdGFDPtRp1EWep9hv4J/KUM+ws9FDPmK+ZxmqIfg
f4qhXuI8J0M9xfslDPUWfO4xnMeZ0f6Jwx4znFdfLPz1mmnzLiUw9566IPUM
/SD2vZqhX4SeFxn6yXjey39NXiz84WHoV5EX7xj6WexDD0O/i/n4Kr33oYvh
vlzn+n1huE+C73OG+9YLu7zY2FcL59fMeu93mxfX83n6KYiF/oEK5oWYd5CC
eSLyJlzBvBH9RSqYR8LPZgXzSvijm2GeifqqHkbeGdjIQwMbeSm+769gnqZx
fiMVzFsffk1SMI+FP0IVzOu+WPhhnIJ5L/zVwfB/IPzZzvB/YWDjf/IPab3x
Fw==
                    "], CurveClosed -> {1}]}, {
                    Thickness[0.001], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{311.277, 271.655006}, {
                    328.816, 271.655006}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    318.28099999999995`, 269.10400000000004`}, {315.848, 
                    270.358}, {315.848, 273.94}, {316.84400000000005`, 
                    273.639}, {317.96099999999996`, 273.518}, {318.066, 
                    271.93199999999996`}, {318.414, 274.194}, {319.039, 
                    274.084}, {320.02, 274.967}, {321., 274.084}, {321.625, 
                    274.194}, {321.97299999999996`, 271.93199999999996`}, {
                    322.082, 273.518}, {323.199, 273.639}, {324.191, 
                    273.94}, {324.191, 270.358}, {321.758, 
                    269.10400000000004`}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    318.28099999999995`, 269.104006}, {315.848, 
                    270.35800600000005`}, {315.848, 273.94000600000004`}, {
                    316.84400000000005`, 273.639006}, {317.96099999999996`, 
                    273.518006}, {318.066, 271.932006}, {318.414, 
                    274.194006}, {319.039, 274.08400600000004`}, {320.02, 
                    274.967006}, {321., 274.08400600000004`}, {321.625, 
                    274.194006}, {321.97299999999996`, 271.932006}, {322.082, 
                    273.518006}, {323.199, 273.639006}, {324.191, 
                    273.94000600000004`}, {324.191, 270.35800600000005`}, {
                    321.758, 269.104006}}}, CurveClosed -> {1}]}, {
                    Thickness[0.001], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{309.195, 266.178006}, {
                    330.621, 266.178006}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    318.117, 263.22499999999997`}, {314.078, 266.002}, {
                    314.078, 269.303}, {315.4959999999999, 
                    268.97499999999997`}, {317.08599999999996`, 
                    268.84200000000004`}, {317.242, 267.10400000000004`}, {
                    317.734, 269.584}, {318.625, 270.87}, {320.02, 271.834}, {
                    321.41799999999995`, 270.87}, {322.309, 269.584}, {
                    322.801, 267.10400000000004`}, {322.957, 
                    268.84200000000004`}, {324.547, 268.97499999999997`}, {
                    325.965, 269.303}, {325.965, 266.002}, {
                    321.92199999999997`, 263.22499999999997`}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    318.117, 263.225006}, {314.078, 266.002006}, {314.078, 
                    269.303006}, {315.4959999999999, 268.975006}, {
                    317.08599999999996`, 268.84200599999997`}, {317.242, 
                    267.104006}, {317.734, 269.58400600000004`}, {318.625, 
                    270.870006}, {320.02, 271.83400600000004`}, {
                    321.41799999999995`, 270.870006}, {322.309, 
                    269.58400600000004`}, {322.801, 267.104006}, {322.957, 
                    268.84200599999997`}, {324.547, 268.975006}, {325.965, 
                    269.303006}, {325.965, 266.002006}, {321.92199999999997`, 
                    263.225006}}}, CurveClosed -> {1}]}, {
                    Thickness[0.001], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{307.121, 259.534006}, {
                    332.625, 259.534006}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    317.832, 254.069}, {313.188, 258.14700000000005`}, {
                    313.188, 262.99799999999993`}, {314.816, 262.514}, {
                    316.64500000000004`, 262.319}, {316.824, 259.764}, {
                    317.39099999999996`, 263.409}, {318.414, 
                    265.29499999999996`}, {320.02, 266.71299999999997`}, {
                    321.629, 265.29499999999996`}, {322.648, 263.409}, {
                    323.219, 259.764}, {323.395, 262.319}, {325.227, 
                    262.514}, {326.855, 262.99799999999993`}, {326.855, 
                    258.14700000000005`}, {322.207, 254.069}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    317.832, 254.069006}, {313.188, 258.14700600000003`}, {
                    313.188, 262.99800600000003`}, {314.816, 262.514006}, {
                    316.64500000000004`, 262.319006}, {316.824, 259.764006}, {
                    317.39099999999996`, 263.409006}, {318.414, 265.295006}, {
                    320.02, 266.71300599999995`}, {321.629, 265.295006}, {
                    322.648, 263.409006}, {323.219, 259.764006}, {323.395, 
                    262.319006}, {325.227, 262.514006}, {326.855, 
                    262.99800600000003`}, {326.855, 258.14700600000003`}, {
                    322.207, 254.069006}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    326.39799999999997`, 248.647}, {322.199, 242.834}, {
                    317.441, 242.834}, {313.23799999999994`, 248.647}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    326.39799999999997`, 248.647006}, {322.199, 
                    242.83400600000002`}, {317.441, 242.83400600000002`}, {
                    313.23799999999994`, 248.647006}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    310.82, 238.893}, {312.92199999999997`, 
                    237.74499999999998`}, {313.699, 235.455}, {
                    313.92199999999997`, 231.159}, {325.75, 231.159}, {
                    325.97299999999996`, 235.455}, {326.75, 
                    237.74499999999998`}, {328.85200000000003`, 238.893}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}}}, {{{
                    310.82, 238.893006}, {312.92199999999997`, 237.745006}, {
                    313.699, 235.45500600000003`}, {313.92199999999997`, 
                    231.159006}, {325.75, 231.159006}, {325.97299999999996`, 
                    235.45500600000003`}, {326.75, 237.745006}, {
                    328.85200000000003`, 238.893006}}}, CurveClosed -> {1}]}, {
                    Thickness[0.001], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{304.945, 251.412006}, {
                    335.191, 251.412006}}}, CurveClosed -> {0}]}, {
                    Thickness[0.001], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{304.25, 242.159006}, {
                    335.40599999999995`, 242.159006}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}}}, {{{329.027, 248.647}, {
                    329.027, 254.48700000000002`}, {327.03099999999995`, 
                    253.936}, {325.73799999999994`, 252.752}, {325.16, 
                    251.151}, {325.16, 253.08800000000002`}, {
                    322.60900000000004`, 257.557}, {319.828, 259.78}, {
                    317.039, 257.29099999999994`}, {314.445, 253.248}, {
                    314.4959999999999, 251.151}, {314.02299999999997`, 
                    252.678}, {312.629, 253.936}, {310.629, 
                    254.48700000000002`}, {310.629, 248.647}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}}}, {{{329.027, 248.647006}, {
                    329.027, 254.48700600000004`}, {327.03099999999995`, 
                    253.93600600000002`}, {325.73799999999994`, 252.752006}, {
                    325.16, 251.15100600000002`}, {325.16, 253.088006}, {
                    322.60900000000004`, 257.557006}, {319.828, 
                    259.78000599999996`}, {317.039, 257.29100600000004`}, {
                    314.445, 253.24800599999998`}, {314.4959999999999, 
                    251.15100600000002`}, {314.02299999999997`, 
                    252.67800599999998`}, {312.629, 253.93600600000002`}, {
                    310.629, 254.48700600000004`}, {310.629, 248.647006}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}}}, {{{329.90999999999997`, 
                    238.893}, {329.90999999999997`, 244.72899999999998`}, {
                    327.72299999999996`, 244.18200000000002`}, {326.305, 
                    242.99800000000002`}, {325.672, 241.393}, {325.672, 
                    243.334}, {322.879, 247.803}, {319.828, 250.026}, {316.77,
                     247.538}, {313.92599999999993`, 243.495}, {313.984, 
                    241.393}, {313.465, 242.924}, {311.93399999999997`, 
                    244.18200000000002`}, {309.746, 244.72899999999998`}, {
                    309.746, 238.893}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}}}, {{{329.90999999999997`, 
                    238.893006}, {329.90999999999997`, 244.729006}, {
                    327.72299999999996`, 244.182006}, {326.305, 242.998006}, {
                    325.672, 241.393006}, {325.672, 243.33400600000002`}, {
                    322.879, 247.803006}, {319.828, 250.02600600000002`}, {
                    316.77, 247.538006}, {313.92599999999993`, 
                    243.49500600000002`}, {313.984, 241.393006}, {313.465, 
                    242.92400600000002`}, {311.93399999999997`, 244.182006}, {
                    309.746, 244.729006}, {309.746, 238.893006}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}}}, {{{332.371, 226.909}, {
                    332.371, 233.64299999999997`}, {329.648, 232.944}, {
                    327.957, 230.92800000000003`}, {327.10200000000003`, 
                    229.752}, {327.10200000000003`, 233.401}, {322.984, 
                    238.959}, {319.828, 240.78}, {316.594, 
                    238.91299999999998`}, {312.559, 233.166}, {312.559, 
                    229.752}, {311.676, 230.92000000000002`}, {310.008, 
                    232.944}, {307.28499999999997`, 233.64299999999997`}, {
                    307.28499999999997`, 226.909}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}}}, {{{332.371, 226.909006}, {
                    332.371, 233.64300599999999`}, {329.648, 232.944006}, {
                    327.957, 230.928006}, {327.10200000000003`, 229.752006}, {
                    327.10200000000003`, 233.40100600000002`}, {322.984, 
                    238.95900600000002`}, {319.828, 240.780006}, {316.594, 
                    238.912006}, {312.559, 233.166006}, {312.559, 
                    229.752006}, {311.676, 230.920006}, {310.008, 
                    232.944006}, {307.28499999999997`, 233.64300599999999`}, {
                    307.28499999999997`, 226.909006}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}}}, {{{330.89799999999997`, 
                    211.959}, {330.89799999999997`, 218.88500000000002`}, {
                    328.4959999999999, 217.944}, {327.777, 215.627}, {327.02, 
                    214.053}, {327.316, 221.077}, {323.066, 228.627}, {
                    319.828, 230.541}, {316.59, 228.627}, {312.258, 
                    220.916}, {312.637, 214.053}, {311.85900000000004`, 
                    215.61599999999999`}, {311.16, 217.944}, {308.758, 
                    218.88500000000002`}, {308.758, 211.959}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}}}, {{{330.89799999999997`, 
                    211.95900600000002`}, {330.89799999999997`, 
                    218.88500600000003`}, {328.4959999999999, 217.944006}, {
                    327.777, 215.62700600000002`}, {327.02, 214.053006}, {
                    327.316, 221.077006}, {323.066, 228.62700600000002`}, {
                    319.828, 230.541006}, {316.59, 228.62700600000002`}, {
                    312.258, 220.916006}, {312.637, 214.053006}, {
                    311.85900000000004`, 215.616006}, {311.16, 217.944006}, {
                    308.758, 218.88500600000003`}, {308.758, 
                    211.95900600000002`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    412.746, 224.538}, {416.859, 224.538}, {416.859, 
                    221.323}, {412.746, 221.323}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Round"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    412.746, 224.538006}, {416.859, 224.538006}, {416.859, 
                    221.323006}, {412.746, 221.323006}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    378.777, 192.791}, {382.449, 192.791}, {382.449, 175.9}, {
                    378.777, 175.9}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Round"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    378.777, 192.791006}, {382.449, 192.791006}, {382.449, 
                    175.90000600000002`}, {378.777, 175.90000600000002`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    410.262, 192.791}, {413.934, 192.791}, {413.934, 175.9}, {
                    410.262, 175.9}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Round"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    410.262, 192.791006}, {413.934, 192.791006}, {413.934, 
                    175.90000600000002`}, {410.262, 175.90000600000002`}}}, 
                    CurveClosed -> {1}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{294.801, 
                    211.95900600000002`}, {344.629, 211.95900600000002`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    310.617, 211.952006}, {329.086, 211.952006}, {329.086, 
                    205.16700600000001`}, {310.617, 205.16700600000001`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}}}, {{{329.215, 
                    201.47899999999998`}, {329.215, 208.401}, {326.695, 
                    207.803}, {326.543, 206.873}, {325.742, 205.323}, {
                    326.039, 209.518}, {323.066, 214.303}, {319.828, 
                    216.21699999999998`}, {316.59, 214.303}, {313.621, 
                    209.518}, {313.91799999999995`, 205.323}, {313.117, 
                    206.873}, {313.01599999999996`, 207.803}, {310.441, 
                    208.401}, {310.441, 201.47899999999998`}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}}}, {{{329.215, 201.479006}, {
                    329.215, 208.40100600000002`}, {326.695, 207.803006}, {
                    326.543, 206.873006}, {325.742, 205.32300600000002`}, {
                    326.039, 209.51800599999999`}, {323.066, 214.303006}, {
                    319.828, 216.217006}, {316.59, 214.303006}, {313.621, 
                    209.51800599999999`}, {313.91799999999995`, 
                    205.32300600000002`}, {313.117, 206.873006}, {
                    313.01599999999996`, 207.803006}, {310.441, 
                    208.40100600000002`}, {310.441, 201.479006}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}}}, {{{266.801, 
                    211.846}, {263.613, 210.21699999999998`}, {260.457, 
                    208.33}, {259.66, 203.866}, {266.801, 203.866}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}}}, {{{266.801, 
                    211.84600600000002`}, {263.613, 210.217006}, {260.457, 
                    208.33000600000003`}, {259.66, 203.86600600000003`}, {
                    266.801, 203.86600600000003`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    223.004, 221.27599999999998`}, {227.42999999999998`, 
                    221.27599999999998`}, {227.42999999999998`, 
                    203.95999999999998`}, {223.004, 203.95999999999998`}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Round"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    223.004, 221.276006}, {227.42999999999998`, 221.276006}, {
                    227.42999999999998`, 203.960006}, {223.004, 203.960006}}},
                     CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    223.004, 224.538}, {227.402, 224.538}, {227.402, 
                    221.323}, {223.004, 221.323}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Round"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    223.004, 224.538006}, {227.402, 224.538006}, {227.402, 
                    221.323006}, {223.004, 221.323006}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    259.39099999999996`, 217.545}, {265.7, 217.545}, {265.7, 
                    204.178}, {259.39099999999996`, 204.178}}}]}, {
                    Thickness[0.001292146875], 
                    CapForm["Round"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    259.39099999999996`, 217.545006}, {265.7, 217.545006}, {
                    265.7, 204.178006}, {259.39099999999996`, 204.178006}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJ7IGYCYqstJ8r2Zec45D7/vfJjU6YDjC9289z3YPNc
h8dLZx9RmILgc19fXGA7K8dhp1zr68A1OQ5VIuvcH35D8B0Tnl5QUs+F8126
c57/Vsx1OL3QddvnpzkOsbs8eZjYcx3ctn3+e0Uk1yEOxH+f41A6WYIlzC7X
IWPi2xr7izkOB04BNZTnOgg3A1k/cxwOf9WI6X8ElReF6p+Q6xDOp7tpbnyu
QwfI4rJcB5AzHwfmOgBdVSWyCupeq1wHkDZTpjwHLhAf6N5kgQjLLQJ5EPM0
cx1sQRIz8yDusc6F+Fc9D+L/Fqh/dPIcQMbEFeU6LAMKb8iD8uNyHaJSrO/7
78xzWAT05l+TXAeQs95fz3NgAIEMqLxjvkMByCKgeSxhQBUn8xzU2BqnOq/O
hbjnAoIPjg+pfDi/PmtPyeSOfEj4Lc916AT5918+1L48B6BrijJECzD4QFfv
kLPNcwBFw0r3AodVHy/5JhUg+EWgAFiM4IPjfzVCPzofHB+W+XD79e+qsDWa
5sPdB+PD3A/jw/wHDs+YfLj/b/2sy9pTkQ8PH4h9+fDwA4dvUz48fMH8vHx4
+BeCwhNoHix+vgGTyaGl+fD4A/tvez48fi8p3f5Z9yofHv8XQPxl+fD0UQ1K
z3358PQDDr/GfHj6KgaZdzofnv7A6f15Pjx9grStYy+Ap1+wez7mw9M3mH8z
H57+Z+QJNR/Ylw/PH+Dw3ZkPzz9g9S8R/PJ986X0lQvg/B0gWq0Anj8vgvxj
hcmH5W8Ajzbb3g==
                    "]]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJ7IGYCYqstJ8r2Zec4qCpO3PaxKdMBxj8vlMISYp7r
8Hjp7CMKUxB87uuLC2xn5TgURUj9CFyT41Alss794TcE3zHh6QUl9Vw436U7
5/lvxVyHltu3Dn1+muMQu8uTh4k91+H/+w6uqyK5DnEg/vscB92zawXC7HId
Mia+rbG/mONQyWIetK0810G4+cCphT9zHKr192X0P4LKi0L1T8h1COfT3TQ3
PtfBsfrrxwtluQ43z30PfhyY65DeWNYusgrqXqtcBy91IR9TpjwHLhAf6F5p
r7euWwTyIOZp5jp8c87ZUDAzD+Ie61yIf9XzIP5vgfpHJ88BqNo0rijXIf5q
pO6GPCg/DujOeRde++/Mc1jkuu3zX5Nch2Np7qveX89zYACBDKi8Y75DgS3Q
BUDz9vYvttx0Ms9Bja1xqvPqXIh7LiD44PiQyofzzZcENk7uyIeE3/JcByeQ
f//lQ+3Lc1i491dFhmgBBr/1deAOOVugPzmNmFa5Fzis+njJN6kAwS8CBcBi
BB8c/6sR+tH54PiwzIfbr39Xha3RNB/uPhgf5n4YH+Y/cHjG5MP9f+tnXdae
inx4+EDsy4eHHzh8m/Lh4Qvm5+XDw78QFJ5A82Dx800jpv/Q0nx4/IH9tz0f
Hr+XlG7/rHuVD4//CyD+snx4+qgGpee+fHj6AYdfYz48fRWDzDudD09/4PT+
PB+ePt0fAnMEewE8/YLd8zEfnr7B/Jv58PQ/I0+o+cC+fHj+AIfvznx4/gGr
f4ngl++bL6WvXADn75ADulCtAJ4/L4L8Y4XJh+VvAFeLyus=
                    "], 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    245.73, 246.42000000000002`}, {247.59, 
                    247.97899999999998`}, {247.59, 249.97899999999998`}, {
                    246.91, 249.91299999999998`}, {246.539, 249.678}, {
                    246.035, 249.02200000000002`}, {245.60899999999998`, 
                    250.346}, {244.672, 251.38100000000003`}, {243.414, 
                    252.026}, {242.15200000000002`, 251.38100000000003`}, {
                    241.21499999999997`, 250.393}, {240.789, 249.069}, {
                    240.285, 249.725}, {239.914, 249.91299999999998`}, {
                    239.23399999999998`, 249.97899999999998`}, {
                    239.23399999999998`, 247.97899999999998`}, {241.094, 
                    246.42000000000002`}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    245.73, 246.420006}, {247.59, 247.979006}, {247.59, 
                    249.979006}, {246.91, 249.912006}, {246.539, 
                    249.67800599999998`}, {246.035, 249.022006}, {
                    245.60899999999998`, 250.34600600000002`}, {244.672, 
                    251.38100600000004`}, {243.414, 252.02600600000002`}, {
                    242.15200000000002`, 251.38100600000004`}, {
                    241.21499999999997`, 250.393006}, {240.789, 249.069006}, {
                    240.285, 249.725006}, {239.914, 249.912006}, {
                    239.23399999999998`, 249.979006}, {239.23399999999998`, 
                    247.979006}, {241.094, 246.420006}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    246.727, 241.405}, {247.59, 243.27599999999998`}, {247.59,
                     245.873}, {246.91, 245.80700000000002`}, {246.539, 
                    245.569}, {246.035, 244.901}, {245.60899999999998`, 
                    246.248}, {244.672, 247.295}, {243.414, 247.948}, {
                    242.15200000000002`, 247.295}, {241.21499999999997`, 
                    246.295}, {240.789, 244.95200000000003`}, {240.285, 
                    245.61599999999999`}, {239.914, 245.80700000000002`}, {
                    239.23399999999998`, 245.873}, {239.23399999999998`, 
                    243.27599999999998`}, {240.098, 241.405}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    246.727, 241.40500600000001`}, {247.59, 243.276006}, {
                    247.59, 245.873006}, {246.91, 245.80700600000003`}, {
                    246.539, 245.569006}, {246.035, 244.90100600000002`}, {
                    245.60899999999998`, 246.24800599999998`}, {244.672, 
                    247.295006}, {243.414, 247.948006}, {242.15200000000002`, 
                    247.295006}, {241.21499999999997`, 246.295006}, {240.789, 
                    244.952006}, {240.285, 245.616006}, {239.914, 
                    245.80700600000003`}, {239.23399999999998`, 245.873006}, {
                    239.23399999999998`, 243.276006}, {240.098, 
                    241.40500600000001`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    246.85500000000002`, 234.623}, {249.617, 237.991}, {
                    249.617, 241.311}, {248.605, 241.198}, {248.055, 
                    240.795}, {247.309, 239.666}, {246.676, 241.94}, {245.281,
                     242.44}, {243.414, 243.541}, {241.54299999999998`, 
                    242.44}, {240.148, 242.02200000000002`}, {239.516, 
                    239.74499999999998`}, {238.76999999999998`, 240.877}, {
                    238.21899999999997`, 241.198}, {237.207, 241.311}, {
                    237.207, 237.991}, {239.969, 234.623}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    246.85500000000002`, 234.623006}, {249.617, 
                    237.99100600000003`}, {249.617, 241.31100600000002`}, {
                    248.605, 241.198006}, {248.055, 240.795006}, {247.309, 
                    239.666006}, {246.676, 241.940006}, {245.281, 
                    242.440006}, {243.414, 243.541006}, {241.54299999999998`, 
                    242.440006}, {240.148, 242.022006}, {239.516, 
                    239.745006}, {238.76999999999998`, 240.87700600000002`}, {
                    238.21899999999997`, 241.198006}, {237.207, 
                    241.31100600000002`}, {237.207, 237.99100600000003`}, {
                    239.969, 234.623006}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4oyJb2vsv+Y5HP6qEdNfl+OAzn+8dPYRhZh8
hx1yra8Db+Q4cF1fXGCblO+gsKEoYyJnLpxvYgwE1bkO72rsTeOs8h0OgfSX
5ToU2AJViOQ7XKt4qWaYk+ugytY41fl7noMdWGOug7ohxxqZe3kO91SAErNz
HWJ3efIwbc9zePF75cdLW3Mh7snNcxC7ee578ONch36QwcoI+ePe5p2Of3Lh
+p0Snl5QAqqDmf8N6IxDR3Ph9jOAwIJcuPvA/qvIhbsfxof5D+hroNdz4f4H
85/mwsMHnQ8ABFCbJg==
                    "]]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4oyJb2vsv+Y51Ojvy+ivy3FA5z9eOvuIQky+
Q2GE1I/AGzkOXNcXF9gm5TvcfMleOpEzF85/k3PC3rg61+Fdjb1pnFW+QzVI
f1muQ4EtUIVIvkP/pjpjw5xcB1W2xqnO3/McvjnnbCiwzXVQN+RYI3Mvz2Fa
3OzeqbNzHWJ3efIwbc9zWGBq/+/S1lyIe3LzHM4LpbCEPM516D/0VSNGGSF/
3Nu80/FPLly/U8LTC0pAdTDzv2nE9B86mgu3nwEEFuTC3Qf2X0Uu3P0wPsx/
ra8Dd8i15sL9D+Y/zYWHDzofANFqmVA=
                    "], 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4tbXgTvkFPMd6rL2lEz+kuWAzlc35Fgjsy7f
IVkgwnLLhGwHb/NOx4SN+Q52XNcXF5xF8A9/1Yjpr8txKLQFStTkO4jdPPc9
uDzHYeuJsn3zvfIdcp//XvkxKMfBcgtQQDnfYeLbGntTLqg8U76D27bPf6/M
yXGoFlnn/vBcnkNA7/Q8IeZchwyQwtw8iHqvXIdikAA3Qh5s3vVcuH4Qd/62
XLj5ViCB/ly4/SBnPY7NhbsP7F/NXLj7YXyY/1TZGqc6G+fC/Q92z85cePig
8wGGoKCb
                    "]]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4tbXgTvkFPMdzJcENk7+kuWAzlc35Fgjsy7f
QdrrreuWCdkO3uadjgkb8x2+OedsKDiL4Nfo78vor8txKLTlur64Jt/hvFAK
S0h5jsPWE2X75nvlO6gqTtz2MSjHwXILUEA538FLXcjHlAsqz5Tv8P99B9fV
OTkO1SLr3B+ey3PgPK5TLcSc65Ax8W2NfW4eRL1XrkMxSIAbIQ8273ouXD+I
O39bLtx8K5BAfy7c/pvnvgc/js2Fuw/sX81cuPthfJj/VNkapzob58L9D3bP
zlx4+KDzAeAhlNE=
                    "], CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4tbXgTvkFPMdlhTYcl3nznJA5ws3Hzi1cGa+
Q4TllhNlbVkO3uadjgkb8x3uqbA1Tt2N4Ltt+/z3Sk62QyFQ2+KafAcQVZCa
7bD1RNm++V75Dh+WH/M2d8x2ABmzTznfYfYRhQ1FP7Ig8kz5DgG90/OEurMd
qkXWuT88l+eQ+/z3yo/3sh0yJr6tsc/NcwCKVomo5TgUgwS4EfJg867nwvWD
uPO35cLNtwIJ9OfC7b957nvw49hcuPvA/tXMhbsfxof5L4xPd9Nc91y4/8Hu
2ZkLDx90PgCrxZ/i
                    "]]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4tbXgTvkFPMdYlddErvOneWAzhduPnBq4cx8
B4Fiz6tlbVkO3uadjgkb8x2mxc3unbobwf//voPrak62Q6Et1/XFNfkO35xz
NhSkZjtsPVG2b75XvsOKh9ER5o7ZDpZbgALK+Q4h/7buKfqRBZFnynfgPK5T
LdSd7VAtss794bk8BzXFids+3st2yJj4tsY+N88hvbGsXUQtx6EYJMCNkAeb
dz0Xrh/Enb8tF26+FUigPxdu/81z34Mfx+bC3Qf2r2Yu3P0wPsx/YXy6m+a6
58L9D3bPzlx4+KDzASGmnw0=
                    "], CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{250.555, 
                    204.131}, {249.45700000000002`, 208.91299999999998`}, {
                    248.512, 212.455}, {243.21899999999997`, 216.053}, {
                    237.93, 212.455}, {236.984, 208.91299999999998`}, {
                    235.88700000000003`, 204.131}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{250.555, 
                    204.131006}, {249.45700000000002`, 208.912006}, {248.512, 
                    212.45500600000003`}, {243.21899999999997`, 216.053006}, {
                    237.93, 212.45500600000003`}, {236.984, 208.912006}, {
                    235.88700000000003`, 204.131006}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}}}, {{{253.277, 
                    201.47899999999998`}, {253.277, 208.401}, {250.875, 
                    207.459}, {248.70299999999997`, 206.065}, {
                    247.90200000000002`, 204.51399999999998`}, {247.008, 
                    208.35800000000003`}, {245.285, 210.053}, {243.137, 
                    212.377}, {240.99200000000002`, 210.053}, {239.555, 
                    208.35800000000003`}, {238.66, 204.51399999999998`}, {
                    237.859, 206.065}, {235.68800000000002`, 207.459}, {
                    233.285, 208.401}, {233.285, 201.47899999999998`}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}}}, {{{253.277, 201.479006}, {
                    253.277, 208.40100600000002`}, {250.875, 
                    207.45900600000002`}, {248.70299999999997`, 206.065006}, {
                    247.90200000000002`, 204.514006}, {247.008, 
                    208.35800600000002`}, {245.285, 210.053006}, {243.137, 
                    212.37700600000002`}, {240.99200000000002`, 210.053006}, {
                    239.555, 208.35800600000002`}, {238.66, 204.514006}, {
                    237.859, 206.065006}, {235.68800000000002`, 
                    207.45900600000002`}, {233.285, 208.40100600000002`}, {
                    233.285, 201.479006}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{220.434, 226.475}, {220.434, 203.866}, {223.004, 
                    203.866}, {223.004, 226.53}, {222.078, 
                    226.99800000000002`}, {221.207, 227.07299999999998`}, {
                    220.434, 226.475}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{220.434, 226.475006}, {220.434, 
                    203.86600600000003`}, {223.004, 203.86600600000003`}, {
                    223.004, 226.53000600000001`}, {222.078, 226.998006}, {
                    221.207, 227.073006}, {220.434, 226.475006}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}}}, {{{220.516, 
                    211.846}, {223.70299999999997`, 210.21699999999998`}, {
                    226.859, 208.33}, {227.656, 203.866}, {220.516, 
                    203.866}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}}}, {{{220.516, 
                    211.84600600000002`}, {223.70299999999997`, 210.217006}, {
                    226.859, 208.33000600000003`}, {227.656, 
                    203.86600600000003`}, {220.516, 203.86600600000003`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{264.719, 218.62}, {264.719, 203.866}, {266.801, 
                    203.866}, {266.801, 218.655}, {266.15200000000004`, 
                    218.959}, {265.262, 219.006}, {264.719, 218.62}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{264.719, 218.620006}, {264.719, 
                    203.86600600000003`}, {266.801, 203.86600600000003`}, {
                    266.801, 218.65500600000001`}, {266.15200000000004`, 
                    218.95900600000002`}, {265.262, 219.006006}, {264.719, 
                    218.620006}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}}}, {{{266.801, 
                    211.959}, {263.613, 210.33}, {260.457, 208.444}, {259.66, 
                    203.97899999999998`}, {266.801, 203.97899999999998`}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}}}, {{{266.801, 
                    211.95900600000002`}, {263.613, 210.33000600000003`}, {
                    260.457, 208.444006}, {259.66, 203.979006}, {266.801, 
                    203.979006}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{419.715, 226.475}, {419.715, 203.866}, {417.141, 
                    203.866}, {417.141, 226.53}, {418.07, 
                    226.99800000000002`}, {418.93799999999993`, 
                    227.07299999999998`}, {419.715, 226.475}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{419.715, 226.475006}, {419.715, 
                    203.86600600000003`}, {417.141, 203.86600600000003`}, {
                    417.141, 226.53000600000001`}, {418.07, 226.998006}, {
                    418.93799999999993`, 227.073006}, {419.715, 226.475006}}},
                     CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJ7IGYC4uPe5p2Op8odcp//XvmxKdMBxhe7ee57sHmu
w33/3ul59xB8hQ1FGRMfljvslGt9Hbgmx0EmKsX6Pn8FnM8AAhoIvh3X9cUF
qhUOpxe6bvv8FKpevMLBbdvnv1dEch34dDfNfc9d4VA6WYIlzC7XAUTx/S13
OHAKqKE81yFj4tsae8EKh8NfNWL6H0Hl5aH6J+Q6HAO516XCocMx4emFslwH
EDfBtsJhnfvDKpFVUPcaVjiAjDFlyoPwge5NFoiw3CKQBzFPs8LBFuTOmXkQ
9wDVg/2rnudwQen2z7owqH908hyEm4Eu861wWDb7iMKGvDwHIRDfucIB5C3/
nXkOOaBw1KuAmHM9DxJ+HlB5x3yH6XlAHUDzgLbqbjqZ5/Dpkm+SQBbUPRcQ
fHB8SOXD+fVZe0omd+Q78ILMTa9w6AT5918+xL51FQ5HQB4TLcDgx+3y5GHa
XOHQDZJwL3DYcqJs3/wzCP7Vipdqhs8QfLA/XyH0o/PB8WFYCbe/fN98KX39
Srj7YHyY+2F8mP8ugsLTqRLu/xmg8AiohIcP2L6sSnj4gcM7tBIevuDw9q6E
hz9YP9A8WPyA1aVXwuMP7L+CSnj8gs3rrITHPyiZrAOqh6UPWZAB0ZXw9LMI
mGz/hlTC0xfYvKpKePoDp/eOSnj6fLwU6LA5lfD0C3ZPbyU8fYP5jZXw9G8J
ipDiSnj+AIdXYSU8/4DVdyL4YP9vR/DB/t9VCc+f4Pg/h8mH5W8A2B3VVg==

                    "]]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJ7IGYC4uPe5p2Op8odVBUnbvvYlOkA458XSmEJMc91
uO/fOz3vHoKvsKEoY+LDcoeiCKkfgWtyHGSiUqzv81fA+QwgoIHg23FdX1yg
WuHQcvvWoc9PoerFKxz+v+/guiqS68Cnu2nue+4KB92zawXC7HIdJkuwhPH9
LXeoZDEP2lae65Ax8W2NvWCFQ7X+voz+R1B5eaj+CbkOx0DudalwcKz++vFC
Wa4DiJtgW+GQ3ljWLrIK6l7DCgcvdSEfU6Y8CB/oXmmvt65bBPIg5mlWOHxz
ztlQMDMP4h6gerB/1fMcLijd/lkXBvWPTp6DcPOBUwt9Kxzir0bqbsjLcxAC
8Z0rHITnXXjtvzPPIef575Uf9SocjqW5r3p/PQ8Sfh5Qecd8h+l5QB1A8/b2
L7bcdDLP4dMl3ySBLKh7LiD44PiQyofzzZcENk7uyHfgBbkvvcLBCeTff/kQ
+9ZVOCzc+6siQ7QAgx+3y5OHaXOFQwanEdMq9wKHLSfK9s0/g+BfrXipZvgM
wd8p1/o68BVCPzofHB+GlXD7y/fNl9LXr4S7D8aHuR/Gh/nvIig8nSrh/p8B
Co+ASnj4gO3LqoSHHzi8Qyvh4QsOb+9KePiD9QPNg8UPKHn5p1fC4w/sv4JK
ePyCzeushMe/+8MqkXVA9bD0IQsyILoSnn4WuW77/DekEp6+wOZVVcLTHzi9
d1TC0+fjpbOPKMyphKdfsHt6K+HpG8xvrISnf0tQhBRXwvMHOLwKK+H5B6y+
E8EH+387gg/2/65KeP4Ex/85TD4sfwMAoHLEYw==
                    "], 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    399.008, 246.42000000000002`}, {400.867, 
                    247.97899999999998`}, {400.867, 249.97899999999998`}, {
                    400.188, 249.91299999999998`}, {399.816, 249.678}, {
                    399.312, 249.02200000000002`}, {398.887, 250.346}, {
                    397.949, 251.38100000000003`}, {396.688, 252.026}, {
                    395.42999999999995`, 251.38100000000003`}, {
                    394.49199999999996`, 250.393}, {394.066, 249.069}, {
                    393.562, 249.725}, {393.191, 249.91299999999998`}, {
                    392.512, 249.97899999999998`}, {392.512, 
                    247.97899999999998`}, {394.371, 246.42000000000002`}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    399.008, 246.420006}, {400.867, 247.979006}, {400.867, 
                    249.979006}, {400.188, 249.912006}, {399.816, 
                    249.67800599999998`}, {399.312, 249.022006}, {398.887, 
                    250.34600600000002`}, {397.949, 251.38100600000004`}, {
                    396.688, 252.02600600000002`}, {395.42999999999995`, 
                    251.38100600000004`}, {394.49199999999996`, 250.393006}, {
                    394.066, 249.069006}, {393.562, 249.725006}, {393.191, 
                    249.912006}, {392.512, 249.979006}, {392.512, 
                    247.979006}, {394.371, 246.420006}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{400.,
                     241.405}, {400.867, 243.27599999999998`}, {400.867, 
                    245.873}, {400.188, 245.80700000000002`}, {399.816, 
                    245.569}, {399.312, 244.901}, {398.887, 246.248}, {
                    397.949, 247.295}, {396.688, 247.948}, {
                    395.42999999999995`, 247.295}, {394.49199999999996`, 
                    246.295}, {394.066, 244.95200000000003`}, {393.562, 
                    245.61599999999999`}, {393.191, 245.80700000000002`}, {
                    392.512, 245.873}, {392.512, 243.27599999999998`}, {
                    393.375, 241.405}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{400.,
                     241.40500600000001`}, {400.867, 243.276006}, {400.867, 
                    245.873006}, {400.188, 245.80700600000003`}, {399.816, 
                    245.569006}, {399.312, 244.90100600000002`}, {398.887, 
                    246.24800599999998`}, {397.949, 247.295006}, {396.688, 
                    247.948006}, {395.42999999999995`, 247.295006}, {
                    394.49199999999996`, 246.295006}, {394.066, 244.952006}, {
                    393.562, 245.616006}, {393.191, 245.80700600000003`}, {
                    392.512, 245.873006}, {392.512, 243.276006}, {393.375, 
                    241.40500600000001`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    400.133, 234.623}, {402.895, 237.991}, {402.895, 
                    241.311}, {401.883, 241.198}, {401.332, 240.795}, {
                    400.58599999999996`, 239.666}, {399.953, 241.94}, {
                    398.559, 242.44}, {396.688, 243.541}, {394.82, 242.44}, {
                    393.42599999999993`, 242.02200000000002`}, {
                    392.79299999999995`, 239.74499999999998`}, {392.047, 
                    240.877}, {391.4959999999999, 241.198}, {390.484, 
                    241.311}, {390.484, 237.991}, {393.246, 234.623}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    400.133, 234.623006}, {402.895, 237.99100600000003`}, {
                    402.895, 241.31100600000002`}, {401.883, 241.198006}, {
                    401.332, 240.795006}, {400.58599999999996`, 239.666006}, {
                    399.953, 241.940006}, {398.559, 242.440006}, {396.688, 
                    243.541006}, {394.82, 242.440006}, {393.42599999999993`, 
                    242.022006}, {392.79299999999995`, 239.745006}, {392.047, 
                    240.87700600000002`}, {391.4959999999999, 241.198006}, {
                    390.484, 241.31100600000002`}, {390.484, 
                    237.99100600000003`}, {393.246, 234.623006}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4skSLGF8/JUOh79qxPTX5Tig8y8q3f5Z51Tp
sEOu9XXgjRwHxQ1FGRNdKx0UQDRnLpxvYgwE1bkOws0HTi00rHQ4BNJflusw
PU+o+YBcpcO1ipdqhjm5DgwgIFDpYMd1fXGBba6D/l0VtkbmSod7QGrq7FwH
Xt1Nc9+/r3B48Xvlx0tbcx3idnnyMJ2ucBC7ee578ONch8dLZx9RWIaQB7tz
UgVcP9j8tgq4+VEp1vf9yyvg9t/3752el1IBd98FkP8CKuDuh/Fh/osF2R9e
Afc/mN9eAQ8fdD4AYnmREg==
                    "]]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4skSLGF8/JUONfr7MvrrchzQ+ReVbv+sc6p0
KIyQ+hF4I8dBcUNRxkTXSoebL9lLJ3Lmwvlvck7YG1fnOgg3Hzi10LDSoRqk
vyzXYXqeUPMBuUqH/k11xoY5uQ4MICBQ6fDNOWdDgW2ug/5dFbZG5kqHaXGz
e6fOznXg1d009/37CocFpvb/Lm3NdYjb5cnDdLrC4bxQCkvI41yHx0tnH1FY
hpA//FUjpn9SBVw/2Py2Crj5USnW9/3LK+D23/fvnZ6XUgF33wWQ/wIq4O6H
8WH+iwXZH14B9z+Y314BDx90PgAvoo88
                    "], 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4kWu2z7/Val0qMvaUzL5S5YDOt+W6/riguxK
h2SBCMstE7IdJkuwhPHlVjrYgcTPIviHv2rE9NflOCybfURhQ1Clg9jNc9+D
y3McrLacKNtnWemQ+/z3yo9BOQ475FpfB6pVOkx8W2NvygWVF610cANae2VO
joNsVIr1/d8VDgG90/OEmHMd4nZ58jCdroCo98p1uFrxUs1wFkIebF5DBVy/
Jci8/Aq4+WD5mAq4/SDj/Z0r4O4Di2tUwN0P48P8xwACehWo/i+sgIcPOh8A
E0eazg==
                    "]]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4kWu2z7/Val0MF8S2Dj5S5YDOt+W6/riguxK
B2mvt65bJmQ7TJZgCePLrXT45pyzoeAsgl+jvy+jvy7HYdnsIwobgiodzgul
sISU5zhYbTlRts+y0kFVceK2j0E5DjvkWl8HqlU6eKkL+ZhyQeVFKx3+v+/g
ujonx0E2KsX6/u8KB87jOtVCzLkOcbs8eZhOV0DUe+U6XK14qWY4CyEPNq+h
Aq7fEmRefgXcfLB8TAXcfpDx/s4VcPflPv+98qNGBdz9MD7MfwwgoFeB6v/C
Cnj4oPMBbMiPBA==
                    "], CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4kWu2z7/Val0WFJgy3WdO8sBnZ8x8W2NfWKl
Q4TllhNlbVkOkyVYwvhyKx3uqbA1Tt2N4LsBtV3JyXZYNvuIwoagSgeg7sUF
qdkOVkBt+ywrHT4sP+Zt7pjtsEOu9XWgWqUDSFnRjyyIvGilQ0Dv9Dyh7mwH
2agU6/u/Kxxyn/9e+fFetkPcLk8eptMVDuvcH1aJqOU4XK14qWY4CyEPNq+h
Aq4f5Mx9+RVw88HyMRVw+0HG+ztXwN0HNkejAu5+GB/mP6CuTkeLClT/F1bA
wwedDwA3dZqj
                    "]]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGYC4kWu2z7/Val0iF11Sew6d5YDOj9j4tsa+8RK
B4Fiz6tlbVkOkyVYwvhyKx2mxc3unbobwf//voPrak62w7LZRxQ2BFU6fHPO
2VCQmu1gteVE2T7LSocVD6MjzB2zHXbItb4OVKt0CPm3dU/RjyyIvGilA+dx
nWqh7mwH2agU6/u/KxzUFCdu+3gv2yFulycP0+kKh/TGsnYRtRyHqxUv1Qxn
IeTB5jVUwPVbgszLr4CbD5aPqYDbDzLe37kC7r7c579XftSogLsfxof575i3
eaejRQWq/wsr4OGDzgcArUeZzg==
                    "], CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{403.832, 
                    204.131}, {402.734, 208.91299999999998`}, {401.789, 
                    212.455}, {396.4959999999999, 216.053}, {391.207, 
                    212.455}, {390.262, 208.91299999999998`}, {
                    389.16400000000004`, 204.131}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{403.832, 
                    204.131006}, {402.734, 208.912006}, {401.789, 
                    212.45500600000003`}, {396.4959999999999, 216.053006}, {
                    391.207, 212.45500600000003`}, {390.262, 208.912006}, {
                    389.16400000000004`, 204.131006}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}}}, {{{419.633, 
                    211.846}, {416.445, 210.21699999999998`}, {413.633, 
                    208.33}, {412.832, 203.866}, {419.633, 203.866}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}}}, {{{419.633, 
                    211.84600600000002`}, {416.445, 210.217006}, {413.633, 
                    208.33000600000003`}, {412.832, 203.86600600000003`}, {
                    419.633, 203.86600600000003`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{375.42999999999995`, 218.62}, {
                    375.42999999999995`, 203.866}, {373.34400000000005`, 
                    203.866}, {373.34400000000005`, 218.655}, {
                    373.9959999999999, 218.959}, {374.887, 219.006}, {
                    375.42999999999995`, 218.62}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{375.42999999999995`, 218.620006}, {
                    375.42999999999995`, 203.86600600000003`}, {
                    373.34400000000005`, 203.86600600000003`}, {
                    373.34400000000005`, 218.65500600000001`}, {
                    373.9959999999999, 218.95900600000002`}, {374.887, 
                    219.006006}, {375.42999999999995`, 218.620006}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}}}, {{{
                    373.34400000000005`, 211.846}, {376.53099999999995`, 
                    210.21699999999998`}, {379.688, 208.33}, {
                    380.48799999999994`, 203.866}, {373.34400000000005`, 
                    203.866}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}}}, {{{
                    373.34400000000005`, 211.84600600000002`}, {
                    376.53099999999995`, 210.217006}, {379.688, 
                    208.33000600000003`}, {380.48799999999994`, 
                    203.86600600000003`}, {373.34400000000005`, 
                    203.86600600000003`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{375.42999999999995`, 218.62}, {
                    375.42999999999995`, 203.866}, {373.34400000000005`, 
                    203.866}, {373.34400000000005`, 218.655}, {
                    373.9959999999999, 218.959}, {374.887, 219.006}, {
                    375.42999999999995`, 218.62}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}}}, {{{375.42999999999995`, 218.620006}, {
                    375.42999999999995`, 203.86600600000003`}, {
                    373.34400000000005`, 203.86600600000003`}, {
                    373.34400000000005`, 218.65500600000001`}, {
                    373.9959999999999, 218.95900600000002`}, {374.887, 
                    219.006006}, {375.42999999999995`, 218.620006}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}}}, {{{
                    373.34400000000005`, 211.846}, {376.53099999999995`, 
                    210.21699999999998`}, {379.688, 208.33}, {
                    380.48799999999994`, 203.866}, {373.34400000000005`, 
                    203.866}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}}}, {{{
                    373.34400000000005`, 211.84600600000002`}, {
                    376.53099999999995`, 210.217006}, {379.688, 
                    208.33000600000003`}, {380.48799999999994`, 
                    203.86600600000003`}, {373.34400000000005`, 
                    203.86600600000003`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}}}, {{{338.191, 
                    232.01399999999998`}, {338.191, 237.768}, {343.156, 
                    238.416}, {343.156, 238.416}, {343.156, 233.295}, {
                    341.26599999999996`, 233.377}, {340.355, 231.678}, {
                    340.355, 229.155}, {340.355, 226.627}, {341.879, 
                    226.58800000000002`}, {341.879, 226.58800000000002`}, {
                    341.879, 212.05700000000002`}, {338.191, 
                    212.05700000000002`}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}}}, {{{338.191, 232.014006}, {
                    338.191, 237.76800599999999`}, {343.156, 238.416006}, {
                    343.156, 238.416006}, {343.156, 233.295006}, {
                    341.26599999999996`, 233.37700600000002`}, {340.355, 
                    231.67800599999998`}, {340.355, 229.15500600000001`}, {
                    340.355, 226.62700600000002`}, {341.879, 226.588006}, {
                    341.879, 226.588006}, {341.879, 212.05700600000003`}, {
                    338.191, 212.05700600000003`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}}}, {{{301.48799999999994`, 
                    232.01399999999998`}, {301.48799999999994`, 237.768}, {
                    296.52299999999997`, 238.416}, {296.52299999999997`, 
                    238.416}, {296.52299999999997`, 233.295}, {298.414, 
                    233.377}, {299.324, 231.678}, {299.324, 229.155}, {
                    299.324, 226.627}, {297.801, 226.58800000000002`}, {
                    297.801, 226.58800000000002`}, {297.801, 
                    212.05700000000002`}, {301.48799999999994`, 
                    212.05700000000002`}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}}}, {{{301.48799999999994`, 
                    232.014006}, {301.48799999999994`, 237.76800599999999`}, {
                    296.52299999999997`, 238.416006}, {296.52299999999997`, 
                    238.416006}, {296.52299999999997`, 233.295006}, {298.414, 
                    233.37700600000002`}, {299.324, 231.67800599999998`}, {
                    299.324, 229.15500600000001`}, {299.324, 
                    226.62700600000002`}, {297.801, 226.588006}, {297.801, 
                    226.588006}, {297.801, 212.05700600000003`}, {
                    301.48799999999994`, 212.05700600000003`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}}}, {{{406.637, 
                    201.55700000000002`}, {406.637, 208.483}, {404.234, 
                    207.541}, {402.062, 206.147}, {401.262, 204.596}, {
                    400.367, 208.44}, {398.64500000000004`, 210.135}, {
                    396.4959999999999, 212.459}, {394.348, 210.135}, {
                    392.90999999999997`, 208.44}, {392.01599999999996`, 
                    204.596}, {391.215, 206.147}, {389.043, 207.541}, {
                    386.641, 208.483}, {386.641, 201.55700000000002`}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}}}, {{{406.637, 
                    201.55700600000003`}, {406.637, 208.48300600000002`}, {
                    404.234, 207.541006}, {402.062, 206.147006}, {401.262, 
                    204.59600600000002`}, {400.367, 208.440006}, {
                    398.64500000000004`, 210.135006}, {396.4959999999999, 
                    212.45900600000002`}, {394.348, 210.135006}, {
                    392.90999999999997`, 208.440006}, {392.01599999999996`, 
                    204.59600600000002`}, {391.215, 206.147006}, {389.043, 
                    207.541006}, {386.641, 208.48300600000002`}, {386.641, 
                    201.55700600000003`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    194.39100000000002`, 145.05700000000002`}, {445.605, 
                    145.05700000000002`}, {445.60900000000004`, 132.225}, {
                    194.395, 132.225}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    194.39100000000002`, 145.057006}, {445.605, 145.057006}, {
                    445.60900000000004`, 132.225006}, {194.395, 132.225006}}},
                     CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    187.76999999999998`, 132.24499999999998`}, {452.227, 
                    132.24499999999998`}, {452.22999999999996`, 119.432}, {
                    187.77299999999997`, 119.432}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    187.76999999999998`, 132.245006}, {452.227, 132.245006}, {
                    452.22999999999996`, 119.432006}, {187.77299999999997`, 
                    119.432006}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    207.586, 164.248}, {432.41400000000004`, 164.248}, {
                    432.41400000000004`, 155.947}, {207.586, 155.947}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    207.586, 164.24800599999998`}, {432.41400000000004`, 
                    164.24800599999998`}, {432.41400000000004`, 155.947006}, {
                    207.586, 155.947006}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    201.012, 156.002}, {438.98900000000003`, 156.002}, {
                    438.98900000000003`, 145.127}, {201.01200000000003`, 
                    145.127}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    201.012, 156.002006}, {438.98900000000003`, 156.002006}, {
                    438.98900000000003`, 145.127006}, {201.01200000000003`, 
                    145.127006}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    211.512, 170.635}, {428.48900000000003`, 170.635}, {
                    428.48900000000003`, 164.31099999999998`}, {
                    211.51200000000003`, 164.31099999999998`}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    211.512, 170.635006}, {428.48900000000003`, 170.635006}, {
                    428.48900000000003`, 164.311006}, {211.51200000000003`, 
                    164.311006}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    235.062, 170.6}, {251.453, 170.6}, {251.453, 
                    119.46699999999998`}, {235.062, 119.46699999999998`}}}]}, {
                    Thickness[0.0013056953125000002`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    235.062, 170.600006}, {251.453, 170.600006}, {251.453, 
                    119.46700600000003`}, {235.062, 119.46700600000003`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    238.691, 170.6}, {247.824, 170.6}, {247.824, 
                    119.46699999999998`}, {238.691, 119.46699999999998`}}}]}, {
                    Thickness[0.001303675], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    238.691, 170.600006}, {247.824, 170.600006}, {247.824, 
                    119.46700600000003`}, {238.691, 119.46700600000003`}}}, 
                    CurveClosed -> {1}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{238.523, 164.291006}, {
                    247.98800000000003`, 164.291006}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{238.523, 157.893006}, {
                    247.98800000000003`, 157.893006}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{238.523, 
                    151.49100599999997`}, {247.98800000000003`, 
                    151.49100599999997`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{238.523, 
                    145.09200600000003`}, {247.98800000000003`, 
                    145.09200600000003`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{238.523, 
                    138.69400600000006`}, {247.98800000000003`, 
                    138.69400600000006`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{238.523, 
                    132.29100599999998`}, {247.98800000000003`, 
                    132.29100599999998`}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{238.523, 
                    125.89300600000001`}, {247.98800000000003`, 
                    125.89300600000001`}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    311.52, 170.6}, {327.911, 170.6}, {327.911, 
                    119.46699999999998`}, {311.52, 119.46699999999998`}}}]}, {
                   
                    Thickness[0.0013056953125000002`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    311.52, 170.600006}, {327.911, 170.600006}, {327.911, 
                    119.46700600000003`}, {311.52, 119.46700600000003`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    315.262, 170.6}, {324.395, 170.6}, {324.395, 
                    119.46699999999998`}, {315.262, 119.46699999999998`}}}]}, {
                    Thickness[0.001303675], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    315.262, 170.600006}, {324.395, 170.600006}, {324.395, 
                    119.46700600000003`}, {315.262, 119.46700600000003`}}}, 
                    CurveClosed -> {1}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{315.309, 164.303006}, {
                    324.121, 164.303006}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{315.309, 
                    157.89700600000003`}, {324.121, 157.89700600000003`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{315.309, 151.495006}, {
                    324.121, 151.495006}}}, CurveClosed -> {0}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{315.309, 
                    145.09200600000003`}, {324.121, 145.09200600000003`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{315.309, 
                    138.69000600000004`}, {324.121, 138.69000600000004`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{315.309, 
                    132.28400600000003`}, {324.121, 132.28400600000003`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{315.309, 
                    125.88100600000001`}, {324.121, 125.88100600000001`}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    388.43399999999997`, 170.6}, {404.825, 170.6}, {404.825, 
                    119.46699999999998`}, {388.43399999999997`, 
                    119.46699999999998`}}}]}, {
                    Thickness[0.0013056953125000002`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    388.43399999999997`, 170.600006}, {404.825, 170.600006}, {
                    404.825, 119.46700600000003`}, {388.43399999999997`, 
                    119.46700600000003`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    392.062, 170.6}, {401.195, 170.6}, {401.195, 
                    119.46699999999998`}, {392.062, 119.46699999999998`}}}]}, {
                    Thickness[0.001303675], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    392.062, 170.600006}, {401.195, 170.600006}, {401.195, 
                    119.46700600000003`}, {392.062, 119.46700600000003`}}}, 
                    CurveClosed -> {1}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{391.89799999999997`, 
                    164.291006}, {401.363, 164.291006}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{391.89799999999997`, 
                    157.893006}, {401.363, 157.893006}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{391.89799999999997`, 
                    151.49100599999997`}, {401.363, 151.49100599999997`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{391.89799999999997`, 
                    145.09200600000003`}, {401.363, 145.09200600000003`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{391.89799999999997`, 
                    138.69400600000006`}, {401.363, 138.69400600000006`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{391.89799999999997`, 
                    132.29100599999998`}, {401.363, 132.29100599999998`}}}, 
                    CurveClosed -> {0}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}}, {{{391.89799999999997`, 
                    125.89300600000001`}, {401.363, 125.89300600000001`}}}, 
                    CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    270.42999999999995`, 192.791}, {274.10599999999994`, 
                    192.791}, {274.10599999999994`, 175.9}, {
                    270.42999999999995`, 175.9}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Round"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    270.42999999999995`, 192.791006}, {274.10599999999994`, 
                    192.791006}, {274.10599999999994`, 175.90000600000002`}, {
                    270.42999999999995`, 175.90000600000002`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    278.10900000000004`, 192.791}, {281.785, 192.791}, {
                    281.785, 175.9}, {278.10900000000004`, 175.9}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Round"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    278.10900000000004`, 192.791006}, {281.785, 192.791006}, {
                    281.785, 175.90000600000002`}, {278.10900000000004`, 
                    175.90000600000002`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    285.79299999999995`, 192.791}, {289.465, 192.791}, {
                    289.465, 175.9}, {285.79299999999995`, 175.9}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Round"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    285.79299999999995`, 192.791006}, {289.465, 192.791006}, {
                    289.465, 175.90000600000002`}, {285.79299999999995`, 
                    175.90000600000002`}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    350.113, 192.791}, {353.785, 192.791}, {353.785, 175.9}, {
                    350.113, 175.9}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Round"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    350.113, 192.791006}, {353.785, 192.791006}, {353.785, 
                    175.90000600000002`}, {350.113, 175.90000600000002`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    357.79299999999995`, 192.791}, {361.46899999999994`, 
                    192.791}, {361.46899999999994`, 175.9}, {
                    357.79299999999995`, 175.9}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Round"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    357.79299999999995`, 192.791006}, {361.46899999999994`, 
                    192.791006}, {361.46899999999994`, 175.90000600000002`}, {
                    357.79299999999995`, 175.90000600000002`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    365.47299999999996`, 192.791}, {369.14899999999994`, 
                    192.791}, {369.14899999999994`, 175.9}, {
                    365.47299999999996`, 175.9}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Round"], 
                    JoinForm["Round"], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    365.47299999999996`, 192.791006}, {369.14899999999994`, 
                    192.791006}, {369.14899999999994`, 175.90000600000002`}, {
                    365.47299999999996`, 175.90000600000002`}}}, 
                    CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    312.191, 277.08799999999997`}, {311.78499999999997`, 
                    280.28799999999995`}, {328.004, 280.28799999999995`}, {
                    327.59799999999996`, 277.08799999999997`}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    312.191, 277.088006}, {311.78499999999997`, 280.288006}, {
                    328.004, 280.288006}, {327.59799999999996`, 277.088006}}},
                     CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    313.277, 280.35}, {312.92999999999995`, 282.979}, {
                    326.85900000000004`, 282.979}, {326.512, 280.35}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    313.277, 280.350006}, {312.92999999999995`, 282.979006}, {
                    326.85900000000004`, 282.979006}, {326.512, 280.350006}}},
                     CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    315.48799999999994`, 283.077}, {315.258, 285.709}, {
                    324.53099999999995`, 285.709}, {324.301, 283.077}}}]}, {
                    Thickness[0.0012000000000000001`], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    315.48799999999994`, 283.077006}, {315.258, 285.709006}, {
                    324.53099999999995`, 285.709006}, {324.301, 283.077006}}},
                     CurveClosed -> {1}]}}, AspectRatio -> Automatic, 
                  ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 640.}, {0., 411.}}], ",", 
                 GraphicsBox[{
                   Thickness[0.0010416666666666667`], {
                    FaceForm[{
                    RGBColor[
                    0.8078430000000001, 0.06666670000000002, 0.14902], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 640.}, {960., 640.}, {960., 0.}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     320.}, {960., 320.}, {960., 0.}, {0., 0.}}}]}}, 
                  AspectRatio -> Automatic, ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 960.}, {0., 640.}}], ",", 
                 GraphicsBox[{
                   Thickness[0.001388888888888889], {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 480.}, {720., 480.}, {720., 0.}}}]}, {
                    FaceForm[{
                    RGBColor[0.737255, 0., 0.17647100000000002`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{504., 240.}, {504., 160.47299999999998`}, {
                    439.527, 96.}, {360., 96.}, {280.47299999999996`, 96.}, {
                    216., 160.47299999999998`}, {216., 240.}, {216., 
                    319.527}, {280.47299999999996`, 384.}, {360., 384.}, {
                    439.527, 384.}, {504., 319.527}, {504., 240.}}}]}}, 
                  AspectRatio -> Automatic, ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 720.}, {0., 480.}}], ",", 
                 GraphicsBox[{
                   Thickness[0.0016666666666666668`], {
                    FaceForm[{
                    RGBColor[0.9294119999999999, 0.109804, 0.141176], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 400.}, {600., 400.}, {600., 0.}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     300.}, {600., 300.}, {600., 100.}, {0., 100.}}}]}, {
                    FaceForm[{
                    RGBColor[0., 0.65098, 0.31764699999999996`], 
                    Opacity[1.]}], 
                    FilledCurveBox[{CompressedData["
1:eJxTTMoPSmJiYGDYBMTMQMzAxMDIzAxEDIwMQARhD29Ef29SYiNV4oWgIWgK
AO1qBvs=
                    "], {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4,
                     3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {CompressedData["
1:eJx9WWmUVNURHhYFhYMIAwjCBBUGjQtwYgRB5cKgaARRUfRNdw9098z0Mr28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                    "], CompressedData["
1:eJxTTMoPSmViYGAwAWIQPVmCJYzPsNABTCcWONhyXV9cYFzo0Po6cIcckM8A
AmYI+S0nyvbNt0Dwl84+orDBB8GPSrG+7x9d6PAYJBFT4OBt3umYkFjocOir
Rkx/SIGD/l0VtkYg/22NvWlcCNT8pEIHPt1Nc98HF0D0AfmWIIuA/OMgA4B8
hQ1FGROB/HcgfUlQ+4D8i0q3f9YB+dUi69wfBhU4lO+bL6WfXOhgBdIfWAAx
JxlqXwDUvhSo//wLHD5d8k0SAPKrQPr9CiDqgPyrFS/VDJH4siCP+RY43Pfv
nZ4H5BuA/OGLkIeEA4J/DORuJD7Yf94I/eBw8kbIx+3y5GFC4j8AqfOChgeQ
Dw43T4T7c5//XvnRowBibjI0fD0Q/gWrA/KFmg+cWgjkuz8E+RAav/HQ8LEs
cADGztMLHoUQdykUOKCkB/4CSLjIQdUzQsNLpNBhkeu2z3+/5EPs5y10iAW5
/3s+JFyAfJCxSkA+2HyeQgdg7L2tAfLB9vBA4xfIB4cTD9S9P/Ih4cxd6LDq
I9AiIB/sbiC/AORwIB8cbtzQ+PsJNZ+r0OESKB38ync4DAoHIN8JZP9vqH1s
hRBxpgIHYVB4sELTpwCCD7ZfA8HXahe7eQ6YvjxA9vNC3RuPFj7A9A4ADNBT
Sg==
                    "], CompressedData["
1:eJxTTMoPSmViYGAQBmIQHbvLk4fJvtgh9/nvlR+1Chz076qwNSLx3R9WiaxD
4j9eOvuIggOC3+GY8PRCHIJvy3V9cUFxscOhrxox/TIFDkLNB04tLC922HKi
bN98lgKHTpD6mmKHvSWTJVjO5TtcULr9s66g2MEAZO/efLj5MD7YXBUEv3zf
fCl90WIHJ6AxSofzHRQ3FGVM5C12eFtjbxp3Kd9BJirF+j57sYO6IccamXv5
EPexFTtYgRzwPt9hkeu2z385EO5pfR24Qw6o/2rFSzVDGShfsdjhIshdQP+g
hw8AONOPXA==
                    "], CompressedData["
1:eJxTTMoPSmViYGAQA2IQnfv898qPS4ocGEBArsBBqPnAqYX7ixweL519REGh
wGGnXOvrwFNFDjtAtACCDyR3yN3Nh/Nlo1Ks73fnO3Q6Jjy9sKvI4aLS7Z91
RfkOwiDzCqHqffMdbLmuLy5wLnLQv6vC1miaDxGXLHLYeqJs33ytfIerFS/V
DAWKHFTZGqc6G+dD3AXkF2VMfFsD5IPdxw+1zxhqHj/UvSb5Dt7mQBcA+cdA
DBOo+UD+/vlS+neB/MkSLGF8QP4i122f/wL5VluAFn8thMjn5Dvw6W6a+567
yKF3ep5Q8xaofu8ih9hdnjxM3/MdLEHqi4sg/gSGR7XIOveHE4oc7vsDdcgU
OKCHJwB+5Zh8
                    "], {{320.469, 257.85200000000003`}, {
                    322.90999999999997`, 257.92999999999995`}, {323.219, 
                    256.777}, {322.027, 253.35200000000003`}, {321.617, 
                    252.172}, {319.914, 251.21499999999997`}, {318.25, 
                    251.21499999999997`}, {315.812, 251.21499999999997`}, {
                    315.29299999999995`, 251.805}, {315.605, 254.262}, {
                    315.887, 256.445}, {316.96099999999996`, 257.441}, {
                    319.383, 257.746}, {319.78499999999997`, 
                    257.79699999999997`}, {320.14500000000004`, 
                    257.84000000000003`}, {320.469, 
                    257.85200000000003`}}, CompressedData["
1:eJxTTMoPSmViYGBQBWIQbct1fXHBxkKHKpF17g/T8h1m5Ak1H9hU6OCY8PSC
Unq+ww651teBWxDyihuKMiZuRfBzn/9e+fEJgg8273ihw+Ols48obMlzOPxV
I6a/q9DhbY29aVxSHsS8kEIH/bsqbI2SeQ7LgMo2SBU6qBtyrJH5lQtRz1Xo
cEHp9s86sTyHB/690/OA/OkgdwH5x73NOx2BfFW2xqnO4nkOVyteqhkC+f2H
gBqBfKDpO+Q4EeaD3cFRCNEnkwcRZy90qAa5Vy4P4l52qHnyeQ7l++ZL6bND
3a8ANQ/I7wU5AMifLMESxgfkg8UV8yD+Zit0uAhyr1IexJ1AftwuTx4m5TwH
kDEbgHxgqL2tAfLvg/wD5B8DuUclDxIuQD5Qd9YeFWj4APk+QOkEVYT6LSfK
9s1XQ6gHu1cdoR7sP408BwYQAPK5gd6y1ULwJ4DCRxvBD+PT3TQXiQ+mdRB8
sHlAflSK9X1/oH9vnvse/LgXGl6VhQ4g79jHQuMbKf0AAGv56A4=
                    
                    "], CompressedData["
1:eJxTTMoPSmViYGCQB2IQfeirRkx/XrFD6+vAHXIncx3K982X0m8tdth6omzf
/HO5Dvp3VdgaJ0Pl5+Y6CDUfOLWwu9iB6/riAlunXIeoFOv7/u3FDlZbgBr4
cx1m5AFVFBQ73PlZl7XnTY5Dlcg694d+xQ6Pl84+ovAkx2GR67bPf02KHYRB
5tyF8lWKHWRBBt3Pcch5/nvlR7liB3VDjjUy76D65aD2Aflg9wL51SBxJH7c
Lk8epvc5Dse8zTsd5aDuAfIZQADIvw1yz4cciLhsMcRfH3McPB4CbQDyvwGN
OQTkG4DEZaHmf8pxABmXAOQ7JTy9oPQZwe8HWQzkT5ZgCeOThbr/M9Q/MsUQ
e7/kQMwB8vcDg/UukD8dFD5A/tsae9O4bzkOIOfMl4Ga9z0HEi6SxQ7FGRPf
1gDD89Ml3yQBtWKHQltgCNjkQuQdoe5thfIDofZtgMZXYrHD3hKgy47lOqDH
LwAEcN+m
                    "], CompressedData["
1:eJxTTMoPSmViYGCQAGIQbXBXha1xb5FD6+vAHXJbcx22nCjbN39fkYOPeadj
ApCvsKEoY+J+hPwFpds/6w4g+LJRKdb33yL45fvmS+l/LXLImPi2xj411+GY
N9CgM0UO+4HCd01yHUDK/XcWOWwF2SOX65Dz/PfKj8uKHPaWTJZg4ct1ANr6
9MKCIofHS2cfUeCBugeJDzYPyFdja5zqzJ3r8OmSb5IAEl8GZMH8IocJh75q
xAD5tlzXFxfMR+gH24/EB7t/dpHDRZC/YPY3Idyn1S5281x6kQNQNmuPQa4D
SNsGsyIHdUOONTJBuQ5XK16qGeYVOTCAQEuuw4w8oeYDXUUO4HCdm+sA9FUY
31qoeZtyHdDDGwDyRK63
                    "], {{323.703, 234.539}, {325.039, 
                    234.60899999999998`}, {326.49199999999996`, 
                    234.35200000000003`}, {327.902, 233.758}, {330.465, 
                    232.684}, {330.96099999999996`, 231.754}, {
                    330.47299999999996`, 228.945}, {329.812, 225.129}, {
                    327.72999999999996`, 224.70299999999997`}, {
                    320.60900000000004`, 226.969}, {317.113, 
                    228.08200000000002`}, {316.754, 228.61299999999997`}, {
                    317.871, 230.92200000000003`}, {318.941, 233.125}, {
                    321.14500000000004`, 234.40200000000002`}, {323.703, 
                    234.539}}, CompressedData["
1:eJxTTMoPSmViYGAQBmIQfczbvNPxXYGDKlvjVGfjXAf9uypsje8R/GWzjyhs
+IDgM4DAJwS/WmSd+0OXQjh/h1zr68CAQocLSrd/1olB1WsUOqz+eMk3aU2O
wwP/3ul5UoUO++ZL6d/tyHGYkSfUfIChEEIH5ThsOVG2bz7QPUBVQs0mOQ6d
jglPL1wqcHhbY28ax5bjsBNk/qkCBzWQfdxQ9TsKHB4vBTo0JMdBYUNRxsTF
BRB3rcpxWOS67fPfOQUQdzzJcciYCDRpeYED1/XFBbZsUP9tKICoU4G690SB
w0WQ+41yHdDDBwASMn/g
                    "], CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQYiBQ4u3TnPf7/McYhKsb7vb17gIAtivM5xaH0d
uEPOt8DhktLtn3WnoPKZBQ7fNGL6D2XmOOQ+/73y44QCh4yJb2vsH2Y7eDys
ElkXWuBQBBLYnO2gsAHIki9wuHnue/DjzmyHCyBzxKD6J2Y79B/6qhFzOR9i
H3+OQ9wuTx6m2fkOE0Di8TkOPuadjgmt+Q6Pl84+ojAlxwGoO2vPlHwH/bsq
bI1bcxzUDTnWyEzLd+idnifUvCPHAeyfGfkQek8OxF8z8x1mAKUP7MuB+GMW
1Pz9OQ5WW06U7QPaV2jLdX3xgRyH495AC+fkQ/xzMMdh/3wp/btAPtj9QD6Y
npvv4JTw9ILS4RyHiyDz5uU7WILMAfLB9myC2n8jx6EYZNDtfIi/Huc4AH3z
9AJPgcOqj5d8k15Aw5O/wOEWyF9AvnDzgVMLBaHh9RLqH6T4AQB+fMn0
                    
                    "], {{338.85200000000003`, 218.539}, {341.305, 
                    218.73399999999998`}, {343.812, 217.008}, {343.453, 
                    214.21899999999997`}, {342.9959999999999, 210.676}, {
                    339.129, 209.65200000000002`}, {335.949, 
                    212.21499999999997`}, {334.051, 213.74599999999998`}, {
                    333.97999999999996`, 214.312}, {335.453, 216.535}, {
                    336.29699999999997`, 217.805}, {337.566, 218.434}, {
                    338.85200000000003`, 218.539}}, CompressedData["
1:eJxTTMoPSmViYGCQB2IQfd+/d3qeR5HD/vlS+ndrshxko1Ks73sWObS+Dtwh
V5vloH9Xha3RGyG/yHXb578+CP4OOaDKAATf27zTMSG4yKE4Y+Lbmuosh0+X
fJMEwoochJsPnFpYmeXg/rBKZF14kcNxkMKKLAeFDUUZEyOLHLacKNs3vyzL
Iff575Ufo4ocCmy5ri8ugZoXXeTAAAIlUPNiihxm5Ak1HyjKcgC7H8hXN+RY
IwPkg80B8r9pxPQfKsxymCzBEsYXW+Rw+2dd1p6CLAeQs+yB/FUfgQYVQM2P
hZoP5Gu3i908B+Q7Jjy9oJSfBRGPg9qXl+XweOnsIwpAPtAU0zgg/9BXoEVA
vgEonHKzHKaD1MVBww/GT4H6PzbLoQNkcFqRgxPIfOcsiDlA+WqRde4P5RDu
d+nOAYZEpgOf7qa5702LHCxBEu2ZDqDo8Vctcojd5cnD9DwTYr9YEcRdNlkQ
c1Sg/quAhg9S/AIATUjYeQ==
                    "], CompressedData["
1:eJxTTMoPSmViYGDQA2IQPSNPqPlAQKFD3C5PHiblLAdbruuLCxILHYoyJr6t
Uc9ymA6Sryl08DbvdEwQzHJ4vHT2EYUZhQ6WW06U7Xuc6QDWv6rQoQCk8Uim
wwP/3ul5mwodLijd/lm3LNPhasVLNUMgvxdk0IRMiH4g/22NvWlcX6YDAwgA
+VYg87ozHbTbxW6e21jo8E0jpv9QZ6aDx8MqkXUboeZ3ZDoINx84tRDIB7ur
LRPiXiBfCCTemukAcrY9kA+0PWtPS6ZDtcg694cbCh2cEp5eUGrOdFgGtH4D
kA/SZtuUCXEHkL/Iddvnvw2ZDjJRKdb31xc6TDj0VSOmPtNBYQMwJIB8dUOO
NTJ1UPvWQ91Xm+kAUu4P5O+fL6V/tybToXwfkAHk94EcCOTHgsIVyAf7G8gH
Gdu/Duqeaqj9QD44HKsyIeGwthDij8pMh9znv1d+XFPooMrWONW5HBp+a6D2
l2Y68Olumvt+daGD/l0VtsZSqHuB/FUfL/kmlWRC4m011P4SaHgvKHS4CIqf
JKh/26HhmZbpsEOu9XVgDtT+iZkOiiDzQqHxtyXTYSvQefOdoPofQd3nUOjA
DQrPX9DwBvLB6n4h5ItBBv5G8GVB9v5GqD8OcugfhDzQFTvk/iL4BiD/IfHB
/hGBpk83qH6FLAf09AwAlTtZfA==
                    "], {{301.66, 
                    208.57399999999998`}, {302.141, 208.61299999999997`}, {
                    302.641, 208.14499999999998`}, {303.477, 
                    207.21899999999997`}, {304.53099999999995`, 206.059}, {
                    305.76599999999996`, 203.84}, {306.215, 202.277}, {
                    307.29699999999997`, 198.523}, {305.59, 
                    196.95700000000002`}, {302.25, 198.66}, {298.668, 
                    200.48800000000003`}, {297.79699999999997`, 
                    203.38700000000003`}, {299.867, 206.648}, {300.66, 
                    207.89100000000002`}, {301.148, 208.52700000000002`}, {
                    301.66, 208.57399999999998`}}, CompressedData["
1:eJxTTMoPSmViYGBQBWIQDQYpxQ6OCU8vKOVnOhz+qhHTX1Ts4ATiF2c6vK2x
N41rK3Yoypj4tsY90wFE2XcXO9w89z348d8Mh8dLZx9R6Ct2iNvlycN0OcOh
fN98KX2gPFjfugyHC0q3f9a1QM1bnOFw3793eh4S/2rFSzXDFqj6RVDzkPh8
upvmvm8udnDpznn+e2GGg8IGoEuA/G9AZx4C8r3NOx0TgHz9uypsjUD+ZAmW
MD4gH+xOIP8iyP6mYof9QGfdXQC1D8gvtOW6vngB1D4kPti+xmIH2agU6/vz
Mxy028VunkPiW205UbYPyAfTQD7YXiR5kDEFSHwQ5Y+kvlpknfvDBoT8MqD1
G5D4YGVIfHA4IPF3yLW+DkTiHwMFABIfHJ9IfF6Qf+oRfDCdjOBbgiwMLoaE
0yUEv296nlCzTiacHwYKmPBMh9znv1d+jIKGV06mA3r6AQC7qQgE
                    
                    "], CompressedData["
1:eJxTTMoPSmViYGDQA2IQXS2yzv0hS4GDS3fO898HMxy028VunlNE8Mv3zZfS
ty5wAKvbl+EgG5Vifd+7wIEBBHZkONhyXV9ckF7gUAhirMlwsNpyomxfZYHD
fqC2u3MyHLYCufObChy4gcpsuzIcLijd/lnXUuCgbsixRqYtw+FqxUs1w7YC
h4yJb2vsGzMcWl8H7pBrh+qvyXAQaj5waiGQDzanKgNib0eBQxif7qa55RkO
x7zNOx2BfB8glVCa4TAjD6gDyAfakrWnIMNh2ewjChuAfDW2xqnO2Qj1QNtM
49IyHBa5bvv8F+ieApD7XTIcpoP05xQ4TDj0VSNGOsNBCxQe9lD/vkl3uAhy
vxTU/CPpDlWgcNmW79APUj893QHk/flp+Q6PlwIt7kh30L+rwtb4MA/irrx0
B1WQO87nQeQr0h0sQRqm50HMfQc1rywP4h6TDIi6mDyI+UD/gt0Vneew6uMl
36QWBL8X5HAkPsRfCD44fFsRfLC7gHxwuAD54HhpQ8iD3YHEj93lycPUDg1/
oHuKQAa2I9wH9geQfxwUvkA+JJ4yIOkiBuoeIB8cr0A+SFlCJzT8Y6DuAfIN
QHRsHiT9AfnCoPgH8mHpB6yvEuqe5VD3JOQ7fNOI6T8ETK/o6RkA8GtGnw==

                    "], {{339.984, 185.88700000000003`}, {344.828, 186.098}, {
                    347.445, 182.824}, {342.18, 178.758}, {
                    338.79299999999995`, 176.141}, {333.816, 176.035}, {
                    330.734, 178.523}, {328.51599999999996`, 180.312}, {
                    328.629, 180.566}, {332.668, 183.285}, {
                    335.22299999999996`, 185.}, {337.82, 185.789}, {339.984, 
                    185.88700000000003`}}, CompressedData["
1:eJxTTMoPSmViYGBQBWIQfbXipZphVJmDS3fO898H0xwUNhRlTIwuc+C6vrjA
9lCaw2QJljC+2DKHm+e+Bz8Gyu+Qa30dGIdQb7XlRNm+TAT/mLd5p2NLmUPs
Lk8epuVpDhkT39bYzyxzAOoCak1zACmfv6/MYd98Kf27HmkOF5Ru/6wD8veD
+C5pDlrtYjfP9Zc5OCY8vaB0PdVBqPnAqYXlZQ5AU0zj5qU6AG1Z+TEO6p7C
VIh4GNS9eakQ9yHxP13yTRJA4jOAABKfT3fT3PehCL7HwyqRdUh8YZD9SHxF
UPgg8aNSrO/7I/HB/kXil4M8isTPBbk/BMGvFlnn/hCJDw4fvzIHdUOONTJF
qQ6HvmrE9OuUOdz5WZe1pybVARS8CZzQ8GhLdTgOEnhUCgnfiamQ+DtZ6lBo
CzRxA4IPC08YHxz+N1Ih8QfkO4Hkb0PDA8hf5Lrt8987qQ6Pl84+onChFBLe
smkQcYMyBxmQx7enOaCnHwBpDxOs
                    "], {{268.883, 176.648}, {
                    269.10900000000004`, 176.66}, {269.375, 176.648}, {269.66,
                     176.648}, {272.99199999999996`, 176.648}, {274.828, 
                    173.906}, {274.828, 168.92200000000003`}, {274.828, 
                    162.22299999999998`}, {270.746, 162.762}, {
                    268.85900000000004`, 169.70299999999997`}, {267.219, 
                    175.74599999999998`}, {267.055, 176.547}, {268.883, 
                    176.648}}, CompressedData["
1:eJxNk21IVFEQhhcRifwgLCJExRZTCUL8EWGx7KhFREQUsfdai4XsgUVEt1NY
lEiiYRFSErHaJkuK/ogQiRLpw0Skwh+6H9ZmKRIRIWFRUSAhNHPuwDkXLofn
zpwz55137vb65uMizeVyefGlVT0BCWp9L+DzUGS6qFPC/huNX/8tCMjZ9aj/
R1xCacWGh/ljAn4ljtRvWpTwt8x/c6qf85E3d0zO3EdePtodbkIeODD2e/2e
5pfRvPIl5Jj741ob8uJaW8Nz5OtVZ77EkNU5Bqv7IF/eMnLwE3LBycC+5YiO
35r6U+Y3uCSj/U5NROdX42c38oUJKiwhQXXvav7e6t1dhxzsWW31ImemBkMe
I6709GkuXyrOaO/T+Yf3YGUjrpZezR9In8Ehz8bUYK/er/QZ8XzSFxbw9uJK
SQXefwfp6RJOndcSKh+/aZmoEbBK9x6R8OAnGuESMF549duxKxJeUWJnwNkf
5H4WC+e7n/t3jvtzQoKPjH3G/vgkvDh/e1v6rGblt8FPsHzUYHWOwWSDe05A
uCm3Y9LH/iBfowCyRfUM3kt6jHylJ6bj3RRAvkR1kM9S/5BR7XihJZ01zv2z
2I8499div5BpW8jieUYuGpXBHov1JQTkks/IlOZBVj5YrA85m+Yfue7poay0
pHB8s3m+ktxfW+crP2ydr/wy8kl21GY/kYfRplGb/UnyPNs8H/Osp5b7Mc96
anmekHd2bV2YPSWd/+od6zvN56f4vsb//R8cH8Yx
                    
                    "], CompressedData["
1:eJxTTMoPSmViYGDQAGIQfeirRkz/vEKHjIlva+wnpjoASdO4JYUQelKqg8Fd
FbbGtYUOE8AKUx0eL519RGEXlN+d6mDLdX1xweVChyKQAc2pDsuA0hteFTp4
m3c6JkSmOoC1vSt06JueJ9Ssk+oQlWJ93/9zocPekskSLN9SIOo/FDrIgiTO
pzh8uuSbJADUD7ZnT4qDwgagyS8LHbaeKNs3f1eKwwygMQdeFDqs+ghUuCPF
4WrFSzVDIN8x4ekFpe0pDvog9z4vdACqOrVwa4rDFpC+Z1DztqQ48Olumvv+
aaFDtcg694ebUhyEQeqA/ItKt3/WAflAV4XxAflg8Y0pDiBnH3gCDR8gH+zf
x4UOxSCB9SkOViALHhY63Dz3Pfjx2hSHYyCPPyh0aH0duEMOyAe7436hw52f
dVl71kDdc6/QYTXI/UA+AwgA+cdB+oB8sLvuFELEgXxwON5G8MH+vYVQD3bv
2UKHcJDH1kPDbw/UvxdSIO6GxR9/KkT/HKh8BDS+p0DDtyoVYt/0Qod986X0
73akQtw/Heq/Tmj8z0DE/wVQuM2Auqcn1UG7XezmuZmFkHjqS3XQAvFnFzoU
ggJuAjQ9IKU3ADaTNHQ=
                    "]}]}}, AspectRatio -> Automatic, 
                  ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 600.}, {0., 400.}}], ",", 
                 GraphicsBox[{{
                    Thickness[0.0017211703958691911`], {
                    RGBColor[0., 0.21960800000000003`, 0.5764710000000001], 
                    Thickness[0.07213642512908776], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, {{{21.047, 365.337471}, {507.949, 
                    365.337471}, {21.047, 670.247471}, {21.047, 
                    21.04847099999995}, {507.949, 21.04847099999995}, {21.047,
                     507.946471}}}, CurveClosed -> {1}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{159.875, 
                    129.36100000000002`}, {142.77299999999997`, 
                    88.99700000000001}, {125.66799999999999`, 
                    129.36100000000002`}}}]}}, {{
                    RGBColor[
                    0.8627450000000002, 0.07843140000000001, 
                    0.23529400000000003`], 
                    
                    PolygonBox[{{{21.047, 365.337}, {507.949, 365.337}, {
                    21.047, 670.247}}}]}, {
                    RGBColor[
                    0.8627450000000002, 0.07843140000000001, 
                    0.23529400000000003`], 
                    
                    PolygonBox[{{21.047, 21.048}, {507.949, 21.048}, {21.047, 
                    507.947}}]}}, {
                    Thickness[0.0017211703958691911`], {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJhIGYC4r0lkyVYnrk5uG37/PfKr1qH4oyJb2vq/RwW
SOnfVZlQ7dB84NRCV79Ih9eBO+Rab1Y63PpZl7XnRiKc/67G3jSOKx3OFwZp
EMyB62cAgR+5cPNh/AJbruuLU2ocgKrYGlfmOGjG9B/6eqHKIW6XJw9TdpbD
QaC12zZWOhSC1OlkOERabjlRNqnCoRVkEWuqgypb41Tn1+Vw98D4vdPzhJoj
YuF8kPN2cYbD9d8Gqe8JgpsPdo+CD9x+WHjA3IcePgAXt4qb
                    "]], 
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{187.90200000000002`, 434.552}, {
                    187.90200000000002`, 409.626}, {167.695, 
                    389.42299999999994`}, {142.77299999999997`, 
                    389.42299999999994`}, {117.848, 389.42299999999994`}, {
                    97.645, 409.626}, {97.645, 434.552}, {97.645, 459.474}, {
                    117.848, 479.677}, {142.77299999999997`, 479.677}, {
                    167.695, 479.677}, {187.90200000000002`, 459.474}, {
                    187.90200000000002`, 434.552}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    160.04299999999998`, 476.243}, {155., 
                    496.02099999999996`}, {142.77299999999997`, 479.677}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{174.684, 
                    466.462}, {177.594, 486.661}, {160.04299999999998`, 
                    476.243}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{184.465, 
                    451.822}, {194.883, 469.368}, {174.684, 466.462}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    187.90200000000002`, 434.552}, {204.242, 446.779}, {
                    184.465, 451.822}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{184.465, 
                    417.282}, {204.242, 422.325}, {187.90200000000002`, 
                    434.552}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{174.684, 
                    402.64200000000005`}, {194.883, 399.73199999999997`}, {
                    184.465, 417.282}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{125.504, 
                    476.243}, {130.547, 496.02099999999996`}, {
                    142.77299999999997`, 479.677}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{110.863, 
                    466.462}, {107.953, 486.661}, {125.504, 476.243}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{101.082, 
                    451.822}, {90.664, 469.368}, {110.863, 466.462}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{97.645, 
                    434.552}, {81.30499999999999, 446.779}, {101.082, 
                    451.822}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{101.082, 
                    417.282}, {81.30499999999999, 422.325}, {97.645, 
                    434.552}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{110.863, 
                    402.64200000000005`}, {90.664, 399.73199999999997`}, {
                    101.082, 417.282}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{208.85500000000002`, 193.19299999999998`}, {
                    208.85500000000002`, 156.697}, {179.26999999999998`, 
                    127.111}, {142.77299999999997`, 127.111}, {106.277, 
                    127.111}, {76.691, 156.697}, {76.691, 
                    193.19299999999998`}, {76.691, 229.689}, {106.277, 
                    259.279}, {142.77299999999997`, 259.279}, {
                    179.26999999999998`, 259.279}, {208.85500000000002`, 
                    229.689}, {208.85500000000002`, 193.19299999999998`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{159.875, 
                    129.36100000000002`}, {142.77299999999997`, 
                    88.99700000000001}, {125.66799999999999`, 
                    129.36100000000002`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    125.66799999999999`, 257.025}, {142.77299999999997`, 
                    297.392}, {159.875, 257.025}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    78.94100000000002, 176.091}, {38.574, 
                    193.19299999999998`}, {78.94100000000002, 210.298}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{206.605, 
                    210.298}, {246.969, 193.19299999999998`}, {206.605, 
                    176.091}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    125.66799999999999`, 129.36100000000002`}, {
                    90.67599999999999, 102.95400000000001`}, {96.043, 
                    146.466}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{159.875, 
                    257.025}, {194.871, 283.4309999999999}, {189.5, 
                    239.923}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    78.94100000000002, 210.298}, {52.535000000000004`, 
                    245.29}, {96.043, 239.923}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{206.605, 
                    176.091}, {233.012, 141.095}, {189.5, 146.466}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{96.043, 
                    146.466}, {52.535000000000004`, 141.095}, {
                    78.94100000000002, 176.091}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{189.5, 
                    239.923}, {233.012, 245.29}, {206.605, 210.298}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{96.043, 
                    239.923}, {90.67599999999999, 283.4309999999999}, {
                    125.66799999999999`, 257.025}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{189.5, 
                    146.466}, {194.871, 102.95400000000001`}, {159.875, 
                    129.36100000000002`}}}]}}}, AspectRatio -> Automatic, 
                  ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 581.}, {0., 709.}}], ",", 
                 GraphicsBox[{{
                    Thickness[0.001388888888888889], {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 480.}, {720., 480.}, {720., 0.}}}]}, {
                    FaceForm[{
                    RGBColor[0.003921569999999999, 0.254902, 0.109804], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    180., 480.}, {720., 480.}, {720., 0.}, {180., 0.}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{594., 240.}, {594., 160.47299999999998`}, {
                    529.5269999999999, 96.}, {450., 96.}, {
                    370.47299999999996`, 96.}, {306., 160.47299999999998`}, {
                    306., 240.}, {306., 319.527}, {370.47299999999996`, 
                    384.}, {450., 384.}, {529.5269999999999, 384.}, {594., 
                    319.527}, {594., 240.}}}]}, {
                    FaceForm[{
                    RGBColor[0.003921569999999999, 0.254902, 0.109804], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{585.4649999999999, 360.414}, {633.898, 
                    305.92599999999993`}, {628.992, 222.49200000000002`}, {
                    574.504, 174.059}, {520.016, 125.62899999999999`}, {
                    436.582, 130.535}, {388.148, 185.023}, {339.719, 
                    239.512}, {344.625, 322.941}, {399.113, 371.375}, {
                    453.59799999999996`, 419.809}, {537.031, 414.902}, {
                    585.4649999999999, 360.414}}}]}}, {
                    RGBColor[1., 1., 1.], 
                    
                    PolygonBox[{{473.984, 299.066}, {508.04896572377527`, 
                    291.59710042426104`}, {511.47299999999996`, 256.895}, {
                    529.1002640300983, 286.9815069648755}, {563.168, 
                    279.512}, {539.9966282021564, 305.5796022787413}, {
                    539.9966282021563, 305.5796022787413}, {557.625, 
                    335.668}, {525.6781375521971, 321.6877862374376}, {
                    502.508, 347.754}, {505.9325235671064, 
                    313.0469406822399}}]}}, AspectRatio -> Automatic, 
                  ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 720.}, {0., 480.}}], ",", 
                 GraphicsBox[{
                   Thickness[0.001388888888888889], {
                    FaceForm[{
                    RGBColor[0., 0.21960800000000003`, 0.6588240000000001], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 360.}, {720., 360.}, {720., 0.}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.8078430000000001, 0.06666670000000002, 0.14902], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     180.}, {720., 180.}, {720., 0.}, {0., 0.}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{311.77, 
                    180.}, {0., 0.}, {0., 360.}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.988235, 0.8196080000000001, 0.08627450000000002], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{148., 180.}, {148., 160.117}, {131.883, 144.}, {
                    112., 144.}, {92.117, 144.}, {76., 160.117}, {76., 
                    180.}, {76., 199.883}, {92.117, 216.}, {112., 216.}, {
                    131.883, 216.}, {148., 199.883}, {148., 180.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    36., 180.}, {40.676, 175.324}, {112., 180.}, {40.676, 
                    184.676}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{44., 
                    171.047}, {47.815999999999995`, 167.23399999999998`}, {
                    112., 180.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{44., 
                    188.953}, {47.815999999999995`, 192.766}, {112., 180.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    58.26200000000001, 233.738}, {58.26200000000001, 
                    227.129}, {112., 180.}, {64.871, 233.738}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{57.586, 
                    221.754}, {57.586, 216.359}, {112., 180.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    70.24600000000001, 234.414}, {75.641, 234.414}, {112., 
                    180.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    112., 256.}, {107.324, 251.324}, {112., 180.}, {
                    116.67599999999999`, 251.324}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    103.04700000000001`, 248.}, {99.23400000000001, 
                    244.184}, {112., 180.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{120.953, 
                    248.}, {124.766, 244.184}, {112., 180.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    165.738, 233.738}, {159.129, 233.738}, {112., 180.}, {
                    165.738, 227.129}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{153.754, 
                    234.414}, {148.359, 234.414}, {112., 180.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{166.414, 
                    221.754}, {166.414, 216.359}, {112., 180.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    188., 180.}, {183.324, 184.676}, {112., 180.}, {183.324, 
                    175.324}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{180., 
                    188.953}, {176.184, 192.766}, {112., 180.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{180., 
                    171.047}, {176.184, 167.23399999999998`}, {112., 180.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    165.738, 126.262}, {165.738, 132.871}, {112., 180.}, {
                    159.129, 126.262}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{166.414, 
                    138.24599999999998`}, {166.414, 143.641}, {112., 180.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{153.754, 
                    125.586}, {148.359, 125.586}, {112., 180.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    112., 104.}, {116.67599999999999`, 108.67599999999999`}, {
                    112., 180.}, {107.324, 108.67599999999999`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{120.953, 
                    112.}, {124.766, 115.816}, {112., 180.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    103.04700000000001`, 112.}, {99.23400000000001, 
                    115.816}, {112., 180.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    58.26200000000001, 126.262}, {64.871, 126.262}, {112., 
                    180.}, {58.26200000000001, 132.871}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    70.24600000000001, 125.586}, {75.641, 125.586}, {112., 
                    180.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{57.586, 
                    138.24599999999998`}, {57.586, 143.641}, {112., 180.}}}], 
                    
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, {{{275.77, 180.}, {262.242, 175.297}, {
                    261.949, 160.98000000000002`}, {253.297, 
                    172.39100000000002`}, {239.59, 168.24599999999998`}, {
                    247.76999999999998`, 180.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, {{{275.77, 180.}, {262.242, 
                    184.70299999999997`}, {261.949, 199.02}, {253.297, 
                    187.60899999999998`}, {239.59, 191.754}, {
                    247.76999999999998`, 180.}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, {{{18., 31.176000000000002`}, {
                    20.691000000000003`, 45.242000000000004`}, {
                    8.437999999999999, 52.656}, {22.648, 
                    54.440999999999995`}, {25.91, 68.387}, {32., 55.426}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, {{{18., 31.176000000000002`}, {
                    28.836000000000002`, 40.543}, {41.382999999999996`, 
                    33.633}, {35.824, 46.836}, {46.27, 56.633}, {32., 
                    55.426}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, {{{18., 328.824}, {28.836000000000002`, 
                    319.457}, {41.382999999999996`, 326.367}, {35.824, 
                    313.16400000000004`}, {46.27, 303.367}, {32., 304.574}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, {{{18., 328.824}, {20.691000000000003`, 
                    314.758}, {8.437999999999999, 307.34400000000005`}, {
                    22.648, 305.559}, {25.91, 291.613}, {32., 304.574}}}]}}, 
                  AspectRatio -> Automatic, ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 720.}, {0., 360.}}], ",", 
                 GraphicsBox[{
                   Thickness[0.001639344262295082], {
                    FaceForm[{
                    RGBColor[
                    0.5529410000000001, 0.105882, 0.23921600000000004`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     240.}, {609.602, 240.}, {609.602, 0.}, {0., 0.}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJRIGZiQAd5DhhCYJABF7/1sy5rj0Sew81z34MfL9Vy
gMlPkWAJ41tr5QCTh4i7wOW3ff57pWKlF1xeha1xqvPqAAdU80Pg8rdBdEg4
XB6iPgrN/Di4/Lsae9O4VQlweaHmA6cWhiahmZ8Cl4eoT4XLQ9Sno5mfiWZ+
Fpr5OWjm5zkAADWeXto=
                    "]]}}, AspectRatio -> Automatic, 
                  ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 610.}, {0., 240.}}], ",", 
                 GraphicsBox[{
                   Thickness[0.00028935185185185184`], {
                    FaceForm[{
                    RGBColor[0.9294119999999999, 0.160784, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     2304.}, {3456., 2304.}, {3456., 1152.}, {0., 1152.}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     1152.}, {3456., 1152.}, {3456., 0.}, {0., 0.}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJDIGYCYm/zTseE1kkODGAw2wHGf6lmyKEjO8tBla1x
qnPEJAc+3U1z861mOrSL3TxXzjjJgWONTNSTjBlgdWtWTXQACn8Pnj7d4fbP
uiwbrYkOP4IfL5W+Ps3hsm+SwI3OCQ5yra8Dd5hNc5jq3J3z/FI/WDxi2lSH
bZ//XqkI6nM4qrCh6IXoVIj963sg+vdPcciY+LbGnqfbYe775ce8M6Y4CERY
bjnh1ukA1G1pYj3F4fHS2UcUGtvhfP27KmyNu1vh/EqQA781w/WD7Q9qgpsP
tO3phfUNcPun5wk1H4irg7uvfN98Kf271XD3A2VPLYyuhPtPNirF+n5kOdz/
IOds+FcKDx+wexaXwMNvsgRLGN/7Ynj4wviw8IfxxYHmXX40G67/4yXfpAlH
58DNB9s/fS7cfnA8ZMyDuw9sv8Z8uPsfVomscz85H+4/sPkmC+D+nwcMH+7S
BfDwAbpCt2jBAnj4AU2XuXV6ATx8z38Pfpz6aAE8/GF8WPzA+LD4g+mHxS/M
fFj8o9gPTB8w98HSD8z9sPQF8x8s/cH8D0ufsPCBpV9Y+MHSNyx80dM/AJyY
ZBE=
                    "]]}, {
                    FaceForm[{
                    RGBColor[0.9294119999999999, 0.160784, 0.223529], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJDIGYCYh/zTscHS6c4MIDBbAcYv9CW6/pizVkOGRPf
1thXT3HwBoonBM90kG99HWihOcXhsm+SQETvDIdls48oGFyf7DD3/fJj3sen
O0SlWN8/HzsZol9wOkT/sUkO69wfVolUTXN4qWbIsUZvEti+hkdTHfaUTJZg
qZzosOVE2T75zKkOLt05z39vmuBgfd+/V1x8qsM0Z6DAzX6HT5eAFh6F2qvb
53Bqoeu24llTHLYC9c1v6IHz+XQ3zX1/uQvOB7tbvROuH+Q+/9ntcPPB7uNv
g9sP1r+4Be4+wQjLLSdKmuHuB0kvd22C+28qyH1BjXD/Ly4ASqxrgIePAEg/
VwM8/IC+DePLroeHL4wPC38Yv//QV42Ya7Ph+kHum79mDtx8HZA7iubC7U8C
KbSYB3cfWP+7eXD3B+2Qa33dOh/uP1AaOMC3AO5/UDwWeC+Ahw/IvJKSBfDw
axe7ea587gJ4+Err31U5tmkBPPxhfFj8wPiw+IPph8UvzHxY/MPsh6UPFPcB
0w/M/bD0BfMfLP3B/A9Ln7DwgaVfWPjB0jcsfNHTPwCAp1ta
                    "]]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{805.758, 1717.547}, {746.906, 
                    1762.6909999999998`}, {688.0740000000001, 1717.527}, {
                    710.727, 1790.3239999999998`}, {651.6880000000001, 
                    1835.195}, {724.535, 1835.043}, {746.883, 1907.941}, {
                    769.254, 1835.051}, {842.102, 1835.23}, {783.082, 
                    1790.336}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{1267.508, 1717.547}, {1208.6599999999999`, 
                    1762.6909999999998`}, {1149.8239999999998`, 1717.527}, {
                    1172.477, 1790.3239999999998`}, {1113.441, 1835.195}, {
                    1186.289, 1835.043}, {1208.6329999999998`, 1907.941}, {
                    1231.008, 1835.051}, {1303.8519999999999`, 1835.23}, {
                    1244.8319999999999`, 1790.336}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{1036.867, 1888.9180000000001`}, {978.02, 
                    1934.062}, {919.1840000000001, 1888.895}, {
                    941.8359999999999, 1961.6909999999998`}, {
                    882.8009999999999, 2006.566}, {955.648, 2006.41}, {
                    977.996, 2079.309}, {1000.3669999999998`, 
                    2006.4180000000001`}, {1073.2150000000001`, 2006.598}, {
                    1014.191, 1961.703}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{892.156, 1443.348}, {833.309, 1488.492}, {
                    774.4730000000001, 1443.328}, {797.125, 1516.125}, {
                    738.09, 1560.996}, {810.938, 1560.8439999999998`}, {
                    833.2850000000001, 1633.742}, {855.656, 
                    1560.8519999999999`}, {928.504, 1561.031}, {869.48, 
                    1516.137}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{1181.105, 1443.348}, {1122.258, 1488.492}, {
                    1063.4260000000002`, 1443.328}, {1086.0739999999998`, 
                    1516.125}, {1027.039, 1560.996}, {1099.887, 
                    1560.8439999999998`}, {1122.234, 1633.742}, {1144.605, 
                    1560.8519999999999`}, {1217.453, 1561.031}, {1158.434, 
                    1516.137}}}]}}, AspectRatio -> Automatic, 
                  ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 3456.}, {0., 2304.}}], ",", 
                 GraphicsBox[{
                   Thickness[0.001388888888888889], {
                    FaceForm[{
                    RGBColor[0.9294119999999999, 0.109804, 0.141176], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 480.}, {720., 480.}, {720., 0.}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     400.}, {720., 400.}, {720., 80.}, {0., 80.}}}]}, {
                    FaceForm[{
                    RGBColor[0.141176, 0.11372500000000002`, 0.309804], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     320.}, {720., 320.}, {720., 160.}, {0., 160.}}}]}}, 
                  AspectRatio -> Automatic, ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 720.}, {0., 480.}}], ",", 
                 GraphicsBox[{
                   Thickness[0.001388888888888889], {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 480.}, {720., 480.}, {720., 0.}}}]}, {
                    Thickness[0.001388888888888889], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    110.387, 334.301}, {176.94899999999998`, 
                    434.14500000000004`}, {243.512, 389.77}, {
                    176.94899999999998`, 289.92199999999997`}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    121.48, 314.883}, {199.137, 431.371}, {
                    207.45700000000002`, 425.824}, {129.80100000000002`, 
                    309.33599999999996`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    146.441, 298.242}, {224.098, 414.72999999999996`}, {
                    232.418, 409.184}, {154.762, 292.695}}}]}, {
                    Thickness[0.001388888888888889], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    476.48799999999994`, 90.23}, {543.0509999999999, 
                    190.078}, {609.613, 145.69899999999998`}, {
                    543.0509999999999, 45.855}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    487.582, 70.816}, {565.238, 187.305}, {573.559, 
                    181.758}, {495.902, 65.27}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    512.543, 54.176}, {590.1990000000001, 170.664}, {598.52, 
                    165.117}, {520.8629999999999, 48.629000000000005`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    498.676, 141.539}, {504.22299999999996`, 149.859}, {
                    587.4259999999999, 94.391}, {581.879, 86.07}}}]}, {
                    FaceForm[{
                    RGBColor[0.776471, 0.047058800000000005`, 0.188235], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{426.562, 339.848}, {481.707, 303.082}, {
                    496.60900000000004`, 228.578}, {459.848, 
                    173.43800000000002`}, {423.082, 118.293}, {348.578, 
                    103.391}, {293.43799999999993`, 140.15200000000002`}, {
                    238.29299999999998`, 176.918}, {223.39100000000002`, 
                    251.42200000000003`}, {260.15200000000004`, 306.562}, {
                    296.91799999999995`, 361.707}, {371.42199999999997`, 
                    376.60900000000004`}, {426.562, 339.848}}}]}, {
                    FaceForm[{
                    RGBColor[0., 0.20392200000000002`, 0.47058800000000006`], 
                    
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4gf+vdPznAocFrlu+/xXo9hBla1xqnN4nkOH
Y8LTC22FEPGQfIfW14E75CTzHKbnCTUf8Cl0KM6Y+LbmdbZDzvPfKz++K3K4
ee578OO9mQ7l++ZL6WeWQuR3ZzkwgEBDGYRmgJo7rdzhuLd5p+OiAofJEixh
fIJVEFqx0AGkzX5zNUSeq8DB4K4KW2NorUOVyDr3h89yHYCypnFXaiH0pwwH
xQ1FGRP31jjsLQGasC7VYensIwobllU76IP0ZSY52HFdX1zwtNLBasuJsn38
CQ6HvmrE9P8oh9gzNc4B6JtTC7nLIP7iioW4/2exgxcPk3b7ujiH2F2ePEzh
RQ77gcJ3WxIh6rYUOGwFGjd/UzLUXGj4mKZDxL3yHKpB7uXLdvABeiOhNdfh
1s+6rD0v8jDCFz38ASyVsr0=
                    "]]}, {
                    Thickness[0.001388888888888889], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    176.94899999999998`, 45.855}, {110.387, 
                    145.69899999999998`}, {176.94899999999998`, 190.078}, {
                    243.512, 90.23}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    199.137, 48.629000000000005`}, {121.48, 165.117}, {
                    129.80100000000002`, 170.664}, {207.45700000000002`, 
                    54.176}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    224.098, 65.27}, {146.441, 181.758}, {154.762, 187.305}, {
                    232.418, 70.816}}}]}, {
                    Thickness[0.001388888888888889], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    543.0509999999999, 289.92199999999997`}, {
                    476.48799999999994`, 389.77}, {543.0509999999999, 
                    434.14500000000004`}, {609.613, 334.301}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    565.238, 292.695}, {487.582, 409.184}, {495.902, 
                    414.72999999999996`}, {573.559, 298.242}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    590.1990000000001, 309.33599999999996`}, {512.543, 
                    425.824}, {520.8629999999999, 431.371}, {598.52, 
                    314.883}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    504.22299999999996`, 330.141}, {498.676, 
                    338.46099999999996`}, {581.879, 393.92999999999995`}, {
                    587.4259999999999, 385.60900000000004`}}}]}, {
                    Thickness[0.001388888888888889], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    540.277, 348.168}, {529.1840000000001, 364.809}, {545.824,
                     375.902}, {556.918, 359.262}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    163.08200000000002`, 102.71100000000001`}, {157.535, 
                    111.031}, {190.816, 133.21899999999997`}, {196.363, 
                    124.898}}}]}}, AspectRatio -> Automatic, 
                  ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 720.}, {0., 480.}}]}], "}"}], ",", 
             RowBox[{"{", 
               RowBox[{
                 GraphicsBox[{
                   Thickness[0.000925925925925926], {
                    FaceForm[{
                    RGBColor[1., 0.6, 0.2], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 720.}, {1080., 720.}, {1080., 0.}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     480.}, {1080., 480.}, {1080., 240.}, {0., 240.}}}]}, {
                    FaceForm[{
                    RGBColor[0.0705882, 0.533333, 0.027451000000000003`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     240.}, {1080., 240.}, {1080., 0.}, {0., 0.}}}]}, {
                    FaceForm[{
                    RGBColor[0., 0., 0.533333], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{636., 360.}, {636., 306.97999999999996`}, {
                    593.02, 264.}, {540., 264.}, {486.97999999999996`, 
                    264.}, {444., 306.97999999999996`}, {444., 360.}, {444., 
                    413.02}, {486.97999999999996`, 456.}, {540., 456.}, {
                    593.02, 456.}, {636., 413.02}, {636., 360.}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{624., 360.}, {624., 313.60900000000004`}, {
                    586.391, 276.}, {540., 276.}, {493.60900000000004`, 
                    276.}, {456., 313.60900000000004`}, {456., 360.}, {456., 
                    406.39099999999996`}, {493.60900000000004`, 444.}, {540., 
                    444.}, {586.391, 444.}, {624., 406.39099999999996`}, {
                    624., 360.}}}]}, {
                    FaceForm[{
                    RGBColor[0., 0., 0.533333], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{556.8009999999999, 360.}, {556.8009999999999, 
                    350.72299999999996`}, {549.277, 343.199}, {540., 
                    343.199}, {530.7230000000001, 343.199}, {
                    523.1990000000001, 350.72299999999996`}, {
                    523.1990000000001, 360.}, {523.1990000000001, 369.277}, {
                    530.7230000000001, 376.801}, {540., 376.801}, {549.277, 
                    376.801}, {556.8009999999999, 369.277}, {
                    556.8009999999999, 360.}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{627.4449999999999, 348.48799999999994`}, {
                    627.145, 346.188}, {625.031, 344.57}, {622.734, 
                    344.871}, {620.434, 345.176}, {618.8159999999999, 
                    347.28499999999997`}, {619.117, 349.58599999999996`}, {
                    619.4219999999999, 351.883}, {621.531, 353.504}, {623.828,
                     353.199}, {626.129, 352.89799999999997`}, {627.75, 
                    350.789}, {627.4449999999999, 348.48799999999994`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    540., 276.}, {542.879, 326.39799999999997`}, {540., 
                    350.39799999999997`}, {537.121, 326.39799999999997`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{621.484, 326.246}, {620.5980000000001, 
                    324.105}, {618.141, 323.08599999999996`}, {616., 
                    323.97299999999996`}, {613.8549999999999, 324.863}, {
                    612.8399999999999, 327.32}, {613.727, 
                    329.46099999999996`}, {614.613, 331.605}, {617.07, 
                    332.621}, {619.215, 331.734}, {621.3549999999999, 
                    330.848}, {622.375, 328.39099999999996`}, {621.484, 
                    326.246}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    518.258, 278.863}, {534.086, 326.801}, {537.516, 
                    350.727}, {528.523, 328.289}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{609.9730000000001, 306.309}, {608.5619999999999, 
                    304.469}, {605.9259999999999, 304.121}, {604.086, 
                    305.53099999999995`}, {602.246, 306.945}, {601.898, 
                    309.582}, {603.309, 311.42199999999997`}, {
                    604.7230000000001, 313.262}, {607.3589999999999, 
                    313.60900000000004`}, {609.1990000000001, 312.195}, {
                    611.039, 310.78499999999997`}, {611.387, 308.148}, {
                    609.9730000000001, 306.309}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    498., 287.254}, {525.695, 329.46099999999996`}, {
                    535.1990000000001, 351.688}, {520.707, 
                    332.34000000000003`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{593.691, 290.027}, {591.8519999999999, 
                    288.613}, {589.215, 288.96099999999996`}, {587.805, 
                    290.801}, {586.391, 292.641}, {586.738, 295.277}, {
                    588.5780000000001, 296.691}, {590.418, 
                    298.10200000000003`}, {593.055, 297.754}, {
                    594.4689999999999, 295.914}, {595.879, 294.074}, {595.531,
                     291.43799999999993`}, {593.691, 290.027}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    480.60200000000003`, 300.60200000000003`}, {518.277, 
                    334.203}, {533.211, 353.21099999999996`}, {
                    514.2030000000001, 338.277}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{573.754, 278.51599999999996`}, {571.609, 
                    277.625}, {569.1519999999999, 278.64500000000004`}, {
                    568.266, 280.78499999999997`}, {567.379, 
                    282.92999999999995`}, {568.395, 285.387}, {570.539, 
                    286.27299999999997`}, {572.6800000000001, 287.16}, {
                    575.137, 286.14500000000004`}, {576.0269999999999, 
                    284.}, {576.914, 281.85900000000004`}, {575.895, 
                    279.402}, {573.754, 278.51599999999996`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    467.254, 318.}, {512.3399999999999, 340.707}, {
                    531.6880000000001, 355.199}, {509.46099999999996`, 
                    345.695}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{551.512, 272.555}, {549.211, 272.25}, {547.102, 
                    273.871}, {546.8009999999999, 276.172}, {546.496, 
                    278.469}, {548.117, 280.578}, {550.414, 280.883}, {
                    552.715, 281.184}, {554.824, 279.566}, {555.129, 
                    277.26599999999996`}, {555.43, 274.969}, {
                    553.8119999999999, 272.855}, {551.512, 272.555}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    458.863, 338.258}, {508.289, 348.52299999999997`}, {
                    530.727, 357.51599999999996`}, {506.801, 
                    354.08599999999996`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{528.488, 272.555}, {526.1880000000001, 
                    272.855}, {524.57, 274.969}, {524.871, 
                    277.26599999999996`}, {525.176, 279.566}, {
                    527.2850000000001, 281.184}, {529.586, 280.883}, {531.883,
                     280.578}, {533.504, 278.469}, {533.1990000000001, 
                    276.172}, {532.898, 273.871}, {530.7890000000001, 
                    272.25}, {528.488, 272.555}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    456., 360.}, {506.39799999999997`, 357.121}, {530.398, 
                    360.}, {506.39799999999997`, 362.879}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{506.246, 278.51599999999996`}, {504.105, 
                    279.402}, {503.08599999999996`, 281.85900000000004`}, {
                    503.97299999999996`, 284.}, {504.863, 
                    286.14500000000004`}, {507.32, 287.16}, {
                    509.46099999999996`, 286.27299999999997`}, {511.605, 
                    285.387}, {512.621, 282.92999999999995`}, {511.734, 
                    280.78499999999997`}, {510.848, 278.64500000000004`}, {
                    508.39099999999996`, 277.625}, {506.246, 
                    278.51599999999996`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    458.863, 381.742}, {506.801, 365.914}, {530.727, 
                    362.484}, {508.289, 371.477}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{486.309, 290.027}, {484.469, 
                    291.43799999999993`}, {484.121, 294.074}, {
                    485.53099999999995`, 295.914}, {486.945, 297.754}, {
                    489.582, 298.10200000000003`}, {491.42199999999997`, 
                    296.691}, {493.262, 295.277}, {493.60900000000004`, 
                    292.641}, {492.195, 290.801}, {490.78499999999997`, 
                    288.96099999999996`}, {488.148, 288.613}, {486.309, 
                    290.027}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    467.254, 402.}, {509.46099999999996`, 374.305}, {
                    531.6880000000001, 364.801}, {512.3399999999999, 
                    379.29299999999995`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{470.027, 306.309}, {468.613, 308.148}, {
                    468.96099999999996`, 310.78499999999997`}, {470.801, 
                    312.195}, {472.641, 313.60900000000004`}, {475.277, 
                    313.262}, {476.691, 311.42199999999997`}, {
                    478.10200000000003`, 309.582}, {477.754, 306.945}, {
                    475.914, 305.53099999999995`}, {474.074, 304.121}, {
                    471.43799999999993`, 304.469}, {470.027, 306.309}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    480.60200000000003`, 419.39799999999997`}, {
                    514.2030000000001, 381.72299999999996`}, {533.211, 
                    366.789}, {518.277, 385.79699999999997`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{458.51599999999996`, 326.246}, {457.625, 
                    328.39099999999996`}, {458.64500000000004`, 330.848}, {
                    460.78499999999997`, 331.734}, {462.92999999999995`, 
                    332.621}, {465.387, 331.605}, {466.27299999999997`, 
                    329.46099999999996`}, {467.16, 327.32}, {
                    466.14500000000004`, 324.863}, {464., 
                    323.97299999999996`}, {461.85900000000004`, 
                    323.08599999999996`}, {459.402, 324.105}, {
                    458.51599999999996`, 326.246}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    498., 432.746}, {520.707, 387.66}, {535.1990000000001, 
                    368.312}, {525.695, 390.539}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{452.555, 348.48799999999994`}, {452.25, 
                    350.789}, {453.871, 352.89799999999997`}, {456.172, 
                    353.199}, {458.469, 353.504}, {460.578, 351.883}, {
                    460.883, 349.58599999999996`}, {461.184, 
                    347.28499999999997`}, {459.566, 345.176}, {
                    457.26599999999996`, 344.871}, {454.969, 344.57}, {
                    452.855, 346.188}, {452.555, 348.48799999999994`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    518.258, 441.137}, {528.523, 391.71099999999996`}, {
                    537.516, 369.27299999999997`}, {534.086, 393.199}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{452.555, 371.512}, {452.855, 373.812}, {454.969, 
                    375.42999999999995`}, {457.26599999999996`, 375.129}, {
                    459.566, 374.824}, {461.184, 372.715}, {460.883, 
                    370.414}, {460.578, 368.117}, {458.469, 
                    366.4959999999999}, {456.172, 366.801}, {453.871, 
                    367.10200000000003`}, {452.25, 369.21099999999996`}, {
                    452.555, 371.512}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    540., 444.}, {537.121, 393.60200000000003`}, {540., 
                    369.60200000000003`}, {542.879, 393.60200000000003`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{458.51599999999996`, 393.754}, {459.402, 
                    395.895}, {461.85900000000004`, 396.914}, {464., 
                    396.027}, {466.14500000000004`, 395.137}, {467.16, 
                    392.68}, {466.27299999999997`, 390.539}, {465.387, 
                    388.395}, {462.92999999999995`, 387.379}, {
                    460.78499999999997`, 388.26599999999996`}, {
                    458.64500000000004`, 389.15200000000004`}, {457.625, 
                    391.60900000000004`}, {458.51599999999996`, 393.754}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    561.742, 441.137}, {545.914, 393.199}, {542.484, 
                    369.27299999999997`}, {551.477, 391.71099999999996`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{470.027, 413.691}, {471.43799999999993`, 
                    415.53099999999995`}, {474.074, 415.879}, {475.914, 
                    414.469}, {477.754, 413.055}, {478.10200000000003`, 
                    410.41799999999995`}, {476.691, 408.578}, {475.277, 
                    406.73799999999994`}, {472.641, 406.39099999999996`}, {
                    470.801, 407.805}, {468.96099999999996`, 409.215}, {
                    468.613, 411.85200000000003`}, {470.027, 413.691}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    582., 432.746}, {554.305, 390.539}, {544.8009999999999, 
                    368.312}, {559.2930000000001, 387.66}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{486.309, 429.97299999999996`}, {488.148, 
                    431.387}, {490.78499999999997`, 431.039}, {492.195, 
                    429.199}, {493.60900000000004`, 427.35900000000004`}, {
                    493.262, 424.72299999999996`}, {491.42199999999997`, 
                    423.309}, {489.582, 421.89799999999997`}, {486.945, 
                    422.246}, {485.53099999999995`, 424.08599999999996`}, {
                    484.121, 425.92599999999993`}, {484.469, 428.562}, {
                    486.309, 429.97299999999996`}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    599.398, 419.39799999999997`}, {561.7230000000001, 
                    385.79699999999997`}, {546.7890000000001, 366.789}, {
                    565.797, 381.72299999999996`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{506.246, 441.484}, {508.39099999999996`, 
                    442.375}, {510.848, 441.355}, {511.734, 439.215}, {
                    512.621, 437.07}, {511.605, 434.613}, {
                    509.46099999999996`, 433.727}, {507.32, 
                    432.84000000000003`}, {504.863, 433.855}, {
                    503.97299999999996`, 436.}, {503.08599999999996`, 
                    438.141}, {504.105, 440.59799999999996`}, {506.246, 
                    441.484}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    612.746, 402.}, {567.66, 379.29299999999995`}, {
                    548.3119999999999, 364.801}, {570.539, 374.305}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{528.488, 447.445}, {530.7890000000001, 447.75}, {
                    532.898, 446.129}, {533.1990000000001, 443.828}, {533.504,
                     441.53099999999995`}, {531.883, 439.42199999999997`}, {
                    529.586, 439.117}, {527.2850000000001, 438.816}, {525.176,
                     440.43399999999997`}, {524.871, 442.734}, {524.57, 
                    445.03099999999995`}, {526.1880000000001, 
                    447.14500000000004`}, {528.488, 447.445}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    621.137, 381.742}, {571.711, 371.477}, {549.2730000000001,
                     362.484}, {573.1990000000001, 365.914}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{551.512, 447.445}, {553.8119999999999, 
                    447.14500000000004`}, {555.43, 445.03099999999995`}, {
                    555.129, 442.734}, {554.824, 440.43399999999997`}, {
                    552.715, 438.816}, {550.414, 439.117}, {548.117, 
                    439.42199999999997`}, {546.496, 441.53099999999995`}, {
                    546.8009999999999, 443.828}, {547.102, 446.129}, {549.211,
                     447.75}, {551.512, 447.445}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    624., 360.}, {573.602, 362.879}, {549.602, 360.}, {
                    573.602, 357.121}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{573.754, 441.484}, {575.895, 
                    440.59799999999996`}, {576.914, 438.141}, {
                    576.0269999999999, 436.}, {575.137, 433.855}, {
                    572.6800000000001, 432.84000000000003`}, {570.539, 
                    433.727}, {568.395, 434.613}, {567.379, 437.07}, {568.266,
                     439.215}, {569.1519999999999, 441.355}, {571.609, 
                    442.375}, {573.754, 441.484}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    621.137, 338.258}, {573.1990000000001, 
                    354.08599999999996`}, {549.2730000000001, 
                    357.51599999999996`}, {571.711, 348.52299999999997`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{593.691, 429.97299999999996`}, {595.531, 
                    428.562}, {595.879, 425.92599999999993`}, {
                    594.4689999999999, 424.08599999999996`}, {593.055, 
                    422.246}, {590.418, 421.89799999999997`}, {
                    588.5780000000001, 423.309}, {586.738, 
                    424.72299999999996`}, {586.391, 427.35900000000004`}, {
                    587.805, 429.199}, {589.215, 431.039}, {591.8519999999999,
                     431.387}, {593.691, 429.97299999999996`}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    612.746, 318.}, {570.539, 345.695}, {548.3119999999999, 
                    355.199}, {567.66, 340.707}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{609.9730000000001, 413.691}, {611.387, 
                    411.85200000000003`}, {611.039, 409.215}, {
                    609.1990000000001, 407.805}, {607.3589999999999, 
                    406.39099999999996`}, {604.7230000000001, 
                    406.73799999999994`}, {603.309, 408.578}, {601.898, 
                    410.41799999999995`}, {602.246, 413.055}, {604.086, 
                    414.469}, {605.9259999999999, 415.879}, {
                    608.5619999999999, 415.53099999999995`}, {
                    609.9730000000001, 413.691}}}], 
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    599.398, 300.60200000000003`}, {565.797, 338.277}, {
                    546.7890000000001, 353.21099999999996`}, {
                    561.7230000000001, 334.203}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{621.484, 393.754}, {622.375, 
                    391.60900000000004`}, {621.3549999999999, 
                    389.15200000000004`}, {619.215, 388.26599999999996`}, {
                    617.07, 387.379}, {614.613, 388.395}, {613.727, 
                    390.539}, {612.8399999999999, 392.68}, {613.8549999999999,
                     395.137}, {616., 396.027}, {618.141, 396.914}, {
                    620.5980000000001, 395.895}, {621.484, 393.754}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    582., 287.254}, {559.2930000000001, 
                    332.34000000000003`}, {544.8009999999999, 351.688}, {
                    554.305, 329.46099999999996`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{627.4449999999999, 371.512}, {627.75, 
                    369.21099999999996`}, {626.129, 367.10200000000003`}, {
                    623.828, 366.801}, {621.531, 366.4959999999999}, {
                    619.4219999999999, 368.117}, {619.117, 370.414}, {
                    618.8159999999999, 372.715}, {620.434, 374.824}, {622.734,
                     375.129}, {625.031, 375.42999999999995`}, {627.145, 
                    373.812}, {627.4449999999999, 371.512}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    561.742, 278.863}, {551.477, 328.289}, {542.484, 
                    350.727}, {545.914, 326.801}}}]}}, AspectRatio -> 
                  Automatic, ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 1080.}, {0., 720.}}], ",", 
                 GraphicsBox[{
                   Thickness[0.0007936507936507937], {
                    FaceForm[{
                    RGBColor[
                    0.13725500000000002`, 0.623529, 0.25098000000000004`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 720.}, {1260., 720.}, {1260., 0.}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     480.}, {1260., 480.}, {1260., 240.}, {0., 240.}}}]}, {
                    FaceForm[{
                    RGBColor[0.854902, 0., 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     240.}, {1260., 240.}, {1260., 0.}, {0., 0.}}}]}, {
                    RGBColor[1., 1., 1.], 
                    Thickness[0.0044444444444444444`], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}}, {{0, 2, 0}}}, {{{579.602, 516.398}, {
                    646.8009999999999, 516.398}}, {{579.602, 494.}, {579.602, 
                    505.19899999999996`}, {602., 505.19899999999996`}, {602., 
                    494.}, {624.398, 494.}, {624.398, 505.19899999999996`}, {
                    613.1990000000001, 505.19899999999996`}}, {{
                    646.8009999999999, 494.}, {635.602, 494.}, {635.602, 
                    505.19899999999996`}, {658., 505.19899999999996`}, {658., 
                    516.398}}, {{658., 505.19899999999996`}, {658., 494.}, {
                    680.398, 494.}, {680.398, 516.398}}, {{669.1990000000001, 
                    516.398}, {669.1990000000001, 494.}}, {{590.8009999999999,
                     494.}, {590.805, 494.}}}, 
                    CurveClosed -> {0, 0, 0, 0, 0, 0}]}, {
                    RGBColor[1., 1., 1.], 
                    Thickness[0.005312127152597305], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{
                    579.6013999999999, 481.602}, {624.3986, 481.602}}, {{
                    635.6013999999999, 481.602}, {680.3986, 481.602}}}, 
                    CurveClosed -> {0, 0}]}, {
                    RGBColor[1., 1., 1.], 
                    Thickness[0.0044444444444444444`], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}}, {{0, 2, 0}}}, {{{579.602, 226.}, {
                    646.8009999999999, 226.}}, {{579.602, 
                    203.60199999999998`}, {579.602, 214.801}, {602., 
                    214.801}, {602., 203.60199999999998`}, {624.398, 
                    203.60199999999998`}, {624.398, 214.801}, {
                    613.1990000000001, 214.801}}, {{646.8009999999999, 
                    203.60199999999998`}, {635.602, 203.60199999999998`}, {
                    635.602, 214.801}, {658., 214.801}, {658., 226.}}, {{658.,
                     214.801}, {658., 203.60199999999998`}, {680.398, 
                    203.60199999999998`}, {680.398, 226.}}, {{
                    669.1990000000001, 226.}, {669.1990000000001, 
                    203.60199999999998`}}, {{590.8009999999999, 
                    203.60199999999998`}, {590.805, 203.60199999999998`}}}, 
                    CurveClosed -> {0, 0, 0, 0, 0, 0}]}, {
                    RGBColor[1., 1., 1.], 
                    Thickness[0.005312127152597305], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{
                    579.6013999999999, 238.39799999999997`}, {624.3986, 
                    238.39799999999997`}}, {{635.6013999999999, 
                    238.39799999999997`}, {680.3986, 238.39799999999997`}}}, 
                    CurveClosed -> {0, 0}]}, {
                    RGBColor[1., 1., 1.], 
                    Thickness[0.0044444444444444444`], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}}, {{0, 2, 0}}}, {{{691.602, 516.398}, {
                    758.8009999999999, 516.398}}, {{691.602, 494.}, {691.602, 
                    505.19899999999996`}, {714., 505.19899999999996`}, {714., 
                    494.}, {736.398, 494.}, {736.398, 505.19899999999996`}, {
                    725.1990000000001, 505.19899999999996`}}, {{
                    758.8009999999999, 494.}, {747.602, 494.}, {747.602, 
                    505.19899999999996`}, {770., 505.19899999999996`}, {770., 
                    516.398}}, {{770., 505.19899999999996`}, {770., 494.}, {
                    792.398, 494.}, {792.398, 516.398}}, {{781.1990000000001, 
                    516.398}, {781.1990000000001, 494.}}, {{702.8009999999999,
                     494.}, {702.805, 494.}}}, 
                    CurveClosed -> {0, 0, 0, 0, 0, 0}]}, {
                    RGBColor[1., 1., 1.], 
                    Thickness[0.005312127152597305], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{
                    691.6013999999999, 481.602}, {736.3986, 481.602}}, {{
                    747.6013999999999, 481.602}, {792.3986, 481.602}}}, 
                    CurveClosed -> {0, 0}]}, {
                    RGBColor[1., 1., 1.], 
                    Thickness[0.0044444444444444444`], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}}, {{0, 2, 0}}}, {{{691.602, 226.}, {
                    758.8009999999999, 226.}}, {{691.602, 
                    203.60199999999998`}, {691.602, 214.801}, {714., 
                    214.801}, {714., 203.60199999999998`}, {736.398, 
                    203.60199999999998`}, {736.398, 214.801}, {
                    725.1990000000001, 214.801}}, {{758.8009999999999, 
                    203.60199999999998`}, {747.602, 203.60199999999998`}, {
                    747.602, 214.801}, {770., 214.801}, {770., 226.}}, {{770.,
                     214.801}, {770., 203.60199999999998`}, {792.398, 
                    203.60199999999998`}, {792.398, 226.}}, {{
                    781.1990000000001, 226.}, {781.1990000000001, 
                    203.60199999999998`}}, {{702.8009999999999, 
                    203.60199999999998`}, {702.805, 203.60199999999998`}}}, 
                    CurveClosed -> {0, 0, 0, 0, 0, 0}]}, {
                    RGBColor[1., 1., 1.], 
                    Thickness[0.005312127152597305], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{
                    691.6013999999999, 238.39799999999997`}, {736.3986, 
                    238.39799999999997`}}, {{747.6013999999999, 
                    238.39799999999997`}, {792.3986, 238.39799999999997`}}}, 
                    CurveClosed -> {0, 0}]}, {
                    RGBColor[1., 1., 1.], 
                    Thickness[0.0044444444444444444`], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}}, {{0, 2, 0}}}, {{{355.60200000000003`, 
                    516.398}, {422.801, 516.398}}, {{355.60200000000003`, 
                    494.}, {355.60200000000003`, 505.19899999999996`}, {378., 
                    505.19899999999996`}, {378., 494.}, {400.39799999999997`, 
                    494.}, {400.39799999999997`, 505.19899999999996`}, {
                    389.199, 505.19899999999996`}}, {{422.801, 494.}, {
                    411.60200000000003`, 494.}, {411.60200000000003`, 
                    505.19899999999996`}, {434., 505.19899999999996`}, {434., 
                    516.398}}, {{434., 505.19899999999996`}, {434., 494.}, {
                    456.39799999999997`, 494.}, {456.39799999999997`, 
                    516.398}}, {{445.199, 516.398}, {445.199, 494.}}, {{
                    366.801, 494.}, {366.805, 494.}}}, 
                    CurveClosed -> {0, 0, 0, 0, 0, 0}]}, {
                    RGBColor[1., 1., 1.], 
                    Thickness[0.005312127152597305], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{355.6014, 
                    481.602}, {400.3986, 481.602}}, {{411.60139999999996`, 
                    481.602}, {456.3986, 481.602}}}, CurveClosed -> {0, 0}]}, {
                    RGBColor[1., 1., 1.], 
                    Thickness[0.0044444444444444444`], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}}, {{0, 2, 0}}}, {{{355.60200000000003`, 
                    226.}, {422.801, 226.}}, {{355.60200000000003`, 
                    203.60199999999998`}, {355.60200000000003`, 214.801}, {
                    378., 214.801}, {378., 203.60199999999998`}, {
                    400.39799999999997`, 203.60199999999998`}, {
                    400.39799999999997`, 214.801}, {389.199, 214.801}}, {{
                    422.801, 203.60199999999998`}, {411.60200000000003`, 
                    203.60199999999998`}, {411.60200000000003`, 214.801}, {
                    434., 214.801}, {434., 226.}}, {{434., 214.801}, {434., 
                    203.60199999999998`}, {456.39799999999997`, 
                    203.60199999999998`}, {456.39799999999997`, 226.}}, {{
                    445.199, 226.}, {445.199, 203.60199999999998`}}, {{
                    366.801, 203.60199999999998`}, {366.805, 
                    203.60199999999998`}}}, 
                    CurveClosed -> {0, 0, 0, 0, 0, 0}]}, {
                    RGBColor[1., 1., 1.], 
                    Thickness[0.005312127152597305], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{355.6014, 
                    238.39799999999997`}, {400.3986, 238.39799999999997`}}, {{
                    411.60139999999996`, 238.39799999999997`}, {456.3986, 
                    238.39799999999997`}}}, CurveClosed -> {0, 0}]}, {
                    RGBColor[1., 1., 1.], 
                    Thickness[0.0044444444444444444`], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}}, {{0, 2, 0}}}, {{{467.60200000000003`, 
                    516.398}, {534.8009999999999, 516.398}}, {{
                    467.60200000000003`, 494.}, {467.60200000000003`, 
                    505.19899999999996`}, {490., 505.19899999999996`}, {490., 
                    494.}, {512.398, 494.}, {512.398, 505.19899999999996`}, {
                    501.199, 505.19899999999996`}}, {{534.8009999999999, 
                    494.}, {523.602, 494.}, {523.602, 505.19899999999996`}, {
                    546., 505.19899999999996`}, {546., 516.398}}, {{546., 
                    505.19899999999996`}, {546., 494.}, {568.398, 494.}, {
                    568.398, 516.398}}, {{557.1990000000001, 516.398}, {
                    557.1990000000001, 494.}}, {{478.801, 494.}, {478.805, 
                    494.}}}, CurveClosed -> {0, 0, 0, 0, 0, 0}]}, {
                    RGBColor[1., 1., 1.], 
                    Thickness[0.005312127152597305], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{
                    467.60139999999996`, 481.602}, {512.3986, 481.602}}, {{
                    523.6013999999999, 481.602}, {568.3986, 481.602}}}, 
                    CurveClosed -> {0, 0}]}, {
                    RGBColor[1., 1., 1.], 
                    Thickness[0.0044444444444444444`], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}}, {{0, 2, 0}}}, {{{467.60200000000003`, 
                    226.}, {534.8009999999999, 226.}}, {{467.60200000000003`, 
                    203.60199999999998`}, {467.60200000000003`, 214.801}, {
                    490., 214.801}, {490., 203.60199999999998`}, {512.398, 
                    203.60199999999998`}, {512.398, 214.801}, {501.199, 
                    214.801}}, {{534.8009999999999, 203.60199999999998`}, {
                    523.602, 203.60199999999998`}, {523.602, 214.801}, {546., 
                    214.801}, {546., 226.}}, {{546., 214.801}, {546., 
                    203.60199999999998`}, {568.398, 203.60199999999998`}, {
                    568.398, 226.}}, {{557.1990000000001, 226.}, {
                    557.1990000000001, 203.60199999999998`}}, {{478.801, 
                    203.60199999999998`}, {478.805, 203.60199999999998`}}}, 
                    CurveClosed -> {0, 0, 0, 0, 0, 0}]}, {
                    RGBColor[1., 1., 1.], 
                    Thickness[0.005312127152597305], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{
                    467.60139999999996`, 238.39799999999997`}, {512.3986, 
                    238.39799999999997`}}, {{523.6013999999999, 
                    238.39799999999997`}, {568.3986, 238.39799999999997`}}}, 
                    CurveClosed -> {0, 0}]}, {
                    RGBColor[1., 1., 1.], 
                    Thickness[0.0044444444444444444`], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}}, {{0, 2, 0}}}, {{{1027.6019999999999`, 
                    516.398}, {1094.801, 516.398}}, {{1027.6019999999999`, 
                    494.}, {1027.6019999999999`, 505.19899999999996`}, {1050.,
                     505.19899999999996`}, {1050., 494.}, {1072.398, 494.}, {
                    1072.398, 505.19899999999996`}, {1061.1989999999998`, 
                    505.19899999999996`}}, {{1094.801, 494.}, {
                    1083.6019999999999`, 494.}, {1083.6019999999999`, 
                    505.19899999999996`}, {1106., 505.19899999999996`}, {
                    1106., 516.398}}, {{1106., 505.19899999999996`}, {1106., 
                    494.}, {1128.398, 494.}, {1128.398, 516.398}}, {{
                    1117.1989999999998`, 516.398}, {1117.1989999999998`, 
                    494.}}, {{1038.801, 494.}, {1038.805, 494.}}}, 
                    CurveClosed -> {0, 0, 0, 0, 0, 0}]}, {
                    RGBColor[1., 1., 1.], 
                    Thickness[0.005312127152597305], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{1027.6014, 
                    481.602}, {1072.3986, 481.602}}, {{1083.6013999999998`, 
                    481.602}, {1128.3986, 481.602}}}, 
                    CurveClosed -> {0, 0}]}, {
                    RGBColor[1., 1., 1.], 
                    Thickness[0.0044444444444444444`], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}}, {{0, 2, 0}}}, {{{1027.6019999999999`, 
                    226.}, {1094.801, 226.}}, {{1027.6019999999999`, 
                    203.60199999999998`}, {1027.6019999999999`, 214.801}, {
                    1050., 214.801}, {1050., 203.60199999999998`}, {1072.398, 
                    203.60199999999998`}, {1072.398, 214.801}, {
                    1061.1989999999998`, 214.801}}, {{1094.801, 
                    203.60199999999998`}, {1083.6019999999999`, 
                    203.60199999999998`}, {1083.6019999999999`, 214.801}, {
                    1106., 214.801}, {1106., 226.}}, {{1106., 214.801}, {
                    1106., 203.60199999999998`}, {1128.398, 
                    203.60199999999998`}, {1128.398, 226.}}, {{
                    1117.1989999999998`, 226.}, {1117.1989999999998`, 
                    203.60199999999998`}}, {{1038.801, 203.60199999999998`}, {
                    1038.805, 203.60199999999998`}}}, 
                    CurveClosed -> {0, 0, 0, 0, 0, 0}]}, {
                    RGBColor[1., 1., 1.], 
                    Thickness[0.005312127152597305], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{1027.6014, 
                    238.39799999999997`}, {1072.3986, 
                    238.39799999999997`}}, {{1083.6013999999998`, 
                    238.39799999999997`}, {1128.3986, 238.39799999999997`}}}, 
                    CurveClosed -> {0, 0}]}, {
                    RGBColor[1., 1., 1.], 
                    Thickness[0.0044444444444444444`], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}}, {{0, 2, 0}}}, {{{1139.6019999999999`, 
                    516.398}, {1206.801, 516.398}}, {{1139.6019999999999`, 
                    494.}, {1139.6019999999999`, 505.19899999999996`}, {1162.,
                     505.19899999999996`}, {1162., 494.}, {1184.398, 494.}, {
                    1184.398, 505.19899999999996`}, {1173.1989999999998`, 
                    505.19899999999996`}}, {{1206.801, 494.}, {
                    1195.6019999999999`, 494.}, {1195.6019999999999`, 
                    505.19899999999996`}, {1218., 505.19899999999996`}, {
                    1218., 516.398}}, {{1218., 505.19899999999996`}, {1218., 
                    494.}, {1240.398, 494.}, {1240.398, 516.398}}, {{
                    1229.1989999999998`, 516.398}, {1229.1989999999998`, 
                    494.}}, {{1150.801, 494.}, {1150.805, 494.}}}, 
                    CurveClosed -> {0, 0, 0, 0, 0, 0}]}, {
                    RGBColor[1., 1., 1.], 
                    Thickness[0.005312127152597305], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{
                    1139.6013999999998`, 481.602}, {1184.3986, 481.602}}, {{
                    1195.6013999999998`, 481.602}, {1240.3986, 481.602}}}, 
                    CurveClosed -> {0, 0}]}, {
                    RGBColor[1., 1., 1.], 
                    Thickness[0.0044444444444444444`], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}}, {{0, 2, 0}}}, {{{1139.6019999999999`, 
                    226.}, {1206.801, 226.}}, {{1139.6019999999999`, 
                    203.60199999999998`}, {1139.6019999999999`, 214.801}, {
                    1162., 214.801}, {1162., 203.60199999999998`}, {1184.398, 
                    203.60199999999998`}, {1184.398, 214.801}, {
                    1173.1989999999998`, 214.801}}, {{1206.801, 
                    203.60199999999998`}, {1195.6019999999999`, 
                    203.60199999999998`}, {1195.6019999999999`, 214.801}, {
                    1218., 214.801}, {1218., 226.}}, {{1218., 214.801}, {
                    1218., 203.60199999999998`}, {1240.398, 
                    203.60199999999998`}, {1240.398, 226.}}, {{
                    1229.1989999999998`, 226.}, {1229.1989999999998`, 
                    203.60199999999998`}}, {{1150.801, 203.60199999999998`}, {
                    1150.805, 203.60199999999998`}}}, 
                    CurveClosed -> {0, 0, 0, 0, 0, 0}]}, {
                    RGBColor[1., 1., 1.], 
                    Thickness[0.005312127152597305], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{
                    1139.6013999999998`, 238.39799999999997`}, {1184.3986, 
                    238.39799999999997`}}, {{1195.6013999999998`, 
                    238.39799999999997`}, {1240.3986, 238.39799999999997`}}}, 
                    CurveClosed -> {0, 0}]}, {
                    RGBColor[1., 1., 1.], 
                    Thickness[0.0044444444444444444`], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}}, {{0, 2, 0}}}, {{{803.602, 516.398}, {
                    870.8009999999999, 516.398}}, {{803.602, 494.}, {803.602, 
                    505.19899999999996`}, {826., 505.19899999999996`}, {826., 
                    494.}, {848.398, 494.}, {848.398, 505.19899999999996`}, {
                    837.1990000000001, 505.19899999999996`}}, {{
                    870.8009999999999, 494.}, {859.602, 494.}, {859.602, 
                    505.19899999999996`}, {882., 505.19899999999996`}, {882., 
                    516.398}}, {{882., 505.19899999999996`}, {882., 494.}, {
                    904.398, 494.}, {904.398, 516.398}}, {{893.1990000000001, 
                    516.398}, {893.1990000000001, 494.}}, {{814.8009999999999,
                     494.}, {814.805, 494.}}}, 
                    CurveClosed -> {0, 0, 0, 0, 0, 0}]}, {
                    RGBColor[1., 1., 1.], 
                    Thickness[0.005312127152597305], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{
                    803.6013999999999, 481.602}, {848.3986, 481.602}}, {{
                    859.6013999999999, 481.602}, {904.3986, 481.602}}}, 
                    CurveClosed -> {0, 0}]}, {
                    RGBColor[1., 1., 1.], 
                    Thickness[0.0044444444444444444`], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}}, {{0, 2, 0}}}, {{{803.602, 226.}, {
                    870.8009999999999, 226.}}, {{803.602, 
                    203.60199999999998`}, {803.602, 214.801}, {826., 
                    214.801}, {826., 203.60199999999998`}, {848.398, 
                    203.60199999999998`}, {848.398, 214.801}, {
                    837.1990000000001, 214.801}}, {{870.8009999999999, 
                    203.60199999999998`}, {859.602, 203.60199999999998`}, {
                    859.602, 214.801}, {882., 214.801}, {882., 226.}}, {{882.,
                     214.801}, {882., 203.60199999999998`}, {904.398, 
                    203.60199999999998`}, {904.398, 226.}}, {{
                    893.1990000000001, 226.}, {893.1990000000001, 
                    203.60199999999998`}}, {{814.8009999999999, 
                    203.60199999999998`}, {814.805, 203.60199999999998`}}}, 
                    CurveClosed -> {0, 0, 0, 0, 0, 0}]}, {
                    RGBColor[1., 1., 1.], 
                    Thickness[0.005312127152597305], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{
                    803.6013999999999, 238.39799999999997`}, {848.3986, 
                    238.39799999999997`}}, {{859.6013999999999, 
                    238.39799999999997`}, {904.3986, 238.39799999999997`}}}, 
                    CurveClosed -> {0, 0}]}, {
                    RGBColor[1., 1., 1.], 
                    Thickness[0.0044444444444444444`], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}}, {{0, 2, 0}}}, {{{915.602, 516.398}, {
                    982.8009999999999, 516.398}}, {{915.602, 494.}, {915.602, 
                    505.19899999999996`}, {938., 505.19899999999996`}, {938., 
                    494.}, {960.398, 494.}, {960.398, 505.19899999999996`}, {
                    949.1990000000001, 505.19899999999996`}}, {{
                    982.8009999999999, 494.}, {971.602, 494.}, {971.602, 
                    505.19899999999996`}, {994., 505.19899999999996`}, {994., 
                    516.398}}, {{994., 505.19899999999996`}, {994., 494.}, {
                    1016.398, 494.}, {1016.398, 516.398}}, {{
                    1005.1990000000001`, 516.398}, {1005.1990000000001`, 
                    494.}}, {{926.8009999999999, 494.}, {926.805, 494.}}}, 
                    CurveClosed -> {0, 0, 0, 0, 0, 0}]}, {
                    RGBColor[1., 1., 1.], 
                    Thickness[0.005312127152597305], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{
                    915.6013999999999, 481.602}, {960.3986, 481.602}}, {{
                    971.6013999999999, 481.602}, {1016.3986, 481.602}}}, 
                    CurveClosed -> {0, 0}]}, {
                    RGBColor[1., 1., 1.], 
                    Thickness[0.0044444444444444444`], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}}, {{0, 2, 0}}}, {{{915.602, 226.}, {
                    982.8009999999999, 226.}}, {{915.602, 
                    203.60199999999998`}, {915.602, 214.801}, {938., 
                    214.801}, {938., 203.60199999999998`}, {960.398, 
                    203.60199999999998`}, {960.398, 214.801}, {
                    949.1990000000001, 214.801}}, {{982.8009999999999, 
                    203.60199999999998`}, {971.602, 203.60199999999998`}, {
                    971.602, 214.801}, {994., 214.801}, {994., 226.}}, {{994.,
                     214.801}, {994., 203.60199999999998`}, {1016.398, 
                    203.60199999999998`}, {1016.398, 226.}}, {{
                    1005.1990000000001`, 226.}, {1005.1990000000001`, 
                    203.60199999999998`}}, {{926.8009999999999, 
                    203.60199999999998`}, {926.805, 203.60199999999998`}}}, 
                    CurveClosed -> {0, 0, 0, 0, 0, 0}]}, {
                    RGBColor[1., 1., 1.], 
                    Thickness[0.005312127152597305], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{
                    915.6013999999999, 238.39799999999997`}, {960.3986, 
                    238.39799999999997`}}, {{971.6013999999999, 
                    238.39799999999997`}, {1016.3986, 238.39799999999997`}}}, 
                    CurveClosed -> {0, 0}]}, {
                    RGBColor[1., 1., 1.], 
                    Thickness[0.0044444444444444444`], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}}, {{0, 2, 0}}}, {{{243.602, 516.398}, {
                    310.801, 516.398}}, {{243.602, 494.}, {243.602, 
                    505.19899999999996`}, {266., 505.19899999999996`}, {266., 
                    494.}, {288.39799999999997`, 494.}, {288.39799999999997`, 
                    505.19899999999996`}, {277.199, 505.19899999999996`}}, {{
                    310.801, 494.}, {299.60200000000003`, 494.}, {
                    299.60200000000003`, 505.19899999999996`}, {322., 
                    505.19899999999996`}, {322., 516.398}}, {{322., 
                    505.19899999999996`}, {322., 494.}, {344.39799999999997`, 
                    494.}, {344.39799999999997`, 516.398}}, {{333.199, 
                    516.398}, {333.199, 494.}}, {{254.80100000000002`, 
                    494.}, {254.805, 494.}}}, 
                    CurveClosed -> {0, 0, 0, 0, 0, 0}]}, {
                    RGBColor[1., 1., 1.], 
                    Thickness[0.005312127152597305], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{
                    243.60139999999998`, 481.602}, {288.39859999999993`, 
                    481.602}}, {{299.6014, 481.602}, {344.39859999999993`, 
                    481.602}}}, CurveClosed -> {0, 0}]}, {
                    RGBColor[1., 1., 1.], 
                    Thickness[0.0044444444444444444`], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}}, {{0, 2, 0}}}, {{{243.602, 226.}, {
                    310.801, 226.}}, {{243.602, 203.60199999999998`}, {
                    243.602, 214.801}, {266., 214.801}, {266., 
                    203.60199999999998`}, {288.39799999999997`, 
                    203.60199999999998`}, {288.39799999999997`, 214.801}, {
                    277.199, 214.801}}, {{310.801, 203.60199999999998`}, {
                    299.60200000000003`, 203.60199999999998`}, {
                    299.60200000000003`, 214.801}, {322., 214.801}, {322., 
                    226.}}, {{322., 214.801}, {322., 203.60199999999998`}, {
                    344.39799999999997`, 203.60199999999998`}, {
                    344.39799999999997`, 226.}}, {{333.199, 226.}, {333.199, 
                    203.60199999999998`}}, {{254.80100000000002`, 
                    203.60199999999998`}, {254.805, 203.60199999999998`}}}, 
                    CurveClosed -> {0, 0, 0, 0, 0, 0}]}, {
                    RGBColor[1., 1., 1.], 
                    Thickness[0.005312127152597305], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{
                    243.60139999999998`, 238.39799999999997`}, {
                    288.39859999999993`, 238.39799999999997`}}, {{299.6014, 
                    238.39799999999997`}, {344.39859999999993`, 
                    238.39799999999997`}}}, CurveClosed -> {0, 0}]}, {
                    RGBColor[1., 1., 1.], 
                    Thickness[0.0044444444444444444`], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}}, {{0, 2, 0}}}, {{{19.602, 516.398}, {
                    86.801, 516.398}}, {{19.602, 494.}, {19.602, 
                    505.19899999999996`}, {42., 505.19899999999996`}, {42., 
                    494.}, {64.398, 494.}, {64.398, 505.19899999999996`}, {
                    53.199000000000005`, 505.19899999999996`}}, {{86.801, 
                    494.}, {75.60199999999999, 494.}, {75.60199999999999, 
                    505.19899999999996`}, {98., 505.19899999999996`}, {98., 
                    516.398}}, {{98., 505.19899999999996`}, {98., 494.}, {
                    120.398, 494.}, {120.398, 516.398}}, {{109.199, 
                    516.398}, {109.199, 494.}}, {{30.801000000000002`, 
                    494.}, {30.805, 494.}}}, 
                    CurveClosed -> {0, 0, 0, 0, 0, 0}]}, {
                    RGBColor[1., 1., 1.], 
                    Thickness[0.005312127152597305], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{
                    19.601399999999998`, 481.602}, {64.3986, 481.602}}, {{
                    75.6014, 481.602}, {120.3986, 481.602}}}, 
                    CurveClosed -> {0, 0}]}, {
                    RGBColor[1., 1., 1.], 
                    Thickness[0.0044444444444444444`], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}}, {{0, 2, 0}}}, {{{19.602, 226.}, {86.801,
                     226.}}, {{19.602, 203.60199999999998`}, {19.602, 
                    214.801}, {42., 214.801}, {42., 203.60199999999998`}, {
                    64.398, 203.60199999999998`}, {64.398, 214.801}, {
                    53.199000000000005`, 214.801}}, {{86.801, 
                    203.60199999999998`}, {75.60199999999999, 
                    203.60199999999998`}, {75.60199999999999, 214.801}, {98., 
                    214.801}, {98., 226.}}, {{98., 214.801}, {98., 
                    203.60199999999998`}, {120.398, 203.60199999999998`}, {
                    120.398, 226.}}, {{109.199, 226.}, {109.199, 
                    203.60199999999998`}}, {{30.801000000000002`, 
                    203.60199999999998`}, {30.805, 203.60199999999998`}}}, 
                    CurveClosed -> {0, 0, 0, 0, 0, 0}]}, {
                    RGBColor[1., 1., 1.], 
                    Thickness[0.005312127152597305], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{
                    19.601399999999998`, 238.39799999999997`}, {64.3986, 
                    238.39799999999997`}}, {{75.6014, 238.39799999999997`}, {
                    120.3986, 238.39799999999997`}}}, 
                    CurveClosed -> {0, 0}]}, {
                    RGBColor[1., 1., 1.], 
                    Thickness[0.0044444444444444444`], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}}, {{0, 2, 0}}}, {{{131.602, 516.398}, {
                    198.80100000000002`, 516.398}}, {{131.602, 494.}, {
                    131.602, 505.19899999999996`}, {154., 
                    505.19899999999996`}, {154., 494.}, {176.39800000000002`, 
                    494.}, {176.39800000000002`, 505.19899999999996`}, {
                    165.19899999999998`, 505.19899999999996`}}, {{
                    198.80100000000002`, 494.}, {187.602, 494.}, {187.602, 
                    505.19899999999996`}, {210., 505.19899999999996`}, {210., 
                    516.398}}, {{210., 505.19899999999996`}, {210., 494.}, {
                    232.39800000000002`, 494.}, {232.39800000000002`, 
                    516.398}}, {{221.19899999999998`, 516.398}, {
                    221.19899999999998`, 494.}}, {{142.80100000000002`, 
                    494.}, {142.805, 494.}}}, 
                    CurveClosed -> {0, 0, 0, 0, 0, 0}]}, {
                    RGBColor[1., 1., 1.], 
                    Thickness[0.005312127152597305], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{131.6014, 
                    481.602}, {176.39860000000002`, 481.602}}, {{
                    187.60139999999998`, 481.602}, {232.39859999999993`, 
                    481.602}}}, CurveClosed -> {0, 0}]}, {
                    RGBColor[1., 1., 1.], 
                    Thickness[0.0044444444444444444`], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1,
                     0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}}, {{0, 2, 0}}}, {{{131.602, 226.}, {
                    198.80100000000002`, 226.}}, {{131.602, 
                    203.60199999999998`}, {131.602, 214.801}, {154., 
                    214.801}, {154., 203.60199999999998`}, {
                    176.39800000000002`, 203.60199999999998`}, {
                    176.39800000000002`, 214.801}, {165.19899999999998`, 
                    214.801}}, {{198.80100000000002`, 203.60199999999998`}, {
                    187.602, 203.60199999999998`}, {187.602, 214.801}, {210., 
                    214.801}, {210., 226.}}, {{210., 214.801}, {210., 
                    203.60199999999998`}, {232.39800000000002`, 
                    203.60199999999998`}, {232.39800000000002`, 226.}}, {{
                    221.19899999999998`, 226.}, {221.19899999999998`, 
                    203.60199999999998`}}, {{142.80100000000002`, 
                    203.60199999999998`}, {142.805, 203.60199999999998`}}}, 
                    CurveClosed -> {0, 0, 0, 0, 0, 0}]}, {
                    RGBColor[1., 1., 1.], 
                    Thickness[0.005312127152597305], 
                    Opacity[1.], 
                    CapForm["Round"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{0, 2, 0}}, {{0, 2, 0}}}, {{{131.6014, 
                    238.39799999999997`}, {176.39860000000002`, 
                    238.39799999999997`}}, {{187.60139999999998`, 
                    238.39799999999997`}, {232.39859999999993`, 
                    238.39799999999997`}}}, CurveClosed -> {0, 0}]}, {
                    FaceForm[{
                    RGBColor[0.854902, 0., 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{666.664, 
                    424.33599999999996`}, {666.664, 424.33599999999996`}, {
                    731.7850000000001, 373.40999999999997`}, {683.918, 
                    300.22299999999996`}, {729., 327.77299999999997`}, {
                    732.895, 403.53499999999997`}, {666.664, 
                    424.33599999999996`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{630., 431.57}, {619.637, 419.883}, {601.824, 
                    431.504}, {607.9449999999999, 444.234}, {618.66, 
                    425.03099999999995`}, {630., 440.547}, {630., 440.547}, {
                    630., 440.547}, {641.3399999999999, 
                    425.03099999999995`}, {652.055, 444.234}, {
                    658.1800000000001, 431.504}, {640.3669999999998, 
                    419.883}, {630., 431.57}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJtIGZigIINzQ6trwN3yPEXOmz7/PdKRUmzQ+7z3ys/
rsLkv19+zNv8RZODHdf1xQW+hQ5HFDYUZeg3ORz6qhHTf67QocMx4emFYwg+
WF662QFsD0sRRNyq2aF833wpfWVMvhzIIY8bHabnCTUfmFLs4GPe6ZjwqtEh
Y+LbGvvWMgdbkL3/Gh22nCjbN7+u0qHypZohx8kmh6sVQEZaFUG+N8i8hEYI
7V3m8AHknyKo/+8WOSwuANoQ1ewAcvZE6XI43wpkoWWVwzTn7pznFc0Q8zyq
HGDhN1mCJYzvOGF+1p6SyRLPEfpj+oEhwNoCNx/Gh9kvGGG55cRbhPvA/v7f
Cnd/u9jNc9+ntTgcAwkA/UeIfxgU3omtkPAFhp/Nff/e6aWtDlEp1vf9geH7
sEpknXtNq0MnKB6B4X8U5BDVFkj4A+MHnQ82z6XF4dMl3yQBYPyC43FmC8Sd
wPgHyxu0wvlg/5S3OBjcVWFrBKYfTx4m7fbXzQ5xu4Cs1Zh8sPvXQ9MHMH0C
AGVtMXs=
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}}}, {{{
                    593.3399999999999, 424.33599999999996`}, {
                    593.3399999999999, 424.33599999999996`}, {528.219, 
                    373.40999999999997`}, {576.086, 300.22299999999996`}, {
                    531., 327.77299999999997`}, {527.102, 
                    403.53499999999997`}, {593.3399999999999, 
                    424.33599999999996`}}}]}}, AspectRatio -> Automatic, 
                  ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 1260.}, {0., 720.}}], ",", 
                 GraphicsBox[{
                   Thickness[0.001388888888888889], {
                    FaceForm[{
                    RGBColor[
                    0.8078430000000001, 0.06666670000000002, 0.14902], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     480.}, {720., 480.}, {720., 320.}, {0., 320.}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     320.}, {720., 320.}, {720., 160.}, {0., 160.}}}]}, {
                    Thickness[0.001388888888888889], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     160.}, {720., 160.}, {720., 0.}, {0., 0.}}}]}, {
                    FaceForm[{
                    RGBColor[0., 0.478431, 0.23921600000000004`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{218.918, 
                    180.562}, {214.781, 185.102}, {223.13299999999998`, 
                    194.102}, {227.26999999999998`, 189.562}, {231.406, 
                    185.02}, {223.055, 176.02}, {218.92200000000003`, 
                    180.57}}, CompressedData["
1:eJxlVQ1olVUYvpqOMce1plmm2UxbUsawJWEiveXC9pOmwzVMxIbd7+d8937n
O99Wq9lIRpmV3o2MnCZOLxs1NYeVmKitFWUqNoRh+7mpSNiQFhplIkHnnOd0
L9SFy8fznfe873Oe5z3vN7PWX/Hi2Egk0ij/6tl19ewztX0WFeVseH/xUIyG
bjS5R9stun9e7r7pozESduuv66ss2vJBoqB5rkVf7rqrOF1oEV+Udy5lW1Tx
6KYn1n4VownnUnzRoEXV0YcO7twbo/tUvok2PfbZiZeOX4lR6Tve5ZsjFrX0
/jFndYVFeSr+oEWDql6ujXpbLPpOJay0qe9eyaTT1Ct1wCtiU6Wq95pDf85Z
nex1HHp18idLLh6yaZuk17PUpbtXrVt4PmmDR6NLEfXjNt4fyGId35vFOl+/
i/O02fTGleWHZ9ww66dtvL+NUaOqV+BAlxJGxenZORvmO9CjxqzXOjj/pwz8
Wwye6NECpUfK4FkeDZy5XnXpi+y6zjfggN81Rpc6dnxTWOoiLu1msPbtoyzW
z3dd7HNdOlb33p3j3nRJ0Xx8KstgrftoFu956tDvf59mNKz0HTb7jzD4nc8o
UOf60KxXMvj0NqNQJWaGn8fgy04GvTwT18ng71sm31FGZ5Wv2xn65aTRr59R
UvXFdQafJnjwu9AD3yc9xJd74Ftn3jd54Lfeo80q/1YPvJIe/D/lgdf4OOq6
cfT5tCzW/sz+D54bB4+vvQzWffkXy+B/9Ts8Q3bKifB/WOvYlUDfpEKcfzhB
0o35a5pCPKM++qUmhI59Jr4kxH1pzWLNZ4fpr3FBBuu+SfkZrOvsi8OH9izW
/dyRxbov9jPo9qNPk5p7Tu5OJ6i/YaRoXpTDlwU+4m7n0LnSJxXeU2Tw6z78
eIQj/34Tv5jjPg349ODGKQNnlnN6+qK8qWM41ldycw5O8nQ/99Vwuibb+dZc
Ti8flwJbZn06x/nrTf4Sw6uZkyrPy8y+rRxz5gWDt5s8Doeu7ZzU8i5u6kn9
dN5bjI6vBKQeyw4EmCejAXg+L7B/haBv1YZfBJ1fJhWrFtQpX3dLrH1eJUi6
Xx0dEci/VtCaI2X5Y4cEfFgnqLBbTozvBc1Uz3qz3zZxzYIuqLwPC4pfvvnx
1RYBvpNN3B6BeSh56f7aZvhcMLwdQYpm908BeFQJUu3/WzrAvLlHQLe2ALoV
B1Sg/F5odGzluBd7E6SuYVL6/7mq/0AcPPI5+qQwjvd5HP07JY56bRz3PWr6
rCzIYO3DJpHBWneJtc45CdSX+DlFOJlAvs2CRlX+PB/naxWYt3f42N8hUGel
6b+GEHEVHOfdGCLPEm70DOFbKTc+hOj3qRx+jK9DH/zg43yizsyJLNbrkxzU
rXczWPv7rIu4JhtzbJaLfjxlYa4MOlgvN9/NBvP9GmO+l9MczPdjMcSX24jv
ihleFuaa/D7/A9PgVSI=
                    "], CompressedData["
1:eJxTTMoPSmViYGCQB2IQrbChKGPi8xIHoeYDpxYezXWA8atE1rk/bCtwmCzB
Esb3usThbY29aZxdIYT/ucRBq13s5jnnQgdbruuLC36WODxeOvuIgkehQ+7z
3ys/ipRC+EaFDse8zTsdDUod4nZ58jAJF0LM9y51kI1Ksb7/ucDhasVLNcMa
KP9ggcN9/97peXNKHfh0N819v7jAIWMi0ObzpQ5bTpTtm19S4HDoq0ZM/xWo
+uwCh2qQO4+UOujfVWFrTCxwuKB0+2fdhFKHHJA77AoctEHunFgKoT0R/EWu
2z7/LcmF88Hmt2VBwuE7gv/pkm+SQFAZnD8jD6giqczBB+ithN4siHt6yiDi
h7Ig9h8oc9g/X0r/Lks2xB+HyyDh8SfL4TgoPFZB+RVZEHMXlEHC2y0L4q+p
ZRB/P82EqJ9U5qDK1jjVeX6mgyVIQ3eZAwMIKGQ6CIPcu7MUQktmwuOvH+Qw
YQQfHH/Hch0AiJroxA==
                    "]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{0, 2, 0}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {CompressedData["
1:eJxlUltIFGEUXiQ2iDCpzSTMVrsQUW0iS1lsHukhTGGxy4bW6hJGtc7O/DNF
NZc1TCyFIsJiBdFNwqCHZDMDidzEwi6QuA9hEmUiIV0WKaiQemjOnHHmwYfh
55v//Od83/m+/OPCgRMZDocD9A/P4v6X55JFMgQyt/Z1loehum73pL9YhsGz
bTmLuuqhfEdraahMhvdzDeEnWRx88l+L8Zdk+L3p2PXhKAdprcRb0yvDiqah
190pDs4n46s9aZnezXGAbWe9CpSGPo8VzHIwie85BaRTN9LaDAf7phRXr6DA
xOifg9NiBDZfyZ4YPaMAXpfk8zD8Sx+k169BYrU87EK+lQqkCnRGEg/uhN6p
UAHmWzJ+p4WH6Z6O5+6dCs1P8dD8rXIgr1YB/Zb5nAK8vfBlY6GkwAsscAsQ
mfl778dtc74sAId4RCE9b8z77wq088ubhrIY8VumQs3jsqUZRYz0u2xs1OfY
GOkkclXSu0qw8CNdRrwhYuENzsZbe2Nh4te3EBu6bkYsPJCnK8tmaKPDkVBp
7n5GurtVaMWFVzOqbzdxHaM+V1XQ3Q1kRkx+l20cQ528jQ1/Lqq05w4Gng/r
nY1xlXx+wOAZ+jPPL8no3ZQKd7HvVwYtONepwQgSc4kwhr5t0chPn0h8/Rr1
C4pUd0ij3FSJ1K9KI54BEwc1MHJbzyx8BB/EeQvP78/g93MhNvpxIuQij3Fz
XrNIPF5p5HObiQc12I66e2xs5PO+jY3994uUh48a5fydCEHMweIo7eefSHv0
RKn/WonyeTRK/lRI9P+kWR+SyOeuKGC82UMJ9uDZGSXeT21s9FkpWPgwClp3
mva/TbawkWuvTLmpCMN/ybjHEQ==
                    "], {{423.09799999999996`, 
                    217.445}, {423.09799999999996`, 222.164}, {
                    420.47999999999996`, 222.164}, {416.965, 222.164}, {
                    413.754, 218.848}, {413.754, 215.21099999999998`}, {
                    413.754, 212.727}, {423.09799999999996`, 212.727}, {
                    423.09799999999996`, 217.441}}, CompressedData["
1:eJxTTMoPSmViYGBQBGIQHbfLk4dJuM7hm0ZM/6GbuQ4w/kWl2z/rJhU4XADR
YnUOM/KEmg94FToc+gpUKFfncLXipZphQKFD7vPfKz+q1EHUhRQ6bDlRtm++
Q53Dff/e6Xl2hQ4MIBBT51C+b76Uvnyhg7d5p2NCeZ0Dr+6mue//F0DMWVHn
YAXSeBZq34k6B/eHVSLr1hc4KGwoypj4G2pfQ4FDtcg694cM9Q62XNcXF5QX
OLS+Dtwh97HOYZHrts9/cwog7ttT53AcZJFXgYNsVIr1/b11EHWhCH4ByICO
XDhfla1xqvP0LIg9avVwPtC1Ty+0IPhgcyfVO+wHeufunCyIv7bXOwBd+bbm
cpaDIsi9Z+sdgL4Xav6SBQnHR/UON899D37MmQ3x59N6iD+YsiHh96Ie4o7f
WRB3Pq6HhNPJLIi6G/XQ+MiC+O9cvUMYHzAAo6HqD9c7+IDUf8100L+rwta4
v94B5Gyl9ZkQ9++Aul8/E2KfEDQ+lRB8dUOONTK3ch0AX6j2uw==
                    
                    "], CompressedData["
1:eJxTTMoPSmViYGBQBGIQ/Xjp7CMKp6ocqkXWuT9MKXSISrG+77+9yuFtjb1p
XE6hg3DzgVMLF1Y5eDysEllXWejw6ZJvksCsKod3IPmmQof7/r3T8/qqHNxB
8v2FDse8zTsdp1Q5LHLd9vnvBKj8viqHByC6qxCij6vaAWTthrpCh9znv1d+
tIDyewodMiYCbU6udgC7aw9Uf0e1g3a72M1zTwsdrla8VDPcA+VfLHRYBtJ3
o9qhCuT+Y4UQd3+rdjj0VSOm/0Chww651teB/6odZEEeO1wI8adQjcMFpds/
685A/WNRA1HPUwRRb1IDcb9CkYMWyB79Goh+yyKHTseEpxdcaiD6zIog7gis
gfhfugji/uwaB17dTXPfPy90YACBsBpIuCyDhq9qjcNxEH9SoYMd1/XFBbw1
UH8i3A/2J5BvueVE2b7z1Q5AV+2Qmwj1z4JqiHlzCiHunlHtMFmCJYxvNlR9
M9S/rdDwDK2GmBsG1c9XDYlPT2h4AuN/ep5Q8wFg/AMAyiz3BA==
                    
                    "], {{436.72299999999996`, 290.289}, {435.117, 291.484}, {
                    431.72299999999996`, 297.59799999999996`}, {431.594, 
                    299.543}, {431.47999999999996`, 301.21099999999996`}, {
                    431.754, 301.72299999999996`}, {432.84400000000005`, 
                    301.895}, {434.754, 302.191}, {435.633, 300.809}, {
                    437.10200000000003`, 295.22299999999996`}, {438.305, 
                    290.64500000000004`}, {438.18, 289.199}, {436.727, 
                    290.289}}}]}}, AspectRatio -> Automatic, 
                  ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 720.}, {0., 480.}}], ",", 
                 GraphicsBox[{
                   Thickness[0.001388888888888889], {
                    Thickness[0.001388888888888889], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 480.}, {720., 480.}, {720., 0.}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     480.}, {720., 480.}, {720., 160.}, {0., 160.}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.8078430000000001, 0.06666670000000002, 0.14902], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     480.}, {720., 480.}, {720., 320.}, {0., 320.}}}]}, {
                    FaceForm[{
                    RGBColor[0., 0.478431, 0.23921600000000004`], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{216., 292.}, {
                    199.93, 242.547}, {230.363, 232.656}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{216., 292.}, {
                    232.07, 242.547}, {201.637, 232.656}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{265.453, 
                    256.07}, {213.453, 256.07}, {213.453, 224.07}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{265.453, 
                    256.07}, {223.38700000000003`, 225.504}, {204.578, 
                    251.395}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{166.547, 
                    256.07}, {208.61299999999997`, 225.504}, {
                    227.42200000000003`, 251.395}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{166.547, 
                    256.07}, {218.547, 256.07}, {218.547, 224.07}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{246.566, 
                    197.93}, {230.496, 247.38700000000003`}, {200.062, 
                    237.496}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{246.566, 
                    197.93}, {204.496, 228.496}, {223.305, 254.383}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{185.434, 
                    197.93}, {227.504, 228.496}, {208.695, 254.383}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{185.434, 
                    197.93}, {201.504, 247.38700000000003`}, {
                    231.93800000000002`, 237.496}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{504., 292.}, {
                    487.92999999999995`, 242.547}, {518.3629999999999, 
                    232.656}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{504., 292.}, {
                    520.07, 242.547}, {489.637, 232.656}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{553.453, 
                    256.07}, {501.453, 256.07}, {501.453, 224.07}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{553.453, 
                    256.07}, {511.387, 225.504}, {492.578, 251.395}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{454.547, 
                    256.07}, {496.613, 225.504}, {515.4219999999999, 
                    251.395}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{454.547, 
                    256.07}, {506.547, 256.07}, {506.547, 224.07}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    534.5659999999999, 197.93}, {518.496, 
                    247.38700000000003`}, {488.062, 237.496}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    534.5659999999999, 197.93}, {492.4959999999999, 
                    228.496}, {511.305, 254.383}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    473.43399999999997`, 197.93}, {515.504, 228.496}, {
                    496.695, 254.383}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}}}, {{{
                    473.43399999999997`, 197.93}, {489.504, 
                    247.38700000000003`}, {519.938, 237.496}}}]}}, 
                  AspectRatio -> Automatic, ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 720.}, {0., 480.}}], ",", 
                 GraphicsBox[{
                   Thickness[0.0010416666666666667`], {
                    FaceForm[{
                    RGBColor[0., 0.4, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 480.}, {960., 480.}, {960., 0.}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     480.}, {960., 480.}, {960., 137.14499999999998`}, {0., 
                    137.14499999999998`}}}]}, {
                    FaceForm[{
                    RGBColor[0.8, 0., 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     480.}, {960., 480.}, {960., 342.855}, {0., 342.855}}}]}, {
                    FaceForm[{
                    RGBColor[0.972549, 0.764706, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIZIGYC4k7HhKcXztQ4PF46+4jCmTyHi0q3f9a9qnHg
ur64wNYo38Fyy4myfdq1Dq2vA3fIZeY7LHLd9vlvSi1EvU++wzFv807HebUO
IGOU9PMdtgKVzz9V61BoCzThQJ7Dff/e6XlnaiHiXgi+/l0VtkbGLAeFDUUZ
E43rMPgw9SDjE0zr4OZZgdyTWAe3L26XJw/T7DpU91ypg7vXAGSuaD3cP+X7
5kvpG9fD/RuVYn3fP7je4ZtGTP+h3nyIuFO9A4jaYFYAcS9bPcQdnQUOy0Di
p+ocPl3yTRK4U+DAAAJpdRB38xdC+Axo/Fm1cD7YPtNauH6w+M8auPmyIAV7
a+D2g+k1NXD3occXAG2yx5Q=
                    "]]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4h1yra8DxWod3tXYm8a9ynfIff575UenWodC
W67ri//kOzzw752eV1TrAOQV2H7Kd2AAgTm1DvvnS+nfPZPvINx84NTCo7UO
YXy6m+Yuz3cAmrZD7mWtg+WWE2X70qHqGeoc9oHUS+Q7VImsc38oVgeXB9tr
VQfXD1aeUgc3X3FDUcbE3jq4/ZMlWML49tbB3efxEGjiyzq4+8H6H9VB1OkW
QPQfrXPQbhe7eS6xACI+uw7ijrYCh0NfNWL6C+ocQNa/X13g8BZkjkWdwyLX
bZ//HiiAux/GFwL593gtnA9yRkF/LVw/OPxSauHmg8PPqhZuP9g4uVq4+9DD
HwAHcqwN
                    "]]}, {
                    FaceForm[{
                    RGBColor[0.972549, 0.764706, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4vv+vdPzztQ6WG45UbZve7aDwV0VtsajtQ6t
rwN3yMlmO4DlV9Q6gKTnt2U5KGwoyphYWetQLbLO/SFXlsOy2UcUNnjVOjgm
PL2g1J/p8HgpUICr1uFtjb1pnF4mRP3BGoj89wyHRa7bPv+tqHGQjUqxvr8/
A6Jfo8aB6/riAttNGQ4XlG7/rLtT7XDc27zT8UKGww45oEsmVEPk32U4HPqq
EdPvUe0gA9JvnunAq7tp7nv+agd1Q441MosyHWxBCu9XOWwFuXddhsP0PKHm
AyVVDoUgiTfpDrG7PHmYvlc6xIHoxekO5fvmS+lXVjrog/wdme4wWYIljO91
hYNLd87z353pEH83VED8q5QB4a+ocAjlA1rMnOrg/rBKZN3/Kog9y1Ih7tWp
dmAAgQ1Q976odnAC+V86DRIubbUOqz5e8k26kQZx7/9ah5vnvgc/ZsxyAADR
07hx
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYCYoUNRRkTjescLLecKNu3PdvhotLtn3VWdQ6t
rwN3yMlmO4Dlw+scQNLz27Ic7vv3Ts9rq3OoFlnn/pAryyEqxfq+/9Y6B8eE
pxeU+jMdZEECX+sc3tbYm8bpZULU29VD5L9nOMTu8uRhaq+HqNufAdF/vd6B
6/riAttNGQ4z8oSaDwg2OBz3Nu90vJDhsKTAluu6eQNE/l2GgxzIYdENDjIg
jeaZDpUv1Qw5Khoc1A051sgsynR4WAV02IQGh60g967LgNBHGxwKgcYsfpPu
cAHkP5ZGhziQOxanOxwBedC50UH/rgpbY2S6w7bPf69UdDU6uHTnPP/dme6w
dDZQxf5GiH+VMiD81Y0OoXy6m+YypzrE9B/6qtHQ4DAd5O5lqRD3ZjY4MIDA
Bqh7uRscnED+l05zEG4+cGphZZ3Dqo+XfJNupDkAdcf0M9Q53Dz3PfgxY5YD
AAodtds=
                    "]], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{451.777, 177.38700000000003`}, {
                    446.551, 166.10899999999998`}, {436.10900000000004`, 
                    164.172}, {426.977, 173.277}, {426.977, 173.277}, {
                    430.648, 175.871}, {434.578, 176.586}, {
                    433.84400000000005`, 179.72299999999998`}, {435.355, 
                    184.062}, {437.484, 186.406}, {439.719, 184.883}, {
                    442.83599999999996`, 181.82000000000002`}, {443.629, 
                    178.266}, {449.133, 178.977}, {451.777, 
                    177.38700000000003`}, {451.777, 177.38700000000003`}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{492.64500000000004`, 178.664}, {
                    485.65200000000004`, 168.38700000000003`}, {
                    475.03499999999997`, 168.176}, {467.508, 
                    178.64499999999998`}, {467.508, 178.64499999999998`}, {
                    471.551, 180.605}, {475.547, 180.672}, {475.328, 
                    183.88700000000003`}, {477.527, 187.92200000000003`}, {
                    480.012, 189.89100000000002`}, {481.965, 188.02}, {
                    484.543, 184.496}, {484.746, 180.85500000000002`}, {
                    490.29699999999997`, 180.664}, {492.64500000000004`, 
                    178.664}, {492.64500000000004`, 178.664}}}], 
                    
                    FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {{{533.172, 173.26999999999998`}, {
                    524.605, 164.26999999999998`}, {514.094, 165.789}, {
                    508.371, 177.344}, {508.371, 177.344}, {512.6800000000001,
                     178.621}, {516.633, 178.035}, {516.9409999999999, 
                    181.242}, {519.766, 184.86700000000002`}, {522.539, 
                    186.40200000000002`}, {524.164, 184.242}, {526.133, 
                    180.344}, {525.738, 176.71899999999997`}, {
                    531.1840000000001, 175.625}, {533.172, 
                    173.26999999999998`}, {533.172, 173.26999999999998`}}}]}, {
                    RGBColor[0.972549, 0.764706, 0.], 
                    Thickness[0.011428571875], 
                    Opacity[1.], 
                    CapForm["Butt"], 
                    JoinForm[{"Miter", 4.}], 
                    
                    JoinedCurveBox[{{{1, 4, 3}}}, {{{413.484, 
                    152.23000000000002`}, {456.58599999999996`, 
                    165.05900000000003`}, {503.414, 165.05900000000003`}, {
                    546.516, 152.23000000000002`}}}, CurveClosed -> {0}]}, {
                    FaceForm[{
                    RGBColor[0.972549, 0.764706, 0.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{480., 332.57}, {490.078, 301.559}, {463.695, 
                    320.727}, {496.305, 320.727}, {469.92199999999997`, 
                    301.559}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{432., 319.71099999999996`}, {442.078, 288.699}, {
                    415.695, 307.863}, {448.305, 307.863}, {
                    421.92199999999997`, 288.699}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{396.863, 284.57}, {406.93799999999993`, 
                    253.559}, {380.559, 272.727}, {413.16400000000004`, 
                    272.727}, {386.78499999999997`, 253.559}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{384., 236.57}, {394.078, 205.559}, {367.695, 
                    224.727}, {400.305, 224.727}, {373.92199999999997`, 
                    205.559}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{528., 319.71099999999996`}, {517.9219999999999, 
                    288.699}, {544.305, 307.863}, {511.695, 307.863}, {
                    538.0780000000001, 288.699}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{563.137, 284.57}, {553.0619999999999, 253.559}, {
                    579.4409999999999, 272.727}, {546.8359999999999, 
                    272.727}, {573.215, 253.559}}}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{576., 236.57}, {565.9219999999999, 205.559}, {
                    592.305, 224.727}, {559.695, 224.727}, {586.0780000000001,
                     205.559}}}]}}, AspectRatio -> Automatic, 
                  ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 960.}, {0., 480.}}], ",", 
                 GraphicsBox[{
                   Thickness[0.0010416666666666667`], {
                    FaceForm[{
                    RGBColor[0., 0.619608, 0.286275], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     480.}, {960., 480.}, {960., 320.}, {0., 320.}}}]}, {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     320.}, {960., 320.}, {960., 160.}, {0., 160.}}}]}, {
                    Thickness[0.0010416666666666667`], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     160.}, {960., 160.}, {960., 0.}, {0., 0.}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.8078430000000001, 0.06666670000000002, 0.14902], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     480.}, {240., 480.}, {240., 0.}, {0., 0.}}}]}}, 
                  AspectRatio -> Automatic, ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 960.}, {0., 480.}}], ",", 
                 GraphicsBox[{
                   Thickness[0.001388888888888889], {
                    FaceForm[{
                    RGBColor[1., 1., 1.], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     0.}, {0., 480.}, {720., 480.}, {720., 0.}}}]}, {
                    FaceForm[{
                    RGBColor[
                    0.8078430000000001, 0.06666670000000002, 0.14902], 
                    Opacity[1.]}], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     480.}, {720., 480.}, {720., 320.}, {0., 320.}}}]}, {
                    Thickness[0.001388888888888889], 
                    
                    FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.,
                     160.}, {720., 160.}, {720., 0.}, {0., 0.}}}]}}, 
                  AspectRatio -> Automatic, ImageSize -> {{128}, {85}}, 
                  PlotRange -> {{0., 720.}, {0., 480.}}]}], "}"}]}], "}"}]], 
        "ExerciseOutput", Selectable -> False, Copyable -> False, Editable -> 
        False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"2d9c9577-4ae0-4e46-9b8b-2f8617738797"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Make raster images of the letters of the alphabet at size 20, then make a \
graph of the 2 nearest neighbors of each one.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "22.13", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"111f3e0e-7028-42e9-a6fe-b1bd2227f759"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       GraphicsBox[
        NamespaceBox["NetworkGraphics",
         DynamicModuleBox[{Typeset`graph = HoldComplete[
           Graph[{
             Graphics[
              Raster[CompressedData["
1:eJztUCEOwyAUJZnbEeZ2gd5hJyCZrqrArhZbVzlXh0JVVaFqUJgaDAaLQVRg
KhCMlqZt1gtM7CU/4fH+f4/PvXg9iwsA4BbrGms+h5/GZE2Edf4kaAbBhgfp
+XvmSE5RtHWW7iGuMMy2NihcCF6VC+lMcnK8QUkdDipR05rkZb6pIfRVsssq
wpRxfhTwoEa3vsF74DF3g3da8pY0NUZLZ77OejsItS+q6bJZMybWLo+EJWVc
MLLujlnqH2WHvlNzbo+/5o0eWNdSSmjHzRT+OOMDUFN0aA==
               "], {{0, 0}, {
               10, 26}}, {0, 255}, ColorFunction -> RGBColor], 
              ImageSize -> {10, 26}, PlotRange -> {{0, 10}, {0, 26}}], 
             Graphics[
              Raster[CompressedData["
1:eJzVkK0OwyAUhUkm9wZzewHegSdoMo2qwO4d6pB1OBRqClWFqZrBYGYmMDMI
xExFRUf/abNmmdtOchO4+bj3HI7p+ZTuAACHUPtQ7bn5P1XuEeSqZffGSYhD
siwBkxBTdgIMw2MfYkISOFzyq18AmNlhtBekgyB1EZAwM2/1JeoIaesZyHXk
68k7Q7n2XwDxisZRtAYg4X56b3gfVrllTIiZVIWgQ1AsqvU/xCJ6nNgDmJu6
skpehBBFaXw9G3qXYqGPgGZtZrQN3CVFENHCbgG/rxcTMKJ1
               "], {{0, 0}, {
               11, 26}}, {0, 255}, ColorFunction -> RGBColor], 
              ImageSize -> {11, 26}, PlotRange -> {{0, 11}, {0, 26}}], 
             Graphics[
              Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmJOIAax/w8+8Ondq6dPn7569wlZ8N2l1TF6DAjgX7n3
zjuQ4uvzYUKOBZWVMY5gpt6M//9fTYSw/Sc++A4x4/uh+RO33/n+/9MJf7Ci
jU9/o1n9HWKa44x3GK76fmcp2LQZnzCk/r87BLbK/wSm3O87BRDHNe1FKH8F
Nf7V3iao09M6tx86tLQzDchu2vsUIntpaSUDKmja/gBh8LsHh7ZvXLp06eqN
e++8+k44WIcjAAC1RVCo
               "], {{0, 0}, {9, 26}}, {0, 255}, 
               ColorFunction -> RGBColor], ImageSize -> {9, 26}, 
              PlotRange -> {{0, 9}, {0, 26}}], 
             Graphics[
              Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmJuIAax/w8t8P3d0wdPnz599R2b5KXVTQwIkLZ043x/
Bgb/GWchsg+2V0Jl9GIKCmLg6vwnQhQ8bdIDSxasfgfR8O5Skz+Sgk9nwTzH
Q++QnHNpBlzB9+tLwfITkeT/f0JS8PvBapANep24FPz/dAJi4YlP2K34//sO
xA+OTXvhCh5sb0Lyxf+nMG86FszYe2j7jMoYVG+CTDk0A+F9jHCAOezBpe2r
Vy9dunrvpafvLs3HVICiGNmRtFHw/c5qfz29yqXXcSkYbAAALCuqpQ==
               "], {{
               0, 0}, {11, 26}}, {0, 255}, ColorFunction -> RGBColor], 
              ImageSize -> {11, 26}, PlotRange -> {{0, 11}, {0, 26}}], 
             Graphics[
              Raster[CompressedData["
1:eJztj68OgzAQxpvM7RHm9gK8w56AZI+AwK4Wi0PicKgqVBWqZgpTU4OpwNRU
nKipQLD+gSyQzU/sl1xyvfvuvt41e9yzE0Lo4uLswufLz2NAK4eG+VCXDN/Q
myStKTehZWW3VW9FVRV5GvJi8k1dh6kEt2rbaNUopjBqhiBN+cEsykYSnRra
93Sld2lHhbZWEvSFaoAFnsEWC7AGPMYaVvpazWGZJQ7KkqnNDeI/ibTuoVgZ
V+GGCjHUeRKOa2AVz7zFe8+Uqd0NRo2MdoSQnnH96bo/LxRCezk=
               "], {{0, 
               0}, {10, 26}}, {0, 255}, ColorFunction -> RGBColor], 
              ImageSize -> {10, 26}, PlotRange -> {{0, 10}, {0, 26}}], 
             Graphics[
              Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmI2IAax/9MXfL++FGgpQ8zSTzCRT5dmgEQcZ7zDEMFU
Q54I3OTf1+eDRPznfwdzX53dWBmjBxJh0GuaOHHG6rNnOyFcOOj8/endpY1N
YHbBiTsPHjwFGfYdYjLMHLC/5kPUXAcJ/QaLPSiAGqKnBwvnT9c3xsBsQAmW
799/UxKsqAAAAhZjvA==
               "], {{0, 0}, {6, 26}}, {0, 255}, 
               ColorFunction -> RGBColor], ImageSize -> {6, 26}, 
              PlotRange -> {{0, 6}, {0, 26}}], 
             Graphics[
              Raster[CompressedData["
1:eJzlUKFuxDAMjTS2TxjbD/Qf/AWVhosOlK609FhhWVlRUFBRUEhQSEhISUBI
SUFASEHBLU66m069SeN7kqU4z8/P9vvl8+PyQgh5i/EaA9+3P2APi1GSI4TS
8xr2O2VoQ06oex6iyk0pK5qeGesWZwXtivQFndwsw3c1PTgtPBXUNy8Bpa1e
Qwg+YZ3FkNgyFjpWnX0TOUZW9WW2ruo7mp6KFQcPI5Ig/PNlHW9RCWUJUADU
7TD7n313S0+WlTpa5c5xO5EEntY4L/Q6swOypQpHq20eMX9gCbWHl5cdth7n
bMvbtDo03DirWHXc8ToJk8fq4Ok5uu/BN6slo5RNXBt7wP1ygv+KL3qCMuA=

               "], {{0, 0}, {10, 26}}, {0, 255}, ColorFunction -> RGBColor], 
              ImageSize -> {10, 26}, PlotRange -> {{0, 10}, {0, 26}}], 
             Graphics[
              Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmJuIAax/w8XcH1+GtA7aUuvw0U+XZoBFImZcQnCvTQj
Bsj1n3gWTQFcZEAUfL80H4sCmJuB4M7qAkwFDI5N1z9BFZyd6A8SQFMAVjRx
9fbVMwognMrtD5AVOBZUwtWBgF7Tg9//Mdzw6tD21UuXLl298cS733AXYfEF
GiCo4OwMFDdjgjsbOx31HDthbh6KAABYzr7r
               "], {{0, 0}, {11, 26}}, {
               0, 255}, ColorFunction -> RGBColor], ImageSize -> {11, 26}, 
              PlotRange -> {{0, 11}, {0, 26}}], 
             Graphics[
              Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmJWIAax/9MSXJ+fBrQibel1CPfSjBgg13/iWTpzz050
BHL1YNzfn17duXPn1aff/+H8V3De96UgrQwMMUu/g7ifZjiCuY4zPkGkX905
tPfQnXcwvVQCAEeBPoI=
               "], {{0, 0}, {5, 26}}, {0, 255}, 
               ColorFunction -> RGBColor], ImageSize -> {5, 26}, 
              PlotRange -> {{0, 5}, {0, 26}}], 
             Graphics[
              Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmI2IAax/2OAd08fXL906dL1B79hIjEMMBAz/x1Y5NCM
pqbOSj2w2IxLn+B6z070B6u6BBe5NAOk23/i2SEkcnaiI1BErxMh8vvTqzt3
7rz6BA8SsNArZIHvSyHBFLP0O1Tk0wxHsIjjDHgA/X5359DeQ3feIZlDAwAA
n1xr8A==
               "], {{0, 0}, {6, 26}}, {0, 255}, ColorFunction -> 
               RGBColor], ImageSize -> {6, 26}, 
              PlotRange -> {{0, 6}, {0, 26}}], 
             Graphics[
              Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmIuIAax/w9NcH1+GtDxaUuvw0UugUUY/OeD2DNiQMyJ
Z6FyT7frgeQYJp54B5d17DwBlvu0FMRj0CvY/htiDlgWKLD0zu9PJzrB7Jiz
n2C2QGURoHL7U4Qb0GTTln5HcjNENm3G9qUFIOfopS39hCHrPwPoozsFYN2O
nYfQZcE++g3zTuXGO5iyQPDqEMTZDPMvfcISGkAFD+5cv37n6affWGWRAX7Z
szP8Qe7EIXtnY6ejnmPn9gdYZQchAADMKmsX
               "], {{0, 0}, {10, 26}}, {
               0, 255}, ColorFunction -> RGBColor], ImageSize -> {10, 26}, 
              PlotRange -> {{0, 10}, {0, 26}}], 
             Graphics[
              Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmJWIAax/1Mb/P706sGDp+++/wax76xmAAPHiWeB3Evz
YyC8jXe+g7gzQFz/GZcgGqFcsMrBwz07wx/ufiC4s7HTUc+xc/sD6gYaAAHv
MDA=
               "], {{0, 0}, {5, 26}}, {0, 255}, ColorFunction -> 
               RGBColor], ImageSize -> {5, 26}, 
              PlotRange -> {{0, 5}, {0, 26}}], 
             Graphics[
              Raster[CompressedData["
1:eJztkaEOgzAQhi/ZE8zO7QV4hz4ByTQKgR12dg5ZV3eqClWFws9gamoqZjCI
iRoEgrUNFNTC3LLwJ5f0vv5/L23P6fWSHgDgZOtoy63HXd9LYWafLuMqEImJ
JUyaGRjuAKCaiGSuj2mzRDyhzStEWAxrsiWCPxLBbREmZ8Mg8si/WP85AqTQ
k8VQ4kCUYTdFdO4AlLNjioAfVQp2iyEoSlCIIot8k4SxjT+U5DlZrEDulazp
CkCCy2UH0yql3b+aZy1Kznn10IPf6jtVWYC8btpx19/pDWR9XYk=
               "], {{0, 
               0}, {17, 26}}, {0, 255}, ColorFunction -> RGBColor], 
              ImageSize -> {17, 26}, PlotRange -> {{0, 17}, {0, 26}}], 
             Graphics[
              Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmJuIAax/w8XcH1+GtA7aUuvw0U+XZoBFImZcQnCvTQj
Bsj1n3gWTQFcZEAUfL80H4sCmJuB4M7qAkwFDI5N1z9BFZyd6A8SQFMAVjRx
9fbVMwognMrtD2DqHUEGVjb5MyABvaYHv6EG/v709Pr1O+9Ajnt6YvvqpUuX
rt544t3v/6OAJAAA/yPYVg==
               "], {{0, 0}, {11, 26}}, {0, 255}, 
               ColorFunction -> RGBColor], ImageSize -> {11, 26}, 
              PlotRange -> {{0, 11}, {0, 26}}], 
             Graphics[
              Raster[CompressedData["
1:eJztkKEOwyAURUkm9wdz+wH+oV9AMo2qqB22tq6yrq4KVVWFqqnC1NTUVMxg
EAgMoqJjsNJtqZlcspuQAOfe9x6c4+slPgAATnYd7Xrsl1+TVlIIIZXZQSNL
IAiCKONyDtRM9UoQSYMRceW5KpG7wJV8BsbUmWDauurc8YjJraMZSpdJBmPt
1PFCvc5kBuy7aDuAM8B819BrO0IXrdU2iQYGwzwRP2PZr3huiOOY+pBgqX8Y
zqqua4sk8sdq0CHCKwLelbPp4zONnNqmppQ2jN/0vPz1pe6vbsT7
               "], {{0, 
               0}, {11, 26}}, {0, 255}, ColorFunction -> RGBColor], 
              ImageSize -> {11, 26}, PlotRange -> {{0, 11}, {0, 26}}], 
             Graphics[
              Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmJuIAax/xMFfn///v03bulLM2KARvnPuERAwcSzFCqI
mX8d6JhXT4Hg1XdsChgYHP0dGWDAccbeBxgKgEAvJi3NXw/KmXjiHbICvZgZ
D6BGv1uaBlak1/kKlzffHQLbprfxwW8cvvg03x9sy9l3JChACclXnY7oCoAB
8Qqu/9J8iGf3vkLzZsz8jXu3L+2EejRmKcRbZyc6QoIAEU4gkAYLhv+/Pz29
fv3OJyDj3Z29G1cvXbp0+6Gz7/BE/yjABgAnJqWw
               "], {{0, 0}, {11, 
               26}}, {0, 255}, ColorFunction -> RGBColor], 
              ImageSize -> {11, 26}, PlotRange -> {{0, 11}, {0, 26}}], 
             Graphics[
              Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmJuIAax/5MJfn8Hgt84pT9dmgE03HHiWfwK/ElV8P3d
0wdPnz59BbT59/X5aAourW5igAO9tM5Kf2QFD7ZXwqRiCgpi4AphCp426YEl
C1a/g2h4d6nJXw+h4NNZkHEMjofeITkHyZHfry8Fy09Ekkfxxe8Hq0HG6XXi
UvD/0wmwFf4nPmG34v/vOxA/ODbthSt4sL0J2ZtPYd50LJix99D2GZUxqN4E
mXJoBsL7iADrPIES/g8ubV+9eunS1XvP3vn+//vTO9cfvPqOK7JGASYAAA9L
rNM=
               "], {{0, 0}, {11, 26}}, {0, 255}, ColorFunction -> 
               RGBColor], ImageSize -> {11, 26}, 
              PlotRange -> {{0, 11}, {0, 26}}], 
             Graphics[
              Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmJ2IAax/w80uD4/DeiMtKXXkQUvzYgBCvpPPEsfQcfO
E5iCQOGND35jCAKBXtOMGRMnbgQKnp3oCOTHNDU5wqSAgr8/Pb1+/c4nIOPV
9Y2rly5dvZeMYBk8AADIm9Yh
               "], {{0, 0}, {7, 26}}, {0, 255}, 
               ColorFunction -> RGBColor], ImageSize -> {7, 26}, 
              PlotRange -> {{0, 7}, {0, 26}}], 
             Graphics[
              Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmIOIAax/w8s+P391VMQePfpO1Tk+9ONEwsYkIBj2vwH
v/9fmugI4cYUNE2cWAnlVG7//+lSU1rTiacw7a/2gqQcJ6JZc3ZpJQOy+PdX
h1bPiNGDWdF5CCj27uxSPSRrO1efBRn6/VIMRMC/cuPZO9/hRn466w92wQOY
wHeIF75fAoszFMzYfv362dWdaUD2xBOvgDLXV1cyoIKm7VDdn55e37tx9dKl
SzduP/Hg02+qB/PgAQC7PPiW
               "], {{0, 0}, {8, 26}}, {0, 255}, 
               ColorFunction -> RGBColor], ImageSize -> {8, 26}, 
              PlotRange -> {{0, 8}, {0, 26}}], 
             Graphics[
              Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmJ2IAax/9Md/P707unTp6/effoNE7m+sYkBBhwnngUr
uhQD4funFcQ4Fqy+DhT7fmc1SESv6SmSaZ8uzQArm/EJU9CRBMF3yC68Ph9s
5vzvcBduX1oZo8cAsX7ijImdEw89/d7JgA6aTrz79OrVg0sbHUG8ghMPHty5
fucVxJTvYB+huvP/97P+QMGY+SiCgwwAAFKhuT4=
               "], {{0, 0}, {7, 
               26}}, {0, 255}, ColorFunction -> RGBColor], 
              ImageSize -> {7, 26}, PlotRange -> {{0, 7}, {0, 26}}], 
             Graphics[
              Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmJuIAax/w8p8OnV0wdPn7569x2r5MYmfwYY8G/aeP3E
fCBjxtlPEOlXhzqhco4xMf56cJUTz76DKDg7EaRdr2AjxPTrG5vQFFyaEQPk
Vm5/CrfyRKc/pgK4jXARNAVw7oAoODvREcjtPIFQgCby/dWD69fvIIfx93dP
gSKvPv3GFuyjADsAAOt53ho=
               "], {{0, 0}, {11, 26}}, {0, 255}, 
               ColorFunction -> RGBColor], ImageSize -> {11, 26}, 
              PlotRange -> {{0, 11}, {0, 26}}], 
             Graphics[
              Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmJOIAax/w8dcKLTnwEE0i59R5X4faeAAQqaDr1Clnl3
diIDHKStRtL3e3uBHlBs4qETnY5A2v/EJ5jM97MxINUxl37/PwuWK9j4ACLz
dHsTxJzf//9/ujQDxPafD9b3aSlYT9Pep0jucdwLdMurvY5g087CzD/UBBJI
W3r9ztI0uGkQADXTceJEkNMYKvci++UOWDXDqwd3rl9/8On3f2TwDixIZrAO
ZQAAtf1PUg==
               "], {{0, 0}, {9, 26}}, {0, 255}, ColorFunction -> 
               RGBColor], ImageSize -> {9, 26}, 
              PlotRange -> {{0, 9}, {0, 26}}], 
             Graphics[
              Raster[CompressedData["
1:eJztUaGShDAM7cz6+4Bz+wP8A1/AzGrUitqrXYtD4upQqCoUCnOqpgaDqajB
IBCYigouCWWX/YFTm5nOpC8vb16S6/3ndr8wxr7hfcHDfPvE8psyjKKfIuIH
TkhW6TNx6guCWfLoAiHrIFmEyvlFDJ1IDvzhCDIyjwhL+yc1WIGcvCqw2jpQ
XSS4Sbgs+dmStw225o0bMRHttHmNtrmaxnq3tDPHmpPzAVIUFd1kJLXaLQwZ
quyW1po+lVlBvgFqInYbjfVQlVRVYGnVlGZIBNGGH4MIG16jcWUXXRJRrnE4
FXcg2rd1caUL3E9amecedlEwe5zA0FEyP7txtLM/ncvZdyTMgNjT+j/xv/EH
JeF/Zw==
               "], {{0, 0}, {14, 26}}, {0, 255}, ColorFunction -> 
               RGBColor], ImageSize -> {14, 26}, 
              PlotRange -> {{0, 14}, {0, 26}}], 
             Graphics[
              Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmJOIAax/w96MN8f6EyGgtV34CKHOsFCaavfnZ0IYjD4
n/gEEv9+fSmYy7D0+vf//39vL9ADsvWaDv3//64TxGRw7DwBNeLTCbARjgUF
MWAdlXeQbHywvZIBBmZc+oTimu+XYqAyeie+o8icgLgKDByb9iJ0QF3luP36
iQKE84DgKcRV/hNBrnqwGizpOPHV//93lkIsKbjzG2LG0yYwP2bpne+vHly/
fv3BK4TdEJGn71BdMzIAAB4dQJ4=
               "], {{0, 0}, {9, 26}}, {0, 255}, 
               ColorFunction -> RGBColor], ImageSize -> {9, 26}, 
              PlotRange -> {{0, 9}, {0, 26}}], 
             Graphics[
              Raster[CompressedData["
1:eJzlUKEOgzAQbTK1X5jbD/AP/YIm01WI2WFnccg6HAqFmkJhpmYwmBpEDaai
AlNRsXFXWGia7Af2kkuu967v3t05vV3SAyHktMRxCcjfP+CsMdoYGzNDyQgi
YYUM+XmoKWXU06ya489WZgmQojcxqZ8FcNcmnurG2ou+ItEuXwfeWxXO6jnZ
wAMz6nGHmmhK6KCd/jJGoFitloEcvYyrmDeQ5BrMNJDT0uwM8GrA15TDgkk7
uc0A5oheMOyU3sD+RFaiPi0E3idrp73fDJfQapRynF2wpYFiuPh/4ANLGjIw

               "], {{0, 0}, {9, 26}}, {0, 255}, ColorFunction -> RGBColor], 
              ImageSize -> {9, 26}, PlotRange -> {{0, 9}, {0, 26}}], 
             Graphics[
              Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmJOIAax/w96cGl+DAMI6OkxIIOYs5/+31mdBuPq+Ts6
6oEBA0MaUOr//1cTHcESlXuxGPp0O8S0zkOvMCXvrC6AW4EBPs33B0umrf6O
KfnuENhOhsrtTzElXx3qBEv6H3oHFdg4YyIYzJg/owDmrfkgOz+dQPUs1I+H
QHK/Xz24gwGe/iY+QIcRAAA9XkVU
               "], {{0, 0}, {9, 26}}, {0, 255}, 
               ColorFunction -> RGBColor], ImageSize -> {9, 26}, 
              PlotRange -> {{0, 9}, {0, 26}}]}, {Null, 
             SparseArray[
             Automatic, {26, 26}, 0, {
              1, {{0, 5, 7, 10, 12, 15, 17, 19, 22, 25, 27, 29, 32, 35, 39, 
                49, 52, 55, 58, 60, 62, 64, 66, 69, 73, 75, 78}, {{5}, {15}, {
                19}, {24}, {26}, {8}, {16}, {5}, {15}, {18}, {15}, {17}, {
                1}, {3}, {15}, {9}, {12}, {16}, {17}, {2}, {11}, {14}, {6}, {
                10}, {12}, {9}, {12}, {8}, {24}, {6}, {9}, {10}, {14}, {15}, {
                18}, {8}, {13}, {15}, {21}, {1}, {3}, {4}, {5}, {13}, {14}, {
                16}, {17}, {19}, {21}, {2}, {7}, {15}, {4}, {7}, {15}, {3}, {
                13}, {20}, {1}, {15}, {18}, {26}, {14}, {15}, {23}, {25}, {
                22}, {24}, {25}, {1}, {11}, {23}, {26}, {22}, {23}, {1}, {
                20}, {24}}}, Pattern}]}, {VertexLabels -> {All}}]]}, 
          TagBox[GraphicsGroupBox[{{{{
                {Hue[0.6, 0.7, 0.5], Opacity[0.7], {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{4.480586225893454, -2.1799474327571104`}, {
                    5.24106218708406, -1.7053517372530047`}}, 
                    0.052478423386308704`]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{4.480586225893454, -2.1799474327571104`}, {
                    5.965103790399207, -2.322804916942334}}, 
                    0.052478423386308704`]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{4.480586225893454, -2.1799474327571104`}, {
                    5.0936340590684415`, -2.420075315170594}}, 
                    0.052478423386308704`]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{4.480586225893454, -2.1799474327571104`}, {
                    3.188711043481997, -2.607258064208528}}, 
                    0.052478423386308704`]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{4.480586225893454, -2.1799474327571104`}, {
                    3.6377999851433134`, -1.7113080955758058`}}, 
                    0.052478423386308704`]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{5.9670411273594635`, -4.1970993673568024`}, {
                    4.986842693816599, -3.8493818994661746`}}, 
                    0.052478423386308704`]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{5.9670411273594635`, -4.1970993673568024`}, {
                    6.688016643036104, -3.4306867425232745`}}, 
                    0.052478423386308704`]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{5.765111935171046, -1.2491283642487643`}, {
                    5.24106218708406, -1.7053517372530047`}}, 
                    0.052478423386308704`]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{5.765111935171046, -1.2491283642487643`}, {
                    5.965103790399207, -2.322804916942334}}, 
                    0.052478423386308704`]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{5.765111935171046, -1.2491283642487643`}, {
                    5.104055270980713, -0.873614448207543}}, 
                    0.052478423386308704`]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{6.993329162302756, -1.9673148421060902`}, {
                    5.965103790399207, -2.322804916942334}}, 
                    0.052478423386308704`]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{6.993329162302756, -1.9673148421060902`}, {
                    7.159884817394166, -2.5216057257948923`}}, 
                    0.052478423386308704`]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{5.24106218708406, -1.7053517372530047`}, {
                    5.965103790399207, -2.322804916942334}}, 
                    0.052478423386308704`]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{2.6759265588555055`, -6.249358300161733}, {
                    1.7418955435258285`, -6.683451809207677}}, 
                    0.052478423386308704`]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{2.6759265588555055`, -6.249358300161733}, {
                    1.7432975798106856`, -5.813881410030349}}, 
                    0.052478423386308704`]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{7.6166730800090585`, -3.214984670662907}, {
                    6.688016643036104, -3.4306867425232745`}}, 
                    0.052478423386308704`]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{7.6166730800090585`, -3.214984670662907}, {
                    7.159884817394166, -2.5216057257948923`}}, 
                    0.052478423386308704`]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{4.986842693816599, -3.8493818994661746`}, {
                    3.8469892110659623`, -3.53684531368041}}, 
                    0.052478423386308704`]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{4.986842693816599, -3.8493818994661746`}, {
                    5.58583296100195, -2.9515506391145854`}}, 
                    0.052478423386308704`]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{1.7418955435258285`, -6.683451809207677}, {
                    0.8083910213367735, -6.248705306432721}}, 
                    0.052478423386308704`]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{1.7418955435258285`, -6.683451809207677}, {
                    1.7432975798106856`, -5.813881410030349}}, 
                    0.052478423386308704`]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{0.8083910213367735, -6.248705306432721}, {
                    1.7432975798106856`, -5.813881410030349}}, 
                    0.052478423386308704`]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{3.8469892110659623`, -3.53684531368041}, {
                    3.188711043481997, -2.607258064208528}}, 
                    0.052478423386308704`]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{5.6639631469428835`, -1.8248221865674927`}, {
                    5.58583296100195, -2.9515506391145854`}}, 
                    0.052478423386308704`]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{5.6639631469428835`, -1.8248221865674927`}, {
                    5.965103790399207, -2.322804916942334}}, 
                    0.052478423386308704`]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{5.6639631469428835`, -1.8248221865674927`}, {
                    5.104055270980713, -0.873614448207543}}, 
                    0.052478423386308704`]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{5.58583296100195, -2.9515506391145854`}, {
                    5.965103790399207, -2.322804916942334}}, 
                    0.052478423386308704`]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{5.58583296100195, -2.9515506391145854`}, {
                    6.215695355594371, -2.9999022913880706`}}, 
                    0.052478423386308704`]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{5.965103790399207, -2.322804916942334}, {
                    6.688016643036104, -3.4306867425232745`}}, 
                    0.052478423386308704`]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{5.965103790399207, -2.322804916942334}, {
                    7.159884817394166, -2.5216057257948923`}}, 
                    0.052478423386308704`]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{5.965103790399207, -2.322804916942334}, {
                    5.0936340590684415`, -2.420075315170594}}, 
                    0.052478423386308704`]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{5.965103790399207, -2.322804916942334}, {
                    6.215695355594371, -2.9999022913880706`}}, 
                    0.052478423386308704`]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{5.104055270980713, -0.873614448207543}, {
                    4.0893098597948505`, -0.8083910213367735}}, 
                    0.052478423386308704`]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{4.0893098597948505`, -0.8083910213367735}, {
                    3.6377999851433134`, -1.7113080955758058`}}, 
                    0.052478423386308704`]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{0.8717601828076917, -3.141020808670527}, {
                    1.7291396205785987`, -2.7951101292059013`}}, 
                    0.052478423386308704`]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{0.8717601828076917, -3.141020808670527}, {
                    0.8083910213367735, -2.6803280265469525`}}, 
                    0.052478423386308704`]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{1.7291396205785987`, -2.7951101292059013`}, {
                    3.188711043481997, -2.607258064208528}}, 
                    0.052478423386308704`]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{1.7291396205785987`, -2.7951101292059013`}, {
                    0.8083910213367735, -2.6803280265469525`}}, 
                    0.052478423386308704`]}}}}, {{{
                    {Arrowheads[0.], 
                    ArrowBox[{{3.188711043481997, -2.607258064208528}, {
                    3.6377999851433134`, -1.7113080955758058`}}, 
                    0.052478423386308704`]}}}}}}}}, {{{
                {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
                 0.7]}], {
                  DiskBox[{4.480586225893454, -2.1799474327571104}, 
                   0.052478423386308704], InsetBox[
                   FormBox[
                    GraphicsBox[RasterBox[CompressedData["
1:eJztUCEOwyAUJZnbEeZ2gd5hJyCZrqrArhZbVzlXh0JVVaFqUJgaDAaLQVRg
KhCMlqZt1gtM7CU/4fH+f4/PvXg9iwsA4BbrGms+h5/GZE2Edf4kaAbBhgfp
+XvmSE5RtHWW7iGuMMy2NihcCF6VC+lMcnK8QUkdDipR05rkZb6pIfRVsssq
wpRxfhTwoEa3vsF74DF3g3da8pY0NUZLZ77OejsItS+q6bJZMybWLo+EJWVc
MLLujlnqH2WHvlNzbo+/5o0eWNdSSmjHzRT+OOMDUFN0aA==
                    "], {{0, 
                    0}, {10, 26}}, {0, 255},
                    ColorFunction->RGBColor],
                    ImageSize->{10, 26},
                    PlotRange->{{0, 10}, {0, 26}}],
                    TraditionalForm], 
                   Offset[{2, 2}, {4.533064649279763, -2.1274690093708015}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{5.9670411273594635, -4.1970993673568024}, 
                   0.052478423386308704], InsetBox[
                   FormBox[
                    GraphicsBox[RasterBox[CompressedData["
1:eJzVkK0OwyAUhUkm9wZzewHegSdoMo2qwO4d6pB1OBRqClWFqZrBYGYmMDMI
xExFRUf/abNmmdtOchO4+bj3HI7p+ZTuAACHUPtQ7bn5P1XuEeSqZffGSYhD
siwBkxBTdgIMw2MfYkISOFzyq18AmNlhtBekgyB1EZAwM2/1JeoIaesZyHXk
68k7Q7n2XwDxisZRtAYg4X56b3gfVrllTIiZVIWgQ1AsqvU/xCJ6nNgDmJu6
skpehBBFaXw9G3qXYqGPgGZtZrQN3CVFENHCbgG/rxcTMKJ1
                    "], {{0, 
                    0}, {11, 26}}, {0, 255},
                    ColorFunction->RGBColor],
                    ImageSize->{11, 26},
                    PlotRange->{{0, 11}, {0, 26}}],
                    TraditionalForm], 
                   Offset[{2, 2}, {6.019519550745772, -4.1446209439704935}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{5.765111935171046, -1.2491283642487643}, 
                   0.052478423386308704], InsetBox[
                   FormBox[
                    GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmJOIAax/w8+8Ondq6dPn7569wlZ8N2l1TF6DAjgX7n3
zjuQ4uvzYUKOBZWVMY5gpt6M//9fTYSw/Sc++A4x4/uh+RO33/n+/9MJf7Ci
jU9/o1n9HWKa44x3GK76fmcp2LQZnzCk/r87BLbK/wSm3O87BRDHNe1FKH8F
Nf7V3iao09M6tx86tLQzDchu2vsUIntpaSUDKmja/gBh8LsHh7ZvXLp06eqN
e++8+k44WIcjAAC1RVCo
                    "], {{0, 0}, {9, 26}}, {0, 255},
                    ColorFunction->RGBColor],
                    ImageSize->{9, 26},
                    PlotRange->{{0, 9}, {0, 26}}],
                    TraditionalForm], 
                   Offset[{2, 2}, {5.8175903585573545, -1.1966499408624556}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{6.993329162302756, -1.9673148421060902}, 
                   0.052478423386308704], InsetBox[
                   FormBox[
                    GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmJuIAax/w8t8P3d0wdPnz599R2b5KXVTQwIkLZ043x/
Bgb/GWchsg+2V0Jl9GIKCmLg6vwnQhQ8bdIDSxasfgfR8O5Skz+Sgk9nwTzH
Q++QnHNpBlzB9+tLwfITkeT/f0JS8PvBapANep24FPz/dAJi4YlP2K34//sO
xA+OTXvhCh5sb0Lyxf+nMG86FszYe2j7jMoYVG+CTDk0A+F9jHCAOezBpe2r
Vy9dunrvpafvLs3HVICiGNmRtFHw/c5qfz29yqXXcSkYbAAALCuqpQ==
                    
                    "], {{0, 0}, {11, 26}}, {0, 255},
                    ColorFunction->RGBColor],
                    ImageSize->{11, 26},
                    PlotRange->{{0, 11}, {0, 26}}],
                    TraditionalForm], 
                   Offset[{2, 2}, {7.045807585689065, -1.9148364187197815}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{5.24106218708406, -1.7053517372530047}, 
                   0.052478423386308704], InsetBox[
                   FormBox[
                    GraphicsBox[RasterBox[CompressedData["
1:eJztj68OgzAQxpvM7RHm9gK8w56AZI+AwK4Wi0PicKgqVBWqZgpTU4OpwNRU
nKipQLD+gSyQzU/sl1xyvfvuvt41e9yzE0Lo4uLswufLz2NAK4eG+VCXDN/Q
myStKTehZWW3VW9FVRV5GvJi8k1dh6kEt2rbaNUopjBqhiBN+cEsykYSnRra
93Sld2lHhbZWEvSFaoAFnsEWC7AGPMYaVvpazWGZJQ7KkqnNDeI/ibTuoVgZ
V+GGCjHUeRKOa2AVz7zFe8+Uqd0NRo2MdoSQnnH96bo/LxRCezk=
                    
                    "], {{0, 0}, {10, 26}}, {0, 255},
                    ColorFunction->RGBColor],
                    ImageSize->{10, 26},
                    PlotRange->{{0, 10}, {0, 26}}],
                    TraditionalForm], 
                   Offset[{2, 2}, {5.293540610470369, -1.652873313866696}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{2.6759265588555055, -6.249358300161733}, 
                   0.052478423386308704], InsetBox[
                   FormBox[
                    GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmI2IAax/9MXfL++FGgpQ8zSTzCRT5dmgEQcZ7zDEMFU
Q54I3OTf1+eDRPznfwdzX53dWBmjBxJh0GuaOHHG6rNnOyFcOOj8/endpY1N
YHbBiTsPHjwFGfYdYjLMHLC/5kPUXAcJ/QaLPSiAGqKnBwvnT9c3xsBsQAmW
799/UxKsqAAAAhZjvA==
                    "], {{0, 0}, {6, 26}}, {0, 255},
                    ColorFunction->RGBColor],
                    ImageSize->{6, 26},
                    PlotRange->{{0, 6}, {0, 26}}],
                    TraditionalForm], 
                   Offset[{2, 2}, {2.7284049822418144, -6.196879876775424}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{7.6166730800090585, -3.214984670662907}, 
                   0.052478423386308704], InsetBox[
                   FormBox[
                    GraphicsBox[RasterBox[CompressedData["
1:eJzlUKFuxDAMjTS2TxjbD/Qf/AWVhosOlK609FhhWVlRUFBRUEhQSEhISUBI
SUFASEHBLU66m069SeN7kqU4z8/P9vvl8+PyQgh5i/EaA9+3P2APi1GSI4TS
8xr2O2VoQ06oex6iyk0pK5qeGesWZwXtivQFndwsw3c1PTgtPBXUNy8Bpa1e
Qwg+YZ3FkNgyFjpWnX0TOUZW9WW2ruo7mp6KFQcPI5Ig/PNlHW9RCWUJUADU
7TD7n313S0+WlTpa5c5xO5EEntY4L/Q6swOypQpHq20eMX9gCbWHl5cdth7n
bMvbtDo03DirWHXc8ToJk8fq4Ok5uu/BN6slo5RNXBt7wP1ygv+KL3qCMuA=

                    "], {{0, 0}, {10, 26}}, {0, 255},
                    ColorFunction->RGBColor],
                    ImageSize->{10, 26},
                    PlotRange->{{0, 10}, {0, 26}}],
                    TraditionalForm], 
                   Offset[{2, 2}, {7.669151503395367, -3.162506247276598}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{4.986842693816599, -3.8493818994661746}, 
                   0.052478423386308704], InsetBox[
                   FormBox[
                    GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmJuIAax/w8XcH1+GtA7aUuvw0U+XZoBFImZcQnCvTQj
Bsj1n3gWTQFcZEAUfL80H4sCmJuB4M7qAkwFDI5N1z9BFZyd6A8SQFMAVjRx
9fbVMwognMrtD5AVOBZUwtWBgF7Tg9//Mdzw6tD21UuXLl298cS733AXYfEF
GiCo4OwMFDdjgjsbOx31HDthbh6KAABYzr7r
                    "], {{0, 0}, {11, 
                    26}}, {0, 255},
                    ColorFunction->RGBColor],
                    ImageSize->{11, 26},
                    PlotRange->{{0, 11}, {0, 26}}],
                    TraditionalForm], 
                   Offset[{2, 2}, {5.039321117202908, -3.7969034760798657}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{1.7418955435258285, -6.683451809207677}, 
                   0.052478423386308704], InsetBox[
                   FormBox[
                    GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmJWIAax/9MSXJ+fBrQibel1CPfSjBgg13/iWTpzz050
BHL1YNzfn17duXPn1aff/+H8V3De96UgrQwMMUu/g7ifZjiCuY4zPkGkX905
tPfQnXcwvVQCAEeBPoI=
                    "], {{0, 0}, {5, 26}}, {0, 255},
                    ColorFunction->RGBColor],
                    ImageSize->{5, 26},
                    PlotRange->{{0, 5}, {0, 26}}],
                    TraditionalForm], 
                   Offset[{2, 2}, {1.7943739669121372, -6.630973385821368}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{0.8083910213367735, -6.248705306432721}, 
                   0.052478423386308704], InsetBox[
                   FormBox[
                    GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmI2IAax/2OAd08fXL906dL1B79hIjEMMBAz/x1Y5NCM
pqbOSj2w2IxLn+B6z070B6u6BBe5NAOk23/i2SEkcnaiI1BErxMh8vvTqzt3
7rz6BA8SsNArZIHvSyHBFLP0O1Tk0wxHsIjjDHgA/X5359DeQ3feIZlDAwAA
n1xr8A==
                    "], {{0, 0}, {6, 26}}, {0, 255},
                    ColorFunction->RGBColor],
                    ImageSize->{6, 26},
                    PlotRange->{{0, 6}, {0, 26}}],
                    TraditionalForm], 
                   Offset[{2, 2}, {0.8608694447230822, -6.196226883046412}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{3.8469892110659623, -3.53684531368041}, 
                   0.052478423386308704], InsetBox[
                   FormBox[
                    GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmIuIAax/w9NcH1+GtDxaUuvw0UugUUY/OeD2DNiQMyJ
Z6FyT7frgeQYJp54B5d17DwBlvu0FMRj0CvY/htiDlgWKLD0zu9PJzrB7Jiz
n2C2QGURoHL7U4Qb0GTTln5HcjNENm3G9qUFIOfopS39hCHrPwPoozsFYN2O
nYfQZcE++g3zTuXGO5iyQPDqEMTZDPMvfcISGkAFD+5cv37n6affWGWRAX7Z
szP8Qe7EIXtnY6ejnmPn9gdYZQchAADMKmsX
                    "], {{0, 0}, {10, 
                    26}}, {0, 255},
                    ColorFunction->RGBColor],
                    ImageSize->{10, 26},
                    PlotRange->{{0, 10}, {0, 26}}],
                    TraditionalForm], 
                   Offset[{2, 2}, {3.8994676344522707, -3.484366890294101}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{1.7432975798106856, -5.813881410030349}, 
                   0.052478423386308704], InsetBox[
                   FormBox[
                    GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmJWIAax/1Mb/P706sGDp+++/wax76xmAAPHiWeB3Evz
YyC8jXe+g7gzQFz/GZcgGqFcsMrBwz07wx/ufiC4s7HTUc+xc/sD6gYaAAHv
MDA=
                    "], {{0, 0}, {5, 26}}, {0, 255},
                    ColorFunction->RGBColor],
                    ImageSize->{5, 26},
                    PlotRange->{{0, 5}, {0, 26}}],
                    TraditionalForm], 
                   Offset[{2, 2}, {1.7957760031969943, -5.76140298664404}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{5.6639631469428835, -1.8248221865674927}, 
                   0.052478423386308704], InsetBox[
                   FormBox[
                    GraphicsBox[RasterBox[CompressedData["
1:eJztkaEOgzAQhi/ZE8zO7QV4hz4ByTQKgR12dg5ZV3eqClWFws9gamoqZjCI
iRoEgrUNFNTC3LLwJ5f0vv5/L23P6fWSHgDgZOtoy63HXd9LYWafLuMqEImJ
JUyaGRjuAKCaiGSuj2mzRDyhzStEWAxrsiWCPxLBbREmZ8Mg8si/WP85AqTQ
k8VQ4kCUYTdFdO4AlLNjioAfVQp2iyEoSlCIIot8k4SxjT+U5DlZrEDulazp
CkCCy2UH0yql3b+aZy1Kznn10IPf6jtVWYC8btpx19/pDWR9XYk=
                    
                    "], {{0, 0}, {17, 26}}, {0, 255},
                    ColorFunction->RGBColor],
                    ImageSize->{17, 26},
                    PlotRange->{{0, 17}, {0, 26}}],
                    TraditionalForm], 
                   Offset[{2, 2}, {5.716441570329192, -1.772343763181184}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{5.58583296100195, -2.9515506391145854}, 
                   0.052478423386308704], InsetBox[
                   FormBox[
                    GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmJuIAax/w8XcH1+GtA7aUuvw0U+XZoBFImZcQnCvTQj
Bsj1n3gWTQFcZEAUfL80H4sCmJuB4M7qAkwFDI5N1z9BFZyd6A8SQFMAVjRx
9fbVMwognMrtD2DqHUEGVjb5MyABvaYHv6EG/v709Pr1O+9Ajnt6YvvqpUuX
rt544t3v/6OAJAAA/yPYVg==
                    "], {{0, 0}, {11, 26}}, {0, 255},
                    
                    ColorFunction->RGBColor],
                    ImageSize->{11, 26},
                    PlotRange->{{0, 11}, {0, 26}}],
                    TraditionalForm], 
                   Offset[{2, 2}, {5.638311384388259, -2.8990722157282764}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{5.965103790399207, -2.322804916942334}, 
                   0.052478423386308704], InsetBox[
                   FormBox[
                    GraphicsBox[RasterBox[CompressedData["
1:eJztkKEOwyAURUkm9wdz+wH+oV9AMo2qqB22tq6yrq4KVVWFqqnC1NTUVMxg
EAgMoqJjsNJtqZlcspuQAOfe9x6c4+slPgAATnYd7Xrsl1+TVlIIIZXZQSNL
IAiCKONyDtRM9UoQSYMRceW5KpG7wJV8BsbUmWDauurc8YjJraMZSpdJBmPt
1PFCvc5kBuy7aDuAM8B819BrO0IXrdU2iQYGwzwRP2PZr3huiOOY+pBgqX8Y
zqqua4sk8sdq0CHCKwLelbPp4zONnNqmppQ2jN/0vPz1pe6vbsT7
                    
                    "], {{0, 0}, {11, 26}}, {0, 255},
                    ColorFunction->RGBColor],
                    ImageSize->{11, 26},
                    PlotRange->{{0, 11}, {0, 26}}],
                    TraditionalForm], 
                   Offset[{2, 2}, {6.0175822137855155, -2.2703264935560252}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{6.688016643036104, -3.4306867425232745}, 
                   0.052478423386308704], InsetBox[
                   FormBox[
                    GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmJuIAax/xMFfn///v03bulLM2KARvnPuERAwcSzFCqI
mX8d6JhXT4Hg1XdsChgYHP0dGWDAccbeBxgKgEAvJi3NXw/KmXjiHbICvZgZ
D6BGv1uaBlak1/kKlzffHQLbprfxwW8cvvg03x9sy9l3JChACclXnY7oCoAB
8Qqu/9J8iGf3vkLzZsz8jXu3L+2EejRmKcRbZyc6QoIAEU4gkAYLhv+/Pz29
fv3OJyDj3Z29G1cvXbp0+6Gz7/BE/yjABgAnJqWw
                    "], {{0, 0}, {11,
                     26}}, {0, 255},
                    ColorFunction->RGBColor],
                    ImageSize->{11, 26},
                    PlotRange->{{0, 11}, {0, 26}}],
                    TraditionalForm], 
                   Offset[{2, 2}, {6.740495066422413, -3.3782083191369656}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{7.159884817394166, -2.5216057257948923}, 
                   0.052478423386308704], InsetBox[
                   FormBox[
                    GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmJuIAax/5MJfn8Hgt84pT9dmgE03HHiWfwK/ElV8P3d
0wdPnz59BbT59/X5aAourW5igAO9tM5Kf2QFD7ZXwqRiCgpi4AphCp426YEl
C1a/g2h4d6nJXw+h4NNZkHEMjofeITkHyZHfry8Fy09Ekkfxxe8Hq0HG6XXi
UvD/0wmwFf4nPmG34v/vOxA/ODbthSt4sL0J2ZtPYd50LJix99D2GZUxqN4E
mXJoBsL7iADrPIES/g8ubV+9eunS1XvP3vn+//vTO9cfvPqOK7JGASYAAA9L
rNM=
                    "], {{0, 0}, {11, 26}}, {0, 255},
                    ColorFunction->RGBColor],
                    ImageSize->{11, 26},
                    PlotRange->{{0, 11}, {0, 26}}],
                    TraditionalForm], 
                   Offset[{2, 2}, {7.2123632407804745, -2.469127302408584}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{5.104055270980713, -0.873614448207543}, 
                   0.052478423386308704], InsetBox[
                   FormBox[
                    GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmJ2IAax/w80uD4/DeiMtKXXkQUvzYgBCvpPPEsfQcfO
E5iCQOGND35jCAKBXtOMGRMnbgQKnp3oCOTHNDU5wqSAgr8/Pb1+/c4nIOPV
9Y2rly5dvZeMYBk8AADIm9Yh
                    "], {{0, 0}, {7, 26}}, {0, 255},
                    ColorFunction->RGBColor],
                    ImageSize->{7, 26},
                    PlotRange->{{0, 7}, {0, 26}}],
                    TraditionalForm], 
                   Offset[{2, 2}, {5.156533694367022, -0.8211360248212343}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{5.0936340590684415, -2.420075315170594}, 
                   0.052478423386308704], InsetBox[
                   FormBox[
                    GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmIOIAax/w8s+P391VMQePfpO1Tk+9ONEwsYkIBj2vwH
v/9fmugI4cYUNE2cWAnlVG7//+lSU1rTiacw7a/2gqQcJ6JZc3ZpJQOy+PdX
h1bPiNGDWdF5CCj27uxSPSRrO1efBRn6/VIMRMC/cuPZO9/hRn466w92wQOY
wHeIF75fAoszFMzYfv362dWdaUD2xBOvgDLXV1cyoIKm7VDdn55e37tx9dKl
SzduP/Hg02+qB/PgAQC7PPiW
                    "], {{0, 0}, {8, 26}}, {0, 255},
                    ColorFunction->RGBColor],
                    ImageSize->{8, 26},
                    PlotRange->{{0, 8}, {0, 26}}],
                    TraditionalForm], 
                   Offset[{2, 2}, {5.14611248245475, -2.3675968917842853}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{4.0893098597948505, -0.8083910213367735}, 
                   0.052478423386308704], InsetBox[
                   FormBox[
                    GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmJ2IAax/9Md/P707unTp6/effoNE7m+sYkBBhwnngUr
uhQD4funFcQ4Fqy+DhT7fmc1SESv6SmSaZ8uzQArm/EJU9CRBMF3yC68Ph9s
5vzvcBduX1oZo8cAsX7ijImdEw89/d7JgA6aTrz79OrVg0sbHUG8ghMPHty5
fucVxJTvYB+huvP/97P+QMGY+SiCgwwAAFKhuT4=
                    "], {{0, 0}, {7, 
                    26}}, {0, 255},
                    ColorFunction->RGBColor],
                    ImageSize->{7, 26},
                    PlotRange->{{0, 7}, {0, 26}}],
                    TraditionalForm], 
                   Offset[{2, 2}, {4.141788283181159, -0.7559125979504648}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{6.215695355594371, -2.9999022913880706}, 
                   0.052478423386308704], InsetBox[
                   FormBox[
                    GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmJuIAax/w8p8OnV0wdPn7569x2r5MYmfwYY8G/aeP3E
fCBjxtlPEOlXhzqhco4xMf56cJUTz76DKDg7EaRdr2AjxPTrG5vQFFyaEQPk
Vm5/CrfyRKc/pgK4jXARNAVw7oAoODvREcjtPIFQgCby/dWD69fvIIfx93dP
gSKvPv3GFuyjADsAAOt53ho=
                    "], {{0, 0}, {11, 26}}, {0, 255},
                    
                    ColorFunction->RGBColor],
                    ImageSize->{11, 26},
                    PlotRange->{{0, 11}, {0, 26}}],
                    TraditionalForm], 
                   Offset[{2, 2}, {6.26817377898068, -2.9474238680017617}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{0.8717601828076917, -3.141020808670527}, 
                   0.052478423386308704], InsetBox[
                   FormBox[
                    GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmJOIAax/w8dcKLTnwEE0i59R5X4faeAAQqaDr1Clnl3
diIDHKStRtL3e3uBHlBs4qETnY5A2v/EJ5jM97MxINUxl37/PwuWK9j4ACLz
dHsTxJzf//9/ujQDxPafD9b3aSlYT9Pep0jucdwLdMurvY5g087CzD/UBBJI
W3r9ztI0uGkQADXTceJEkNMYKvci++UOWDXDqwd3rl9/8On3f2TwDixIZrAO
ZQAAtf1PUg==
                    "], {{0, 0}, {9, 26}}, {0, 255},
                    ColorFunction->RGBColor],
                    ImageSize->{9, 26},
                    PlotRange->{{0, 9}, {0, 26}}],
                    TraditionalForm], 
                   Offset[{2, 2}, {0.9242386061940004, -3.088542385284218}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{1.7291396205785987, -2.7951101292059013}, 
                   0.052478423386308704], InsetBox[
                   FormBox[
                    GraphicsBox[RasterBox[CompressedData["
1:eJztUaGShDAM7cz6+4Bz+wP8A1/AzGrUitqrXYtD4upQqCoUCnOqpgaDqajB
IBCYigouCWWX/YFTm5nOpC8vb16S6/3ndr8wxr7hfcHDfPvE8psyjKKfIuIH
TkhW6TNx6guCWfLoAiHrIFmEyvlFDJ1IDvzhCDIyjwhL+yc1WIGcvCqw2jpQ
XSS4Sbgs+dmStw225o0bMRHttHmNtrmaxnq3tDPHmpPzAVIUFd1kJLXaLQwZ
quyW1po+lVlBvgFqInYbjfVQlVRVYGnVlGZIBNGGH4MIG16jcWUXXRJRrnE4
FXcg2rd1caUL3E9amecedlEwe5zA0FEyP7txtLM/ncvZdyTMgNjT+j/xv/EH
JeF/Zw==
                    "], {{0, 0}, {14, 26}}, {0, 255},
                    ColorFunction->RGBColor],
                    ImageSize->{14, 26},
                    PlotRange->{{0, 14}, {0, 26}}],
                    TraditionalForm], 
                   Offset[{2, 2}, {1.7816180439649074, -2.7426317058195924}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{3.188711043481997, -2.607258064208528}, 
                   0.052478423386308704], InsetBox[
                   FormBox[
                    GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmJOIAax/w96MN8f6EyGgtV34CKHOsFCaavfnZ0IYjD4
n/gEEv9+fSmYy7D0+vf//39vL9ADsvWaDv3//64TxGRw7DwBNeLTCbARjgUF
MWAdlXeQbHywvZIBBmZc+oTimu+XYqAyeie+o8icgLgKDByb9iJ0QF3luP36
iQKE84DgKcRV/hNBrnqwGizpOPHV//93lkIsKbjzG2LG0yYwP2bpne+vHly/
fv3BK4TdEJGn71BdMzIAAB4dQJ4=
                    "], {{0, 0}, {9, 26}}, {0, 
                    255},
                    ColorFunction->RGBColor],
                    ImageSize->{9, 26},
                    PlotRange->{{0, 9}, {0, 26}}],
                    TraditionalForm], 
                   Offset[{2, 2}, {3.241189466868306, -2.554779640822219}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{0.8083910213367735, -2.6803280265469525}, 
                   0.052478423386308704], InsetBox[
                   FormBox[
                    GraphicsBox[RasterBox[CompressedData["
1:eJzlUKEOgzAQbTK1X5jbD/AP/YIm01WI2WFnccg6HAqFmkJhpmYwmBpEDaai
AlNRsXFXWGia7Af2kkuu967v3t05vV3SAyHktMRxCcjfP+CsMdoYGzNDyQgi
YYUM+XmoKWXU06ya489WZgmQojcxqZ8FcNcmnurG2ou+ItEuXwfeWxXO6jnZ
wAMz6nGHmmhK6KCd/jJGoFitloEcvYyrmDeQ5BrMNJDT0uwM8GrA15TDgkk7
uc0A5oheMOyU3sD+RFaiPi0E3idrp73fDJfQapRynF2wpYFiuPh/4ANLGjIw

                    "], {{0, 0}, {9, 26}}, {0, 255},
                    ColorFunction->RGBColor],
                    ImageSize->{9, 26},
                    PlotRange->{{0, 9}, {0, 26}}],
                    TraditionalForm], 
                   Offset[{2, 2}, {0.8608694447230822, -2.6278496031606435}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{3.6377999851433134, -1.7113080955758058}, 
                   0.052478423386308704], InsetBox[
                   FormBox[
                    GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmJOIAax/w96cGl+DAMI6OkxIIOYs5/+31mdBuPq+Ts6
6oEBA0MaUOr//1cTHcESlXuxGPp0O8S0zkOvMCXvrC6AW4EBPs33B0umrf6O
KfnuENhOhsrtTzElXx3qBEv6H3oHFdg4YyIYzJg/owDmrfkgOz+dQPUs1I+H
QHK/Xz24gwGe/iY+QIcRAAA9XkVU
                    "], {{0, 0}, {9, 26}}, {0, 
                    255},
                    ColorFunction->RGBColor],
                    ImageSize->{9, 26},
                    PlotRange->{{0, 9}, {0, 26}}],
                    TraditionalForm], 
                   Offset[{2, 2}, {3.690278408529622, -1.658829672189497}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}}}}}}],
           MouseAppearanceTag["NetworkGraphics"]],
          AllowKernelInitialization->False]],
        DefaultBaseStyle->{
         "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
          Hue[0.8, 1., 0.6]},
        FormatType->TraditionalForm,
        FrameTicks->None,
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]]]], "ExerciseOutput",ExpressionUUID->
       "36303457-cb8f-4841-b64a-a144c5c814df"],
      Apply[TextCell, 
       Cell[
        BoxData[
         GraphicsBox[
          NamespaceBox["NetworkGraphics", 
           DynamicModuleBox[{Typeset`graph = HoldComplete[
               Graph[{
                 Graphics[
                  Raster[CompressedData["
1:eJztUCEOwyAUJZnbEeZ2gd5hJyCZrqrArhZbVzlXh0JVVaFqUJgaDAaLQVRg
KhCMlqZt1gtM7CU/4fH+f4/PvXg9iwsA4BbrGms+h5/GZE2Edf4kaAbBhgfp
+XvmSE5RtHWW7iGuMMy2NihcCF6VC+lMcnK8QUkdDipR05rkZb6pIfRVsssq
wpRxfhTwoEa3vsF74DF3g3da8pY0NUZLZ77OejsItS+q6bJZMybWLo+EJWVc
MLLujlnqH2WHvlNzbo+/5o0eWNdSSmjHzRT+OOMDUFN0aA==
                   "], {{0, 
                   0}, {10, 26}}, {0, 255}, ColorFunction -> RGBColor], 
                  ImageSize -> {10, 26}, PlotRange -> {{0, 10}, {0, 26}}], 
                 Graphics[
                  Raster[CompressedData["
1:eJzVkK0OwyAUhUkm9wZzewHegSdoMo2qwO4d6pB1OBRqClWFqZrBYGYmMDMI
xExFRUf/abNmmdtOchO4+bj3HI7p+ZTuAACHUPtQ7bn5P1XuEeSqZffGSYhD
siwBkxBTdgIMw2MfYkISOFzyq18AmNlhtBekgyB1EZAwM2/1JeoIaesZyHXk
68k7Q7n2XwDxisZRtAYg4X56b3gfVrllTIiZVIWgQ1AsqvU/xCJ6nNgDmJu6
skpehBBFaXw9G3qXYqGPgGZtZrQN3CVFENHCbgG/rxcTMKJ1
                   "], {{0, 
                   0}, {11, 26}}, {0, 255}, ColorFunction -> RGBColor], 
                  ImageSize -> {11, 26}, PlotRange -> {{0, 11}, {0, 26}}], 
                 Graphics[
                  Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmJOIAax/w8+8Ondq6dPn7569wlZ8N2l1TF6DAjgX7n3
zjuQ4uvzYUKOBZWVMY5gpt6M//9fTYSw/Sc++A4x4/uh+RO33/n+/9MJf7Ci
jU9/o1n9HWKa44x3GK76fmcp2LQZnzCk/r87BLbK/wSm3O87BRDHNe1FKH8F
Nf7V3iao09M6tx86tLQzDchu2vsUIntpaSUDKmja/gBh8LsHh7ZvXLp06eqN
e++8+k44WIcjAAC1RVCo
                   "], {{0, 0}, {9, 26}}, {0, 255}, 
                   ColorFunction -> RGBColor], ImageSize -> {9, 26}, 
                  PlotRange -> {{0, 9}, {0, 26}}], 
                 Graphics[
                  Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmJuIAax/w8t8P3d0wdPnz599R2b5KXVTQwIkLZ043x/
Bgb/GWchsg+2V0Jl9GIKCmLg6vwnQhQ8bdIDSxasfgfR8O5Skz+Sgk9nwTzH
Q++QnHNpBlzB9+tLwfITkeT/f0JS8PvBapANep24FPz/dAJi4YlP2K34//sO
xA+OTXvhCh5sb0Lyxf+nMG86FszYe2j7jMoYVG+CTDk0A+F9jHCAOezBpe2r
Vy9dunrvpafvLs3HVICiGNmRtFHw/c5qfz29yqXXcSkYbAAALCuqpQ==
                   
                   "], {{0, 0}, {11, 26}}, {0, 255}, ColorFunction -> 
                   RGBColor], ImageSize -> {11, 26}, 
                  PlotRange -> {{0, 11}, {0, 26}}], 
                 Graphics[
                  Raster[CompressedData["
1:eJztj68OgzAQxpvM7RHm9gK8w56AZI+AwK4Wi0PicKgqVBWqZgpTU4OpwNRU
nKipQLD+gSyQzU/sl1xyvfvuvt41e9yzE0Lo4uLswufLz2NAK4eG+VCXDN/Q
myStKTehZWW3VW9FVRV5GvJi8k1dh6kEt2rbaNUopjBqhiBN+cEsykYSnRra
93Sld2lHhbZWEvSFaoAFnsEWC7AGPMYaVvpazWGZJQ7KkqnNDeI/ibTuoVgZ
V+GGCjHUeRKOa2AVz7zFe8+Uqd0NRo2MdoSQnnH96bo/LxRCezk=
                   "], {{
                   0, 0}, {10, 26}}, {0, 255}, ColorFunction -> RGBColor], 
                  ImageSize -> {10, 26}, PlotRange -> {{0, 10}, {0, 26}}], 
                 Graphics[
                  Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmI2IAax/9MXfL++FGgpQ8zSTzCRT5dmgEQcZ7zDEMFU
Q54I3OTf1+eDRPznfwdzX53dWBmjBxJh0GuaOHHG6rNnOyFcOOj8/endpY1N
YHbBiTsPHjwFGfYdYjLMHLC/5kPUXAcJ/QaLPSiAGqKnBwvnT9c3xsBsQAmW
799/UxKsqAAAAhZjvA==
                   "], {{0, 0}, {6, 26}}, {0, 255}, 
                   ColorFunction -> RGBColor], ImageSize -> {6, 26}, 
                  PlotRange -> {{0, 6}, {0, 26}}], 
                 Graphics[
                  Raster[CompressedData["
1:eJzlUKFuxDAMjTS2TxjbD/Qf/AWVhosOlK609FhhWVlRUFBRUEhQSEhISUBI
SUFASEHBLU66m069SeN7kqU4z8/P9vvl8+PyQgh5i/EaA9+3P2APi1GSI4TS
8xr2O2VoQ06oex6iyk0pK5qeGesWZwXtivQFndwsw3c1PTgtPBXUNy8Bpa1e
Qwg+YZ3FkNgyFjpWnX0TOUZW9WW2ruo7mp6KFQcPI5Ig/PNlHW9RCWUJUADU
7TD7n313S0+WlTpa5c5xO5EEntY4L/Q6swOypQpHq20eMX9gCbWHl5cdth7n
bMvbtDo03DirWHXc8ToJk8fq4Ok5uu/BN6slo5RNXBt7wP1ygv+KL3qCMuA=

                   "], {{0, 0}, {10, 26}}, {0, 255}, ColorFunction -> 
                   RGBColor], ImageSize -> {10, 26}, 
                  PlotRange -> {{0, 10}, {0, 26}}], 
                 Graphics[
                  Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmJuIAax/w8XcH1+GtA7aUuvw0U+XZoBFImZcQnCvTQj
Bsj1n3gWTQFcZEAUfL80H4sCmJuB4M7qAkwFDI5N1z9BFZyd6A8SQFMAVjRx
9fbVMwognMrtD5AVOBZUwtWBgF7Tg9//Mdzw6tD21UuXLl298cS733AXYfEF
GiCo4OwMFDdjgjsbOx31HDthbh6KAABYzr7r
                   "], {{0, 0}, {11, 
                   26}}, {0, 255}, ColorFunction -> RGBColor], 
                  ImageSize -> {11, 26}, PlotRange -> {{0, 11}, {0, 26}}], 
                 Graphics[
                  Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmJWIAax/9MSXJ+fBrQibel1CPfSjBgg13/iWTpzz050
BHL1YNzfn17duXPn1aff/+H8V3De96UgrQwMMUu/g7ifZjiCuY4zPkGkX905
tPfQnXcwvVQCAEeBPoI=
                   "], {{0, 0}, {5, 26}}, {0, 255}, 
                   ColorFunction -> RGBColor], ImageSize -> {5, 26}, 
                  PlotRange -> {{0, 5}, {0, 26}}], 
                 Graphics[
                  Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmI2IAax/2OAd08fXL906dL1B79hIjEMMBAz/x1Y5NCM
pqbOSj2w2IxLn+B6z070B6u6BBe5NAOk23/i2SEkcnaiI1BErxMh8vvTqzt3
7rz6BA8SsNArZIHvSyHBFLP0O1Tk0wxHsIjjDHgA/X5359DeQ3feIZlDAwAA
n1xr8A==
                   "], {{0, 0}, {6, 26}}, {0, 255}, ColorFunction -> 
                   RGBColor], ImageSize -> {6, 26}, 
                  PlotRange -> {{0, 6}, {0, 26}}], 
                 Graphics[
                  Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmIuIAax/w9NcH1+GtDxaUuvw0UugUUY/OeD2DNiQMyJ
Z6FyT7frgeQYJp54B5d17DwBlvu0FMRj0CvY/htiDlgWKLD0zu9PJzrB7Jiz
n2C2QGURoHL7U4Qb0GTTln5HcjNENm3G9qUFIOfopS39hCHrPwPoozsFYN2O
nYfQZcE++g3zTuXGO5iyQPDqEMTZDPMvfcISGkAFD+5cv37n6affWGWRAX7Z
szP8Qe7EIXtnY6ejnmPn9gdYZQchAADMKmsX
                   "], {{0, 0}, {10, 
                   26}}, {0, 255}, ColorFunction -> RGBColor], 
                  ImageSize -> {10, 26}, PlotRange -> {{0, 10}, {0, 26}}], 
                 Graphics[
                  Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmJWIAax/1Mb/P706sGDp+++/wax76xmAAPHiWeB3Evz
YyC8jXe+g7gzQFz/GZcgGqFcsMrBwz07wx/ufiC4s7HTUc+xc/sD6gYaAAHv
MDA=
                   "], {{0, 0}, {5, 26}}, {0, 255}, ColorFunction -> 
                   RGBColor], ImageSize -> {5, 26}, 
                  PlotRange -> {{0, 5}, {0, 26}}], 
                 Graphics[
                  Raster[CompressedData["
1:eJztkaEOgzAQhi/ZE8zO7QV4hz4ByTQKgR12dg5ZV3eqClWFws9gamoqZjCI
iRoEgrUNFNTC3LLwJ5f0vv5/L23P6fWSHgDgZOtoy63HXd9LYWafLuMqEImJ
JUyaGRjuAKCaiGSuj2mzRDyhzStEWAxrsiWCPxLBbREmZ8Mg8si/WP85AqTQ
k8VQ4kCUYTdFdO4AlLNjioAfVQp2iyEoSlCIIot8k4SxjT+U5DlZrEDulazp
CkCCy2UH0yql3b+aZy1Kznn10IPf6jtVWYC8btpx19/pDWR9XYk=
                   "], {{
                   0, 0}, {17, 26}}, {0, 255}, ColorFunction -> RGBColor], 
                  ImageSize -> {17, 26}, PlotRange -> {{0, 17}, {0, 26}}], 
                 Graphics[
                  Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmJuIAax/w8XcH1+GtA7aUuvw0U+XZoBFImZcQnCvTQj
Bsj1n3gWTQFcZEAUfL80H4sCmJuB4M7qAkwFDI5N1z9BFZyd6A8SQFMAVjRx
9fbVMwognMrtD2DqHUEGVjb5MyABvaYHv6EG/v709Pr1O+9Ajnt6YvvqpUuX
rt544t3v/6OAJAAA/yPYVg==
                   "], {{0, 0}, {11, 26}}, {0, 255}, 
                   ColorFunction -> RGBColor], ImageSize -> {11, 26}, 
                  PlotRange -> {{0, 11}, {0, 26}}], 
                 Graphics[
                  Raster[CompressedData["
1:eJztkKEOwyAURUkm9wdz+wH+oV9AMo2qqB22tq6yrq4KVVWFqqnC1NTUVMxg
EAgMoqJjsNJtqZlcspuQAOfe9x6c4+slPgAATnYd7Xrsl1+TVlIIIZXZQSNL
IAiCKONyDtRM9UoQSYMRceW5KpG7wJV8BsbUmWDauurc8YjJraMZSpdJBmPt
1PFCvc5kBuy7aDuAM8B819BrO0IXrdU2iQYGwzwRP2PZr3huiOOY+pBgqX8Y
zqqua4sk8sdq0CHCKwLelbPp4zONnNqmppQ2jN/0vPz1pe6vbsT7
                   "], {{
                   0, 0}, {11, 26}}, {0, 255}, ColorFunction -> RGBColor], 
                  ImageSize -> {11, 26}, PlotRange -> {{0, 11}, {0, 26}}], 
                 Graphics[
                  Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmJuIAax/xMFfn///v03bulLM2KARvnPuERAwcSzFCqI
mX8d6JhXT4Hg1XdsChgYHP0dGWDAccbeBxgKgEAvJi3NXw/KmXjiHbICvZgZ
D6BGv1uaBlak1/kKlzffHQLbprfxwW8cvvg03x9sy9l3JChACclXnY7oCoAB
8Qqu/9J8iGf3vkLzZsz8jXu3L+2EejRmKcRbZyc6QoIAEU4gkAYLhv+/Pz29
fv3OJyDj3Z29G1cvXbp0+6Gz7/BE/yjABgAnJqWw
                   "], {{0, 0}, {11, 
                   26}}, {0, 255}, ColorFunction -> RGBColor], 
                  ImageSize -> {11, 26}, PlotRange -> {{0, 11}, {0, 26}}], 
                 Graphics[
                  Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmJuIAax/5MJfn8Hgt84pT9dmgE03HHiWfwK/ElV8P3d
0wdPnz59BbT59/X5aAourW5igAO9tM5Kf2QFD7ZXwqRiCgpi4AphCp426YEl
C1a/g2h4d6nJXw+h4NNZkHEMjofeITkHyZHfry8Fy09Ekkfxxe8Hq0HG6XXi
UvD/0wmwFf4nPmG34v/vOxA/ODbthSt4sL0J2ZtPYd50LJix99D2GZUxqN4E
mXJoBsL7iADrPIES/g8ubV+9eunS1XvP3vn+//vTO9cfvPqOK7JGASYAAA9L
rNM=
                   "], {{0, 0}, {11, 26}}, {0, 255}, ColorFunction -> 
                   RGBColor], ImageSize -> {11, 26}, 
                  PlotRange -> {{0, 11}, {0, 26}}], 
                 Graphics[
                  Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmJ2IAax/w80uD4/DeiMtKXXkQUvzYgBCvpPPEsfQcfO
E5iCQOGND35jCAKBXtOMGRMnbgQKnp3oCOTHNDU5wqSAgr8/Pb1+/c4nIOPV
9Y2rly5dvZeMYBk8AADIm9Yh
                   "], {{0, 0}, {7, 26}}, {0, 255}, 
                   ColorFunction -> RGBColor], ImageSize -> {7, 26}, 
                  PlotRange -> {{0, 7}, {0, 26}}], 
                 Graphics[
                  Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmIOIAax/w8s+P391VMQePfpO1Tk+9ONEwsYkIBj2vwH
v/9fmugI4cYUNE2cWAnlVG7//+lSU1rTiacw7a/2gqQcJ6JZc3ZpJQOy+PdX
h1bPiNGDWdF5CCj27uxSPSRrO1efBRn6/VIMRMC/cuPZO9/hRn466w92wQOY
wHeIF75fAoszFMzYfv362dWdaUD2xBOvgDLXV1cyoIKm7VDdn55e37tx9dKl
SzduP/Hg02+qB/PgAQC7PPiW
                   "], {{0, 0}, {8, 26}}, {0, 255}, 
                   ColorFunction -> RGBColor], ImageSize -> {8, 26}, 
                  PlotRange -> {{0, 8}, {0, 26}}], 
                 Graphics[
                  Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmJ2IAax/9Md/P707unTp6/effoNE7m+sYkBBhwnngUr
uhQD4funFcQ4Fqy+DhT7fmc1SESv6SmSaZ8uzQArm/EJU9CRBMF3yC68Ph9s
5vzvcBduX1oZo8cAsX7ijImdEw89/d7JgA6aTrz79OrVg0sbHUG8ghMPHty5
fucVxJTvYB+huvP/97P+QMGY+SiCgwwAAFKhuT4=
                   "], {{0, 0}, {7, 
                   26}}, {0, 255}, ColorFunction -> RGBColor], 
                  ImageSize -> {7, 26}, PlotRange -> {{0, 7}, {0, 26}}], 
                 Graphics[
                  Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmJuIAax/w8p8OnV0wdPn7569x2r5MYmfwYY8G/aeP3E
fCBjxtlPEOlXhzqhco4xMf56cJUTz76DKDg7EaRdr2AjxPTrG5vQFFyaEQPk
Vm5/CrfyRKc/pgK4jXARNAVw7oAoODvREcjtPIFQgCby/dWD69fvIIfx93dP
gSKvPv3GFuyjADsAAOt53ho=
                   "], {{0, 0}, {11, 26}}, {0, 255}, 
                   ColorFunction -> RGBColor], ImageSize -> {11, 26}, 
                  PlotRange -> {{0, 11}, {0, 26}}], 
                 Graphics[
                  Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmJOIAax/w8dcKLTnwEE0i59R5X4faeAAQqaDr1Clnl3
diIDHKStRtL3e3uBHlBs4qETnY5A2v/EJ5jM97MxINUxl37/PwuWK9j4ACLz
dHsTxJzf//9/ujQDxPafD9b3aSlYT9Pep0jucdwLdMurvY5g087CzD/UBBJI
W3r9ztI0uGkQADXTceJEkNMYKvci++UOWDXDqwd3rl9/8On3f2TwDixIZrAO
ZQAAtf1PUg==
                   "], {{0, 0}, {9, 26}}, {0, 255}, 
                   ColorFunction -> RGBColor], ImageSize -> {9, 26}, 
                  PlotRange -> {{0, 9}, {0, 26}}], 
                 Graphics[
                  Raster[CompressedData["
1:eJztUaGShDAM7cz6+4Bz+wP8A1/AzGrUitqrXYtD4upQqCoUCnOqpgaDqajB
IBCYigouCWWX/YFTm5nOpC8vb16S6/3ndr8wxr7hfcHDfPvE8psyjKKfIuIH
TkhW6TNx6guCWfLoAiHrIFmEyvlFDJ1IDvzhCDIyjwhL+yc1WIGcvCqw2jpQ
XSS4Sbgs+dmStw225o0bMRHttHmNtrmaxnq3tDPHmpPzAVIUFd1kJLXaLQwZ
quyW1po+lVlBvgFqInYbjfVQlVRVYGnVlGZIBNGGH4MIG16jcWUXXRJRrnE4
FXcg2rd1caUL3E9amecedlEwe5zA0FEyP7txtLM/ncvZdyTMgNjT+j/xv/EH
JeF/Zw==
                   "], {{0, 0}, {14, 26}}, {0, 255}, ColorFunction -> 
                   RGBColor], ImageSize -> {14, 26}, 
                  PlotRange -> {{0, 14}, {0, 26}}], 
                 Graphics[
                  Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmJOIAax/w96MN8f6EyGgtV34CKHOsFCaavfnZ0IYjD4
n/gEEv9+fSmYy7D0+vf//39vL9ADsvWaDv3//64TxGRw7DwBNeLTCbARjgUF
MWAdlXeQbHywvZIBBmZc+oTimu+XYqAyeie+o8icgLgKDByb9iJ0QF3luP36
iQKE84DgKcRV/hNBrnqwGizpOPHV//93lkIsKbjzG2LG0yYwP2bpne+vHly/
fv3BK4TdEJGn71BdMzIAAB4dQJ4=
                   "], {{0, 0}, {9, 26}}, {0, 
                   255}, ColorFunction -> RGBColor], ImageSize -> {9, 26}, 
                  PlotRange -> {{0, 9}, {0, 26}}], 
                 Graphics[
                  Raster[CompressedData["
1:eJzlUKEOgzAQbTK1X5jbD/AP/YIm01WI2WFnccg6HAqFmkJhpmYwmBpEDaai
AlNRsXFXWGia7Af2kkuu967v3t05vV3SAyHktMRxCcjfP+CsMdoYGzNDyQgi
YYUM+XmoKWXU06ya489WZgmQojcxqZ8FcNcmnurG2ou+ItEuXwfeWxXO6jnZ
wAMz6nGHmmhK6KCd/jJGoFitloEcvYyrmDeQ5BrMNJDT0uwM8GrA15TDgkk7
uc0A5oheMOyU3sD+RFaiPi0E3idrp73fDJfQapRynF2wpYFiuPh/4ANLGjIw

                   "], {{0, 0}, {9, 26}}, {0, 255}, ColorFunction -> 
                   RGBColor], ImageSize -> {9, 26}, 
                  PlotRange -> {{0, 9}, {0, 26}}], 
                 Graphics[
                  Raster[CompressedData["
1:eJxTTMoPSmJmYGCQAmJOIAax/w96cGl+DAMI6OkxIIOYs5/+31mdBuPq+Ts6
6oEBA0MaUOr//1cTHcESlXuxGPp0O8S0zkOvMCXvrC6AW4EBPs33B0umrf6O
KfnuENhOhsrtTzElXx3qBEv6H3oHFdg4YyIYzJg/owDmrfkgOz+dQPUs1I+H
QHK/Xz24gwGe/iY+QIcRAAA9XkVU
                   "], {{0, 0}, {9, 26}}, {0, 
                   255}, ColorFunction -> RGBColor], ImageSize -> {9, 26}, 
                  PlotRange -> {{0, 9}, {0, 26}}]}, {Null, 
                 SparseArray[
                 Automatic, {26, 26}, 0, {
                  1, {{0, 5, 7, 10, 12, 15, 17, 19, 22, 25, 27, 29, 32, 35, 
                    39, 49, 52, 55, 58, 60, 62, 64, 66, 69, 73, 75, 78}, {{
                    5}, {15}, {19}, {24}, {26}, {8}, {16}, {5}, {15}, {18}, {
                    15}, {17}, {1}, {3}, {15}, {9}, {12}, {16}, {17}, {2}, {
                    11}, {14}, {6}, {10}, {12}, {9}, {12}, {8}, {24}, {6}, {
                    9}, {10}, {14}, {15}, {18}, {8}, {13}, {15}, {21}, {1}, {
                    3}, {4}, {5}, {13}, {14}, {16}, {17}, {19}, {21}, {2}, {
                    7}, {15}, {4}, {7}, {15}, {3}, {13}, {20}, {1}, {15}, {
                    18}, {26}, {14}, {15}, {23}, {25}, {22}, {24}, {25}, {
                    1}, {11}, {23}, {26}, {22}, {23}, {1}, {20}, {24}}}, 
                   Pattern}]}, {VertexLabels -> {All}}]]}, 
            TagBox[
             GraphicsGroupBox[{{
                Hue[0.6, 0.7, 0.5], 
                Opacity[0.7], {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{4.480586225893454, -2.1799474327571104`}, {
                  5.24106218708406, -1.7053517372530047`}}, 
                  0.052478423386308704`]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{4.480586225893454, -2.1799474327571104`}, {
                  5.965103790399207, -2.322804916942334}}, 
                  0.052478423386308704`]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{4.480586225893454, -2.1799474327571104`}, {
                  5.0936340590684415`, -2.420075315170594}}, 
                  0.052478423386308704`]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{4.480586225893454, -2.1799474327571104`}, {
                  3.188711043481997, -2.607258064208528}}, 
                  0.052478423386308704`]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{4.480586225893454, -2.1799474327571104`}, {
                  3.6377999851433134`, -1.7113080955758058`}}, 
                  0.052478423386308704`]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{5.9670411273594635`, -4.1970993673568024`}, {
                  4.986842693816599, -3.8493818994661746`}}, 
                  0.052478423386308704`]}, {
                 Arrowheads[0.], 
                 ArrowBox[{{5.9670411273594635`, -4.1970993673568024`}, {
                  6.688016643036104, -3.4306867425232745`}}, 
                  0.052478423386308704`]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{5.765111935171046, -1.2491283642487643`}, {
                  5.24106218708406, -1.7053517372530047`}}, 
                  0.052478423386308704`]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{5.765111935171046, -1.2491283642487643`}, {
                  5.965103790399207, -2.322804916942334}}, 
                  0.052478423386308704`]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{5.765111935171046, -1.2491283642487643`}, {
                  5.104055270980713, -0.873614448207543}}, 
                  0.052478423386308704`]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{6.993329162302756, -1.9673148421060902`}, {
                  5.965103790399207, -2.322804916942334}}, 
                  0.052478423386308704`]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{6.993329162302756, -1.9673148421060902`}, {
                  7.159884817394166, -2.5216057257948923`}}, 
                  0.052478423386308704`]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{5.24106218708406, -1.7053517372530047`}, {
                  5.965103790399207, -2.322804916942334}}, 
                  0.052478423386308704`]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{2.6759265588555055`, -6.249358300161733}, {
                  1.7418955435258285`, -6.683451809207677}}, 
                  0.052478423386308704`]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{2.6759265588555055`, -6.249358300161733}, {
                  1.7432975798106856`, -5.813881410030349}}, 
                  0.052478423386308704`]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{7.6166730800090585`, -3.214984670662907}, {
                  6.688016643036104, -3.4306867425232745`}}, 
                  0.052478423386308704`]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{7.6166730800090585`, -3.214984670662907}, {
                  7.159884817394166, -2.5216057257948923`}}, 
                  0.052478423386308704`]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{4.986842693816599, -3.8493818994661746`}, {
                  3.8469892110659623`, -3.53684531368041}}, 
                  0.052478423386308704`]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{4.986842693816599, -3.8493818994661746`}, {
                  5.58583296100195, -2.9515506391145854`}}, 
                  0.052478423386308704`]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{1.7418955435258285`, -6.683451809207677}, {
                  0.8083910213367735, -6.248705306432721}}, 
                  0.052478423386308704`]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{1.7418955435258285`, -6.683451809207677}, {
                  1.7432975798106856`, -5.813881410030349}}, 
                  0.052478423386308704`]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{0.8083910213367735, -6.248705306432721}, {
                  1.7432975798106856`, -5.813881410030349}}, 
                  0.052478423386308704`]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{3.8469892110659623`, -3.53684531368041}, {
                  3.188711043481997, -2.607258064208528}}, 
                  0.052478423386308704`]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{5.6639631469428835`, -1.8248221865674927`}, {
                  5.58583296100195, -2.9515506391145854`}}, 
                  0.052478423386308704`]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{5.6639631469428835`, -1.8248221865674927`}, {
                  5.965103790399207, -2.322804916942334}}, 
                  0.052478423386308704`]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{5.6639631469428835`, -1.8248221865674927`}, {
                  5.104055270980713, -0.873614448207543}}, 
                  0.052478423386308704`]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{5.58583296100195, -2.9515506391145854`}, {
                  5.965103790399207, -2.322804916942334}}, 
                  0.052478423386308704`]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{5.58583296100195, -2.9515506391145854`}, {
                  6.215695355594371, -2.9999022913880706`}}, 
                  0.052478423386308704`]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{5.965103790399207, -2.322804916942334}, {
                  6.688016643036104, -3.4306867425232745`}}, 
                  0.052478423386308704`]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{5.965103790399207, -2.322804916942334}, {
                  7.159884817394166, -2.5216057257948923`}}, 
                  0.052478423386308704`]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{5.965103790399207, -2.322804916942334}, {
                  5.0936340590684415`, -2.420075315170594}}, 
                  0.052478423386308704`]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{5.965103790399207, -2.322804916942334}, {
                  6.215695355594371, -2.9999022913880706`}}, 
                  0.052478423386308704`]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{5.104055270980713, -0.873614448207543}, {
                  4.0893098597948505`, -0.8083910213367735}}, 
                  0.052478423386308704`]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{4.0893098597948505`, -0.8083910213367735}, {
                  3.6377999851433134`, -1.7113080955758058`}}, 
                  0.052478423386308704`]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{0.8717601828076917, -3.141020808670527}, {
                  1.7291396205785987`, -2.7951101292059013`}}, 
                  0.052478423386308704`]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{0.8717601828076917, -3.141020808670527}, {
                  0.8083910213367735, -2.6803280265469525`}}, 
                  0.052478423386308704`]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{1.7291396205785987`, -2.7951101292059013`}, {
                  3.188711043481997, -2.607258064208528}}, 
                  0.052478423386308704`]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{1.7291396205785987`, -2.7951101292059013`}, {
                  0.8083910213367735, -2.6803280265469525`}}, 
                  0.052478423386308704`]}, {
                 Arrowheads[0.], 
                 
                 ArrowBox[{{3.188711043481997, -2.607258064208528}, {
                  3.6377999851433134`, -1.7113080955758058`}}, 
                  0.052478423386308704`]}}, {
                Hue[0.6, 0.2, 0.8], 
                EdgeForm[{
                  GrayLevel[0], 
                  Opacity[0.7]}], {
                 
                 DiskBox[{4.480586225893454, -2.1799474327571104`}, 
                  0.052478423386308704`], 
                 InsetBox[
                  FormBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJztUCEOwyAUJZnbEeZ2gd5hJyCZrqrArhZbVzlXh0JVVaFqUJgaDAaLQVRg
KhCMlqZt1gtM7CU/4fH+f4/PvXg9iwsA4BbrGms+h5/GZE2Edf4kaAbBhgfp
+XvmSE5RtHWW7iGuMMy2NihcCF6VC+lMcnK8QUkdDipR05rkZb6pIfRVsssq
wpRxfhTwoEa3vsF74DF3g3da8pY0NUZLZ77OejsItS+q6bJZMybWLo+EJWVc
MLLujlnqH2WHvlNzbo+/5o0eWNdSSmjHzRT+OOMDUFN0aA==
                    "], {{0, 
                    0}, {10, 26}}, {0, 255}, ColorFunction -> RGBColor], 
                    ImageSize -> {10, 26}, PlotRange -> {{0, 10}, {0, 26}}], 
                   TraditionalForm], 
                  Offset[{2, 2}, {4.533064649279763, -2.1274690093708015`}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{5.9670411273594635`, -4.1970993673568024`}, 
                  0.052478423386308704`], 
                 InsetBox[
                  FormBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJzVkK0OwyAUhUkm9wZzewHegSdoMo2qwO4d6pB1OBRqClWFqZrBYGYmMDMI
xExFRUf/abNmmdtOchO4+bj3HI7p+ZTuAACHUPtQ7bn5P1XuEeSqZffGSYhD
siwBkxBTdgIMw2MfYkISOFzyq18AmNlhtBekgyB1EZAwM2/1JeoIaesZyHXk
68k7Q7n2XwDxisZRtAYg4X56b3gfVrllTIiZVIWgQ1AsqvU/xCJ6nNgDmJu6
skpehBBFaXw9G3qXYqGPgGZtZrQN3CVFENHCbgG/rxcTMKJ1
                    "], {{0, 
                    0}, {11, 26}}, {0, 255}, ColorFunction -> RGBColor], 
                    ImageSize -> {11, 26}, PlotRange -> {{0, 11}, {0, 26}}], 
                   TraditionalForm], 
                  Offset[{2, 2}, {6.019519550745772, -4.1446209439704935`}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 DiskBox[{5.765111935171046, -1.2491283642487643`}, 
                  0.052478423386308704`], 
                 InsetBox[
                  FormBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmJOIAax/w8+8Ondq6dPn7569wlZ8N2l1TF6DAjgX7n3
zjuQ4uvzYUKOBZWVMY5gpt6M//9fTYSw/Sc++A4x4/uh+RO33/n+/9MJf7Ci
jU9/o1n9HWKa44x3GK76fmcp2LQZnzCk/r87BLbK/wSm3O87BRDHNe1FKH8F
Nf7V3iao09M6tx86tLQzDchu2vsUIntpaSUDKmja/gBh8LsHh7ZvXLp06eqN
e++8+k44WIcjAAC1RVCo
                    "], {{0, 0}, {9, 26}}, {0, 255}, 
                    ColorFunction -> RGBColor], ImageSize -> {9, 26}, 
                    PlotRange -> {{0, 9}, {0, 26}}], TraditionalForm], 
                  Offset[{2, 2}, {5.8175903585573545`, -1.1966499408624556`}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{6.993329162302756, -1.9673148421060902`}, 
                  0.052478423386308704`], 
                 InsetBox[
                  FormBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmJuIAax/w8t8P3d0wdPnz599R2b5KXVTQwIkLZ043x/
Bgb/GWchsg+2V0Jl9GIKCmLg6vwnQhQ8bdIDSxasfgfR8O5Skz+Sgk9nwTzH
Q++QnHNpBlzB9+tLwfITkeT/f0JS8PvBapANep24FPz/dAJi4YlP2K34//sO
xA+OTXvhCh5sb0Lyxf+nMG86FszYe2j7jMoYVG+CTDk0A+F9jHCAOezBpe2r
Vy9dunrvpafvLs3HVICiGNmRtFHw/c5qfz29yqXXcSkYbAAALCuqpQ==
                    
                    "], {{0, 0}, {11, 26}}, {0, 255}, ColorFunction -> 
                    RGBColor], ImageSize -> {11, 26}, 
                    PlotRange -> {{0, 11}, {0, 26}}], TraditionalForm], 
                  Offset[{2, 2}, {7.045807585689065, -1.9148364187197815`}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{5.24106218708406, -1.7053517372530047`}, 
                  0.052478423386308704`], 
                 InsetBox[
                  FormBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJztj68OgzAQxpvM7RHm9gK8w56AZI+AwK4Wi0PicKgqVBWqZgpTU4OpwNRU
nKipQLD+gSyQzU/sl1xyvfvuvt41e9yzE0Lo4uLswufLz2NAK4eG+VCXDN/Q
myStKTehZWW3VW9FVRV5GvJi8k1dh6kEt2rbaNUopjBqhiBN+cEsykYSnRra
93Sld2lHhbZWEvSFaoAFnsEWC7AGPMYaVvpazWGZJQ7KkqnNDeI/ibTuoVgZ
V+GGCjHUeRKOa2AVz7zFe8+Uqd0NRo2MdoSQnnH96bo/LxRCezk=
                    
                    "], {{0, 0}, {10, 26}}, {0, 255}, ColorFunction -> 
                    RGBColor], ImageSize -> {10, 26}, 
                    PlotRange -> {{0, 10}, {0, 26}}], TraditionalForm], 
                  Offset[{2, 2}, {5.293540610470369, -1.652873313866696}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{2.6759265588555055`, -6.249358300161733}, 
                  0.052478423386308704`], 
                 InsetBox[
                  FormBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmI2IAax/9MXfL++FGgpQ8zSTzCRT5dmgEQcZ7zDEMFU
Q54I3OTf1+eDRPznfwdzX53dWBmjBxJh0GuaOHHG6rNnOyFcOOj8/endpY1N
YHbBiTsPHjwFGfYdYjLMHLC/5kPUXAcJ/QaLPSiAGqKnBwvnT9c3xsBsQAmW
799/UxKsqAAAAhZjvA==
                    "], {{0, 0}, {6, 26}}, {0, 255}, 
                    ColorFunction -> RGBColor], ImageSize -> {6, 26}, 
                    PlotRange -> {{0, 6}, {0, 26}}], TraditionalForm], 
                  Offset[{2, 2}, {2.7284049822418144`, -6.196879876775424}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{7.6166730800090585`, -3.214984670662907}, 
                  0.052478423386308704`], 
                 InsetBox[
                  FormBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJzlUKFuxDAMjTS2TxjbD/Qf/AWVhosOlK609FhhWVlRUFBRUEhQSEhISUBI
SUFASEHBLU66m069SeN7kqU4z8/P9vvl8+PyQgh5i/EaA9+3P2APi1GSI4TS
8xr2O2VoQ06oex6iyk0pK5qeGesWZwXtivQFndwsw3c1PTgtPBXUNy8Bpa1e
Qwg+YZ3FkNgyFjpWnX0TOUZW9WW2ruo7mp6KFQcPI5Ig/PNlHW9RCWUJUADU
7TD7n313S0+WlTpa5c5xO5EEntY4L/Q6swOypQpHq20eMX9gCbWHl5cdth7n
bMvbtDo03DirWHXc8ToJk8fq4Ok5uu/BN6slo5RNXBt7wP1ygv+KL3qCMuA=

                    "], {{0, 0}, {10, 26}}, {0, 255}, ColorFunction -> 
                    RGBColor], ImageSize -> {10, 26}, 
                    PlotRange -> {{0, 10}, {0, 26}}], TraditionalForm], 
                  Offset[{2, 2}, {7.669151503395367, -3.162506247276598}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{4.986842693816599, -3.8493818994661746`}, 
                  0.052478423386308704`], 
                 InsetBox[
                  FormBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmJuIAax/w8XcH1+GtA7aUuvw0U+XZoBFImZcQnCvTQj
Bsj1n3gWTQFcZEAUfL80H4sCmJuB4M7qAkwFDI5N1z9BFZyd6A8SQFMAVjRx
9fbVMwognMrtD5AVOBZUwtWBgF7Tg9//Mdzw6tD21UuXLl298cS733AXYfEF
GiCo4OwMFDdjgjsbOx31HDthbh6KAABYzr7r
                    "], {{0, 0}, {11, 
                    26}}, {0, 255}, ColorFunction -> RGBColor], 
                    ImageSize -> {11, 26}, PlotRange -> {{0, 11}, {0, 26}}], 
                   TraditionalForm], 
                  Offset[{2, 2}, {5.039321117202908, -3.7969034760798657`}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{1.7418955435258285`, -6.683451809207677}, 
                  0.052478423386308704`], 
                 InsetBox[
                  FormBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmJWIAax/9MSXJ+fBrQibel1CPfSjBgg13/iWTpzz050
BHL1YNzfn17duXPn1aff/+H8V3De96UgrQwMMUu/g7ifZjiCuY4zPkGkX905
tPfQnXcwvVQCAEeBPoI=
                    "], {{0, 0}, {5, 26}}, {0, 255}, 
                    ColorFunction -> RGBColor], ImageSize -> {5, 26}, 
                    PlotRange -> {{0, 5}, {0, 26}}], TraditionalForm], 
                  Offset[{2, 2}, {1.7943739669121372`, -6.630973385821368}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{0.8083910213367735, -6.248705306432721}, 
                  0.052478423386308704`], 
                 InsetBox[
                  FormBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmI2IAax/2OAd08fXL906dL1B79hIjEMMBAz/x1Y5NCM
pqbOSj2w2IxLn+B6z070B6u6BBe5NAOk23/i2SEkcnaiI1BErxMh8vvTqzt3
7rz6BA8SsNArZIHvSyHBFLP0O1Tk0wxHsIjjDHgA/X5359DeQ3feIZlDAwAA
n1xr8A==
                    "], {{0, 0}, {6, 26}}, {0, 255}, ColorFunction -> 
                    RGBColor], ImageSize -> {6, 26}, 
                    PlotRange -> {{0, 6}, {0, 26}}], TraditionalForm], 
                  Offset[{2, 2}, {0.8608694447230822, -6.196226883046412}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{3.8469892110659623`, -3.53684531368041}, 
                  0.052478423386308704`], 
                 InsetBox[
                  FormBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmIuIAax/w9NcH1+GtDxaUuvw0UugUUY/OeD2DNiQMyJ
Z6FyT7frgeQYJp54B5d17DwBlvu0FMRj0CvY/htiDlgWKLD0zu9PJzrB7Jiz
n2C2QGURoHL7U4Qb0GTTln5HcjNENm3G9qUFIOfopS39hCHrPwPoozsFYN2O
nYfQZcE++g3zTuXGO5iyQPDqEMTZDPMvfcISGkAFD+5cv37n6affWGWRAX7Z
szP8Qe7EIXtnY6ejnmPn9gdYZQchAADMKmsX
                    "], {{0, 0}, {10, 
                    26}}, {0, 255}, ColorFunction -> RGBColor], 
                    ImageSize -> {10, 26}, PlotRange -> {{0, 10}, {0, 26}}], 
                   TraditionalForm], 
                  Offset[{2, 2}, {3.8994676344522707`, -3.484366890294101}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{1.7432975798106856`, -5.813881410030349}, 
                  0.052478423386308704`], 
                 InsetBox[
                  FormBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmJWIAax/1Mb/P706sGDp+++/wax76xmAAPHiWeB3Evz
YyC8jXe+g7gzQFz/GZcgGqFcsMrBwz07wx/ufiC4s7HTUc+xc/sD6gYaAAHv
MDA=
                    "], {{0, 0}, {5, 26}}, {0, 255}, ColorFunction -> 
                    RGBColor], ImageSize -> {5, 26}, 
                    PlotRange -> {{0, 5}, {0, 26}}], TraditionalForm], 
                  Offset[{2, 2}, {1.7957760031969943`, -5.76140298664404}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{5.6639631469428835`, -1.8248221865674927`}, 
                  0.052478423386308704`], 
                 InsetBox[
                  FormBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJztkaEOgzAQhi/ZE8zO7QV4hz4ByTQKgR12dg5ZV3eqClWFws9gamoqZjCI
iRoEgrUNFNTC3LLwJ5f0vv5/L23P6fWSHgDgZOtoy63HXd9LYWafLuMqEImJ
JUyaGRjuAKCaiGSuj2mzRDyhzStEWAxrsiWCPxLBbREmZ8Mg8si/WP85AqTQ
k8VQ4kCUYTdFdO4AlLNjioAfVQp2iyEoSlCIIot8k4SxjT+U5DlZrEDulazp
CkCCy2UH0yql3b+aZy1Kznn10IPf6jtVWYC8btpx19/pDWR9XYk=
                    
                    "], {{0, 0}, {17, 26}}, {0, 255}, ColorFunction -> 
                    RGBColor], ImageSize -> {17, 26}, 
                    PlotRange -> {{0, 17}, {0, 26}}], TraditionalForm], 
                  Offset[{2, 2}, {5.716441570329192, -1.772343763181184}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{5.58583296100195, -2.9515506391145854`}, 
                  0.052478423386308704`], 
                 InsetBox[
                  FormBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmJuIAax/w8XcH1+GtA7aUuvw0U+XZoBFImZcQnCvTQj
Bsj1n3gWTQFcZEAUfL80H4sCmJuB4M7qAkwFDI5N1z9BFZyd6A8SQFMAVjRx
9fbVMwognMrtD2DqHUEGVjb5MyABvaYHv6EG/v709Pr1O+9Ajnt6YvvqpUuX
rt544t3v/6OAJAAA/yPYVg==
                    "], {{0, 0}, {11, 26}}, {0, 255},
                     ColorFunction -> RGBColor], ImageSize -> {11, 26}, 
                    PlotRange -> {{0, 11}, {0, 26}}], TraditionalForm], 
                  Offset[{2, 2}, {5.638311384388259, -2.8990722157282764`}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{5.965103790399207, -2.322804916942334}, 
                  0.052478423386308704`], 
                 InsetBox[
                  FormBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJztkKEOwyAURUkm9wdz+wH+oV9AMo2qqB22tq6yrq4KVVWFqqnC1NTUVMxg
EAgMoqJjsNJtqZlcspuQAOfe9x6c4+slPgAATnYd7Xrsl1+TVlIIIZXZQSNL
IAiCKONyDtRM9UoQSYMRceW5KpG7wJV8BsbUmWDauurc8YjJraMZSpdJBmPt
1PFCvc5kBuy7aDuAM8B819BrO0IXrdU2iQYGwzwRP2PZr3huiOOY+pBgqX8Y
zqqua4sk8sdq0CHCKwLelbPp4zONnNqmppQ2jN/0vPz1pe6vbsT7
                    
                    "], {{0, 0}, {11, 26}}, {0, 255}, ColorFunction -> 
                    RGBColor], ImageSize -> {11, 26}, 
                    PlotRange -> {{0, 11}, {0, 26}}], TraditionalForm], 
                  Offset[{2, 2}, {6.0175822137855155`, -2.2703264935560252`}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{6.688016643036104, -3.4306867425232745`}, 
                  0.052478423386308704`], 
                 InsetBox[
                  FormBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmJuIAax/xMFfn///v03bulLM2KARvnPuERAwcSzFCqI
mX8d6JhXT4Hg1XdsChgYHP0dGWDAccbeBxgKgEAvJi3NXw/KmXjiHbICvZgZ
D6BGv1uaBlak1/kKlzffHQLbprfxwW8cvvg03x9sy9l3JChACclXnY7oCoAB
8Qqu/9J8iGf3vkLzZsz8jXu3L+2EejRmKcRbZyc6QoIAEU4gkAYLhv+/Pz29
fv3OJyDj3Z29G1cvXbp0+6Gz7/BE/yjABgAnJqWw
                    "], {{0, 0}, {11,
                     26}}, {0, 255}, ColorFunction -> RGBColor], 
                    ImageSize -> {11, 26}, PlotRange -> {{0, 11}, {0, 26}}], 
                   TraditionalForm], 
                  Offset[{2, 2}, {6.740495066422413, -3.3782083191369656`}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{7.159884817394166, -2.5216057257948923`}, 
                  0.052478423386308704`], 
                 InsetBox[
                  FormBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmJuIAax/5MJfn8Hgt84pT9dmgE03HHiWfwK/ElV8P3d
0wdPnz59BbT59/X5aAourW5igAO9tM5Kf2QFD7ZXwqRiCgpi4AphCp426YEl
C1a/g2h4d6nJXw+h4NNZkHEMjofeITkHyZHfry8Fy09Ekkfxxe8Hq0HG6XXi
UvD/0wmwFf4nPmG34v/vOxA/ODbthSt4sL0J2ZtPYd50LJix99D2GZUxqN4E
mXJoBsL7iADrPIES/g8ubV+9eunS1XvP3vn+//vTO9cfvPqOK7JGASYAAA9L
rNM=
                    "], {{0, 0}, {11, 26}}, {0, 255}, ColorFunction -> 
                    RGBColor], ImageSize -> {11, 26}, 
                    PlotRange -> {{0, 11}, {0, 26}}], TraditionalForm], 
                  Offset[{2, 2}, {7.2123632407804745`, -2.469127302408584}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{5.104055270980713, -0.873614448207543}, 
                  0.052478423386308704`], 
                 InsetBox[
                  FormBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmJ2IAax/w80uD4/DeiMtKXXkQUvzYgBCvpPPEsfQcfO
E5iCQOGND35jCAKBXtOMGRMnbgQKnp3oCOTHNDU5wqSAgr8/Pb1+/c4nIOPV
9Y2rly5dvZeMYBk8AADIm9Yh
                    "], {{0, 0}, {7, 26}}, {0, 255}, 
                    ColorFunction -> RGBColor], ImageSize -> {7, 26}, 
                    PlotRange -> {{0, 7}, {0, 26}}], TraditionalForm], 
                  Offset[{2, 2}, {5.156533694367022, -0.8211360248212343}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{5.0936340590684415`, -2.420075315170594}, 
                  0.052478423386308704`], 
                 InsetBox[
                  FormBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmIOIAax/w8s+P391VMQePfpO1Tk+9ONEwsYkIBj2vwH
v/9fmugI4cYUNE2cWAnlVG7//+lSU1rTiacw7a/2gqQcJ6JZc3ZpJQOy+PdX
h1bPiNGDWdF5CCj27uxSPSRrO1efBRn6/VIMRMC/cuPZO9/hRn466w92wQOY
wHeIF75fAoszFMzYfv362dWdaUD2xBOvgDLXV1cyoIKm7VDdn55e37tx9dKl
SzduP/Hg02+qB/PgAQC7PPiW
                    "], {{0, 0}, {8, 26}}, {0, 255}, 
                    ColorFunction -> RGBColor], ImageSize -> {8, 26}, 
                    PlotRange -> {{0, 8}, {0, 26}}], TraditionalForm], 
                  Offset[{2, 2}, {5.14611248245475, -2.3675968917842853`}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{4.0893098597948505`, -0.8083910213367735}, 
                  0.052478423386308704`], 
                 InsetBox[
                  FormBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmJ2IAax/9Md/P707unTp6/effoNE7m+sYkBBhwnngUr
uhQD4funFcQ4Fqy+DhT7fmc1SESv6SmSaZ8uzQArm/EJU9CRBMF3yC68Ph9s
5vzvcBduX1oZo8cAsX7ijImdEw89/d7JgA6aTrz79OrVg0sbHUG8ghMPHty5
fucVxJTvYB+huvP/97P+QMGY+SiCgwwAAFKhuT4=
                    "], {{0, 0}, {7, 
                    26}}, {0, 255}, ColorFunction -> RGBColor], 
                    ImageSize -> {7, 26}, PlotRange -> {{0, 7}, {0, 26}}], 
                   TraditionalForm], 
                  Offset[{2, 2}, {4.141788283181159, -0.7559125979504648}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{6.215695355594371, -2.9999022913880706`}, 
                  0.052478423386308704`], 
                 InsetBox[
                  FormBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmJuIAax/w8p8OnV0wdPn7569x2r5MYmfwYY8G/aeP3E
fCBjxtlPEOlXhzqhco4xMf56cJUTz76DKDg7EaRdr2AjxPTrG5vQFFyaEQPk
Vm5/CrfyRKc/pgK4jXARNAVw7oAoODvREcjtPIFQgCby/dWD69fvIIfx93dP
gSKvPv3GFuyjADsAAOt53ho=
                    "], {{0, 0}, {11, 26}}, {0, 255},
                     ColorFunction -> RGBColor], ImageSize -> {11, 26}, 
                    PlotRange -> {{0, 11}, {0, 26}}], TraditionalForm], 
                  Offset[{2, 2}, {6.26817377898068, -2.9474238680017617`}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{0.8717601828076917, -3.141020808670527}, 
                  0.052478423386308704`], 
                 InsetBox[
                  FormBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmJOIAax/w8dcKLTnwEE0i59R5X4faeAAQqaDr1Clnl3
diIDHKStRtL3e3uBHlBs4qETnY5A2v/EJ5jM97MxINUxl37/PwuWK9j4ACLz
dHsTxJzf//9/ujQDxPafD9b3aSlYT9Pep0jucdwLdMurvY5g087CzD/UBBJI
W3r9ztI0uGkQADXTceJEkNMYKvci++UOWDXDqwd3rl9/8On3f2TwDixIZrAO
ZQAAtf1PUg==
                    "], {{0, 0}, {9, 26}}, {0, 255}, 
                    ColorFunction -> RGBColor], ImageSize -> {9, 26}, 
                    PlotRange -> {{0, 9}, {0, 26}}], TraditionalForm], 
                  Offset[{2, 2}, {0.9242386061940004, -3.088542385284218}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{1.7291396205785987`, -2.7951101292059013`}, 
                  0.052478423386308704`], 
                 InsetBox[
                  FormBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJztUaGShDAM7cz6+4Bz+wP8A1/AzGrUitqrXYtD4upQqCoUCnOqpgaDqajB
IBCYigouCWWX/YFTm5nOpC8vb16S6/3ndr8wxr7hfcHDfPvE8psyjKKfIuIH
TkhW6TNx6guCWfLoAiHrIFmEyvlFDJ1IDvzhCDIyjwhL+yc1WIGcvCqw2jpQ
XSS4Sbgs+dmStw225o0bMRHttHmNtrmaxnq3tDPHmpPzAVIUFd1kJLXaLQwZ
quyW1po+lVlBvgFqInYbjfVQlVRVYGnVlGZIBNGGH4MIG16jcWUXXRJRrnE4
FXcg2rd1caUL3E9amecedlEwe5zA0FEyP7txtLM/ncvZdyTMgNjT+j/xv/EH
JeF/Zw==
                    "], {{0, 0}, {14, 26}}, {0, 255}, ColorFunction -> 
                    RGBColor], ImageSize -> {14, 26}, 
                    PlotRange -> {{0, 14}, {0, 26}}], TraditionalForm], 
                  Offset[{2, 2}, {1.7816180439649074`, -2.7426317058195924`}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{3.188711043481997, -2.607258064208528}, 
                  0.052478423386308704`], 
                 InsetBox[
                  FormBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmJOIAax/w96MN8f6EyGgtV34CKHOsFCaavfnZ0IYjD4
n/gEEv9+fSmYy7D0+vf//39vL9ADsvWaDv3//64TxGRw7DwBNeLTCbARjgUF
MWAdlXeQbHywvZIBBmZc+oTimu+XYqAyeie+o8icgLgKDByb9iJ0QF3luP36
iQKE84DgKcRV/hNBrnqwGizpOPHV//93lkIsKbjzG2LG0yYwP2bpne+vHly/
fv3BK4TdEJGn71BdMzIAAB4dQJ4=
                    "], {{0, 0}, {9, 26}}, {0, 
                    255}, ColorFunction -> RGBColor], ImageSize -> {9, 26}, 
                    PlotRange -> {{0, 9}, {0, 26}}], TraditionalForm], 
                  Offset[{2, 2}, {3.241189466868306, -2.554779640822219}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{0.8083910213367735, -2.6803280265469525`}, 
                  0.052478423386308704`], 
                 InsetBox[
                  FormBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJzlUKEOgzAQbTK1X5jbD/AP/YIm01WI2WFnccg6HAqFmkJhpmYwmBpEDaai
AlNRsXFXWGia7Af2kkuu967v3t05vV3SAyHktMRxCcjfP+CsMdoYGzNDyQgi
YYUM+XmoKWXU06ya489WZgmQojcxqZ8FcNcmnurG2ou+ItEuXwfeWxXO6jnZ
wAMz6nGHmmhK6KCd/jJGoFitloEcvYyrmDeQ5BrMNJDT0uwM8GrA15TDgkk7
uc0A5oheMOyU3sD+RFaiPi0E3idrp73fDJfQapRynF2wpYFiuPh/4ANLGjIw

                    "], {{0, 0}, {9, 26}}, {0, 255}, ColorFunction -> 
                    RGBColor], ImageSize -> {9, 26}, 
                    PlotRange -> {{0, 9}, {0, 26}}], TraditionalForm], 
                  Offset[{2, 2}, {0.8608694447230822, -2.6278496031606435`}], 
                  
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 
                 DiskBox[{3.6377999851433134`, -1.7113080955758058`}, 
                  0.052478423386308704`], 
                 InsetBox[
                  FormBox[
                   GraphicsBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmJmYGCQAmJOIAax/w96cGl+DAMI6OkxIIOYs5/+31mdBuPq+Ts6
6oEBA0MaUOr//1cTHcESlXuxGPp0O8S0zkOvMCXvrC6AW4EBPs33B0umrf6O
KfnuENhOhsrtTzElXx3qBEv6H3oHFdg4YyIYzJg/owDmrfkgOz+dQPUs1I+H
QHK/Xz24gwGe/iY+QIcRAAA9XkVU
                    "], {{0, 0}, {9, 26}}, {0, 
                    255}, ColorFunction -> RGBColor], ImageSize -> {9, 26}, 
                    PlotRange -> {{0, 9}, {0, 26}}], TraditionalForm], 
                  Offset[{2, 2}, {3.690278408529622, -1.658829672189497}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}}}], 
             MouseAppearanceTag["NetworkGraphics"]], 
            AllowKernelInitialization -> False]], 
          DefaultBaseStyle -> {
           "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
            Hue[0.8, 1., 0.6]}, FormatType -> TraditionalForm, FrameTicks -> 
          None, GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]]]], "ExerciseOutput", Selectable -> False, 
        Copyable -> False, Editable -> False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"70e1a13f-5e4d-463a-ba45-161e6eb76838"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Generate a table of the results of using ",
 ButtonBox["TextRecognize",
  BaseStyle->"Link"],
 " on ",
 Cell[BoxData[
 "\"\<hello\>\""], "InlineCode",ExpressionUUID->
  "63c75c38-351f-47f1-9a9d-fd3e7fa38d25"],
 " rasterized at size 50 and then blurred by between 1 and 10.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "22.14", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->False,
 CellTags->
  "LastCellOfAPage",ExpressionUUID->"800d8988-2274-4784-a0e4-00a8d3fa0eec"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       RowBox[{"{", 
        RowBox[{"\<\"hello\"\>", ",", "\<\"hello\"\>", ",", "\<\"hello\"\>", 
         ",", "\<\"hello\"\>", ",", "\<\"hello\"\>", ",", "\<\"hello\"\>", 
         ",", "\<\"hllo\"\>", ",", "\<\"\"\>", ",", "\<\"\"\>", 
         ",", "\<\"\"\>"}], "}"}]], "ExerciseOutput",ExpressionUUID->
       "5af01b34-1819-476f-87f2-3504c73c41b7"],
      Apply[TextCell, 
       Cell[
        BoxData[
         RowBox[{"{", 
           
           RowBox[{"\"hello\"", ",", "\"hello\"", ",", "\"hello\"", ",", 
             "\"hello\"", ",", "\"hello\"", ",", "\"hello\"", ",", "\"hllo\"",
              ",", "\"\"", ",", "\"\"", ",", "\"\""}], "}"}]], 
        "ExerciseOutput", Selectable -> False, Copyable -> False, Editable -> 
        False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"cbdd312b-9b18-426e-848f-9897e0c8bb7c"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Make a table of image identifications for a picture of the Eiffel Tower, \
blurred by an amount from 1 to 5.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "+22.1", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"e8dd0568-ac6f-4f65-aa1d-4b6db873c094"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       RowBox[{"{", 
        RowBox[{
         TemplateBox[{"\"Eiffel Tower\"",RowBox[{"Entity", "[", 
             RowBox[{"\"Building\"", ",", "\"EiffelTower::5h9w8\""}], "]"}],
           "\"Entity[\\\"Building\\\", \\\"EiffelTower::5h9w8\\\"]\"",
           "\"building\""},
          "Entity"], ",", 
         TemplateBox[{"\"tower\"",RowBox[{"Entity", "[", 
             RowBox[{"\"Concept\"", ",", "\"Tower::72xxm\""}], "]"}],
           "\"Entity[\\\"Concept\\\", \\\"Tower::72xxm\\\"]\"","\"concept\""},
          
          "Entity"], ",", 
         TemplateBox[{"\"tower\"",RowBox[{"Entity", "[", 
             RowBox[{"\"Concept\"", ",", "\"Tower::72xxm\""}], "]"}],
           "\"Entity[\\\"Concept\\\", \\\"Tower::72xxm\\\"]\"","\"concept\""},
          
          "Entity"], ",", 
         TemplateBox[{"\"tower\"",RowBox[{"Entity", "[", 
             RowBox[{"\"Concept\"", ",", "\"Tower::72xxm\""}], "]"}],
           "\"Entity[\\\"Concept\\\", \\\"Tower::72xxm\\\"]\"","\"concept\""},
          
          "Entity"], ",", 
         TemplateBox[{"\"device\"",RowBox[{"Entity", "[", 
             RowBox[{"\"Concept\"", ",", "\"Device::f2cw8\""}], "]"}],
           "\"Entity[\\\"Concept\\\", \\\"Device::f2cw8\\\"]\"","\"concept\""},
          "Entity"]}], "}"}]], "ExerciseOutput",ExpressionUUID->
       "7bce2872-d36d-44d4-8825-8eb67da0727b"],
      Apply[TextCell, 
       Cell[
        BoxData[
         RowBox[{"{", 
           RowBox[{
             TemplateBox[{"\"Eiffel Tower\"", 
               RowBox[{"Entity", "[", 
                 RowBox[{"\"Building\"", ",", "\"EiffelTower::5h9w8\""}], 
                 "]"}], "\"Entity[\\\"Building\\\", \
\\\"EiffelTower::5h9w8\\\"]\"", "\"building\""}, "Entity"], ",", 
             TemplateBox[{"\"tower\"", 
               RowBox[{"Entity", "[", 
                 RowBox[{"\"Concept\"", ",", "\"Tower::72xxm\""}], "]"}], 
               "\"Entity[\\\"Concept\\\", \\\"Tower::72xxm\\\"]\"", 
               "\"concept\""}, "Entity"], ",", 
             TemplateBox[{"\"tower\"", 
               RowBox[{"Entity", "[", 
                 RowBox[{"\"Concept\"", ",", "\"Tower::72xxm\""}], "]"}], 
               "\"Entity[\\\"Concept\\\", \\\"Tower::72xxm\\\"]\"", 
               "\"concept\""}, "Entity"], ",", 
             TemplateBox[{"\"tower\"", 
               RowBox[{"Entity", "[", 
                 RowBox[{"\"Concept\"", ",", "\"Tower::72xxm\""}], "]"}], 
               "\"Entity[\\\"Concept\\\", \\\"Tower::72xxm\\\"]\"", 
               "\"concept\""}, "Entity"], ",", 
             TemplateBox[{"\"device\"", 
               RowBox[{"Entity", "[", 
                 RowBox[{"\"Concept\"", ",", "\"Device::f2cw8\""}], "]"}], 
               "\"Entity[\\\"Concept\\\", \\\"Device::f2cw8\\\"]\"", 
               "\"concept\""}, "Entity"]}], "}"}]], "ExerciseOutput", 
        Selectable -> False, Copyable -> False, Editable -> False, 
        ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"84b175be-6b4b-4e99-ae56-dac95aab1e6a"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Classify the sentiment of the Wikipedia article on \
\[OpenCurlyDoubleQuote]happiness\[CloseCurlyDoubleQuote].",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "+22.2", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"402d0874-5657-4df2-b738-11e8685defdc"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[
      BoxData["\<\"Neutral\"\>"], "ExerciseOutput",ExpressionUUID->
       "6c0c3ad0-918d-47b3-8c84-073400d929b2"],
      Apply[TextCell, 
       Cell[
        BoxData["\"Neutral\""], "ExerciseOutput", Selectable -> False, 
        Copyable -> False, Editable -> False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"384a5a69-084e-4736-9bf9-8b700e7144a6"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Of colors in the list ",
 Cell[BoxData[
  RowBox[{
   ButtonBox["Table",
    BaseStyle->"CodeLink"], "[", 
   RowBox[{
    RowBox[{
     ButtonBox["Hue",
      BaseStyle->"CodeLink"], "[", "h", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"h", ",", "0", ",", "1", ",", ".05"}], "}"}]}], "]"}]], 
  "InlineCode",ExpressionUUID->"fad8f373-2a9b-431a-b0a9-33372f83bd6b"],
 ", find which are the 3 nearest to ",
 ButtonBox["Pink",
  BaseStyle->"Link"],
 ".",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "+22.3", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"fd25f862-e39d-42ba-8a25-e73d01f5771b"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       RowBox[{"{", 
        RowBox[{
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{{{{
                 {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                 {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                 {Hue[0.9500000000000001], RectangleBox[{0, -1}, {2, 1}]}}}}},
             
             AspectRatio->1,
             Frame->True,
             FrameStyle->Hue[0.9500000000000001, 1., 0.6666666666666667],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            "Hue[0.9500000000000001]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               Hue[0.9500000000000001, 0.5, 0.5]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["HueColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          Hue[0.9500000000000001],
          Editable->False,
          Selectable->False], ",", 
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{{{{
                 {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                 {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                 {Hue[0.9], RectangleBox[{0, -1}, {2, 1}]}}}}},
             AspectRatio->1,
             Frame->True,
             FrameStyle->Hue[0.9, 1., 0.6666666666666667],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            "Hue[0.9]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               Hue[0.9, 0.5, 0.5]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["HueColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          Hue[0.9],
          Editable->False,
          Selectable->False], ",", 
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{{{{
                 {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                 {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                 {Hue[0.05], RectangleBox[{0, -1}, {2, 1}]}}}}},
             AspectRatio->1,
             Frame->True,
             FrameStyle->Hue[0.05000000000000001, 1., 0.6666666666666667],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            "Hue[0.05]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               Hue[0.05, 0.5, 0.5]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["HueColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          Hue[0.05],
          Editable->False,
          Selectable->False]}], "}"}]], "ExerciseOutput",ExpressionUUID->
       "d9796269-ea7e-4c00-931e-07dac5f2c4fc"],
      Apply[TextCell, 
       Cell[
        BoxData[
         RowBox[{"{", 
           RowBox[{
             InterpretationBox[
              ButtonBox[
               TooltipBox[
                GraphicsBox[{{
                   GrayLevel[0], 
                   RectangleBox[{0, 0}]}, {
                   GrayLevel[0], 
                   RectangleBox[{1, -1}]}, {
                   Hue[0.9500000000000001], 
                   RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                 True, FrameStyle -> 
                 Hue[0.9500000000000001, 1., 0.6666666666666667], FrameTicks -> 
                 None, ImageSize -> 
                 Dynamic[{
                   Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                "Hue[0.9500000000000001]"], Appearance -> None, 
               BaseStyle -> {}, BaselinePosition -> Baseline, ButtonFunction :> 
               With[{Typeset`box$ = EvaluationBox[]}, 
                 If[
                  Not[
                   AbsoluteCurrentValue["Deployed"]], 
                  SelectionMove[Typeset`box$, All, Expression]; 
                  FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                  FrontEnd`Private`$ColorSelectorInitialColor = 
                   Hue[0.9500000000000001, 0.5, 0.5]; 
                  FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                  MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
               Automatic, Method -> "Preemptive"], 
              Hue[0.9500000000000001], Editable -> False, Selectable -> 
              False], ",", 
             InterpretationBox[
              ButtonBox[
               TooltipBox[
                GraphicsBox[{{
                   GrayLevel[0], 
                   RectangleBox[{0, 0}]}, {
                   GrayLevel[0], 
                   RectangleBox[{1, -1}]}, {
                   Hue[0.9], 
                   RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                 True, FrameStyle -> Hue[0.9, 1., 0.6666666666666667], 
                 FrameTicks -> None, ImageSize -> 
                 Dynamic[{
                   Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], "Hue[0.9]"],
                Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
               Baseline, ButtonFunction :> 
               With[{Typeset`box$ = EvaluationBox[]}, 
                 If[
                  Not[
                   AbsoluteCurrentValue["Deployed"]], 
                  SelectionMove[Typeset`box$, All, Expression]; 
                  FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                  FrontEnd`Private`$ColorSelectorInitialColor = 
                   Hue[0.9, 0.5, 0.5]; 
                  FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                  MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
               Automatic, Method -> "Preemptive"], 
              Hue[0.9], Editable -> False, Selectable -> False], ",", 
             InterpretationBox[
              ButtonBox[
               TooltipBox[
                GraphicsBox[{{
                   GrayLevel[0], 
                   RectangleBox[{0, 0}]}, {
                   GrayLevel[0], 
                   RectangleBox[{1, -1}]}, {
                   Hue[0.05], 
                   RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                 True, FrameStyle -> 
                 Hue[0.05000000000000001, 1., 0.6666666666666667], FrameTicks -> 
                 None, ImageSize -> 
                 Dynamic[{
                   Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                "Hue[0.05]"], Appearance -> None, BaseStyle -> {}, 
               BaselinePosition -> Baseline, ButtonFunction :> 
               With[{Typeset`box$ = EvaluationBox[]}, 
                 If[
                  Not[
                   AbsoluteCurrentValue["Deployed"]], 
                  SelectionMove[Typeset`box$, All, Expression]; 
                  FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                  FrontEnd`Private`$ColorSelectorInitialColor = 
                   Hue[0.05, 0.5, 0.5]; 
                  FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                  MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
               Automatic, Method -> "Preemptive"], 
              Hue[0.05], Editable -> False, Selectable -> False]}], "}"}]], 
        "ExerciseOutput", Selectable -> False, Copyable -> False, Editable -> 
        False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"fff8119a-3f0c-4173-a8bf-3b5d003a30a1"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Compute all fractions ",
 Cell[BoxData[
  RowBox[{"i", "/", "j"}]], "InlineCode",ExpressionUUID->
  "6636c5e4-6140-45d1-94ff-ca29407bfe46"],
 " for ",
 Cell[BoxData[
 "i"], "InlineCode",ExpressionUUID->"f28fe2b4-bd9a-48e3-836e-2a8b013f7de6"],
 " and ",
 Cell[BoxData[
 "j"], "InlineCode",ExpressionUUID->"dcd4a4df-a168-45bb-99d9-de640685f01d"],
 " up to 500, and find the 10 fractions closest to pi.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "+22.4", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"eb5d1a48-d850-4d4d-9a6d-e76b8c98c58b"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       RowBox[{"{", 
        RowBox[{
         FractionBox["355", "113"], ",", 
         FractionBox["377", "120"], ",", 
         FractionBox["333", "106"], ",", 
         FractionBox["399", "127"], ",", 
         FractionBox["311", "99"], ",", 
         FractionBox["421", "134"], ",", 
         FractionBox["443", "141"], ",", 
         FractionBox["289", "92"], ",", 
         FractionBox["465", "148"], ",", 
         FractionBox["487", "155"]}], "}"}]], "ExerciseOutput",
       ExpressionUUID->"caa91ad9-8242-4649-b0aa-3f3168c0edb6"],
      Apply[TextCell, 
       Cell[
        BoxData[
         RowBox[{"{", 
           RowBox[{
             FractionBox["355", "113"], ",", 
             FractionBox["377", "120"], ",", 
             FractionBox["333", "106"], ",", 
             FractionBox["399", "127"], ",", 
             FractionBox["311", "99"], ",", 
             FractionBox["421", "134"], ",", 
             FractionBox["443", "141"], ",", 
             FractionBox["289", "92"], ",", 
             FractionBox["465", "148"], ",", 
             FractionBox["487", "155"]}], "}"}]], "ExerciseOutput", 
        Selectable -> False, Copyable -> False, Editable -> False, 
        ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"93721613-8848-4523-b94c-89929c180185"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Generate a list of 10 random numbers from 0 to 10, and make a graph of the \
3 nearest neighbors of each one.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "+22.5", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"d989f328-8ffe-48e0-b58e-c87ba6927775"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       GraphicsBox[
        NamespaceBox["NetworkGraphics",
         DynamicModuleBox[{Typeset`graph = HoldComplete[
           Graph[{8, 9, 6, 2, 5, 7, 0, 10}, {Null, 
             SparseArray[
             Automatic, {8, 8}, 0, {
              1, {{0, 5, 8, 13, 16, 21, 26, 29, 32}, {{2}, {3}, {5}, {6}, {
                8}, {1}, {6}, {8}, {1}, {4}, {5}, {6}, {7}, {3}, {5}, {7}, {
                1}, {3}, {4}, {6}, {7}, {1}, {2}, {3}, {5}, {8}, {3}, {4}, {
                5}, {1}, {2}, {6}}}, Pattern}]}, {
            GraphLayout -> "LinearEmbedding", 
             VertexCoordinates -> {{8, 0}, {9, 0}, {6, 0}, {2, 0}, {5, 0}, {7,
               0}, {0, 0}, {10, 0}}, VertexLabels -> {All}}]]}, 
          TagBox[GraphicsGroupBox[{{{{
                {Hue[0.6, 0.7, 0.5], Opacity[0.7], 
                 BezierCurveBox[{{8., 0.}, {8.5, 0.5}, {9., 0.}}], 
                 BezierCurveBox[{{8., 0.}, {7., 1.}, {6., 0.}}], 
                 BezierCurveBox[{{8., 0.}, {6.5, 1.5}, {5., 0.}}], 
                 BezierCurveBox[{{8., 0.}, {7.5, 0.5}, {7., 0.}}], 
                 BezierCurveBox[{{8., 0.}, {9., 1.}, {10., 0.}}], 
                 BezierCurveBox[{{9., 0.}, {8., 1.}, {7., 0.}}], 
                 BezierCurveBox[{{9., 0.}, {9.5, 0.5}, {10., 0.}}], 
                 BezierCurveBox[{{6., 0.}, {4., 2.}, {2., 0.}}], 
                 BezierCurveBox[{{6., 0.}, {5.5, 0.5}, {5., 0.}}], 
                 BezierCurveBox[{{6., 0.}, {6.5, 0.5}, {7., 0.}}], 
                 BezierCurveBox[{{6., 0.}, {3., 3.}, {0., 0.}}], 
                 BezierCurveBox[{{2., 0.}, {3.5, 1.5}, {5., 0.}}], 
                 BezierCurveBox[{{2., 0.}, {1., 1.}, {0., 0.}}], 
                 BezierCurveBox[{{5., 0.}, {6., 1.}, {7., 0.}}], 
                 BezierCurveBox[{{5., 0.}, {2.5, 2.5}, {0., 0.}}], 
                 BezierCurveBox[{{7., 0.}, {8.5, 1.5}, {10., 0.}}]}}}}, {{{
                {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
                 0.7]}], {DiskBox[{8., 0.}, 0.06561181434599156], 
                  InsetBox["8", 
                   Offset[{2, 2}, {8.065611814345992, 0.06561181434599156}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{9., 0.}, 0.06561181434599156], 
                  InsetBox["9", 
                   Offset[{2, 2}, {9.065611814345992, 0.06561181434599156}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{6., 0.}, 0.06561181434599156], 
                  InsetBox["6", 
                   Offset[{2, 2}, {6.065611814345991, 0.06561181434599156}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{2., 0.}, 0.06561181434599156], 
                  InsetBox["2", 
                   Offset[{2, 2}, {2.0656118143459916, 0.06561181434599156}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{5., 0.}, 0.06561181434599156], 
                  InsetBox["5", 
                   Offset[{2, 2}, {5.065611814345991, 0.06561181434599156}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{7., 0.}, 0.06561181434599156], 
                  InsetBox["7", 
                   Offset[{2, 2}, {7.065611814345991, 0.06561181434599156}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{0., 0.}, 0.06561181434599156], 
                  InsetBox["0", 
                   Offset[{2, 2}, {0.06561181434599156, 0.06561181434599156}],
                    ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}, {
                  DiskBox[{10., 0.}, 0.06561181434599156], 
                  InsetBox["10", 
                   Offset[{2, 2}, {10.065611814345992, 0.06561181434599156}], 
                   ImageScaled[{0, 0}],
                   BaseStyle->"Graphics"]}}}}}}],
           MouseAppearanceTag["NetworkGraphics"]],
          AllowKernelInitialization->False]],
        DefaultBaseStyle->{
         "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
          Hue[0.8, 1., 0.6]},
        FrameTicks->None,
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]]]], "ExerciseOutput",ExpressionUUID->
       "31505f18-8e42-42c5-858b-927522e6aa0b"],
      Apply[TextCell, 
       Cell[
        BoxData[
         GraphicsBox[
          NamespaceBox["NetworkGraphics", 
           DynamicModuleBox[{Typeset`graph = HoldComplete[
               Graph[{8, 9, 6, 2, 5, 7, 0, 10}, {Null, 
                 SparseArray[
                 Automatic, {8, 8}, 0, {
                  1, {{0, 5, 8, 13, 16, 21, 26, 29, 32}, {{2}, {3}, {5}, {
                    6}, {8}, {1}, {6}, {8}, {1}, {4}, {5}, {6}, {7}, {3}, {
                    5}, {7}, {1}, {3}, {4}, {6}, {7}, {1}, {2}, {3}, {5}, {
                    8}, {3}, {4}, {5}, {1}, {2}, {6}}}, Pattern}]}, {
                GraphLayout -> "LinearEmbedding", 
                 VertexCoordinates -> {{8, 0}, {9, 0}, {6, 0}, {2, 0}, {5, 
                  0}, {7, 0}, {0, 0}, {10, 0}}, VertexLabels -> {All}}]]}, 
            TagBox[
             GraphicsGroupBox[{{
                Hue[0.6, 0.7, 0.5], 
                Opacity[0.7], 
                BezierCurveBox[{{8., 0.}, {8.5, 0.5}, {9., 0.}}], 
                BezierCurveBox[{{8., 0.}, {7., 1.}, {6., 0.}}], 
                BezierCurveBox[{{8., 0.}, {6.5, 1.5}, {5., 0.}}], 
                BezierCurveBox[{{8., 0.}, {7.5, 0.5}, {7., 0.}}], 
                BezierCurveBox[{{8., 0.}, {9., 1.}, {10., 0.}}], 
                BezierCurveBox[{{9., 0.}, {8., 1.}, {7., 0.}}], 
                BezierCurveBox[{{9., 0.}, {9.5, 0.5}, {10., 0.}}], 
                BezierCurveBox[{{6., 0.}, {4., 2.}, {2., 0.}}], 
                BezierCurveBox[{{6., 0.}, {5.5, 0.5}, {5., 0.}}], 
                BezierCurveBox[{{6., 0.}, {6.5, 0.5}, {7., 0.}}], 
                BezierCurveBox[{{6., 0.}, {3., 3.}, {0., 0.}}], 
                BezierCurveBox[{{2., 0.}, {3.5, 1.5}, {5., 0.}}], 
                BezierCurveBox[{{2., 0.}, {1., 1.}, {0., 0.}}], 
                BezierCurveBox[{{5., 0.}, {6., 1.}, {7., 0.}}], 
                BezierCurveBox[{{5., 0.}, {2.5, 2.5}, {0., 0.}}], 
                BezierCurveBox[{{7., 0.}, {8.5, 1.5}, {10., 0.}}]}, {
                Hue[0.6, 0.2, 0.8], 
                EdgeForm[{
                  GrayLevel[0], 
                  Opacity[0.7]}], {
                 DiskBox[{8., 0.}, 0.06561181434599156], 
                 InsetBox["8", 
                  Offset[{2, 2}, {8.065611814345992, 0.06561181434599156}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 DiskBox[{9., 0.}, 0.06561181434599156], 
                 InsetBox["9", 
                  Offset[{2, 2}, {9.065611814345992, 0.06561181434599156}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 DiskBox[{6., 0.}, 0.06561181434599156], 
                 InsetBox["6", 
                  Offset[{2, 2}, {6.065611814345991, 0.06561181434599156}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 DiskBox[{2., 0.}, 0.06561181434599156], 
                 InsetBox["2", 
                  Offset[{2, 2}, {2.0656118143459916`, 0.06561181434599156}], 
                  
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 DiskBox[{5., 0.}, 0.06561181434599156], 
                 InsetBox["5", 
                  Offset[{2, 2}, {5.065611814345991, 0.06561181434599156}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 DiskBox[{7., 0.}, 0.06561181434599156], 
                 InsetBox["7", 
                  Offset[{2, 2}, {7.065611814345991, 0.06561181434599156}], 
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 DiskBox[{0., 0.}, 0.06561181434599156], 
                 InsetBox["0", 
                  Offset[{2, 2}, {0.06561181434599156, 0.06561181434599156}], 
                  
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, {
                 DiskBox[{10., 0.}, 0.06561181434599156], 
                 InsetBox["10", 
                  Offset[{2, 2}, {10.065611814345992`, 0.06561181434599156}], 
                  
                  ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}}}], 
             MouseAppearanceTag["NetworkGraphics"]], 
            AllowKernelInitialization -> False]], 
          DefaultBaseStyle -> {
           "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
            Hue[0.8, 1., 0.6]}, FrameTicks -> None, GridLinesStyle -> 
          Directive[
            GrayLevel[0.5, 0.4]]]], "ExerciseOutput", Selectable -> False, 
        Copyable -> False, Editable -> False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"2c8ef976-8290-4d66-b05f-de76f924ed5b"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Find clusters of similar colors in a list of 100 random colors.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "+22.6", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"57d1b963-1c62-41cc-aa4b-fd8f2a310349"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.8116438051434329, 0.8547919864863347, 
                    0.7807710853793401], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.541095870095622, 0.5698613243242232, 0.5205140569195601],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.8116438051434329, 0.8547919864863347, \
0.7807710853793401]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.8116438051434329, 0.8547919864863347, 0.7807710853793401]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.8116438051434329, 0.8547919864863347, 0.7807710853793401],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.2983278570382957, 0.9907444932950316, 
                    0.9284043344039434], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.19888523802553046`, 0.6604963288633544, 0.6189362229359623],
               
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.2983278570382957, 0.9907444932950316, \
0.9284043344039434]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.2983278570382957, 0.9907444932950316, 0.9284043344039434]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.2983278570382957, 0.9907444932950316, 0.9284043344039434],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.18676117011450066`, 0.5486089602170863, 
                    0.04303247680226141], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.12450744674300045`, 0.3657393068113909, 
                 0.028688317868174273`],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.18676117011450066, 0.5486089602170863, \
0.04303247680226141]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.18676117011450066`, 0.5486089602170863, 
                   0.04303247680226141]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.18676117011450066`, 0.5486089602170863, 0.04303247680226141],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.4044608902823441, 0.9788998961090443, 
                    0.8108975624714536], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.2696405935215628, 0.6525999307393628, 0.5405983749809691],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.4044608902823441, 0.9788998961090443, \
0.8108975624714536]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.4044608902823441, 0.9788998961090443, 0.8108975624714536]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.4044608902823441, 0.9788998961090443, 0.8108975624714536],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.5308001574813235, 0.9503472359039511, 
                    0.8646083755834806], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.35386677165421565`, 0.6335648239359675, 0.5764055837223204],
               
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.5308001574813235, 0.9503472359039511, \
0.8646083755834806]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.5308001574813235, 0.9503472359039511, 0.8646083755834806]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.5308001574813235, 0.9503472359039511, 0.8646083755834806],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.5926608241659339, 0.4671421812435703, 
                    0.027570072930602985`], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.3951072161106226, 0.3114281208290469, 0.01838004862040199],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.5926608241659339, 0.4671421812435703, \
0.027570072930602985]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.5926608241659339, 0.4671421812435703, 
                   0.027570072930602985`]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.5926608241659339, 0.4671421812435703, 0.027570072930602985`],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.49843743964638865`, 0.7588128836239783, 
                    0.6588996785867525], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.3322916264309258, 0.5058752557493189, 0.43926645239116835`],
               
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.49843743964638865, 0.7588128836239783, \
0.6588996785867525]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.49843743964638865`, 0.7588128836239783, 
                   0.6588996785867525]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.49843743964638865`, 0.7588128836239783, 0.6588996785867525],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.6788691428209239, 0.8865118691450595, 
                    0.06859340947663295], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.4525794285472826, 0.5910079127633731, 0.04572893965108864],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.6788691428209239, 0.8865118691450595, \
0.06859340947663295]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.6788691428209239, 0.8865118691450595, 
                   0.06859340947663295]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.6788691428209239, 0.8865118691450595, 0.06859340947663295],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.3966954095359472, 0.9303983446364068, 
                    0.27133513969525125`], RectangleBox[{0, -1}, {2, 1}]}}}}},
               
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.26446360635729815`, 0.6202655630909379, 
                 0.18089009313016752`],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.3966954095359472, 0.9303983446364068, \
0.27133513969525125]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.3966954095359472, 0.9303983446364068, 
                   0.27133513969525125`]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.3966954095359472, 0.9303983446364068, 0.27133513969525125`],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.7496777159050012, 0.8414031368083361, 
                    0.29000881481349006`], RectangleBox[{0, -1}, {2, 1}]}}}}},
               
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.4997851439366675, 0.5609354245388908, 0.19333920987566006`],
               
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.7496777159050012, 0.8414031368083361, \
0.29000881481349006]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.7496777159050012, 0.8414031368083361, 
                   0.29000881481349006`]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.7496777159050012, 0.8414031368083361, 0.29000881481349006`],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.1722869702422274, 0.42066881136044554`, 
                    0.18877704427888808`], RectangleBox[{0, -1}, {2, 1}]}}}}},
               
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.11485798016148493`, 0.28044587424029704`, 
                 0.12585136285259207`],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.1722869702422274, 0.42066881136044554, \
0.18877704427888808]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.1722869702422274, 0.42066881136044554`, 
                   0.18877704427888808`]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.1722869702422274, 0.42066881136044554`, 0.18877704427888808`],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.020568097401979735`, 0.32843933224376776`, 
                    0.2578912775452169], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.013712064934653156`, 0.2189595548291785, 
                 0.17192751836347794`],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.020568097401979735, 0.32843933224376776, \
0.2578912775452169]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.020568097401979735`, 0.32843933224376776`, 
                   0.2578912775452169]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.020568097401979735`, 0.32843933224376776`, 0.2578912775452169],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.4276762158276948, 0.9445301871184215, 
                    0.6339408432442302], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.2851174772184632, 0.629686791412281, 0.4226272288294868],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.4276762158276948, 0.9445301871184215, \
0.6339408432442302]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.4276762158276948, 0.9445301871184215, 0.6339408432442302]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.4276762158276948, 0.9445301871184215, 0.6339408432442302],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.3449333805776824, 0.8214093187031501, 
                    0.00535396147946221], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.22995558705178828`, 0.5476062124687668, 
                 0.003569307652974807],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.3449333805776824, 0.8214093187031501, \
0.00535396147946221]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.3449333805776824, 0.8214093187031501, 
                   0.00535396147946221]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.3449333805776824, 0.8214093187031501, 0.00535396147946221],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.9595114792486563, 0.9614567195621035, 
                    0.09956803288245264], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.6396743194991042, 0.6409711463747357, 0.06637868858830176],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.9595114792486563, 0.9614567195621035, \
0.09956803288245264]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.9595114792486563, 0.9614567195621035, 
                   0.09956803288245264]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.9595114792486563, 0.9614567195621035, 0.09956803288245264],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.13927723404143122`, 0.9837658758454813, 
                    0.6275322853052734], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.09285148936095415, 0.6558439172303209, 0.41835485687018226`],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.13927723404143122, 0.9837658758454813, \
0.6275322853052734]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.13927723404143122`, 0.9837658758454813, 
                   0.6275322853052734]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.13927723404143122`, 0.9837658758454813, 0.6275322853052734],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.4129872979782936, 0.599123151026224, 
                    0.5563798982651478], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.2753248653188624, 0.3994154340174827, 0.3709199321767652],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.4129872979782936, 0.599123151026224, \
0.5563798982651478]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.4129872979782936, 0.599123151026224, 0.5563798982651478]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.4129872979782936, 0.599123151026224, 0.5563798982651478],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.5517409716001453, 0.7226268672047083, 
                    0.04296745155978088], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.3678273144000969, 0.48175124480313886`, 
                 0.028644967706520585`],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.5517409716001453, 0.7226268672047083, \
0.04296745155978088]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.5517409716001453, 0.7226268672047083, 
                   0.04296745155978088]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.5517409716001453, 0.7226268672047083, 0.04296745155978088],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.2471012449687613, 0.6622219052252245, 
                    0.34136700529740893`], RectangleBox[{0, -1}, {2, 1}]}}}}},
               
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.16473416331250754`, 0.4414812701501497, 
                 0.22757800353160595`],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.2471012449687613, 0.6622219052252245, \
0.34136700529740893]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.2471012449687613, 0.6622219052252245, 
                   0.34136700529740893`]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.2471012449687613, 0.6622219052252245, 0.34136700529740893`],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.00852878273374924, 0.7623891609381206, 
                    0.495048201930645], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.005685855155832828, 0.5082594406254137, 0.33003213462043],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.00852878273374924, 0.7623891609381206, \
0.495048201930645]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.00852878273374924, 0.7623891609381206, 0.495048201930645]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.00852878273374924, 0.7623891609381206, 0.495048201930645],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.410530117230961, 0.65951899493187, 
                    0.31274019237510875`], RectangleBox[{0, -1}, {2, 1}]}}}}},
               
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.2736867448206407, 0.43967932995458003`, 
                 0.20849346158340584`],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.410530117230961, 0.65951899493187, \
0.31274019237510875]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.410530117230961, 0.65951899493187, 0.31274019237510875`]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.410530117230961, 0.65951899493187, 0.31274019237510875`],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.14914425266109754`, 0.8632288046219025, 
                    0.2165769996518021], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.09942950177406504, 0.575485869747935, 0.14438466643453474`],
               
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.14914425266109754, 0.8632288046219025, \
0.2165769996518021]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.14914425266109754`, 0.8632288046219025, 
                   0.2165769996518021]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.14914425266109754`, 0.8632288046219025, 0.2165769996518021],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.5019554020533212, 0.5771425709059108, 
                    0.4324648041012522], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.3346369347022142, 0.3847617139372739, 0.2883098694008348],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.5019554020533212, 0.5771425709059108, \
0.4324648041012522]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.5019554020533212, 0.5771425709059108, 0.4324648041012522]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.5019554020533212, 0.5771425709059108, 0.4324648041012522],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.2375846642639532, 0.7953276430316651, 
                    0.9346352336682711], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.1583897761759688, 0.5302184286877768, 0.6230901557788474],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.2375846642639532, 0.7953276430316651, \
0.9346352336682711]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.2375846642639532, 0.7953276430316651, 0.9346352336682711]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.2375846642639532, 0.7953276430316651, 0.9346352336682711],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.5670638896981823, 0.30694748662903737`, 
                    0.07724772234151844], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               FrameStyle->RGBColor[
                0.3780425931321216, 0.2046316577526916, 0.0514984815610123],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.5670638896981823, 0.30694748662903737, \
0.07724772234151844]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.5670638896981823, 0.30694748662903737`, 
                   0.07724772234151844]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.5670638896981823, 0.30694748662903737`, 0.07724772234151844],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.9836330486106633, 0.9337141420685637, 
                    0.45110780147188234`], RectangleBox[{0, -1}, {2, 1}]}}}}},
               
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.6557553657404422, 0.6224760947123759, 0.30073853431458825`],
               
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.9836330486106633, 0.9337141420685637, \
0.45110780147188234]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.9836330486106633, 0.9337141420685637, 
                   0.45110780147188234`]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.9836330486106633, 0.9337141420685637, 0.45110780147188234`],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.548151102001315, 0.9273818734933321, 
                    0.6138604019189067], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.3654340680008767, 0.6182545823288881, 0.4092402679459378],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.548151102001315, 0.9273818734933321, \
0.6138604019189067]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.548151102001315, 0.9273818734933321, 0.6138604019189067]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.548151102001315, 0.9273818734933321, 0.6138604019189067],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.08996343949980967, 0.7502285322367264, 
                    0.7647837622874905], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.05997562633320645, 0.5001523548244843, 0.5098558415249936],
               FrameTicks->None,
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.08996343949980967, 0.7502285322367264, \
0.7647837622874905]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.08996343949980967, 0.7502285322367264, 
                   0.7647837622874905]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.08996343949980967, 0.7502285322367264, 0.7647837622874905],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.9554445238224603, 0.9118174885785313, 
                    0.7586039763217882], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.6369630158816402, 0.6078783257190209, 0.5057359842145255],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.9554445238224603, 0.9118174885785313, \
0.7586039763217882]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.9554445238224603, 0.9118174885785313, 0.7586039763217882]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.9554445238224603, 0.9118174885785313, 0.7586039763217882],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.12407876246761118`, 0.8951986963374581, 
                    0.405054951518828], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.08271917497840746, 0.5967991308916387, 0.2700366343458853],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.12407876246761118, 0.8951986963374581, \
0.405054951518828]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.12407876246761118`, 0.8951986963374581, 
                   0.405054951518828]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.12407876246761118`, 0.8951986963374581, 0.405054951518828],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.3518853673765441, 0.6267881822227646, 
                    0.01601455063963053], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.23459024491769606`, 0.41785878814850974`, 
                 0.010676367093087022`],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.3518853673765441, 0.6267881822227646, \
0.01601455063963053]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.3518853673765441, 0.6267881822227646, 
                   0.01601455063963053]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.3518853673765441, 0.6267881822227646, 0.01601455063963053],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.38175543134617906`, 0.6109792496345561, 
                    0.30321055377645356`], RectangleBox[{0, -1}, {2, 1}]}}}}},
               
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.2545036208974527, 0.4073194997563707, 0.2021403691843024],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.38175543134617906, 0.6109792496345561, \
0.30321055377645356]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.38175543134617906`, 0.6109792496345561, 
                   0.30321055377645356`]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.38175543134617906`, 0.6109792496345561, 0.30321055377645356`],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.5015968883258048, 0.9477341972992892, 
                    0.7518749706067847], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.3343979255505366, 0.6318227981995261, 0.5012499804045232],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.5015968883258048, 0.9477341972992892, \
0.7518749706067847]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.5015968883258048, 0.9477341972992892, 0.7518749706067847]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.5015968883258048, 0.9477341972992892, 0.7518749706067847],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.4853791041906068, 0.9983056811536988, 
                    0.059586297674913524`], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.3235860694604046, 0.6655371207691325, 0.03972419844994235],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.4853791041906068, 0.9983056811536988, \
0.059586297674913524]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.4853791041906068, 0.9983056811536988, 
                   0.059586297674913524`]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.4853791041906068, 0.9983056811536988, 0.059586297674913524`],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.39598681356054666`, 0.5894657294683947, 
                    0.2897133293523855], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.26399120904036444`, 0.3929771529789298, 0.193142219568257],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.39598681356054666, 0.5894657294683947, \
0.2897133293523855]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.39598681356054666`, 0.5894657294683947, 
                   0.2897133293523855]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.39598681356054666`, 0.5894657294683947, 0.2897133293523855],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.06510008212093177, 0.7580810151353965, 
                    0.4838966525370989], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.04340005474728785, 0.5053873434235977, 0.322597768358066],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.06510008212093177, 0.7580810151353965, \
0.4838966525370989]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.06510008212093177, 0.7580810151353965, 
                   0.4838966525370989]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.06510008212093177, 0.7580810151353965, 0.4838966525370989],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.02229677965825383, 0.35028891391213257`, 
                    0.0684550207396537], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.01486451977216922, 0.2335259426080884, 
                 0.045636680493102474`],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.02229677965825383, 0.35028891391213257, \
0.0684550207396537]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.02229677965825383, 0.35028891391213257`, 
                   0.0684550207396537]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.02229677965825383, 0.35028891391213257`, 0.0684550207396537],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.15578960479774717`, 0.33156505911261824`, 
                    0.10795082362400787`], RectangleBox[{0, -1}, {2, 1}]}}}}},
               
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.10385973653183145`, 0.22104337274174551`, 
                 0.07196721574933859],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.15578960479774717, 0.33156505911261824, \
0.10795082362400787]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.15578960479774717`, 0.33156505911261824`, 
                   0.10795082362400787`]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.15578960479774717`, 0.33156505911261824`, 0.10795082362400787`],
            
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.9666406011133539, 0.6653552686335491, 
                    0.5546554666254075], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.6444270674089027, 0.44357017908903273`, 
                 0.36977031108360503`],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.9666406011133539, 0.6653552686335491, \
0.5546554666254075]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.9666406011133539, 0.6653552686335491, 0.5546554666254075]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.9666406011133539, 0.6653552686335491, 0.5546554666254075],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.21832422216206182`, 0.4452088456726624, 
                    0.34195667187604584`], RectangleBox[{0, -1}, {2, 1}]}}}}},
               
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.14554948144137456`, 0.2968058971151083, 
                 0.22797111458403058`],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.21832422216206182, 0.4452088456726624, \
0.34195667187604584]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.21832422216206182`, 0.4452088456726624, 
                   0.34195667187604584`]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.21832422216206182`, 0.4452088456726624, 0.34195667187604584`],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.4939446101923697, 0.31678858836269796`, 
                    0.11346988660388835`], RectangleBox[{0, -1}, {2, 1}]}}}}},
               
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.3292964067949131, 0.21119239224179864`, 0.0756465910692589],
               
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.4939446101923697, 0.31678858836269796, \
0.11346988660388835]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.4939446101923697, 0.31678858836269796`, 
                   0.11346988660388835`]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.4939446101923697, 0.31678858836269796`, 0.11346988660388835`],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.9566388456878347, 0.9651195544633302, 
                    0.9076564789046491], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.6377592304585565, 0.6434130363088868, 0.605104319269766],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.9566388456878347, 0.9651195544633302, \
0.9076564789046491]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.9566388456878347, 0.9651195544633302, 0.9076564789046491]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.9566388456878347, 0.9651195544633302, 0.9076564789046491],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.4000855073593619, 0.39588066174906866`, 
                    0.1685452332949151], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.26672367157290794`, 0.2639204411660458, 
                 0.11236348886327674`],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.4000855073593619, 0.39588066174906866, \
0.1685452332949151]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.4000855073593619, 0.39588066174906866`, 
                   0.1685452332949151]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.4000855073593619, 0.39588066174906866`, 0.1685452332949151],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.5700736595139675, 0.4069545472059297, 
                    0.1981313907220874], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.380049106342645, 0.27130303147061985`, 0.13208759381472496`],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.5700736595139675, 0.4069545472059297, \
0.1981313907220874]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.5700736595139675, 0.4069545472059297, 0.1981313907220874]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.5700736595139675, 0.4069545472059297, 0.1981313907220874],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.16637070232988593`, 0.6273450506223697, 
                    0.6129198387249786], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.1109138015532573, 0.41823003374824647`, 0.4086132258166524],
               
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.16637070232988593, 0.6273450506223697, \
0.6129198387249786]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.16637070232988593`, 0.6273450506223697, 
                   0.6129198387249786]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.16637070232988593`, 0.6273450506223697, 0.6129198387249786],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.15217789308335927`, 0.6805446503579162, 
                    0.7536712821543405], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.10145192872223951`, 0.45369643357194417`, 
                 0.5024475214362271],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.15217789308335927, 0.6805446503579162, \
0.7536712821543405]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.15217789308335927`, 0.6805446503579162, 
                   0.7536712821543405]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.15217789308335927`, 0.6805446503579162, 0.7536712821543405],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.011500166973726689`, 0.9344737120630893, 
                    0.41519231703372195`], RectangleBox[{0, -1}, {2, 1}]}}}}},
               
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.00766677798248446, 0.6229824747087263, 0.2767948780224813],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.011500166973726689, 0.9344737120630893, \
0.41519231703372195]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.011500166973726689`, 0.9344737120630893, 
                   0.41519231703372195`]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.011500166973726689`, 0.9344737120630893, 0.41519231703372195`],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.6487763190386047, 0.9218976224198998, 
                    0.711816672844579], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.43251754602573644`, 0.6145984149466, 0.47454444856305267`],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.6487763190386047, 0.9218976224198998, \
0.711816672844579]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.6487763190386047, 0.9218976224198998, 0.711816672844579]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.6487763190386047, 0.9218976224198998, 0.711816672844579],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.47327935747334204`, 0.8834140175937308, 
                    0.33245673464773584`], RectangleBox[{0, -1}, {2, 1}]}}}}},
               
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.3155195716488947, 0.5889426783958206, 0.22163782309849056`],
               
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.47327935747334204, 0.8834140175937308, \
0.33245673464773584]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.47327935747334204`, 0.8834140175937308, 
                   0.33245673464773584`]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.47327935747334204`, 0.8834140175937308, 0.33245673464773584`],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.25560515056407795`, 0.8012401319897553, 
                    0.15094027368448049`], RectangleBox[{0, -1}, {2, 1}]}}}}},
               
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.17040343370938532`, 0.5341600879931703, 0.100626849122987],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.25560515056407795, 0.8012401319897553, \
0.15094027368448049]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.25560515056407795`, 0.8012401319897553, 
                   0.15094027368448049`]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.25560515056407795`, 0.8012401319897553, 0.15094027368448049`],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.13360546814982577`, 0.7871863239201633, 
                    0.018599162734135977`], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.08907031209988385, 0.5247908826134422, 
                 0.012399441822757318`],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.13360546814982577, 0.7871863239201633, \
0.018599162734135977]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.13360546814982577`, 0.7871863239201633, 
                   0.018599162734135977`]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.13360546814982577`, 0.7871863239201633, 0.018599162734135977`],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.38337417819768205`, 0.4988952587556723, 
                    0.08321860516969015], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.25558278546512136`, 0.33259683917044824`, 
                 0.05547907011312677],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.38337417819768205, 0.4988952587556723, \
0.08321860516969015]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.38337417819768205`, 0.4988952587556723, 
                   0.08321860516969015]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.38337417819768205`, 0.4988952587556723, 0.08321860516969015],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.4181367040733106, 0.49313383402211364`, 
                    0.10167945128775124`], RectangleBox[{0, -1}, {2, 1}]}}}}},
               
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.2787578027155404, 0.32875588934807576`, 0.06778630085850083],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.4181367040733106, 0.49313383402211364, \
0.10167945128775124]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.4181367040733106, 0.49313383402211364`, 
                   0.10167945128775124`]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.4181367040733106, 0.49313383402211364`, 0.10167945128775124`],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.4812053533680498, 0.873332380181423, 0.327028956990717],
                     RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.3208035689120332, 0.5822215867876154, 0.218019304660478],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.4812053533680498, 0.873332380181423, \
0.327028956990717]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.4812053533680498, 0.873332380181423, 0.327028956990717]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[0.4812053533680498, 0.873332380181423, 0.327028956990717],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.5269434582467774, 0.8294337802982428, 
                    0.1734709900484559], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.3512956388311849, 0.5529558535321619, 0.1156473266989706],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.5269434582467774, 0.8294337802982428, \
0.1734709900484559]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.5269434582467774, 0.8294337802982428, 0.1734709900484559]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.5269434582467774, 0.8294337802982428, 0.1734709900484559],
            Editable->False,
            Selectable->False]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.37266534273681007`, 0.38750269832660855`, 
                    0.3948182017762212], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.24844356182454005`, 0.25833513221773907`, 
                 0.2632121345174808],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.37266534273681007, 0.38750269832660855, \
0.3948182017762212]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.37266534273681007`, 0.38750269832660855`, 
                   0.3948182017762212]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.37266534273681007`, 0.38750269832660855`, 0.3948182017762212],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.733606571264461, 0.4291909747287308, 
                    0.4301886698173236], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.4890710475096407, 0.28612731648582057`, 
                 0.28679244654488245`],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.733606571264461, 0.4291909747287308, \
0.4301886698173236]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.733606571264461, 0.4291909747287308, 0.4301886698173236]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.733606571264461, 0.4291909747287308, 0.4301886698173236],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.17707863410973768`, 0.672607405954065, 
                    0.8338273497920801], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.11805242273982512`, 0.44840493730271, 0.5558848998613868],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.17707863410973768, 0.672607405954065, \
0.8338273497920801]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.17707863410973768`, 0.672607405954065, 
                   0.8338273497920801]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.17707863410973768`, 0.672607405954065, 0.8338273497920801],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.8745580077995285, 0.08910005366925322, 
                    0.5820198361552016], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.5830386718663524, 0.05940003577950215, 0.3880132241034677],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.8745580077995285, 0.08910005366925322, \
0.5820198361552016]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.8745580077995285, 0.08910005366925322, 
                   0.5820198361552016]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.8745580077995285, 0.08910005366925322, 0.5820198361552016],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.9090294322469556, 0.2839329014344203, 
                    0.5231271919589293], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.6060196214979705, 0.1892886009562802, 0.3487514613059529],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.9090294322469556, 0.2839329014344203, \
0.5231271919589293]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.9090294322469556, 0.2839329014344203, 0.5231271919589293]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.9090294322469556, 0.2839329014344203, 0.5231271919589293],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.4864384781423896, 0.2590016473319656, 
                    0.8939198034327294], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.3242923187615931, 0.17266776488797708`, 0.5959465356218197],
               
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.4864384781423896, 0.2590016473319656, \
0.8939198034327294]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.4864384781423896, 0.2590016473319656, 0.8939198034327294]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.4864384781423896, 0.2590016473319656, 0.8939198034327294],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.2674220618976657, 0.5345197867819858, 
                    0.7888815584252213], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.17828137459844381`, 0.35634652452132387`, 
                 0.5259210389501476],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.2674220618976657, 0.5345197867819858, \
0.7888815584252213]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.2674220618976657, 0.5345197867819858, 0.7888815584252213]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.2674220618976657, 0.5345197867819858, 0.7888815584252213],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.18736123677107708`, 0.3952086052502788, 
                    0.86460527303447], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.12490749118071806`, 0.26347240350018586`, 
                 0.5764035153563134],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.18736123677107708, 0.3952086052502788, \
0.86460527303447]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.18736123677107708`, 0.3952086052502788, 0.86460527303447]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.18736123677107708`, 0.3952086052502788, 0.86460527303447],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.7776461280660796, 0.8643601244579295, 
                    0.9944319426310919], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.5184307520440531, 0.5762400829719531, 0.6629546284207279],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.7776461280660796, 0.8643601244579295, \
0.9944319426310919]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.7776461280660796, 0.8643601244579295, 0.9944319426310919]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.7776461280660796, 0.8643601244579295, 0.9944319426310919],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.10244743490058794`, 0.1869170597224914, 
                    0.6271170684614624], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.0682982899337253, 0.1246113731483276, 0.41807804564097495`],
               
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.10244743490058794, 0.1869170597224914, \
0.6271170684614624]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.10244743490058794`, 0.1869170597224914, 
                   0.6271170684614624]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.10244743490058794`, 0.1869170597224914, 0.6271170684614624],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.4573447796522936, 0.007181376876192136, 
                    0.566195028583903], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.30489651976819576`, 0.004787584584128091, 
                 0.3774633523892687],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.4573447796522936, 0.007181376876192136, \
0.566195028583903]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.4573447796522936, 0.007181376876192136, 
                   0.566195028583903]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.4573447796522936, 0.007181376876192136, 0.566195028583903],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.23258722219837846`, 0.08344742427005825, 
                    0.30644177688225716`], RectangleBox[{0, -1}, {2, 1}]}}}}},
               
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.15505814813225233`, 0.05563161618003883, 
                 0.20429451792150477`],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.23258722219837846, 0.08344742427005825, \
0.30644177688225716]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.23258722219837846`, 0.08344742427005825, 
                   0.30644177688225716`]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.23258722219837846`, 0.08344742427005825, 0.30644177688225716`],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.711485166849398, 0.017375777675906035`, 
                    0.7454946682315056], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.47432344456626535`, 0.011583851783937357`, 
                 0.4969964454876704],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.711485166849398, 0.017375777675906035, \
0.7454946682315056]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.711485166849398, 0.017375777675906035`, 
                   0.7454946682315056]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.711485166849398, 0.017375777675906035`, 0.7454946682315056],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.31452599923983104`, 0.6908103742720597, 
                    0.9463506847311731], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.2096839994932207, 0.4605402495147065, 0.6309004564874487],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.31452599923983104, 0.6908103742720597, \
0.9463506847311731]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.31452599923983104`, 0.6908103742720597, 
                   0.9463506847311731]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.31452599923983104`, 0.6908103742720597, 0.9463506847311731],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.922559309792595, 0.2703946335791436, 
                    0.09665543181913394], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.6150395398617301, 0.18026308905276242`, 0.0644369545460893],
               
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.922559309792595, 0.2703946335791436, \
0.09665543181913394]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.922559309792595, 0.2703946335791436, 0.09665543181913394]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.922559309792595, 0.2703946335791436, 0.09665543181913394],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.11122524183982829`, 0.12772449779541217`, 
                    0.6139200516853858], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.0741501612265522, 0.08514966519694145, 0.40928003445692385`],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.11122524183982829, 0.12772449779541217, \
0.6139200516853858]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.11122524183982829`, 0.12772449779541217`, 
                   0.6139200516853858]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.11122524183982829`, 0.12772449779541217`, 0.6139200516853858],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.6357194627252103, 0.15357943517679362`, 
                    0.860476954867391], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.4238129751501402, 0.10238629011786242`, 0.5736513032449273],
               
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.6357194627252103, 0.15357943517679362, \
0.860476954867391]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.6357194627252103, 0.15357943517679362`, 
                   0.860476954867391]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.6357194627252103, 0.15357943517679362`, 0.860476954867391],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.4431832834876257, 0.18321465791748515`, 
                    0.7764518003586576], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.2954555223250838, 0.12214310527832344`, 0.5176345335724384],
               
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.4431832834876257, 0.18321465791748515, \
0.7764518003586576]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.4431832834876257, 0.18321465791748515`, 
                   0.7764518003586576]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.4431832834876257, 0.18321465791748515`, 0.7764518003586576],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.3553518860908462, 0.6443320866741731, 
                    0.7499636864238166], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.2369012573938975, 0.42955472444944875`, 0.4999757909492111],
               
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.3553518860908462, 0.6443320866741731, \
0.7499636864238166]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.3553518860908462, 0.6443320866741731, 0.7499636864238166]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.3553518860908462, 0.6443320866741731, 0.7499636864238166],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.8943854155561495, 0.03560200287351467, 
                    0.16578917868909593`], RectangleBox[{0, -1}, {2, 1}]}}}}},
               
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.5962569437040997, 0.023734668582343115`, 
                 0.11052611912606396`],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.8943854155561495, 0.03560200287351467, \
0.16578917868909593]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.8943854155561495, 0.03560200287351467, 
                   0.16578917868909593`]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.8943854155561495, 0.03560200287351467, 0.16578917868909593`],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.6672396717157738, 0.3586192991395154, 
                    0.8976595916455246], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.4448264478105159, 0.23907953275967694`, 0.598439727763683],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.6672396717157738, 0.3586192991395154, \
0.8976595916455246]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.6672396717157738, 0.3586192991395154, 0.8976595916455246]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.6672396717157738, 0.3586192991395154, 0.8976595916455246],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.37001635641206, 0.3047563933568622, 0.7684408201506054],
                     RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.24667757094137333`, 0.20317092890457483`, 
                 0.5122938801004037],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.37001635641206, 0.3047563933568622, \
0.7684408201506054]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.37001635641206, 0.3047563933568622, 0.7684408201506054]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[0.37001635641206, 0.3047563933568622, 0.7684408201506054],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.38698691150966935`, 0.10328204902950966`, 
                    0.8013210231747274], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.2579912743397796, 0.06885469935300645, 0.5342140154498183],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.38698691150966935, 0.10328204902950966, \
0.8013210231747274]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.38698691150966935`, 0.10328204902950966`, 
                   0.8013210231747274]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.38698691150966935`, 0.10328204902950966`, 0.8013210231747274],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.29215345853340424`, 0.35497646703617836`, 
                    0.6346432521789236], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.19476897235560284`, 0.2366509780241189, 
                 0.42309550145261576`],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.29215345853340424, 0.35497646703617836, \
0.6346432521789236]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.29215345853340424`, 0.35497646703617836`, 
                   0.6346432521789236]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.29215345853340424`, 0.35497646703617836`, 0.6346432521789236],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.9678407581110904, 0.025426491397912976`, 
                    0.587777889276665], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.6452271720740603, 0.01695099426527532, 0.3918519261844433],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.9678407581110904, 0.025426491397912976, \
0.587777889276665]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.9678407581110904, 0.025426491397912976`, 
                   0.587777889276665]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.9678407581110904, 0.025426491397912976`, 0.587777889276665],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.4918965330955356, 0.29233426982370303`, 
                    0.5281824844462943], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.3279310220636904, 0.19488951321580203`, 
                 0.35212165629752956`],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.4918965330955356, 0.29233426982370303, \
0.5281824844462943]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.4918965330955356, 0.29233426982370303`, 
                   0.5281824844462943]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.4918965330955356, 0.29233426982370303`, 0.5281824844462943],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.1252423737911874, 0.5183189386335805, 
                    0.7491160058315705], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.08349491586079161, 0.34554595908905367`, 0.4994106705543803],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.1252423737911874, 0.5183189386335805, \
0.7491160058315705]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.1252423737911874, 0.5183189386335805, 0.7491160058315705]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.1252423737911874, 0.5183189386335805, 0.7491160058315705],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.9765556387211944, 0.12357617097291551`, 
                    0.5068373458296718], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.6510370924807963, 0.08238411398194367, 0.33789156388644787`],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.9765556387211944, 0.12357617097291551, \
0.5068373458296718]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.9765556387211944, 0.12357617097291551`, 
                   0.5068373458296718]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.9765556387211944, 0.12357617097291551`, 0.5068373458296718],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.8227934753153485, 0.3797246867796864, 
                    0.6782582898466567], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.5485289835435657, 0.25314979118645764`, 
                 0.45217219323110447`],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.8227934753153485, 0.3797246867796864, \
0.6782582898466567]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.8227934753153485, 0.3797246867796864, 0.6782582898466567]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.8227934753153485, 0.3797246867796864, 0.6782582898466567],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.6820734720667967, 0.43856527685111324`, 
                    0.8695673460178908], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.45471564804453113`, 0.29237685123407553`, 
                 0.5797115640119272],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.6820734720667967, 0.43856527685111324, \
0.8695673460178908]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.6820734720667967, 0.43856527685111324`, 
                   0.8695673460178908]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.6820734720667967, 0.43856527685111324`, 0.8695673460178908],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.11654903299881392`, 0.07006336344132391, 
                    0.56484752468554], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.07769935533254262, 0.04670890896088261, 
                 0.37656501645702667`],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.11654903299881392, 0.07006336344132391, \
0.56484752468554]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.11654903299881392`, 0.07006336344132391, 
                   0.56484752468554]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.11654903299881392`, 0.07006336344132391, 0.56484752468554],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.6402988781363921, 0.035330434441392944`, 
                    0.28001275709114415`], RectangleBox[{0, -1}, {2, 1}]}}}}},
               
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.4268659187575947, 0.02355362296092863, 0.18667517139409612`],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.6402988781363921, 0.035330434441392944, \
0.28001275709114415]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.6402988781363921, 0.035330434441392944`, 
                   0.28001275709114415`]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.6402988781363921, 0.035330434441392944`, 0.28001275709114415`],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.4249737173056105, 0.08087713350797054, 
                    0.5561568741925262], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.2833158115370737, 0.053918089005313696`, 
                 0.37077124946168416`],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.4249737173056105, 0.08087713350797054, \
0.5561568741925262]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.4249737173056105, 0.08087713350797054, 
                   0.5561568741925262]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.4249737173056105, 0.08087713350797054, 0.5561568741925262],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.7495302686726302, 0.3453338459340154, 
                    0.3119406215616949], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               FrameStyle->RGBColor[
                0.4996868457817535, 0.23022256395601026`, 
                 0.20796041437446328`],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.7495302686726302, 0.3453338459340154, \
0.3119406215616949]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.7495302686726302, 0.3453338459340154, 0.3119406215616949]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.7495302686726302, 0.3453338459340154, 0.3119406215616949],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.836090631447431, 0.10393312541533217`, 
                    0.9133348768403533], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.5573937542982874, 0.06928875027688812, 0.6088899178935689],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.836090631447431, 0.10393312541533217, \
0.9133348768403533]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.836090631447431, 0.10393312541533217`, 
                   0.9133348768403533]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.836090631447431, 0.10393312541533217`, 0.9133348768403533],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.19151655035273674`, 0.14390156161230028`, 
                    0.5247101500257152], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.12767770023515784`, 0.09593437440820018, 
                 0.34980676668381017`],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.19151655035273674, 0.14390156161230028, \
0.5247101500257152]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.19151655035273674`, 0.14390156161230028`, 
                   0.5247101500257152]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.19151655035273674`, 0.14390156161230028`, 0.5247101500257152],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.8789399682999111, 0.042929493135203334`, 
                    0.19233219566452364`], RectangleBox[{0, -1}, {2, 1}]}}}}},
               
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.5859599788666074, 0.028619662090135556`, 0.1282214637763491],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.8789399682999111, 0.042929493135203334, \
0.19233219566452364]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.8789399682999111, 0.042929493135203334`, 
                   0.19233219566452364`]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.8789399682999111, 0.042929493135203334`, 0.19233219566452364`],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.8279081820793655, 0.007601665021679249, 
                    0.007776314948584773], RectangleBox[{0, -1}, {2, 1}]}}}}},
               
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.5519387880529103, 0.0050677766811195, 0.005184209965723182],
               
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.8279081820793655, 0.007601665021679249, \
0.007776314948584773]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.8279081820793655, 0.007601665021679249, 
                   0.007776314948584773]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.8279081820793655, 0.007601665021679249, 0.007776314948584773],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.8905220469868362, 0.6720465313460078, 
                    0.8782899541874138], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.5936813646578909, 0.44803102089733854`, 0.5855266361249426],
               
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.8905220469868362, 0.6720465313460078, \
0.8782899541874138]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.8905220469868362, 0.6720465313460078, 0.8782899541874138]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.8905220469868362, 0.6720465313460078, 0.8782899541874138],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.4739838883353795, 0.01643240988333261, 
                    0.7672816104627056], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.31598925889025303`, 0.01095493992222174, 0.5115210736418038],
               FrameTicks->None,
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.4739838883353795, 0.01643240988333261, \
0.7672816104627056]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.4739838883353795, 0.01643240988333261, 
                   0.7672816104627056]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.4739838883353795, 0.01643240988333261, 0.7672816104627056],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.73262590528079, 0.4345872718612065, 0.9513218213654053],
                     RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.48841727018719333`, 0.289724847907471, 0.634214547576937],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.73262590528079, 0.4345872718612065, \
0.9513218213654053]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.73262590528079, 0.4345872718612065, 0.9513218213654053]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[0.73262590528079, 0.4345872718612065, 0.9513218213654053],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.7193138046226939, 0.736637476380962, 
                    0.9909551197977506], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.4795425364151293, 0.49109165092064133`, 0.6606367465318338],
               
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.7193138046226939, 0.736637476380962, \
0.9909551197977506]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.7193138046226939, 0.736637476380962, 0.9909551197977506]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.7193138046226939, 0.736637476380962, 0.9909551197977506],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.5532261835871646, 0.1424067735626049, 
                    0.6840947116434117], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.3688174557247764, 0.0949378490417366, 0.45606314109560786`],
               
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.5532261835871646, 0.1424067735626049, \
0.6840947116434117]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.5532261835871646, 0.1424067735626049, 0.6840947116434117]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.5532261835871646, 0.1424067735626049, 0.6840947116434117],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.24015696649735507`, 0.2276921291555416, 
                    0.5618669828113934], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.16010464433157007`, 0.15179475277036109`, 
                 0.37457798854092894`],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.24015696649735507, 0.2276921291555416, \
0.5618669828113934]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.24015696649735507`, 0.2276921291555416, 
                   0.5618669828113934]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.24015696649735507`, 0.2276921291555416, 0.5618669828113934],
            Editable->False,
            Selectable->False], ",", 
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{{{{
                   {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                   {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                   {RGBColor[
                    0.3614530023699991, 0.23838000474075272`, 
                    0.351099450461986], RectangleBox[{0, -1}, {2, 1}]}}}}},
               AspectRatio->1,
               Frame->True,
               
               FrameStyle->RGBColor[
                0.24096866824666607`, 0.1589200031605018, 
                 0.23406630030799067`],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              
              "RGBColor[0.3614530023699991, 0.23838000474075272, \
0.351099450461986]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[
                  0.3614530023699991, 0.23838000474075272`, 
                   0.351099450461986]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[
            0.3614530023699991, 0.23838000474075272`, 0.351099450461986],
            Editable->False,
            Selectable->False]}], "}"}]}], "}"}]], "ExerciseOutput",
       ExpressionUUID->"a7728469-c5d7-45c0-bf5d-f3121fad0494"],
      Apply[TextCell, 
       Cell[
        BoxData[
         RowBox[{"{", 
           RowBox[{
             RowBox[{"{", 
               RowBox[{
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.8116438051434329, 0.8547919864863347, 
                    0.7807710853793401], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.541095870095622, 0.5698613243242232, 
                    0.5205140569195601], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.8116438051434329, 0.8547919864863347, \
0.7807710853793401]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.8116438051434329, 0.8547919864863347, 
                    0.7807710853793401]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.8116438051434329, 0.8547919864863347, 0.7807710853793401],
                   Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.2983278570382957, 0.9907444932950316, 
                    0.9284043344039434], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.19888523802553046`, 0.6604963288633544, 
                    0.6189362229359623], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    
                    "RGBColor[0.2983278570382957, 0.9907444932950316, \
0.9284043344039434]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.2983278570382957, 0.9907444932950316, 
                    0.9284043344039434]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.2983278570382957, 0.9907444932950316, 0.9284043344039434],
                   Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.18676117011450066`, 0.5486089602170863, 
                    0.04303247680226141], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.12450744674300045`, 0.3657393068113909, 
                    0.028688317868174273`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.18676117011450066, 0.5486089602170863, \
0.04303247680226141]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.18676117011450066`, 0.5486089602170863, 
                    0.04303247680226141]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.18676117011450066`, 0.5486089602170863, 
                   0.04303247680226141], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.4044608902823441, 0.9788998961090443, 
                    0.8108975624714536], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.2696405935215628, 0.6525999307393628, 
                    0.5405983749809691], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.4044608902823441, 0.9788998961090443, \
0.8108975624714536]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.4044608902823441, 0.9788998961090443, 
                    0.8108975624714536]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.4044608902823441, 0.9788998961090443, 0.8108975624714536],
                   Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.5308001574813235, 0.9503472359039511, 
                    0.8646083755834806], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.35386677165421565`, 0.6335648239359675, 
                    0.5764055837223204], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.5308001574813235, 0.9503472359039511, \
0.8646083755834806]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.5308001574813235, 0.9503472359039511, 
                    0.8646083755834806]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.5308001574813235, 0.9503472359039511, 0.8646083755834806],
                   Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.5926608241659339, 0.4671421812435703, 
                    0.027570072930602985`], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.3951072161106226, 0.3114281208290469, 
                    0.01838004862040199], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.5926608241659339, 0.4671421812435703, \
0.027570072930602985]"], Appearance -> None, BaseStyle -> {}, 
                   BaselinePosition -> Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.5926608241659339, 0.4671421812435703, 
                    0.027570072930602985`]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.5926608241659339, 0.4671421812435703, 
                   0.027570072930602985`], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.49843743964638865`, 0.7588128836239783, 
                    0.6588996785867525], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.3322916264309258, 0.5058752557493189, 
                    0.43926645239116835`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.49843743964638865, 0.7588128836239783, \
0.6588996785867525]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.49843743964638865`, 0.7588128836239783, 
                    0.6588996785867525]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.49843743964638865`, 0.7588128836239783, 
                   0.6588996785867525], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.6788691428209239, 0.8865118691450595, 
                    0.06859340947663295], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.4525794285472826, 0.5910079127633731, 
                    0.04572893965108864], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.6788691428209239, 0.8865118691450595, \
0.06859340947663295]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.6788691428209239, 0.8865118691450595, 
                    0.06859340947663295]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.6788691428209239, 0.8865118691450595, 
                   0.06859340947663295], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.3966954095359472, 0.9303983446364068, 
                    0.27133513969525125`], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.26446360635729815`, 0.6202655630909379, 
                    0.18089009313016752`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.3966954095359472, 0.9303983446364068, \
0.27133513969525125]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.3966954095359472, 0.9303983446364068, 
                    0.27133513969525125`]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.3966954095359472, 0.9303983446364068, 
                   0.27133513969525125`], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.7496777159050012, 0.8414031368083361, 
                    0.29000881481349006`], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.4997851439366675, 0.5609354245388908, 
                    0.19333920987566006`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.7496777159050012, 0.8414031368083361, \
0.29000881481349006]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.7496777159050012, 0.8414031368083361, 
                    0.29000881481349006`]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.7496777159050012, 0.8414031368083361, 
                   0.29000881481349006`], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.1722869702422274, 0.42066881136044554`, 
                    0.18877704427888808`], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.11485798016148493`, 0.28044587424029704`, 
                    0.12585136285259207`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.1722869702422274, 0.42066881136044554, \
0.18877704427888808]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.1722869702422274, 0.42066881136044554`, 
                    0.18877704427888808`]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.1722869702422274, 0.42066881136044554`, 
                   0.18877704427888808`], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.020568097401979735`, 0.32843933224376776`, 
                    0.2578912775452169], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.013712064934653156`, 0.2189595548291785, 
                    0.17192751836347794`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.020568097401979735, 0.32843933224376776, \
0.2578912775452169]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.020568097401979735`, 0.32843933224376776`, 
                    0.2578912775452169]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.020568097401979735`, 0.32843933224376776`, 
                   0.2578912775452169], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.4276762158276948, 0.9445301871184215, 
                    0.6339408432442302], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.2851174772184632, 0.629686791412281, 
                    0.4226272288294868], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.4276762158276948, 0.9445301871184215, \
0.6339408432442302]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.4276762158276948, 0.9445301871184215, 
                    0.6339408432442302]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.4276762158276948, 0.9445301871184215, 0.6339408432442302],
                   Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.3449333805776824, 0.8214093187031501, 
                    0.00535396147946221], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.22995558705178828`, 0.5476062124687668, 
                    0.003569307652974807], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.3449333805776824, 0.8214093187031501, \
0.00535396147946221]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.3449333805776824, 0.8214093187031501, 
                    0.00535396147946221]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.3449333805776824, 0.8214093187031501, 
                   0.00535396147946221], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.9595114792486563, 0.9614567195621035, 
                    0.09956803288245264], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.6396743194991042, 0.6409711463747357, 
                    0.06637868858830176], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.9595114792486563, 0.9614567195621035, \
0.09956803288245264]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.9595114792486563, 0.9614567195621035, 
                    0.09956803288245264]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.9595114792486563, 0.9614567195621035, 
                   0.09956803288245264], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.13927723404143122`, 0.9837658758454813, 
                    0.6275322853052734], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.09285148936095415, 0.6558439172303209, 
                    0.41835485687018226`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.13927723404143122, 0.9837658758454813, \
0.6275322853052734]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.13927723404143122`, 0.9837658758454813, 
                    0.6275322853052734]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.13927723404143122`, 0.9837658758454813, 
                   0.6275322853052734], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.4129872979782936, 0.599123151026224, 
                    0.5563798982651478], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.2753248653188624, 0.3994154340174827, 
                    0.3709199321767652], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.4129872979782936, 0.599123151026224, \
0.5563798982651478]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.4129872979782936, 0.599123151026224, 
                    0.5563798982651478]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.4129872979782936, 0.599123151026224, 0.5563798982651478], 
                  Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.5517409716001453, 0.7226268672047083, 
                    0.04296745155978088], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.3678273144000969, 0.48175124480313886`, 
                    0.028644967706520585`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.5517409716001453, 0.7226268672047083, \
0.04296745155978088]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.5517409716001453, 0.7226268672047083, 
                    0.04296745155978088]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.5517409716001453, 0.7226268672047083, 
                   0.04296745155978088], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.2471012449687613, 0.6622219052252245, 
                    0.34136700529740893`], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.16473416331250754`, 0.4414812701501497, 
                    0.22757800353160595`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.2471012449687613, 0.6622219052252245, \
0.34136700529740893]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.2471012449687613, 0.6622219052252245, 
                    0.34136700529740893`]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.2471012449687613, 0.6622219052252245, 
                   0.34136700529740893`], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.00852878273374924, 0.7623891609381206, 
                    0.495048201930645], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.005685855155832828, 0.5082594406254137, 
                    0.33003213462043], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.00852878273374924, 0.7623891609381206, \
0.495048201930645]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.00852878273374924, 0.7623891609381206, 
                    0.495048201930645]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.00852878273374924, 0.7623891609381206, 0.495048201930645],
                   Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.410530117230961, 0.65951899493187, 
                    0.31274019237510875`], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.2736867448206407, 0.43967932995458003`, 
                    0.20849346158340584`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.410530117230961, 0.65951899493187, \
0.31274019237510875]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.410530117230961, 0.65951899493187, 
                    0.31274019237510875`]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.410530117230961, 0.65951899493187, 0.31274019237510875`], 
                  Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.14914425266109754`, 0.8632288046219025, 
                    0.2165769996518021], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.09942950177406504, 0.575485869747935, 
                    0.14438466643453474`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.14914425266109754, 0.8632288046219025, \
0.2165769996518021]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.14914425266109754`, 0.8632288046219025, 
                    0.2165769996518021]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.14914425266109754`, 0.8632288046219025, 
                   0.2165769996518021], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.5019554020533212, 0.5771425709059108, 
                    0.4324648041012522], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.3346369347022142, 0.3847617139372739, 
                    0.2883098694008348], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.5019554020533212, 0.5771425709059108, \
0.4324648041012522]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.5019554020533212, 0.5771425709059108, 
                    0.4324648041012522]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.5019554020533212, 0.5771425709059108, 0.4324648041012522],
                   Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.2375846642639532, 0.7953276430316651, 
                    0.9346352336682711], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.1583897761759688, 0.5302184286877768, 
                    0.6230901557788474], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.2375846642639532, 0.7953276430316651, \
0.9346352336682711]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.2375846642639532, 0.7953276430316651, 
                    0.9346352336682711]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.2375846642639532, 0.7953276430316651, 0.9346352336682711],
                   Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.5670638896981823, 0.30694748662903737`, 
                    0.07724772234151844], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.3780425931321216, 0.2046316577526916, 
                    0.0514984815610123], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.5670638896981823, 0.30694748662903737, \
0.07724772234151844]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.5670638896981823, 0.30694748662903737`, 
                    0.07724772234151844]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.5670638896981823, 0.30694748662903737`, 
                   0.07724772234151844], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.9836330486106633, 0.9337141420685637, 
                    0.45110780147188234`], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.6557553657404422, 0.6224760947123759, 
                    0.30073853431458825`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.9836330486106633, 0.9337141420685637, \
0.45110780147188234]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.9836330486106633, 0.9337141420685637, 
                    0.45110780147188234`]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.9836330486106633, 0.9337141420685637, 
                   0.45110780147188234`], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.548151102001315, 0.9273818734933321, 
                    0.6138604019189067], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.3654340680008767, 0.6182545823288881, 
                    0.4092402679459378], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.548151102001315, 0.9273818734933321, \
0.6138604019189067]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.548151102001315, 0.9273818734933321, 
                    0.6138604019189067]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.548151102001315, 0.9273818734933321, 0.6138604019189067], 
                  Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.08996343949980967, 0.7502285322367264, 
                    0.7647837622874905], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.05997562633320645, 0.5001523548244843, 
                    0.5098558415249936], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.08996343949980967, 0.7502285322367264, \
0.7647837622874905]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.08996343949980967, 0.7502285322367264, 
                    0.7647837622874905]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.08996343949980967, 0.7502285322367264, 
                   0.7647837622874905], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.9554445238224603, 0.9118174885785313, 
                    0.7586039763217882], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.6369630158816402, 0.6078783257190209, 
                    0.5057359842145255], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.9554445238224603, 0.9118174885785313, \
0.7586039763217882]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.9554445238224603, 0.9118174885785313, 
                    0.7586039763217882]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.9554445238224603, 0.9118174885785313, 0.7586039763217882],
                   Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.12407876246761118`, 0.8951986963374581, 
                    0.405054951518828], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.08271917497840746, 0.5967991308916387, 
                    0.2700366343458853], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.12407876246761118, 0.8951986963374581, \
0.405054951518828]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.12407876246761118`, 0.8951986963374581, 
                    0.405054951518828]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.12407876246761118`, 0.8951986963374581, 
                   0.405054951518828], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.3518853673765441, 0.6267881822227646, 
                    0.01601455063963053], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.23459024491769606`, 0.41785878814850974`, 
                    0.010676367093087022`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.3518853673765441, 0.6267881822227646, \
0.01601455063963053]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.3518853673765441, 0.6267881822227646, 
                    0.01601455063963053]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.3518853673765441, 0.6267881822227646, 
                   0.01601455063963053], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.38175543134617906`, 0.6109792496345561, 
                    0.30321055377645356`], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.2545036208974527, 0.4073194997563707, 
                    0.2021403691843024], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    
                    "RGBColor[0.38175543134617906, 0.6109792496345561, \
0.30321055377645356]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.38175543134617906`, 0.6109792496345561, 
                    0.30321055377645356`]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.38175543134617906`, 0.6109792496345561, 
                   0.30321055377645356`], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.5015968883258048, 0.9477341972992892, 
                    0.7518749706067847], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.3343979255505366, 0.6318227981995261, 
                    0.5012499804045232], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.5015968883258048, 0.9477341972992892, \
0.7518749706067847]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.5015968883258048, 0.9477341972992892, 
                    0.7518749706067847]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.5015968883258048, 0.9477341972992892, 0.7518749706067847],
                   Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.4853791041906068, 0.9983056811536988, 
                    0.059586297674913524`], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.3235860694604046, 0.6655371207691325, 
                    0.03972419844994235], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.4853791041906068, 0.9983056811536988, \
0.059586297674913524]"], Appearance -> None, BaseStyle -> {}, 
                   BaselinePosition -> Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.4853791041906068, 0.9983056811536988, 
                    0.059586297674913524`]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.4853791041906068, 0.9983056811536988, 
                   0.059586297674913524`], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.39598681356054666`, 0.5894657294683947, 
                    0.2897133293523855], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.26399120904036444`, 0.3929771529789298, 
                    0.193142219568257], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.39598681356054666, 0.5894657294683947, \
0.2897133293523855]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.39598681356054666`, 0.5894657294683947, 
                    0.2897133293523855]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.39598681356054666`, 0.5894657294683947, 
                   0.2897133293523855], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.06510008212093177, 0.7580810151353965, 
                    0.4838966525370989], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.04340005474728785, 0.5053873434235977, 
                    0.322597768358066], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.06510008212093177, 0.7580810151353965, \
0.4838966525370989]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.06510008212093177, 0.7580810151353965, 
                    0.4838966525370989]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.06510008212093177, 0.7580810151353965, 
                   0.4838966525370989], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.02229677965825383, 0.35028891391213257`, 
                    0.0684550207396537], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.01486451977216922, 0.2335259426080884, 
                    0.045636680493102474`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.02229677965825383, 0.35028891391213257, \
0.0684550207396537]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.02229677965825383, 0.35028891391213257`, 
                    0.0684550207396537]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.02229677965825383, 0.35028891391213257`, 
                   0.0684550207396537], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.15578960479774717`, 0.33156505911261824`, 
                    0.10795082362400787`], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.10385973653183145`, 0.22104337274174551`, 
                    0.07196721574933859], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.15578960479774717, 0.33156505911261824, \
0.10795082362400787]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.15578960479774717`, 0.33156505911261824`, 
                    0.10795082362400787`]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.15578960479774717`, 0.33156505911261824`, 
                   0.10795082362400787`], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.9666406011133539, 0.6653552686335491, 
                    0.5546554666254075], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.6444270674089027, 0.44357017908903273`, 
                    0.36977031108360503`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.9666406011133539, 0.6653552686335491, \
0.5546554666254075]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.9666406011133539, 0.6653552686335491, 
                    0.5546554666254075]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.9666406011133539, 0.6653552686335491, 0.5546554666254075],
                   Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.21832422216206182`, 0.4452088456726624, 
                    0.34195667187604584`], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.14554948144137456`, 0.2968058971151083, 
                    0.22797111458403058`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.21832422216206182, 0.4452088456726624, \
0.34195667187604584]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.21832422216206182`, 0.4452088456726624, 
                    0.34195667187604584`]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.21832422216206182`, 0.4452088456726624, 
                   0.34195667187604584`], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.4939446101923697, 0.31678858836269796`, 
                    0.11346988660388835`], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.3292964067949131, 0.21119239224179864`, 
                    0.0756465910692589], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.4939446101923697, 0.31678858836269796, \
0.11346988660388835]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.4939446101923697, 0.31678858836269796`, 
                    0.11346988660388835`]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.4939446101923697, 0.31678858836269796`, 
                   0.11346988660388835`], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.9566388456878347, 0.9651195544633302, 
                    0.9076564789046491], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.6377592304585565, 0.6434130363088868, 
                    0.605104319269766], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.9566388456878347, 0.9651195544633302, \
0.9076564789046491]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.9566388456878347, 0.9651195544633302, 
                    0.9076564789046491]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.9566388456878347, 0.9651195544633302, 0.9076564789046491],
                   Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.4000855073593619, 0.39588066174906866`, 
                    0.1685452332949151], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.26672367157290794`, 0.2639204411660458, 
                    0.11236348886327674`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.4000855073593619, 0.39588066174906866, \
0.1685452332949151]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.4000855073593619, 0.39588066174906866`, 
                    0.1685452332949151]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.4000855073593619, 0.39588066174906866`, 
                   0.1685452332949151], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.5700736595139675, 0.4069545472059297, 
                    0.1981313907220874], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.380049106342645, 0.27130303147061985`, 
                    0.13208759381472496`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.5700736595139675, 0.4069545472059297, \
0.1981313907220874]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.5700736595139675, 0.4069545472059297, 
                    0.1981313907220874]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.5700736595139675, 0.4069545472059297, 0.1981313907220874],
                   Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.16637070232988593`, 0.6273450506223697, 
                    0.6129198387249786], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.1109138015532573, 0.41823003374824647`, 
                    0.4086132258166524], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.16637070232988593, 0.6273450506223697, \
0.6129198387249786]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.16637070232988593`, 0.6273450506223697, 
                    0.6129198387249786]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.16637070232988593`, 0.6273450506223697, 
                   0.6129198387249786], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.15217789308335927`, 0.6805446503579162, 
                    0.7536712821543405], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.10145192872223951`, 0.45369643357194417`, 
                    0.5024475214362271], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.15217789308335927, 0.6805446503579162, \
0.7536712821543405]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.15217789308335927`, 0.6805446503579162, 
                    0.7536712821543405]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.15217789308335927`, 0.6805446503579162, 
                   0.7536712821543405], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.011500166973726689`, 0.9344737120630893, 
                    0.41519231703372195`], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.00766677798248446, 0.6229824747087263, 
                    0.2767948780224813], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.011500166973726689, 0.9344737120630893, \
0.41519231703372195]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.011500166973726689`, 0.9344737120630893, 
                    0.41519231703372195`]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.011500166973726689`, 0.9344737120630893, 
                   0.41519231703372195`], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.6487763190386047, 0.9218976224198998, 
                    0.711816672844579], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.43251754602573644`, 0.6145984149466, 
                    0.47454444856305267`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    
                    "RGBColor[0.6487763190386047, 0.9218976224198998, \
0.711816672844579]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.6487763190386047, 0.9218976224198998, 
                    0.711816672844579]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.6487763190386047, 0.9218976224198998, 0.711816672844579], 
                  Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.47327935747334204`, 0.8834140175937308, 
                    0.33245673464773584`], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.3155195716488947, 0.5889426783958206, 
                    0.22163782309849056`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.47327935747334204, 0.8834140175937308, \
0.33245673464773584]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.47327935747334204`, 0.8834140175937308, 
                    0.33245673464773584`]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.47327935747334204`, 0.8834140175937308, 
                   0.33245673464773584`], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.25560515056407795`, 0.8012401319897553, 
                    0.15094027368448049`], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.17040343370938532`, 0.5341600879931703, 
                    0.100626849122987], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.25560515056407795, 0.8012401319897553, \
0.15094027368448049]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.25560515056407795`, 0.8012401319897553, 
                    0.15094027368448049`]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.25560515056407795`, 0.8012401319897553, 
                   0.15094027368448049`], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.13360546814982577`, 0.7871863239201633, 
                    0.018599162734135977`], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.08907031209988385, 0.5247908826134422, 
                    0.012399441822757318`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.13360546814982577, 0.7871863239201633, \
0.018599162734135977]"], Appearance -> None, BaseStyle -> {}, 
                   BaselinePosition -> Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.13360546814982577`, 0.7871863239201633, 
                    0.018599162734135977`]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.13360546814982577`, 0.7871863239201633, 
                   0.018599162734135977`], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.38337417819768205`, 0.4988952587556723, 
                    0.08321860516969015], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.25558278546512136`, 0.33259683917044824`, 
                    0.05547907011312677], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.38337417819768205, 0.4988952587556723, \
0.08321860516969015]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.38337417819768205`, 0.4988952587556723, 
                    0.08321860516969015]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.38337417819768205`, 0.4988952587556723, 
                   0.08321860516969015], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.4181367040733106, 0.49313383402211364`, 
                    0.10167945128775124`], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.2787578027155404, 0.32875588934807576`, 
                    0.06778630085850083], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.4181367040733106, 0.49313383402211364, \
0.10167945128775124]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.4181367040733106, 0.49313383402211364`, 
                    0.10167945128775124`]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.4181367040733106, 0.49313383402211364`, 
                   0.10167945128775124`], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.4812053533680498, 0.873332380181423, 0.327028956990717], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.3208035689120332, 0.5822215867876154, 
                    0.218019304660478], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.4812053533680498, 0.873332380181423, \
0.327028956990717]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.4812053533680498, 0.873332380181423, 0.327028956990717]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.4812053533680498, 0.873332380181423, 0.327028956990717], 
                  Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.5269434582467774, 0.8294337802982428, 
                    0.1734709900484559], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.3512956388311849, 0.5529558535321619, 
                    0.1156473266989706], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.5269434582467774, 0.8294337802982428, \
0.1734709900484559]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.5269434582467774, 0.8294337802982428, 
                    0.1734709900484559]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.5269434582467774, 0.8294337802982428, 0.1734709900484559],
                   Editable -> False, Selectable -> False]}], "}"}], ",", 
             RowBox[{"{", 
               RowBox[{
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.37266534273681007`, 0.38750269832660855`, 
                    0.3948182017762212], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.24844356182454005`, 0.25833513221773907`, 
                    0.2632121345174808], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.37266534273681007, 0.38750269832660855, \
0.3948182017762212]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.37266534273681007`, 0.38750269832660855`, 
                    0.3948182017762212]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.37266534273681007`, 0.38750269832660855`, 
                   0.3948182017762212], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.733606571264461, 0.4291909747287308, 
                    0.4301886698173236], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.4890710475096407, 0.28612731648582057`, 
                    0.28679244654488245`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.733606571264461, 0.4291909747287308, \
0.4301886698173236]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.733606571264461, 0.4291909747287308, 
                    0.4301886698173236]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.733606571264461, 0.4291909747287308, 0.4301886698173236], 
                  Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.17707863410973768`, 0.672607405954065, 
                    0.8338273497920801], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.11805242273982512`, 0.44840493730271, 
                    0.5558848998613868], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.17707863410973768, 0.672607405954065, \
0.8338273497920801]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.17707863410973768`, 0.672607405954065, 
                    0.8338273497920801]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.17707863410973768`, 0.672607405954065, 
                   0.8338273497920801], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.8745580077995285, 0.08910005366925322, 
                    0.5820198361552016], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.5830386718663524, 0.05940003577950215, 
                    0.3880132241034677], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.8745580077995285, 0.08910005366925322, \
0.5820198361552016]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.8745580077995285, 0.08910005366925322, 
                    0.5820198361552016]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.8745580077995285, 0.08910005366925322, 
                   0.5820198361552016], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.9090294322469556, 0.2839329014344203, 
                    0.5231271919589293], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.6060196214979705, 0.1892886009562802, 
                    0.3487514613059529], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.9090294322469556, 0.2839329014344203, \
0.5231271919589293]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.9090294322469556, 0.2839329014344203, 
                    0.5231271919589293]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.9090294322469556, 0.2839329014344203, 0.5231271919589293],
                   Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.4864384781423896, 0.2590016473319656, 
                    0.8939198034327294], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.3242923187615931, 0.17266776488797708`, 
                    0.5959465356218197], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.4864384781423896, 0.2590016473319656, \
0.8939198034327294]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.4864384781423896, 0.2590016473319656, 
                    0.8939198034327294]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.4864384781423896, 0.2590016473319656, 0.8939198034327294],
                   Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.2674220618976657, 0.5345197867819858, 
                    0.7888815584252213], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.17828137459844381`, 0.35634652452132387`, 
                    0.5259210389501476], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.2674220618976657, 0.5345197867819858, \
0.7888815584252213]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.2674220618976657, 0.5345197867819858, 
                    0.7888815584252213]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.2674220618976657, 0.5345197867819858, 0.7888815584252213],
                   Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.18736123677107708`, 0.3952086052502788, 
                    0.86460527303447], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.12490749118071806`, 0.26347240350018586`, 
                    0.5764035153563134], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.18736123677107708, 0.3952086052502788, \
0.86460527303447]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.18736123677107708`, 0.3952086052502788, 
                    0.86460527303447]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.18736123677107708`, 0.3952086052502788, 0.86460527303447],
                   Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.7776461280660796, 0.8643601244579295, 
                    0.9944319426310919], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.5184307520440531, 0.5762400829719531, 
                    0.6629546284207279], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.7776461280660796, 0.8643601244579295, \
0.9944319426310919]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.7776461280660796, 0.8643601244579295, 
                    0.9944319426310919]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.7776461280660796, 0.8643601244579295, 0.9944319426310919],
                   Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.10244743490058794`, 0.1869170597224914, 
                    0.6271170684614624], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.0682982899337253, 0.1246113731483276, 
                    0.41807804564097495`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.10244743490058794, 0.1869170597224914, \
0.6271170684614624]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.10244743490058794`, 0.1869170597224914, 
                    0.6271170684614624]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.10244743490058794`, 0.1869170597224914, 
                   0.6271170684614624], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.4573447796522936, 0.007181376876192136, 
                    0.566195028583903], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.30489651976819576`, 0.004787584584128091, 
                    0.3774633523892687], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.4573447796522936, 0.007181376876192136, \
0.566195028583903]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.4573447796522936, 0.007181376876192136, 
                    0.566195028583903]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.4573447796522936, 0.007181376876192136, 
                   0.566195028583903], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.23258722219837846`, 0.08344742427005825, 
                    0.30644177688225716`], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.15505814813225233`, 0.05563161618003883, 
                    0.20429451792150477`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.23258722219837846, 0.08344742427005825, \
0.30644177688225716]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.23258722219837846`, 0.08344742427005825, 
                    0.30644177688225716`]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.23258722219837846`, 0.08344742427005825, 
                   0.30644177688225716`], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.711485166849398, 0.017375777675906035`, 
                    0.7454946682315056], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.47432344456626535`, 0.011583851783937357`, 
                    0.4969964454876704], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.711485166849398, 0.017375777675906035, \
0.7454946682315056]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.711485166849398, 0.017375777675906035`, 
                    0.7454946682315056]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.711485166849398, 0.017375777675906035`, 
                   0.7454946682315056], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.31452599923983104`, 0.6908103742720597, 
                    0.9463506847311731], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.2096839994932207, 0.4605402495147065, 
                    0.6309004564874487], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.31452599923983104, 0.6908103742720597, \
0.9463506847311731]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.31452599923983104`, 0.6908103742720597, 
                    0.9463506847311731]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.31452599923983104`, 0.6908103742720597, 
                   0.9463506847311731], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.922559309792595, 0.2703946335791436, 
                    0.09665543181913394], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.6150395398617301, 0.18026308905276242`, 
                    0.0644369545460893], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.922559309792595, 0.2703946335791436, \
0.09665543181913394]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.922559309792595, 0.2703946335791436, 
                    0.09665543181913394]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.922559309792595, 0.2703946335791436, 0.09665543181913394],
                   Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.11122524183982829`, 0.12772449779541217`, 
                    0.6139200516853858], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.0741501612265522, 0.08514966519694145, 
                    0.40928003445692385`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.11122524183982829, 0.12772449779541217, \
0.6139200516853858]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.11122524183982829`, 0.12772449779541217`, 
                    0.6139200516853858]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.11122524183982829`, 0.12772449779541217`, 
                   0.6139200516853858], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.6357194627252103, 0.15357943517679362`, 
                    0.860476954867391], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.4238129751501402, 0.10238629011786242`, 
                    0.5736513032449273], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.6357194627252103, 0.15357943517679362, \
0.860476954867391]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.6357194627252103, 0.15357943517679362`, 
                    0.860476954867391]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.6357194627252103, 0.15357943517679362`, 
                   0.860476954867391], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.4431832834876257, 0.18321465791748515`, 
                    0.7764518003586576], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.2954555223250838, 0.12214310527832344`, 
                    0.5176345335724384], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.4431832834876257, 0.18321465791748515, \
0.7764518003586576]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.4431832834876257, 0.18321465791748515`, 
                    0.7764518003586576]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.4431832834876257, 0.18321465791748515`, 
                   0.7764518003586576], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.3553518860908462, 0.6443320866741731, 
                    0.7499636864238166], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.2369012573938975, 0.42955472444944875`, 
                    0.4999757909492111], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.3553518860908462, 0.6443320866741731, \
0.7499636864238166]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.3553518860908462, 0.6443320866741731, 
                    0.7499636864238166]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.3553518860908462, 0.6443320866741731, 0.7499636864238166],
                   Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.8943854155561495, 0.03560200287351467, 
                    0.16578917868909593`], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.5962569437040997, 0.023734668582343115`, 
                    0.11052611912606396`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.8943854155561495, 0.03560200287351467, \
0.16578917868909593]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.8943854155561495, 0.03560200287351467, 
                    0.16578917868909593`]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.8943854155561495, 0.03560200287351467, 
                   0.16578917868909593`], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.6672396717157738, 0.3586192991395154, 
                    0.8976595916455246], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, 
                    Frame -> True, FrameStyle -> 
                    RGBColor[
                    0.4448264478105159, 0.23907953275967694`, 
                    0.598439727763683], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.6672396717157738, 0.3586192991395154, \
0.8976595916455246]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.6672396717157738, 0.3586192991395154, 
                    0.8976595916455246]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.6672396717157738, 0.3586192991395154, 0.8976595916455246],
                   Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.37001635641206, 0.3047563933568622, 0.7684408201506054], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.24667757094137333`, 0.20317092890457483`, 
                    0.5122938801004037], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.37001635641206, 0.3047563933568622, \
0.7684408201506054]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.37001635641206, 0.3047563933568622, 0.7684408201506054]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.37001635641206, 0.3047563933568622, 0.7684408201506054], 
                  Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.38698691150966935`, 0.10328204902950966`, 
                    0.8013210231747274], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.2579912743397796, 0.06885469935300645, 
                    0.5342140154498183], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    
                    "RGBColor[0.38698691150966935, 0.10328204902950966, \
0.8013210231747274]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.38698691150966935`, 0.10328204902950966`, 
                    0.8013210231747274]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.38698691150966935`, 0.10328204902950966`, 
                   0.8013210231747274], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.29215345853340424`, 0.35497646703617836`, 
                    0.6346432521789236], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.19476897235560284`, 0.2366509780241189, 
                    0.42309550145261576`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.29215345853340424, 0.35497646703617836, \
0.6346432521789236]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.29215345853340424`, 0.35497646703617836`, 
                    0.6346432521789236]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.29215345853340424`, 0.35497646703617836`, 
                   0.6346432521789236], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.9678407581110904, 0.025426491397912976`, 
                    0.587777889276665], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.6452271720740603, 0.01695099426527532, 
                    0.3918519261844433], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.9678407581110904, 0.025426491397912976, \
0.587777889276665]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.9678407581110904, 0.025426491397912976`, 
                    0.587777889276665]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.9678407581110904, 0.025426491397912976`, 
                   0.587777889276665], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.4918965330955356, 0.29233426982370303`, 
                    0.5281824844462943], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.3279310220636904, 0.19488951321580203`, 
                    0.35212165629752956`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.4918965330955356, 0.29233426982370303, \
0.5281824844462943]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.4918965330955356, 0.29233426982370303`, 
                    0.5281824844462943]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.4918965330955356, 0.29233426982370303`, 
                   0.5281824844462943], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.1252423737911874, 0.5183189386335805, 
                    0.7491160058315705], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.08349491586079161, 0.34554595908905367`, 
                    0.4994106705543803], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.1252423737911874, 0.5183189386335805, \
0.7491160058315705]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.1252423737911874, 0.5183189386335805, 
                    0.7491160058315705]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.1252423737911874, 0.5183189386335805, 0.7491160058315705],
                   Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.9765556387211944, 0.12357617097291551`, 
                    0.5068373458296718], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.6510370924807963, 0.08238411398194367, 
                    0.33789156388644787`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.9765556387211944, 0.12357617097291551, \
0.5068373458296718]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.9765556387211944, 0.12357617097291551`, 
                    0.5068373458296718]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.9765556387211944, 0.12357617097291551`, 
                   0.5068373458296718], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.8227934753153485, 0.3797246867796864, 
                    0.6782582898466567], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.5485289835435657, 0.25314979118645764`, 
                    0.45217219323110447`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.8227934753153485, 0.3797246867796864, \
0.6782582898466567]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.8227934753153485, 0.3797246867796864, 
                    0.6782582898466567]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.8227934753153485, 0.3797246867796864, 0.6782582898466567],
                   Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.6820734720667967, 0.43856527685111324`, 
                    0.8695673460178908], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.45471564804453113`, 0.29237685123407553`, 
                    0.5797115640119272], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.6820734720667967, 0.43856527685111324, \
0.8695673460178908]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.6820734720667967, 0.43856527685111324`, 
                    0.8695673460178908]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.6820734720667967, 0.43856527685111324`, 
                   0.8695673460178908], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.11654903299881392`, 0.07006336344132391, 
                    0.56484752468554], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.07769935533254262, 0.04670890896088261, 
                    0.37656501645702667`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.11654903299881392, 0.07006336344132391, \
0.56484752468554]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.11654903299881392`, 0.07006336344132391, 
                    0.56484752468554]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.11654903299881392`, 0.07006336344132391, 
                   0.56484752468554], Editable -> False, Selectable -> False],
                  ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.6402988781363921, 0.035330434441392944`, 
                    0.28001275709114415`], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.4268659187575947, 0.02355362296092863, 
                    0.18667517139409612`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.6402988781363921, 0.035330434441392944, \
0.28001275709114415]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.6402988781363921, 0.035330434441392944`, 
                    0.28001275709114415`]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.6402988781363921, 0.035330434441392944`, 
                   0.28001275709114415`], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.4249737173056105, 0.08087713350797054, 
                    0.5561568741925262], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.2833158115370737, 0.053918089005313696`, 
                    0.37077124946168416`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.4249737173056105, 0.08087713350797054, \
0.5561568741925262]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.4249737173056105, 0.08087713350797054, 
                    0.5561568741925262]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.4249737173056105, 0.08087713350797054, 
                   0.5561568741925262], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.7495302686726302, 0.3453338459340154, 
                    0.3119406215616949], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.4996868457817535, 0.23022256395601026`, 
                    0.20796041437446328`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.7495302686726302, 0.3453338459340154, \
0.3119406215616949]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.7495302686726302, 0.3453338459340154, 
                    0.3119406215616949]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.7495302686726302, 0.3453338459340154, 0.3119406215616949],
                   Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.836090631447431, 0.10393312541533217`, 
                    0.9133348768403533], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.5573937542982874, 0.06928875027688812, 
                    0.6088899178935689], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.836090631447431, 0.10393312541533217, \
0.9133348768403533]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.836090631447431, 0.10393312541533217`, 
                    0.9133348768403533]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.836090631447431, 0.10393312541533217`, 
                   0.9133348768403533], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.19151655035273674`, 0.14390156161230028`, 
                    0.5247101500257152], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.12767770023515784`, 0.09593437440820018, 
                    0.34980676668381017`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.19151655035273674, 0.14390156161230028, \
0.5247101500257152]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.19151655035273674`, 0.14390156161230028`, 
                    0.5247101500257152]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.19151655035273674`, 0.14390156161230028`, 
                   0.5247101500257152], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.8789399682999111, 0.042929493135203334`, 
                    0.19233219566452364`], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.5859599788666074, 0.028619662090135556`, 
                    0.1282214637763491], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.8789399682999111, 0.042929493135203334, \
0.19233219566452364]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.8789399682999111, 0.042929493135203334`, 
                    0.19233219566452364`]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.8789399682999111, 0.042929493135203334`, 
                   0.19233219566452364`], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.8279081820793655, 0.007601665021679249, 
                    0.007776314948584773], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.5519387880529103, 0.0050677766811195, 
                    0.005184209965723182], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    
                    "RGBColor[0.8279081820793655, 0.007601665021679249, \
0.007776314948584773]"], Appearance -> None, BaseStyle -> {}, 
                   BaselinePosition -> Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.8279081820793655, 0.007601665021679249, 
                    0.007776314948584773]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.8279081820793655, 0.007601665021679249, 
                   0.007776314948584773], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.8905220469868362, 0.6720465313460078, 
                    0.8782899541874138], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.5936813646578909, 0.44803102089733854`, 
                    0.5855266361249426], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.8905220469868362, 0.6720465313460078, \
0.8782899541874138]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.8905220469868362, 0.6720465313460078, 
                    0.8782899541874138]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.8905220469868362, 0.6720465313460078, 0.8782899541874138],
                   Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.4739838883353795, 0.01643240988333261, 
                    0.7672816104627056], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.31598925889025303`, 0.01095493992222174, 
                    0.5115210736418038], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.4739838883353795, 0.01643240988333261, \
0.7672816104627056]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.4739838883353795, 0.01643240988333261, 
                    0.7672816104627056]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.4739838883353795, 0.01643240988333261, 
                   0.7672816104627056], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.73262590528079, 0.4345872718612065, 0.9513218213654053], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.48841727018719333`, 0.289724847907471, 
                    0.634214547576937], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.73262590528079, 0.4345872718612065, \
0.9513218213654053]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.73262590528079, 0.4345872718612065, 0.9513218213654053]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.73262590528079, 0.4345872718612065, 0.9513218213654053], 
                  Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.7193138046226939, 0.736637476380962, 
                    0.9909551197977506], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.4795425364151293, 0.49109165092064133`, 
                    0.6606367465318338], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.7193138046226939, 0.736637476380962, \
0.9909551197977506]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.7193138046226939, 0.736637476380962, 
                    0.9909551197977506]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.7193138046226939, 0.736637476380962, 0.9909551197977506], 
                  Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.5532261835871646, 0.1424067735626049, 
                    0.6840947116434117], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.3688174557247764, 0.0949378490417366, 
                    0.45606314109560786`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.5532261835871646, 0.1424067735626049, \
0.6840947116434117]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.5532261835871646, 0.1424067735626049, 
                    0.6840947116434117]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.5532261835871646, 0.1424067735626049, 0.6840947116434117],
                   Editable -> False, Selectable -> False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.24015696649735507`, 0.2276921291555416, 
                    0.5618669828113934], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.16010464433157007`, 0.15179475277036109`, 
                    0.37457798854092894`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.24015696649735507, 0.2276921291555416, \
0.5618669828113934]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.24015696649735507`, 0.2276921291555416, 
                    0.5618669828113934]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.24015696649735507`, 0.2276921291555416, 
                   0.5618669828113934], Editable -> False, Selectable -> 
                  False], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.3614530023699991, 0.23838000474075272`, 
                    0.351099450461986], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.24096866824666607`, 0.1589200031605018, 
                    0.23406630030799067`], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                    "RGBColor[0.3614530023699991, 0.23838000474075272, \
0.351099450461986]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.3614530023699991, 0.23838000474075272`, 
                    0.351099450461986]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.3614530023699991, 0.23838000474075272`, 
                   0.351099450461986], Editable -> False, Selectable -> 
                  False]}], "}"}]}], "}"}]], "ExerciseOutput", Selectable -> 
        False, Copyable -> False, Editable -> False, ShowCellBracket -> 
        False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"aae7eeba-c3d4-43ca-8f2f-8fdcca3b4fcf"]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Q&A", "QASection",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"p:127",ExpressionUUID->"f1614bd5-3320-4b37-9b9c-c6788d93c17a"],

Cell["How do Wolfram Language functions for machine learning work?", \
"Question",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"bb8ed27a-a6ab-4d91-89a7-d906824dc586"],

Cell["\<\
They use a range of state-of-the-art methods, and have meta-algorithms for \
picking between methods based on the particular problems they\
\[CloseCurlyQuote]re given. \
\>", "Answer",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:19",ExpressionUUID->"fb5bafd0-5ba3-4aa4-93ca-380e4eb0c255"],

Cell[TextData[{
 "Doesn\[CloseCurlyQuote]t ",
 ButtonBox["LanguageIdentify",
  BaseStyle->"Link"],
 " just need a dictionary?"
}], "Question",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"5dea382a-3c4e-4146-86b2-c14381b24524"],

Cell["\<\
No. Specific words can occur in several languages. One needs to learn from \
examples how to deduce the language from combinations of words.\
\>", "Answer",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:20",ExpressionUUID->"dc1c923e-93fc-4850-80fd-4d9a7551687a"],

Cell[TextData[{
 "Can ",
 ButtonBox["ImageIdentify",
  BaseStyle->"Link"],
 " get the wrong answer?"
}], "Question",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"9e001ff8-305a-44ec-9af9-c739810fbae1"],

Cell["\<\
Yes. It can make mistakes, much like a human. This happens particularly if it\
\[CloseCurlyQuote]s asked about an object that\[CloseCurlyQuote]s in an \
unusual configuration or environment.\
\>", "Answer",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"0918495e-913d-4f4b-8227-d8b5c77122e1"],

Cell[TextData[{
 "Can I ask ",
 ButtonBox["ImageIdentify",
  BaseStyle->"Link"],
 " ",
 "the probabilities it assigns to different identifications",
 "?"
}], "Question",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"6faa2c57-9cfe-4972-8561-b77a93b80bd5"],

Cell[TextData[{
 "Yes. To find the probabilities for the top 10 identifications in all \
categories use ",
 Cell[BoxData[
  RowBox[{
   ButtonBox["ImageIdentify",
    BaseStyle->"CodeLink"], "[", 
   RowBox[{
    StyleBox["image", "CodeVariable"], ",", "All", ",", "10", ",", 
    "\"\<Probability\>\""}], "]"}]], "InlineCode",ExpressionUUID->
  "c2e1ff20-9901-48c9-8627-d7ece5eb694a"],
 "."
}], "Answer",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:21",ExpressionUUID->"d93e94aa-57e9-4082-a4e4-e99ba88690b7"],

Cell[TextData[{
 "How many examples does ",
 ButtonBox["Classify",
  BaseStyle->"Link"],
 " typically need to work well?"
}], "Question",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"23fd5b0b-b3f2-4ce9-b412-f06d01e6a43c"],

Cell["\<\
If the general area (like everyday images) is one it already knows well, then \
as few as a hundred. But in areas that are new, it can take many millions of \
examples to achieve good results. \
\>", "Answer",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"8544cc65-0b7d-4476-aa68-73af26cdd798"],

Cell[TextData[{
 "How does ",
 ButtonBox["Nearest",
  BaseStyle->"Link"],
 " figure out a distance between colors?"
}], "Question",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"a2dc4acf-b49b-47c6-952c-dd73d3c356b4"],

Cell[TextData[{
 "It uses",
 " the function ",
 ButtonBox["ColorDistance",
  BaseStyle->"Link"],
 ", which is based on a model of human color vision."
}], "Answer",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:22",ExpressionUUID->"f3fb7961-3a3c-470b-b926-bb7f71b8479d"],

Cell[TextData[{
 "How does ",
 ButtonBox["Nearest",
  BaseStyle->"Link"],
 " determine nearby words?"
}], "Question",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"aaf7fea0-193d-4b3b-878d-63bc5528c86e"],

Cell[TextData[{
 "By looking at those at the smallest ",
 ButtonBox["EditDistance",
  BaseStyle->"Link"],
 ", that is, reached by the smallest number of single-letter insertions, \
deletions and substitutions."
}], "Answer",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:23",ExpressionUUID->"1be5a182-5cde-4f5a-9f9b-d8383d74fbbd"],

Cell["Can a single graph have several disconnected parts?", "Question",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:24",ExpressionUUID->"70b9cef2-9d85-4f81-ae4a-569efe31b9ed"],

Cell[TextData[{
 "Absolutely. An example is the ",
 ButtonBox["last graph in this section",
  BaseStyle->"Hyperlink",
  ButtonData->{
    StringJoin[
     ReplaceAll["22-MachineLearning", "EIWL1-22-machine-learning.nb"], ".nb"],
     "graph-with-disconnected-parts"}],
 ". "
}], "Answer",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"82af8ce3-e225-4630-b527-419bf88ea212"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Tech Notes", "TechNoteSection",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"aef2a434-0902-439d-bc13-c09183d9ceff"],

Cell[TextData[{
 ButtonBox["BarcodeImage",
  BaseStyle->"Link"],
 " and ",
 ButtonBox["BarcodeRecognize",
  BaseStyle->"Link"],
 " work with bar codes and QR codes ",
 "instead of pure text",
 "."
}], "TechNote",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:25",ExpressionUUID->"2aedfa9b-b856-4d5a-8dc3-54ad1700c7e8"],

Cell[TextData[{
 ButtonBox["ImageIdentify",
  BaseStyle->"Link"],
 " is the core of what the ",
 ButtonBox["imageidentify.com",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.imageidentify.com"], None},
  ButtonNote->"http://www.imageidentify.com"],
 " website does."
}], "TechNote",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:26",ExpressionUUID->"e3863f9d-3dbf-490c-b4e7-06e3c7a8b4c6"],

Cell[TextData[{
 ButtonBox["ImageIdentify",
  BaseStyle->"Link"],
 " uses methods that are inspired by idealized models of neural networks in \
the brain. "
}], "TechNote",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:27",ExpressionUUID->"4fbe9504-c35f-4977-b2ca-840fef9531ac"],

Cell[TextData[{
 "If you just give ",
 ButtonBox["Classify",
  BaseStyle->"Link"],
 " training examples, it\[CloseCurlyQuote]ll produce a ",
 ButtonBox["ClassifierFunction",
  BaseStyle->"Link"],
 " that can later be applied to many different pieces of data.  This is \
pretty much always how ",
 ButtonBox["Classify",
  BaseStyle->"Link"],
 " is used in practice."
}], "TechNote",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:28",ExpressionUUID->"c179a738-f049-41df-a9b1-85f7b2756df5"],

Cell[TextData[{
 ButtonBox["Classify",
  BaseStyle->"Link"],
 " automatically picks between methods such as ",
 StyleBox["logistic regression",
  FontSlant->"Italic"],
 ", ",
 StyleBox["naive Bayes",
  FontSlant->"Italic"],
 ", ",
 StyleBox["random forests",
  FontSlant->"Italic"],
 ", ",
 StyleBox["support vector machines",
  FontSlant->"Italic"],
 " and ",
 StyleBox["neural networks",
  FontSlant->"Italic"],
 "."
}], "TechNote",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:29",ExpressionUUID->"19ced587-b3f4-474b-9cb2-480acc9d600b"],

Cell[TextData[{
 ButtonBox["FindClusters",
  BaseStyle->"Link"],
 " does ",
 StyleBox["unsupervised machine learning",
  FontSlant->"Italic"],
 ", where the computer just looks at data without being told anything about \
it. ",
 ButtonBox["Classify",
  BaseStyle->"Link"],
 " does ",
 StyleBox["supervised machine learning",
  FontSlant->"Italic"],
 ", being given a set of training examples. "
}], "TechNote",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:30",ExpressionUUID->"682a597c-ffe1-4849-b12f-b0aea0cd754e"]
}, Open  ]],

Cell[CellGroupData[{

Cell["More to Explore", "MoreExploreSection",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"af834819-eae0-42f0-a8c7-664a8af0461b"],

Cell[TextData[ButtonBox["Guide to Machine Learning in the Wolfram Language\
\[NonBreakingSpace]\[RightGuillemet]",
 BaseStyle->"Link",
 ButtonData->{"paclet:guide/MachineLearning", None}]], "MoreExplore",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->
  "LastCellOfAPage",ExpressionUUID->"45c06e9d-fb71-47cb-8774-ba3c094fa4b9"]
}, Open  ]]
},
Saveable->False,
WindowToolbars->{},
BlinkingCellInsertionPoint->False,
CellInsertionPointCell->None,
WindowSize->{830, 800},
WindowMargins->Automatic,
WindowPersistentStyles->{
 WindowFrame, WindowMargins, WindowSize, Magnification},
WindowTitle->"Machine Learning: Elementary Introduction to the Wolfram \
Language",
DockedCells->{
  Cell[
   BoxData[
    TagBox[
     GridBox[{{
        TemplateBox[{
         "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]", 
          "\"\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\"", 
          GraphicsBox[
           TagBox[
            RasterBox[CompressedData["
1:eJztl01IVFEUxyctMFzUysjIyUDCTauiIJFM6ENpM4NEtJrBUaSYZMYPhCRm
rYuoICgiW0VEBVIUEbTNEMTAIqRsk6JGCVFBHx7//+4JLo/36DqvB4Ie+Mk7
7+t3733nHpzq9NlEW0ksFsuX4U8i1duQy6X6kpuRtGTzHe3ZTOuxbFemPZPb
ny7FyZ2gEqwHInICfJToguOIReywPVHHlYDzcY4hJHZ486giyBOXtfms5Pms
Bs9zUBDTow6DJOgBT8DP/+B5CepAPbgqZm+zT70Bt9VXCx6H8DwE28Gw5ufB
IT2eA1N6PKquC0V4xtUxqfkE6ARD4BHYAx5Y938Gu8GdZXq4VsNWngIfwDzY
Aa6Bm55nOKYq8NXRw29eb+Uz4JSVd4Nn4IbPs2fARUdPQcfLWAQJ8Mq6Tkdd
gGcEHHT0sHYn9Jg1dcnnnhf6vnee8xzXVkcP9wdr97eY7z0NnlrX74qpxffg
iOZ2VDp6kvqOe6AVXAb7xNQB462YNfsCfoBzoE1MzTEqHD096mgE98WsEec4
Jqamvvk8cx2kwWuw19HDXnIAbNAx03ka9IO8mO+3ScyebRZTi01i1rqguHjY
r3aJWaugOA5O6vEC+K6ebWDW0cNgv6oBnwKus87KwKDmv8BRMOBz77/6G/sV
e8lkwHWuTwm4pQ7WzGIRHgb7FXsJ9/mI5z2si42gXMw8/ByuHgb7FXsJ9yX3
IPfHFjF1xTl5v0exnrCx5gnn+fu7JC7h/z/0Y52+P+rfWX9iCXVYErg=
             "], {{0,
              34}, {26, 0}}, {0, 255}, ColorFunction -> RGBColor], 
            BoxForm`ImageTag[
            "Byte", ColorSpace -> "RGB", Interleaving -> True, Magnification -> 
             1], Selectable -> False], DefaultBaseStyle -> "ImageGraphics", 
           ImageSize -> Magnification[1], ImageSizeRaw -> {26, 34}, 
           PlotRange -> {{0, 26}, {0, 34}}], 
          GraphicsBox[
           TagBox[
            RasterBox[CompressedData["
1:eJztXUuS47gRLX8WXtYRaJ+gl17SS+8U4/CeM+H2hDdtRY8jHF6ZR9AReATt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             "], {{0, 34}, {383, 0}}, {0, 255}, 
             ColorFunction -> RGBColor], 
            BoxForm`ImageTag[
            "Byte", ColorSpace -> "RGB", Interleaving -> True, Magnification -> 
             1], Selectable -> False], DefaultBaseStyle -> "ImageGraphics", 
           ImageSize -> Magnification[1], ImageSizeRaw -> {383, 34}, 
           PlotRange -> {{0, 383}, {0, 34}}]}, "RowWithSeparators"], 
        PaneBox[
         StyleBox["\[VeryThinSpace]", ShowStringCharacters -> False], 
         Alignment -> Right, ImageSize -> {174, 47}], 
        PaneBox[
         PaneBox[
          TemplateBox[{"\[ThinSpace]", "\" \"", 
            TagBox[
             TooltipBox[
              PaneSelectorBox[{False -> ButtonBox[
                  PaneBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAPiDmBmIUBO/j//z8jEDcA8W8g3oBFnhmIZ/9HgE9o8mxAvBZJ/hsQuyPJ
8wPxfiT5N0BsjiQvCsTnkOSfALEWkrwSEN9Bkr8OxDJobniAJP8ZZCYWfxCj
RpGQXcS4mVi/ExuGxMYFmlp4nAIAG14fWQ==
                    "], {{0, 14}, {9, 
                    0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                     ImageSizeRaw -> {9, 14}, PlotRange -> {{0, 9}, {0, 14}}, 
                    ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                   Alignment -> Center], 
                  ButtonFunction :> (
                   NotebookLocate[{"EIWL1-21-graphs-and-networks.nb", ""}, 
                    FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Enabled -> True, Appearance -> 
                  None, Evaluator -> Automatic, Method -> "Preemptive"], True -> 
                ButtonBox[
                  PaneBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAPiDmBmIUBO/j//z8jEDcA8W8g3oBFnhmIZ/9HgE9o8mxAvBZJ/hsQuyPJ
8wPxfiT5N0BsjiQvCsTnkOSfALEWkrwSEN9Bkr8OxDJobniAJP8ZZCYWfxCj
RpGQXcS4mVi/ExuGxMYFmlp4nAIAG14fWQ==
                    "], {{0, 14}, {9, 
                    0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                     ImageSizeRaw -> {9, 14}, PlotRange -> {{0, 9}, {0, 14}}, 
                    ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                   Alignment -> Center], 
                  ButtonFunction :> (
                   NotebookLocate[{"EIWL1-21-graphs-and-networks.nb", ""}, 
                    FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Enabled -> True, Appearance -> 
                  None, Background -> RGBColor[0.835294, 0.364706, 0.0196078],
                   Evaluator -> Automatic, Method -> "Preemptive"]}, 
               Dynamic[
                CurrentValue["MouseOver"]], ImageSize -> Automatic, 
               FrameMargins -> 0], "\"Graphs and Networks\"", TooltipDelay -> 
              0.15, LabelStyle -> "TextStyling"], 
             Annotation[#, "Graphs and Networks", "Tooltip"]& ], 
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {5, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[5], Selectable -> False], 
            TagBox[
             TooltipBox[
              PaneSelectorBox[{False -> ButtonBox[
                  PaneBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAfiDmBmAWI////vwKIfwFxMQMOAJT7+R8B6nGoSf+PCjpwqMskUl0SEP9F
UtcHxIxY1EWjqZuOQ10Mmr2TcNj7BEnNP1LNIeQeIDsZn78IhQ8x4fwfNb4a
cPgTFu8l2ORBAAC+1hnm
                    "], {{0, 15}, {9, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                     ImageSizeRaw -> {9, 15}, PlotRange -> {{0, 9}, {0, 15}}, 
                    ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                   Alignment -> Center], 
                  ButtonFunction :> (
                   NotebookLocate[{"EIWL1-23-more-about-numbers.nb", ""}, 
                    FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Appearance -> None, Evaluator -> 
                  Automatic, Method -> "Preemptive"], True -> ButtonBox[
                  PaneBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAfiDmBmAWI////vwKIfwFxMQMOAJT7+R8B6nGoSf+PCjpwqMskUl0SEP9F
UtcHxIxY1EWjqZuOQ10Mmr2TcNj7BEnNP1LNIeQeIDsZn78IhQ8x4fwfNb4a
cPgTFu8l2ORBAAC+1hnm
                    "], {{0, 15}, {9, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                     ImageSizeRaw -> {9, 15}, PlotRange -> {{0, 9}, {0, 15}}, 
                    ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                   Alignment -> Center], 
                  ButtonFunction :> (
                   NotebookLocate[{"EIWL1-23-more-about-numbers.nb", ""}, 
                    FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Appearance -> None, Background -> 
                  RGBColor[0.835294, 0.364706, 0.0196078], Evaluator -> 
                  Automatic, Method -> "Preemptive"]}, 
               Dynamic[
                CurrentValue["MouseOver"]], ImageSize -> Automatic, 
               FrameMargins -> 0], "\"More about Numbers\"", TooltipDelay -> 
              0.15, LabelStyle -> "TextStyling"], 
             Annotation[#, "More about Numbers", "Tooltip"]& ]}, 
           "RowWithSeparators"], Alignment -> Right], ImageSize -> {100, 30}, 
         FrameMargins -> {{0, 6}, {0, 0}}, Alignment -> Right], 
        ActionMenuBox[
         PaneSelectorBox[{True -> PanelBox[
             GraphicsBox[
              TagBox[
               RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UBAkIQ3ELED8////Jf/pA0D2/KWTXSB7ZtPBPrA9DKOAYgAMR1Eg9gPiABpi
P6g912mcLmAAZM9XOtkFsicKiNcD8QYaYpD5UQOdXoYD+E/HMooO9iDbR7c6
BQDxtyEt
                "], {{0, 16}, {27, 0}}, {0, 255}, ColorFunction -> 
                RGBColor], 
               BoxForm`ImageTag[
               "Byte", ColorSpace -> "RGB", Interleaving -> True, 
                Magnification -> 1], Selectable -> False], DefaultBaseStyle -> 
              "ImageGraphics", ImageSize -> Magnification[1], 
              ImageSizeRaw -> {27, 16}, PlotRange -> {{0, 27}, {0, 16}}], 
             Appearance -> None, Background -> 
             RGBColor[0.835294, 0.364706, 0.0196078], ImageSize -> {35, 30}, 
             Alignment -> Center], False -> PanelBox[
             GraphicsBox[
              TagBox[
               RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UBAkIQ3ELED8////Jf/pA0D2/KWTXSB7ZtPBPrA9DKOAYgAMR1Eg9gPiABpi
P6g912mcLmAAZM9XOtkFsicKiNcD8QYaYpD5UQOdXoYD+E/HMooO9iDbR7c6
BQDxtyEt
                "], {{0, 16}, {27, 0}}, {0, 255}, ColorFunction -> 
                RGBColor], 
               BoxForm`ImageTag[
               "Byte", ColorSpace -> "RGB", Interleaving -> True, 
                Magnification -> 1], Selectable -> False], DefaultBaseStyle -> 
              "ImageGraphics", ImageSize -> Magnification[1], 
              ImageSizeRaw -> {27, 16}, PlotRange -> {{0, 27}, {0, 16}}], 
             Appearance -> None, Background -> 
             RGBColor[0.952941, 0.509804, 0], ImageSize -> {35, 30}, 
             Alignment -> Center]}, 
          Dynamic[
           CurrentValue["MouseOver"]]], {
         "Preface" :> 
          NotebookLocate[{"EIWL1-0a-preface.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "What Is the Wolfram Language?" :> 
          NotebookLocate[{"EIWL1-0b-what-is-the-wolfram-language.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "Practicalities of Using the Wolfram Language" :> 
          NotebookLocate[{
            "EIWL1-0c-practicalities-of-using-the-wolfram-language.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "Other Resources" :> 
          NotebookLocate[{"EIWL1-0d-other-resources.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]1\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Starting Out: Elementary Arithmetic" :> 
          NotebookLocate[{
            "EIWL1-01-starting-out-elementary-arithmetic.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]2\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Introducing Functions" :> 
          NotebookLocate[{"EIWL1-02-introducing-functions.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]3\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]First Look at Lists" :> 
          NotebookLocate[{"EIWL1-03-first-look-at-lists.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]4\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Displaying Lists" :> 
          NotebookLocate[{"EIWL1-04-displaying-lists.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]5\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Operations on Lists" :> 
          NotebookLocate[{"EIWL1-05-operations-on-lists.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]6\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Making Tables" :> 
          NotebookLocate[{"EIWL1-06-making-tables.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]7\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Colors and Styles" :> 
          NotebookLocate[{"EIWL1-07-colors-and-styles.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]8\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Basic Graphics Objects" :> 
          NotebookLocate[{"EIWL1-08-basic-graphics-objects.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]9\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Interactive Manipulation" :> 
          NotebookLocate[{"EIWL1-09-interactive-manipulation.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "10\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Images" :> 
          NotebookLocate[{"EIWL1-10-images.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "11\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Strings and \
Text" :> NotebookLocate[{"EIWL1-11-strings-and-text.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "12\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Sound" :> 
          NotebookLocate[{"EIWL1-12-sound.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "13\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Arrays, or \
Lists of Lists" :> 
          NotebookLocate[{"EIWL1-13-arrays-or-lists-of-lists.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "14\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Coordinates \
and Graphics" :> 
          NotebookLocate[{"EIWL1-14-coordinates-and-graphics.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "15\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]The Scope \
of the Wolfram Language" :> 
          NotebookLocate[{
            "EIWL1-15-the-scope-of-the-wolfram-language.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "16\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Real\
\[VeryThinSpace]\[Hyphen]\[VeryThinSpace]\[NegativeVeryThinSpace]World Data" :> 
          NotebookLocate[{"EIWL1-16-real-world-data.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "17\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Units" :> 
          NotebookLocate[{"EIWL1-17-units.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "18\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]\
Geocomputation" :> 
          NotebookLocate[{"EIWL1-18-geocomputation.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "19\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Dates and \
Times" :> NotebookLocate[{"EIWL1-19-dates-and-times.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "20\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Options" :> 
          NotebookLocate[{"EIWL1-20-options.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "21\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Graphs and \
Networks" :> 
          NotebookLocate[{"EIWL1-21-graphs-and-networks.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "22\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Machine \
Learning" :> 
          NotebookLocate[{"EIWL1-22-machine-learning.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "23\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]More about \
Numbers" :> NotebookLocate[{"EIWL1-23-more-about-numbers.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "24\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]More Forms \
of Visualization" :> 
          NotebookLocate[{"EIWL1-24-more-forms-of-visualization.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "25\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Ways to \
Apply Functions" :> 
          NotebookLocate[{"EIWL1-25-ways-to-apply-functions.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "26\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Pure \
Anonymous Functions" :> 
          NotebookLocate[{"EIWL1-26-pure-anonymous-functions.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "27\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Applying \
Functions Repeatedly" :> 
          NotebookLocate[{"EIWL1-27-applying-functions-repeatedly.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "28\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Tests and \
Conditionals" :> 
          NotebookLocate[{"EIWL1-28-tests-and-conditionals.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "29\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]More about \
Pure Functions" :> 
          NotebookLocate[{"EIWL1-29-more-about-pure-functions.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "30\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Rearranging \
Lists" :> NotebookLocate[{"EIWL1-30-rearranging-lists.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "31\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Parts of \
Lists" :> NotebookLocate[{"EIWL1-31-parts-of-lists.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "32\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Patterns" :> 
          NotebookLocate[{"EIWL1-32-patterns.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "33\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Expressions \
and Their Structure" :> 
          NotebookLocate[{"EIWL1-33-expressions-and-their-structure.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "34\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]\
Associations" :> 
          NotebookLocate[{"EIWL1-34-associations.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "35\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Natural \
Language Understanding" :> 
          NotebookLocate[{"EIWL1-35-natural-language-understanding.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "36\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Creating \
Websites and Apps" :> 
          NotebookLocate[{"EIWL1-36-creating-websites-and-apps.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "37\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Layout and \
Display" :> NotebookLocate[{"EIWL1-37-layout-and-display.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "38\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Assigning \
Names to Things" :> 
          NotebookLocate[{"EIWL1-38-assigning-names-to-things.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "39\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Immediate \
and Delayed Values" :> 
          NotebookLocate[{"EIWL1-39-immediate-and-delayed-values.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "40\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Defining \
Your Own Functions" :> 
          NotebookLocate[{"EIWL1-40-defining-your-own-functions.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "41\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]More about \
Patterns" :> 
          NotebookLocate[{"EIWL1-41-more-about-patterns.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "42\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]String \
Patterns and Templates " :> 
          NotebookLocate[{"EIWL1-42-string-patterns-and-templates.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "43\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Storing \
Things" :> NotebookLocate[{"EIWL1-43-storing-things.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "44\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Importing \
and Exporting" :> 
          NotebookLocate[{"EIWL1-44-importing-and-exporting.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "45\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Datasets" :> 
          NotebookLocate[{"EIWL1-45-datasets.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "46\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Writing \
Good Code" :> 
          NotebookLocate[{"EIWL1-46-writing-good-code.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "47\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Debugging \
Your Code" :> 
          NotebookLocate[{"EIWL1-47-debugging-your-code.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "What We Haven\[CloseCurlyQuote]t Discussed" :> 
          NotebookLocate[{"EIWL1-what-we-havent-discussed.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "Afterword: Being a Programmer" :> 
          NotebookLocate[{"EIWL1-being-a-programmer.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "Answers to Exercises" :> 
          NotebookLocate[{"EIWL1-answers-to-exercises.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "Index" :> 
          NotebookLocate[{"EIWL1-book-index.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}]}, Appearance -> None]}}, 
      GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Center}}}, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"]], 
   "Text", ShowCellBracket -> False, CellFrame -> {{0, 0}, {3, 0}}, 
   Selectable -> False, CellFrameColor -> 
   RGBColor[0.835294, 0.364706, 0.0196078], CellMargins -> {{0, 0}, {0, -1}}, 
   CellFrameMargins -> {{27, 0}, {1, 7}}, Background -> 
   RGBColor[0.952941, 0.509804, 0], CellTags -> "DockedCellLogoCell"], 
  Cell["FIRST EDITION (2015)", "Text", FontFamily -> "Source Sans Pro", 
   CellFrame -> {{0, 0}, {3, 0}}, ShowCellBracket -> False, 
   CellMargins -> {{0, 0}, {-1, -1}}, CellFrameMargins -> {{66, 0}, {2, 4}}, 
   CellFrameColor -> RGBColor[0.952941, 0.509804, 0], FontSize -> 10, 
   FontTracking -> "Extended", FontColor -> RGBColor[1, 0.929412, 0.721569], 
   Background -> RGBColor[0.862745, 0.309804, 0], CellTags -> 
   "DockedCellLogoCell"]},
PrintingStartingPageNumber->180,
PageHeaders->{{
   Cell[
    TextData[{
      StyleBox[
       CounterBox["Page"], "PageNumber"], 
      StyleBox[
      "    An Elementary Introduction to the Wolfram Language", "Header"]}], 
    "Header", CellMargins -> {{37, Inherited}, {Inherited, Inherited}}], None,
    None}, {None, None, 
   Cell[
    TextData[{
      StyleBox[
       CounterBox["Section"], "Header"], 
      StyleBox[" | Machine Learning \[LongDash] wolfr.am/eiwl-", "Header"], 
      StyleBox[
       CounterBox["Section"], "Header"], 
      StyleBox["    ", "Header"], 
      StyleBox[
       CounterBox["Page"], "PageNumber"]}], "Header", 
    CellMargins -> {{Inherited, 17}, {Inherited, Inherited}}]}},
PrintingOptions->{"FirstPageHeader"->True},
ShowCellBracket->Automatic,
ShowSyntaxStyles->False,
Magnification->1.,
FrontEndVersion->"11.1 for Mac OS X x86 (32-bit, 64-bit Kernel) (March 16, \
2017)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "Default.nb"]], 
   Cell[
    CellGroupData[{
      Cell[
      "Style Environments", "Section", 
       CellChangeTimes -> {{3.64661165091824*^9, 3.646611654013329*^9}, 
         3.6485723794335403`*^9, 3.651347081728628*^9, 3.651347179462186*^9, 
         3.651347384135805*^9, 3.651348171662589*^9}], 
      Cell[
       StyleData[All, "Working"], CellInsertionPointCell -> 
       FEPrivate`FrontEndResource["FEExpressions", "CellInsertionMenu"], 
       CreateCellID -> True, $CellContext`GhostCellInEmptyNotebook -> False], 
      
      Cell[
       StyleData[All, "Printout"], 
       PrintingOptions -> {
        "PageSize" -> {504, 720}, "PrintRegistrationMarks" -> True}, 
       Magnification -> 0.6]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell["Styles for Headers and Footers", "Section"], 
      Cell[
       StyleData["Header"], StyleMenuListing -> None, FontFamily -> "Verdana",
        FontSize -> 7, FontSlant -> "Plain", FontColor -> GrayLevel[0.6]], 
      Cell[
       StyleData["PageNumber"], CellMargins -> {{0, 0}, {4, 1}}, 
       StyleMenuListing -> None, FontFamily -> "Verdana", FontSize -> 7, 
       FontWeight -> "Bold", FontSlant -> "Plain", FontColor -> 
       GrayLevel[0]]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell[
      "WPL Specific", "Section", 
       CellChangeTimes -> {{3.6556608433734913`*^9, 3.6556608489412746`*^9}}], 
      Cell[
       StyleData["Link"], FontFamily -> "Source Sans Pro", FontSize :> 
       If[CurrentValue[
           EvaluationCell[], "FontFamily"] === "Source Sans Pro", Inherited, 
         If[CurrentValue[
            EvaluationCell[], "FontFamily"] === "WolframCodeSans", Inherited, 
          Inherited 0.9]], FontColor -> GrayLevel[0]], 
      Cell[
       StyleData["CodeLink"], 
       ButtonBoxOptions -> {
        Appearance -> None, ButtonFunction :> (FEPrivate`FrontEndExecute[
           FrontEndToken["OpenHelpLink", {
             Part[#, 1], Null}]]& ), ButtonSource -> ButtonContents, 
         Evaluator -> None, Method -> "Preemptive"}]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell[
      "Custom Styles", "Section", 
       CellChangeTimes -> {{3.646611660445352*^9, 3.646611669493331*^9}}], 
      Cell[
       StyleData["Notebook"], PageWidth -> 700, 
       PrintingOptions -> {
        "InnerOuterMargins" -> {35, 16}, "PaperOrientation" -> "Portrait", 
         "PaperSize" -> {504, 720}, 
         "PrintingMargins" -> {{20, 20}, {54, 54}}}, CellLabelAutoDelete -> 
       False, ShowSyntaxStyles -> False, MenuSortingValue -> None, 
       GraphicsBoxOptions -> {ImageSize -> 240}, 
       Graphics3DBoxOptions -> {ImageSize -> 240}], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Title"], CellMargins -> {{64, Inherited}, {50, 72}}, 
          MenuCommandKey -> None, FontFamily -> "Verdana", FontSize -> 42, 
          FontWeight -> "Bold", FontColor -> GrayLevel[0.4]], 
         Cell[
          StyleData["Title", "Printout"], 
          CellMargins -> {{64, Inherited}, {50, 72}}]}, Closed]], 
      Cell[
       StyleData["Chapter"], MenuCommandKey -> None], 
      Cell[
       StyleData["Subchapter"], MenuCommandKey -> None], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Section"], CellFrame -> {{0, 0}, {0, 0}}, CellDingbat -> 
          Cell[
            TextData[
             CounterBox["Section"], 
             StyleBox[
             "|\[NegativeThinSpace]", FontColor -> 
              RGBColor[
               0.9019607843137255, 0.4117647058823529, 0.027450980392156862`],
               FontFamily -> "Courier", FontSize -> 36, FontWeight -> Plain]],
             "SectionNumber"], CellMargins -> {{96, Inherited}, {12, 44}}, 
          Evaluatable -> True, CellGroupingRules -> {"SectionGrouping", 60}, 
          PageBreakAbove -> True, ShowCellLabel -> False, 
          CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
          CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
          CounterIncrements -> "Section", 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", 
          FontSize -> 26, FontSlant -> "Plain", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          InterpretationBoxOptions -> {Editable -> True}], 
         Cell[
          StyleData["Section", "Printout"], 
          CellMargins -> {{96, Inherited}, {12, 2}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionDoubleDigit"], CellFrame -> {{0, 0}, {0, 0}}, 
          CellDingbat -> Cell[
            TextData[
             CounterBox["Section"], 
             StyleBox[
             "|\[NegativeThinSpace]", FontColor -> 
              RGBColor[
               0.9019607843137255, 0.4117647058823529, 0.027450980392156862`],
               FontFamily -> "Courier", FontSize -> 36, FontWeight -> Plain]],
             "SectionNumber"], CellMargins -> {{112, Inherited}, {12, 44}}, 
          Evaluatable -> True, CellGroupingRules -> {"SectionGrouping", 60}, 
          PageBreakAbove -> True, ShowCellLabel -> False, 
          CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
          CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
          CounterIncrements -> "Section", 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", 
          FontSize -> 26, FontSlant -> "Plain", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          InterpretationBoxOptions -> {Editable -> True}], 
         Cell[
          StyleData["SectionDoubleDigit", "Printout"], 
          CellMargins -> {{112, Inherited}, {12, 2}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionNumber"], CellBaseline -> Baseline, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 26, FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["SectionNumber", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionInline"], FontFamily -> 
          "Source Sans Pro Semibold", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["SectionInline", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionNoDingbat"], 
          CellMargins -> {{64, Inherited}, {12, 44}}, Evaluatable -> True, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakAbove -> 
          True, ShowCellLabel -> False, 
          CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
          CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
          CounterIncrements -> "Section", 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", 
          FontSize -> 26, FontSlant -> "Plain", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          InterpretationBoxOptions -> {Editable -> True}], 
         Cell[
          StyleData["SectionNoDingbat", "Printout"], 
          CellMargins -> {{64, Inherited}, {12, 2}}]}, Closed]], 
      Cell[
       StyleData["AnswerKeyNumberedSection"], 
       CellMargins -> {{64, Inherited}, {8, 28}}, Evaluatable -> True, 
       CellGroupingRules -> {"SectionGrouping", 60}, PageBreakAbove -> True, 
       ShowCellLabel -> False, 
       CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
       CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
       CounterIncrements -> "Section", 
       CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
         "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", FontSize -> 
       18, FontSlant -> "Plain", FontColor -> 
       RGBColor[
        0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
       InterpretationBoxOptions -> {Editable -> True}], 
      Cell[
       StyleData["AnswerKeySectionNumber"], CellBaseline -> Baseline, 
       FontFamily -> "Source Sans Pro Semibold", FontSize -> 18, FontColor -> 
       RGBColor[
        0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
      Cell[
       StyleData["IndexLinkGuide"], 
       CellMargins -> {{64, Inherited}, {48, 28}}, Evaluatable -> True, 
       CellGroupingRules -> {"SectionGrouping", 60}, PageBreakAbove -> True, 
       ShowCellLabel -> False, 
       CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
       CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
       CounterIncrements -> "Section", 
       CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
         "Exercise", 0}}, FontFamily -> "Source Sans Pro", FontSize -> 14, 
       FontSlant -> "Plain", FontColor -> 
       RGBColor[
        0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
       InterpretationBoxOptions -> {Editable -> True}], 
      Cell[
       StyleData["Index"], MenuSortingValue -> 10000, FontFamily -> 
       "Source Sans Pro", FontSize -> 11], 
      Cell[
       StyleData["IndexSubentry"], MenuSortingValue -> 10000, FontFamily -> 
       "Source Sans Pro", FontSize -> 11], 
      Cell[
       StyleData["FunctionName"], MenuSortingValue -> 10000, FontFamily -> 
       "Source Sans Pro Semibold", FontWeight -> "Bold"], 
      Cell[
       StyleData["IndexColumn"], 
       CellMargins -> {{66, 0}, {Inherited, Inherited}}, TabSpacings -> {2.}, 
       MenuSortingValue -> 10000, FontFamily -> "Source Sans Pro", 
       GridBoxOptions -> {
        GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
         GridBoxItemSize -> {"Columns" -> {{25}}}, 
         GridBoxSpacings -> {"Columns" -> {{2}}}}], 
      Cell[
       StyleData["IndexSubsection"], 
       CellMargins -> {{64, Inherited}, {9, 28}}, 
       CellGroupingRules -> {"SectionGrouping", 40}, MenuSortingValue -> 
       10000, FontFamily -> "Source Sans Pro", FontSize -> 24], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Subsection"], CellMargins -> {{64, Inherited}, {12, 32}},
           FontFamily -> "Source Sans Pro Semibold", FontSize -> 18, 
          FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["Subsection", "Printout"], 
          CellMargins -> {{64, Inherited}, {12, 32}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ResourcesSubsection"], 
          CellMargins -> {{64, Inherited}, {4, 16}}, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 15, FontSlant -> "Plain", 
          FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["ResourcesSubsection", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 16}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Subsubsection"], 
          CellMargins -> {{64, Inherited}, {6, 12}}, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 16, FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["Subsubsection", "Printout"], 
          CellMargins -> {{64, Inherited}, {6, 12}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularySection"], PageWidth -> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 24}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["VocabularySection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 24}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularyTable", StyleDefinitions -> StyleData["Text"]],
           SpanMaxSize -> 1, FontFamily -> "Source Sans Pro Light", FontColor -> 
          GrayLevel[0.8], 
          GridBoxOptions -> {
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
            GridBoxDividers -> {"Columns" -> {{False}}, "Rows" -> {False, {
                 Directive[
                  Thickness[0.5], "VocabDivColor"]}, False}}, 
            GridBoxItemStyle -> {
             "Columns" -> {"VocabularyCode", Inherited, Inherited}, 
              "Rows" -> {{Automatic}}}, 
            GridBoxSpacings -> {
             "Columns" -> {{0, 1, 2, 1, 2}}, "Rows" -> {{1}}}}], 
         Cell[
          StyleData["VocabularyTable", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "VocabularyTable3Column", StyleDefinitions -> StyleData["Text"]], 
          SpanMaxSize -> 1, FontFamily -> "Source Sans Pro Light", FontColor -> 
          GrayLevel[0.8], 
          GridBoxOptions -> {
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
            GridBoxDividers -> {"Columns" -> {{False}}, "Rows" -> {False, {
                 Directive[
                  Thickness[0.5], "VocabDivColor"]}, False}}, 
            GridBoxItemStyle -> {
             "Columns" -> {
               "VocabularyCode", Inherited, "VocabularyCode", Inherited, 
                Inherited}, "Rows" -> {{Automatic}}}, 
            GridBoxSpacings -> {
             "Columns" -> {{0, 1, 2, 1, 2}}, "Rows" -> {{1}}}}], 
         Cell[
          StyleData["VocabularyTable3Column", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularyText"], FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["VocabularyText", "Printout"], 
          CellMargins -> {{66, 10}, {7, 7}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularyCode", StyleDefinitions -> StyleData["Text"]], 
          Deletable -> False, FontFamily -> "Source Sans Pro", FontSize -> 14,
           FontWeight -> "Bold", FontColor -> GrayLevel[0.25], 
          GridBoxOptions -> {
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
            GridBoxDividers -> {
             "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {True, {True}, True}, "RowsIndexed" -> {}}}], 
         Cell[
          StyleData["VocabularyCode", "Printout"], FontColor -> 
          GrayLevel[0.25]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabDivColor"], FontColor -> GrayLevel[0.8]], 
         Cell[
          StyleData["VocabDivColor", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseSection"], PageWidth -> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 30}}, Evaluatable -> True, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, ShowCellLabel -> False, CellFrameMargins -> {{8, 8}, {4, 6}},
           CellFrameColor -> RGBColor[0.901961, 0.411765, 0.027451], 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro", FontSize -> 18, 
          FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["ExerciseSection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Exercise"], PageWidth -> 700, CellDingbat -> Cell[
            TextData[{"  ", 
              CounterBox["Section"], ".", 
              CounterBox["Exercise"]}], "ExerciseNumber", FontColor -> 
            RGBColor[
             0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
          ShowGroupOpener -> True, CellMargins -> {{108, Inherited}, {4, 8}}, 
          CellGroupingRules -> {"SectionGrouping", 67}, CounterIncrements -> 
          "Exercise", MenuSortingValue -> 10020, MenuCommandKey -> "2", 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Plain", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["Exercise", "Printout"], ShowGroupOpener -> False, 
          CellMargins -> {{110, Inherited}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseNumber"], FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Bold", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["ExerciseNumber", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseSubsection"], PageWidth -> 500, 
          CellFrame -> {{False, False}, {1, False}}, 
          CellMargins -> {{64, Inherited}, {8, 18}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, CellFrameColor -> 
          RGBColor[0.65, 0.6, 0.6], FontFamily -> "Source Sans Pro", FontSize -> 
          18, FontSlant -> "Italic", FontColor -> RGBColor[0.65, 0.6, 0.6]], 
         Cell[
          StyleData["ExerciseSubsection", "Printout"], 
          CellFrame -> {{False, False}, {1, False}}, CellFrameColor -> 
          RGBColor[0.65, 0.6, 0.6]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseNote"], PageWidth -> 700, 
          CellMargins -> {{64, Inherited}, {4, 8}}, PageBreakBelow -> False, 
          MenuSortingValue -> 10050, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25], $CellContext`ReturnCreatesNewCell -> 
          True], 
         Cell[
          StyleData["ExerciseNote", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["QASection"], PageWidth -> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 30}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Question", 0}}, FontFamily -> "Source Sans Pro", FontSize -> 18, 
          FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["QASection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Question"], PageWidth -> 700, 
          CellMargins -> {{64, Inherited}, {2, 12}}, PageBreakBelow -> False, 
          CounterIncrements -> "Question", MenuSortingValue -> 10030, 
          MenuCommandKey -> "3", FontFamily -> "Source Sans Pro", FontSize -> 
          14, FontWeight -> "Bold", FontSlant -> 
          "Plain", $CellContext`ReturnCreatesNewCell -> 
          True, $CellContext`DefaultReturnCreatedCellStyle -> "Answer"], 
         Cell[
          StyleData["Question", "Printout"], 
          CellMargins -> {{65, Inherited}, {2, 12}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Answer"], PageWidth -> 700, 
          CellMargins -> {{66, 10}, {4, 1}}, LineSpacing -> {1.125, 1., 2.}, 
          MenuSortingValue -> 10032, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25], $CellContext`ReturnCreatesNewCell -> 
          True, $CellContext`DefaultReturnCreatedCellStyle -> "Question"], 
         Cell[
          StyleData["Answer", "Printout"], 
          CellMargins -> {{66, 10}, {4, 1}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["QuestionNumber"], FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Bold", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["QuestionNumber", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TechNoteSection"], PageWidth -> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 30}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["TechNoteSection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TechNote"], PageWidth -> 700, CellDingbat -> Cell[
            TextData[{"\[FilledSmallSquare]"}], FontSize -> 12, FontColor -> 
            GrayLevel[0.5]], CellMargins -> {{78, Inherited}, {4, 8}}, 
          CellChangeTimes -> {{3.651515120816633*^9, 3.651515125814807*^9}, 
            3.6515155174947033`*^9}, LineSpacing -> {1.25, 1., 2.}, 
          MenuSortingValue -> 10040, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25], $CellContext`ReturnCreatesNewCell -> 
          True], 
         Cell[
          StyleData["TechNote", "Printout"], 
          CellMargins -> {{82, Inherited}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["MoreExploreSection"], PageWidth -> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 30}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["MoreExploreSection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["MoreExplore"], PageWidth -> 700, 
          CellMargins -> {{64, Inherited}, {4, 8}}, PageBreakBelow -> False, 
          MenuSortingValue -> 10050, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0], $CellContext`ReturnCreatesNewCell -> 
          True], 
         Cell[
          StyleData["MoreExplore", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["MoreExploreShortURL"], 
          CellMargins -> {{64, Inherited}, {4, 8}}, PageBreakBelow -> False, 
          FontFamily -> "Source Sans Pro Light", FontSize -> 14, FontSlant -> 
          "Plain", FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["MoreExploreShortURL", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Text"], CellMargins -> {{66, 10}, {4, 14}}, FontFamily -> 
          "Baskerville", FontSize -> 18, FontColor -> 
          GrayLevel[0], $CellContext`ReturnCreatesNewCell -> True], 
         Cell[
          StyleData["Text", "Printout"], CellMargins -> {{66, 10}, {7, 7}}]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ResourcesText"], CellMargins -> {{66, 10}, {2, 0}}, 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Plain", FontColor -> 
          GrayLevel[0], $CellContext`ReturnCreatesNewCell -> True], 
         Cell[
          StyleData["ResourcesText", "Printout"], 
          CellMargins -> {{66, 10}, {2, 0}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ResourcesLink"], CellMargins -> {{66, 10}, {2, 0}}, 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Italic", FontColor -> 
          GrayLevel[0], $CellContext`ReturnCreatesNewCell -> True], 
         Cell[
          StyleData["ResourcesLink", "Printout"], 
          CellMargins -> {{66, 10}, {2, 0}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CodeCaption"], CellFrame -> {{0, 0}, {0, 0}}, 
          CellMargins -> {{66, 10}, {4, 12}}, PageBreakBelow -> False, 
          CellFrameColor -> GrayLevel[0.4], MenuSortingValue -> 10010, 
          MenuCommandKey -> "1", FontFamily -> "Source Sans Pro", FontSize -> 
          16, FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["CodeCaption", "Printout"], 
          CellMargins -> {{66, 10}, {4, 12}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Input"], CellMargins -> {{99, 10}, {3, 7}}, SpanMaxSize -> 
          1, FontSize -> 15], 
         Cell[
          StyleData["Input", "Printout"], CellMargins -> {{99, 10}, {3, 7}}]},
         Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Output"], CellMargins -> {{99, 10}, {14, 7}}, FontSize -> 
          15], 
         Cell[
          StyleData["Output", "Printout"], 
          CellMargins -> {{99, 10}, {14, 7}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["InputOnly"], CellMargins -> {{99, 10}, {25, 10}}, 
          SpanMaxSize -> 1, MenuSortingValue -> 1500, FontSize -> 15], 
         Cell[
          StyleData["InputOnly", "Printout"], 
          CellMargins -> {{99, 10}, {15, 10}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CellLabel"], 
          CellLabelMargins -> {{12, Inherited}, {Inherited, Inherited}}, 
          LanguageCategory -> None, StyleMenuListing -> None, FontFamily -> 
          "Helvetica Neue", FontSize -> 9, FontWeight -> "Plain", FontSlant -> 
          "Plain", FontColor -> GrayLevel[0.5]], 
         Cell[
          StyleData["CellLabel", "Printout"], FontSize -> 8, FontColor -> 
          GrayLevel[0.5]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Message"], Editable -> False, 
          CellMargins -> {{66, Inherited}, {Inherited, Inherited}}, 
          CellGroupingRules -> "OutputGrouping", TextClipboardType -> 
          "PlainText", PageBreakWithin -> False, GroupPageBreakWithin -> 
          False, GeneratedCell -> True, CellAutoOverwrite -> True, 
          ShowCellLabel -> False, DefaultFormatType -> 
          DefaultOutputFormatType, ContextMenu -> 
          FEPrivate`FrontEndResource["ContextMenus", "Output"], 
          ShowAutoStyles -> False, ShowSyntaxStyles -> False, 
          AutoStyleOptions -> {
           "StringStyle" -> None, "SyntaxErrorStyle" -> None}, 
          HyphenationOptions -> {"HyphenationCharacter" -> "\[Continuation]"},
           AutoItalicWords -> {}, AutoQuoteCharacters -> {}, 
          PasteAutoQuoteCharacters -> {}, LanguageCategory -> None, 
          FormatType -> InputForm, ShowStringCharacters -> False, 
          CounterIncrements -> "Message", MenuSortingValue -> 1600, 
          StyleMenuListing -> None, FontFamily :> 
          CurrentValue["PanelFontFamily"], FontSize -> 11, FontColor -> 
          RGBColor[0.5072, 0.16933, 0.15221], $CellContext`StripStyleOnPaste -> 
          True], 
         Cell[
          StyleData["Message", "Printout"], 
          CellMargins -> {{100, Inherited}, {Inherited, Inherited}}, 
          CellFrameLabels -> {{None, None}, {None, None}}, FontColor -> 
          GrayLevel[0]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseInput", StyleDefinitions -> StyleData["Input"]], 
          CellMargins -> {{88, 10}, {4, 7}}, ShowCellLabel -> False, 
          SpanMaxSize -> 1, FontSize -> 
          14, $CellContext`GeneratedCellStyles -> {
           "Output" -> "ExerciseOutput"}], 
         Cell[
          StyleData["ExerciseInput", "Printout"], 
          CellMargins -> {{88, 10}, {4, 7}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "ExerciseOutput", StyleDefinitions -> StyleData["Output"]], 
          CellMargins -> {{88, 10}, {10, 4}}, ShowCellLabel -> False, 
          FontSize -> 14], 
         Cell[
          StyleData["ExerciseOutput", "Printout"], 
          CellMargins -> {{88, 10}, {10, 4}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Picture"], CellMargins -> {{66, 10}, {10, 10}}, 
          CellGroupingRules -> "GraphicsGrouping", StyleMenuListing -> None], 
         
         Cell[
          StyleData["Picture", "Printout"], 
          CellMargins -> {{66, 10}, {8, 8}}]}, Closed]], 
      Cell[
       StyleData["ExerciseSummaryCell"], PageWidth -> 700, CellFrame -> 0, 
       CellMargins -> {{64, Inherited}, {8, 10}}, 
       CellGroupingRules -> {"SectionGrouping", 64}, PageBreakBelow -> False, 
       ShowCellLabel -> False, CellFrameMargins -> 0, ShowStringCharacters -> 
       False, FontFamily -> "Source Sans Pro", FontSize -> 18, FontColor -> 
       RGBColor[1, 1, 1], 
       GridBoxOptions -> {GridBoxBackground -> {"Columns" -> {{
              RGBColor[0.990997, 0.539528, 0.155779], 
              RGBColor[0.989487, 0.434699, 0.0320439]}}, "Rows" -> {{None}}}, 
         GridBoxItemSize -> {"Columns" -> {
             Scaled[0.7], 
             Scaled[0.3]}, "Rows" -> {{Automatic}}}}], 
      Cell[
       StyleData["ExerciseSummaryHeading"], ShowStringCharacters -> False, 
       FontFamily -> "Source Sans Pro", FontSize -> 18, FontColor -> 
       RGBColor[1, 1, 1]], 
      Cell[
       StyleData["ExerciseSummarySubheading"], ShowStringCharacters -> False, 
       FontFamily -> "Source Sans Pro", FontSize -> 15, FontColor -> 
       RGBColor[1., 0.9294117647058824, 0.7215686274509804]], 
      Cell[
       StyleData["ExercisePreviewButtonText"], ShowStringCharacters -> False, 
       FontFamily -> "Source Sans Pro", FontSize -> 14, FontSlant -> "Plain", 
       FontColor -> RGBColor[0.6, 0.6, 0.6]], 
      Cell[
       StyleData["ExercisePreviewButtonTextHighlight"], ShowStringCharacters -> 
       False, FontFamily -> "Source Sans Pro", FontSize -> 14, FontSlant -> 
       "Plain", FontColor -> 
       RGBColor[
        0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]]}, 
     Closed]], 
   Cell[
    CellGroupData[{
      Cell[
      "Inline and special formatting", "Section", 
       CellChangeTimes -> {{3.646681732592888*^9, 3.646681749414035*^9}}], 
      Cell[
       StyleData["Graphics"], MenuSortingValue -> None], 
      Cell[
       StyleData["Graphics3D"], MenuSortingValue -> None], 
      Cell[
       StyleData["StandardForm"], 
       InputAutoReplacements -> {
        "->" -> "\[Rule]", ":>" -> "\[RuleDelayed]", "<=" -> "\[LessEqual]", 
         ">=" -> "\[GreaterEqual]", "!=" -> "\[NotEqual]", "==" -> "\[Equal]",
          "@>" -> "\\[InlinePart]", "<->" -> "\[UndirectedEdge]", ParentList},
        LineSpacing -> {1.25, 0, 2}, SingleLetterItalics -> False, 
       StyleMenuListing -> None, FontFamily -> "Source Sans Pro", 
       PrivateFontOptions -> {"OperatorSubstitution" -> True}], 
      Cell[
       StyleData["OutputForm"], PageWidth -> DirectedInfinity[1], 
       TextAlignment -> Left, LineSpacing -> {0.6, 1}, 
       AutoQuoteCharacters -> {}, PasteAutoQuoteCharacters -> {}, 
       StyleMenuListing -> None, FontFamily -> "Source Sans Pro", 
       PrivateFontOptions -> {"OperatorSubstitution" -> True}], 
      Cell[
       StyleData["InputForm"], PageWidth -> DirectedInfinity[1], 
       InputAutoReplacements -> {}, AllowInlineCells -> False, Hyphenation -> 
       False, AutoQuoteCharacters -> {}, PasteAutoQuoteCharacters -> {}, 
       AutoSpacing -> False, NumberMarks -> True, AutoNumberFormatting -> 
       False, StyleMenuListing -> None, FontFamily -> "Source Sans Pro", 
       PrivateFontOptions -> {"OperatorSubstitution" -> True}], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["DetailsLink"], FontFamily -> "Source Sans Pro", FontSize :> 
          If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.9]], FontColor -> GrayLevel[0], 
          ButtonBoxOptions -> {
           ButtonFunction :> (
             Function[$CellContext`t, 
              NotebookFind[$CellContext`t, "Notes", All, CellStyle]; 
              NotebookFind[$CellContext`t, "NotesSection", All, CellStyle, 
                AutoScroll -> Top]][
              Documentation`HelpLookup[
               StringJoin["ref/", #]]]& ), ButtonSource -> ButtonContents, 
            Evaluator -> Automatic}], 
         Cell[
          StyleData["DetailsLink", "Printout"], FontFamily -> 
          "Source Sans Pro", FontSize :> If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.88]], FontColor -> GrayLevel[0]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["LinkAlt"], FontFamily -> "Source Sans Pro", FontSize :> 
          If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.9]], FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["LinkAlt", "Printout"], FontFamily -> "Source Sans Pro", 
          FontSize :> If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.88]], FontColor -> GrayLevel[0]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Hyperlink"], MenuSortingValue -> None, FontColor -> 
          RGBColor[0.3, 0.35, 0.5]], 
         Cell[
          StyleData["Hyperlink", "Printout"]]}, Closed]], 
      Cell[
       StyleData[
       "IndexNavigationLink", StyleDefinitions -> StyleData["Hyperlink"]], 
       MenuSortingValue -> None, FontColor -> 
       RGBColor[
        0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
      Cell[
       StyleData["Crosslink"], 
       ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
            
            NotebookLocate[#2, "OpenInNewWindow" -> 
             CurrentValue["HyperlinkModifierKey"]]}]& ), Evaluator -> None, 
         Method -> "Queued"}], 
      Cell[
       StyleData["VocabularyLink"], FontColor -> GrayLevel[0], 
       ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
            
            NotebookLocate[#2, "OpenInNewWindow" -> 
             CurrentValue["HyperlinkModifierKey"]]}]& ), Evaluator -> None, 
         Method -> "Queued"}], 
      Cell[
       StyleData["InlineCode"], SpanMaxSize -> 1, FontColor -> GrayLevel[0]], 
      
      Cell[
       StyleData["InlineCodeText"], SpanMaxSize -> 1, FontFamily -> 
       "Source Sans Pro", FontSize -> 0.95 Inherited], 
      Cell[
       StyleData["NoLabel"], ShowCellLabel -> 
       False, $CellContext`GeneratedCellStyles -> {
        "Output" -> "ExerciseOutput"}], 
      Cell[
       StyleData["MenuName"], FontFamily -> "Verdana", FontWeight -> "Bold", 
       FontColor -> GrayLevel[0.286275]], 
      Cell[
       StyleData["KeyEvent"], CellFrame -> {{0.5, 0.5}, {0.5, 0.5}}, 
       CellFrameMargins -> {{2, 2}, {2, 2}}, CellFrameColor -> GrayLevel[0.7],
        FontFamily -> "Verdana", FontColor -> GrayLevel[0.4]], 
      Cell[
       StyleData["KeyEventDelimiter"], FontColor -> GrayLevel[0.5]], 
      Cell[
       CellGroupData[{
         Cell["Key Styles", "Subsubsection"], 
         Cell[
          StyleData["Key0"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {"Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-2, -2}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}], 
         Cell[
          StyleData["Key1"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #2, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {
                 "ColumnsIndexed" -> {2 -> GrayLevel[0.8352941176470589]}, 
                  "Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-2, -2}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}], 
         Cell[
          StyleData["Key2"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #2, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #3, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {
                 "ColumnsIndexed" -> {
                   2 -> GrayLevel[0.8352941176470589], 3 -> 
                    GrayLevel[0.8352941176470589]}, "Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-2, -2}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}], 
         Cell[
          StyleData["Key3"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #2, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   TemplateBox[{"\[ThickSpace]", #3, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #4, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {
                 "ColumnsIndexed" -> {
                   2 -> GrayLevel[0.8352941176470589], 3 -> 
                    GrayLevel[0.8352941176470589], 4 -> 
                    GrayLevel[0.8352941176470589]}, "Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-2, -2}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Entity styles", "Subsubsection"], 
         Cell[
          StyleData["Entity"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               PaneSelectorBox[{True -> GridBox[{{
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontFamily -> "Source Sans Pro", 
                    FontWeight -> "Plain", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}},
                    BaselinePosition -> {1, 1}], False -> 
                 PaneBox[#, 
                   BaseStyle -> {
                    FontColor -> RGBColor[0.395437, 0.20595, 0.061158]}, 
                   BaselinePosition -> Baseline]}, 
                Dynamic[
                 CurrentValue[Evaluatable]], ImageSize -> Automatic, 
                BaselinePosition -> Baseline, 
                BaseStyle -> {FontFamily -> "Helvetica"}], FrameStyle -> 
               RGBColor[1., 0.504768, 0.], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityFrameless"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              PaneSelectorBox[{True -> GridBox[{{
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontFamily -> "Source Sans Pro", 
                    FontWeight -> "Plain", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                  BaselinePosition -> {1, 1}], False -> 
                PaneBox[#, 
                  BaseStyle -> {
                   FontColor -> RGBColor[0.395437, 0.20595, 0.061158]}, 
                  BaselinePosition -> Baseline]}, 
               Dynamic[
                CurrentValue[Evaluatable]], ImageSize -> Automatic, 
               BaselinePosition -> Baseline, 
               BaseStyle -> {FontFamily -> "Helvetica"}], #3, 
              BaseStyle -> {
               ShowStringCharacters -> False, LineIndent -> 0, 
                PrivateFontOptions -> {
                 FontWeight -> "Plain", "OperatorSubstitution" -> False}}]& ),
             Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityFramelessHot"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {
           DisplayFunction -> (PaneSelectorBox[{True -> GridBox[{{
                   
                   StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0]], 
                   StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0], Selectable -> 
                    False]}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 1}], False -> 
               PaneBox[#, BaseStyle -> {FontColor -> GrayLevel[0]}, 
                 BaselinePosition -> Baseline]}, 
              Dynamic[
               CurrentValue[Evaluatable]], ImageSize -> Automatic, 
              BaselinePosition -> Baseline, 
              BaseStyle -> {
               FontWeight -> "Plain", FontFamily -> "Helvetica", 
                ShowStringCharacters -> False, LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityClass"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               PaneSelectorBox[{True -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}},
                    BaselinePosition -> {1, 2}], False -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]]}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}},
                    BaselinePosition -> {1, 2}]}, 
                Dynamic[
                 CurrentValue[Evaluatable]], ImageSize -> Automatic, 
                BaselinePosition -> Baseline, 
                BaseStyle -> {FontFamily -> "Helvetica"}], FrameStyle -> 
               RGBColor[1., 0.504768, 0.], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityClassFrameless"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              PaneSelectorBox[{True -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                  BaselinePosition -> {1, 2}], False -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]]}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                  BaselinePosition -> {1, 2}]}, 
               Dynamic[
                CurrentValue[Evaluatable]], ImageSize -> Automatic, 
               BaselinePosition -> Baseline, 
               BaseStyle -> {FontFamily -> "Helvetica"}], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityClassFramelessHot"], ShowStringCharacters -> False,
           TemplateBoxOptions -> {
           DisplayFunction -> (PaneSelectorBox[{True -> GridBox[{{
                   PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                   
                   StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0]], 
                   StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0], Selectable -> 
                    False]}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 2}], False -> GridBox[{{
                   PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                   StyleBox[#, FontColor -> GrayLevel[0]]}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 2}]}, 
              Dynamic[
               CurrentValue[Evaluatable]], ImageSize -> Automatic, 
              BaselinePosition -> Baseline, 
              BaseStyle -> {
               FontWeight -> "Plain", FontFamily -> "Helvetica", 
                ShowStringCharacters -> False, LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityProperty"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               
               PaneBox[#, 
                BaseStyle -> {
                 FontSlant -> Italic, FontWeight -> Plain, FontFamily -> 
                  "Source Sans Pro", FontColor -> 
                  RGBColor[0.395437, 0.20595, 0.061158]}, BaselinePosition -> 
                Baseline], FrameStyle -> 
               RGBColor[0.94227, 0.703639, 0.033387], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityPropertyClass"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               PaneBox[
                GridBox[{{
                   PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], #}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 2}], 
                BaseStyle -> {
                 FontSlant -> Italic, FontWeight -> Plain, FontFamily -> 
                  "Source Sans Pro", FontColor -> 
                  RGBColor[0.395437, 0.20595, 0.061158]}, BaselinePosition -> 
                Baseline], FrameStyle -> 
               RGBColor[0.94227, 0.703639, 0.033387], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityValue"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              
              GridBox[{{#, #2}}, GridBoxAlignment -> {"Rows" -> {{Baseline}}},
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
               GridBoxSpacings -> {"Columns" -> {{0}}}, 
               BaselinePosition -> {1, 1}], Background -> 
              RGBColor[{0.9921568627450981, 0.9529411764705882, 
                0.8509803921568627}], BaselinePosition -> Baseline, 
              FrameMargins -> {{1, 1}, {1, 1}}, ImageMargins -> 2, FrameStyle -> 
              RGBColor[{0.9333333333333333, 0.8470588235294118, 
                0.5529411764705883}], RoundingRadius -> 5]& )}]}, Closed]]}, 
     Closed]]}, Visible -> False, FrontEndVersion -> 
  "11.1 for Mac OS X x86 (32-bit, 64-bit Kernel) (March 16, 2017)", 
  StyleDefinitions -> "StylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "p:123"->{
  Cell[661, 24, 419, 10, 
  70, "SectionDoubleDigit", "ExpressionUUID" -> "c97ab850-4a76-4666-
   aa61-74c4b348c44c",
   CounterAssignments->{{"Section", 21}, {"Subsection", 0}, {
     "Subsubsection", 0}, {"Exercise", 0}},
   CellTags->"p:123"]},
 "i:1"->{
  Cell[1083, 36, 512, 12, 
  70, "Text", "ExpressionUUID" -> "915b6f3c-f225-4996-ac14-daa47344249a",
   CellTags->"i:1"]},
 "i:2"->{
  Cell[1943, 60, 315, 10, 
  70, "Text", "ExpressionUUID" -> "f11b647e-7bf2-4c4c-9d41-fc529403a277",
   CellTags->"i:2"]},
 "i:3"->{
  Cell[2261, 72, 198, 4, 
  70, "CodeCaption", "ExpressionUUID" -> "d29a7c56-1ab8-4e56-86fc-93b883bc0ae3
   ",
   CellTags->"i:3"]},
 "i:4"->{
  Cell[4127, 120, 339, 8, 
  70, "Text", "ExpressionUUID" -> "cbc9e568-f31c-4611-a1e5-2ef6b6b65ba1",
   CellTags->"i:4"]},
 "i:5"->{
  Cell[4469, 130, 187, 4, 
  70, "CodeCaption", "ExpressionUUID" -> "4ea5e5fb-0ba2-4f16-a1ff-8b390713de44
   ",
   CellTags->"i:5"]},
 "i:6"->{
  Cell[262487, 4380, 425, 12, 
  70, "Text", "ExpressionUUID" -> "bdcb1c61-b798-43ee-9c38-3a85263af201",
   CellTags->"i:6"]},
 "i:7"->{
  Cell[262915, 4394, 213, 4, 
  70, "CodeCaption", "ExpressionUUID" -> "a1c49e7b-dd7e-4a7f-9291-5eb7080b915f
   ",
   CellTags->"i:7"]},
 "LastCellOfAPage"->{
  Cell[264060, 4433, 217, 5, 
  70, "Output", "ExpressionUUID" -> "a705f288-6ff9-4ed3-a28f-0b426ef098b3",
   Evaluatable->False,
   CellTags->"LastCellOfAPage"],
  Cell[326296, 5938, 427, 14, 
  70, "Text", "ExpressionUUID" -> "1f51a703-2c19-4149-abfa-2d40ba83fea6",
   CellTags->{"LastCellOfAPage", "i:13"}],
  Cell[465648, 9435, 70309, 1552, 
  70, "Output", "ExpressionUUID" -> "7ac2c583-6f43-41ca-957c-f9c9482c147a",
   Evaluatable->False,
   CellTags->"LastCellOfAPage"],
  Cell[4658202, 81823, 968, 28, 
  70, "Exercise", "ExpressionUUID" -> "800d8988-2274-4784-a0e4-00a8d3fa0eec",
   CellTags->"LastCellOfAPage"],
  Cell[5165530, 92973, 354, 8, 
  70, "MoreExplore", "ExpressionUUID" -> "45c06e9d-fb71-47cb-8774-ba3c094fa4b9
   ",
   CellTags->"LastCellOfAPage"]},
 "p:124"->{
  Cell[264292, 4441, 568, 16, 
  70, "Text", "ExpressionUUID" -> "aa4f2372-7772-46fc-8d47-2372e74b70b5",
   CellTags->{"p:124", "i:8"}]},
 "i:8"->{
  Cell[264292, 4441, 568, 16, 
  70, "Text", "ExpressionUUID" -> "aa4f2372-7772-46fc-8d47-2372e74b70b5",
   CellTags->{"p:124", "i:8"}]},
 "i:9"->{
  Cell[289121, 4925, 451, 12, 
  70, "Text", "ExpressionUUID" -> "7d7f33ff-a858-4678-ab3a-ca59f3367a45",
   CellTags->"i:9"]},
 "i:10"->{
  Cell[291077, 4992, 244, 8, 
  70, "Text", "ExpressionUUID" -> "3f1792fe-3c2a-40a6-b748-a23e7b3e5f55",
   CellTags->"i:10"]},
 "i:11"->{
  Cell[325153, 5903, 175, 4, 
  70, "Text", "ExpressionUUID" -> "2aa7403f-57ce-4ce0-9ba2-a10485dd7cf0",
   CellTags->"i:11"]},
 "i:12"->{
  Cell[325331, 5909, 263, 5, 
  70, "CodeCaption", "ExpressionUUID" -> "43586c80-36d2-41ca-aa07-74ed27a61f5e
   ",
   CellTags->"i:12"]},
 "i:13"->{
  Cell[326296, 5938, 427, 14, 
  70, "Text", "ExpressionUUID" -> "1f51a703-2c19-4149-abfa-2d40ba83fea6",
   CellTags->{"LastCellOfAPage", "i:13"}]},
 "p:125"->{
  Cell[326726, 5954, 410, 11, 
  70, "Text", "ExpressionUUID" -> "9ad91d6e-8d51-44cd-ba69-db6ca5a530cc",
   CellTags->{"p:125", "i:14"}]},
 "i:14"->{
  Cell[326726, 5954, 410, 11, 
  70, "Text", "ExpressionUUID" -> "9ad91d6e-8d51-44cd-ba69-db6ca5a530cc",
   CellTags->{"p:125", "i:14"}]},
 "i:15"->{
  Cell[327139, 5967, 256, 5, 
  70, "CodeCaption", "ExpressionUUID" -> "102a34da-ceb6-4b31-919c-86b4970f1a0d
   ",
   CellTags->"i:15"]},
 "i:16"->{
  Cell[332983, 6082, 275, 10, 
  70, "Text", "ExpressionUUID" -> "0c6bc1f5-40e6-4b4d-908b-6aad4e5b2877",
   CellTags->"i:16"]},
 "i:17"->{
  Cell[338916, 6203, 386, 12, 
  70, "Text", "ExpressionUUID" -> "8c1d3d23-191b-494e-9685-f476279971e5",
   CellTags->"i:17"]},
 "NearestNeighborGraph"->{
  Cell[422753, 8348, 411, 11, 
  70, "Text", "ExpressionUUID" -> "c4ffd346-536d-41fe-9782-6c228e167a0b",
   CellTags->"NearestNeighborGraph"]},
 "graph-with-disconnected-parts"->{
  Cell[423167, 8361, 321, 9, 
  70, "CodeCaption", "ExpressionUUID" -> "7f061ea9-6eff-4ac7-9f94-19133ef933f2
   ",
   CellTags->{"graph-with-disconnected-parts", "i:18"}]},
 "i:18"->{
  Cell[423167, 8361, 321, 9, 
  70, "CodeCaption", "ExpressionUUID" -> "7f061ea9-6eff-4ac7-9f94-19133ef933f2
   ",
   CellTags->{"graph-with-disconnected-parts", "i:18"}]},
 "p:126"->{
  Cell[536006, 10993, 176, 4, 
  70, "VocabularySection", "ExpressionUUID" -> "10430372-4a8f-4f0c-b981-
   c2e68639a8fc",
   CellTags->"p:126"]},
 "p:127"->{
  Cell[5157324, 92667, 161, 4, 
  70, "QASection", "ExpressionUUID" -> "f1614bd5-3320-4b37-9b9c-c6788d93c17a",
   
   CellTags->"p:127"]},
 "i:19"->{
  Cell[5157693, 92680, 330, 8, 
  70, "Answer", "ExpressionUUID" -> "fb5bafd0-5ba3-4aa4-93ca-380e4eb0c255",
   CellTags->"i:19"]},
 "i:20"->{
  Cell[5158291, 92701, 302, 7, 
  70, "Answer", "ExpressionUUID" -> "dc1c923e-93fc-4850-80fd-4d9a7551687a",
   CellTags->"i:20"]},
 "i:21"->{
  Cell[5159466, 92744, 541, 16, 
  70, "Answer", "ExpressionUUID" -> "d93e94aa-57e9-4082-a4e4-e99ba88690b7",
   CellTags->"i:21"]},
 "i:22"->{
  Cell[5160866, 92794, 300, 10, 
  70, "Answer", "ExpressionUUID" -> "f3fb7961-3a3c-470b-b926-bb7f71b8479d",
   CellTags->"i:22"]},
 "i:23"->{
  Cell[5161409, 92817, 360, 10, 
  70, "Answer", "ExpressionUUID" -> "1be5a182-5cde-4f5a-9f9b-d8383d74fbbd",
   CellTags->"i:23"]},
 "i:24"->{
  Cell[5161772, 92829, 207, 4, 
  70, "Question", "ExpressionUUID" -> "70b9cef2-9d85-4f81-ae4a-569efe31b9ed",
   CellTags->"i:24"]},
 "i:25"->{
  Cell[5162587, 92859, 348, 13, 
  70, "TechNote", "ExpressionUUID" -> "2aedfa9b-b856-4d5a-8dc3-54ad1700c7e8",
   CellTags->"i:25"]},
 "i:26"->{
  Cell[5162938, 92874, 434, 14, 
  70, "TechNote", "ExpressionUUID" -> "e3863f9d-3dbf-490c-b4e7-06e3c7a8b4c6",
   CellTags->"i:26"]},
 "i:27"->{
  Cell[5163375, 92890, 308, 9, 
  70, "TechNote", "ExpressionUUID" -> "4fbe9504-c35f-4977-b2ca-840fef9531ac",
   CellTags->"i:27"]},
 "i:28"->{
  Cell[5163686, 92901, 517, 16, 
  70, "TechNote", "ExpressionUUID" -> "c179a738-f049-41df-a9b1-85f7b2756df5",
   CellTags->"i:28"]},
 "i:29"->{
  Cell[5164206, 92919, 570, 23, 
  70, "TechNote", "ExpressionUUID" -> "19ced587-b3f4-474b-9cb2-480acc9d600b",
   CellTags->"i:29"]},
 "i:30"->{
  Cell[5164779, 92944, 546, 18, 
  70, "TechNote", "ExpressionUUID" -> "682a597c-ffe1-4849-b12f-b0aea0cd754e",
   CellTags->"i:30"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"p:123", 5255614, 94802},
 {"i:1", 5255872, 94809},
 {"i:2", 5256005, 94813},
 {"i:3", 5256138, 94817},
 {"i:4", 5256281, 94822},
 {"i:5", 5256414, 94826},
 {"i:6", 5256558, 94831},
 {"i:7", 5256695, 94835},
 {"LastCellOfAPage", 5256854, 94840},
 {"p:124", 5257638, 94859},
 {"i:8", 5257786, 94863},
 {"i:9", 5257934, 94867},
 {"i:10", 5258072, 94871},
 {"i:11", 5258210, 94875},
 {"i:12", 5258348, 94879},
 {"i:13", 5258497, 94884},
 {"p:125", 5258658, 94888},
 {"i:14", 5258808, 94892},
 {"i:15", 5258958, 94896},
 {"i:16", 5259107, 94901},
 {"i:17", 5259246, 94905},
 {"NearestNeighborGraph", 5259401, 94909},
 {"graph-with-disconnected-parts", 5259581, 94913},
 {"i:18", 5259765, 94918},
 {"p:126", 5259950, 94923},
 {"p:127", 5260108, 94928},
 {"i:19", 5260258, 94933},
 {"i:20", 5260400, 94937},
 {"i:21", 5260542, 94941},
 {"i:22", 5260685, 94945},
 {"i:23", 5260828, 94949},
 {"i:24", 5260971, 94953},
 {"i:25", 5261115, 94957},
 {"i:26", 5261260, 94961},
 {"i:27", 5261405, 94965},
 {"i:28", 5261549, 94969},
 {"i:29", 5261694, 94973},
 {"i:30", 5261839, 94977}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[661, 24, 419, 10, 70, "SectionDoubleDigit", "ExpressionUUID" -> \
"c97ab850-4a76-4666-aa61-74c4b348c44c",
 CounterAssignments->{{"Section", 21}, {"Subsection", 0}, {
   "Subsubsection", 0}, {"Exercise", 0}},
 CellTags->"p:123"],
Cell[1083, 36, 512, 12, 70, "Text", "ExpressionUUID" -> \
"915b6f3c-f225-4996-ac14-daa47344249a",
 CellTags->"i:1"],
Cell[1598, 50, 342, 8, 70, "Text", "ExpressionUUID" -> \
"1c8c6f73-34ba-47a0-8790-89236c4827e3"],
Cell[1943, 60, 315, 10, 70, "Text", "ExpressionUUID" -> \
"f11b647e-7bf2-4c4c-9d41-fc529403a277",
 CellTags->"i:2"],
Cell[2261, 72, 198, 4, 70, "CodeCaption", "ExpressionUUID" -> \
"d29a7c56-1ab8-4e56-86fc-93b883bc0ae3",
 CellTags->"i:3"],
Cell[CellGroupData[{
Cell[2484, 80, 406, 9, 70, "Input", "ExpressionUUID" -> \
"e273792f-fb5a-4243-b881-59f2864cdd57"],
Cell[2893, 91, 1219, 26, 70, "Output", "ExpressionUUID" -> \
"35103a01-9f72-47a4-9864-79e103fb298b",
 Evaluatable->False]
}, Open  ]],
Cell[4127, 120, 339, 8, 70, "Text", "ExpressionUUID" -> \
"cbc9e568-f31c-4611-a1e5-2ef6b6b65ba1",
 CellTags->"i:4"],
Cell[4469, 130, 187, 4, 70, "CodeCaption", "ExpressionUUID" -> \
"4ea5e5fb-0ba2-4f16-a1ff-8b390713de44",
 CellTags->"i:5"],
Cell[CellGroupData[{
Cell[4681, 138, 257398, 4228, 70, "Input", "ExpressionUUID" -> \
"24ab5800-def3-4052-8c1c-3bc8bcc7dac2"],
Cell[262082, 4368, 390, 9, 70, "Output", "ExpressionUUID" -> \
"06029f14-f918-45b7-8bf9-298727e46c30",
 Evaluatable->False]
}, Open  ]],
Cell[262487, 4380, 425, 12, 70, "Text", "ExpressionUUID" -> \
"bdcb1c61-b798-43ee-9c38-3a85263af201",
 CellTags->"i:6"],
Cell[262915, 4394, 213, 4, 70, "CodeCaption", "ExpressionUUID" -> \
"a1c49e7b-dd7e-4a7f-9291-5eb7080b915f",
 CellTags->"i:7"],
Cell[CellGroupData[{
Cell[263153, 4402, 242, 6, 70, "Input", "ExpressionUUID" -> \
"5e38586c-b936-4af6-951d-ab4fc0ae1309"],
Cell[263398, 4410, 187, 4, 70, "Output", "ExpressionUUID" -> \
"97dc60b0-458e-4dcb-a566-8b9366dc9cdf",
 Evaluatable->False]
}, Open  ]],
Cell[263600, 4417, 202, 5, 70, "CodeCaption", "ExpressionUUID" -> \
"f2ed0dda-c079-4adc-8030-5cae3908c3f0"],
Cell[CellGroupData[{
Cell[263827, 4426, 230, 5, 70, "Input", "ExpressionUUID" -> \
"3c1aad97-5044-43ac-8f17-3155ed368974"],
Cell[264060, 4433, 217, 5, 70, "Output", "ExpressionUUID" -> \
"a705f288-6ff9-4ed3-a28f-0b426ef098b3",
 Evaluatable->False,
 CellTags->"LastCellOfAPage"]
}, Open  ]],
Cell[264292, 4441, 568, 16, 70, "Text", "ExpressionUUID" -> \
"aa4f2372-7772-46fc-8d47-2372e74b70b5",
 CellTags->{"p:124", "i:8"}],
Cell[264863, 4459, 270, 9, 70, "CodeCaption", "ExpressionUUID" -> \
"29152688-d53f-4c73-a850-72a03d821a94"],
Cell[CellGroupData[{
Cell[265158, 4472, 23773, 444, 70, "Input", "ExpressionUUID" -> \
"6f73d5c0-1e1b-4dfc-ba61-be627d15d13e"],
Cell[288934, 4918, 172, 4, 70, "Output", "ExpressionUUID" -> \
"fff54c99-fc83-4da4-94da-21a073270bf0",
 Evaluatable->False]
}, Open  ]],
Cell[289121, 4925, 451, 12, 70, "Text", "ExpressionUUID" -> \
"7d7f33ff-a858-4678-ab3a-ca59f3367a45",
 CellTags->"i:9"],
Cell[289575, 4939, 189, 4, 70, "CodeCaption", "ExpressionUUID" -> \
"6aba28a7-1c69-4008-9757-12c696aed462"],
Cell[CellGroupData[{
Cell[289789, 4947, 309, 8, 70, "Input", "ExpressionUUID" -> \
"254d4ec0-4be1-4fa1-a274-8c715cf5d97e"],
Cell[290101, 4957, 195, 5, 70, "Output", "ExpressionUUID" -> \
"33400ac2-ba2e-4ee8-ad21-2fc8fb3297e2",
 Evaluatable->False]
}, Open  ]],
Cell[290311, 4965, 174, 4, 70, "CodeCaption", "ExpressionUUID" -> \
"485d5a7e-1ea3-48bd-b462-795a02bda5a3"],
Cell[CellGroupData[{
Cell[290510, 4973, 319, 8, 70, "Input", "ExpressionUUID" -> \
"db8d331e-b80d-4531-9c15-83bd0eca8c39"],
Cell[290832, 4983, 230, 6, 70, "Output", "ExpressionUUID" -> \
"91f1067c-eef6-4ffd-9fbc-1314bda4f949",
 Evaluatable->False]
}, Open  ]],
Cell[291077, 4992, 244, 8, 70, "Text", "ExpressionUUID" -> \
"3f1792fe-3c2a-40a6-b748-a23e7b3e5f55",
 CellTags->"i:10"],
Cell[291324, 5002, 220, 6, 70, "CodeCaption", "ExpressionUUID" -> \
"0f7209ec-c3dd-41de-8dde-6b67752f6ae2"],
Cell[CellGroupData[{
Cell[291569, 5012, 28832, 755, 70, "Input", "ExpressionUUID" -> \
"b92b1b76-7c31-457f-96ed-919a5a319e33"],
Cell[320404, 5769, 4734, 131, 70, "Output", "ExpressionUUID" -> \
"74a9d9eb-c5d2-4aee-879d-631f7fabe6bc",
 Evaluatable->False]
}, Open  ]],
Cell[325153, 5903, 175, 4, 70, "Text", "ExpressionUUID" -> \
"2aa7403f-57ce-4ce0-9ba2-a10485dd7cf0",
 CellTags->"i:11"],
Cell[325331, 5909, 263, 5, 70, "CodeCaption", "ExpressionUUID" -> \
"43586c80-36d2-41ca-aa07-74ed27a61f5e",
 CellTags->"i:12"],
Cell[CellGroupData[{
Cell[325619, 5918, 241, 6, 70, "Input", "ExpressionUUID" -> \
"724286fa-cd1e-455b-badd-3d3beffd66f0"],
Cell[325863, 5926, 418, 9, 70, "Output", "ExpressionUUID" -> \
"6a25814f-16c2-4ebd-9269-a56388ae09c2",
 Evaluatable->False]
}, Open  ]],
Cell[326296, 5938, 427, 14, 70, "Text", "ExpressionUUID" -> \
"1f51a703-2c19-4149-abfa-2d40ba83fea6",
 CellTags->{"LastCellOfAPage", "i:13"}],
Cell[326726, 5954, 410, 11, 70, "Text", "ExpressionUUID" -> \
"9ad91d6e-8d51-44cd-ba69-db6ca5a530cc",
 CellTags->{"p:125", "i:14"}],
Cell[327139, 5967, 256, 5, 70, "CodeCaption", "ExpressionUUID" -> \
"102a34da-ceb6-4b31-919c-86b4970f1a0d",
 CellTags->"i:15"],
Cell[CellGroupData[{
Cell[327420, 5976, 291, 8, 70, "Input", "ExpressionUUID" -> \
"b39028a3-fc19-46e6-9a1b-9ed3a6228475"],
Cell[327714, 5986, 5254, 93, 70, "Output", "ExpressionUUID" -> \
"46a1eb73-78cb-4857-a9c2-b6d00805f70b",
 Evaluatable->False]
}, Open  ]],
Cell[332983, 6082, 275, 10, 70, "Text", "ExpressionUUID" -> \
"0c6bc1f5-40e6-4b4d-908b-6aad4e5b2877",
 CellTags->"i:16"],
Cell[333261, 6094, 171, 4, 70, "CodeCaption", "ExpressionUUID" -> \
"bef6ef40-20d4-4d35-8051-acae79162c41"],
Cell[CellGroupData[{
Cell[333457, 6102, 5256, 92, 70, "Input", "ExpressionUUID" -> \
"b53292b5-3b15-45de-a4e7-2b261371b1f1"],
Cell[338716, 6196, 185, 4, 70, "Output", "ExpressionUUID" -> \
"9afcfcac-5a13-49e5-86dd-32a331fcf5ff",
 Evaluatable->False]
}, Open  ]],
Cell[338916, 6203, 386, 12, 70, "Text", "ExpressionUUID" -> \
"8c1d3d23-191b-494e-9685-f476279971e5",
 CellTags->"i:17"],
Cell[339305, 6217, 247, 5, 70, "CodeCaption", "ExpressionUUID" -> \
"89eb4948-d7da-423f-925a-e044ed0edeaa"],
Cell[CellGroupData[{
Cell[339577, 6226, 40987, 1053, 70, "Input", "ExpressionUUID" -> \
"3ea70913-b20f-4a1e-a571-2fe3712fe551"],
Cell[380567, 7281, 42171, 1064, 70, "Output", "ExpressionUUID" -> \
"41495b31-bce5-44a3-a715-a1b82dae8aaa",
 Evaluatable->False]
}, Open  ]],
Cell[422753, 8348, 411, 11, 70, "Text", "ExpressionUUID" -> \
"c4ffd346-536d-41fe-9782-6c228e167a0b",
 CellTags->"NearestNeighborGraph"],
Cell[423167, 8361, 321, 9, 70, "CodeCaption", "ExpressionUUID" -> \
"7f061ea9-6eff-4ac7-9f94-19133ef933f2",
 CellTags->{"graph-with-disconnected-parts", "i:18"}],
Cell[CellGroupData[{
Cell[423513, 8374, 42132, 1059, 70, "Input", "ExpressionUUID" -> \
"429adaa7-cf32-45a5-abcc-32f0fd8d5cef"],
Cell[465648, 9435, 70309, 1552, 70, "Output", "ExpressionUUID" -> \
"7ac2c583-6f43-41ca-957c-f9c9482c147a",
 Evaluatable->False,
 CellTags->"LastCellOfAPage"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[536006, 10993, 176, 4, 70, "VocabularySection", "ExpressionUUID" -> \
"10430372-4a8f-4f0c-b981-c2e68639a8fc",
 CellTags->"p:126"],
Cell[536185, 10999, 3095, 83, 70, "VocabularyTable", "ExpressionUUID" -> \
"7191c57a-d61a-4f10-95e8-906039f3ca5c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[539317, 11087, 1780, 46, 70, "ExerciseSection", "ExpressionUUID" -> \
"51441cf8-4401-4b44-b0b8-203a6e0bcaac"],
Cell[CellGroupData[{
Cell[541122, 11137, 1451, 45, 70, "ExerciseSummaryCell", "ExpressionUUID" -> \
"88971523-4291-4ee9-be1b-eda42bb0b0ce"],
Cell[CellGroupData[{
Cell[542598, 11186, 766, 21, 70, "Exercise", "ExpressionUUID" -> \
"24a3c41f-2ace-406b-9396-b2e81de5ce23"],
Cell[543367, 11209, 1504, 39, 70, "ExerciseOutput", "ExpressionUUID" -> \
"6de3bb35-e2aa-405f-afb5-41a3687491b3"]
}, Closed]],
Cell[CellGroupData[{
Cell[544908, 11253, 1205, 34, 70, "Exercise", "ExpressionUUID" -> \
"3455edf4-4bb2-4aeb-b5dd-4ce8fa464738"],
Cell[546116, 11289, 1561, 40, 70, "ExerciseOutput", "ExpressionUUID" -> \
"f4ba4a61-f611-41d1-971f-a4c63f8b40a4"]
}, Closed]],
Cell[CellGroupData[{
Cell[547714, 11334, 763, 21, 70, "Exercise", "ExpressionUUID" -> \
"ae142673-3369-4b07-95f4-8b7d9b496b2d"],
Cell[548480, 11357, 3825, 84, 70, "ExerciseOutput", "ExpressionUUID" -> \
"c0fe7a6c-f516-42b2-965e-44cbb09369b5"]
}, Closed]],
Cell[CellGroupData[{
Cell[552342, 11446, 781, 21, 70, "Exercise", "ExpressionUUID" -> \
"09a55fa3-4d76-453b-aef0-52cb41bfb28e"],
Cell[553126, 11469, 1091, 31, 70, "ExerciseOutput", "ExpressionUUID" -> \
"371f75d0-c745-4276-a9db-bec8ab7200e0"]
}, Closed]],
Cell[CellGroupData[{
Cell[554254, 11505, 937, 27, 70, "Exercise", "ExpressionUUID" -> \
"7a90848f-6c49-4a1a-937f-da47fc2bdc55"],
Cell[555194, 11534, 1623, 41, 70, "ExerciseOutput", "ExpressionUUID" -> \
"87b1a40f-a7e1-461f-a768-208d9df7c80a"]
}, Closed]],
Cell[CellGroupData[{
Cell[556854, 11580, 741, 21, 70, "Exercise", "ExpressionUUID" -> \
"cc688ba3-fc92-4419-bf66-45979f2047a5"],
Cell[557598, 11603, 1229, 35, 70, "ExerciseOutput", "ExpressionUUID" -> \
"a5c9f82b-468c-43bf-8d0f-348ae00d1c63"]
}, Closed]],
Cell[CellGroupData[{
Cell[558864, 11643, 780, 23, 70, "Exercise", "ExpressionUUID" -> \
"257d98eb-a3f3-4e3c-8dca-511943539cc2"],
Cell[559647, 11668, 23105, 521, 70, "ExerciseOutput", "ExpressionUUID" -> \
"415cb257-4004-46ea-ae02-c7725dc1cfbd"]
}, Closed]],
Cell[CellGroupData[{
Cell[582789, 12194, 720, 20, 70, "Exercise", "ExpressionUUID" -> \
"bca74320-1507-46d4-8c41-2e758aaec250"],
Cell[583512, 12216, 1071, 31, 70, "ExerciseOutput", "ExpressionUUID" -> \
"a569f35b-4077-4bce-ab7d-f6e31149aa9e"]
}, Closed]],
Cell[CellGroupData[{
Cell[584620, 12252, 721, 20, 70, "Exercise", "ExpressionUUID" -> \
"9bf7a3a1-8733-420d-b5a6-72e3f9918daa"],
Cell[585344, 12274, 50979, 844, 70, "ExerciseOutput", "ExpressionUUID" -> \
"9b0c2fa3-9b43-473b-9312-a21bd1e2e0e1"]
}, Closed]],
Cell[CellGroupData[{
Cell[636360, 13123, 1071, 32, 70, "Exercise", "ExpressionUUID" -> \
"2ea59eba-d241-4817-bbd1-9d5fe7decf5f"],
Cell[637434, 13157, 114818, 2334, 70, "ExerciseOutput", "ExpressionUUID" -> \
"e1356f8f-f9a6-4551-ab7f-810a54ae1007"]
}, Closed]],
Cell[CellGroupData[{
Cell[752289, 15496, 777, 21, 70, "Exercise", "ExpressionUUID" -> \
"afd20ffc-e506-48d6-a48c-66265b70cbe5"],
Cell[753069, 15519, 43192, 855, 70, "ExerciseOutput", "ExpressionUUID" -> \
"24436223-a045-4762-bb17-0c1a6f3b6af6"]
}, Closed]],
Cell[CellGroupData[{
Cell[796298, 16379, 723, 20, 70, "Exercise", "ExpressionUUID" -> \
"1bde4736-3d03-43ae-8fd9-495a7468f920"],
Cell[797024, 16401, 3767187, 63549, 70, "ExerciseOutput", "ExpressionUUID" -> \
"2d9c9577-4ae0-4e46-9b8b-2f8617738797"]
}, Closed]],
Cell[CellGroupData[{
Cell[4564248, 79955, 787, 21, 70, "Exercise", "ExpressionUUID" -> \
"111f3e0e-7028-42e9-a6fe-b1bd2227f759"],
Cell[4565038, 79978, 93127, 1840, 70, "ExerciseOutput", "ExpressionUUID" -> \
"70e1a13f-5e4d-463a-ba45-161e6eb76838"]
}, Closed]],
Cell[CellGroupData[{
Cell[4658202, 81823, 968, 28, 70, "Exercise", "ExpressionUUID" -> \
"800d8988-2274-4784-a0e4-00a8d3fa0eec",
 CellTags->"LastCellOfAPage"],
Cell[4659173, 81853, 1584, 41, 70, "ExerciseOutput", "ExpressionUUID" -> \
"cbdd312b-9b18-426e-848f-9897e0c8bb7c"]
}, Closed]],
Cell[CellGroupData[{
Cell[4660794, 81899, 774, 21, 70, "Exercise", "ExpressionUUID" -> \
"e8dd0568-ac6f-4f65-aa1d-4b6db873c094"],
Cell[4661571, 81922, 3754, 84, 70, "ExerciseOutput", "ExpressionUUID" -> \
"84b175be-6b4b-4e99-ae56-dac95aab1e6a"]
}, Closed]],
Cell[CellGroupData[{
Cell[4665362, 82011, 776, 21, 70, "Exercise", "ExpressionUUID" -> \
"402d0874-5657-4df2-b738-11e8685defdc"],
Cell[4666141, 82034, 1089, 31, 70, "ExerciseOutput", "ExpressionUUID" -> \
"384a5a69-084e-4736-9bf9-8b700e7144a6"]
}, Closed]],
Cell[CellGroupData[{
Cell[4667267, 82070, 1116, 35, 70, "Exercise", "ExpressionUUID" -> \
"fd25f862-e39d-42ba-8a25-e73d01f5771b"],
Cell[4668386, 82107, 12113, 279, 70, "ExerciseOutput", "ExpressionUUID" -> \
"fff8119a-3f0c-4173-a8bf-3b5d003a30a1"]
}, Closed]],
Cell[CellGroupData[{
Cell[4680536, 82391, 1065, 30, 70, "Exercise", "ExpressionUUID" -> \
"eb5d1a48-d850-4d4d-9a6d-e76b8c98c58b"],
Cell[4681604, 82423, 2022, 55, 70, "ExerciseOutput", "ExpressionUUID" -> \
"93721613-8848-4523-b94c-89929c180185"]
}, Closed]],
Cell[CellGroupData[{
Cell[4683663, 82483, 775, 21, 70, "Exercise", "ExpressionUUID" -> \
"d989f328-8ffe-48e0-b58e-c87ba6927775"],
Cell[4684441, 82506, 9723, 189, 70, "ExerciseOutput", "ExpressionUUID" -> \
"2c8ef976-8290-4d66-b05f-de76f924ed5b"]
}, Closed]],
Cell[CellGroupData[{
Cell[4694201, 82700, 729, 20, 70, "Exercise", "ExpressionUUID" -> \
"57d1b963-1c62-41cc-aa4b-fd8f2a310349"],
Cell[4694933, 82722, 462330, 9938, 70, "ExerciseOutput", "ExpressionUUID" -> \
"aae7eeba-c3d4-43ca-8f2f-8fdcca3b4fcf"]
}, Closed]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[5157324, 92667, 161, 4, 70, "QASection", "ExpressionUUID" -> \
"f1614bd5-3320-4b37-9b9c-c6788d93c17a",
 CellTags->"p:127"],
Cell[5157488, 92673, 202, 5, 70, "Question", "ExpressionUUID" -> \
"bb8ed27a-a6ab-4d91-89a7-d906824dc586"],
Cell[5157693, 92680, 330, 8, 70, "Answer", "ExpressionUUID" -> \
"fb5bafd0-5ba3-4aa4-93ca-380e4eb0c255",
 CellTags->"i:19"],
Cell[5158026, 92690, 262, 9, 70, "Question", "ExpressionUUID" -> \
"5dea382a-3c4e-4146-86b2-c14381b24524"],
Cell[5158291, 92701, 302, 7, 70, "Answer", "ExpressionUUID" -> \
"dc1c923e-93fc-4850-80fd-4d9a7551687a",
 CellTags->"i:20"],
Cell[5158596, 92710, 236, 9, 70, "Question", "ExpressionUUID" -> \
"9e001ff8-305a-44ec-9af9-c739810fbae1"],
Cell[5158835, 92721, 336, 8, 70, "Answer", "ExpressionUUID" -> \
"0918495e-913d-4f4b-8227-d8b5c77122e1"],
Cell[5159174, 92731, 289, 11, 70, "Question", "ExpressionUUID" -> \
"6faa2c57-9cfe-4972-8561-b77a93b80bd5"],
Cell[5159466, 92744, 541, 16, 70, "Answer", "ExpressionUUID" -> \
"d93e94aa-57e9-4082-a4e4-e99ba88690b7",
 CellTags->"i:21"],
Cell[5160010, 92762, 257, 9, 70, "Question", "ExpressionUUID" -> \
"23fd5b0b-b3f2-4ce9-b412-f06d01e6a43c"],
Cell[5160270, 92773, 339, 8, 70, "Answer", "ExpressionUUID" -> \
"8544cc65-0b7d-4476-aa68-73af26cdd798"],
Cell[5160612, 92783, 251, 9, 70, "Question", "ExpressionUUID" -> \
"a2dc4acf-b49b-47c6-952c-dd73d3c356b4"],
Cell[5160866, 92794, 300, 10, 70, "Answer", "ExpressionUUID" -> \
"f3fb7961-3a3c-470b-b926-bb7f71b8479d",
 CellTags->"i:22"],
Cell[5161169, 92806, 237, 9, 70, "Question", "ExpressionUUID" -> \
"aaf7fea0-193d-4b3b-878d-63bc5528c86e"],
Cell[5161409, 92817, 360, 10, 70, "Answer", "ExpressionUUID" -> \
"1be5a182-5cde-4f5a-9f9b-d8383d74fbbd",
 CellTags->"i:23"],
Cell[5161772, 92829, 207, 4, 70, "Question", "ExpressionUUID" -> \
"70b9cef2-9d85-4f81-ae4a-569efe31b9ed",
 CellTags->"i:24"],
Cell[5161982, 92835, 408, 13, 70, "Answer", "ExpressionUUID" -> \
"82af8ce3-e225-4630-b527-419bf88ea212"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5162427, 92853, 157, 4, 70, "TechNoteSection", "ExpressionUUID" -> \
"aef2a434-0902-439d-bc13-c09183d9ceff"],
Cell[5162587, 92859, 348, 13, 70, "TechNote", "ExpressionUUID" -> \
"2aedfa9b-b856-4d5a-8dc3-54ad1700c7e8",
 CellTags->"i:25"],
Cell[5162938, 92874, 434, 14, 70, "TechNote", "ExpressionUUID" -> \
"e3863f9d-3dbf-490c-b4e7-06e3c7a8b4c6",
 CellTags->"i:26"],
Cell[5163375, 92890, 308, 9, 70, "TechNote", "ExpressionUUID" -> \
"4fbe9504-c35f-4977-b2ca-840fef9531ac",
 CellTags->"i:27"],
Cell[5163686, 92901, 517, 16, 70, "TechNote", "ExpressionUUID" -> \
"c179a738-f049-41df-a9b1-85f7b2756df5",
 CellTags->"i:28"],
Cell[5164206, 92919, 570, 23, 70, "TechNote", "ExpressionUUID" -> \
"19ced587-b3f4-474b-9cb2-480acc9d600b",
 CellTags->"i:29"],
Cell[5164779, 92944, 546, 18, 70, "TechNote", "ExpressionUUID" -> \
"682a597c-ffe1-4849-b12f-b0aea0cd754e",
 CellTags->"i:30"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5165362, 92967, 165, 4, 70, "MoreExploreSection", "ExpressionUUID" -> \
"af834819-eae0-42f0-a8c7-664a8af0461b"],
Cell[5165530, 92973, 354, 8, 70, "MoreExplore", "ExpressionUUID" -> \
"45c06e9d-fb71-47cb-8774-ba3c094fa4b9",
 CellTags->"LastCellOfAPage"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
(* NotebookSignature LRsnrtog#UwTviYj8GA12SmN *)
