(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    530734,      13456]
NotebookOptionsPosition[    405693,      10722]
NotebookOutlinePosition[    503019,      12776]
CellTagsIndexPosition[    502029,      12736]
WindowTitle->Rearranging Lists: Elementary Introduction to the Wolfram Language
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[BoxData[
 InterpretationBox[Cell[
  "Rearranging Lists", "SectionInline",ExpressionUUID->
   "41df32d3-28a2-4da0-a132-3fa4e91b042c"],
  $Line = 0; Null]], "SectionDoubleDigit",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CounterAssignments->{{"Section", 29}, {"Subsection", 0}, {
   "Subsubsection", 0}, {"Exercise", 0}},
 CellTags->"p:177",ExpressionUUID->"53cc3f3b-aba3-4367-9eb2-285a9183af26"],

Cell["\<\
It\[CloseCurlyQuote]s common for lists that come out of one computation to \
have to be rearranged before going into another computation. For example, one \
might have a list of pairs, and need to convert it into a pair of lists, or \
vice versa.\
\>", "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"59fe08c8-ff36-40b4-a954-47614a4263cb"],

Cell["Transpose a list of pairs so it becomes a pair of lists:", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:1",ExpressionUUID->"285f9fd7-5343-49c7-95b9-b79e5f10f9ee"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Transpose", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "2"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"3", ",", "4"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"5", ",", "6"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"7", ",", "8"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"9", ",", "10"}], "}"}]}], "}"}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[1]:=",ExpressionUUID->"2e664132-5289-460f-a6ba-f0ee1854192c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "3", ",", "5", ",", "7", ",", "9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "4", ",", "6", ",", "8", ",", "10"}], "}"}]}], 
  "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[1]=",ExpressionUUID->"62cc5b4c-617d-49ee-8270-abdfb89e02c8"]
}, Open  ]],

Cell["Transpose the pair of lists back to a list of pairs:", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"91c51327-80a3-446d-92bd-cc54042c1c99"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Transpose", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "3", ",", "5", ",", "7", ",", "9"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"2", ",", "4", ",", "6", ",", "8", ",", "10"}], "}"}]}], "}"}], 
  "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[2]:=",ExpressionUUID->"f67800ee-983b-4026-8f70-167902572f03"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"7", ",", "8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"9", ",", "10"}], "}"}]}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[2]=",ExpressionUUID->"28ecbafb-f638-4655-8daf-d184b1560de2"]
}, Open  ]],

Cell[TextData[{
 ButtonBox["Thread",
  BaseStyle->"Link"],
 " is a closely related operation, often useful for generating input to ",
 ButtonBox["Graph",
  BaseStyle->"Link"],
 "."
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:2",ExpressionUUID->"b932171f-a912-4b24-9c2f-6110eaed014b"],

Cell[TextData[{
 "\[OpenCurlyDoubleQuote]Thread\[CloseCurlyDoubleQuote]",
 " ",
 Cell[BoxData[
  ButtonBox["\[Rule]",
   BaseStyle->"Link",
   ButtonData->"Rule"]], "InlineCode",ExpressionUUID->
  "c1d17176-e25d-4eec-88db-196d4b9e9843"],
 " across the elements of two lists:"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"0fc91897-ebe6-4e40-9367-d23bdeeca945"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Thread", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "3", ",", "5", ",", "7", ",", "9"}], "}"}], "\[Rule]", 
   RowBox[{"{", 
    RowBox[{"2", ",", "4", ",", "6", ",", "8", ",", "10"}], "}"}]}], 
  "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[3]:=",ExpressionUUID->"c52c3d0d-f152-4754-830f-b69d70d81698"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"1", "\[Rule]", "2"}], ",", 
   RowBox[{"3", "\[Rule]", "4"}], ",", 
   RowBox[{"5", "\[Rule]", "6"}], ",", 
   RowBox[{"7", "\[Rule]", "8"}], ",", 
   RowBox[{"9", "\[Rule]", "10"}]}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[3]=",ExpressionUUID->"ceb180c8-c808-48a2-8819-80649a49c37e"]
}, Open  ]],

Cell[TextData[{
 ButtonBox["Partition",
  BaseStyle->"Link"],
 " takes a list, and partitions it into ",
 "blocks",
 " of a specified size."
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:3",ExpressionUUID->"22d5103c-bd42-47c0-ad0b-fb7cac4a5b7b"],

Cell["Partition a 12-element list into blocks of size 3:", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"e881bec0-1c4f-4c62-ae39-1ac802f77a44"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Partition", "[", 
  RowBox[{
   RowBox[{"Range", "[", "12", "]"}], ",", "3"}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[4]:=",ExpressionUUID->"e0b4f87b-51f7-4247-90b3-aba981ffa7e4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "5", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"7", ",", "8", ",", "9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"10", ",", "11", ",", "12"}], "}"}]}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[4]=",ExpressionUUID->"8a14fc90-ef70-42ed-a9b6-86b4cce7e0b1"]
}, Open  ]],

Cell["Partition a list of characters to display them in a grid:", \
"CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:4",ExpressionUUID->"8ed87a46-3596-41d7-894e-e5eeb2ece04c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Grid", "[", 
  RowBox[{
   RowBox[{"Partition", "[", 
    RowBox[{
     RowBox[{
     "Characters", "[", 
      "\"\<An array of text made in the Wolfram Language\>\"", "]"}], ",", 
     "9"}], "]"}], ",", 
   RowBox[{"Frame", "\[Rule]", "All"}]}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[5]:=",ExpressionUUID->"2760a5bd-6f48-463b-aecf-bf24a9858edb"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"A\"\>", "\<\"n\"\>", "\<\" \"\>", "\<\"a\"\>", "\<\"r\"\>", \
"\<\"r\"\>", "\<\"a\"\>", "\<\"y\"\>", "\<\" \"\>"},
    {"\<\"o\"\>", "\<\"f\"\>", "\<\" \"\>", "\<\"t\"\>", "\<\"e\"\>", \
"\<\"x\"\>", "\<\"t\"\>", "\<\" \"\>", "\<\"m\"\>"},
    {"\<\"a\"\>", "\<\"d\"\>", "\<\"e\"\>", "\<\" \"\>", "\<\"i\"\>", \
"\<\"n\"\>", "\<\" \"\>", "\<\"t\"\>", "\<\"h\"\>"},
    {"\<\"e\"\>", "\<\" \"\>", "\<\"W\"\>", "\<\"o\"\>", "\<\"l\"\>", \
"\<\"f\"\>", "\<\"r\"\>", "\<\"a\"\>", "\<\"m\"\>"},
    {"\<\" \"\>", "\<\"L\"\>", "\<\"a\"\>", "\<\"n\"\>", "\<\"g\"\>", \
"\<\"u\"\>", "\<\"a\"\>", "\<\"g\"\>", "\<\"e\"\>"}
   },
   AutoDelete->False,
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[5]=",ExpressionUUID->"25155c1e-97a7-413b-b51a-fc98e0950438"]
}, Open  ]],

Cell[TextData[{
 "If you don\[CloseCurlyQuote]t tell it otherwise, ",
 ButtonBox["Partition",
  BaseStyle->"Link"],
 " breaks a list up into non-overlapping blocks. But you can also tell it to \
break the list into blocks that have ",
 "some specified offset",
 ". "
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"b755653b-e3cd-4b74-b7b4-830f334ca0af"],

Cell["Partition a list into blocks of size 3 with offset 1:", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:5",ExpressionUUID->"a6589622-e13a-44b8-894b-2af27fd428ee"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Partition", "[", 
  RowBox[{
   RowBox[{"Range", "[", "10", "]"}], ",", "3", ",", "1"}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[6]:=",ExpressionUUID->"04c3de2f-4927-4006-8c2e-b845fcaf10bb"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "3", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "4", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "5", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "6", ",", "7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6", ",", "7", ",", "8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"7", ",", "8", ",", "9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8", ",", "9", ",", "10"}], "}"}]}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellTags->"LastCellOfAPage",
 CellLabel->"Out[6]=",ExpressionUUID->"2d0e077f-ab53-43c6-8269-8627f9d6057d"]
}, Open  ]],

Cell["\<\
Partition a list of characters into blocks with an offset of 1:\
\>", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"p:178",ExpressionUUID->"aea99943-33c1-415a-83ee-c34f01e89f56"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Grid", "[", 
  RowBox[{
   RowBox[{"Partition", "[", 
    RowBox[{
     RowBox[{"Characters", "[", "\"\<Wolfram Language\>\"", "]"}], ",", "12", 
     ",", "1"}], "]"}], ",", 
   RowBox[{"Frame", "\[Rule]", "All"}]}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[7]:=",ExpressionUUID->"3e2e3b32-647b-4bd0-ae2e-07173f7ca1c2"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"W\"\>", "\<\"o\"\>", "\<\"l\"\>", "\<\"f\"\>", "\<\"r\"\>", \
"\<\"a\"\>", "\<\"m\"\>", "\<\" \"\>", "\<\"L\"\>", "\<\"a\"\>", "\<\"n\"\>", \
"\<\"g\"\>"},
    {"\<\"o\"\>", "\<\"l\"\>", "\<\"f\"\>", "\<\"r\"\>", "\<\"a\"\>", \
"\<\"m\"\>", "\<\" \"\>", "\<\"L\"\>", "\<\"a\"\>", "\<\"n\"\>", "\<\"g\"\>", \
"\<\"u\"\>"},
    {"\<\"l\"\>", "\<\"f\"\>", "\<\"r\"\>", "\<\"a\"\>", "\<\"m\"\>", "\<\" \
\"\>", "\<\"L\"\>", "\<\"a\"\>", "\<\"n\"\>", "\<\"g\"\>", "\<\"u\"\>", \
"\<\"a\"\>"},
    {"\<\"f\"\>", "\<\"r\"\>", "\<\"a\"\>", "\<\"m\"\>", "\<\" \"\>", \
"\<\"L\"\>", "\<\"a\"\>", "\<\"n\"\>", "\<\"g\"\>", "\<\"u\"\>", "\<\"a\"\>", \
"\<\"g\"\>"},
    {"\<\"r\"\>", "\<\"a\"\>", "\<\"m\"\>", "\<\" \"\>", "\<\"L\"\>", \
"\<\"a\"\>", "\<\"n\"\>", "\<\"g\"\>", "\<\"u\"\>", "\<\"a\"\>", "\<\"g\"\>", \
"\<\"e\"\>"}
   },
   AutoDelete->False,
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[7]=",ExpressionUUID->"4a40fdfe-07c8-4e87-9957-6f6fb269f41f"]
}, Open  ]],

Cell["Use an offset of 2 instead:", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"311e7dee-1cef-434f-886a-5623e9cc9961"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Grid", "[", 
  RowBox[{
   RowBox[{"Partition", "[", 
    RowBox[{
     RowBox[{"Characters", "[", "\"\<Wolfram Language\>\"", "]"}], ",", "12", 
     ",", "2"}], "]"}], ",", 
   RowBox[{"Frame", "\[Rule]", "All"}]}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[8]:=",ExpressionUUID->"aa604c51-99a5-4fbb-9c4d-3edd8ff69bc2"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"W\"\>", "\<\"o\"\>", "\<\"l\"\>", "\<\"f\"\>", "\<\"r\"\>", \
"\<\"a\"\>", "\<\"m\"\>", "\<\" \"\>", "\<\"L\"\>", "\<\"a\"\>", "\<\"n\"\>", \
"\<\"g\"\>"},
    {"\<\"l\"\>", "\<\"f\"\>", "\<\"r\"\>", "\<\"a\"\>", "\<\"m\"\>", "\<\" \
\"\>", "\<\"L\"\>", "\<\"a\"\>", "\<\"n\"\>", "\<\"g\"\>", "\<\"u\"\>", \
"\<\"a\"\>"},
    {"\<\"r\"\>", "\<\"a\"\>", "\<\"m\"\>", "\<\" \"\>", "\<\"L\"\>", \
"\<\"a\"\>", "\<\"n\"\>", "\<\"g\"\>", "\<\"u\"\>", "\<\"a\"\>", "\<\"g\"\>", \
"\<\"e\"\>"}
   },
   AutoDelete->False,
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[8]=",ExpressionUUID->"6aa10a54-34bb-4c7d-bc0c-3f0ffdc56dd4"]
}, Open  ]],

Cell[TextData[{
 ButtonBox["Partition",
  BaseStyle->"Link"],
 " takes a list and breaks it into sublists. ",
 ButtonBox["Flatten",
  BaseStyle->"Link"],
 " \[OpenCurlyDoubleQuote]flattens out\[CloseCurlyDoubleQuote] sublists."
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:6",ExpressionUUID->"8088e86b-9142-4a38-a7b0-df734de590ce"],

Cell["Make a list of lists from digits of successive integers:", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"85897c72-bff7-4082-b024-113e147adff7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IntegerDigits", "/@", 
  RowBox[{"Range", "[", "20", "]"}]}]], "Input",
 Deletable->False,
 CellLabel->"In[9]:=",ExpressionUUID->"f617bc74-63c1-49d0-95b4-eaccda96365a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", "1", "}"}], ",", 
   RowBox[{"{", "2", "}"}], ",", 
   RowBox[{"{", "3", "}"}], ",", 
   RowBox[{"{", "4", "}"}], ",", 
   RowBox[{"{", "5", "}"}], ",", 
   RowBox[{"{", "6", "}"}], ",", 
   RowBox[{"{", "7", "}"}], ",", 
   RowBox[{"{", "8", "}"}], ",", 
   RowBox[{"{", "9", "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "0"}], "}"}]}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[9]=",ExpressionUUID->"4ff52954-de25-4e73-baf8-784d071d584a"]
}, Open  ]],

Cell["Make a flattened version:", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"a2d9a5d8-72e1-406f-80df-9e73a7c0432f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Flatten", "[", 
  RowBox[{"IntegerDigits", "/@", 
   RowBox[{"Range", "[", "20", "]"}]}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[10]:=",ExpressionUUID->"0947e929-049a-4e6b-89b3-1c4e749475fd"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "7", ",", "8", 
   ",", "9", ",", "1", ",", "0", ",", "1", ",", "1", ",", "1", ",", "2", ",", 
   "1", ",", "3", ",", "1", ",", "4", ",", "1", ",", "5", ",", "1", ",", "6", 
   ",", "1", ",", "7", ",", "1", ",", "8", ",", "1", ",", "9", ",", "2", ",", 
   "0"}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[10]=",ExpressionUUID->"3ed27447-f95a-4ffd-9ac5-34ed0e6508f6"]
}, Open  ]],

Cell["Make a plot from the sequence of digits:", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"ed62b3c8-8fb4-4da1-a08b-9f8dbc3d95aa"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListLinePlot", "[", 
  RowBox[{"Flatten", "[", 
   RowBox[{"IntegerDigits", "/@", 
    RowBox[{"Range", "[", "20", "]"}]}], "]"}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[11]:=",ExpressionUUID->"4eefaafc-0087-4ede-bb31-cb85ec0e9631"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, {{{
       {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
        0.019444444444444445`], AbsoluteThickness[1.6], 
        LineBox[CompressedData["
1:eJxdkEsKwlAQBAdXLrNw4UIwCSIiQdQk/jU5g0cQXHt1j6Bi9+LVwKMomgfT
Uzxe9+cgIqbf9+N/3l3K6FMOwQwcgWNwAuZgCc76dJ+599EskC/hFXzl/+Ia
+Ubuflvktdx9G+St3P13yPdy3+OA/Cj3fU7Iz3Lf64L8Ki/Fm+i+nT0+01kj
RA==
         "]]}}}}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->180,
  Method->{},
  PlotRange->{{0., 31.}, {0, 9.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[11]=",ExpressionUUID->"d340123c-140f-4e1a-8c7d-251b8443b631"]
}, Open  ]],

Cell[TextData[{
 ButtonBox["Flatten",
  BaseStyle->"Link"],
 " will normally flatten out all levels of lists. But quite often you only \
want to flatten, say, one level of lists. This makes a 4\[Times]4 table ",
 "in which each element is itself",
 " a list."
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"8db4586b-31d6-4a0b-bad3-688dea443e1e"],

Cell["Make a list of lists of lists:", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"806fa3d3-37ae-432b-bee5-da90c2686fbf"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"IntegerDigits", "[", 
    RowBox[{"i", "^", "j"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"j", ",", "4"}], "}"}]}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[12]:=",ExpressionUUID->"7b296465-b2cd-4ad3-b4b3-d50764526988"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", "1", "}"}], ",", 
     RowBox[{"{", "1", "}"}], ",", 
     RowBox[{"{", "1", "}"}], ",", 
     RowBox[{"{", "1", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", "2", "}"}], ",", 
     RowBox[{"{", "4", "}"}], ",", 
     RowBox[{"{", "8", "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "6"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", "3", "}"}], ",", 
     RowBox[{"{", "9", "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"8", ",", "1"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", "4", "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"6", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "5", ",", "6"}], "}"}]}], "}"}]}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellTags->"LastCellOfAPage",
 CellLabel->"Out[12]=",ExpressionUUID->"8c5aa34e-1f95-4ca4-a122-d1a14fd4fcbb"]
}, Open  ]],

Cell["Flatten everything out:", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"p:179",ExpressionUUID->"6111076d-734b-4cb3-837a-5ed8cabb3e83"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Flatten", "[", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"IntegerDigits", "[", 
     RowBox[{"i", "^", "j"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "4"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "4"}], "}"}]}], "]"}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[13]:=",ExpressionUUID->"918a3d0d-3f8f-44d2-b440-1207cd5bc7ee"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "1", ",", "1", ",", "1", ",", "2", ",", "4", ",", "8", ",", "1", 
   ",", "6", ",", "3", ",", "9", ",", "2", ",", "7", ",", "8", ",", "1", ",", 
   "4", ",", "1", ",", "6", ",", "6", ",", "4", ",", "2", ",", "5", ",", 
   "6"}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[13]=",ExpressionUUID->"00eed6b0-bbde-4485-9c86-5dc6511eb87d"]
}, Open  ]],

Cell["Flatten out only one level of list:", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"45226e35-25f2-4756-a409-300489071fb5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Flatten", "[", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"IntegerDigits", "[", 
      RowBox[{"i", "^", "j"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "4"}], "}"}]}], "]"}], ",", "1"}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[14]:=",ExpressionUUID->"86e1519a-add9-498d-9cdc-856b27671dc0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", "1", "}"}], ",", 
   RowBox[{"{", "1", "}"}], ",", 
   RowBox[{"{", "1", "}"}], ",", 
   RowBox[{"{", "1", "}"}], ",", 
   RowBox[{"{", "2", "}"}], ",", 
   RowBox[{"{", "4", "}"}], ",", 
   RowBox[{"{", "8", "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "6"}], "}"}], ",", 
   RowBox[{"{", "3", "}"}], ",", 
   RowBox[{"{", "9", "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8", ",", "1"}], "}"}], ",", 
   RowBox[{"{", "4", "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "5", ",", "6"}], "}"}]}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[14]=",ExpressionUUID->"40a0043a-4ac9-4662-8e18-0f88df7104e7"]
}, Open  ]],

Cell[TextData[{
 ButtonBox["ArrayFlatten",
  BaseStyle->"Link"],
 " is a generalization of ",
 ButtonBox["Flatten",
  BaseStyle->"Link"],
 ", which takes arrays of arrays, and flattens them into individual arrays",
 "."
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:7",ExpressionUUID->"e685c3b9-f346-4627-bd31-21556e4835c1"],

Cell["\<\
This generates a deeply nested structure that\[CloseCurlyQuote]s hard to \
understand:\
\>", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"c0f8bbaa-c958-4e0b-b325-9df6977d009e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"NestList", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"#", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"#", ",", "#"}], "}"}]}], "}"}], "&"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", "1", "}"}], "}"}], ",", "2"}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[15]:=",ExpressionUUID->"40236244-7d1f-4218-9bc0-59830a3c77d7"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"{", "1", "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", "1", "}"}], "}"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", "1", "}"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"{", "1", "}"}], "}"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"{", "1", "}"}], "}"}], ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"{", "1", "}"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"{", "1", "}"}], "}"}]}], "}"}]}], "}"}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"{", "1", "}"}], "}"}], ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"{", "1", "}"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"{", "1", "}"}], "}"}]}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"{", "1", "}"}], "}"}], ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"{", "1", "}"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"{", "1", "}"}], "}"}]}], "}"}]}], "}"}]}], "}"}]}], 
    "}"}]}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[15]=",ExpressionUUID->"612d2983-bc09-46dc-b658-cfdd8d15c9b7"]
}, Open  ]],

Cell[TextData[{
 ButtonBox["ArrayFlatten",
  BaseStyle->"Link"],
 " makes a structure that\[CloseCurlyQuote]s a little easier to understand:"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:8",ExpressionUUID->"181af151-5b53-45be-8585-497ca037a29e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"NestList", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ArrayFlatten", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"#", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"#", ",", "#"}], "}"}]}], "}"}], "]"}], "&"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", "1", "}"}], "}"}], ",", "2"}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[16]:=",ExpressionUUID->"5f46a310-d75c-4ecd-887d-88fc60c6649d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"{", "1", "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "0", ",", "1", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "}"}]}], "}"}]}], 
  "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[16]=",ExpressionUUID->"8b3998d0-a2fe-4e01-9281-de2a28d0098c"]
}, Open  ]],

Cell[TextData[{
 "With ",
 ButtonBox["ArrayPlot",
  BaseStyle->"Link"],
 ", it\[CloseCurlyQuote]s considerably easier to see what\[CloseCurlyQuote]s \
going on:"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"1d181803-5ffa-40fc-8175-95dcd331d71e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ArrayPlot", "/@", 
  RowBox[{"NestList", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"ArrayFlatten", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"#", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"#", ",", "#"}], "}"}]}], "}"}], "]"}], "&"}], ",", 
    RowBox[{"{", 
     RowBox[{"{", "1", "}"}], "}"}], ",", "4"}], "]"}]}]], "Input",
 Deletable->False,
 CellLabel->"In[17]:=",ExpressionUUID->"af4aeba1-de22-4bd6-88af-4aa7cac3fcaf"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   GraphicsBox[RasterBox[{{0}}, {{0, 0}, {1, 1}}, {0, 1}],
    Frame->Automatic,
    FrameLabel->{None, None},
    FrameTicks->{{None, None}, {None, None}},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    ImageSize->{89.81640625, Automatic},
    Method->{
     "DefaultBoundaryStyle" -> Automatic, "DefaultPlotStyle" -> Automatic}], 
   ",", 
   GraphicsBox[RasterBox[{{0, 0}, {0, 1}}, {{0, 0}, {2, 2}}, {0, 1}],
    Frame->Automatic,
    FrameLabel->{None, None},
    FrameTicks->{{None, None}, {None, None}},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    ImageSize->{90.47265625, Automatic},
    Method->{
     "DefaultBoundaryStyle" -> Automatic, "DefaultPlotStyle" -> Automatic}], 
   ",", 
   GraphicsBox[
    RasterBox[{{0, 0, 0, 0}, {0, 1, 0, 1}, {0, 0, 1, 1}, {0, 1, 1, 1}}, {{0, 
     0}, {4, 4}}, {0, 1}],
    Frame->Automatic,
    FrameLabel->{None, None},
    FrameTicks->{{None, None}, {None, None}},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    ImageSize->{90.2109375, Automatic},
    Method->{
     "DefaultBoundaryStyle" -> Automatic, "DefaultPlotStyle" -> Automatic}], 
   ",", 
   GraphicsBox[
    RasterBox[{{0, 0, 0, 0, 0, 0, 0, 0}, {0, 1, 0, 1, 0, 1, 0, 1}, {0, 0, 1, 
     1, 0, 0, 1, 1}, {0, 1, 1, 1, 0, 1, 1, 1}, {0, 0, 0, 0, 1, 1, 1, 1}, {0, 
     1, 0, 1, 1, 1, 1, 1}, {0, 0, 1, 1, 1, 1, 1, 1}, {0, 1, 1, 1, 1, 1, 1, 
     1}}, {{0, 0}, {8, 8}}, {0, 1}],
    Frame->Automatic,
    FrameLabel->{None, None},
    FrameTicks->{{None, None}, {None, None}},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    ImageSize->{90.0859375, Automatic},
    Method->{
     "DefaultBoundaryStyle" -> Automatic, "DefaultPlotStyle" -> Automatic}], 
   ",", 
   GraphicsBox[
    RasterBox[{{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, {0, 1, 0, 1, 
     0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1}, {0, 0, 1, 1, 0, 0, 1, 1, 0, 0, 1, 1,
      0, 0, 1, 1}, {0, 1, 1, 1, 0, 1, 1, 1, 0, 1, 1, 1, 0, 1, 1, 1}, {0, 0, 0,
      0, 1, 1, 1, 1, 0, 0, 0, 0, 1, 1, 1, 1}, {0, 1, 0, 1, 1, 1, 1, 1, 0, 1, 
     0, 1, 1, 1, 1, 1}, {0, 0, 1, 1, 1, 1, 1, 1, 0, 0, 1, 1, 1, 1, 1, 1}, {0, 
     1, 1, 1, 1, 1, 1, 1, 0, 1, 1, 1, 1, 1, 1, 1}, {0, 0, 0, 0, 0, 0, 0, 0, 1,
      1, 1, 1, 1, 1, 1, 1}, {0, 1, 0, 1, 0, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 
     1}, {0, 0, 1, 1, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1}, {0, 1, 1, 1, 0, 1, 
     1, 1, 1, 1, 1, 1, 1, 1, 1, 1}, {0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
      1, 1}, {0, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1}, {0, 0, 1, 1, 1,
      1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1}, {0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
     1, 1, 1, 1}}, {{0, 0}, {16, 16}}, {0, 1}],
    Frame->Automatic,
    FrameLabel->{None, None},
    FrameTicks->{{None, None}, {None, None}},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    ImageSize->{90.43359375, Automatic},
    Method->{
     "DefaultBoundaryStyle" -> Automatic, "DefaultPlotStyle" -> Automatic}]}],
   "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[17]=",ExpressionUUID->"e2f6bca7-1342-40e1-b68f-734d87bd3c47"]
}, Open  ]],

Cell[TextData[{
 "Generate a ",
 StyleBox["fractal Sierpinski pattern",
  FontSlant->"Italic"],
 " with 8 levels of nesting:"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:9",ExpressionUUID->"574c71a9-fe37-44fc-9492-261da57b158d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ArrayPlot", "[", 
  RowBox[{"Nest", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"ArrayFlatten", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"#", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"#", ",", "#"}], "}"}]}], "}"}], "]"}], "&"}], ",", 
    RowBox[{"{", 
     RowBox[{"{", "1", "}"}], "}"}], ",", "8"}], "]"}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[18]:=",ExpressionUUID->"d1cef060-ff39-400e-9bcf-8f8f887ca43b"],

Cell[BoxData[
 GraphicsBox[RasterBox[CompressedData["
1:eJzlmVFuGzEMRKXepFfqEXKB3v+v3daLZqfxTmhGIjl8hiAQBDOODIIY8Pvb
zx9v38Zv5uN0Zzb/jNn7zObnaIHO959XaHz/vfres/l9jsGu8ePTNh7/eqFl
POe712gYj/ev0TC+vEbD+Br2i2fzGJjd8vBplx/X0y4Pp13+0RMf9UaL/ONV
PuqNFvlxvdvl4W6XfzIX2+SfzMU2+SdzsU1+Pu+NFvmb3miRv32dBvn7tH7+
Pq2fJ5Dy+vXkI18/7o98PTny9ePqj/GWr3+80rNbvn7c3/L15Javhzn52bkp
Uw9z8rNzU6Ye5uRn56ZM/bz2ymfnpkw99IqldyTq4bUsvSNRP+5j+XoSy9cb
/bJcPXza1Y/raVcPp1290S/L1T9e7ZXekagf17tdPdzt6l+cmzL1L85NmfoX
56ZM/Xy9dyTqHb0jUe96PYF6X3n9el95/XonTvl4feenvP7wnfL6zlNef1z9
s/Uur/94xVfv8vrDd5fXd97l9WGOWuPy+jBHrXF5fZij1ri8/rz2kjUurw+9
ZI3L68NrWuPy+sMXl9d3xuX1iZ/+ar+dTh8+1nx5/XE91nx5fTjWfHl94qe/
2m+n03+86rPe+mq/nU5/XG9rvrw+3NZ8eX0yV1fN3TT6ZK6umrtp9MlcXTV3
0+jP+95aNXfT6JPeWtl7KfTJ667svRT65M+vff0E+s58eX3CYvl4ffKR1x/3
R16fHHl98Ner/XY6ffDXq/12Ov1xf8vrk1teH+bsrrmbRh/m7K65m0Yf5uyu
uZtGf157bdfcTaMPvbaz91Low2vv7L0U+uM+ltcnsbz+Zr+dTn+z306nv9lv
p9OH005/s99Op7/Zb6fT3+y30+nD3U4/aO6m0Q+au2n0g+ZuGv0Z13sp9AN7
L4V+6Osn0I+Vj9ePlY/XDyb43//Pf+/+RMP276tPNOi/d59ozh6MuqNh+/fV
dzRs/776jmYE39HgHN4dR8P276vjaNj+fXUcDc7h3XE02Iu742iwF3fH0bD9
++o4Gvw6u+NomB9fnY+G+fHV+WiYH1+dj2bA2Z2Phvnx1flomB9fnY+G+fHV
+WgG3Lvz0bC5vDofDZvLq/PRsLm8Oh8Nm8ur89Gw3lydj4b15up8NOzXWZ2P
hn291flo0J9b/bq3Phrvft5bHw36c6tf99ZHg/7c6te99dGgP7f6dW99NN79
fPb9PsO7n/fWR4P+3OrXvfXR4Jy2zm1vfTTe/Xz2/T7Du5/Pvt9n4Jy2zm1v
fTTYq9be9dZH493PZ9/vM7z7+ez7fQZ+XevX99ZH4/Xr1fw+4vXr1fw+4vXr
1fw+4vXr1fw+4vXr1fw+4vXr1fw+4vXr1fw+4vXr1fw+4p3bVef+iXduV537
J965XXXun3jndtW5f+Lt3cq9f+Dt3cq9f+D99Wr/+v7eLf7v0/09I/r7e2H7
++r7fQbb31ff7zPQv1tPddC/W+/qsP199f0+g+3vq+/3GejfrXd1cI5b4+qw
/X31/T6D7e+r7/cZOMetcXWwl61xddj+vvp+n8H299X3+wz8d6xxdZifV/P7
CPPzan4fYX5eze8jzM+r+X2E+Xk1v48wP6/m9xHm59X8PsL8vJrfR9hcV537
J2yuq879EzbXVef+CZvrqnP/hPW2cu8fsN5W7v0D9utq//q8t8X/fbr/j/5+
q1Hf7zPU9/sM9Pfqfh9R3+8z1Pf7DPX9PgP9vbrfR9T3+wz1/T5Dfb/PUN/v
M9T3+wz1/T5Dfb/PUN/vM7r5faSb30e6+X2km99Huvl9pJvfR7r5faSb30e6
zv2TrnP/pOvcP+k690869/5B594/6P3r9+79g18pFOgK
   "], {{0, 0}, {256, 256}}, {0, 
   1}],
  Frame->Automatic,
  FrameLabel->{None, None},
  FrameTicks->{{None, None}, {None, None}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->{174.97265625, Automatic},
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultPlotStyle" -> 
    Automatic}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellTags->"LastCellOfAPage",
 CellLabel->"Out[18]=",ExpressionUUID->"304ff744-271d-4572-aae7-92b3a0a526fb"]
}, Open  ]],

Cell[TextData[{
 "There are many other ways to rearrange lists. For example, ",
 ButtonBox["Split",
  BaseStyle->"Link"],
 " splits a list into ",
 "runs",
 " of identical elements."
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->{
  "i:10", "p:180"},ExpressionUUID->"d24fcf9b-ba11-4725-8a6d-63aa28717ba1"],

Cell["\<\
Split a list into sequences of successive identical elements:\
\>", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"bc790624-c91a-4d9e-a5be-23e617ad3ca4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Split", "[", 
  RowBox[{"{", 
   RowBox[{
   "1", ",", "1", ",", "1", ",", "2", ",", "2", ",", "1", ",", "1", ",", "3", 
    ",", "1", ",", "1", ",", "1", ",", "2"}], "}"}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[19]:=",ExpressionUUID->"db4bd512-7ea9-4d63-8833-2c633d792749"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", "3", "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", "2", "}"}]}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[19]=",ExpressionUUID->"aeddaf1d-8d5a-4426-a36b-629ce10f8cf4"]
}, Open  ]],

Cell[TextData[{
 ButtonBox["Gather",
  BaseStyle->"Link"],
 ", on the other hand, gathers identical elements together, wherever they \
appear."
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:11",ExpressionUUID->"afcb4d88-75a1-4880-ba3b-26a55fba6cf5"],

Cell["Gather identical elements together in lists:", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"4a73b5aa-065b-4de7-8b0c-8c0d7a72718b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Gather", "[", 
  RowBox[{"{", 
   RowBox[{
   "1", ",", "1", ",", "1", ",", "2", ",", "2", ",", "1", ",", "1", ",", "3", 
    ",", "1", ",", "1", ",", "1", ",", "2"}], "}"}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[20]:=",ExpressionUUID->"e8772f08-f43b-40bd-8fee-181dec9255c1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", 
     "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "2", ",", "2"}], "}"}], ",", 
   RowBox[{"{", "3", "}"}]}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[20]=",ExpressionUUID->"4be490bf-e441-40d5-8caa-9ab37b320eba"]
}, Open  ]],

Cell[TextData[{
 ButtonBox["GatherBy",
  BaseStyle->"Link"],
 " gathers elements according to the result of applying a function to them. \
Here it\[CloseCurlyQuote]s using ",
 ButtonBox["LetterQ",
  BaseStyle->"Link"],
 ", so that it ",
 "gathers separately letters and non-letters",
 "."
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:12",ExpressionUUID->"5c85405c-061f-482f-82cf-4812a6def897"],

Cell["\<\
Gather characters according to whether they are letters or not:\
\>", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"ba3f62ff-e574-47a8-bec6-d0f2fd1601d9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GatherBy", "[", 
  RowBox[{
   RowBox[{
   "Characters", "[", "\"\<It's true that 2+2 is equal to 4!\>\"", "]"}], ",",
    "LetterQ"}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[21]:=",ExpressionUUID->"f618cfc0-ff7f-4a9f-8301-f1768237927b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\<\"I\"\>", ",", "\<\"t\"\>", ",", "\<\"s\"\>", ",", "\<\"t\"\>",
      ",", "\<\"r\"\>", ",", "\<\"u\"\>", ",", "\<\"e\"\>", ",", "\<\"t\"\>", 
     ",", "\<\"h\"\>", ",", "\<\"a\"\>", ",", "\<\"t\"\>", ",", "\<\"i\"\>", 
     ",", "\<\"s\"\>", ",", "\<\"e\"\>", ",", "\<\"q\"\>", ",", "\<\"u\"\>", 
     ",", "\<\"a\"\>", ",", "\<\"l\"\>", ",", "\<\"t\"\>", ",", "\<\"o\"\>"}],
     "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"'\"\>", ",", "\<\" \"\>", ",", "\<\" \"\>", ",", "\<\" \"\>",
      ",", "\<\"2\"\>", ",", "\<\"+\"\>", ",", "\<\"2\"\>", ",", "\<\" \"\>", 
     ",", "\<\" \"\>", ",", "\<\" \"\>", ",", "\<\" \"\>", ",", "\<\"4\"\>", 
     ",", "\<\"!\"\>"}], "}"}]}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[21]=",ExpressionUUID->"5eb0431e-2e93-47e5-bd94-0bbf696dcf73"]
}, Open  ]],

Cell[TextData[{
 ButtonBox["SortBy",
  BaseStyle->"Link"],
 " sorts according to the result of applying a function."
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:13",ExpressionUUID->"2556d1ca-791a-4c5d-a54b-541c86b36199"],

Cell[TextData[{
 ButtonBox["Sort",
  BaseStyle->"Link"],
 " normally sorts shorter lists before longer ones:"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:14",ExpressionUUID->"a0922f10-2e01-4420-949f-16c3e0e58df6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Sort", "[", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"IntegerDigits", "[", 
     RowBox[{"2", "^", "n"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"n", ",", "10"}], "}"}]}], "]"}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[22]:=",ExpressionUUID->"e6988bf2-8ace-4593-835d-36055399bc0f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", "2", "}"}], ",", 
   RowBox[{"{", "4", "}"}], ",", 
   RowBox[{"{", "8", "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "5", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "2", ",", "4"}], "}"}]}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[22]=",ExpressionUUID->"5e94eaff-61d9-4284-abb6-5decdc263734"]
}, Open  ]],

Cell[TextData[{
 "Here ",
 ButtonBox["SortBy",
  BaseStyle->"Link"],
 " is told to sort by the first element in each list:"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"1b9d14ca-4b22-4ad8-a315-f657811de3d1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SortBy", "[", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"IntegerDigits", "[", 
      RowBox[{"2", "^", "n"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "10"}], "}"}]}], "]"}], ",", "First"}], 
  "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[23]:=",ExpressionUUID->"be995fa3-6266-4d6a-9bd3-45559241e75a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "2", ",", "4"}], "}"}], ",", 
   RowBox[{"{", "2", "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "5", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}], ",", 
   RowBox[{"{", "4", "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6", ",", "4"}], "}"}], ",", 
   RowBox[{"{", "8", "}"}]}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[23]=",ExpressionUUID->"73a4431c-63da-481a-8b11-05822b1bfef3"]
}, Open  ]],

Cell[TextData[{
 ButtonBox["Sort",
  BaseStyle->"Link"],
 " sorts a list in order. ",
 ButtonBox["Union",
  BaseStyle->"Link"],
 " also removes any repeated elements."
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:15",ExpressionUUID->"bfb50fa5-f987-482d-8da7-4667e9acb28e"],

Cell["Find all the distinct elements that appear: ", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"b0760045-6040-4fee-9411-eb10d2919f4b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Union", "[", 
  RowBox[{"{", 
   RowBox[{
   "1", ",", "9", ",", "5", ",", "3", ",", "1", ",", "4", ",", "3", ",", "1", 
    ",", "3", ",", "3", ",", "5", ",", "3", ",", "9"}], "}"}], "]"}]], "Input",\

 Deletable->False,
 CellLabel->"In[24]:=",ExpressionUUID->"788b81f2-122a-4a45-a0cc-dd821d7710b9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "3", ",", "4", ",", "5", ",", "9"}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellTags->"LastCellOfAPage",
 CellLabel->"Out[24]=",ExpressionUUID->"371d254d-6185-4969-8280-2259fea6685b"]
}, Open  ]],

Cell[TextData[{
 "You can use ",
 ButtonBox["Union",
  BaseStyle->"Link"],
 " to find the \[OpenCurlyDoubleQuote]union\[CloseCurlyDoubleQuote] of \
elements that appear in any of several lists."
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"2b3e2c10-2415-4fa0-b1fa-5863f9153088"],

Cell["Get a list of all elements that appear in any of the lists:", \
"CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"c20ad5ac-41df-44ac-b13b-ed7e466691ba"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Union", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2", ",", "1", ",", "3", ",", "7", ",", "9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "5", ",", "1", ",", "2", ",", "3", ",", "3"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1", ",", "2", ",", "8", ",", "5"}], "}"}]}], 
  "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[25]:=",ExpressionUUID->"cef1ef9f-a65a-4186-81c3-454b45ff74d6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "7", ",", "8", ",", "9"}],
   "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[25]=",ExpressionUUID->"ac59f959-98e2-41ee-961c-d3311b0cb112"]
}, Open  ]],

Cell["Find which elements are common to all the lists:", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->{
  "i:16", "p:181"},ExpressionUUID->"98d3dd0e-1dc3-460d-a8f6-30f55c0af6e8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Intersection", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2", ",", "1", ",", "3", ",", "7", ",", "9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "5", ",", "1", ",", "2", ",", "3", ",", "3"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1", ",", "2", ",", "8"}], "}"}]}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[26]:=",ExpressionUUID->"c02516a0-6904-49b6-88dc-2b55a2ae98dd"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "2", ",", "3"}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[26]=",ExpressionUUID->"1483a7a6-8169-4121-aa3f-610410a23ff4"]
}, Open  ]],

Cell["\<\
Find which elements are in the first list but not the second one: \
\>", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:17",ExpressionUUID->"35dd7317-d4c3-48a6-9852-8b87fb4a4a5f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Complement", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"4", ",", "5", ",", "1", ",", "2", ",", "3", ",", "3"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1", ",", "2", ",", "8"}], "}"}]}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[27]:=",ExpressionUUID->"c6ce9567-510b-46cd-afeb-67906e094be3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"4", ",", "5"}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[27]=",ExpressionUUID->"4285e7ce-6820-493a-9b75-8ff3adb5571f"]
}, Open  ]],

Cell["\<\
Find letters that appear in any of English, Swedish and Turkish:\
\>", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:18",ExpressionUUID->"0bb4c6d9-c9b0-40dc-8cec-62385c592b50"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Union", "[", 
  RowBox[{
   RowBox[{"Alphabet", "[", "\"\<English\>\"", "]"}], ",", 
   RowBox[{"Alphabet", "[", "\"\<Swedish\>\"", "]"}], ",", 
   RowBox[{"Alphabet", "[", "\"\<Turkish\>\"", "]"}]}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[28]:=",ExpressionUUID->"a10dae26-fa4a-4b69-b47e-eab79f168737"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"\:011f\"\>", ",", "\<\"\:015f\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"\[ARing]\"\>", ",", "\<\"\[ADoubleDot]\"\>", ",", "\<\"b\"\>", 
   ",", "\<\"c\"\>", ",", "\<\"\[CCedilla]\"\>", ",", "\<\"d\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"f\"\>", ",", "\<\"g\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"\[DotlessI]\"\>", ",", "\<\"j\"\>", 
   ",", "\<\"k\"\>", ",", "\<\"l\"\>", ",", "\<\"m\"\>", ",", "\<\"n\"\>", 
   ",", "\<\"o\"\>", ",", "\<\"\[ODoubleDot]\"\>", ",", "\<\"p\"\>", 
   ",", "\<\"q\"\>", ",", "\<\"r\"\>", ",", "\<\"s\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"u\"\>", ",", "\<\"\[UDoubleDot]\"\>", ",", "\<\"v\"\>", 
   ",", "\<\"w\"\>", ",", "\<\"x\"\>", ",", "\<\"y\"\>", ",", "\<\"z\"\>"}], 
  "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[28]=",ExpressionUUID->"f75bcf4d-9945-4572-9b37-d88a9daeffa9"]
}, Open  ]],

Cell["Letters that appear in Swedish but not English:", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"0cb096d7-633f-4096-b75a-2e2e94264154"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Complement", "[", 
  RowBox[{
   RowBox[{"Alphabet", "[", "\"\<Swedish\>\"", "]"}], ",", 
   RowBox[{"Alphabet", "[", "\"\<English\>\"", "]"}]}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[29]:=",ExpressionUUID->"dd4b60d4-0379-4e6b-b2c4-a6b2c7b0a038"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"\[ARing]\"\>", ",", "\<\"\[ADoubleDot]\"\>", 
   ",", "\<\"\[ODoubleDot]\"\>"}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[29]=",ExpressionUUID->"67a51f55-d6ef-4a23-8811-b442deba91d0"]
}, Open  ]],

Cell[TextData[{
 "Another of the many functions ",
 "you can apply",
 " to lists is ",
 ButtonBox["Riffle",
  BaseStyle->"Link"],
 ", which inserts things between successive elements of a list. "
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:19",ExpressionUUID->"069e6e98-e64e-4ef6-a603-649cbe54f59a"],

Cell[TextData[{
 "Riffle ",
 Cell[BoxData[
 "x"], "InlineCode",ExpressionUUID->"c57a8577-533d-4cc8-82e8-bae24429fb5d"],
 " in between the elements of a list:"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"d6974f09-b54e-4513-8d87-64e1d2886be2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Riffle", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "3", ",", "4", ",", "5"}], "}"}], ",", "x"}], 
  "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[30]:=",ExpressionUUID->"342980af-eeaf-4852-a28a-aedcbd2c012a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "x", ",", "2", ",", "x", ",", "3", ",", "x", ",", "4", ",", "x", 
   ",", "5"}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[30]=",ExpressionUUID->"4a07e65a-bde6-4f5d-a895-80a6ecc7df63"]
}, Open  ]],

Cell[TextData[{
 "Riffle ",
 Cell[BoxData["--"], "InlineCode",ExpressionUUID->
  "b4243966-e748-43fa-a620-37f33bf97e46"],
 " into a list of characters:"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"6a5af1bb-6e14-42c9-9137-2c7dd5a5bca5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Riffle", "[", 
  RowBox[{
   RowBox[{"Characters", "[", "\"\<WOLFRAM\>\"", "]"}], ",", "\"\<--\>\""}], 
  "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[31]:=",ExpressionUUID->"1d8bd867-158f-446c-881d-973a1814d0a3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"W\"\>", ",", "\<\"--\"\>", ",", "\<\"O\"\>", ",", "\<\"--\"\>",
    ",", "\<\"L\"\>", ",", "\<\"--\"\>", ",", "\<\"F\"\>", ",", "\<\"--\"\>", 
   ",", "\<\"R\"\>", ",", "\<\"--\"\>", ",", "\<\"A\"\>", ",", "\<\"--\"\>", 
   ",", "\<\"M\"\>"}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[31]=",ExpressionUUID->"18d85d33-0918-4802-a91c-3e7ece0ade75"]
}, Open  ]],

Cell["Join everything together in a single string:", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"6be246c1-9777-47aa-9656-0d75505b2c34"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringJoin", "[", 
  RowBox[{"Riffle", "[", 
   RowBox[{
    RowBox[{"Characters", "[", "\"\<WOLFRAM\>\"", "]"}], ",", "\"\<--\>\""}], 
   "]"}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[32]:=",ExpressionUUID->"b355488f-d76d-46ba-8222-f45f2287a94b"],

Cell[BoxData["\<\"W--O--L--F--R--A--M\"\>"], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[32]=",ExpressionUUID->"49240d05-2812-49b0-8de9-7a1860402d3c"]
}, Open  ]],

Cell[TextData[{
 "Functions like ",
 ButtonBox["Partition",
  BaseStyle->"Link"],
 " let you take a list and break it into sublists. Sometimes ",
 "you\[CloseCurlyQuote]ll instead just want to start",
 " from a collection of possible elements, and form lists from them."
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->
  "LastCellOfAPage",ExpressionUUID->"96e18496-dabd-4a5d-9821-a0ae235dee6d"],

Cell[TextData[{
 ButtonBox["Permutations",
  BaseStyle->"Link"],
 " gives all possible orderings, or ",
 StyleBox["permutations",
  FontSlant->"Italic"],
 ", of a list."
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->{
  "i:20", "p:182"},ExpressionUUID->"b5f9767f-1b94-415a-84e8-14fbaa6fe50e"],

Cell["\<\
Generate a list of the 3!=3\[Times]2\[Times]1=6 possible orderings of 3 \
elements:\
\>", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"9ec83a79-6597-42de-abdc-b7cf0ef11a31"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Permutations", "[", 
  RowBox[{"{", 
   RowBox[{"Red", ",", "Green", ",", "Blue"}], "}"}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[33]:=",ExpressionUUID->"b0505d91-ddef-4cd2-a143-796051b4d733"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[1, 0, 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0.6666666666666666, 0., 0.],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[1, 0, 0]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[1, 0, 0]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[1, 0, 0],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[0, 1, 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0., 0.6666666666666666, 0.],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[0, 1, 0]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0, 1, 0]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[0, 1, 0],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[0, 0, 1], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0., 0., 0.6666666666666666],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[0, 0, 1]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0, 0, 1]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[0, 0, 1],
      Editable->False,
      Selectable->False]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[1, 0, 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0.6666666666666666, 0., 0.],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[1, 0, 0]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[1, 0, 0]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[1, 0, 0],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[0, 0, 1], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0., 0., 0.6666666666666666],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[0, 0, 1]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0, 0, 1]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[0, 0, 1],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[0, 1, 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0., 0.6666666666666666, 0.],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[0, 1, 0]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0, 1, 0]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[0, 1, 0],
      Editable->False,
      Selectable->False]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[0, 1, 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0., 0.6666666666666666, 0.],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[0, 1, 0]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0, 1, 0]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[0, 1, 0],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[1, 0, 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0.6666666666666666, 0., 0.],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[1, 0, 0]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[1, 0, 0]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[1, 0, 0],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[0, 0, 1], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0., 0., 0.6666666666666666],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[0, 0, 1]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0, 0, 1]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[0, 0, 1],
      Editable->False,
      Selectable->False]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[0, 1, 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0., 0.6666666666666666, 0.],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[0, 1, 0]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0, 1, 0]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[0, 1, 0],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[0, 0, 1], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0., 0., 0.6666666666666666],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[0, 0, 1]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0, 0, 1]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[0, 0, 1],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[1, 0, 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0.6666666666666666, 0., 0.],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[1, 0, 0]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[1, 0, 0]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[1, 0, 0],
      Editable->False,
      Selectable->False]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[0, 0, 1], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0., 0., 0.6666666666666666],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[0, 0, 1]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0, 0, 1]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[0, 0, 1],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[1, 0, 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0.6666666666666666, 0., 0.],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[1, 0, 0]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[1, 0, 0]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[1, 0, 0],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[0, 1, 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0., 0.6666666666666666, 0.],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[0, 1, 0]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0, 1, 0]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[0, 1, 0],
      Editable->False,
      Selectable->False]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[0, 0, 1], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0., 0., 0.6666666666666666],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[0, 0, 1]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0, 0, 1]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[0, 0, 1],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[0, 1, 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0., 0.6666666666666666, 0.],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[0, 1, 0]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0, 1, 0]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[0, 1, 0],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[1, 0, 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0.6666666666666666, 0., 0.],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[1, 0, 0]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[1, 0, 0]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[1, 0, 0],
      Editable->False,
      Selectable->False]}], "}"}]}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 GraphicsBoxOptions->{BaselinePosition->Scaled[0.1]},
 CellLabel->"Out[33]=",ExpressionUUID->"c2cfb4a8-8179-4b89-882a-7365d01e6630"]
}, Open  ]],

Cell[TextData[{
 "Generate all ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["2", "3"], "=", "8"}], TraditionalForm]],ExpressionUUID->
  "93998a02-d65f-4eb9-b6f7-43497f726907"],
 " possible subsets of a list of 3 elements:"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:21",ExpressionUUID->"2aa9eacb-c84d-4a97-9edd-3e74b32772aa"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Subsets", "[", 
  RowBox[{"{", 
   RowBox[{"Red", ",", "Green", ",", "Blue"}], "}"}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[34]:=",ExpressionUUID->"9ee833e6-24f3-49c7-a17d-29c51f462217"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", "}"}], ",", 
   RowBox[{"{", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{{{{
            {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
            {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
            {RGBColor[1, 0, 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[0.6666666666666666, 0., 0.],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[1, 0, 0]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[1, 0, 0]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[1, 0, 0],
     Editable->False,
     Selectable->False], "}"}], ",", 
   RowBox[{"{", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{{{{
            {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
            {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
            {RGBColor[0, 1, 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[0., 0.6666666666666666, 0.],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[0, 1, 0]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0, 1, 0]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[0, 1, 0],
     Editable->False,
     Selectable->False], "}"}], ",", 
   RowBox[{"{", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{{{{
            {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
            {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
            {RGBColor[0, 0, 1], RectangleBox[{0, -1}, {2, 1}]}}}}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->RGBColor[0., 0., 0.6666666666666666],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 
           1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification])}],
        PlotRangePadding->None],
       "RGBColor[0, 0, 1]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0, 0, 1]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
            Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     RGBColor[0, 0, 1],
     Editable->False,
     Selectable->False], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[1, 0, 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0.6666666666666666, 0., 0.],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[1, 0, 0]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[1, 0, 0]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[1, 0, 0],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[0, 1, 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0., 0.6666666666666666, 0.],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[0, 1, 0]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0, 1, 0]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[0, 1, 0],
      Editable->False,
      Selectable->False]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[1, 0, 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0.6666666666666666, 0., 0.],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[1, 0, 0]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[1, 0, 0]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[1, 0, 0],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[0, 0, 1], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0., 0., 0.6666666666666666],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[0, 0, 1]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0, 0, 1]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[0, 0, 1],
      Editable->False,
      Selectable->False]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[0, 1, 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0., 0.6666666666666666, 0.],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[0, 1, 0]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0, 1, 0]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[0, 1, 0],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[0, 0, 1], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0., 0., 0.6666666666666666],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[0, 0, 1]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0, 0, 1]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[0, 0, 1],
      Editable->False,
      Selectable->False]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[1, 0, 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0.6666666666666666, 0., 0.],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[1, 0, 0]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[1, 0, 0]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[1, 0, 0],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[0, 1, 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0., 0.6666666666666666, 0.],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[0, 1, 0]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0, 1, 0]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[0, 1, 0],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[0, 0, 1], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0., 0., 0.6666666666666666],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[0, 0, 1]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0, 0, 1]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[0, 0, 1],
      Editable->False,
      Selectable->False]}], "}"}]}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 GraphicsBoxOptions->{BaselinePosition->Scaled[0.1]},
 CellLabel->"Out[34]=",ExpressionUUID->"6a9f4898-7ae0-40dc-bbdb-fcbc584c50d2"]
}, Open  ]],

Cell[TextData[{
 ButtonBox["Tuples",
  BaseStyle->"Link"],
 " takes a list of elements, and generates all possible combinations of a \
given number of those elements."
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:22",ExpressionUUID->"c314740a-e723-47a2-8e52-8c5ff6eef3bf"],

Cell["Generate a list of all possible triples of red and green:", \
"CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"3f2ceb4e-9726-4a73-adb1-a2795248f570"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Tuples", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"Red", ",", "Green"}], "}"}], ",", "3"}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[35]:=",ExpressionUUID->"5f8124f8-96d0-4075-9098-8c71e5aa81a9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[1, 0, 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0.6666666666666666, 0., 0.],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[1, 0, 0]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[1, 0, 0]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[1, 0, 0],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[1, 0, 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0.6666666666666666, 0., 0.],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[1, 0, 0]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[1, 0, 0]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[1, 0, 0],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[1, 0, 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0.6666666666666666, 0., 0.],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[1, 0, 0]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[1, 0, 0]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[1, 0, 0],
      Editable->False,
      Selectable->False]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[1, 0, 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0.6666666666666666, 0., 0.],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[1, 0, 0]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[1, 0, 0]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[1, 0, 0],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[1, 0, 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0.6666666666666666, 0., 0.],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[1, 0, 0]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[1, 0, 0]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[1, 0, 0],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[0, 1, 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0., 0.6666666666666666, 0.],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[0, 1, 0]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0, 1, 0]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[0, 1, 0],
      Editable->False,
      Selectable->False]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[1, 0, 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0.6666666666666666, 0., 0.],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[1, 0, 0]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[1, 0, 0]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[1, 0, 0],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[0, 1, 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0., 0.6666666666666666, 0.],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[0, 1, 0]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0, 1, 0]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[0, 1, 0],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[1, 0, 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0.6666666666666666, 0., 0.],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[1, 0, 0]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[1, 0, 0]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[1, 0, 0],
      Editable->False,
      Selectable->False]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[1, 0, 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0.6666666666666666, 0., 0.],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[1, 0, 0]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[1, 0, 0]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[1, 0, 0],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[0, 1, 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0., 0.6666666666666666, 0.],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[0, 1, 0]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0, 1, 0]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[0, 1, 0],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[0, 1, 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0., 0.6666666666666666, 0.],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[0, 1, 0]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0, 1, 0]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[0, 1, 0],
      Editable->False,
      Selectable->False]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[0, 1, 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0., 0.6666666666666666, 0.],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[0, 1, 0]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0, 1, 0]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[0, 1, 0],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[1, 0, 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0.6666666666666666, 0., 0.],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[1, 0, 0]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[1, 0, 0]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[1, 0, 0],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[1, 0, 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0.6666666666666666, 0., 0.],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[1, 0, 0]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[1, 0, 0]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[1, 0, 0],
      Editable->False,
      Selectable->False]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[0, 1, 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0., 0.6666666666666666, 0.],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[0, 1, 0]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0, 1, 0]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[0, 1, 0],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[1, 0, 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0.6666666666666666, 0., 0.],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[1, 0, 0]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[1, 0, 0]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[1, 0, 0],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[0, 1, 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0., 0.6666666666666666, 0.],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[0, 1, 0]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0, 1, 0]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[0, 1, 0],
      Editable->False,
      Selectable->False]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[0, 1, 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0., 0.6666666666666666, 0.],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[0, 1, 0]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0, 1, 0]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[0, 1, 0],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[0, 1, 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0., 0.6666666666666666, 0.],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[0, 1, 0]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0, 1, 0]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[0, 1, 0],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[1, 0, 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0.6666666666666666, 0., 0.],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[1, 0, 0]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[1, 0, 0]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[1, 0, 0],
      Editable->False,
      Selectable->False]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[0, 1, 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0., 0.6666666666666666, 0.],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[0, 1, 0]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0, 1, 0]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[0, 1, 0],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[0, 1, 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0., 0.6666666666666666, 0.],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[0, 1, 0]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0, 1, 0]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[0, 1, 0],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[0, 1, 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0., 0.6666666666666666, 0.],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[0, 1, 0]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0, 1, 0]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[0, 1, 0],
      Editable->False,
      Selectable->False]}], "}"}]}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 GraphicsBoxOptions->{BaselinePosition->Scaled[0.1]},
 CellLabel->"Out[35]=",ExpressionUUID->"8edb56e2-edf1-4607-8790-cadfe4327496"]
}, Open  ]],

Cell[TextData[{
 ButtonBox["RandomChoice",
  BaseStyle->"Link"],
 " ",
 "lets you make a random choice",
 " from a list of elements."
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:23",ExpressionUUID->"0d530c04-16a7-45b7-b12e-a0a9f5eb72b9"],

Cell["Make a single random choice from a list:", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"72392d92-8dcc-426c-9d40-11d61c212776"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RandomChoice", "[", 
  RowBox[{"{", 
   RowBox[{"Red", ",", "Green", ",", "Blue"}], "}"}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[36]:=",ExpressionUUID->"55e1d318-b402-4088-ae6c-071fdf3fdb31"],

Cell[BoxData[
 InterpretationBox[
  ButtonBox[
   TooltipBox[
    GraphicsBox[{{{{
         {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
         {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
         {RGBColor[0, 1, 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
     AspectRatio->1,
     Frame->True,
     FrameStyle->RGBColor[0., 0.6666666666666666, 0.],
     FrameTicks->None,
     ImageSize->
      Dynamic[{Automatic, 
        1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
         Magnification])}],
     PlotRangePadding->None],
    "RGBColor[0, 1, 0]"],
   Appearance->None,
   BaseStyle->{},
   BaselinePosition->Baseline,
   ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
     If[
      Not[
       AbsoluteCurrentValue["Deployed"]], 
      SelectionMove[Typeset`box$, All, Expression]; 
      FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
      FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0, 1, 0]; 
      FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
      MathLink`CallFrontEnd[
        FrontEnd`AttachCell[Typeset`box$, 
         FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
         Left, Top}, 
         "ClosingActions" -> {
          "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
   DefaultBaseStyle->{},
   Evaluator->Automatic,
   Method->"Preemptive"],
  RGBColor[0, 1, 0],
  Editable->False,
  Selectable->False]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 GraphicsBoxOptions->{BaselinePosition->Scaled[0.1]},
 CellLabel->"Out[36]=",ExpressionUUID->"cc62a685-a077-48ba-8ba1-e40d330ad392"]
}, Open  ]],

Cell["Make a list of 20 random choices:", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"2b29533a-fce2-41c7-afe4-46cc63caccb9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RandomChoice", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"Red", ",", "Green", ",", "Blue"}], "}"}], ",", "20"}], 
  "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[37]:=",ExpressionUUID->"2c130951-5407-4713-8479-431a382d2386"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   InterpretationBox[
    ButtonBox[
     TooltipBox[
      GraphicsBox[{{{{
           {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
           {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
           {RGBColor[0, 0, 1], RectangleBox[{0, -1}, {2, 1}]}}}}},
       AspectRatio->1,
       Frame->True,
       FrameStyle->RGBColor[0., 0., 0.6666666666666666],
       FrameTicks->None,
       ImageSize->
        Dynamic[{
         Automatic, 
          1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
           Magnification])}],
       PlotRangePadding->None],
      "RGBColor[0, 0, 1]"],
     Appearance->None,
     BaseStyle->{},
     BaselinePosition->Baseline,
     ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
       If[
        Not[
         AbsoluteCurrentValue["Deployed"]], 
        SelectionMove[Typeset`box$, All, Expression]; 
        FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
        FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0, 0, 1]; 
        FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
        MathLink`CallFrontEnd[
          FrontEnd`AttachCell[Typeset`box$, 
           FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
           Left, Top}, 
           "ClosingActions" -> {
            "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
     DefaultBaseStyle->{},
     Evaluator->Automatic,
     Method->"Preemptive"],
    RGBColor[0, 0, 1],
    Editable->False,
    Selectable->False], ",", 
   InterpretationBox[
    ButtonBox[
     TooltipBox[
      GraphicsBox[{{{{
           {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
           {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
           {RGBColor[0, 1, 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
       AspectRatio->1,
       Frame->True,
       FrameStyle->RGBColor[0., 0.6666666666666666, 0.],
       FrameTicks->None,
       ImageSize->
        Dynamic[{
         Automatic, 
          1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
           Magnification])}],
       PlotRangePadding->None],
      "RGBColor[0, 1, 0]"],
     Appearance->None,
     BaseStyle->{},
     BaselinePosition->Baseline,
     ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
       If[
        Not[
         AbsoluteCurrentValue["Deployed"]], 
        SelectionMove[Typeset`box$, All, Expression]; 
        FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
        FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0, 1, 0]; 
        FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
        MathLink`CallFrontEnd[
          FrontEnd`AttachCell[Typeset`box$, 
           FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
           Left, Top}, 
           "ClosingActions" -> {
            "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
     DefaultBaseStyle->{},
     Evaluator->Automatic,
     Method->"Preemptive"],
    RGBColor[0, 1, 0],
    Editable->False,
    Selectable->False], ",", 
   InterpretationBox[
    ButtonBox[
     TooltipBox[
      GraphicsBox[{{{{
           {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
           {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
           {RGBColor[1, 0, 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
       AspectRatio->1,
       Frame->True,
       FrameStyle->RGBColor[0.6666666666666666, 0., 0.],
       FrameTicks->None,
       ImageSize->
        Dynamic[{
         Automatic, 
          1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
           Magnification])}],
       PlotRangePadding->None],
      "RGBColor[1, 0, 0]"],
     Appearance->None,
     BaseStyle->{},
     BaselinePosition->Baseline,
     ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
       If[
        Not[
         AbsoluteCurrentValue["Deployed"]], 
        SelectionMove[Typeset`box$, All, Expression]; 
        FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
        FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[1, 0, 0]; 
        FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
        MathLink`CallFrontEnd[
          FrontEnd`AttachCell[Typeset`box$, 
           FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
           Left, Top}, 
           "ClosingActions" -> {
            "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
     DefaultBaseStyle->{},
     Evaluator->Automatic,
     Method->"Preemptive"],
    RGBColor[1, 0, 0],
    Editable->False,
    Selectable->False], ",", 
   InterpretationBox[
    ButtonBox[
     TooltipBox[
      GraphicsBox[{{{{
           {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
           {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
           {RGBColor[0, 1, 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
       AspectRatio->1,
       Frame->True,
       FrameStyle->RGBColor[0., 0.6666666666666666, 0.],
       FrameTicks->None,
       ImageSize->
        Dynamic[{
         Automatic, 
          1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
           Magnification])}],
       PlotRangePadding->None],
      "RGBColor[0, 1, 0]"],
     Appearance->None,
     BaseStyle->{},
     BaselinePosition->Baseline,
     ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
       If[
        Not[
         AbsoluteCurrentValue["Deployed"]], 
        SelectionMove[Typeset`box$, All, Expression]; 
        FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
        FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0, 1, 0]; 
        FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
        MathLink`CallFrontEnd[
          FrontEnd`AttachCell[Typeset`box$, 
           FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
           Left, Top}, 
           "ClosingActions" -> {
            "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
     DefaultBaseStyle->{},
     Evaluator->Automatic,
     Method->"Preemptive"],
    RGBColor[0, 1, 0],
    Editable->False,
    Selectable->False], ",", 
   InterpretationBox[
    ButtonBox[
     TooltipBox[
      GraphicsBox[{{{{
           {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
           {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
           {RGBColor[0, 0, 1], RectangleBox[{0, -1}, {2, 1}]}}}}},
       AspectRatio->1,
       Frame->True,
       FrameStyle->RGBColor[0., 0., 0.6666666666666666],
       FrameTicks->None,
       ImageSize->
        Dynamic[{
         Automatic, 
          1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
           Magnification])}],
       PlotRangePadding->None],
      "RGBColor[0, 0, 1]"],
     Appearance->None,
     BaseStyle->{},
     BaselinePosition->Baseline,
     ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
       If[
        Not[
         AbsoluteCurrentValue["Deployed"]], 
        SelectionMove[Typeset`box$, All, Expression]; 
        FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
        FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0, 0, 1]; 
        FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
        MathLink`CallFrontEnd[
          FrontEnd`AttachCell[Typeset`box$, 
           FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
           Left, Top}, 
           "ClosingActions" -> {
            "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
     DefaultBaseStyle->{},
     Evaluator->Automatic,
     Method->"Preemptive"],
    RGBColor[0, 0, 1],
    Editable->False,
    Selectable->False], ",", 
   InterpretationBox[
    ButtonBox[
     TooltipBox[
      GraphicsBox[{{{{
           {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
           {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
           {RGBColor[1, 0, 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
       AspectRatio->1,
       Frame->True,
       FrameStyle->RGBColor[0.6666666666666666, 0., 0.],
       FrameTicks->None,
       ImageSize->
        Dynamic[{
         Automatic, 
          1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
           Magnification])}],
       PlotRangePadding->None],
      "RGBColor[1, 0, 0]"],
     Appearance->None,
     BaseStyle->{},
     BaselinePosition->Baseline,
     ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
       If[
        Not[
         AbsoluteCurrentValue["Deployed"]], 
        SelectionMove[Typeset`box$, All, Expression]; 
        FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
        FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[1, 0, 0]; 
        FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
        MathLink`CallFrontEnd[
          FrontEnd`AttachCell[Typeset`box$, 
           FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
           Left, Top}, 
           "ClosingActions" -> {
            "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
     DefaultBaseStyle->{},
     Evaluator->Automatic,
     Method->"Preemptive"],
    RGBColor[1, 0, 0],
    Editable->False,
    Selectable->False], ",", 
   InterpretationBox[
    ButtonBox[
     TooltipBox[
      GraphicsBox[{{{{
           {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
           {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
           {RGBColor[0, 0, 1], RectangleBox[{0, -1}, {2, 1}]}}}}},
       AspectRatio->1,
       Frame->True,
       FrameStyle->RGBColor[0., 0., 0.6666666666666666],
       FrameTicks->None,
       ImageSize->
        Dynamic[{
         Automatic, 
          1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
           Magnification])}],
       PlotRangePadding->None],
      "RGBColor[0, 0, 1]"],
     Appearance->None,
     BaseStyle->{},
     BaselinePosition->Baseline,
     ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
       If[
        Not[
         AbsoluteCurrentValue["Deployed"]], 
        SelectionMove[Typeset`box$, All, Expression]; 
        FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
        FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0, 0, 1]; 
        FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
        MathLink`CallFrontEnd[
          FrontEnd`AttachCell[Typeset`box$, 
           FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
           Left, Top}, 
           "ClosingActions" -> {
            "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
     DefaultBaseStyle->{},
     Evaluator->Automatic,
     Method->"Preemptive"],
    RGBColor[0, 0, 1],
    Editable->False,
    Selectable->False], ",", 
   InterpretationBox[
    ButtonBox[
     TooltipBox[
      GraphicsBox[{{{{
           {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
           {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
           {RGBColor[0, 1, 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
       AspectRatio->1,
       Frame->True,
       FrameStyle->RGBColor[0., 0.6666666666666666, 0.],
       FrameTicks->None,
       ImageSize->
        Dynamic[{
         Automatic, 
          1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
           Magnification])}],
       PlotRangePadding->None],
      "RGBColor[0, 1, 0]"],
     Appearance->None,
     BaseStyle->{},
     BaselinePosition->Baseline,
     ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
       If[
        Not[
         AbsoluteCurrentValue["Deployed"]], 
        SelectionMove[Typeset`box$, All, Expression]; 
        FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
        FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0, 1, 0]; 
        FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
        MathLink`CallFrontEnd[
          FrontEnd`AttachCell[Typeset`box$, 
           FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
           Left, Top}, 
           "ClosingActions" -> {
            "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
     DefaultBaseStyle->{},
     Evaluator->Automatic,
     Method->"Preemptive"],
    RGBColor[0, 1, 0],
    Editable->False,
    Selectable->False], ",", 
   InterpretationBox[
    ButtonBox[
     TooltipBox[
      GraphicsBox[{{{{
           {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
           {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
           {RGBColor[0, 0, 1], RectangleBox[{0, -1}, {2, 1}]}}}}},
       AspectRatio->1,
       Frame->True,
       FrameStyle->RGBColor[0., 0., 0.6666666666666666],
       FrameTicks->None,
       ImageSize->
        Dynamic[{
         Automatic, 
          1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
           Magnification])}],
       PlotRangePadding->None],
      "RGBColor[0, 0, 1]"],
     Appearance->None,
     BaseStyle->{},
     BaselinePosition->Baseline,
     ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
       If[
        Not[
         AbsoluteCurrentValue["Deployed"]], 
        SelectionMove[Typeset`box$, All, Expression]; 
        FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
        FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0, 0, 1]; 
        FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
        MathLink`CallFrontEnd[
          FrontEnd`AttachCell[Typeset`box$, 
           FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
           Left, Top}, 
           "ClosingActions" -> {
            "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
     DefaultBaseStyle->{},
     Evaluator->Automatic,
     Method->"Preemptive"],
    RGBColor[0, 0, 1],
    Editable->False,
    Selectable->False], ",", 
   InterpretationBox[
    ButtonBox[
     TooltipBox[
      GraphicsBox[{{{{
           {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
           {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
           {RGBColor[0, 0, 1], RectangleBox[{0, -1}, {2, 1}]}}}}},
       AspectRatio->1,
       Frame->True,
       FrameStyle->RGBColor[0., 0., 0.6666666666666666],
       FrameTicks->None,
       ImageSize->
        Dynamic[{
         Automatic, 
          1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
           Magnification])}],
       PlotRangePadding->None],
      "RGBColor[0, 0, 1]"],
     Appearance->None,
     BaseStyle->{},
     BaselinePosition->Baseline,
     ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
       If[
        Not[
         AbsoluteCurrentValue["Deployed"]], 
        SelectionMove[Typeset`box$, All, Expression]; 
        FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
        FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0, 0, 1]; 
        FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
        MathLink`CallFrontEnd[
          FrontEnd`AttachCell[Typeset`box$, 
           FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
           Left, Top}, 
           "ClosingActions" -> {
            "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
     DefaultBaseStyle->{},
     Evaluator->Automatic,
     Method->"Preemptive"],
    RGBColor[0, 0, 1],
    Editable->False,
    Selectable->False], ",", 
   InterpretationBox[
    ButtonBox[
     TooltipBox[
      GraphicsBox[{{{{
           {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
           {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
           {RGBColor[0, 0, 1], RectangleBox[{0, -1}, {2, 1}]}}}}},
       AspectRatio->1,
       Frame->True,
       FrameStyle->RGBColor[0., 0., 0.6666666666666666],
       FrameTicks->None,
       ImageSize->
        Dynamic[{
         Automatic, 
          1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
           Magnification])}],
       PlotRangePadding->None],
      "RGBColor[0, 0, 1]"],
     Appearance->None,
     BaseStyle->{},
     BaselinePosition->Baseline,
     ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
       If[
        Not[
         AbsoluteCurrentValue["Deployed"]], 
        SelectionMove[Typeset`box$, All, Expression]; 
        FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
        FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0, 0, 1]; 
        FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
        MathLink`CallFrontEnd[
          FrontEnd`AttachCell[Typeset`box$, 
           FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
           Left, Top}, 
           "ClosingActions" -> {
            "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
     DefaultBaseStyle->{},
     Evaluator->Automatic,
     Method->"Preemptive"],
    RGBColor[0, 0, 1],
    Editable->False,
    Selectable->False], ",", 
   InterpretationBox[
    ButtonBox[
     TooltipBox[
      GraphicsBox[{{{{
           {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
           {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
           {RGBColor[0, 1, 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
       AspectRatio->1,
       Frame->True,
       FrameStyle->RGBColor[0., 0.6666666666666666, 0.],
       FrameTicks->None,
       ImageSize->
        Dynamic[{
         Automatic, 
          1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
           Magnification])}],
       PlotRangePadding->None],
      "RGBColor[0, 1, 0]"],
     Appearance->None,
     BaseStyle->{},
     BaselinePosition->Baseline,
     ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
       If[
        Not[
         AbsoluteCurrentValue["Deployed"]], 
        SelectionMove[Typeset`box$, All, Expression]; 
        FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
        FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0, 1, 0]; 
        FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
        MathLink`CallFrontEnd[
          FrontEnd`AttachCell[Typeset`box$, 
           FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
           Left, Top}, 
           "ClosingActions" -> {
            "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
     DefaultBaseStyle->{},
     Evaluator->Automatic,
     Method->"Preemptive"],
    RGBColor[0, 1, 0],
    Editable->False,
    Selectable->False], ",", 
   InterpretationBox[
    ButtonBox[
     TooltipBox[
      GraphicsBox[{{{{
           {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
           {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
           {RGBColor[0, 0, 1], RectangleBox[{0, -1}, {2, 1}]}}}}},
       AspectRatio->1,
       Frame->True,
       FrameStyle->RGBColor[0., 0., 0.6666666666666666],
       FrameTicks->None,
       ImageSize->
        Dynamic[{
         Automatic, 
          1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
           Magnification])}],
       PlotRangePadding->None],
      "RGBColor[0, 0, 1]"],
     Appearance->None,
     BaseStyle->{},
     BaselinePosition->Baseline,
     ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
       If[
        Not[
         AbsoluteCurrentValue["Deployed"]], 
        SelectionMove[Typeset`box$, All, Expression]; 
        FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
        FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0, 0, 1]; 
        FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
        MathLink`CallFrontEnd[
          FrontEnd`AttachCell[Typeset`box$, 
           FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
           Left, Top}, 
           "ClosingActions" -> {
            "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
     DefaultBaseStyle->{},
     Evaluator->Automatic,
     Method->"Preemptive"],
    RGBColor[0, 0, 1],
    Editable->False,
    Selectable->False], ",", 
   InterpretationBox[
    ButtonBox[
     TooltipBox[
      GraphicsBox[{{{{
           {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
           {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
           {RGBColor[0, 1, 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
       AspectRatio->1,
       Frame->True,
       FrameStyle->RGBColor[0., 0.6666666666666666, 0.],
       FrameTicks->None,
       ImageSize->
        Dynamic[{
         Automatic, 
          1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
           Magnification])}],
       PlotRangePadding->None],
      "RGBColor[0, 1, 0]"],
     Appearance->None,
     BaseStyle->{},
     BaselinePosition->Baseline,
     ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
       If[
        Not[
         AbsoluteCurrentValue["Deployed"]], 
        SelectionMove[Typeset`box$, All, Expression]; 
        FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
        FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0, 1, 0]; 
        FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
        MathLink`CallFrontEnd[
          FrontEnd`AttachCell[Typeset`box$, 
           FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
           Left, Top}, 
           "ClosingActions" -> {
            "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
     DefaultBaseStyle->{},
     Evaluator->Automatic,
     Method->"Preemptive"],
    RGBColor[0, 1, 0],
    Editable->False,
    Selectable->False], ",", 
   InterpretationBox[
    ButtonBox[
     TooltipBox[
      GraphicsBox[{{{{
           {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
           {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
           {RGBColor[1, 0, 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
       AspectRatio->1,
       Frame->True,
       FrameStyle->RGBColor[0.6666666666666666, 0., 0.],
       FrameTicks->None,
       ImageSize->
        Dynamic[{
         Automatic, 
          1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
           Magnification])}],
       PlotRangePadding->None],
      "RGBColor[1, 0, 0]"],
     Appearance->None,
     BaseStyle->{},
     BaselinePosition->Baseline,
     ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
       If[
        Not[
         AbsoluteCurrentValue["Deployed"]], 
        SelectionMove[Typeset`box$, All, Expression]; 
        FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
        FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[1, 0, 0]; 
        FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
        MathLink`CallFrontEnd[
          FrontEnd`AttachCell[Typeset`box$, 
           FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
           Left, Top}, 
           "ClosingActions" -> {
            "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
     DefaultBaseStyle->{},
     Evaluator->Automatic,
     Method->"Preemptive"],
    RGBColor[1, 0, 0],
    Editable->False,
    Selectable->False], ",", 
   InterpretationBox[
    ButtonBox[
     TooltipBox[
      GraphicsBox[{{{{
           {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
           {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
           {RGBColor[1, 0, 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
       AspectRatio->1,
       Frame->True,
       FrameStyle->RGBColor[0.6666666666666666, 0., 0.],
       FrameTicks->None,
       ImageSize->
        Dynamic[{
         Automatic, 
          1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
           Magnification])}],
       PlotRangePadding->None],
      "RGBColor[1, 0, 0]"],
     Appearance->None,
     BaseStyle->{},
     BaselinePosition->Baseline,
     ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
       If[
        Not[
         AbsoluteCurrentValue["Deployed"]], 
        SelectionMove[Typeset`box$, All, Expression]; 
        FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
        FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[1, 0, 0]; 
        FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
        MathLink`CallFrontEnd[
          FrontEnd`AttachCell[Typeset`box$, 
           FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
           Left, Top}, 
           "ClosingActions" -> {
            "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
     DefaultBaseStyle->{},
     Evaluator->Automatic,
     Method->"Preemptive"],
    RGBColor[1, 0, 0],
    Editable->False,
    Selectable->False], ",", 
   InterpretationBox[
    ButtonBox[
     TooltipBox[
      GraphicsBox[{{{{
           {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
           {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
           {RGBColor[0, 0, 1], RectangleBox[{0, -1}, {2, 1}]}}}}},
       AspectRatio->1,
       Frame->True,
       FrameStyle->RGBColor[0., 0., 0.6666666666666666],
       FrameTicks->None,
       ImageSize->
        Dynamic[{
         Automatic, 
          1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
           Magnification])}],
       PlotRangePadding->None],
      "RGBColor[0, 0, 1]"],
     Appearance->None,
     BaseStyle->{},
     BaselinePosition->Baseline,
     ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
       If[
        Not[
         AbsoluteCurrentValue["Deployed"]], 
        SelectionMove[Typeset`box$, All, Expression]; 
        FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
        FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0, 0, 1]; 
        FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
        MathLink`CallFrontEnd[
          FrontEnd`AttachCell[Typeset`box$, 
           FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
           Left, Top}, 
           "ClosingActions" -> {
            "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
     DefaultBaseStyle->{},
     Evaluator->Automatic,
     Method->"Preemptive"],
    RGBColor[0, 0, 1],
    Editable->False,
    Selectable->False], ",", 
   InterpretationBox[
    ButtonBox[
     TooltipBox[
      GraphicsBox[{{{{
           {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
           {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
           {RGBColor[0, 0, 1], RectangleBox[{0, -1}, {2, 1}]}}}}},
       AspectRatio->1,
       Frame->True,
       FrameStyle->RGBColor[0., 0., 0.6666666666666666],
       FrameTicks->None,
       ImageSize->
        Dynamic[{
         Automatic, 
          1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
           Magnification])}],
       PlotRangePadding->None],
      "RGBColor[0, 0, 1]"],
     Appearance->None,
     BaseStyle->{},
     BaselinePosition->Baseline,
     ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
       If[
        Not[
         AbsoluteCurrentValue["Deployed"]], 
        SelectionMove[Typeset`box$, All, Expression]; 
        FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
        FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0, 0, 1]; 
        FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
        MathLink`CallFrontEnd[
          FrontEnd`AttachCell[Typeset`box$, 
           FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
           Left, Top}, 
           "ClosingActions" -> {
            "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
     DefaultBaseStyle->{},
     Evaluator->Automatic,
     Method->"Preemptive"],
    RGBColor[0, 0, 1],
    Editable->False,
    Selectable->False], ",", 
   InterpretationBox[
    ButtonBox[
     TooltipBox[
      GraphicsBox[{{{{
           {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
           {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
           {RGBColor[0, 1, 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
       AspectRatio->1,
       Frame->True,
       FrameStyle->RGBColor[0., 0.6666666666666666, 0.],
       FrameTicks->None,
       ImageSize->
        Dynamic[{
         Automatic, 
          1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
           Magnification])}],
       PlotRangePadding->None],
      "RGBColor[0, 1, 0]"],
     Appearance->None,
     BaseStyle->{},
     BaselinePosition->Baseline,
     ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
       If[
        Not[
         AbsoluteCurrentValue["Deployed"]], 
        SelectionMove[Typeset`box$, All, Expression]; 
        FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
        FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0, 1, 0]; 
        FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
        MathLink`CallFrontEnd[
          FrontEnd`AttachCell[Typeset`box$, 
           FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
           Left, Top}, 
           "ClosingActions" -> {
            "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
     DefaultBaseStyle->{},
     Evaluator->Automatic,
     Method->"Preemptive"],
    RGBColor[0, 1, 0],
    Editable->False,
    Selectable->False], ",", 
   InterpretationBox[
    ButtonBox[
     TooltipBox[
      GraphicsBox[{{{{
           {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
           {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
           {RGBColor[0, 0, 1], RectangleBox[{0, -1}, {2, 1}]}}}}},
       AspectRatio->1,
       Frame->True,
       FrameStyle->RGBColor[0., 0., 0.6666666666666666],
       FrameTicks->None,
       ImageSize->
        Dynamic[{
         Automatic, 
          1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
           Magnification])}],
       PlotRangePadding->None],
      "RGBColor[0, 0, 1]"],
     Appearance->None,
     BaseStyle->{},
     BaselinePosition->Baseline,
     ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
       If[
        Not[
         AbsoluteCurrentValue["Deployed"]], 
        SelectionMove[Typeset`box$, All, Expression]; 
        FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
        FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0, 0, 1]; 
        FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
        MathLink`CallFrontEnd[
          FrontEnd`AttachCell[Typeset`box$, 
           FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
           Left, Top}, 
           "ClosingActions" -> {
            "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
     DefaultBaseStyle->{},
     Evaluator->Automatic,
     Method->"Preemptive"],
    RGBColor[0, 0, 1],
    Editable->False,
    Selectable->False]}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 GraphicsBoxOptions->{BaselinePosition->Scaled[0.1]},
 CellLabel->"Out[37]=",ExpressionUUID->"93121874-33ae-4d27-b373-426c77af20a4"]
}, Open  ]],

Cell["Make 5 lists of 3 random choices:", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"ae56cbd0-e626-4a72-8fe7-a080ec96bd29"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RandomChoice", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"Red", ",", "Green", ",", "Blue"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "3"}], "}"}]}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[38]:=",ExpressionUUID->"e4e48deb-cfe5-4552-99d3-721f39db1637"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[0, 0, 1], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0., 0., 0.6666666666666666],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[0, 0, 1]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0, 0, 1]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[0, 0, 1],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[0, 1, 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0., 0.6666666666666666, 0.],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[0, 1, 0]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0, 1, 0]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[0, 1, 0],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[0, 0, 1], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0., 0., 0.6666666666666666],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[0, 0, 1]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0, 0, 1]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[0, 0, 1],
      Editable->False,
      Selectable->False]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[0, 0, 1], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0., 0., 0.6666666666666666],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[0, 0, 1]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0, 0, 1]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[0, 0, 1],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[1, 0, 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0.6666666666666666, 0., 0.],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[1, 0, 0]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[1, 0, 0]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[1, 0, 0],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[1, 0, 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0.6666666666666666, 0., 0.],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[1, 0, 0]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[1, 0, 0]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[1, 0, 0],
      Editable->False,
      Selectable->False]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[1, 0, 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0.6666666666666666, 0., 0.],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[1, 0, 0]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[1, 0, 0]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[1, 0, 0],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[1, 0, 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0.6666666666666666, 0., 0.],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[1, 0, 0]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[1, 0, 0]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[1, 0, 0],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[1, 0, 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0.6666666666666666, 0., 0.],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[1, 0, 0]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[1, 0, 0]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[1, 0, 0],
      Editable->False,
      Selectable->False]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[0, 1, 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0., 0.6666666666666666, 0.],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[0, 1, 0]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0, 1, 0]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[0, 1, 0],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[1, 0, 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0.6666666666666666, 0., 0.],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[1, 0, 0]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[1, 0, 0]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[1, 0, 0],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[0, 0, 1], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0., 0., 0.6666666666666666],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[0, 0, 1]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0, 0, 1]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[0, 0, 1],
      Editable->False,
      Selectable->False]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[0, 0, 1], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0., 0., 0.6666666666666666],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[0, 0, 1]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0, 0, 1]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[0, 0, 1],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[1, 0, 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0.6666666666666666, 0., 0.],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[1, 0, 0]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[1, 0, 0]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[1, 0, 0],
      Editable->False,
      Selectable->False], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{{{{
             {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
             {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
             {RGBColor[1, 0, 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0.6666666666666666, 0., 0.],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 
            1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}],
         PlotRangePadding->None],
        "RGBColor[1, 0, 0]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[1, 0, 0]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[1, 0, 0],
      Editable->False,
      Selectable->False]}], "}"}]}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 GraphicsBoxOptions->{BaselinePosition->Scaled[0.1]},
 CellLabel->"Out[38]=",ExpressionUUID->"9d24566d-dba3-4386-be5e-80249737f2b6"]
}, Open  ]],

Cell[TextData[{
 ButtonBox["RandomSample",
  BaseStyle->"Link"],
 " picks a random sample of elements from a list, never picking any \
particular element more than once."
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:24",ExpressionUUID->"ad70bb26-8682-4c53-9fef-94ebd4f544b5"],

Cell["\<\
Pick 20 elements from the range 1 to 100, never picking any number more than \
once:\
\>", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"3ce63356-866d-40f6-bbe5-3cf02d1b4a63"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RandomSample", "[", 
  RowBox[{
   RowBox[{"Range", "[", "100", "]"}], ",", "20"}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[39]:=",ExpressionUUID->"eaaa32e9-0e7c-4044-87bb-1fc6b809641b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "82", ",", "3", ",", "93", ",", "92", ",", "39", ",", "45", ",", "63", ",", 
   "32", ",", "79", ",", "75", ",", "34", ",", "1", ",", "11", ",", "59", ",",
    "98", ",", "67", ",", "38", ",", "44", ",", "28", ",", "76"}], 
  "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[39]=",ExpressionUUID->"eb2f11b7-f5bd-4572-a796-a9bcff88b896"]
}, Open  ]],

Cell["\<\
If you don\[CloseCurlyQuote]t say how many elements to pick you get a random \
ordering of the whole list:\
\>", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"58d5e1fe-f710-4fae-bc8e-e8d5fc90e456"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RandomSample", "[", 
  RowBox[{"Range", "[", "10", "]"}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[40]:=",ExpressionUUID->"1484bc83-3465-47b6-9de0-4d3c5b415160"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "2", ",", "5", ",", "1", ",", "7", ",", "4", ",", "6", ",", "3", ",", "8", 
   ",", "9", ",", "10"}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellTags->"LastCellOfAPage",
 CellLabel->"Out[40]=",ExpressionUUID->"837306dd-ed2e-45be-8a6d-edd7e5379496"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Vocabulary", "VocabularySection",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"p:183",ExpressionUUID->"41753a4f-c674-4830-8724-6eba7c3bc3b3"],

Cell[BoxData[GridBox[{
   {
    RowBox[{
     ButtonBox["Transpose",
      BaseStyle->"CodeLink"], "[", 
     StyleBox["list", "CodeVariableLrg"], "]"}], " ", Cell[
    "transpose inner and outer lists ", "VocabularyText",ExpressionUUID->
     "4ebfb456-ebd7-4c94-8331-40a8fc279208"]},
   {
    RowBox[{
     ButtonBox["Thread",
      BaseStyle->"CodeLink"], "[", 
     RowBox[{
      SubscriptBox[
       StyleBox["list", "CodeVariableLrg"], "1"], "\[Rule]", 
      SubscriptBox[
       StyleBox["list", "CodeVariableLrg"], "2"]}], "]"}], " ", Cell[
    "thread across elements of lists ", "VocabularyText",ExpressionUUID->
     "7c74387b-f93d-4d77-851a-f21f6739bd1c"]},
   {
    RowBox[{
     ButtonBox["Partition",
      BaseStyle->"CodeLink"], "[", 
     RowBox[{
      StyleBox["list", "CodeVariableLrg"], ",", 
      StyleBox["n", "CodeVariableLrg"]}], "]"}], " ", Cell[TextData[{
     "partition into blocks of size ",
     Cell[BoxData[
      StyleBox["n", "CodeVariable"]], "InlineCode",ExpressionUUID->
      "a4953dcb-7778-44a2-b6d7-8e74e7d6226e"],
     " "
    }], "VocabularyText",ExpressionUUID->
     "ac0194c3-32cd-4c81-b670-ab200b900b3d"]},
   {
    RowBox[{
     ButtonBox["Flatten",
      BaseStyle->"CodeLink"], "[", 
     StyleBox["list", "CodeVariableLrg"], "]"}], " ", Cell[
    "flatten out all sublists ", "VocabularyText",ExpressionUUID->
     "d1be87c4-a82e-4de6-afff-79e4a3387e7a"]},
   {
    RowBox[{
     ButtonBox["Flatten",
      BaseStyle->"CodeLink"], "[", 
     RowBox[{
      StyleBox["list", "CodeVariableLrg"], ",", 
      StyleBox["k", "CodeVariableLrg"]}], "]"}], " ", Cell[TextData[{
     "flatten out ",
     Cell[BoxData[
      StyleBox["k", "CodeVariable"]], "InlineCode",ExpressionUUID->
      "b9337ac3-f4b7-4e56-8c02-b8e7bee74796"],
     " levels of sublists "
    }], "VocabularyText",ExpressionUUID->
     "134a82e9-21a6-4bc3-ab40-7d7e46c7cabb"]},
   {
    RowBox[{
     ButtonBox["ArrayFlatten",
      BaseStyle->"CodeLink"], "[", 
     StyleBox["list", "CodeVariableLrg"], "]"}], " ", Cell[
    "flatten arrays of arrays ", "VocabularyText",ExpressionUUID->
     "f7229c6c-886f-45d1-9dfd-8be38f258cbf"]},
   {
    RowBox[{
     ButtonBox["Split",
      BaseStyle->"CodeLink"], "[", 
     StyleBox["list", "CodeVariableLrg"], "]"}], " ", Cell[
    "split into runs of identical elements ", "VocabularyText",
     ExpressionUUID->"3d5ca939-f30d-448d-9871-fd274e268d3f"]},
   {
    RowBox[{
     ButtonBox["Gather",
      BaseStyle->"CodeLink"], "[", 
     StyleBox["list", "CodeVariableLrg"], "]"}], " ", Cell[
    "gather identical elements into lists ", "VocabularyText",ExpressionUUID->
     "db998a4e-3006-4ec9-9e34-92fc6b49f033"]},
   {
    RowBox[{
     ButtonBox["GatherBy",
      BaseStyle->"CodeLink"], "[", 
     RowBox[{
      StyleBox["list", "CodeVariableLrg"], ",", 
      StyleBox["f", "CodeVariableLrg"]}], "]"}], " ", Cell[TextData[{
     "gather according to results of applying ",
     Cell[BoxData[
      StyleBox[
       RowBox[{"f", " "}], "CodeVariable"]], "InlineCode",ExpressionUUID->
      "df11f280-5c04-4023-bce9-f0f65ec75a7e"]
    }], "VocabularyText",ExpressionUUID->
     "cad18b4e-795d-46ae-8ceb-9ccc6b9902a2"]},
   {
    RowBox[{
     ButtonBox["SortBy",
      BaseStyle->"CodeLink"], "[", 
     RowBox[{
      StyleBox["list", "CodeVariableLrg"], ",", 
      StyleBox["f", "CodeVariableLrg"]}], "]"}], " ", Cell[TextData[{
     "sort according to results of applying ",
     Cell[BoxData[
      StyleBox[
       RowBox[{"f", " "}], "CodeVariable"]], "InlineCode",ExpressionUUID->
      "6da4f3d4-6143-4d10-b64b-ba68c28a43ac"],
     " "
    }], "VocabularyText",ExpressionUUID->
     "8e42cfe8-fe28-44c0-bd64-1009dfbdc694"]},
   {
    RowBox[{
     ButtonBox["Riffle",
      BaseStyle->"CodeLink"], "[", 
     RowBox[{
      StyleBox["list", "CodeVariableLrg"], ",", 
      StyleBox["x", "CodeVariableLrg"]}], "]"}], " ", Cell[TextData[{
     "riffle ",
     Cell[BoxData[
      StyleBox["x", "CodeVariable"]], "InlineCode",ExpressionUUID->
      "303498e2-c836-4745-abf7-781101af822b"],
     " between elements of ",
     Cell[BoxData[
      StyleBox["list", "CodeVariable"]], "InlineCode",ExpressionUUID->
      "afce8fa5-c056-4010-a3a7-442f874175e1"],
     " "
    }], "VocabularyText",ExpressionUUID->
     "3abd799f-ff7a-4bc4-afa3-88a79968e91a"]},
   {
    RowBox[{
     ButtonBox["Union",
      BaseStyle->"CodeLink"], "[", 
     StyleBox["list", "CodeVariableLrg"], "]"}], " ", Cell[TextData[{
     "distinct elements in ",
     Cell[BoxData[
      StyleBox["list", "CodeVariable"]], "InlineCode",ExpressionUUID->
      "b3a04042-28c8-4ca2-9b67-9a8db993cd6a"]
    }], "VocabularyText",ExpressionUUID->
     "fc409ae0-5f98-4ee3-bc3d-49efa9e4db4c"]},
   {
    RowBox[{
     ButtonBox["Union",
      BaseStyle->"CodeLink"], "[", 
     RowBox[{
      SubscriptBox[
       StyleBox["list", "CodeVariableLrg"], "1"], ",", 
      SubscriptBox[
       StyleBox["list", "CodeVariableLrg"], "2"], ",", "\[NegativeThinSpace]", 
      StyleBox["...", "GrayPointSix"]}], "]"}], " ", Cell[
    "elements that appear in any of the lists", "VocabularyText",
     ExpressionUUID->"a0bb9204-3b2d-4495-a1a4-853b8d9889e1"]},
   {
    RowBox[{
     ButtonBox["Intersection",
      BaseStyle->"CodeLink"], "[", 
     RowBox[{
      SubscriptBox[
       StyleBox["list", "CodeVariableLrg"], "1"], ",", 
      SubscriptBox[
       StyleBox["list", "CodeVariableLrg"], "2"], ",", "\[NegativeThinSpace]", 
      StyleBox["...", "GrayPointSix"]}], "]"}], " ", Cell[
    "elements that appear in all the lists", "VocabularyText",ExpressionUUID->
     "e080d46b-de4c-4910-a710-e374fd353796"]},
   {
    RowBox[{
     ButtonBox["Complement",
      BaseStyle->"CodeLink"], "[", 
     RowBox[{
      SubscriptBox[
       StyleBox["list", "CodeVariableLrg"], "1"], ",", 
      SubscriptBox[
       StyleBox["list", "CodeVariableLrg"], "2"]}], "]"}], " ", Cell[TextData[{
     "elements that appear in ",
     Cell[BoxData[
      FormBox[
       StyleBox[
        SubscriptBox[
         StyleBox["list", "CodeVariableLrg"], "1"],
        FontColor->GrayLevel[0]], TraditionalForm]],ExpressionUUID->
      "073c36be-633d-49c0-9d65-31fde2a9d030"],
     " but not ",
     Cell[BoxData[
      FormBox[
       StyleBox[
        SubscriptBox[
         StyleBox["list", "CodeVariableLrg"], "2"],
        FontColor->GrayLevel[0]], TraditionalForm]],ExpressionUUID->
      "b4018aac-a4d1-4d70-b5ba-66241b28e7a7"]
    }], "VocabularyText",ExpressionUUID->
     "6f569b8b-9dac-4180-8917-844d1d8fe16c"]},
   {
    RowBox[{
     ButtonBox["Permutations",
      BaseStyle->"CodeLink"], "[", 
     StyleBox["list", "CodeVariableLrg"], "]"}], " ", Cell[
    "all possible permutations (orderings) ", "VocabularyText",
     ExpressionUUID->"3198eaf1-5909-4e3a-931f-1bf8b3f4b033"]},
   {
    RowBox[{
     ButtonBox["Subsets",
      BaseStyle->"CodeLink"], "[", 
     StyleBox["list", "CodeVariableLrg"], "]"}], " ", Cell[
    "all possible subsets ", "VocabularyText",ExpressionUUID->
     "67312cf2-3131-4322-ad11-1f8a15d520b7"]},
   {
    RowBox[{
     ButtonBox["Tuples",
      BaseStyle->"CodeLink"], "[", 
     RowBox[{
      StyleBox["list", "CodeVariableLrg"], ",", 
      StyleBox["n", "CodeVariableLrg"]}], "]"}], " ", Cell[TextData[{
     "all possible combinations of ",
     Cell[BoxData[
      StyleBox["n", "CodeVariable"]], "InlineCode",ExpressionUUID->
      "4b553339-2b01-43be-9ef9-64e378af23d4"],
     " elements "
    }], "VocabularyText",ExpressionUUID->
     "e26a4761-30ee-44ca-9c92-14122da147fd"]},
   {
    RowBox[{
     ButtonBox["RandomChoice",
      BaseStyle->"CodeLink"], "[", 
     StyleBox["list", "CodeVariableLrg"], "]"}], " ", Cell[TextData[{
     "random choice from ",
     Cell[BoxData[
      StyleBox["list", "CodeVariable"]], "InlineCode",ExpressionUUID->
      "da2e8387-b832-41ac-832c-b00ae15d2eac"],
     " "
    }], "VocabularyText",ExpressionUUID->
     "6eb3ddb5-2194-4739-b35e-74a200c4db0e"]},
   {
    RowBox[{
     ButtonBox["RandomChoice",
      BaseStyle->"CodeLink"], "[", 
     RowBox[{
      StyleBox["list", "CodeVariableLrg"], ",", 
      StyleBox["n", "CodeVariableLrg"]}], "]"}], " ", Cell[TextData[{
     Cell[BoxData[
      StyleBox["n", "CodeVariable"]], "InlineCode",ExpressionUUID->
      "7cc9a374-bc1c-4959-b607-ddbcccb757d6"],
     " random choices "
    }], "VocabularyText",ExpressionUUID->
     "c6e9bc88-ea06-49b5-af55-267840897d0a"]},
   {
    RowBox[{
     ButtonBox["RandomSample",
      BaseStyle->"CodeLink"], "[", 
     RowBox[{
      StyleBox["list", "CodeVariableLrg"], ",", 
      StyleBox["n", "CodeVariableLrg"]}], "]"}], " ", Cell[TextData[{
     Cell[BoxData[
      StyleBox["n", "CodeVariable"]], "InlineCode",ExpressionUUID->
      "7bddda00-613d-4d62-bc2c-04b4586cec9e"],
     " random non-repeating samples "
    }], "VocabularyText",ExpressionUUID->
     "3d374897-7612-496d-8eb2-9f6d880753e2"]},
   {
    RowBox[{
     ButtonBox["RandomSample",
      BaseStyle->"CodeLink"], "[", 
     StyleBox["list", "CodeVariableLrg"], "]"}], " ", Cell[
    "random ordering of a list ", "VocabularyText",ExpressionUUID->
     "53b3cffc-ce09-4af2-9dd8-28fd9e8bc2ad"]}
  }]], "VocabularyTable",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 GridBoxOptions->{GridBoxDividers->{"Columns" -> {{False}}}},
 CellTags->
  "LastCellOfAPage",ExpressionUUID->"58d7e8d8-9585-41ed-bfa3-552a4a8c459a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 DynamicModuleBox[{$CellContext`open$$ = False}, 
  TagBox[GridBox[{
     {
      StyleBox["\<\"Exercises\"\>",
       StripOnInput->False,
       FontSlant->"Italic"], 
      PaneBox[
       TagBox[
        ButtonBox[
         DynamicBox[ToBoxes[
           If[$CellContext`open$$, 
            Row[{
              Style["-", "ExercisePreviewButtonTextHighlight"], 
              Style[" Preview Exercises", "ExercisePreviewButtonText"]}], 
            Row[{
              Style["+", "ExercisePreviewButtonTextHighlight"], 
              Style[" Preview Exercises", "ExercisePreviewButtonText"]}]], 
           StandardForm],
          ImageSizeCache->{115., {1., 10.}}],
         Appearance->None,
         ButtonFunction:>(
          If[$CellContext`open$$, $CellContext`open$$ = 
            False, $CellContext`open$$ = True]; NotebookFind[
            EvaluationNotebook[], "ExerciseSummaryCell", Next, CellStyle, 
            WrapAround -> True, AutoScroll -> False]; FrontEndTokenExecute[
            EvaluationNotebook[], "ExpandSelection"]; FrontEndExecute[
            FrontEndToken[
             EvaluationNotebook[], "OpenCloseGroup"]]),
         Evaluator->Automatic,
         Method->"Preemptive"],
        MouseAppearanceTag["LinkHand"]],
       Alignment->Right,
       ImageSize->Full]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {Left, Right}, "Rows" -> {{Center}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"],
  DynamicModuleValues:>{}]], "ExerciseSection",
 Editable->False,
 ShowCellBracket->False,
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{3.669991951589675*^9},
 ShowStringCharacters->
  False,ExpressionUUID->"0d0ad356-782b-4a09-86e7-7cc725aae97d"],

Cell[CellGroupData[{

Cell[BoxData[
 TagBox[GridBox[{
    {
     TagBox[GridBox[{
        {
         PaneBox[
          
          StyleBox["\<\"21 Exercises Available\"\>", "ExerciseSummaryHeading",
           
           StripOnInput->False],
          ImageMargins->{{20, 0}, {0, 10}}]},
        {
         PaneBox[
          StyleBox["\<\"with 13 extras\"\>", "ExerciseSummarySubheading",
           StripOnInput->False],
          ImageMargins->{{20, 0}, {10, 0}}]}
       },
       DefaultBaseStyle->"Column",
       GridBoxAlignment->{"Columns" -> {{Left}}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
       
       GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{0}}}],
      "Column"], 
     PaneBox[
      ButtonBox[
       StyleBox["\<\"Get Started \[RightGuillemet]\"\>", 
        "ExerciseSummaryHeading",
        StripOnInput->False],
       Appearance->None,
       ButtonFunction:>
        NotebookLocate[{"EIWL1-30-rearranging-lists-exercises.nb", ""}],
       Evaluator->Automatic,
       Method->"Preemptive"],
      FrameMargins->{{10, 0}, {10, 10}},
      ImageSize->Full]}
   },
   AutoDelete->False,
   GridBoxAlignment->{"Columns" -> {{Left}}},
   GridBoxItemSize->{"Columns" -> {
       Scaled[0.7], 
       Scaled[0.3]}, "Rows" -> {{Automatic}}}],
  "Grid"]], "ExerciseSummaryCell",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"b7588562-5abc-4472-a3d0-6f51c618def1"],

Cell[CellGroupData[{

Cell[TextData[{
 "Use ",
 ButtonBox["Thread",
  BaseStyle->"Link"],
 " to make a list of rules with each letter of the alphabet going to its \
position in the alphabet.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "30.1", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"8ecef57e-2b69-433c-bbd4-033508fe7a60"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\<\"a\"\>", "\[Rule]", "1"}], ",", 
         RowBox[{"\<\"b\"\>", "\[Rule]", "2"}], ",", 
         RowBox[{"\<\"c\"\>", "\[Rule]", "3"}], ",", 
         RowBox[{"\<\"d\"\>", "\[Rule]", "4"}], ",", 
         RowBox[{"\<\"e\"\>", "\[Rule]", "5"}], ",", 
         RowBox[{"\<\"f\"\>", "\[Rule]", "6"}], ",", 
         RowBox[{"\<\"g\"\>", "\[Rule]", "7"}], ",", 
         RowBox[{"\<\"h\"\>", "\[Rule]", "8"}], ",", 
         RowBox[{"\<\"i\"\>", "\[Rule]", "9"}], ",", 
         RowBox[{"\<\"j\"\>", "\[Rule]", "10"}], ",", 
         RowBox[{"\<\"k\"\>", "\[Rule]", "11"}], ",", 
         RowBox[{"\<\"l\"\>", "\[Rule]", "12"}], ",", 
         RowBox[{"\<\"m\"\>", "\[Rule]", "13"}], ",", 
         RowBox[{"\<\"n\"\>", "\[Rule]", "14"}], ",", 
         RowBox[{"\<\"o\"\>", "\[Rule]", "15"}], ",", 
         RowBox[{"\<\"p\"\>", "\[Rule]", "16"}], ",", 
         RowBox[{"\<\"q\"\>", "\[Rule]", "17"}], ",", 
         RowBox[{"\<\"r\"\>", "\[Rule]", "18"}], ",", 
         RowBox[{"\<\"s\"\>", "\[Rule]", "19"}], ",", 
         RowBox[{"\<\"t\"\>", "\[Rule]", "20"}], ",", 
         RowBox[{"\<\"u\"\>", "\[Rule]", "21"}], ",", 
         RowBox[{"\<\"v\"\>", "\[Rule]", "22"}], ",", 
         RowBox[{"\<\"w\"\>", "\[Rule]", "23"}], ",", 
         RowBox[{"\<\"x\"\>", "\[Rule]", "24"}], ",", 
         RowBox[{"\<\"y\"\>", "\[Rule]", "25"}], ",", 
         RowBox[{"\<\"z\"\>", "\[Rule]", "26"}]}], "}"}]], "ExerciseOutput",
       ExpressionUUID->"46eebcc5-a0ae-4d07-bbbc-bed212bb7e42"],
      Apply[TextCell, 
       Cell[
        BoxData[
         RowBox[{"{", 
           RowBox[{
             RowBox[{"\"a\"", "\[Rule]", "1"}], ",", 
             RowBox[{"\"b\"", "\[Rule]", "2"}], ",", 
             RowBox[{"\"c\"", "\[Rule]", "3"}], ",", 
             RowBox[{"\"d\"", "\[Rule]", "4"}], ",", 
             RowBox[{"\"e\"", "\[Rule]", "5"}], ",", 
             RowBox[{"\"f\"", "\[Rule]", "6"}], ",", 
             RowBox[{"\"g\"", "\[Rule]", "7"}], ",", 
             RowBox[{"\"h\"", "\[Rule]", "8"}], ",", 
             RowBox[{"\"i\"", "\[Rule]", "9"}], ",", 
             RowBox[{"\"j\"", "\[Rule]", "10"}], ",", 
             RowBox[{"\"k\"", "\[Rule]", "11"}], ",", 
             RowBox[{"\"l\"", "\[Rule]", "12"}], ",", 
             RowBox[{"\"m\"", "\[Rule]", "13"}], ",", 
             RowBox[{"\"n\"", "\[Rule]", "14"}], ",", 
             RowBox[{"\"o\"", "\[Rule]", "15"}], ",", 
             RowBox[{"\"p\"", "\[Rule]", "16"}], ",", 
             RowBox[{"\"q\"", "\[Rule]", "17"}], ",", 
             RowBox[{"\"r\"", "\[Rule]", "18"}], ",", 
             RowBox[{"\"s\"", "\[Rule]", "19"}], ",", 
             RowBox[{"\"t\"", "\[Rule]", "20"}], ",", 
             RowBox[{"\"u\"", "\[Rule]", "21"}], ",", 
             RowBox[{"\"v\"", "\[Rule]", "22"}], ",", 
             RowBox[{"\"w\"", "\[Rule]", "23"}], ",", 
             RowBox[{"\"x\"", "\[Rule]", "24"}], ",", 
             RowBox[{"\"y\"", "\[Rule]", "25"}], ",", 
             RowBox[{"\"z\"", "\[Rule]", "26"}]}], "}"}]], "ExerciseOutput", 
        Selectable -> False, Copyable -> False, Editable -> False, 
        ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"18d6579a-c045-4e19-b1a6-160ad83fa466"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Make a 4\[Times]6 grid of the first 24 letters of the alphabet.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "30.2", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"355ab225-cdf1-435b-864d-461f1533ddc0"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       TagBox[GridBox[{
          {"\<\"a\"\>", "\<\"b\"\>", "\<\"c\"\>", "\<\"d\"\>", "\<\"e\"\>", "\
\<\"f\"\>"},
          {"\<\"g\"\>", "\<\"h\"\>", "\<\"i\"\>", "\<\"j\"\>", "\<\"k\"\>", "\
\<\"l\"\>"},
          {"\<\"m\"\>", "\<\"n\"\>", "\<\"o\"\>", "\<\"p\"\>", "\<\"q\"\>", "\
\<\"r\"\>"},
          {"\<\"s\"\>", "\<\"t\"\>", "\<\"u\"\>", "\<\"v\"\>", "\<\"w\"\>", "\
\<\"x\"\>"}
         },
         AutoDelete->False,
         GridBoxItemSize->{
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
        "Grid"]], "ExerciseOutput",ExpressionUUID->
       "77dd97a6-eaab-45cc-84cc-9e9a4a6bd32c"],
      Apply[TextCell, 
       Cell[
        BoxData[
         TagBox[
          
          GridBox[{{"\"a\"", "\"b\"", "\"c\"", "\"d\"", "\"e\"", "\"f\""}, {
            "\"g\"", "\"h\"", "\"i\"", "\"j\"", "\"k\"", "\"l\""}, {
            "\"m\"", "\"n\"", "\"o\"", "\"p\"", "\"q\"", "\"r\""}, {
            "\"s\"", "\"t\"", "\"u\"", "\"v\"", "\"w\"", "\"x\""}}, 
           AutoDelete -> False, 
           GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"]], 
        "ExerciseOutput", Selectable -> False, Copyable -> False, Editable -> 
        False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"b51fcd7a-4470-42a9-a99e-0c75dc477055"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Make a grid of the digits in 2^1000, with 50 digits per row, and put frames \
around everything.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "30.3", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"886fb4c0-5000-4cab-a545-01d412332f7e"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       TagBox[GridBox[{
          {"1", "0", "7", "1", "5", "0", "8", "6", "0", "7", "1", "8", "6", 
           "2", "6", "7", "3", "2", "0", "9", "4", "8", "4", "2", "5", "0", 
           "4", "9", "0", "6", "0", "0", "0", "1", "8", "1", "0", "5", "6", 
           "1", "4", "0", "4", "8", "1", "1", "7", "0", "5", "5"},
          {"3", "3", "6", "0", "7", "4", "4", "3", "7", "5", "0", "3", "8", 
           "8", "3", "7", "0", "3", "5", "1", "0", "5", "1", "1", "2", "4", 
           "9", "3", "6", "1", "2", "2", "4", "9", "3", "1", "9", "8", "3", 
           "7", "8", "8", "1", "5", "6", "9", "5", "8", "5", "8"},
          {"1", "2", "7", "5", "9", "4", "6", "7", "2", "9", "1", "7", "5", 
           "5", "3", "1", "4", "6", "8", "2", "5", "1", "8", "7", "1", "4", 
           "5", "2", "8", "5", "6", "9", "2", "3", "1", "4", "0", "4", "3", 
           "5", "9", "8", "4", "5", "7", "7", "5", "7", "4", "6"},
          {"9", "8", "5", "7", "4", "8", "0", "3", "9", "3", "4", "5", "6", 
           "7", "7", "7", "4", "8", "2", "4", "2", "3", "0", "9", "8", "5", 
           "4", "2", "1", "0", "7", "4", "6", "0", "5", "0", "6", "2", "3", 
           "7", "1", "1", "4", "1", "8", "7", "7", "9", "5", "4"},
          {"1", "8", "2", "1", "5", "3", "0", "4", "6", "4", "7", "4", "9", 
           "8", "3", "5", "8", "1", "9", "4", "1", "2", "6", "7", "3", "9", 
           "8", "7", "6", "7", "5", "5", "9", "1", "6", "5", "5", "4", "3", 
           "9", "4", "6", "0", "7", "7", "0", "6", "2", "9", "1"},
          {"4", "5", "7", "1", "1", "9", "6", "4", "7", "7", "6", "8", "6", 
           "5", "4", "2", "1", "6", "7", "6", "6", "0", "4", "2", "9", "8", 
           "3", "1", "6", "5", "2", "6", "2", "4", "3", "8", "6", "8", "3", 
           "7", "2", "0", "5", "6", "6", "8", "0", "6", "9", "3"}
         },
         AutoDelete->False,
         GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
         GridBoxItemSize->{
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
        "Grid"]], "ExerciseOutput",ExpressionUUID->
       "2f6bc498-8c4d-4121-9a75-c033a8416930"],
      Apply[TextCell, 
       Cell[
        BoxData[
         TagBox[
          
          GridBox[{{
            "1", "0", "7", "1", "5", "0", "8", "6", "0", "7", "1", "8", "6", 
             "2", "6", "7", "3", "2", "0", "9", "4", "8", "4", "2", "5", "0", 
             "4", "9", "0", "6", "0", "0", "0", "1", "8", "1", "0", "5", "6", 
             "1", "4", "0", "4", "8", "1", "1", "7", "0", "5", "5"}, {
            "3", "3", "6", "0", "7", "4", "4", "3", "7", "5", "0", "3", "8", 
             "8", "3", "7", "0", "3", "5", "1", "0", "5", "1", "1", "2", "4", 
             "9", "3", "6", "1", "2", "2", "4", "9", "3", "1", "9", "8", "3", 
             "7", "8", "8", "1", "5", "6", "9", "5", "8", "5", "8"}, {
            "1", "2", "7", "5", "9", "4", "6", "7", "2", "9", "1", "7", "5", 
             "5", "3", "1", "4", "6", "8", "2", "5", "1", "8", "7", "1", "4", 
             "5", "2", "8", "5", "6", "9", "2", "3", "1", "4", "0", "4", "3", 
             "5", "9", "8", "4", "5", "7", "7", "5", "7", "4", "6"}, {
            "9", "8", "5", "7", "4", "8", "0", "3", "9", "3", "4", "5", "6", 
             "7", "7", "7", "4", "8", "2", "4", "2", "3", "0", "9", "8", "5", 
             "4", "2", "1", "0", "7", "4", "6", "0", "5", "0", "6", "2", "3", 
             "7", "1", "1", "4", "1", "8", "7", "7", "9", "5", "4"}, {
            "1", "8", "2", "1", "5", "3", "0", "4", "6", "4", "7", "4", "9", 
             "8", "3", "5", "8", "1", "9", "4", "1", "2", "6", "7", "3", "9", 
             "8", "7", "6", "7", "5", "5", "9", "1", "6", "5", "5", "4", "3", 
             "9", "4", "6", "0", "7", "7", "0", "6", "2", "9", "1"}, {
            "4", "5", "7", "1", "1", "9", "6", "4", "7", "7", "6", "8", "6", 
             "5", "4", "2", "1", "6", "7", "6", "6", "0", "4", "2", "9", "8", 
             "3", "1", "6", "5", "2", "6", "2", "4", "3", "8", "6", "8", "3", 
             "7", "2", "0", "5", "6", "6", "8", "0", "6", "9", "3"}}, 
           AutoDelete -> False, 
           GridBoxFrame -> {"Columns" -> {{True}}, "Rows" -> {{True}}}, 
           GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"]], 
        "ExerciseOutput", Selectable -> False, Copyable -> False, Editable -> 
        False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"47998158-0821-467d-9334-cf919786fd07"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Make a grid of the first 400 characters in the Wikipedia article for \
\[OpenCurlyDoubleQuote]computers\[CloseCurlyDoubleQuote], with 20 characters \
per row, and frames around everything.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "30.4", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"9ede4dd8-97fb-4236-a8da-15bae1d966bd"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Sample", " ", "expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       TagBox[GridBox[{
          {"\<\"A\"\>", "\<\" \"\>", "\<\"c\"\>", "\<\"o\"\>", "\<\"m\"\>", "\
\<\"p\"\>", "\<\"u\"\>", "\<\"t\"\>", "\<\"e\"\>", "\<\"r\"\>", "\<\" \"\>", \
"\<\"i\"\>", "\<\"s\"\>", "\<\" \"\>", "\<\"a\"\>", "\<\" \"\>", "\<\"g\"\>", \
"\<\"e\"\>", "\<\"n\"\>", "\<\"e\"\>"},
          {"\<\"r\"\>", "\<\"a\"\>", "\<\"l\"\>", "\<\"-\"\>", "\<\"p\"\>", "\
\<\"u\"\>", "\<\"r\"\>", "\<\"p\"\>", "\<\"o\"\>", "\<\"s\"\>", "\<\"e\"\>", \
"\<\" \"\>", "\<\"d\"\>", "\<\"e\"\>", "\<\"v\"\>", "\<\"i\"\>", "\<\"c\"\>", \
"\<\"e\"\>", "\<\" \"\>", "\<\"t\"\>"},
          {"\<\"h\"\>", "\<\"a\"\>", "\<\"t\"\>", "\<\" \"\>", "\<\"c\"\>", "\
\<\"a\"\>", "\<\"n\"\>", "\<\" \"\>", "\<\"b\"\>", "\<\"e\"\>", "\<\" \"\>", \
"\<\"p\"\>", "\<\"r\"\>", "\<\"o\"\>", "\<\"g\"\>", "\<\"r\"\>", "\<\"a\"\>", \
"\<\"m\"\>", "\<\"m\"\>", "\<\"e\"\>"},
          {"\<\"d\"\>", "\<\" \"\>", "\<\"t\"\>", "\<\"o\"\>", "\<\" \"\>", "\
\<\"c\"\>", "\<\"a\"\>", "\<\"r\"\>", "\<\"r\"\>", "\<\"y\"\>", "\<\" \"\>", \
"\<\"o\"\>", "\<\"u\"\>", "\<\"t\"\>", "\<\" \"\>", "\<\"a\"\>", "\<\" \"\>", \
"\<\"s\"\>", "\<\"e\"\>", "\<\"t\"\>"},
          {"\<\" \"\>", "\<\"o\"\>", "\<\"f\"\>", "\<\" \"\>", "\<\"a\"\>", "\
\<\"r\"\>", "\<\"i\"\>", "\<\"t\"\>", "\<\"h\"\>", "\<\"m\"\>", "\<\"e\"\>", \
"\<\"t\"\>", "\<\"i\"\>", "\<\"c\"\>", "\<\" \"\>", "\<\"o\"\>", "\<\"r\"\>", \
"\<\" \"\>", "\<\"l\"\>", "\<\"o\"\>"},
          {"\<\"g\"\>", "\<\"i\"\>", "\<\"c\"\>", "\<\"a\"\>", "\<\"l\"\>", "\
\<\" \"\>", "\<\"o\"\>", "\<\"p\"\>", "\<\"e\"\>", "\<\"r\"\>", "\<\"a\"\>", \
"\<\"t\"\>", "\<\"i\"\>", "\<\"o\"\>", "\<\"n\"\>", "\<\"s\"\>", "\<\" \"\>", \
"\<\"a\"\>", "\<\"u\"\>", "\<\"t\"\>"},
          {"\<\"o\"\>", "\<\"m\"\>", "\<\"a\"\>", "\<\"t\"\>", "\<\"i\"\>", "\
\<\"c\"\>", "\<\"a\"\>", "\<\"l\"\>", "\<\"l\"\>", "\<\"y\"\>", "\<\".\"\>", \
"\<\" \"\>", "\<\"S\"\>", "\<\"i\"\>", "\<\"n\"\>", "\<\"c\"\>", "\<\"e\"\>", \
"\<\" \"\>", "\<\"a\"\>", "\<\" \"\>"},
          {"\<\"s\"\>", "\<\"e\"\>", "\<\"q\"\>", "\<\"u\"\>", "\<\"e\"\>", "\
\<\"n\"\>", "\<\"c\"\>", "\<\"e\"\>", "\<\" \"\>", "\<\"o\"\>", "\<\"f\"\>", \
"\<\" \"\>", "\<\"o\"\>", "\<\"p\"\>", "\<\"e\"\>", "\<\"r\"\>", "\<\"a\"\>", \
"\<\"t\"\>", "\<\"i\"\>", "\<\"o\"\>"},
          {"\<\"n\"\>", "\<\"s\"\>", "\<\" \"\>", "\<\"c\"\>", "\<\"a\"\>", "\
\<\"n\"\>", "\<\" \"\>", "\<\"b\"\>", "\<\"e\"\>", "\<\" \"\>", "\<\"r\"\>", \
"\<\"e\"\>", "\<\"a\"\>", "\<\"d\"\>", "\<\"i\"\>", "\<\"l\"\>", "\<\"y\"\>", \
"\<\" \"\>", "\<\"c\"\>", "\<\"h\"\>"},
          {"\<\"a\"\>", "\<\"n\"\>", "\<\"g\"\>", "\<\"e\"\>", "\<\"d\"\>", "\
\<\",\"\>", "\<\" \"\>", "\<\"t\"\>", "\<\"h\"\>", "\<\"e\"\>", "\<\" \"\>", \
"\<\"c\"\>", "\<\"o\"\>", "\<\"m\"\>", "\<\"p\"\>", "\<\"u\"\>", "\<\"t\"\>", \
"\<\"e\"\>", "\<\"r\"\>", "\<\" \"\>"},
          {"\<\"c\"\>", "\<\"a\"\>", "\<\"n\"\>", "\<\" \"\>", "\<\"s\"\>", "\
\<\"o\"\>", "\<\"l\"\>", "\<\"v\"\>", "\<\"e\"\>", "\<\" \"\>", "\<\"m\"\>", \
"\<\"o\"\>", "\<\"r\"\>", "\<\"e\"\>", "\<\" \"\>", "\<\"t\"\>", "\<\"h\"\>", \
"\<\"a\"\>", "\<\"n\"\>", "\<\" \"\>"},
          {"\<\"o\"\>", "\<\"n\"\>", "\<\"e\"\>", "\<\" \"\>", "\<\"k\"\>", "\
\<\"i\"\>", "\<\"n\"\>", "\<\"d\"\>", "\<\" \"\>", "\<\"o\"\>", "\<\"f\"\>", \
"\<\" \"\>", "\<\"p\"\>", "\<\"r\"\>", "\<\"o\"\>", "\<\"b\"\>", "\<\"l\"\>", \
"\<\"e\"\>", "\<\"m\"\>", "\<\".\"\>"},
          {"\<\"\\n\"\>", "\<\"C\"\>", "\<\"o\"\>", "\<\"n\"\>", "\<\"v\"\>", \
"\<\"e\"\>", "\<\"n\"\>", "\<\"t\"\>", "\<\"i\"\>", "\<\"o\"\>", "\<\"n\"\>", \
"\<\"a\"\>", "\<\"l\"\>", "\<\"l\"\>", "\<\"y\"\>", "\<\",\"\>", "\<\" \"\>", \
"\<\"a\"\>", "\<\" \"\>", "\<\"c\"\>"},
          {"\<\"o\"\>", "\<\"m\"\>", "\<\"p\"\>", "\<\"u\"\>", "\<\"t\"\>", "\
\<\"e\"\>", "\<\"r\"\>", "\<\" \"\>", "\<\"c\"\>", "\<\"o\"\>", "\<\"n\"\>", \
"\<\"s\"\>", "\<\"i\"\>", "\<\"s\"\>", "\<\"t\"\>", "\<\"s\"\>", "\<\" \"\>", \
"\<\"o\"\>", "\<\"f\"\>", "\<\" \"\>"},
          {"\<\"a\"\>", "\<\"t\"\>", "\<\" \"\>", "\<\"l\"\>", "\<\"e\"\>", "\
\<\"a\"\>", "\<\"s\"\>", "\<\"t\"\>", "\<\" \"\>", "\<\"o\"\>", "\<\"n\"\>", \
"\<\"e\"\>", "\<\" \"\>", "\<\"p\"\>", "\<\"r\"\>", "\<\"o\"\>", "\<\"c\"\>", \
"\<\"e\"\>", "\<\"s\"\>", "\<\"s\"\>"},
          {"\<\"i\"\>", "\<\"n\"\>", "\<\"g\"\>", "\<\" \"\>", "\<\"e\"\>", "\
\<\"l\"\>", "\<\"e\"\>", "\<\"m\"\>", "\<\"e\"\>", "\<\"n\"\>", "\<\"t\"\>", \
"\<\",\"\>", "\<\" \"\>", "\<\"t\"\>", "\<\"y\"\>", "\<\"p\"\>", "\<\"i\"\>", \
"\<\"c\"\>", "\<\"a\"\>", "\<\"l\"\>"},
          {"\<\"l\"\>", "\<\"y\"\>", "\<\" \"\>", "\<\"a\"\>", "\<\" \"\>", "\
\<\"c\"\>", "\<\"e\"\>", "\<\"n\"\>", "\<\"t\"\>", "\<\"r\"\>", "\<\"a\"\>", \
"\<\"l\"\>", "\<\" \"\>", "\<\"p\"\>", "\<\"r\"\>", "\<\"o\"\>", "\<\"c\"\>", \
"\<\"e\"\>", "\<\"s\"\>", "\<\"s\"\>"},
          {"\<\"i\"\>", "\<\"n\"\>", "\<\"g\"\>", "\<\" \"\>", "\<\"u\"\>", "\
\<\"n\"\>", "\<\"i\"\>", "\<\"t\"\>", "\<\" \"\>", "\<\"(\"\>", "\<\"C\"\>", \
"\<\"P\"\>", "\<\"U\"\>", "\<\")\"\>", "\<\",\"\>", "\<\" \"\>", "\<\"a\"\>", \
"\<\"n\"\>", "\<\"d\"\>", "\<\" \"\>"},
          {"\<\"s\"\>", "\<\"o\"\>", "\<\"m\"\>", "\<\"e\"\>", "\<\" \"\>", "\
\<\"f\"\>", "\<\"o\"\>", "\<\"r\"\>", "\<\"m\"\>", "\<\" \"\>", "\<\"o\"\>", \
"\<\"f\"\>", "\<\" \"\>", "\<\"m\"\>", "\<\"e\"\>", "\<\"m\"\>", "\<\"o\"\>", \
"\<\"r\"\>", "\<\"y\"\>", "\<\".\"\>"},
          {"\<\" \"\>", "\<\"T\"\>", "\<\"h\"\>", "\<\"e\"\>", "\<\" \"\>", "\
\<\"p\"\>", "\<\"r\"\>", "\<\"o\"\>", "\<\"c\"\>", "\<\"e\"\>", "\<\"s\"\>", \
"\<\"s\"\>", "\<\"i\"\>", "\<\"n\"\>", "\<\"g\"\>", "\<\" \"\>", "\<\"e\"\>", \
"\<\"l\"\>", "\<\"e\"\>", "\<\"m\"\>"}
         },
         AutoDelete->False,
         GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
         GridBoxItemSize->{
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
        "Grid"]], "ExerciseOutput",ExpressionUUID->
       "c3d27cd5-f4cc-40ab-a1da-d6ad0e7f9565"],
      Apply[TextCell, 
       Cell[
        BoxData[
         TagBox[
          
          GridBox[{{
            "\"A\"", "\" \"", "\"c\"", "\"o\"", "\"m\"", "\"p\"", "\"u\"", 
             "\"t\"", "\"e\"", "\"r\"", "\" \"", "\"i\"", "\"s\"", "\" \"", 
             "\"a\"", "\" \"", "\"g\"", "\"e\"", "\"n\"", "\"e\""}, {
            "\"r\"", "\"a\"", "\"l\"", "\"-\"", "\"p\"", "\"u\"", "\"r\"", 
             "\"p\"", "\"o\"", "\"s\"", "\"e\"", "\" \"", "\"d\"", "\"e\"", 
             "\"v\"", "\"i\"", "\"c\"", "\"e\"", "\" \"", "\"t\""}, {
            "\"h\"", "\"a\"", "\"t\"", "\" \"", "\"c\"", "\"a\"", "\"n\"", 
             "\" \"", "\"b\"", "\"e\"", "\" \"", "\"p\"", "\"r\"", "\"o\"", 
             "\"g\"", "\"r\"", "\"a\"", "\"m\"", "\"m\"", "\"e\""}, {
            "\"d\"", "\" \"", "\"t\"", "\"o\"", "\" \"", "\"c\"", "\"a\"", 
             "\"r\"", "\"r\"", "\"y\"", "\" \"", "\"o\"", "\"u\"", "\"t\"", 
             "\" \"", "\"a\"", "\" \"", "\"s\"", "\"e\"", "\"t\""}, {
            "\" \"", "\"o\"", "\"f\"", "\" \"", "\"a\"", "\"r\"", "\"i\"", 
             "\"t\"", "\"h\"", "\"m\"", "\"e\"", "\"t\"", "\"i\"", "\"c\"", 
             "\" \"", "\"o\"", "\"r\"", "\" \"", "\"l\"", "\"o\""}, {
            "\"g\"", "\"i\"", "\"c\"", "\"a\"", "\"l\"", "\" \"", "\"o\"", 
             "\"p\"", "\"e\"", "\"r\"", "\"a\"", "\"t\"", "\"i\"", "\"o\"", 
             "\"n\"", "\"s\"", "\" \"", "\"a\"", "\"u\"", "\"t\""}, {
            "\"o\"", "\"m\"", "\"a\"", "\"t\"", "\"i\"", "\"c\"", "\"a\"", 
             "\"l\"", "\"l\"", "\"y\"", "\".\"", "\" \"", "\"S\"", "\"i\"", 
             "\"n\"", "\"c\"", "\"e\"", "\" \"", "\"a\"", "\" \""}, {
            "\"s\"", "\"e\"", "\"q\"", "\"u\"", "\"e\"", "\"n\"", "\"c\"", 
             "\"e\"", "\" \"", "\"o\"", "\"f\"", "\" \"", "\"o\"", "\"p\"", 
             "\"e\"", "\"r\"", "\"a\"", "\"t\"", "\"i\"", "\"o\""}, {
            "\"n\"", "\"s\"", "\" \"", "\"c\"", "\"a\"", "\"n\"", "\" \"", 
             "\"b\"", "\"e\"", "\" \"", "\"r\"", "\"e\"", "\"a\"", "\"d\"", 
             "\"i\"", "\"l\"", "\"y\"", "\" \"", "\"c\"", "\"h\""}, {
            "\"a\"", "\"n\"", "\"g\"", "\"e\"", "\"d\"", "\",\"", "\" \"", 
             "\"t\"", "\"h\"", "\"e\"", "\" \"", "\"c\"", "\"o\"", "\"m\"", 
             "\"p\"", "\"u\"", "\"t\"", "\"e\"", "\"r\"", "\" \""}, {
            "\"c\"", "\"a\"", "\"n\"", "\" \"", "\"s\"", "\"o\"", "\"l\"", 
             "\"v\"", "\"e\"", "\" \"", "\"m\"", "\"o\"", "\"r\"", "\"e\"", 
             "\" \"", "\"t\"", "\"h\"", "\"a\"", "\"n\"", "\" \""}, {
            "\"o\"", "\"n\"", "\"e\"", "\" \"", "\"k\"", "\"i\"", "\"n\"", 
             "\"d\"", "\" \"", "\"o\"", "\"f\"", "\" \"", "\"p\"", "\"r\"", 
             "\"o\"", "\"b\"", "\"l\"", "\"e\"", "\"m\"", "\".\""}, {
            "\"\\n\"", "\"C\"", "\"o\"", "\"n\"", "\"v\"", "\"e\"", "\"n\"", 
             "\"t\"", "\"i\"", "\"o\"", "\"n\"", "\"a\"", "\"l\"", "\"l\"", 
             "\"y\"", "\",\"", "\" \"", "\"a\"", "\" \"", "\"c\""}, {
            "\"o\"", "\"m\"", "\"p\"", "\"u\"", "\"t\"", "\"e\"", "\"r\"", 
             "\" \"", "\"c\"", "\"o\"", "\"n\"", "\"s\"", "\"i\"", "\"s\"", 
             "\"t\"", "\"s\"", "\" \"", "\"o\"", "\"f\"", "\" \""}, {
            "\"a\"", "\"t\"", "\" \"", "\"l\"", "\"e\"", "\"a\"", "\"s\"", 
             "\"t\"", "\" \"", "\"o\"", "\"n\"", "\"e\"", "\" \"", "\"p\"", 
             "\"r\"", "\"o\"", "\"c\"", "\"e\"", "\"s\"", "\"s\""}, {
            "\"i\"", "\"n\"", "\"g\"", "\" \"", "\"e\"", "\"l\"", "\"e\"", 
             "\"m\"", "\"e\"", "\"n\"", "\"t\"", "\",\"", "\" \"", "\"t\"", 
             "\"y\"", "\"p\"", "\"i\"", "\"c\"", "\"a\"", "\"l\""}, {
            "\"l\"", "\"y\"", "\" \"", "\"a\"", "\" \"", "\"c\"", "\"e\"", 
             "\"n\"", "\"t\"", "\"r\"", "\"a\"", "\"l\"", "\" \"", "\"p\"", 
             "\"r\"", "\"o\"", "\"c\"", "\"e\"", "\"s\"", "\"s\""}, {
            "\"i\"", "\"n\"", "\"g\"", "\" \"", "\"u\"", "\"n\"", "\"i\"", 
             "\"t\"", "\" \"", "\"(\"", "\"C\"", "\"P\"", "\"U\"", "\")\"", 
             "\",\"", "\" \"", "\"a\"", "\"n\"", "\"d\"", "\" \""}, {
            "\"s\"", "\"o\"", "\"m\"", "\"e\"", "\" \"", "\"f\"", "\"o\"", 
             "\"r\"", "\"m\"", "\" \"", "\"o\"", "\"f\"", "\" \"", "\"m\"", 
             "\"e\"", "\"m\"", "\"o\"", "\"r\"", "\"y\"", "\".\""}, {
            "\" \"", "\"T\"", "\"h\"", "\"e\"", "\" \"", "\"p\"", "\"r\"", 
             "\"o\"", "\"c\"", "\"e\"", "\"s\"", "\"s\"", "\"i\"", "\"n\"", 
             "\"g\"", "\" \"", "\"e\"", "\"l\"", "\"e\"", "\"m\""}}, 
           AutoDelete -> False, 
           GridBoxFrame -> {"Columns" -> {{True}}, "Rows" -> {{True}}}, 
           GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"]], 
        "ExerciseOutput", Selectable -> False, Copyable -> False, Editable -> 
        False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"939647bd-e4d1-4815-ae33-86a28796221e"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Make a line plot of the flattened list of the digits from the numbers from \
0 to 200 (",
 StyleBox["Champernowne sequence",
  FontSlant->"Italic"],
 ").",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "30.5", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->False,
 CellTags->"i:25",ExpressionUUID->"e0ad99d4-f544-461f-9d34-2ed72d1f6f48"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       GraphicsBox[{{}, {{}, {}, {{{
             {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
              0.011111111111111112`], AbsoluteThickness[1.6], 
              LineBox[CompressedData["
1:eJxdmEkO3EQUhgtWLHvBggULYyGEEELNPJMKZCIJiZMACSQEZ4aEEGeeozpC
H8FH6CPUEfoIvgBSHwEh/3+j99Xm6fP/ld1+5aG737h46+SVl1NK/7yU0n91
Hts9KY4ct7+S4/ZFjttfxfbXsP11bG+wvcX2N7H9LXyet/15NN5B/i74PfDS
81XfR/6B2Of3IfKPxD7fj5F/Ivb5f4r8M7H78TnyL8Tuz5fIvxK7X18j/0bc
qu5R9flm8zxKRr437q/sRf5t5AJO36mqf+U75PtU1b+yD/l+VfWv7Ed+QFX9
KweQH1RV/8pB5IdU1b9yCPn3qq1ys6+Hw/bnUQ4jP6Lq/h1BfjQerxxF/kPk
Ak7HVN2/Y8iPq7p/x5F3qupf7mJezOpfRZ5OqKp/+UTMi7nVfLPvl5OqGvlk
zItZ/avI0ynP1/FPxbyY9Xkq8vRj5AwuZvWvIk8/qbp/P8W8mN0/5OlnVffv
55gXc6v5Zj9PTqtq5NMxL2b3D3k64/k6/pmYF7P7hzz9Ej9v/iXmBVzB6VdV
9+/XmBez+4c8nVV1/87GvJhbzTf7eXtOVSOfi3kxu3/I02+er+P/FvNidv+Q
p/Oq7t/5mBez+4c8/R45g4vZ/UOeelX1r+ljns3tXHuzn6dmjRF5Nat/E/J0
wfN1/Asxz2b1r0dezOrfiLya1b8JebqoqvNtLsY8g3twMat/I/JqbnV8+OmS
qkZzKebZrP71yMtuvo6PvJrVvwl5uqyq/jWXY57N6l+PvJjVvxF5NasfE/J0
JXIDzuZWxwcXs8aIvJp9/SFPVz1fx78a82z29Ye8mH39Ia9mX3/I0zVVX3/X
Yp7Nvv6QF7OvP+QVPJn9/fAPsUYDzmZff8gL8hFc4U87Vv0z+s2f0c9m9x9+
gT+atR4V/gQ/XRdrfZrr0c/Xo9+b/XyFP8KvZl//8NON6DdmX/83ot/DL+Z2
riP8Cp4wP/0V8wacwT24gEez1rcin8Dppljr29yMeQb3Zn8/Qj6Cq9n3H/L0
d+TG7Pcf8h5czFrfEXkFT2Y//27h+OBsbufaIy9mP/93PI8Kf4KfhpgvwM0Q
/SU4w++Q92at7wC/wF+Z/TyFv4ZfzVrfDfwJ/tbs7z+3o7+4Hf3GrPVdws/w
O7PWt4c/wC/mdq4r+KNZ/Vvv5s+jwt/An5BvwelO9Bdmn/+d6C/hZ3AHv0c+
mH3/wl/BH81a3zX8Cn9j1vpO8Lfw011Vre/ibvSbu9Ffmv18ht/B783tXAf4
xax+rMwaI/w1/Ip8A57gb3f7V70X/cW96Ddmnz/8DL8D9/AH5MWs9V3BH+Gv
zVrfCn8DfzJrfbfw0/3oL8z+Pno/+kv42dzOtYPfm3V+g1mjwF/BH5GvwRX+
Zrf/uU7wt/DTA1Xf/w+i3zyI/tLs84ffwe/BA/yCfGX27wn4a/jVrPXdwJ/g
b81+/z6M/uJh9BtzO9cl/GzW5+3MGj38AX5BvgKP8Ne7/c+1wt/An8xa3y38
9Cj6C7Pv/0fRX8LPZvWrg9/DH8AF/gr5aNb6ruFX+Buz1neCv4WfHqu2c108
jn5j9vvfrJHhd/B75AO4wF/t9j/XEf4afjX7/Qd/gr81+//HJ9FfPIl+Y/b9
Dz/D78zqbw9/gF/AK/gj8rXZ/y/A38CfzO1ct/DT07i/hVmjeRr9JfyMvAP3
8Ifd/uda4K/gj2Z//4Nf4W/Mfv/B38JPz1S1votn0W+eRX9p9v0Pv4Pfm7Ue
A/wCfwUe4a+RV3M71w38CfnW7PE8+ovn0W+QL8EZfmf27x/4A/xi1vqu4I/w
12Z//4O/gT+Z/f6Dn15Ef2H2/1Evor+En82+/+H38Aez/z+Ev4I/gtdmv/92
PI/N//wvBq4bIA==
               "]]}}}}}, {}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{False, False}, {False, False}},
        FrameLabel->{{None, None}, {None, None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        ImageSize->{465.4453125, Automatic},
        Method->{},
        PlotRange->{{0., 493.}, {0, 9.}},
        PlotRangeClipping->True,
        PlotRangePadding->{{
           Scaled[0.02], 
           Scaled[0.02]}, {
           Scaled[0.02], 
           Scaled[0.05]}},
        Ticks->{Automatic, Automatic}]], "ExerciseOutput",ExpressionUUID->
       "2c4a3dd3-1dc1-4b2c-898d-e461e141523c"],
      Apply[TextCell, 
       Cell[
        BoxData[
         GraphicsBox[{{}, {{}, {}, {
             RGBColor[0.368417, 0.506779, 0.709798], 
             PointSize[0.011111111111111112`], 
             AbsoluteThickness[1.6], 
             LineBox[CompressedData["
1:eJxdmEkO3EQUhgtWLHvBggULYyGEEELNPJMKZCIJiZMACSQEZ4aEEGeeozpC
H8FH6CPUEfoIvgBSHwEh/3+j99Xm6fP/ld1+5aG737h46+SVl1NK/7yU0n91
Hts9KY4ct7+S4/ZFjttfxfbXsP11bG+wvcX2N7H9LXyet/15NN5B/i74PfDS
81XfR/6B2Of3IfKPxD7fj5F/Ivb5f4r8M7H78TnyL8Tuz5fIvxK7X18j/0bc
qu5R9flm8zxKRr437q/sRf5t5AJO36mqf+U75PtU1b+yD/l+VfWv7Ed+QFX9
KweQH1RV/8pB5IdU1b9yCPn3qq1ys6+Hw/bnUQ4jP6Lq/h1BfjQerxxF/kPk
Ak7HVN2/Y8iPq7p/x5F3qupf7mJezOpfRZ5OqKp/+UTMi7nVfLPvl5OqGvlk
zItZ/avI0ynP1/FPxbyY9Xkq8vRj5AwuZvWvIk8/qbp/P8W8mN0/5OlnVffv
55gXc6v5Zj9PTqtq5NMxL2b3D3k64/k6/pmYF7P7hzz9Ej9v/iXmBVzB6VdV
9+/XmBez+4c8nVV1/87GvJhbzTf7eXtOVSOfi3kxu3/I02+er+P/FvNidv+Q
p/Oq7t/5mBez+4c8/R45g4vZ/UOeelX1r+ljns3tXHuzn6dmjRF5Nat/E/J0
wfN1/Asxz2b1r0dezOrfiLya1b8JebqoqvNtLsY8g3twMat/I/JqbnV8+OmS
qkZzKebZrP71yMtuvo6PvJrVvwl5uqyq/jWXY57N6l+PvJjVvxF5NasfE/J0
JXIDzuZWxwcXs8aIvJp9/SFPVz1fx78a82z29Ye8mH39Ia9mX3/I0zVVX3/X
Yp7Nvv6QF7OvP+QVPJn9/fAPsUYDzmZff8gL8hFc4U87Vv0z+s2f0c9m9x9+
gT+atR4V/gQ/XRdrfZrr0c/Xo9+b/XyFP8KvZl//8NON6DdmX/83ot/DL+Z2
riP8Cp4wP/0V8wacwT24gEez1rcin8Dppljr29yMeQb3Zn8/Qj6Cq9n3H/L0
d+TG7Pcf8h5czFrfEXkFT2Y//27h+OBsbufaIy9mP/93PI8Kf4KfhpgvwM0Q
/SU4w++Q92at7wC/wF+Z/TyFv4ZfzVrfDfwJ/tbs7z+3o7+4Hf3GrPVdws/w
O7PWt4c/wC/mdq4r+KNZ/Vvv5s+jwt/An5BvwelO9Bdmn/+d6C/hZ3AHv0c+
mH3/wl/BH81a3zX8Cn9j1vpO8Lfw011Vre/ibvSbu9Ffmv18ht/B783tXAf4
xax+rMwaI/w1/Ip8A57gb3f7V70X/cW96Ddmnz/8DL8D9/AH5MWs9V3BH+Gv
zVrfCn8DfzJrfbfw0/3oL8z+Pno/+kv42dzOtYPfm3V+g1mjwF/BH5GvwRX+
Zrf/uU7wt/DTA1Xf/w+i3zyI/tLs84ffwe/BA/yCfGX27wn4a/jVrPXdwJ/g
b81+/z6M/uJh9BtzO9cl/GzW5+3MGj38AX5BvgKP8Ne7/c+1wt/An8xa3y38
9Cj6C7Pv/0fRX8LPZvWrg9/DH8AF/gr5aNb6ruFX+Buz1neCv4WfHqu2c108
jn5j9vvfrJHhd/B75AO4wF/t9j/XEf4afjX7/Qd/gr81+//HJ9FfPIl+Y/b9
Dz/D78zqbw9/gF/AK/gj8rXZ/y/A38CfzO1ct/DT07i/hVmjeRr9JfyMvAP3
8Ifd/uda4K/gj2Z//4Nf4W/Mfv/B38JPz1S1votn0W+eRX9p9v0Pv4Pfm7Ue
A/wCfwUe4a+RV3M71w38CfnW7PE8+ovn0W+QL8EZfmf27x/4A/xi1vqu4I/w
12Z//4O/gT+Z/f6Dn15Ef2H2/1Evor+En82+/+H38Aez/z+Ev4I/gtdmv/92
PI/N//wvBq4bIA==
              "]]}}, {}}, AspectRatio -> 
          NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
          AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, DisplayFunction -> 
          Identity, Frame -> {{False, False}, {False, False}}, 
          FrameLabel -> {{None, None}, {None, None}}, 
          FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
          GridLines -> {None, None}, GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], ImageSize -> {465.4453125, Automatic}, 
          Method -> {}, PlotRange -> {{0., 493.}, {0, 9.}}, PlotRangeClipping -> 
          True, PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, Ticks -> {Automatic, Automatic}]], 
        "ExerciseOutput", Selectable -> False, Copyable -> False, Editable -> 
        False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"7f56db5a-6c2d-4b3a-915a-bddd8e977176"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Make 4 steps in the ",
 StyleBox["\[OpenCurlyDoubleQuote]Menger sponge\[CloseCurlyDoubleQuote]",
  FontSlant->"Italic"],
 " analog of the fractal Sierpinski pattern from the text, but with a \
\[OpenCurlyDoubleQuote]kernel\[CloseCurlyDoubleQuote] of the form ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"#", ",", "#", ",", "#"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"#", ",", "0", ",", "#"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"#", ",", "#", ",", "#"}], "}"}]}], "}"}]], "InlineCode",
  ExpressionUUID->"1b792c08-2035-4283-ba02-0166c85caf23"],
 ".",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "30.6", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"1db8ad4c-d2fe-46ad-a7ef-7b82ac1163dc"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       RowBox[{"{", 
        RowBox[{
         GraphicsBox[RasterBox[{{0}}, {{0, 0}, {1, 1}}, {0, 1}],
          Frame->Automatic,
          FrameLabel->{None, None},
          FrameTicks->{{None, None}, {None, None}},
          GridLinesStyle->Directive[
            GrayLevel[0.5, 0.4]],
          
          Method->{
           "DefaultBoundaryStyle" -> Automatic, "DefaultPlotStyle" -> 
            Automatic}], ",", 
         GraphicsBox[
          RasterBox[{{0, 0, 0}, {0, 1, 0}, {0, 0, 0}}, {{0, 0}, {3, 3}}, {0, 
           1}],
          Frame->Automatic,
          FrameLabel->{None, None},
          FrameTicks->{{None, None}, {None, None}},
          GridLinesStyle->Directive[
            GrayLevel[0.5, 0.4]],
          
          Method->{
           "DefaultBoundaryStyle" -> Automatic, "DefaultPlotStyle" -> 
            Automatic}], ",", 
         GraphicsBox[
          RasterBox[{{0, 0, 0, 0, 0, 0, 0, 0, 0}, {0, 1, 0, 0, 1, 0, 0, 1, 
           0}, {0, 0, 0, 0, 0, 0, 0, 0, 0}, {0, 0, 0, 1, 1, 1, 0, 0, 0}, {0, 
           1, 0, 1, 1, 1, 0, 1, 0}, {0, 0, 0, 1, 1, 1, 0, 0, 0}, {0, 0, 0, 0, 
           0, 0, 0, 0, 0}, {0, 1, 0, 0, 1, 0, 0, 1, 0}, {0, 0, 0, 0, 0, 0, 0, 
           0, 0}}, {{0, 0}, {9, 9}}, {0, 1}],
          Frame->Automatic,
          FrameLabel->{None, None},
          FrameTicks->{{None, None}, {None, None}},
          GridLinesStyle->Directive[
            GrayLevel[0.5, 0.4]],
          
          Method->{
           "DefaultBoundaryStyle" -> Automatic, "DefaultPlotStyle" -> 
            Automatic}], ",", 
         GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmJiYGCQhmJ8gBE3wq+PkRE7gxHMYMTGwKOLBi6Emw8BmAYipDAM
xKIL5lRkKTQvIxuI5mUsumjgQtyhMDxjGQCjewK4
           "], {{0, 0}, {27, 27}}, {
           0, 1}],
          Frame->Automatic,
          FrameLabel->{None, None},
          FrameTicks->{{None, None}, {None, None}},
          GridLinesStyle->Directive[
            GrayLevel[0.5, 0.4]],
          
          Method->{
           "DefaultBoundaryStyle" -> Automatic, "DefaultPlotStyle" -> 
            Automatic}], ",", 
         GraphicsBox[RasterBox[CompressedData["
1:eJztWFEKwzAIjbvJjrQdoRfo/f8GI+mKRqnmFSKLpCCxumfeM5Q9t/29PUop
r/rgjdDrDoxESIe+DuEcOEK4ZWC5Im02GmpQfyHRhS8ER9joPoeYEnyhJsgz
eKZVXwiOEH6GGVgGW4ZZZkoYddaNPSXLKnbdzDR1WQVDLQcR6gKwCwaEbbes
ZeERws8wA8ss3VWw8xOiQVfLnUOAIxQikTvdglqWlLFL2HIHj/AvWdbsSsFe
WoJZPl5gjl1Qy1o39pwsg80AH1t3YFzf2IOWgeWKVJ8CX0hMrjHUl0JwhOL2
O3aCofWvyJQsgy3DLDMljDrrxp6P5Q9Tgwvs
           "], {{0, 0}, {81, 81}}, {0, 
           1}],
          Frame->Automatic,
          FrameLabel->{None, None},
          FrameTicks->{{None, None}, {None, None}},
          GridLinesStyle->Directive[
            GrayLevel[0.5, 0.4]],
          
          Method->{
           "DefaultBoundaryStyle" -> Automatic, "DefaultPlotStyle" -> 
            Automatic}]}], "}"}]], "ExerciseOutput",ExpressionUUID->
       "c7020422-1510-43fb-91d2-f0a8ce8d6ce2"],
      Apply[TextCell, 
       Cell[
        BoxData[
         RowBox[{"{", 
           RowBox[{
             GraphicsBox[
              RasterBox[{{0}}, {{0, 0}, {1, 1}}, {0, 1}], Frame -> Automatic, 
              FrameLabel -> {None, None}, 
              FrameTicks -> {{None, None}, {None, None}}, GridLinesStyle -> 
              Directive[
                GrayLevel[0.5, 0.4]], 
              Method -> {
               "DefaultBoundaryStyle" -> Automatic, "DefaultPlotStyle" -> 
                Automatic}], ",", 
             GraphicsBox[
              
              RasterBox[{{0, 0, 0}, {0, 1, 0}, {0, 0, 0}}, {{0, 0}, {3, 3}}, {
               0, 1}], Frame -> Automatic, FrameLabel -> {None, None}, 
              FrameTicks -> {{None, None}, {None, None}}, GridLinesStyle -> 
              Directive[
                GrayLevel[0.5, 0.4]], 
              Method -> {
               "DefaultBoundaryStyle" -> Automatic, "DefaultPlotStyle" -> 
                Automatic}], ",", 
             GraphicsBox[
              
              RasterBox[{{0, 0, 0, 0, 0, 0, 0, 0, 0}, {0, 1, 0, 0, 1, 0, 0, 1,
                0}, {0, 0, 0, 0, 0, 0, 0, 0, 0}, {0, 0, 0, 1, 1, 1, 0, 0, 
               0}, {0, 1, 0, 1, 1, 1, 0, 1, 0}, {0, 0, 0, 1, 1, 1, 0, 0, 0}, {
               0, 0, 0, 0, 0, 0, 0, 0, 0}, {0, 1, 0, 0, 1, 0, 0, 1, 0}, {0, 0,
                0, 0, 0, 0, 0, 0, 0}}, {{0, 0}, {9, 9}}, {0, 1}], Frame -> 
              Automatic, FrameLabel -> {None, None}, 
              FrameTicks -> {{None, None}, {None, None}}, GridLinesStyle -> 
              Directive[
                GrayLevel[0.5, 0.4]], 
              Method -> {
               "DefaultBoundaryStyle" -> Automatic, "DefaultPlotStyle" -> 
                Automatic}], ",", 
             GraphicsBox[
              RasterBox[CompressedData["
1:eJxTTMoPSmJiYGCQhmJ8gBE3wq+PkRE7gxHMYMTGwKOLBi6Emw8BmAYipDAM
xKIL5lRkKTQvIxuI5mUsumjgQtyhMDxjGQCjewK4
               "], {{0, 0}, {27, 
               27}}, {0, 1}], Frame -> Automatic, FrameLabel -> {None, None}, 
              FrameTicks -> {{None, None}, {None, None}}, GridLinesStyle -> 
              Directive[
                GrayLevel[0.5, 0.4]], 
              Method -> {
               "DefaultBoundaryStyle" -> Automatic, "DefaultPlotStyle" -> 
                Automatic}], ",", 
             GraphicsBox[
              RasterBox[CompressedData["
1:eJztWFEKwzAIjbvJjrQdoRfo/f8GI+mKRqnmFSKLpCCxumfeM5Q9t/29PUop
r/rgjdDrDoxESIe+DuEcOEK4ZWC5Im02GmpQfyHRhS8ER9joPoeYEnyhJsgz
eKZVXwiOEH6GGVgGW4ZZZkoYddaNPSXLKnbdzDR1WQVDLQcR6gKwCwaEbbes
ZeERws8wA8ss3VWw8xOiQVfLnUOAIxQikTvdglqWlLFL2HIHj/AvWdbsSsFe
WoJZPl5gjl1Qy1o39pwsg80AH1t3YFzf2IOWgeWKVJ8CX0hMrjHUl0JwhOL2
O3aCofWvyJQsgy3DLDMljDrrxp6P5Q9Tgwvs
               "], {{0, 0}, {81, 81}}, {
               0, 1}], Frame -> Automatic, FrameLabel -> {None, None}, 
              FrameTicks -> {{None, None}, {None, None}}, GridLinesStyle -> 
              Directive[
                GrayLevel[0.5, 0.4]], 
              Method -> {
               "DefaultBoundaryStyle" -> Automatic, "DefaultPlotStyle" -> 
                Automatic}]}], "}"}]], "ExerciseOutput", Selectable -> False, 
        Copyable -> False, Editable -> False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"5291b86b-932a-4efe-86ef-539aad4873c2"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Find ",
 StyleBox["Pythagorean triples",
  FontSlant->"Italic"],
 " involving only integers by selecting ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{"x", ",", "y", ",", 
    RowBox[{
     ButtonBox["Sqrt",
      BaseStyle->"CodeLink"], "[", 
     RowBox[{
      RowBox[{"x", "^", "2"}], "+", 
      RowBox[{"y", "^", "2"}]}], "]"}]}], "}"}]], "InlineCode",
  ExpressionUUID->"51ce94ed-b478-4cd3-a773-d5f47ff89df6"],
 " with ",
 Cell[BoxData[
 "x"], "InlineCode",ExpressionUUID->"7d6ff494-ff63-4597-b4fd-cf24c5450e93"],
 " and ",
 Cell[BoxData[
 "y"], "InlineCode",ExpressionUUID->"d048a8f0-fe65-42bf-af5a-5aef660f97dc"],
 " up to 20.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "30.7", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->False,
 CellTags->"i:26",ExpressionUUID->"a44b2f7b-6b1d-4f9e-9a27-8ca4857bdaf7"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"3", ",", "4", ",", "5"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"4", ",", "3", ",", "5"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"5", ",", "12", ",", "13"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"6", ",", "8", ",", "10"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"8", ",", "6", ",", "10"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"8", ",", "15", ",", "17"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"9", ",", "12", ",", "15"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"12", ",", "5", ",", "13"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"12", ",", "9", ",", "15"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"12", ",", "16", ",", "20"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"15", ",", "8", ",", "17"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"15", ",", "20", ",", "25"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"16", ",", "12", ",", "20"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"20", ",", "15", ",", "25"}], "}"}]}], "}"}]], 
       "ExerciseOutput",ExpressionUUID->
       "9f70cb78-56d4-492d-b202-d584bb859236"],
      Apply[TextCell, 
       Cell[
        BoxData[
         RowBox[{"{", 
           RowBox[{
             RowBox[{"{", 
               RowBox[{"3", ",", "4", ",", "5"}], "}"}], ",", 
             RowBox[{"{", 
               RowBox[{"4", ",", "3", ",", "5"}], "}"}], ",", 
             RowBox[{"{", 
               RowBox[{"5", ",", "12", ",", "13"}], "}"}], ",", 
             RowBox[{"{", 
               RowBox[{"6", ",", "8", ",", "10"}], "}"}], ",", 
             RowBox[{"{", 
               RowBox[{"8", ",", "6", ",", "10"}], "}"}], ",", 
             RowBox[{"{", 
               RowBox[{"8", ",", "15", ",", "17"}], "}"}], ",", 
             RowBox[{"{", 
               RowBox[{"9", ",", "12", ",", "15"}], "}"}], ",", 
             RowBox[{"{", 
               RowBox[{"12", ",", "5", ",", "13"}], "}"}], ",", 
             RowBox[{"{", 
               RowBox[{"12", ",", "9", ",", "15"}], "}"}], ",", 
             RowBox[{"{", 
               RowBox[{"12", ",", "16", ",", "20"}], "}"}], ",", 
             RowBox[{"{", 
               RowBox[{"15", ",", "8", ",", "17"}], "}"}], ",", 
             RowBox[{"{", 
               RowBox[{"15", ",", "20", ",", "25"}], "}"}], ",", 
             RowBox[{"{", 
               RowBox[{"16", ",", "12", ",", "20"}], "}"}], ",", 
             RowBox[{"{", 
               RowBox[{"20", ",", "15", ",", "25"}], "}"}]}], "}"}]], 
        "ExerciseOutput", Selectable -> False, Copyable -> False, Editable -> 
        False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"d36fa6fe-b007-4382-974b-20f86067dae8"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Find the lengths of the longest sequences of identical digits in ",
 Cell[BoxData[
  RowBox[{"2", "^", "n"}]], "InlineCode",ExpressionUUID->
  "c114f4f7-3d35-4780-95f2-5aedb3d2ed7b"],
 " for ",
 Cell[BoxData[
 "n"], "InlineCode",ExpressionUUID->"a290a6c6-9cec-4ad7-9363-4ec9803b87c1"],
 " up to 100.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "30.8", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"8010156d-4d40-41b0-9d5a-3472576ad1cc"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       RowBox[{"{", 
        RowBox[{
        "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", 
         "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",",
          "1", ",", "2", ",", "1", ",", "2", ",", "2", ",", "1", ",", "1", 
         ",", "1", ",", "2", ",", "3", ",", "2", ",", "2", ",", "2", ",", "1",
          ",", "1", ",", "1", ",", "1", ",", "1", ",", "2", ",", "1", ",", 
         "1", ",", "1", ",", "1", ",", "2", ",", "3", ",", "3", ",", "4", ",",
          "3", ",", "3", ",", "3", ",", "3", ",", "2", ",", "2", ",", "1", 
         ",", "2", ",", "3", ",", "2", ",", "2", ",", "2", ",", "1", ",", "1",
          ",", "1", ",", "2", ",", "2", ",", "2", ",", "2", ",", "2", ",", 
         "2", ",", "2", ",", "2", ",", "2", ",", "1", ",", "1", ",", "1", ",",
          "1", ",", "2", ",", "2", ",", "2", ",", "3", ",", "3", ",", "3", 
         ",", "3", ",", "3", ",", "2", ",", "2", ",", "1", ",", "2", ",", "2",
          ",", "3", ",", "2", ",", "2", ",", "2", ",", "1", ",", "2", ",", 
         "2", ",", "2", ",", "2", ",", "2", ",", "2", ",", "2", ",", "2", ",",
          "2", ",", "2", ",", "2", ",", "2", ",", "2"}], "}"}]], 
       "ExerciseOutput",ExpressionUUID->
       "fdefa21f-ecac-44c9-9379-57e73e72abc1"],
      Apply[TextCell, 
       Cell[
        BoxData[
         RowBox[{"{", 
           
           RowBox[{"1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",",
              "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1",
              ",", "1", ",", "1", ",", "2", ",", "1", ",", "2", ",", "2", ",",
              "1", ",", "1", ",", "1", ",", "2", ",", "3", ",", "2", ",", "2",
              ",", "2", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",",
              "2", ",", "1", ",", "1", ",", "1", ",", "1", ",", "2", ",", "3",
              ",", "3", ",", "4", ",", "3", ",", "3", ",", "3", ",", "3", ",",
              "2", ",", "2", ",", "1", ",", "2", ",", "3", ",", "2", ",", "2",
              ",", "2", ",", "1", ",", "1", ",", "1", ",", "2", ",", "2", ",",
              "2", ",", "2", ",", "2", ",", "2", ",", "2", ",", "2", ",", "2",
              ",", "1", ",", "1", ",", "1", ",", "1", ",", "2", ",", "2", ",",
              "2", ",", "3", ",", "3", ",", "3", ",", "3", ",", "3", ",", "2",
              ",", "2", ",", "1", ",", "2", ",", "2", ",", "3", ",", "2", ",",
              "2", ",", "2", ",", "1", ",", "2", ",", "2", ",", "2", ",", "2",
              ",", "2", ",", "2", ",", "2", ",", "2", ",", "2", ",", "2", ",",
              "2", ",", "2", ",", "2"}], "}"}]], "ExerciseOutput", Selectable -> 
        False, Copyable -> False, Editable -> False, ShowCellBracket -> 
        False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"1cdf46a4-fcd2-4687-a81c-e35dac81a7ec"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Take the names of integers up to 100 and gather them into sublists \
according to their first letters.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "30.9", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"f0b66fa9-2ae4-47c8-aeed-7b5ddac8c3d2"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"\<\"one\"\>", ",", "\<\"one hundred\"\>"}], "}"}], ",", 
         RowBox[{"{", 
          
          RowBox[{"\<\"two\"\>", ",", "\<\"three\"\>", ",", "\<\"ten\"\>", 
           ",", "\<\"twelve\"\>", ",", "\<\"thirteen\"\>", 
           ",", "\<\"twenty\"\>", ",", "\<\"twenty\[Hyphen]one\"\>", 
           ",", "\<\"twenty\[Hyphen]two\"\>", 
           ",", "\<\"twenty\[Hyphen]three\"\>", 
           ",", "\<\"twenty\[Hyphen]four\"\>", 
           ",", "\<\"twenty\[Hyphen]five\"\>", 
           ",", "\<\"twenty\[Hyphen]six\"\>", 
           ",", "\<\"twenty\[Hyphen]seven\"\>", 
           ",", "\<\"twenty\[Hyphen]eight\"\>", 
           ",", "\<\"twenty\[Hyphen]nine\"\>", ",", "\<\"thirty\"\>", 
           ",", "\<\"thirty\[Hyphen]one\"\>", 
           ",", "\<\"thirty\[Hyphen]two\"\>", 
           ",", "\<\"thirty\[Hyphen]three\"\>", 
           ",", "\<\"thirty\[Hyphen]four\"\>", 
           ",", "\<\"thirty\[Hyphen]five\"\>", 
           ",", "\<\"thirty\[Hyphen]six\"\>", 
           ",", "\<\"thirty\[Hyphen]seven\"\>", 
           ",", "\<\"thirty\[Hyphen]eight\"\>", 
           ",", "\<\"thirty\[Hyphen]nine\"\>"}], "}"}], ",", 
         RowBox[{"{", 
          
          RowBox[{"\<\"four\"\>", ",", "\<\"five\"\>", 
           ",", "\<\"fourteen\"\>", ",", "\<\"fifteen\"\>", 
           ",", "\<\"forty\"\>", ",", "\<\"forty\[Hyphen]one\"\>", 
           ",", "\<\"forty\[Hyphen]two\"\>", 
           ",", "\<\"forty\[Hyphen]three\"\>", 
           ",", "\<\"forty\[Hyphen]four\"\>", 
           ",", "\<\"forty\[Hyphen]five\"\>", 
           ",", "\<\"forty\[Hyphen]six\"\>", 
           ",", "\<\"forty\[Hyphen]seven\"\>", 
           ",", "\<\"forty\[Hyphen]eight\"\>", 
           ",", "\<\"forty\[Hyphen]nine\"\>", ",", "\<\"fifty\"\>", 
           ",", "\<\"fifty\[Hyphen]one\"\>", ",", "\<\"fifty\[Hyphen]two\"\>",
            ",", "\<\"fifty\[Hyphen]three\"\>", 
           ",", "\<\"fifty\[Hyphen]four\"\>", 
           ",", "\<\"fifty\[Hyphen]five\"\>", 
           ",", "\<\"fifty\[Hyphen]six\"\>", 
           ",", "\<\"fifty\[Hyphen]seven\"\>", 
           ",", "\<\"fifty\[Hyphen]eight\"\>", 
           ",", "\<\"fifty\[Hyphen]nine\"\>"}], "}"}], ",", 
         RowBox[{"{", 
          
          RowBox[{"\<\"six\"\>", ",", "\<\"seven\"\>", ",", "\<\"sixteen\"\>",
            ",", "\<\"seventeen\"\>", ",", "\<\"sixty\"\>", 
           ",", "\<\"sixty\[Hyphen]one\"\>", ",", "\<\"sixty\[Hyphen]two\"\>",
            ",", "\<\"sixty\[Hyphen]three\"\>", 
           ",", "\<\"sixty\[Hyphen]four\"\>", 
           ",", "\<\"sixty\[Hyphen]five\"\>", 
           ",", "\<\"sixty\[Hyphen]six\"\>", 
           ",", "\<\"sixty\[Hyphen]seven\"\>", 
           ",", "\<\"sixty\[Hyphen]eight\"\>", 
           ",", "\<\"sixty\[Hyphen]nine\"\>", ",", "\<\"seventy\"\>", 
           ",", "\<\"seventy\[Hyphen]one\"\>", 
           ",", "\<\"seventy\[Hyphen]two\"\>", 
           ",", "\<\"seventy\[Hyphen]three\"\>", 
           ",", "\<\"seventy\[Hyphen]four\"\>", 
           ",", "\<\"seventy\[Hyphen]five\"\>", 
           ",", "\<\"seventy\[Hyphen]six\"\>", 
           ",", "\<\"seventy\[Hyphen]seven\"\>", 
           ",", "\<\"seventy\[Hyphen]eight\"\>", 
           ",", "\<\"seventy\[Hyphen]nine\"\>"}], "}"}], ",", 
         RowBox[{"{", 
          
          RowBox[{"\<\"eight\"\>", ",", "\<\"eleven\"\>", 
           ",", "\<\"eighteen\"\>", ",", "\<\"eighty\"\>", 
           ",", "\<\"eighty\[Hyphen]one\"\>", 
           ",", "\<\"eighty\[Hyphen]two\"\>", 
           ",", "\<\"eighty\[Hyphen]three\"\>", 
           ",", "\<\"eighty\[Hyphen]four\"\>", 
           ",", "\<\"eighty\[Hyphen]five\"\>", 
           ",", "\<\"eighty\[Hyphen]six\"\>", 
           ",", "\<\"eighty\[Hyphen]seven\"\>", 
           ",", "\<\"eighty\[Hyphen]eight\"\>", 
           ",", "\<\"eighty\[Hyphen]nine\"\>"}], "}"}], ",", 
         RowBox[{"{", 
          
          RowBox[{"\<\"nine\"\>", ",", "\<\"nineteen\"\>", 
           ",", "\<\"ninety\"\>", ",", "\<\"ninety\[Hyphen]one\"\>", 
           ",", "\<\"ninety\[Hyphen]two\"\>", 
           ",", "\<\"ninety\[Hyphen]three\"\>", 
           ",", "\<\"ninety\[Hyphen]four\"\>", 
           ",", "\<\"ninety\[Hyphen]five\"\>", 
           ",", "\<\"ninety\[Hyphen]six\"\>", 
           ",", "\<\"ninety\[Hyphen]seven\"\>", 
           ",", "\<\"ninety\[Hyphen]eight\"\>", 
           ",", "\<\"ninety\[Hyphen]nine\"\>"}], "}"}]}], "}"}]], 
       "ExerciseOutput",ExpressionUUID->
       "fe1b9bfd-979b-458f-ada9-1c656c8def6f"],
      Apply[TextCell, 
       Cell[
        BoxData[
         RowBox[{"{", 
           RowBox[{
             RowBox[{"{", 
               RowBox[{"\"one\"", ",", "\"one hundred\""}], "}"}], ",", 
             RowBox[{"{", 
               
               RowBox[{
                "\"two\"", ",", "\"three\"", ",", "\"ten\"", ",", 
                 "\"twelve\"", ",", "\"thirteen\"", ",", "\"twenty\"", ",", 
                 "\"twenty\[Hyphen]one\"", ",", "\"twenty\[Hyphen]two\"", ",",
                  "\"twenty\[Hyphen]three\"", ",", "\"twenty\[Hyphen]four\"", 
                 ",", "\"twenty\[Hyphen]five\"", ",", 
                 "\"twenty\[Hyphen]six\"", ",", "\"twenty\[Hyphen]seven\"", 
                 ",", "\"twenty\[Hyphen]eight\"", ",", 
                 "\"twenty\[Hyphen]nine\"", ",", "\"thirty\"", ",", 
                 "\"thirty\[Hyphen]one\"", ",", "\"thirty\[Hyphen]two\"", ",",
                  "\"thirty\[Hyphen]three\"", ",", "\"thirty\[Hyphen]four\"", 
                 ",", "\"thirty\[Hyphen]five\"", ",", 
                 "\"thirty\[Hyphen]six\"", ",", "\"thirty\[Hyphen]seven\"", 
                 ",", "\"thirty\[Hyphen]eight\"", ",", 
                 "\"thirty\[Hyphen]nine\""}], "}"}], ",", 
             RowBox[{"{", 
               
               RowBox[{
                "\"four\"", ",", "\"five\"", ",", "\"fourteen\"", ",", 
                 "\"fifteen\"", ",", "\"forty\"", ",", 
                 "\"forty\[Hyphen]one\"", ",", "\"forty\[Hyphen]two\"", ",", 
                 "\"forty\[Hyphen]three\"", ",", "\"forty\[Hyphen]four\"", 
                 ",", "\"forty\[Hyphen]five\"", ",", "\"forty\[Hyphen]six\"", 
                 ",", "\"forty\[Hyphen]seven\"", ",", 
                 "\"forty\[Hyphen]eight\"", ",", "\"forty\[Hyphen]nine\"", 
                 ",", "\"fifty\"", ",", "\"fifty\[Hyphen]one\"", ",", 
                 "\"fifty\[Hyphen]two\"", ",", "\"fifty\[Hyphen]three\"", ",",
                  "\"fifty\[Hyphen]four\"", ",", "\"fifty\[Hyphen]five\"", 
                 ",", "\"fifty\[Hyphen]six\"", ",", "\"fifty\[Hyphen]seven\"",
                  ",", "\"fifty\[Hyphen]eight\"", ",", 
                 "\"fifty\[Hyphen]nine\""}], "}"}], ",", 
             RowBox[{"{", 
               
               RowBox[{
                "\"six\"", ",", "\"seven\"", ",", "\"sixteen\"", ",", 
                 "\"seventeen\"", ",", "\"sixty\"", ",", 
                 "\"sixty\[Hyphen]one\"", ",", "\"sixty\[Hyphen]two\"", ",", 
                 "\"sixty\[Hyphen]three\"", ",", "\"sixty\[Hyphen]four\"", 
                 ",", "\"sixty\[Hyphen]five\"", ",", "\"sixty\[Hyphen]six\"", 
                 ",", "\"sixty\[Hyphen]seven\"", ",", 
                 "\"sixty\[Hyphen]eight\"", ",", "\"sixty\[Hyphen]nine\"", 
                 ",", "\"seventy\"", ",", "\"seventy\[Hyphen]one\"", ",", 
                 "\"seventy\[Hyphen]two\"", ",", "\"seventy\[Hyphen]three\"", 
                 ",", "\"seventy\[Hyphen]four\"", ",", 
                 "\"seventy\[Hyphen]five\"", ",", "\"seventy\[Hyphen]six\"", 
                 ",", "\"seventy\[Hyphen]seven\"", ",", 
                 "\"seventy\[Hyphen]eight\"", ",", 
                 "\"seventy\[Hyphen]nine\""}], "}"}], ",", 
             RowBox[{"{", 
               
               RowBox[{
                "\"eight\"", ",", "\"eleven\"", ",", "\"eighteen\"", ",", 
                 "\"eighty\"", ",", "\"eighty\[Hyphen]one\"", ",", 
                 "\"eighty\[Hyphen]two\"", ",", "\"eighty\[Hyphen]three\"", 
                 ",", "\"eighty\[Hyphen]four\"", ",", 
                 "\"eighty\[Hyphen]five\"", ",", "\"eighty\[Hyphen]six\"", 
                 ",", "\"eighty\[Hyphen]seven\"", ",", 
                 "\"eighty\[Hyphen]eight\"", ",", "\"eighty\[Hyphen]nine\""}],
                "}"}], ",", 
             RowBox[{"{", 
               
               RowBox[{
                "\"nine\"", ",", "\"nineteen\"", ",", "\"ninety\"", ",", 
                 "\"ninety\[Hyphen]one\"", ",", "\"ninety\[Hyphen]two\"", ",",
                  "\"ninety\[Hyphen]three\"", ",", "\"ninety\[Hyphen]four\"", 
                 ",", "\"ninety\[Hyphen]five\"", ",", 
                 "\"ninety\[Hyphen]six\"", ",", "\"ninety\[Hyphen]seven\"", 
                 ",", "\"ninety\[Hyphen]eight\"", ",", 
                 "\"ninety\[Hyphen]nine\""}], "}"}]}], "}"}]], 
        "ExerciseOutput", Selectable -> False, Copyable -> False, Editable -> 
        False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"e56dd932-ab78-445d-9f62-a4d2291b54f7"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Sort the first 50 words in ",
 Cell[BoxData[
  RowBox[{
   ButtonBox["WordList",
    BaseStyle->"CodeLink"], "[", " ", "]"}]], "InlineCode",ExpressionUUID->
  "6104a4ac-9d54-4cb2-b0af-fe7b7d29d22c"],
 " by their last letters.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "30.10", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"6daf639b-a740-410c-956c-379e35641bab"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       RowBox[{"{", 
        RowBox[{"\<\"a\"\>", ",", "\<\"abandoned\"\>", ",", "\<\"abashed\"\>",
          ",", "\<\"abbreviated\"\>", ",", "\<\"abed\"\>", 
         ",", "\<\"abalone\"\>", ",", "\<\"abase\"\>", ",", "\<\"abate\"\>", 
         ",", "\<\"abbe\"\>", ",", "\<\"abbreviate\"\>", 
         ",", "\<\"abdicate\"\>", ",", "\<\"abeyance\"\>", 
         ",", "\<\"abhorrence\"\>", ",", "\<\"abidance\"\>", 
         ",", "\<\"abide\"\>", ",", "\<\"abducting\"\>", 
         ",", "\<\"abiding\"\>", ",", "\<\"aah\"\>", ",", "\<\"abash\"\>", 
         ",", "\<\"aardvark\"\>", ",", "\<\"aback\"\>", 
         ",", "\<\"abdominal\"\>", ",", "\<\"abeam\"\>", 
         ",", "\<\"abandon\"\>", ",", "\<\"abbreviation\"\>", 
         ",", "\<\"abdication\"\>", ",", "\<\"abdomen\"\>", 
         ",", "\<\"abduction\"\>", ",", "\<\"aberration\"\>", 
         ",", "\<\"abjection\"\>", ",", "\<\"abattoir\"\>", 
         ",", "\<\"abductor\"\>", ",", "\<\"abettor\"\>", 
         ",", "\<\"abhor\"\>", ",", "\<\"abacus\"\>", ",", "\<\"abbess\"\>", 
         ",", "\<\"abaft\"\>", ",", "\<\"abandonment\"\>", 
         ",", "\<\"abasement\"\>", ",", "\<\"abashment\"\>", 
         ",", "\<\"abatement\"\>", ",", "\<\"abbot\"\>", 
         ",", "\<\"abduct\"\>", ",", "\<\"aberrant\"\>", ",", "\<\"abet\"\>", 
         ",", "\<\"abhorrent\"\>", ",", "\<\"abject\"\>", 
         ",", "\<\"abbey\"\>", ",", "\<\"ability\"\>", 
         ",", "\<\"abjectly\"\>"}], "}"}]], "ExerciseOutput",ExpressionUUID->
       "dc68e5ea-e67e-4d31-a2da-4617e7333d59"],
      Apply[TextCell, 
       Cell[
        BoxData[
         RowBox[{"{", 
           
           RowBox[{"\"a\"", ",", "\"abandoned\"", ",", "\"abashed\"", ",", 
             "\"abbreviated\"", ",", "\"abed\"", ",", "\"abalone\"", ",", 
             "\"abase\"", ",", "\"abate\"", ",", "\"abbe\"", ",", 
             "\"abbreviate\"", ",", "\"abdicate\"", ",", "\"abeyance\"", ",", 
             "\"abhorrence\"", ",", "\"abidance\"", ",", "\"abide\"", ",", 
             "\"abducting\"", ",", "\"abiding\"", ",", "\"aah\"", ",", 
             "\"abash\"", ",", "\"aardvark\"", ",", "\"aback\"", ",", 
             "\"abdominal\"", ",", "\"abeam\"", ",", "\"abandon\"", ",", 
             "\"abbreviation\"", ",", "\"abdication\"", ",", "\"abdomen\"", 
             ",", "\"abduction\"", ",", "\"aberration\"", ",", 
             "\"abjection\"", ",", "\"abattoir\"", ",", "\"abductor\"", ",", 
             "\"abettor\"", ",", "\"abhor\"", ",", "\"abacus\"", ",", 
             "\"abbess\"", ",", "\"abaft\"", ",", "\"abandonment\"", ",", 
             "\"abasement\"", ",", "\"abashment\"", ",", "\"abatement\"", ",",
              "\"abbot\"", ",", "\"abduct\"", ",", "\"aberrant\"", ",", 
             "\"abet\"", ",", "\"abhorrent\"", ",", "\"abject\"", ",", 
             "\"abbey\"", ",", "\"ability\"", ",", "\"abjectly\""}], "}"}]], 
        "ExerciseOutput", Selectable -> False, Copyable -> False, Editable -> 
        False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"690307c8-b6ba-4d94-8a4e-d61592455148"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Make a list of the first 20 squares, sorted by their first digits.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "30.11", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"ce3045c2-1b54-4600-bc2b-840759fa7ee2"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       RowBox[{"{", 
        RowBox[{
        "1", ",", "16", ",", "100", ",", "121", ",", "144", ",", "169", ",", 
         "196", ",", "25", ",", "225", ",", "256", ",", "289", ",", "36", ",",
          "324", ",", "361", ",", "4", ",", "49", ",", "400", ",", "64", ",", 
         "81", ",", "9"}], "}"}]], "ExerciseOutput",ExpressionUUID->
       "72a139b9-164c-4ae5-b444-8f3829e5d3f9"],
      Apply[TextCell, 
       Cell[
        BoxData[
         RowBox[{"{", 
           
           RowBox[{"1", ",", "16", ",", "100", ",", "121", ",", "144", ",", 
             "169", ",", "196", ",", "25", ",", "225", ",", "256", ",", "289",
              ",", "36", ",", "324", ",", "361", ",", "4", ",", "49", ",", 
             "400", ",", "64", ",", "81", ",", "9"}], "}"}]], 
        "ExerciseOutput", Selectable -> False, Copyable -> False, Editable -> 
        False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"b4e2d642-23d2-47c5-aa5a-36ff12bf15c7"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Sort integers up to 20 by the length of their names in English.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "30.12", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"820bc882-4877-4521-9b33-d37eae1e5eda"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       RowBox[{"{", 
        RowBox[{
        "1", ",", "2", ",", "6", ",", "10", ",", "4", ",", "5", ",", "9", ",",
          "3", ",", "7", ",", "8", ",", "11", ",", "12", ",", "20", ",", "15",
          ",", "16", ",", "13", ",", "14", ",", "18", ",", "19", ",", "17"}], 
        "}"}]], "ExerciseOutput",ExpressionUUID->
       "75772131-00c5-4a65-9d97-d663475a4e4d"],
      Apply[TextCell, 
       Cell[
        BoxData[
         RowBox[{"{", 
           
           RowBox[{"1", ",", "2", ",", "6", ",", "10", ",", "4", ",", "5", 
             ",", "9", ",", "3", ",", "7", ",", "8", ",", "11", ",", "12", 
             ",", "20", ",", "15", ",", "16", ",", "13", ",", "14", ",", "18",
              ",", "19", ",", "17"}], "}"}]], "ExerciseOutput", Selectable -> 
        False, Copyable -> False, Editable -> False, ShowCellBracket -> 
        False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"5f0f692e-ec66-42eb-9284-4772e9e2d385"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Get a random sample of 20 words from ",
 Cell[BoxData[
  RowBox[{
   ButtonBox["WordList",
    BaseStyle->"CodeLink"], "[", " ", "]"}]], "InlineCode",ExpressionUUID->
  "17877122-ebd1-4982-abee-407a390d199a"],
 ", and gather them into sublists by length.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "30.13", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"6168e1c7-80a5-4829-95bc-fe7289e4adf3"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Sample", " ", "expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", "\<\"paste\"\>", "}"}], ",", 
         RowBox[{"{", 
          
          RowBox[{"\<\"mistakenly\"\>", ",", "\<\"unintended\"\>", 
           ",", "\<\"victorious\"\>", ",", "\<\"watercress\"\>"}], "}"}], ",", 
         RowBox[{"{", 
          
          RowBox[{"\<\"powerful\"\>", ",", "\<\"jingoist\"\>", 
           ",", "\<\"ballpark\"\>", ",", "\<\"rapeseed\"\>", 
           ",", "\<\"dyslexia\"\>"}], "}"}], ",", 
         RowBox[{"{", "\<\"repeal\"\>", "}"}], ",", 
         RowBox[{"{", "\<\"paleontological\"\>", "}"}], ",", 
         RowBox[{"{", "\<\"encouragement\"\>", "}"}], ",", 
         RowBox[{"{", "\<\"countryside\"\>", "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"\<\"selfish\"\>", ",", "\<\"hedging\"\>"}], "}"}], ",", 
         RowBox[{"{", "\<\"barometer\"\>", "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"\<\"veil\"\>", ",", "\<\"well\"\>"}], "}"}], ",", 
         RowBox[{"{", "\<\"municipality\"\>", "}"}]}], "}"}]], 
       "ExerciseOutput",ExpressionUUID->
       "caab44b4-2311-4407-81c6-c37590ae903c"],
      Apply[TextCell, 
       Cell[
        BoxData[
         RowBox[{"{", 
           RowBox[{
             RowBox[{"{", "\"paste\"", "}"}], ",", 
             RowBox[{"{", 
               
               RowBox[{
                "\"mistakenly\"", ",", "\"unintended\"", ",", 
                 "\"victorious\"", ",", "\"watercress\""}], "}"}], ",", 
             RowBox[{"{", 
               
               RowBox[{
                "\"powerful\"", ",", "\"jingoist\"", ",", "\"ballpark\"", ",",
                  "\"rapeseed\"", ",", "\"dyslexia\""}], "}"}], ",", 
             RowBox[{"{", "\"repeal\"", "}"}], ",", 
             RowBox[{"{", "\"paleontological\"", "}"}], ",", 
             RowBox[{"{", "\"encouragement\"", "}"}], ",", 
             RowBox[{"{", "\"countryside\"", "}"}], ",", 
             RowBox[{"{", 
               RowBox[{"\"selfish\"", ",", "\"hedging\""}], "}"}], ",", 
             RowBox[{"{", "\"barometer\"", "}"}], ",", 
             RowBox[{"{", 
               RowBox[{"\"veil\"", ",", "\"well\""}], "}"}], ",", 
             RowBox[{"{", "\"municipality\"", "}"}]}], "}"}]], 
        "ExerciseOutput", Selectable -> False, Copyable -> False, Editable -> 
        False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"6a2a49de-3c9f-4628-aee4-493d7381deea"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Find letters that appear in Ukrainian but not Russian.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "30.14", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"2e45159e-7fba-40d7-a83a-7cec404c3b8f"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       RowBox[{"{", 
        RowBox[{"\<\"\:0454\"\>", ",", "\<\"\:0456\"\>", 
         ",", "\<\"\:0457\"\>", ",", "\<\"\:0491\"\>"}], "}"}]], 
       "ExerciseOutput",ExpressionUUID->
       "bcfcbad4-b022-4a2e-8513-ff11fd90be98"],
      Apply[TextCell, 
       Cell[
        BoxData[
         RowBox[{"{", 
           
           RowBox[{"\"\:0454\"", ",", "\"\:0456\"", ",", "\"\:0457\"", ",", 
             "\"\:0491\""}], "}"}]], "ExerciseOutput", Selectable -> False, 
        Copyable -> False, Editable -> False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"86e4340d-4404-4fd4-af1a-174563329b31"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Use ",
 ButtonBox["Intersection",
  BaseStyle->"Link"],
 " to find numbers that appear both among the first 100 squares and cubes.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "30.15", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"e88c73ef-3d83-450c-9ca5-09eae926203c"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       RowBox[{"{", 
        RowBox[{"1", ",", "64", ",", "729", ",", "4096"}], "}"}]], 
       "ExerciseOutput",ExpressionUUID->
       "fe820d2b-c4b6-46a9-8092-dead67886c1c"],
      Apply[TextCell, 
       Cell[
        BoxData[
         RowBox[{"{", 
           RowBox[{"1", ",", "64", ",", "729", ",", "4096"}], "}"}]], 
        "ExerciseOutput", Selectable -> False, Copyable -> False, Editable -> 
        False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"3520c54e-b565-4abe-b9c4-b636a4bc2791"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Find the list of countries that are in both NATO and the G8.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "30.16", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->False,
 CellTags->"i:27",ExpressionUUID->"dac10470-4f0c-4289-9d32-bb146550b47c"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       RowBox[{"{", 
        RowBox[{
         TemplateBox[{"\"Canada\"",RowBox[{"Entity", "[", 
             RowBox[{"\"Country\"", ",", "\"Canada\""}], "]"}],
           "\"Entity[\\\"Country\\\", \\\"Canada\\\"]\"","\"country\""},
          "Entity"], ",", 
         TemplateBox[{"\"France\"",RowBox[{"Entity", "[", 
             RowBox[{"\"Country\"", ",", "\"France\""}], "]"}],
           "\"Entity[\\\"Country\\\", \\\"France\\\"]\"","\"country\""},
          "Entity"], ",", 
         TemplateBox[{"\"Germany\"",RowBox[{"Entity", "[", 
             RowBox[{"\"Country\"", ",", "\"Germany\""}], "]"}],
           "\"Entity[\\\"Country\\\", \\\"Germany\\\"]\"","\"country\""},
          "Entity"], ",", 
         TemplateBox[{"\"Italy\"",RowBox[{"Entity", "[", 
             RowBox[{"\"Country\"", ",", "\"Italy\""}], "]"}],
           "\"Entity[\\\"Country\\\", \\\"Italy\\\"]\"","\"country\""},
          "Entity"], ",", 
         TemplateBox[{"\"United Kingdom\"",RowBox[{"Entity", "[", 
             RowBox[{"\"Country\"", ",", "\"UnitedKingdom\""}], "]"}],
           "\"Entity[\\\"Country\\\", \\\"UnitedKingdom\\\"]\"","\"country\""},
          "Entity"], ",", 
         TemplateBox[{"\"United States\"",RowBox[{"Entity", "[", 
             RowBox[{"\"Country\"", ",", "\"UnitedStates\""}], "]"}],
           "\"Entity[\\\"Country\\\", \\\"UnitedStates\\\"]\"","\"country\""},
          
          "Entity"]}], "}"}]], "ExerciseOutput",ExpressionUUID->
       "5fc9f2c3-5a71-4cc6-abc1-fab78c4950ef"],
      Apply[TextCell, 
       Cell[
        BoxData[
         RowBox[{"{", 
           RowBox[{
             TemplateBox[{"\"Canada\"", 
               RowBox[{"Entity", "[", 
                 RowBox[{"\"Country\"", ",", "\"Canada\""}], "]"}], 
               "\"Entity[\\\"Country\\\", \\\"Canada\\\"]\"", "\"country\""}, 
              "Entity"], ",", 
             TemplateBox[{"\"France\"", 
               RowBox[{"Entity", "[", 
                 RowBox[{"\"Country\"", ",", "\"France\""}], "]"}], 
               "\"Entity[\\\"Country\\\", \\\"France\\\"]\"", "\"country\""}, 
              "Entity"], ",", 
             TemplateBox[{"\"Germany\"", 
               RowBox[{"Entity", "[", 
                 RowBox[{"\"Country\"", ",", "\"Germany\""}], "]"}], 
               "\"Entity[\\\"Country\\\", \\\"Germany\\\"]\"", "\"country\""},
               "Entity"], ",", 
             TemplateBox[{"\"Italy\"", 
               RowBox[{"Entity", "[", 
                 RowBox[{"\"Country\"", ",", "\"Italy\""}], "]"}], 
               "\"Entity[\\\"Country\\\", \\\"Italy\\\"]\"", "\"country\""}, 
              "Entity"], ",", 
             TemplateBox[{"\"United Kingdom\"", 
               RowBox[{"Entity", "[", 
                 RowBox[{"\"Country\"", ",", "\"UnitedKingdom\""}], "]"}], 
               "\"Entity[\\\"Country\\\", \\\"UnitedKingdom\\\"]\"", 
               "\"country\""}, "Entity"], ",", 
             TemplateBox[{"\"United States\"", 
               RowBox[{"Entity", "[", 
                 RowBox[{"\"Country\"", ",", "\"UnitedStates\""}], "]"}], 
               "\"Entity[\\\"Country\\\", \\\"UnitedStates\\\"]\"", 
               "\"country\""}, "Entity"]}], "}"}]], "ExerciseOutput", 
        Selectable -> False, Copyable -> False, Editable -> False, 
        ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"fc4b82aa-ee36-4355-b876-385ca0d6cd1c"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Make a grid in which all possible permutations of the numbers 1 through 4 \
appear as successive columns.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "30.17", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"69fed7e7-fdc9-47c2-bcb5-3ed14ab3f8ad"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       TagBox[GridBox[{
          {"1", "1", "1", "1", "1", "1", "2", "2", "2", "2", "2", "2", "3", 
           "3", "3", "3", "3", "3", "4", "4", "4", "4", "4", "4"},
          {"2", "2", "3", "3", "4", "4", "1", "1", "3", "3", "4", "4", "1", 
           "1", "2", "2", "4", "4", "1", "1", "2", "2", "3", "3"},
          {"3", "4", "2", "4", "2", "3", "3", "4", "1", "4", "1", "3", "2", 
           "4", "1", "4", "1", "2", "2", "3", "1", "3", "1", "2"},
          {"4", "3", "4", "2", "3", "2", "4", "3", "4", "1", "3", "1", "4", 
           "2", "4", "1", "2", "1", "3", "2", "3", "1", "2", "1"}
         },
         AutoDelete->False,
         GridBoxItemSize->{
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
        "Grid"]], "ExerciseOutput",ExpressionUUID->
       "1962057c-28a2-4820-b70c-ea7720d9a111"],
      Apply[TextCell, 
       Cell[
        BoxData[
         TagBox[
          
          GridBox[{{
            "1", "1", "1", "1", "1", "1", "2", "2", "2", "2", "2", "2", "3", 
             "3", "3", "3", "3", "3", "4", "4", "4", "4", "4", "4"}, {
            "2", "2", "3", "3", "4", "4", "1", "1", "3", "3", "4", "4", "1", 
             "1", "2", "2", "4", "4", "1", "1", "2", "2", "3", "3"}, {
            "3", "4", "2", "4", "2", "3", "3", "4", "1", "4", "1", "3", "2", 
             "4", "1", "4", "1", "2", "2", "3", "1", "3", "1", "2"}, {
            "4", "3", "4", "2", "3", "2", "4", "3", "4", "1", "3", "1", "4", 
             "2", "4", "1", "2", "1", "3", "2", "3", "1", "2", "1"}}, 
           AutoDelete -> False, 
           GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"]], 
        "ExerciseOutput", Selectable -> False, Copyable -> False, Editable -> 
        False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"7fabdfad-12c8-40c2-8087-b05831cdb9bd"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Make a list of all distinct strings that can be obtained by permuting the \
characters in \[OpenCurlyDoubleQuote]hello\[CloseCurlyDoubleQuote].",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "30.18", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"70d37fc4-3ff2-454f-a43b-e062d2b61756"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       RowBox[{"{", 
        RowBox[{"\<\"ehllo\"\>", ",", "\<\"ehlol\"\>", ",", "\<\"eholl\"\>", 
         ",", "\<\"elhlo\"\>", ",", "\<\"elhol\"\>", ",", "\<\"ellho\"\>", 
         ",", "\<\"elloh\"\>", ",", "\<\"elohl\"\>", ",", "\<\"elolh\"\>", 
         ",", "\<\"eohll\"\>", ",", "\<\"eolhl\"\>", ",", "\<\"eollh\"\>", 
         ",", "\<\"hello\"\>", ",", "\<\"helol\"\>", ",", "\<\"heoll\"\>", 
         ",", "\<\"hlelo\"\>", ",", "\<\"hleol\"\>", ",", "\<\"hlleo\"\>", 
         ",", "\<\"hlloe\"\>", ",", "\<\"hloel\"\>", ",", "\<\"hlole\"\>", 
         ",", "\<\"hoell\"\>", ",", "\<\"holel\"\>", ",", "\<\"holle\"\>", 
         ",", "\<\"lehlo\"\>", ",", "\<\"lehol\"\>", ",", "\<\"lelho\"\>", 
         ",", "\<\"leloh\"\>", ",", "\<\"leohl\"\>", ",", "\<\"leolh\"\>", 
         ",", "\<\"lhelo\"\>", ",", "\<\"lheol\"\>", ",", "\<\"lhleo\"\>", 
         ",", "\<\"lhloe\"\>", ",", "\<\"lhoel\"\>", ",", "\<\"lhole\"\>", 
         ",", "\<\"lleho\"\>", ",", "\<\"lleoh\"\>", ",", "\<\"llheo\"\>", 
         ",", "\<\"llhoe\"\>", ",", "\<\"lloeh\"\>", ",", "\<\"llohe\"\>", 
         ",", "\<\"loehl\"\>", ",", "\<\"loelh\"\>", ",", "\<\"lohel\"\>", 
         ",", "\<\"lohle\"\>", ",", "\<\"loleh\"\>", ",", "\<\"lolhe\"\>", 
         ",", "\<\"oehll\"\>", ",", "\<\"oelhl\"\>", ",", "\<\"oellh\"\>", 
         ",", "\<\"ohell\"\>", ",", "\<\"ohlel\"\>", ",", "\<\"ohlle\"\>", 
         ",", "\<\"olehl\"\>", ",", "\<\"olelh\"\>", ",", "\<\"olhel\"\>", 
         ",", "\<\"olhle\"\>", ",", "\<\"olleh\"\>", ",", "\<\"ollhe\"\>"}], 
        "}"}]], "ExerciseOutput",ExpressionUUID->
       "7d812ea7-24f5-455d-a95b-f82c50923e55"],
      Apply[TextCell, 
       Cell[
        BoxData[
         RowBox[{"{", 
           
           RowBox[{"\"ehllo\"", ",", "\"ehlol\"", ",", "\"eholl\"", ",", 
             "\"elhlo\"", ",", "\"elhol\"", ",", "\"ellho\"", ",", 
             "\"elloh\"", ",", "\"elohl\"", ",", "\"elolh\"", ",", 
             "\"eohll\"", ",", "\"eolhl\"", ",", "\"eollh\"", ",", 
             "\"hello\"", ",", "\"helol\"", ",", "\"heoll\"", ",", 
             "\"hlelo\"", ",", "\"hleol\"", ",", "\"hlleo\"", ",", 
             "\"hlloe\"", ",", "\"hloel\"", ",", "\"hlole\"", ",", 
             "\"hoell\"", ",", "\"holel\"", ",", "\"holle\"", ",", 
             "\"lehlo\"", ",", "\"lehol\"", ",", "\"lelho\"", ",", 
             "\"leloh\"", ",", "\"leohl\"", ",", "\"leolh\"", ",", 
             "\"lhelo\"", ",", "\"lheol\"", ",", "\"lhleo\"", ",", 
             "\"lhloe\"", ",", "\"lhoel\"", ",", "\"lhole\"", ",", 
             "\"lleho\"", ",", "\"lleoh\"", ",", "\"llheo\"", ",", 
             "\"llhoe\"", ",", "\"lloeh\"", ",", "\"llohe\"", ",", 
             "\"loehl\"", ",", "\"loelh\"", ",", "\"lohel\"", ",", 
             "\"lohle\"", ",", "\"loleh\"", ",", "\"lolhe\"", ",", 
             "\"oehll\"", ",", "\"oelhl\"", ",", "\"oellh\"", ",", 
             "\"ohell\"", ",", "\"ohlel\"", ",", "\"ohlle\"", ",", 
             "\"olehl\"", ",", "\"olelh\"", ",", "\"olhel\"", ",", 
             "\"olhle\"", ",", "\"olleh\"", ",", "\"ollhe\""}], "}"}]], 
        "ExerciseOutput", Selectable -> False, Copyable -> False, Editable -> 
        False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"b6765e1a-f15a-4447-85d2-f6a0fa643f44"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Make an array plot of the sequence of possible 5-tuples of 0 and 1.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "30.19", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"093165f0-4d77-4f69-a1e3-2dde24f3c703"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       GraphicsBox[
        RasterBox[{{0, 0, 0, 0, 0}, {0, 0, 0, 0, 1}, {0, 0, 0, 1, 0}, {0, 0, 
         0, 1, 1}, {0, 0, 1, 0, 0}, {0, 0, 1, 0, 1}, {0, 0, 1, 1, 0}, {0, 0, 
         1, 1, 1}, {0, 1, 0, 0, 0}, {0, 1, 0, 0, 1}, {0, 1, 0, 1, 0}, {0, 1, 
         0, 1, 1}, {0, 1, 1, 0, 0}, {0, 1, 1, 0, 1}, {0, 1, 1, 1, 0}, {0, 1, 
         1, 1, 1}, {1, 0, 0, 0, 0}, {1, 0, 0, 0, 1}, {1, 0, 0, 1, 0}, {1, 0, 
         0, 1, 1}, {1, 0, 1, 0, 0}, {1, 0, 1, 0, 1}, {1, 0, 1, 1, 0}, {1, 0, 
         1, 1, 1}, {1, 1, 0, 0, 0}, {1, 1, 0, 0, 1}, {1, 1, 0, 1, 0}, {1, 1, 
         0, 1, 1}, {1, 1, 1, 0, 0}, {1, 1, 1, 0, 1}, {1, 1, 1, 1, 0}, {1, 1, 
         1, 1, 1}}, {{0, 0}, {5, 32}}, {0, 1}],
        Frame->Automatic,
        FrameLabel->{None, None},
        FrameTicks->{{None, None}, {None, None}},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        ImageSize->{72.41796875, Automatic},
        Method->{
         "DefaultBoundaryStyle" -> Automatic, "DefaultPlotStyle" -> 
          Automatic}]], "ExerciseOutput",ExpressionUUID->
       "ed69f201-2af2-49f5-95a9-8151ff7814a0"],
      Apply[TextCell, 
       Cell[
        BoxData[
         GraphicsBox[
          
          RasterBox[{{0, 0, 0, 0, 0}, {0, 0, 0, 0, 1}, {0, 0, 0, 1, 0}, {0, 0,
            0, 1, 1}, {0, 0, 1, 0, 0}, {0, 0, 1, 0, 1}, {0, 0, 1, 1, 0}, {0, 
           0, 1, 1, 1}, {0, 1, 0, 0, 0}, {0, 1, 0, 0, 1}, {0, 1, 0, 1, 0}, {0,
            1, 0, 1, 1}, {0, 1, 1, 0, 0}, {0, 1, 1, 0, 1}, {0, 1, 1, 1, 0}, {
           0, 1, 1, 1, 1}, {1, 0, 0, 0, 0}, {1, 0, 0, 0, 1}, {1, 0, 0, 1, 
           0}, {1, 0, 0, 1, 1}, {1, 0, 1, 0, 0}, {1, 0, 1, 0, 1}, {1, 0, 1, 1,
            0}, {1, 0, 1, 1, 1}, {1, 1, 0, 0, 0}, {1, 1, 0, 0, 1}, {1, 1, 0, 
           1, 0}, {1, 1, 0, 1, 1}, {1, 1, 1, 0, 0}, {1, 1, 1, 0, 1}, {1, 1, 1,
            1, 0}, {1, 1, 1, 1, 1}}, {{0, 0}, {5, 32}}, {0, 1}], Frame -> 
          Automatic, FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, GridLinesStyle -> 
          Directive[
            GrayLevel[0.5, 0.4]], ImageSize -> {72.41796875, Automatic}, 
          Method -> {
           "DefaultBoundaryStyle" -> Automatic, "DefaultPlotStyle" -> 
            Automatic}]], "ExerciseOutput", Selectable -> False, Copyable -> 
        False, Editable -> False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"1cf95e1c-3203-4e28-bbbb-e4d0db3645b7"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Generate a list of 10 random sequences of 5 letters.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "30.20", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"82b641d6-1472-4f7a-97a5-a895fa445c93"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Sample", " ", "expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       RowBox[{"{", 
        RowBox[{"\<\"ayasl\"\>", ",", "\<\"icnry\"\>", ",", "\<\"ahbaa\"\>", 
         ",", "\<\"jqkpc\"\>", ",", "\<\"orlaf\"\>", ",", "\<\"rmexo\"\>", 
         ",", "\<\"ngrfy\"\>", ",", "\<\"vwhii\"\>", ",", "\<\"wjiqn\"\>", 
         ",", "\<\"gngvk\"\>"}], "}"}]], "ExerciseOutput",ExpressionUUID->
       "e81c7ed4-60f2-45d5-a340-8cbb4afcec26"],
      Apply[TextCell, 
       Cell[
        BoxData[
         RowBox[{"{", 
           
           RowBox[{"\"ayasl\"", ",", "\"icnry\"", ",", "\"ahbaa\"", ",", 
             "\"jqkpc\"", ",", "\"orlaf\"", ",", "\"rmexo\"", ",", 
             "\"ngrfy\"", ",", "\"vwhii\"", ",", "\"wjiqn\"", ",", 
             "\"gngvk\""}], "}"}]], "ExerciseOutput", Selectable -> False, 
        Copyable -> False, Editable -> False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"11b73d93-a762-4897-bce3-693ec062de47"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Find a simpler form for ",
 Cell[BoxData[
  RowBox[{
   ButtonBox["Flatten",
    BaseStyle->"CodeLink"], "[", 
   RowBox[{
    RowBox[{
     ButtonBox["Table",
      BaseStyle->"CodeLink"], "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"i", ",", "j", ",", "k"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"k", ",", "2"}], "}"}]}], "]"}], ",", "2"}], "]"}]], 
  "InlineCode",ExpressionUUID->"83f28f1b-8ecc-4afd-8341-f3c7a77c04c6"],
 ".",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "30.21", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->False,
 CellTags->
  "LastCellOfAPage",ExpressionUUID->"1b9bcacb-716a-4a0e-8bc0-516ebe1c9c37"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "1", ",", "2"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "2", ",", "1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "2", ",", "2"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"2", ",", "1", ",", "1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"2", ",", "1", ",", "2"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"2", ",", "2", ",", "1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"2", ",", "2", ",", "2"}], "}"}]}], "}"}]], 
       "ExerciseOutput",ExpressionUUID->
       "5b9a73ac-74bf-4e92-a887-0a11ae225c58"],
      Apply[TextCell, 
       Cell[
        BoxData[
         RowBox[{"{", 
           RowBox[{
             RowBox[{"{", 
               RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", 
             RowBox[{"{", 
               RowBox[{"1", ",", "1", ",", "2"}], "}"}], ",", 
             RowBox[{"{", 
               RowBox[{"1", ",", "2", ",", "1"}], "}"}], ",", 
             RowBox[{"{", 
               RowBox[{"1", ",", "2", ",", "2"}], "}"}], ",", 
             RowBox[{"{", 
               RowBox[{"2", ",", "1", ",", "1"}], "}"}], ",", 
             RowBox[{"{", 
               RowBox[{"2", ",", "1", ",", "2"}], "}"}], ",", 
             RowBox[{"{", 
               RowBox[{"2", ",", "2", ",", "1"}], "}"}], ",", 
             RowBox[{"{", 
               RowBox[{"2", ",", "2", ",", "2"}], "}"}]}], "}"}]], 
        "ExerciseOutput", Selectable -> False, Copyable -> False, Editable -> 
        False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"cf8e51e8-8bc8-4e70-91ff-c05108a8920b"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Make an array plot from the numbers of the letters in the first 1000 \
characters in the Wikipedia article on \[OpenCurlyDoubleQuote]computers\
\[CloseCurlyDoubleQuote], with 30 letters per row.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "+30.1", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"23dd6585-f043-4d0c-be0d-d5dbacf59b26"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       GraphicsBox[RasterBox[CompressedData["
1:eJxlklGO2zAMROONRbEipYKxKS1RoECv1CPsBXr/vw6NbBZoP+TEljh8M9Sv
jz+/P95ut9sPrJ9YEtZNj1kYT3pYJetODz+NK/kKMtFay3pEXTFWGfiCg8LN
Z/V5Ctfmy2LYzWe3YRS8RWsDMihSQ1VoDDmW9FbIud6dvUjPnZckmpjehce8
B5txgbYpODp+fY/hHOgVlVhUj2vrQlyuVNBRZ8pCyv9tV0FEPsHkKZ12Yse7
TnZiiIP7E5VRWqXwcmyjBXstg+SUhv7E/SIlefdX6cnSQ/2NPLdwzBrKYkzf
bXmNMeRuesrTIgQb/jhJRYbpEa56yChqtEKT48j8hafzs3H2znIwRfVvxXVh
BnhbgGFQAwXU8Gn0wPRgRCcisCWNu5zdu/AG0cYCJmAcPpCsEoH06+PF0AqK
q3RH7/+Oby2nNrZA7Hg8I15prVKVM2g4ZiTqivXddMoJlXeU49AOCfiAABQz
3pdAaJWxJya8IwX/jDxtYzcDj2ljQz7PLApJjuPCASImdkVDkeGeX1HgTmUS
uBIQXClPlyCwDo6O+0WSEW5SXoasxuGaY2yFm+AuYpp/AffXL94=
         "], {{0, 0}, {
         30, 27}}, {0, 26}],
        Frame->Automatic,
        FrameLabel->{None, None},
        FrameTicks->{{None, None}, {None, None}},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "DefaultBoundaryStyle" -> Automatic, "DefaultPlotStyle" -> 
          Automatic}]], "ExerciseOutput",ExpressionUUID->
       "7300da2f-66b5-4f95-8985-b19c88fc7c41"],
      Apply[TextCell, 
       Cell[
        BoxData[
         GraphicsBox[
          RasterBox[CompressedData["
1:eJxlklGO2zAMROONRbEipYKxKS1RoECv1CPsBXr/vw6NbBZoP+TEljh8M9Sv
jz+/P95ut9sPrJ9YEtZNj1kYT3pYJetODz+NK/kKMtFay3pEXTFWGfiCg8LN
Z/V5Ctfmy2LYzWe3YRS8RWsDMihSQ1VoDDmW9FbIud6dvUjPnZckmpjehce8
B5txgbYpODp+fY/hHOgVlVhUj2vrQlyuVNBRZ8pCyv9tV0FEPsHkKZ12Yse7
TnZiiIP7E5VRWqXwcmyjBXstg+SUhv7E/SIlefdX6cnSQ/2NPLdwzBrKYkzf
bXmNMeRuesrTIgQb/jhJRYbpEa56yChqtEKT48j8hafzs3H2znIwRfVvxXVh
BnhbgGFQAwXU8Gn0wPRgRCcisCWNu5zdu/AG0cYCJmAcPpCsEoH06+PF0AqK
q3RH7/+Oby2nNrZA7Hg8I15prVKVM2g4ZiTqivXddMoJlXeU49AOCfiAABQz
3pdAaJWxJya8IwX/jDxtYzcDj2ljQz7PLApJjuPCASImdkVDkeGeX1HgTmUS
uBIQXClPlyCwDo6O+0WSEW5SXoasxuGaY2yFm+AuYpp/AffXL94=
           "], {{0, 0}, {
           30, 27}}, {0, 26}], Frame -> Automatic, FrameLabel -> {None, None},
           FrameTicks -> {{None, None}, {None, None}}, GridLinesStyle -> 
          Directive[
            GrayLevel[0.5, 0.4]], 
          Method -> {
           "DefaultBoundaryStyle" -> Automatic, "DefaultPlotStyle" -> 
            Automatic}]], "ExerciseOutput", Selectable -> False, Copyable -> 
        False, Editable -> False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"f65c0b09-679a-4026-a7fd-00ddb443e6d2"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Gather integers up to 30 into lists based on their values modulo 3.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "+30.2", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"6ac63e59-b9bc-4dcc-acaa-9a877685d53b"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
          "1", ",", "4", ",", "7", ",", "10", ",", "13", ",", "16", ",", "19",
            ",", "22", ",", "25", ",", "28"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
          "2", ",", "5", ",", "8", ",", "11", ",", "14", ",", "17", ",", "20",
            ",", "23", ",", "26", ",", "29"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
          "3", ",", "6", ",", "9", ",", "12", ",", "15", ",", "18", ",", "21",
            ",", "24", ",", "27", ",", "30"}], "}"}]}], "}"}]], 
       "ExerciseOutput",ExpressionUUID->
       "840d8e32-1e81-4b47-a23f-2588925aecea"],
      Apply[TextCell, 
       Cell[
        BoxData[
         RowBox[{"{", 
           RowBox[{
             RowBox[{"{", 
               
               RowBox[{
                "1", ",", "4", ",", "7", ",", "10", ",", "13", ",", "16", ",",
                  "19", ",", "22", ",", "25", ",", "28"}], "}"}], ",", 
             RowBox[{"{", 
               
               RowBox[{
                "2", ",", "5", ",", "8", ",", "11", ",", "14", ",", "17", ",",
                  "20", ",", "23", ",", "26", ",", "29"}], "}"}], ",", 
             RowBox[{"{", 
               
               RowBox[{
                "3", ",", "6", ",", "9", ",", "12", ",", "15", ",", "18", ",",
                  "21", ",", "24", ",", "27", ",", "30"}], "}"}]}], "}"}]], 
        "ExerciseOutput", Selectable -> False, Copyable -> False, Editable -> 
        False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"0e1eed3f-ec4b-4520-8742-62bdf5b9a217"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Gather the first 50 powers of 2 according to their last digits.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "+30.3", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"093fbcd6-4ffb-41c1-8206-8c5985f47306"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
          "2", ",", "32", ",", "512", ",", "8192", ",", "131072", ",", 
           "2097152", ",", "33554432", ",", "536870912", ",", "8589934592", 
           ",", "137438953472", ",", "2199023255552", ",", "35184372088832", 
           ",", "562949953421312"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
          "4", ",", "64", ",", "1024", ",", "16384", ",", "262144", ",", 
           "4194304", ",", "67108864", ",", "1073741824", ",", "17179869184", 
           ",", "274877906944", ",", "4398046511104", ",", "70368744177664", 
           ",", "1125899906842624"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
          "8", ",", "128", ",", "2048", ",", "32768", ",", "524288", ",", 
           "8388608", ",", "134217728", ",", "2147483648", ",", "34359738368",
            ",", "549755813888", ",", "8796093022208", ",", 
           "140737488355328"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
          "16", ",", "256", ",", "4096", ",", "65536", ",", "1048576", ",", 
           "16777216", ",", "268435456", ",", "4294967296", ",", 
           "68719476736", ",", "1099511627776", ",", "17592186044416", ",", 
           "281474976710656"}], "}"}]}], "}"}]], "ExerciseOutput",
       ExpressionUUID->"cf0507ad-feb5-40b7-9590-be6208eaf022"],
      Apply[TextCell, 
       Cell[
        BoxData[
         RowBox[{"{", 
           RowBox[{
             RowBox[{"{", 
               
               RowBox[{
                "2", ",", "32", ",", "512", ",", "8192", ",", "131072", ",", 
                 "2097152", ",", "33554432", ",", "536870912", ",", 
                 "8589934592", ",", "137438953472", ",", "2199023255552", ",",
                  "35184372088832", ",", "562949953421312"}], "}"}], ",", 
             RowBox[{"{", 
               
               RowBox[{
                "4", ",", "64", ",", "1024", ",", "16384", ",", "262144", ",",
                  "4194304", ",", "67108864", ",", "1073741824", ",", 
                 "17179869184", ",", "274877906944", ",", "4398046511104", 
                 ",", "70368744177664", ",", "1125899906842624"}], "}"}], ",", 
             RowBox[{"{", 
               
               RowBox[{
                "8", ",", "128", ",", "2048", ",", "32768", ",", "524288", 
                 ",", "8388608", ",", "134217728", ",", "2147483648", ",", 
                 "34359738368", ",", "549755813888", ",", "8796093022208", 
                 ",", "140737488355328"}], "}"}], ",", 
             RowBox[{"{", 
               
               RowBox[{
                "16", ",", "256", ",", "4096", ",", "65536", ",", "1048576", 
                 ",", "16777216", ",", "268435456", ",", "4294967296", ",", 
                 "68719476736", ",", "1099511627776", ",", "17592186044416", 
                 ",", "281474976710656"}], "}"}]}], "}"}]], "ExerciseOutput", 
        Selectable -> False, Copyable -> False, Editable -> False, 
        ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"635ab79f-bfdf-48ee-92da-16436d6d7b83"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Make a line plot of the result of sorting the numbers from \[Minus]10 to \
+10 by their absolute values.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "+30.4", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"ac104319-0bf3-4f5c-b5b1-72c7f79847f8"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       GraphicsBox[{{}, {{}, {}, {{{
             {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
              0.019444444444444445`], AbsoluteThickness[1.6], 
              LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQEf7BlQgQNUfD+E5nBAVScA5TMcgFAiMD6UloDS
HFB5GRgfSitAaQGovBKMD6VVoLQIVF4NxofSGjB7oPJaaPbqQGkZqLwejA+l
DWDugMobornLCEorQeWNYXwobQJzJ1TeFO5uAFL6GCM=
               "]]}}}}}, {}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{False, False}, {False, False}},
        FrameLabel->{{None, None}, {None, None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{},
        PlotRange->{{0., 21.}, {-10., 10.}},
        PlotRangeClipping->True,
        PlotRangePadding->{{
           Scaled[0.02], 
           Scaled[0.02]}, {
           Scaled[0.05], 
           Scaled[0.05]}},
        Ticks->{Automatic, Automatic}]], "ExerciseOutput",ExpressionUUID->
       "46198f47-143b-4254-8951-4030b0e721fd"],
      Apply[TextCell, 
       Cell[
        BoxData[
         GraphicsBox[{{}, {{}, {}, {
             RGBColor[0.368417, 0.506779, 0.709798], 
             PointSize[0.019444444444444445`], 
             AbsoluteThickness[1.6], 
             LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQEf7BlQgQNUfD+E5nBAVScA5TMcgFAiMD6UloDS
HFB5GRgfSitAaQGovBKMD6VVoLQIVF4NxofSGjB7oPJaaPbqQGkZqLwejA+l
DWDugMobornLCEorQeWNYXwobQJzJ1TeFO5uAFL6GCM=
              "]]}}, {}}, 
          AspectRatio -> NCache[GoldenRatio^(-1), 0.6180339887498948], 
          Axes -> {True, True}, AxesLabel -> {None, None}, 
          AxesOrigin -> {0, 0}, DisplayFunction -> Identity, 
          Frame -> {{False, False}, {False, False}}, 
          FrameLabel -> {{None, None}, {None, None}}, 
          FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
          GridLines -> {None, None}, GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], Method -> {}, 
          PlotRange -> {{0., 21.}, {-10., 10.}}, PlotRangeClipping -> True, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.05], 
             Scaled[0.05]}}, Ticks -> {Automatic, Automatic}]], 
        "ExerciseOutput", Selectable -> False, Copyable -> False, Editable -> 
        False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"1c555e6e-121c-4406-848b-98b54c35ebdc"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Make a line plot of the list of the first 200 squares, sorted by their \
first digits.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "+30.5", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"c2b304ee-be20-441d-8e53-e657d2440e68"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       GraphicsBox[{{}, {{}, {}, {{{
             {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
              0.01388888888888889], AbsoluteThickness[1.6], 
              LineBox[CompressedData["
1:eJxd1luMnHMcxvFfNnuxl5PlQsTFq5k0KhupVYet0r8xatShtapoi9mxdYrE
IdJEJPKrU95K08w6VBfh3bWo0sMWVZS+nS4GRZc6Vw3mQhMX7brRG0Gf7/+C
Jpsnn3nmmV8mafLOibXb+5d3mFnzn79/U/8Ozf1vWlDMJLvIa8iCMlyHjyVr
5HHKZDk+Qek344Ssk9OUnUO4qCw8iqcri4/hk7j/OD5ZOfgE7lHW1+JTlBNP
/u97DZOnKstP4V72T+PTlO1n8CzuP4tPV6a78RlH03+PPlPZP4HPUr89uk+Z
vI9nq0+jz1ZORc9Rv+wDfI6yGX2u+lkf4rnK0eigvtCUPZDYzlN/KPay1T6i
L6nfh122ysf056vfgV223k/oy+rXY5ct2UN/gfp12GXr/pR+nvrV2GXr+oz+
QvUPYpet43P6inrHXuH1veRFRzME7LKtjP189Y3Yy9Y5SX+x+nnYZVsV+0vU
74m9bIUv6C9Vvwi7bMOxv0z9gdjLVvySfoH6W7Ev4HX+n9lCZXKbMmC7g/fj
wl3KHI89x/suV6YZe1waYY9tlD1uYOtn/zx73D/GHicvsMdT2K5QNl9kj8fj
95XDnzinD/vYL1Kf4iDbJHb6479iTz+I7Ur1m3CQ7Qh2+vLX7Onr2Bar34+D
bDO+YU+/Auf0E9iuUt/9LXvZBrDTb8E5vX1HXq1+IQ6yjWCnn8I5ffl79noO
hLU48Fw4iJ1+zg/s6evYlqhv4yBb33729GtwTt/GtlT97B/ZL+X1Ensc7maP
6yt43zLl6Eu8D/t6EtdeZo8rG9hfq+x9hT1OXmWPuzeyx12b2PPc7NjMHg/x
fVwOv+GcPhxgf736dTjIdhg7/fyf2NOPYauq/wsnsve0+Dw5WYKrsqXY6bfh
jH0b5/TH/Cy32JewDai/EyeyZzjQ78XVAXa/cJ9+Js7YV3FOP4Rb7BuY3ynJ
HziRvfgr9+kX42qNHb97HMfnRhb7e7iP6/dyH4f7eN8N5Bbu45U44M5x7uNV
2HFhK/fxMM5x8TXu45TvY4PYuY/tfu7jcfZVHF7nPp7EGR58g/v4CG7h+jbu
8Ltwxpvcj78Tec4EnD7AfZw8xH08wT7DA9u5Hz/vLe7jEWw3Kstv87n4IA64
+TD3sackrr/Dfdy3g/u4jVt46F3u38Sd97iPD+MQe547VVx5hPt4bCf3Ze/J
uU+f4hZ9Gxu/w0u7uB9/l0/jLk5Wcx93reG+7Bn7LO4b3Kev4hZ9A9st6ou7
w9/sq93O
               "]]}}}}}, {}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{False, False}, {False, False}},
        FrameLabel->{{None, None}, {None, None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        ImageSize->{337.6328125, Automatic},
        Method->{},
        PlotRange->{{0., 200.}, {0, 40000.}},
        PlotRangeClipping->True,
        PlotRangePadding->{{
           Scaled[0.02], 
           Scaled[0.02]}, {
           Scaled[0.02], 
           Scaled[0.05]}},
        Ticks->{Automatic, Automatic}]], "ExerciseOutput",ExpressionUUID->
       "03cba048-3a36-408a-bc58-9c51c722751a"],
      Apply[TextCell, 
       Cell[
        BoxData[
         GraphicsBox[{{}, {{}, {}, {
             RGBColor[0.368417, 0.506779, 0.709798], 
             PointSize[0.01388888888888889], 
             AbsoluteThickness[1.6], 
             LineBox[CompressedData["
1:eJxd1luMnHMcxvFfNnuxl5PlQsTFq5k0KhupVYet0r8xatShtapoi9mxdYrE
IdJEJPKrU95K08w6VBfh3bWo0sMWVZS+nS4GRZc6Vw3mQhMX7brRG0Gf7/+C
Jpsnn3nmmV8mafLOibXb+5d3mFnzn79/U/8Ozf1vWlDMJLvIa8iCMlyHjyVr
5HHKZDk+Qek344Ssk9OUnUO4qCw8iqcri4/hk7j/OD5ZOfgE7lHW1+JTlBNP
/u97DZOnKstP4V72T+PTlO1n8CzuP4tPV6a78RlH03+PPlPZP4HPUr89uk+Z
vI9nq0+jz1ZORc9Rv+wDfI6yGX2u+lkf4rnK0eigvtCUPZDYzlN/KPay1T6i
L6nfh122ysf056vfgV223k/oy+rXY5ct2UN/gfp12GXr/pR+nvrV2GXr+oz+
QvUPYpet43P6inrHXuH1veRFRzME7LKtjP189Y3Yy9Y5SX+x+nnYZVsV+0vU
74m9bIUv6C9Vvwi7bMOxv0z9gdjLVvySfoH6W7Ev4HX+n9lCZXKbMmC7g/fj
wl3KHI89x/suV6YZe1waYY9tlD1uYOtn/zx73D/GHicvsMdT2K5QNl9kj8fj
95XDnzinD/vYL1Kf4iDbJHb6479iTz+I7Ur1m3CQ7Qh2+vLX7Onr2Bar34+D
bDO+YU+/Auf0E9iuUt/9LXvZBrDTb8E5vX1HXq1+IQ6yjWCnn8I5ffl79noO
hLU48Fw4iJ1+zg/s6evYlqhv4yBb33729GtwTt/GtlT97B/ZL+X1Ensc7maP
6yt43zLl6Eu8D/t6EtdeZo8rG9hfq+x9hT1OXmWPuzeyx12b2PPc7NjMHg/x
fVwOv+GcPhxgf736dTjIdhg7/fyf2NOPYauq/wsnsve0+Dw5WYKrsqXY6bfh
jH0b5/TH/Cy32JewDai/EyeyZzjQ78XVAXa/cJ9+Js7YV3FOP4Rb7BuY3ynJ
HziRvfgr9+kX42qNHb97HMfnRhb7e7iP6/dyH4f7eN8N5Bbu45U44M5x7uNV
2HFhK/fxMM5x8TXu45TvY4PYuY/tfu7jcfZVHF7nPp7EGR58g/v4CG7h+jbu
8Ltwxpvcj78Tec4EnD7AfZw8xH08wT7DA9u5Hz/vLe7jEWw3Kstv87n4IA64
+TD3sackrr/Dfdy3g/u4jVt46F3u38Sd97iPD+MQe547VVx5hPt4bCf3Ze/J
uU+f4hZ9Gxu/w0u7uB9/l0/jLk5Wcx93reG+7Bn7LO4b3Kev4hZ9A9st6ou7
w9/sq93O
              "]]}}, {}}, AspectRatio -> 
          NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
          AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, DisplayFunction -> 
          Identity, Frame -> {{False, False}, {False, False}}, 
          FrameLabel -> {{None, None}, {None, None}}, 
          FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
          GridLines -> {None, None}, GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], ImageSize -> {337.6328125, Automatic}, 
          Method -> {}, PlotRange -> {{0., 200.}, {0, 40000.}}, 
          PlotRangeClipping -> True, PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, Ticks -> {Automatic, Automatic}]], 
        "ExerciseOutput", Selectable -> False, Copyable -> False, Editable -> 
        False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"69a4f918-85bf-4646-bed2-ce842578248b"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Make a line plot of integers up to 200 sorted by the lengths of their names \
in English.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "+30.6", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"55716bfa-cc29-441c-9dc4-4c10382cfc6f"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       GraphicsBox[{{}, {{}, {}, {{{
             {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
              0.01388888888888889], AbsoluteThickness[1.6], 
              LineBox[CompressedData["
1:eJx1l0tuFTEQRS1GDBkwYMCgiRBCCCEI/29MgCT8IUAgQEi/wOMzYgteSi/F
Q5bRS2AJgPqcktoSkaKr0+Wy2+6qcr0TBz+3l4dSSr/+/v/T6e/32qRd5gG6
ih5GX6NH0B306KT5DXwMlY9jdzzrZOdbmbQ6/uSkRT6F3fGnsctn5uPSWfRc
ow/R8+hT9ALzPYbdt3wRu+Mvwc53GX4CX0Hlq9gfwddQ+TrKOaYb6H30JrqF
3mK+Dfg2Kt/B7vg12PkyvInCCU53ef4AhROc1lHioMie+z10BbvMObqvsjN/
r/Juvk5927wH7D4r4z2Hanyxj6zdfTk/55Kd33Nyfr8reRHfeRf1u33AHy57
PCduyldU/oaduOjgiBvtxNmgXWa+9GzSXjuc9X8+6ej6cNX/Bcz7Z/kj4+UD
VP6M/0vWhzOc4QKPcJWZL22zH/3hoj/c6Q8n13+F33sULgtU9v3hzvWtG7B1
aICtKwPzWXd6/alLWX94dH246m8d432tm4Xzti5m4wmuxJNxXf2+xGn9jh/c
w+ZJhs2jETYPRuYzTwb9zRv94U5/88D1d+da0Mp+q3bzw++2RGXjFR6XzTyw
edcz3nPrsRe4w26cJ+Ofcx9c37jXX3ZdOO01+qXZl/7wgN3vWOD0ifdzfRl7
gUf94ar/Pvt1fTjrD3sOVbv76GG0kxfz5yPaoxUtPmf88J9x3WI+T1rMdWjG
leY9jBvX8buZ556jeeq+zDvPxbz03Mx7921d8DuY156beR/nqt31tfudZN4/
6h59UNQx+o6uqZtRR6lbfVMH2zppHbXO1bbuWmexG7fWUePOOmwcWaeNM/u6
iGP6KOPceyni1PWdn3vEPPEeijxw/+aR95x1gPGRp7B5HPec83sPyvSVUQfo
G60T9k3WIfsY64x9kPe6fZL3sn1O3LP0XXEPr/PcOg5HH0AfFvc47D1vHx59
BH2wfYJ9adwT9InW+egzreP0oVHX6SO9N+xrvVfsQ70X7FO9N+xzvZfsg+Pe
8XfFj9A/fxRoNQ==
               "]]}}}}}, {}},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{True, True},
        AxesLabel->{None, None},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{False, False}, {False, False}},
        FrameLabel->{{None, None}, {None, None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{},
        PlotRange->{{0., 200.}, {0, 200.}},
        PlotRangeClipping->True,
        PlotRangePadding->{{
           Scaled[0.02], 
           Scaled[0.02]}, {
           Scaled[0.02], 
           Scaled[0.05]}},
        Ticks->{Automatic, Automatic}]], "ExerciseOutput",ExpressionUUID->
       "fc160e8b-b236-436e-870d-afcb48f4625b"],
      Apply[TextCell, 
       Cell[
        BoxData[
         GraphicsBox[{{}, {{}, {}, {
             RGBColor[0.368417, 0.506779, 0.709798], 
             PointSize[0.01388888888888889], 
             AbsoluteThickness[1.6], 
             LineBox[CompressedData["
1:eJx1l0tuFTEQRS1GDBkwYMCgiRBCCCEI/29MgCT8IUAgQEi/wOMzYgteSi/F
Q5bRS2AJgPqcktoSkaKr0+Wy2+6qcr0TBz+3l4dSSr/+/v/T6e/32qRd5gG6
ih5GX6NH0B306KT5DXwMlY9jdzzrZOdbmbQ6/uSkRT6F3fGnsctn5uPSWfRc
ow/R8+hT9ALzPYbdt3wRu+Mvwc53GX4CX0Hlq9gfwddQ+TrKOaYb6H30JrqF
3mK+Dfg2Kt/B7vg12PkyvInCCU53ef4AhROc1lHioMie+z10BbvMObqvsjN/
r/Juvk5927wH7D4r4z2Hanyxj6zdfTk/55Kd33Nyfr8reRHfeRf1u33AHy57
PCduyldU/oaduOjgiBvtxNmgXWa+9GzSXjuc9X8+6ej6cNX/Bcz7Z/kj4+UD
VP6M/0vWhzOc4QKPcJWZL22zH/3hoj/c6Q8n13+F33sULgtU9v3hzvWtG7B1
aICtKwPzWXd6/alLWX94dH246m8d432tm4Xzti5m4wmuxJNxXf2+xGn9jh/c
w+ZJhs2jETYPRuYzTwb9zRv94U5/88D1d+da0Mp+q3bzw++2RGXjFR6XzTyw
edcz3nPrsRe4w26cJ+Ofcx9c37jXX3ZdOO01+qXZl/7wgN3vWOD0ifdzfRl7
gUf94ar/Pvt1fTjrD3sOVbv76GG0kxfz5yPaoxUtPmf88J9x3WI+T1rMdWjG
leY9jBvX8buZ556jeeq+zDvPxbz03Mx7921d8DuY156beR/nqt31tfudZN4/
6h59UNQx+o6uqZtRR6lbfVMH2zppHbXO1bbuWmexG7fWUePOOmwcWaeNM/u6
iGP6KOPceyni1PWdn3vEPPEeijxw/+aR95x1gPGRp7B5HPec83sPyvSVUQfo
G60T9k3WIfsY64x9kPe6fZL3sn1O3LP0XXEPr/PcOg5HH0AfFvc47D1vHx59
BH2wfYJ9adwT9InW+egzreP0oVHX6SO9N+xrvVfsQ70X7FO9N+xzvZfsg+Pe
8XfFj9A/fxRoNQ==
              "]]}}, {}}, AspectRatio -> 
          NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
          AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, DisplayFunction -> 
          Identity, Frame -> {{False, False}, {False, False}}, 
          FrameLabel -> {{None, None}, {None, None}}, 
          FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
          GridLines -> {None, None}, GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], Method -> {}, 
          PlotRange -> {{0., 200.}, {0, 200.}}, PlotRangeClipping -> True, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, Ticks -> {Automatic, Automatic}]], 
        "ExerciseOutput", Selectable -> False, Copyable -> False, Editable -> 
        False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"8b8f1d72-5873-4420-9c56-4823d73f6294"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Get a random sample of 25 words from ",
 Cell[BoxData[
  RowBox[{
   ButtonBox["WordList",
    BaseStyle->"CodeLink"], "[", "]"}]], "InlineCode",ExpressionUUID->
  "5b1faf14-4335-4def-b3b5-237f55e68fc1"],
 ".",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "+30.7", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"26c9fd4d-590a-44bc-a87e-89fe09409464"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       RowBox[{"{", 
        RowBox[{"\<\"autopsy\"\>", ",", "\<\"reclassification\"\>", 
         ",", "\<\"advancement\"\>", ",", "\<\"forswear\"\>", 
         ",", "\<\"swimwear\"\>", ",", "\<\"cravat\"\>", 
         ",", "\<\"cyclone\"\>", ",", "\<\"taps\"\>", 
         ",", "\<\"diplomatic\"\>", ",", "\<\"effacement\"\>", 
         ",", "\<\"peaked\"\>", ",", "\<\"ponderously\"\>", 
         ",", "\<\"publication\"\>", ",", "\<\"immune\"\>", 
         ",", "\<\"outstay\"\>", ",", "\<\"petrol\"\>", ",", "\<\"deaf\"\>", 
         ",", "\<\"bilk\"\>", ",", "\<\"oddments\"\>", 
         ",", "\<\"scoreboard\"\>", ",", "\<\"lifeless\"\>", 
         ",", "\<\"debriefing\"\>", ",", "\<\"radiogram\"\>", 
         ",", "\<\"doting\"\>", ",", "\<\"inter\"\>"}], "}"}]], 
       "ExerciseOutput",ExpressionUUID->
       "bf44dd4b-8fb6-474f-a325-80e1188b75f7"],
      Apply[TextCell, 
       Cell[
        BoxData[
         RowBox[{"{", 
           
           RowBox[{"\"autopsy\"", ",", "\"reclassification\"", ",", 
             "\"advancement\"", ",", "\"forswear\"", ",", "\"swimwear\"", ",",
              "\"cravat\"", ",", "\"cyclone\"", ",", "\"taps\"", ",", 
             "\"diplomatic\"", ",", "\"effacement\"", ",", "\"peaked\"", ",", 
             "\"ponderously\"", ",", "\"publication\"", ",", "\"immune\"", 
             ",", "\"outstay\"", ",", "\"petrol\"", ",", "\"deaf\"", ",", 
             "\"bilk\"", ",", "\"oddments\"", ",", "\"scoreboard\"", ",", 
             "\"lifeless\"", ",", "\"debriefing\"", ",", "\"radiogram\"", ",",
              "\"doting\"", ",", "\"inter\""}], "}"}]], "ExerciseOutput", 
        Selectable -> False, Copyable -> False, Editable -> False, 
        ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"21ea5991-71df-4874-9591-3d4f6d5e1bde"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Riffle periods into the string \[OpenCurlyDoubleQuote]UNCLE\
\[CloseCurlyDoubleQuote] to make \[OpenCurlyDoubleQuote]U.N.C.L.E.\
\[CloseCurlyDoubleQuote].",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "+30.8", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"355f2f02-862e-44ff-8fc1-33f129d01ae6"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[
      BoxData["\<\"U.N.C.L.E.\"\>"], "ExerciseOutput",ExpressionUUID->
       "8dfcbe1a-1d15-40ae-b691-578c686ec42e"],
      Apply[TextCell, 
       Cell[
        BoxData["\"U.N.C.L.E.\""], "ExerciseOutput", Selectable -> False, 
        Copyable -> False, Editable -> False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"9c8a7be7-c464-4c17-93a8-f0acbb82c875"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Find letters that appear in Swedish or Polish but not English.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "+30.9", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"5f23e6df-23d6-4652-89b8-e1c1f06dd36d"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       RowBox[{"{", 
        RowBox[{"\<\"\:0105\"\>", ",", "\<\"\:0119\"\>", 
         ",", "\<\"\:0144\"\>", ",", "\<\"\:015b\"\>", ",", "\<\"\:017a\"\>", 
         ",", "\<\"\:017c\"\>", ",", "\<\"\[ARing]\"\>", 
         ",", "\<\"\[ADoubleDot]\"\>", ",", "\<\"\[CAcute]\"\>", 
         ",", "\<\"\[LSlash]\"\>", ",", "\<\"\[OAcute]\"\>", 
         ",", "\<\"\[ODoubleDot]\"\>"}], "}"}]], "ExerciseOutput",
       ExpressionUUID->"2e2afb27-37f9-4255-9de5-511a2e576ef5"],
      Apply[TextCell, 
       Cell[
        BoxData[
         RowBox[{"{", 
           
           RowBox[{"\"\:0105\"", ",", "\"\:0119\"", ",", "\"\:0144\"", ",", 
             "\"\:015b\"", ",", "\"\:017a\"", ",", "\"\:017c\"", ",", 
             "\"\[ARing]\"", ",", "\"\[ADoubleDot]\"", ",", "\"\[CAcute]\"", 
             ",", "\"\[LSlash]\"", ",", "\"\[OAcute]\"", ",", 
             "\"\[ODoubleDot]\""}], "}"}]], "ExerciseOutput", Selectable -> 
        False, Copyable -> False, Editable -> False, ShowCellBracket -> 
        False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"5f632437-2f1e-44ba-8e3c-634842d9f311"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Find countries that are in the World Health Organization but not the United \
Nations.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "+30.10", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"cdbcb782-040a-44ca-b7c5-eb5101dd3238"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       RowBox[{"{", 
        RowBox[{
         TemplateBox[{"\"Cook Islands\"",RowBox[{"Entity", "[", 
             RowBox[{"\"Country\"", ",", "\"CookIslands\""}], "]"}],
           "\"Entity[\\\"Country\\\", \\\"CookIslands\\\"]\"","\"country\""},
          "Entity"], ",", 
         TemplateBox[{"\"Niue\"",RowBox[{"Entity", "[", 
             RowBox[{"\"Country\"", ",", "\"Niue\""}], "]"}],
           "\"Entity[\\\"Country\\\", \\\"Niue\\\"]\"","\"country\""},
          "Entity"]}], "}"}]], "ExerciseOutput",ExpressionUUID->
       "343fad7e-4ec0-4d50-b2e1-a365e4347e2e"],
      Apply[TextCell, 
       Cell[
        BoxData[
         RowBox[{"{", 
           RowBox[{
             TemplateBox[{"\"Cook Islands\"", 
               RowBox[{"Entity", "[", 
                 RowBox[{"\"Country\"", ",", "\"CookIslands\""}], "]"}], 
               "\"Entity[\\\"Country\\\", \\\"CookIslands\\\"]\"", 
               "\"country\""}, "Entity"], ",", 
             TemplateBox[{"\"Niue\"", 
               RowBox[{"Entity", "[", 
                 RowBox[{"\"Country\"", ",", "\"Niue\""}], "]"}], 
               "\"Entity[\\\"Country\\\", \\\"Niue\\\"]\"", "\"country\""}, 
              "Entity"]}], "}"}]], "ExerciseOutput", Selectable -> False, 
        Copyable -> False, Editable -> False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"82756bef-263c-4ecb-9e5f-a8e5f454647b"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Make a list of all pair-wise blends of red, green and blue.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "+30.11", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"8f5e4edf-2d34-4d5d-867d-fcd181902929"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       RowBox[{"{", 
        RowBox[{
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{{{{
                 {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                 {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                 {RGBColor[1, 0, 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
             AspectRatio->1,
             Frame->True,
             FrameStyle->RGBColor[0.6666666666666666, 0., 0.],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            "RGBColor[1, 0, 0]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[1, 0, 0]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[1, 0, 0],
          Editable->False,
          Selectable->False], ",", 
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{{{{
                 {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                 {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                 {RGBColor[
                   Rational[1, 2], 
                   Rational[1, 2], 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
             AspectRatio->1,
             Frame->True,
             FrameStyle->RGBColor[0.3333333333333333, 0.3333333333333333, 0.],
             
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            "RGBColor[1/2, 1/2, 0]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[
                 Rational[1, 2], 
                 Rational[1, 2], 0]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
           Rational[1, 2], 
           Rational[1, 2], 0],
          Editable->False,
          Selectable->False], ",", 
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{{{{
                 {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                 {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                 {RGBColor[
                   Rational[1, 2], 0, 
                   Rational[1, 2]], RectangleBox[{0, -1}, {2, 1}]}}}}},
             AspectRatio->1,
             Frame->True,
             FrameStyle->RGBColor[0.3333333333333333, 0., 0.3333333333333333],
             
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            "RGBColor[1/2, 0, 1/2]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[
                 Rational[1, 2], 0, 
                 Rational[1, 2]]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
           Rational[1, 2], 0, 
           Rational[1, 2]],
          Editable->False,
          Selectable->False], ",", 
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{{{{
                 {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                 {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                 {RGBColor[
                   Rational[1, 2], 
                   Rational[1, 2], 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
             AspectRatio->1,
             Frame->True,
             FrameStyle->RGBColor[0.3333333333333333, 0.3333333333333333, 0.],
             
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            "RGBColor[1/2, 1/2, 0]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[
                 Rational[1, 2], 
                 Rational[1, 2], 0]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
           Rational[1, 2], 
           Rational[1, 2], 0],
          Editable->False,
          Selectable->False], ",", 
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{{{{
                 {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                 {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                 {RGBColor[0, 1, 0], RectangleBox[{0, -1}, {2, 1}]}}}}},
             AspectRatio->1,
             Frame->True,
             FrameStyle->RGBColor[0., 0.6666666666666666, 0.],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            "RGBColor[0, 1, 0]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0, 1, 0]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[0, 1, 0],
          Editable->False,
          Selectable->False], ",", 
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{{{{
                 {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                 {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                 {RGBColor[0, 
                   Rational[1, 2], 
                   Rational[1, 2]], RectangleBox[{0, -1}, {2, 1}]}}}}},
             AspectRatio->1,
             Frame->True,
             FrameStyle->RGBColor[0., 0.3333333333333333, 0.3333333333333333],
             
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            "RGBColor[0, 1/2, 1/2]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0, 
                 Rational[1, 2], 
                 Rational[1, 2]]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[0, 
           Rational[1, 2], 
           Rational[1, 2]],
          Editable->False,
          Selectable->False], ",", 
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{{{{
                 {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                 {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                 {RGBColor[
                   Rational[1, 2], 0, 
                   Rational[1, 2]], RectangleBox[{0, -1}, {2, 1}]}}}}},
             AspectRatio->1,
             Frame->True,
             FrameStyle->RGBColor[0.3333333333333333, 0., 0.3333333333333333],
             
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            "RGBColor[1/2, 0, 1/2]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[
                 Rational[1, 2], 0, 
                 Rational[1, 2]]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[
           Rational[1, 2], 0, 
           Rational[1, 2]],
          Editable->False,
          Selectable->False], ",", 
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{{{{
                 {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                 {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                 {RGBColor[0, 
                   Rational[1, 2], 
                   Rational[1, 2]], RectangleBox[{0, -1}, {2, 1}]}}}}},
             AspectRatio->1,
             Frame->True,
             FrameStyle->RGBColor[0., 0.3333333333333333, 0.3333333333333333],
             
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            "RGBColor[0, 1/2, 1/2]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0, 
                 Rational[1, 2], 
                 Rational[1, 2]]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[0, 
           Rational[1, 2], 
           Rational[1, 2]],
          Editable->False,
          Selectable->False], ",", 
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{{{{
                 {GrayLevel[0], RectangleBox[{0, 0}]}}}}, {{{
                 {GrayLevel[0], RectangleBox[{1, -1}]}}}}, {{{
                 {RGBColor[0, 0, 1], RectangleBox[{0, -1}, {2, 1}]}}}}},
             AspectRatio->1,
             Frame->True,
             FrameStyle->RGBColor[0., 0., 0.6666666666666666],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            "RGBColor[0, 0, 1]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0, 0, 1]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[0, 0, 1],
          Editable->False,
          Selectable->False]}], "}"}]], "ExerciseOutput",ExpressionUUID->
       "9460ea53-783b-4f76-9fe4-15aa836cc154"],
      Apply[TextCell, 
       Cell[
        BoxData[
         RowBox[{"{", 
           RowBox[{
             InterpretationBox[
              ButtonBox[
               TooltipBox[
                GraphicsBox[{{
                   GrayLevel[0], 
                   RectangleBox[{0, 0}]}, {
                   GrayLevel[0], 
                   RectangleBox[{1, -1}]}, {
                   RGBColor[1, 0, 0], 
                   RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                 True, FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                 FrameTicks -> None, ImageSize -> 
                 Dynamic[{
                   Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                "RGBColor[1, 0, 0]"], Appearance -> None, BaseStyle -> {}, 
               BaselinePosition -> Baseline, ButtonFunction :> 
               With[{Typeset`box$ = EvaluationBox[]}, 
                 If[
                  Not[
                   AbsoluteCurrentValue["Deployed"]], 
                  SelectionMove[Typeset`box$, All, Expression]; 
                  FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                  FrontEnd`Private`$ColorSelectorInitialColor = 
                   RGBColor[1, 0, 0]; 
                  FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                  MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
               Automatic, Method -> "Preemptive"], 
              RGBColor[1, 0, 0], Editable -> False, Selectable -> False], ",", 
             InterpretationBox[
              ButtonBox[
               TooltipBox[
                GraphicsBox[{{
                   GrayLevel[0], 
                   RectangleBox[{0, 0}]}, {
                   GrayLevel[0], 
                   RectangleBox[{1, -1}]}, {
                   RGBColor[
                    Rational[1, 2], 
                    Rational[1, 2], 0], 
                   RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                 True, FrameStyle -> 
                 RGBColor[0.3333333333333333, 0.3333333333333333, 0.], 
                 FrameTicks -> None, ImageSize -> 
                 Dynamic[{
                   Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                "RGBColor[1/2, 1/2, 0]"], Appearance -> None, BaseStyle -> {},
                BaselinePosition -> Baseline, ButtonFunction :> 
               With[{Typeset`box$ = EvaluationBox[]}, 
                 If[
                  Not[
                   AbsoluteCurrentValue["Deployed"]], 
                  SelectionMove[Typeset`box$, All, Expression]; 
                  FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                  FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[
                    Rational[1, 2], 
                    Rational[1, 2], 0]; 
                  FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                  MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
               Automatic, Method -> "Preemptive"], 
              RGBColor[
               Rational[1, 2], 
               Rational[1, 2], 0], Editable -> False, Selectable -> False], 
             ",", 
             InterpretationBox[
              ButtonBox[
               TooltipBox[
                GraphicsBox[{{
                   GrayLevel[0], 
                   RectangleBox[{0, 0}]}, {
                   GrayLevel[0], 
                   RectangleBox[{1, -1}]}, {
                   RGBColor[
                    Rational[1, 2], 0, 
                    Rational[1, 2]], 
                   RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                 True, FrameStyle -> 
                 RGBColor[0.3333333333333333, 0., 0.3333333333333333], 
                 FrameTicks -> None, ImageSize -> 
                 Dynamic[{
                   Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                "RGBColor[1/2, 0, 1/2]"], Appearance -> None, BaseStyle -> {},
                BaselinePosition -> Baseline, ButtonFunction :> 
               With[{Typeset`box$ = EvaluationBox[]}, 
                 If[
                  Not[
                   AbsoluteCurrentValue["Deployed"]], 
                  SelectionMove[Typeset`box$, All, Expression]; 
                  FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                  FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[
                    Rational[1, 2], 0, 
                    Rational[1, 2]]; 
                  FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                  MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
               Automatic, Method -> "Preemptive"], 
              RGBColor[
               Rational[1, 2], 0, 
               Rational[1, 2]], Editable -> False, Selectable -> False], ",", 
             
             InterpretationBox[
              ButtonBox[
               TooltipBox[
                GraphicsBox[{{
                   GrayLevel[0], 
                   RectangleBox[{0, 0}]}, {
                   GrayLevel[0], 
                   RectangleBox[{1, -1}]}, {
                   RGBColor[
                    Rational[1, 2], 
                    Rational[1, 2], 0], 
                   RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                 True, FrameStyle -> 
                 RGBColor[0.3333333333333333, 0.3333333333333333, 0.], 
                 FrameTicks -> None, ImageSize -> 
                 Dynamic[{
                   Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                "RGBColor[1/2, 1/2, 0]"], Appearance -> None, BaseStyle -> {},
                BaselinePosition -> Baseline, ButtonFunction :> 
               With[{Typeset`box$ = EvaluationBox[]}, 
                 If[
                  Not[
                   AbsoluteCurrentValue["Deployed"]], 
                  SelectionMove[Typeset`box$, All, Expression]; 
                  FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                  FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[
                    Rational[1, 2], 
                    Rational[1, 2], 0]; 
                  FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                  MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
               Automatic, Method -> "Preemptive"], 
              RGBColor[
               Rational[1, 2], 
               Rational[1, 2], 0], Editable -> False, Selectable -> False], 
             ",", 
             InterpretationBox[
              ButtonBox[
               TooltipBox[
                GraphicsBox[{{
                   GrayLevel[0], 
                   RectangleBox[{0, 0}]}, {
                   GrayLevel[0], 
                   RectangleBox[{1, -1}]}, {
                   RGBColor[0, 1, 0], 
                   RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                 True, FrameStyle -> RGBColor[0., 0.6666666666666666, 0.], 
                 FrameTicks -> None, ImageSize -> 
                 Dynamic[{
                   Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                "RGBColor[0, 1, 0]"], Appearance -> None, BaseStyle -> {}, 
               BaselinePosition -> Baseline, ButtonFunction :> 
               With[{Typeset`box$ = EvaluationBox[]}, 
                 If[
                  Not[
                   AbsoluteCurrentValue["Deployed"]], 
                  SelectionMove[Typeset`box$, All, Expression]; 
                  FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                  FrontEnd`Private`$ColorSelectorInitialColor = 
                   RGBColor[0, 1, 0]; 
                  FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                  MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
               Automatic, Method -> "Preemptive"], 
              RGBColor[0, 1, 0], Editable -> False, Selectable -> False], ",", 
             InterpretationBox[
              ButtonBox[
               TooltipBox[
                GraphicsBox[{{
                   GrayLevel[0], 
                   RectangleBox[{0, 0}]}, {
                   GrayLevel[0], 
                   RectangleBox[{1, -1}]}, {
                   RGBColor[0, 
                    Rational[1, 2], 
                    Rational[1, 2]], 
                   RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                 True, FrameStyle -> 
                 RGBColor[0., 0.3333333333333333, 0.3333333333333333], 
                 FrameTicks -> None, ImageSize -> 
                 Dynamic[{
                   Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                "RGBColor[0, 1/2, 1/2]"], Appearance -> None, BaseStyle -> {},
                BaselinePosition -> Baseline, ButtonFunction :> 
               With[{Typeset`box$ = EvaluationBox[]}, 
                 If[
                  Not[
                   AbsoluteCurrentValue["Deployed"]], 
                  SelectionMove[Typeset`box$, All, Expression]; 
                  FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                  FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0, 
                    Rational[1, 2], 
                    Rational[1, 2]]; 
                  FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                  MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
               Automatic, Method -> "Preemptive"], 
              RGBColor[0, 
               Rational[1, 2], 
               Rational[1, 2]], Editable -> False, Selectable -> False], ",", 
             
             InterpretationBox[
              ButtonBox[
               TooltipBox[
                GraphicsBox[{{
                   GrayLevel[0], 
                   RectangleBox[{0, 0}]}, {
                   GrayLevel[0], 
                   RectangleBox[{1, -1}]}, {
                   RGBColor[
                    Rational[1, 2], 0, 
                    Rational[1, 2]], 
                   RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                 True, FrameStyle -> 
                 RGBColor[0.3333333333333333, 0., 0.3333333333333333], 
                 FrameTicks -> None, ImageSize -> 
                 Dynamic[{
                   Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                "RGBColor[1/2, 0, 1/2]"], Appearance -> None, BaseStyle -> {},
                BaselinePosition -> Baseline, ButtonFunction :> 
               With[{Typeset`box$ = EvaluationBox[]}, 
                 If[
                  Not[
                   AbsoluteCurrentValue["Deployed"]], 
                  SelectionMove[Typeset`box$, All, Expression]; 
                  FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                  FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[
                    Rational[1, 2], 0, 
                    Rational[1, 2]]; 
                  FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                  MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
               Automatic, Method -> "Preemptive"], 
              RGBColor[
               Rational[1, 2], 0, 
               Rational[1, 2]], Editable -> False, Selectable -> False], ",", 
             
             InterpretationBox[
              ButtonBox[
               TooltipBox[
                GraphicsBox[{{
                   GrayLevel[0], 
                   RectangleBox[{0, 0}]}, {
                   GrayLevel[0], 
                   RectangleBox[{1, -1}]}, {
                   RGBColor[0, 
                    Rational[1, 2], 
                    Rational[1, 2]], 
                   RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                 True, FrameStyle -> 
                 RGBColor[0., 0.3333333333333333, 0.3333333333333333], 
                 FrameTicks -> None, ImageSize -> 
                 Dynamic[{
                   Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                "RGBColor[0, 1/2, 1/2]"], Appearance -> None, BaseStyle -> {},
                BaselinePosition -> Baseline, ButtonFunction :> 
               With[{Typeset`box$ = EvaluationBox[]}, 
                 If[
                  Not[
                   AbsoluteCurrentValue["Deployed"]], 
                  SelectionMove[Typeset`box$, All, Expression]; 
                  FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                  FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0, 
                    Rational[1, 2], 
                    Rational[1, 2]]; 
                  FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                  MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
               Automatic, Method -> "Preemptive"], 
              RGBColor[0, 
               Rational[1, 2], 
               Rational[1, 2]], Editable -> False, Selectable -> False], ",", 
             
             InterpretationBox[
              ButtonBox[
               TooltipBox[
                GraphicsBox[{{
                   GrayLevel[0], 
                   RectangleBox[{0, 0}]}, {
                   GrayLevel[0], 
                   RectangleBox[{1, -1}]}, {
                   RGBColor[0, 0, 1], 
                   RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                 True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                 FrameTicks -> None, ImageSize -> 
                 Dynamic[{
                   Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRangePadding -> None], 
                "RGBColor[0, 0, 1]"], Appearance -> None, BaseStyle -> {}, 
               BaselinePosition -> Baseline, ButtonFunction :> 
               With[{Typeset`box$ = EvaluationBox[]}, 
                 If[
                  Not[
                   AbsoluteCurrentValue["Deployed"]], 
                  SelectionMove[Typeset`box$, All, Expression]; 
                  FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                  FrontEnd`Private`$ColorSelectorInitialColor = 
                   RGBColor[0, 0, 1]; 
                  FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                  MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], DefaultBaseStyle -> {}, Evaluator -> 
               Automatic, Method -> "Preemptive"], 
              RGBColor[0, 0, 1], Editable -> False, Selectable -> False]}], 
           "}"}]], "ExerciseOutput", Selectable -> False, Copyable -> False, 
        Editable -> False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"2e4a7c97-8c54-4609-ad28-d367606c30d4"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Make a list of array plots, each 50 rows high and with image size 50, of \
successive possible 8-tuples of 0 and 1.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "+30.12", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"d511fba6-6114-4b03-9643-f0464f4428e4"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       RowBox[{"{", 
        RowBox[{
         GraphicsBox[RasterBox[CompressedData["
1:eJxdj8sRgCAQQ/M82YYtWIol0AD930QI4OSws5+QD1epTzkk3a3OVvAVs/dR
444MtebdOMYxjnHzMX9LrydjN3/XAvssG8uGspETykl83mL/DxCBiYBEICIA
YUgYEIKEAEEgHhCHObzRVwLu
           "], {{0, 0}, {8, 50}}, {0, 1}],
          Frame->Automatic,
          FrameLabel->{None, None},
          FrameTicks->{{None, None}, {None, None}},
          GridLinesStyle->Directive[
            GrayLevel[0.5, 0.4]],
          ImageSize->50,
          
          Method->{
           "DefaultBoundaryStyle" -> Automatic, "DefaultPlotStyle" -> 
            Automatic}], ",", 
         GraphicsBox[RasterBox[CompressedData["
1:eJxVkMENgDAMA21erMEKjMIIXYD9f1TtOS2CKFjEvrRXe592SLp7nb3cX7u6
ZzearzE3OtroTPLfilOVoJ8DXc/U+I0/LviGb/hrOisvtPcU+IZv+N7YGVIN
h8rxJ11sQZhqq4Rrh2RLorip/a7rFFkq5Q+1UwK8
           "], {{0, 0}, {8, 50}}, {0,
            1}],
          Frame->Automatic,
          FrameLabel->{None, None},
          FrameTicks->{{None, None}, {None, None}},
          GridLinesStyle->Directive[
            GrayLevel[0.5, 0.4]],
          ImageSize->50,
          
          Method->{
           "DefaultBoundaryStyle" -> Automatic, "DefaultPlotStyle" -> 
            Automatic}], ",", 
         GraphicsBox[RasterBox[CompressedData["
1:eJxNkcERgzAMBPfyShtpIaWkBBpI/78QvIc1oJHxCp3Ofh3fz/EA3mc8zyDh
/5j70uXK8vTj4leVkFlE5JFHnjZZPP6vfsXtLIgbSVdL3uQwzKGIXCs4UrVH
1ATDDDoaR3Fbym7NKA3zENib9cj2Wk2y476B/ACzhQKs
           "], {{0, 0}, {8, 
           50}}, {0, 1}],
          Frame->Automatic,
          FrameLabel->{None, None},
          FrameTicks->{{None, None}, {None, None}},
          GridLinesStyle->Directive[
            GrayLevel[0.5, 0.4]],
          ImageSize->50,
          
          Method->{
           "DefaultBoundaryStyle" -> Automatic, "DefaultPlotStyle" -> 
            Automatic}], ",", 
         GraphicsBox[RasterBox[CompressedData["
1:eJxVkNsVgDAIQxO/XMMVHMURXMD9/3z0pmB7gENDCGU7r+NcJO2PrXqP7Yoe
0eQeucENbvCUfjDeJHBGq2lprZJQp7g5WVEEh98mTccou5MnoxAuOHz067XE
U6WqZiFmEWzv16WGdvurSnta1LIq35i5Apo=
           "], {{0, 0}, {8, 50}}, {0, 1}],
          Frame->Automatic,
          FrameLabel->{None, None},
          FrameTicks->{{None, None}, {None, None}},
          GridLinesStyle->Directive[
            GrayLevel[0.5, 0.4]],
          ImageSize->50,
          
          Method->{
           "DefaultBoundaryStyle" -> Automatic, "DefaultPlotStyle" -> 
            Automatic}], ",", 
         GraphicsBox[RasterBox[CompressedData["
1:eJxVj8sNwDAIQ3FPXaMrdJSOkAW6/61R8wwhEgrC+MM13mccEXHPOoMn+f8b
eUwrJmKx1sEZaDUb3WVZ8JQDty38kg81G/hlB+5YMiWvUIthyYK0xwr4Fc9L
jg2eccF91uJv8S2e3urngPvsyf8AdrECeA==
           "], {{0, 0}, {8, 50}}, {0, 1}],
          Frame->Automatic,
          FrameLabel->{None, None},
          FrameTicks->{{None, None}, {None, None}},
          GridLinesStyle->Directive[
            GrayLevel[0.5, 0.4]],
          ImageSize->50,
          
          Method->{
           "DefaultBoundaryStyle" -> Automatic, "DefaultPlotStyle" -> 
            Automatic}]}], "}"}]], "ExerciseOutput",ExpressionUUID->
       "86f766a3-7eec-4d44-9be4-0f8df90c2550"],
      Apply[TextCell, 
       Cell[
        BoxData[
         RowBox[{"{", 
           RowBox[{
             GraphicsBox[
              RasterBox[CompressedData["
1:eJxdj8sRgCAQQ/M82YYtWIol0AD930QI4OSws5+QD1epTzkk3a3OVvAVs/dR
444MtebdOMYxjnHzMX9LrydjN3/XAvssG8uGspETykl83mL/DxCBiYBEICIA
YUgYEIKEAEEgHhCHObzRVwLu
               "], {{0, 0}, {8, 50}}, {0, 1}], Frame -> 
              Automatic, FrameLabel -> {None, None}, 
              FrameTicks -> {{None, None}, {None, None}}, GridLinesStyle -> 
              Directive[
                GrayLevel[0.5, 0.4]], ImageSize -> 50, 
              Method -> {
               "DefaultBoundaryStyle" -> Automatic, "DefaultPlotStyle" -> 
                Automatic}], ",", 
             GraphicsBox[
              RasterBox[CompressedData["
1:eJxVkMENgDAMA21erMEKjMIIXYD9f1TtOS2CKFjEvrRXe592SLp7nb3cX7u6
ZzearzE3OtroTPLfilOVoJ8DXc/U+I0/LviGb/hrOisvtPcU+IZv+N7YGVIN
h8rxJ11sQZhqq4Rrh2RLorip/a7rFFkq5Q+1UwK8
               "], {{0, 0}, {8, 
               50}}, {0, 1}], Frame -> Automatic, FrameLabel -> {None, None}, 
              FrameTicks -> {{None, None}, {None, None}}, GridLinesStyle -> 
              Directive[
                GrayLevel[0.5, 0.4]], ImageSize -> 50, 
              Method -> {
               "DefaultBoundaryStyle" -> Automatic, "DefaultPlotStyle" -> 
                Automatic}], ",", 
             GraphicsBox[
              RasterBox[CompressedData["
1:eJxNkcERgzAMBPfyShtpIaWkBBpI/78QvIc1oJHxCp3Ofh3fz/EA3mc8zyDh
/5j70uXK8vTj4leVkFlE5JFHnjZZPP6vfsXtLIgbSVdL3uQwzKGIXCs4UrVH
1ATDDDoaR3Fbym7NKA3zENib9cj2Wk2y476B/ACzhQKs
               "], {{0, 0}, {8, 
               50}}, {0, 1}], Frame -> Automatic, FrameLabel -> {None, None}, 
              FrameTicks -> {{None, None}, {None, None}}, GridLinesStyle -> 
              Directive[
                GrayLevel[0.5, 0.4]], ImageSize -> 50, 
              Method -> {
               "DefaultBoundaryStyle" -> Automatic, "DefaultPlotStyle" -> 
                Automatic}], ",", 
             GraphicsBox[
              RasterBox[CompressedData["
1:eJxVkNsVgDAIQxO/XMMVHMURXMD9/3z0pmB7gENDCGU7r+NcJO2PrXqP7Yoe
0eQeucENbvCUfjDeJHBGq2lprZJQp7g5WVEEh98mTccou5MnoxAuOHz067XE
U6WqZiFmEWzv16WGdvurSnta1LIq35i5Apo=
               "], {{0, 0}, {8, 50}}, {0,
                1}], Frame -> Automatic, FrameLabel -> {None, None}, 
              FrameTicks -> {{None, None}, {None, None}}, GridLinesStyle -> 
              Directive[
                GrayLevel[0.5, 0.4]], ImageSize -> 50, 
              Method -> {
               "DefaultBoundaryStyle" -> Automatic, "DefaultPlotStyle" -> 
                Automatic}], ",", 
             GraphicsBox[
              RasterBox[CompressedData["
1:eJxVj8sNwDAIQ3FPXaMrdJSOkAW6/61R8wwhEgrC+MM13mccEXHPOoMn+f8b
eUwrJmKx1sEZaDUb3WVZ8JQDty38kg81G/hlB+5YMiWvUIthyYK0xwr4Fc9L
jg2eccF91uJv8S2e3urngPvsyf8AdrECeA==
               "], {{0, 0}, {8, 50}}, {0,
                1}], Frame -> Automatic, FrameLabel -> {None, None}, 
              FrameTicks -> {{None, None}, {None, None}}, GridLinesStyle -> 
              Directive[
                GrayLevel[0.5, 0.4]], ImageSize -> 50, 
              Method -> {
               "DefaultBoundaryStyle" -> Automatic, "DefaultPlotStyle" -> 
                Automatic}]}], "}"}]], "ExerciseOutput", Selectable -> False, 
        Copyable -> False, Editable -> False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"bf637e7b-92e2-4d57-9a86-4fc5720a73f4"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Generate 1000 random sequences of 4 letters, and make a list of ones that \
appear in ",
 Cell[BoxData[
  RowBox[{
   ButtonBox["WordList",
    BaseStyle->"CodeLink"], "[", " ", "]"}]], "InlineCode",ExpressionUUID->
  "714b124d-63c5-4546-aa8e-8d840ca87ce1"],
 ". ",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "+30.13", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"e7fbcf9d-9be2-4294-bc77-44b51bf3b28b"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       RowBox[{"{", 
        RowBox[{"\<\"avow\"\>", ",", "\<\"frog\"\>", ",", "\<\"know\"\>", 
         ",", "\<\"lido\"\>", ",", "\<\"snot\"\>"}], "}"}]], "ExerciseOutput",
       ExpressionUUID->"d30456e0-38dc-4acf-af9e-99059e85fe25"],
      Apply[TextCell, 
       Cell[
        BoxData[
         RowBox[{"{", 
           
           RowBox[{"\"avow\"", ",", "\"frog\"", ",", "\"know\"", ",", 
             "\"lido\"", ",", "\"snot\""}], "}"}]], "ExerciseOutput", 
        Selectable -> False, Copyable -> False, Editable -> False, 
        ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"744e81e5-8bc8-491a-b1b3-b0590601e621"]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Q&A", "QASection",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"p:185",ExpressionUUID->"e4cdd159-fc85-443c-ae48-fced46015f57"],

Cell[TextData[{
 "What does ",
 ButtonBox["Partition",
  BaseStyle->"Link"],
 " do if the blocks don\[CloseCurlyQuote]t fit perfectly?"
}], "Question",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"86631de9-084c-4c09-97bc-4900ddaffc20"],

Cell["\<\
If it\[CloseCurlyQuote]s not told otherwise, it\[CloseCurlyQuote]ll only \
include complete blocks, so it\[CloseCurlyQuote]ll just drop elements that \
appear only in incomplete blocks. You can tell it to do something different \
if you want.\
\>", "Answer",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"9a8fa50e-c424-407d-a36d-a95b18fb8a9a"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Tech Note", "TechNoteSection",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"04b2001a-1738-4641-9ac8-3ed9ec5a8934"],

Cell[TextData[{
 Cell[BoxData[
  RowBox[{
   ButtonBox["DeleteDuplicates",
    BaseStyle->"CodeLink"], "[", 
   StyleBox["list", "CodeVariable"], "]"}]], "InlineCode",ExpressionUUID->
  "331896c8-9a6b-499a-8e99-a27ec515fc53"],
 " does the same as ",
 Cell[BoxData[
  RowBox[{
   ButtonBox["Union",
    BaseStyle->"CodeLink"], "[", 
   StyleBox["list", "CodeVariable"], "]"}]], "InlineCode",ExpressionUUID->
  "aa033c0d-a8dc-4d3b-94a3-0c1f0a155b0f"],
 ", except it doesn\[CloseCurlyQuote]t reorder elements."
}], "TechNote",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"1cd79ff5-2f10-4d73-9ac3-1778092d0402"]
}, Open  ]],

Cell[CellGroupData[{

Cell["More to Explore", "MoreExploreSection",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"fa40186b-026d-4d6a-8464-334e7aa122a9"],

Cell[TextData[ButtonBox["Guide to Rearranging & Restructuring Lists in the \
Wolfram Language\[NonBreakingSpace]\[RightGuillemet]",
 BaseStyle->"Link",
 ButtonData->{
  "paclet:guide/RearrangingAndRestructuringLists", None}]], "MoreExplore",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->
  "LastCellOfAPage",ExpressionUUID->"ed3c5927-ce9e-4081-b91d-cd5ab3c86fec"]
}, Open  ]]
},
Saveable->False,
WindowToolbars->{},
BlinkingCellInsertionPoint->False,
CellInsertionPointCell->None,
WindowSize->{830, 800},
WindowMargins->Automatic,
WindowPersistentStyles->{
 WindowFrame, WindowMargins, WindowSize, Magnification},
WindowTitle->"Rearranging Lists: Elementary Introduction to the Wolfram \
Language",
DockedCells->{
  Cell[
   BoxData[
    TagBox[
     GridBox[{{
        TemplateBox[{
         "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]", 
          "\"\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\"", 
          GraphicsBox[
           TagBox[
            RasterBox[CompressedData["
1:eJztl01IVFEUxyctMFzUysjIyUDCTauiIJFM6ENpM4NEtJrBUaSYZMYPhCRm
rYuoICgiW0VEBVIUEbTNEMTAIqRsk6JGCVFBHx7//+4JLo/36DqvB4Ie+Mk7
7+t3733nHpzq9NlEW0ksFsuX4U8i1duQy6X6kpuRtGTzHe3ZTOuxbFemPZPb
ny7FyZ2gEqwHInICfJToguOIReywPVHHlYDzcY4hJHZ486giyBOXtfms5Pms
Bs9zUBDTow6DJOgBT8DP/+B5CepAPbgqZm+zT70Bt9VXCx6H8DwE28Gw5ufB
IT2eA1N6PKquC0V4xtUxqfkE6ARD4BHYAx5Y938Gu8GdZXq4VsNWngIfwDzY
Aa6Bm55nOKYq8NXRw29eb+Uz4JSVd4Nn4IbPs2fARUdPQcfLWAQJ8Mq6Tkdd
gGcEHHT0sHYn9Jg1dcnnnhf6vnee8xzXVkcP9wdr97eY7z0NnlrX74qpxffg
iOZ2VDp6kvqOe6AVXAb7xNQB462YNfsCfoBzoE1MzTEqHD096mgE98WsEec4
Jqamvvk8cx2kwWuw19HDXnIAbNAx03ka9IO8mO+3ScyebRZTi01i1rqguHjY
r3aJWaugOA5O6vEC+K6ebWDW0cNgv6oBnwKus87KwKDmv8BRMOBz77/6G/sV
e8lkwHWuTwm4pQ7WzGIRHgb7FXsJ9/mI5z2si42gXMw8/ByuHgb7FXsJ9yX3
IPfHFjF1xTl5v0exnrCx5gnn+fu7JC7h/z/0Y52+P+rfWX9iCXVYErg=
             "], {{0,
              34}, {26, 0}}, {0, 255}, ColorFunction -> RGBColor], 
            BoxForm`ImageTag[
            "Byte", ColorSpace -> "RGB", Interleaving -> True, Magnification -> 
             1], Selectable -> False], DefaultBaseStyle -> "ImageGraphics", 
           ImageSize -> Magnification[1], ImageSizeRaw -> {26, 34}, 
           PlotRange -> {{0, 26}, {0, 34}}], 
          GraphicsBox[
           TagBox[
            RasterBox[CompressedData["
1:eJztXUuS47gRLX8WXtYRaJ+gl17SS+8U4/CeM+H2hDdtRY8jHF6ZR9AReATt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             "], {{0, 34}, {383, 0}}, {0, 255}, 
             ColorFunction -> RGBColor], 
            BoxForm`ImageTag[
            "Byte", ColorSpace -> "RGB", Interleaving -> True, Magnification -> 
             1], Selectable -> False], DefaultBaseStyle -> "ImageGraphics", 
           ImageSize -> Magnification[1], ImageSizeRaw -> {383, 34}, 
           PlotRange -> {{0, 383}, {0, 34}}]}, "RowWithSeparators"], 
        PaneBox[
         StyleBox["\[VeryThinSpace]", ShowStringCharacters -> False], 
         Alignment -> Right, ImageSize -> {174, 47}], 
        PaneBox[
         PaneBox[
          TemplateBox[{"\[ThinSpace]", "\" \"", 
            TagBox[
             TooltipBox[
              PaneSelectorBox[{False -> ButtonBox[
                  PaneBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAPiDmBmIUBO/j//z8jEDcA8W8g3oBFnhmIZ/9HgE9o8mxAvBZJ/hsQuyPJ
8wPxfiT5N0BsjiQvCsTnkOSfALEWkrwSEN9Bkr8OxDJobniAJP8ZZCYWfxCj
RpGQXcS4mVi/ExuGxMYFmlp4nAIAG14fWQ==
                    "], {{0, 14}, {9, 
                    0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                     ImageSizeRaw -> {9, 14}, PlotRange -> {{0, 9}, {0, 14}}, 
                    ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                   Alignment -> Center], 
                  ButtonFunction :> (
                   NotebookLocate[{
                    "EIWL1-29-more-about-pure-functions.nb", ""}, 
                    FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Enabled -> True, Appearance -> 
                  None, Evaluator -> Automatic, Method -> "Preemptive"], True -> 
                ButtonBox[
                  PaneBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAPiDmBmIUBO/j//z8jEDcA8W8g3oBFnhmIZ/9HgE9o8mxAvBZJ/hsQuyPJ
8wPxfiT5N0BsjiQvCsTnkOSfALEWkrwSEN9Bkr8OxDJobniAJP8ZZCYWfxCj
RpGQXcS4mVi/ExuGxMYFmlp4nAIAG14fWQ==
                    "], {{0, 14}, {9, 
                    0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                     ImageSizeRaw -> {9, 14}, PlotRange -> {{0, 9}, {0, 14}}, 
                    ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                   Alignment -> Center], 
                  ButtonFunction :> (
                   NotebookLocate[{
                    "EIWL1-29-more-about-pure-functions.nb", ""}, 
                    FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Enabled -> True, Appearance -> 
                  None, Background -> RGBColor[0.835294, 0.364706, 0.0196078],
                   Evaluator -> Automatic, Method -> "Preemptive"]}, 
               Dynamic[
                CurrentValue["MouseOver"]], ImageSize -> Automatic, 
               FrameMargins -> 0], "\"More about Pure Functions\"", 
              TooltipDelay -> 0.15, LabelStyle -> "TextStyling"], 
             Annotation[#, "More about Pure Functions", "Tooltip"]& ], 
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {5, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[5], Selectable -> False], 
            TagBox[
             TooltipBox[
              PaneSelectorBox[{False -> ButtonBox[
                  PaneBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAfiDmBmAWI////vwKIfwFxMQMOAJT7+R8B6nGoSf+PCjpwqMskUl0SEP9F
UtcHxIxY1EWjqZuOQ10Mmr2TcNj7BEnNP1LNIeQeIDsZn78IhQ8x4fwfNb4a
cPgTFu8l2ORBAAC+1hnm
                    "], {{0, 15}, {9, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                     ImageSizeRaw -> {9, 15}, PlotRange -> {{0, 9}, {0, 15}}, 
                    ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                   Alignment -> Center], 
                  ButtonFunction :> (
                   NotebookLocate[{"EIWL1-31-parts-of-lists.nb", ""}, 
                    FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Appearance -> None, Evaluator -> 
                  Automatic, Method -> "Preemptive"], True -> ButtonBox[
                  PaneBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAfiDmBmAWI////vwKIfwFxMQMOAJT7+R8B6nGoSf+PCjpwqMskUl0SEP9F
UtcHxIxY1EWjqZuOQ10Mmr2TcNj7BEnNP1LNIeQeIDsZn78IhQ8x4fwfNb4a
cPgTFu8l2ORBAAC+1hnm
                    "], {{0, 15}, {9, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                     ImageSizeRaw -> {9, 15}, PlotRange -> {{0, 9}, {0, 15}}, 
                    ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                   Alignment -> Center], 
                  ButtonFunction :> (
                   NotebookLocate[{"EIWL1-31-parts-of-lists.nb", ""}, 
                    FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Appearance -> None, Background -> 
                  RGBColor[0.835294, 0.364706, 0.0196078], Evaluator -> 
                  Automatic, Method -> "Preemptive"]}, 
               Dynamic[
                CurrentValue["MouseOver"]], ImageSize -> Automatic, 
               FrameMargins -> 0], "\"Parts of Lists\"", TooltipDelay -> 0.15,
               LabelStyle -> "TextStyling"], 
             Annotation[#, "Parts of Lists", "Tooltip"]& ]}, 
           "RowWithSeparators"], Alignment -> Right], ImageSize -> {100, 30}, 
         FrameMargins -> {{0, 6}, {0, 0}}, Alignment -> Right], 
        ActionMenuBox[
         PaneSelectorBox[{True -> PanelBox[
             GraphicsBox[
              TagBox[
               RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UBAkIQ3ELED8////Jf/pA0D2/KWTXSB7ZtPBPrA9DKOAYgAMR1Eg9gPiABpi
P6g912mcLmAAZM9XOtkFsicKiNcD8QYaYpD5UQOdXoYD+E/HMooO9iDbR7c6
BQDxtyEt
                "], {{0, 16}, {27, 0}}, {0, 255}, ColorFunction -> 
                RGBColor], 
               BoxForm`ImageTag[
               "Byte", ColorSpace -> "RGB", Interleaving -> True, 
                Magnification -> 1], Selectable -> False], DefaultBaseStyle -> 
              "ImageGraphics", ImageSize -> Magnification[1], 
              ImageSizeRaw -> {27, 16}, PlotRange -> {{0, 27}, {0, 16}}], 
             Appearance -> None, Background -> 
             RGBColor[0.835294, 0.364706, 0.0196078], ImageSize -> {35, 30}, 
             Alignment -> Center], False -> PanelBox[
             GraphicsBox[
              TagBox[
               RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UBAkIQ3ELED8////Jf/pA0D2/KWTXSB7ZtPBPrA9DKOAYgAMR1Eg9gPiABpi
P6g912mcLmAAZM9XOtkFsicKiNcD8QYaYpD5UQOdXoYD+E/HMooO9iDbR7c6
BQDxtyEt
                "], {{0, 16}, {27, 0}}, {0, 255}, ColorFunction -> 
                RGBColor], 
               BoxForm`ImageTag[
               "Byte", ColorSpace -> "RGB", Interleaving -> True, 
                Magnification -> 1], Selectable -> False], DefaultBaseStyle -> 
              "ImageGraphics", ImageSize -> Magnification[1], 
              ImageSizeRaw -> {27, 16}, PlotRange -> {{0, 27}, {0, 16}}], 
             Appearance -> None, Background -> 
             RGBColor[0.952941, 0.509804, 0], ImageSize -> {35, 30}, 
             Alignment -> Center]}, 
          Dynamic[
           CurrentValue["MouseOver"]]], {
         "Preface" :> 
          NotebookLocate[{"EIWL1-0a-preface.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "What Is the Wolfram Language?" :> 
          NotebookLocate[{"EIWL1-0b-what-is-the-wolfram-language.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "Practicalities of Using the Wolfram Language" :> 
          NotebookLocate[{
            "EIWL1-0c-practicalities-of-using-the-wolfram-language.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "Other Resources" :> 
          NotebookLocate[{"EIWL1-0d-other-resources.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]1\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Starting Out: Elementary Arithmetic" :> 
          NotebookLocate[{
            "EIWL1-01-starting-out-elementary-arithmetic.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]2\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Introducing Functions" :> 
          NotebookLocate[{"EIWL1-02-introducing-functions.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]3\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]First Look at Lists" :> 
          NotebookLocate[{"EIWL1-03-first-look-at-lists.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]4\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Displaying Lists" :> 
          NotebookLocate[{"EIWL1-04-displaying-lists.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]5\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Operations on Lists" :> 
          NotebookLocate[{"EIWL1-05-operations-on-lists.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]6\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Making Tables" :> 
          NotebookLocate[{"EIWL1-06-making-tables.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]7\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Colors and Styles" :> 
          NotebookLocate[{"EIWL1-07-colors-and-styles.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]8\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Basic Graphics Objects" :> 
          NotebookLocate[{"EIWL1-08-basic-graphics-objects.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]9\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Interactive Manipulation" :> 
          NotebookLocate[{"EIWL1-09-interactive-manipulation.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "10\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Images" :> 
          NotebookLocate[{"EIWL1-10-images.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "11\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Strings and \
Text" :> NotebookLocate[{"EIWL1-11-strings-and-text.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "12\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Sound" :> 
          NotebookLocate[{"EIWL1-12-sound.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "13\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Arrays, or \
Lists of Lists" :> 
          NotebookLocate[{"EIWL1-13-arrays-or-lists-of-lists.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "14\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Coordinates \
and Graphics" :> 
          NotebookLocate[{"EIWL1-14-coordinates-and-graphics.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "15\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]The Scope \
of the Wolfram Language" :> 
          NotebookLocate[{
            "EIWL1-15-the-scope-of-the-wolfram-language.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "16\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Real\
\[VeryThinSpace]\[Hyphen]\[VeryThinSpace]\[NegativeVeryThinSpace]World Data" :> 
          NotebookLocate[{"EIWL1-16-real-world-data.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "17\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Units" :> 
          NotebookLocate[{"EIWL1-17-units.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "18\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]\
Geocomputation" :> 
          NotebookLocate[{"EIWL1-18-geocomputation.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "19\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Dates and \
Times" :> NotebookLocate[{"EIWL1-19-dates-and-times.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "20\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Options" :> 
          NotebookLocate[{"EIWL1-20-options.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "21\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Graphs and \
Networks" :> NotebookLocate[{"EIWL1-21-graphs-and-networks.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "22\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Machine \
Learning" :> 
          NotebookLocate[{"EIWL1-22-machine-learning.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "23\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]More about \
Numbers" :> NotebookLocate[{"EIWL1-23-more-about-numbers.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "24\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]More Forms \
of Visualization" :> 
          NotebookLocate[{"EIWL1-24-more-forms-of-visualization.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "25\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Ways to \
Apply Functions" :> 
          NotebookLocate[{"EIWL1-25-ways-to-apply-functions.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "26\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Pure \
Anonymous Functions" :> 
          NotebookLocate[{"EIWL1-26-pure-anonymous-functions.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "27\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Applying \
Functions Repeatedly" :> 
          NotebookLocate[{"EIWL1-27-applying-functions-repeatedly.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "28\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Tests and \
Conditionals" :> 
          NotebookLocate[{"EIWL1-28-tests-and-conditionals.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "29\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]More about \
Pure Functions" :> 
          NotebookLocate[{"EIWL1-29-more-about-pure-functions.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "30\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Rearranging \
Lists" :> NotebookLocate[{"EIWL1-30-rearranging-lists.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "31\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Parts of \
Lists" :> NotebookLocate[{"EIWL1-31-parts-of-lists.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "32\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Patterns" :> 
          NotebookLocate[{"EIWL1-32-patterns.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "33\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Expressions \
and Their Structure" :> 
          NotebookLocate[{"EIWL1-33-expressions-and-their-structure.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "34\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]\
Associations" :> 
          NotebookLocate[{"EIWL1-34-associations.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "35\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Natural \
Language Understanding" :> 
          NotebookLocate[{"EIWL1-35-natural-language-understanding.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "36\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Creating \
Websites and Apps" :> 
          NotebookLocate[{"EIWL1-36-creating-websites-and-apps.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "37\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Layout and \
Display" :> NotebookLocate[{"EIWL1-37-layout-and-display.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "38\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Assigning \
Names to Things" :> 
          NotebookLocate[{"EIWL1-38-assigning-names-to-things.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "39\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Immediate \
and Delayed Values" :> 
          NotebookLocate[{"EIWL1-39-immediate-and-delayed-values.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "40\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Defining \
Your Own Functions" :> 
          NotebookLocate[{"EIWL1-40-defining-your-own-functions.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "41\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]More about \
Patterns" :> 
          NotebookLocate[{"EIWL1-41-more-about-patterns.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "42\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]String \
Patterns and Templates " :> 
          NotebookLocate[{"EIWL1-42-string-patterns-and-templates.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "43\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Storing \
Things" :> NotebookLocate[{"EIWL1-43-storing-things.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "44\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Importing \
and Exporting" :> 
          NotebookLocate[{"EIWL1-44-importing-and-exporting.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "45\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Datasets" :> 
          NotebookLocate[{"EIWL1-45-datasets.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "46\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Writing \
Good Code" :> 
          NotebookLocate[{"EIWL1-46-writing-good-code.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "47\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Debugging \
Your Code" :> 
          NotebookLocate[{"EIWL1-47-debugging-your-code.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "What We Haven\[CloseCurlyQuote]t Discussed" :> 
          NotebookLocate[{"EIWL1-what-we-havent-discussed.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "Afterword: Being a Programmer" :> 
          NotebookLocate[{"EIWL1-being-a-programmer.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "Answers to Exercises" :> 
          NotebookLocate[{"EIWL1-answers-to-exercises.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "Index" :> 
          NotebookLocate[{"EIWL1-book-index.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}]}, Appearance -> None]}}, 
      GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Center}}}, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"]], 
   "Text", ShowCellBracket -> False, CellFrame -> {{0, 0}, {3, 0}}, 
   Selectable -> False, CellFrameColor -> 
   RGBColor[0.835294, 0.364706, 0.0196078], CellMargins -> {{0, 0}, {0, -1}}, 
   CellFrameMargins -> {{27, 0}, {1, 7}}, Background -> 
   RGBColor[0.952941, 0.509804, 0], CellTags -> "DockedCellLogoCell"], 
  Cell["FIRST EDITION (2015)", "Text", FontFamily -> "Source Sans Pro", 
   CellFrame -> {{0, 0}, {3, 0}}, ShowCellBracket -> False, 
   CellMargins -> {{0, 0}, {-1, -1}}, CellFrameMargins -> {{66, 0}, {2, 4}}, 
   CellFrameColor -> RGBColor[0.952941, 0.509804, 0], FontSize -> 10, 
   FontTracking -> "Extended", FontColor -> RGBColor[1, 0.929412, 0.721569], 
   Background -> RGBColor[0.862745, 0.309804, 0], CellTags -> 
   "DockedCellLogoCell"]},
PrintingStartingPageNumber->254,
PageHeaders->{{
   Cell[
    TextData[{
      StyleBox[
       CounterBox["Page"], "PageNumber"], 
      StyleBox[
      "    An Elementary Introduction to the Wolfram Language", "Header"]}], 
    "Header", CellMargins -> {{37, Inherited}, {Inherited, Inherited}}], None,
    None}, {None, None, 
   Cell[
    TextData[{
      StyleBox[
       CounterBox["Section"], "Header"], 
      StyleBox[" | Rearranging Lists \[LongDash] wolfr.am/eiwl-", "Header"], 
      StyleBox[
       CounterBox["Section"], "Header"], 
      StyleBox["    ", "Header"], 
      StyleBox[
       CounterBox["Page"], "PageNumber"]}], "Header", 
    CellMargins -> {{Inherited, 17}, {Inherited, Inherited}}]}},
PrintingOptions->{"FirstPageHeader"->True},
ShowCellBracket->Automatic,
ShowSyntaxStyles->False,
Magnification->1.,
FrontEndVersion->"11.1 for Mac OS X x86 (32-bit, 64-bit Kernel) (March 16, \
2017)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "Default.nb"]], 
   Cell[
    CellGroupData[{
      Cell[
      "Style Environments", "Section", 
       CellChangeTimes -> {{3.64661165091824*^9, 3.646611654013329*^9}, 
         3.6485723794335403`*^9, 3.651347081728628*^9, 3.651347179462186*^9, 
         3.651347384135805*^9, 3.651348171662589*^9}], 
      Cell[
       StyleData[All, "Working"], CellInsertionPointCell -> 
       FEPrivate`FrontEndResource["FEExpressions", "CellInsertionMenu"], 
       CreateCellID -> True, $CellContext`GhostCellInEmptyNotebook -> False], 
      
      Cell[
       StyleData[All, "Printout"], 
       PrintingOptions -> {
        "PageSize" -> {504, 720}, "PrintRegistrationMarks" -> True}, 
       Magnification -> 0.6]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell["Styles for Headers and Footers", "Section"], 
      Cell[
       StyleData["Header"], StyleMenuListing -> None, FontFamily -> "Verdana",
        FontSize -> 7, FontSlant -> "Plain", FontColor -> GrayLevel[0.6]], 
      Cell[
       StyleData["PageNumber"], CellMargins -> {{0, 0}, {4, 1}}, 
       StyleMenuListing -> None, FontFamily -> "Verdana", FontSize -> 7, 
       FontWeight -> "Bold", FontSlant -> "Plain", FontColor -> 
       GrayLevel[0]]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell[
      "WPL Specific", "Section", 
       CellChangeTimes -> {{3.6556608433734913`*^9, 3.6556608489412746`*^9}}], 
      Cell[
       StyleData["Link"], FontFamily -> "Source Sans Pro", FontSize :> 
       If[CurrentValue[
           EvaluationCell[], "FontFamily"] === "Source Sans Pro", Inherited, 
         If[CurrentValue[
            EvaluationCell[], "FontFamily"] === "WolframCodeSans", Inherited, 
          Inherited 0.9]], FontColor -> GrayLevel[0]], 
      Cell[
       StyleData["CodeLink"], 
       ButtonBoxOptions -> {
        Appearance -> None, ButtonFunction :> (FEPrivate`FrontEndExecute[
           FrontEndToken["OpenHelpLink", {
             Part[#, 1], Null}]]& ), ButtonSource -> ButtonContents, 
         Evaluator -> None, Method -> "Preemptive"}]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell[
      "Custom Styles", "Section", 
       CellChangeTimes -> {{3.646611660445352*^9, 3.646611669493331*^9}}], 
      Cell[
       StyleData["Notebook"], PageWidth -> 700, 
       PrintingOptions -> {
        "InnerOuterMargins" -> {35, 16}, "PaperOrientation" -> "Portrait", 
         "PaperSize" -> {504, 720}, 
         "PrintingMargins" -> {{20, 20}, {54, 54}}}, CellLabelAutoDelete -> 
       False, ShowSyntaxStyles -> False, MenuSortingValue -> None, 
       GraphicsBoxOptions -> {ImageSize -> 240}, 
       Graphics3DBoxOptions -> {ImageSize -> 240}], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Title"], CellMargins -> {{64, Inherited}, {50, 72}}, 
          MenuCommandKey -> None, FontFamily -> "Verdana", FontSize -> 42, 
          FontWeight -> "Bold", FontColor -> GrayLevel[0.4]], 
         Cell[
          StyleData["Title", "Printout"], 
          CellMargins -> {{64, Inherited}, {50, 72}}]}, Closed]], 
      Cell[
       StyleData["Chapter"], MenuCommandKey -> None], 
      Cell[
       StyleData["Subchapter"], MenuCommandKey -> None], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Section"], CellFrame -> {{0, 0}, {0, 0}}, CellDingbat -> 
          Cell[
            TextData[
             CounterBox["Section"], 
             StyleBox[
             "|\[NegativeThinSpace]", FontColor -> 
              RGBColor[
               0.9019607843137255, 0.4117647058823529, 0.027450980392156862`],
               FontFamily -> "Courier", FontSize -> 36, FontWeight -> Plain]],
             "SectionNumber"], CellMargins -> {{96, Inherited}, {12, 44}}, 
          Evaluatable -> True, CellGroupingRules -> {"SectionGrouping", 60}, 
          PageBreakAbove -> True, ShowCellLabel -> False, 
          CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
          CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
          CounterIncrements -> "Section", 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", 
          FontSize -> 26, FontSlant -> "Plain", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          InterpretationBoxOptions -> {Editable -> True}], 
         Cell[
          StyleData["Section", "Printout"], 
          CellMargins -> {{96, Inherited}, {12, 2}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionDoubleDigit"], CellFrame -> {{0, 0}, {0, 0}}, 
          CellDingbat -> Cell[
            TextData[
             CounterBox["Section"], 
             StyleBox[
             "|\[NegativeThinSpace]", FontColor -> 
              RGBColor[
               0.9019607843137255, 0.4117647058823529, 0.027450980392156862`],
               FontFamily -> "Courier", FontSize -> 36, FontWeight -> Plain]],
             "SectionNumber"], CellMargins -> {{112, Inherited}, {12, 44}}, 
          Evaluatable -> True, CellGroupingRules -> {"SectionGrouping", 60}, 
          PageBreakAbove -> True, ShowCellLabel -> False, 
          CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
          CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
          CounterIncrements -> "Section", 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", 
          FontSize -> 26, FontSlant -> "Plain", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          InterpretationBoxOptions -> {Editable -> True}], 
         Cell[
          StyleData["SectionDoubleDigit", "Printout"], 
          CellMargins -> {{112, Inherited}, {12, 2}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionNumber"], CellBaseline -> Baseline, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 26, FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["SectionNumber", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionInline"], FontFamily -> 
          "Source Sans Pro Semibold", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["SectionInline", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionNoDingbat"], 
          CellMargins -> {{64, Inherited}, {12, 44}}, Evaluatable -> True, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakAbove -> 
          True, ShowCellLabel -> False, 
          CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
          CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
          CounterIncrements -> "Section", 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", 
          FontSize -> 26, FontSlant -> "Plain", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          InterpretationBoxOptions -> {Editable -> True}], 
         Cell[
          StyleData["SectionNoDingbat", "Printout"], 
          CellMargins -> {{64, Inherited}, {12, 2}}]}, Closed]], 
      Cell[
       StyleData["AnswerKeyNumberedSection"], 
       CellMargins -> {{64, Inherited}, {8, 28}}, Evaluatable -> True, 
       CellGroupingRules -> {"SectionGrouping", 60}, PageBreakAbove -> True, 
       ShowCellLabel -> False, 
       CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
       CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
       CounterIncrements -> "Section", 
       CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
         "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", FontSize -> 
       18, FontSlant -> "Plain", FontColor -> 
       RGBColor[
        0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
       InterpretationBoxOptions -> {Editable -> True}], 
      Cell[
       StyleData["AnswerKeySectionNumber"], CellBaseline -> Baseline, 
       FontFamily -> "Source Sans Pro Semibold", FontSize -> 18, FontColor -> 
       RGBColor[
        0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
      Cell[
       StyleData["IndexLinkGuide"], 
       CellMargins -> {{64, Inherited}, {48, 28}}, Evaluatable -> True, 
       CellGroupingRules -> {"SectionGrouping", 60}, PageBreakAbove -> True, 
       ShowCellLabel -> False, 
       CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
       CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
       CounterIncrements -> "Section", 
       CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
         "Exercise", 0}}, FontFamily -> "Source Sans Pro", FontSize -> 14, 
       FontSlant -> "Plain", FontColor -> 
       RGBColor[
        0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
       InterpretationBoxOptions -> {Editable -> True}], 
      Cell[
       StyleData["Index"], MenuSortingValue -> 10000, FontFamily -> 
       "Source Sans Pro", FontSize -> 11], 
      Cell[
       StyleData["IndexSubentry"], MenuSortingValue -> 10000, FontFamily -> 
       "Source Sans Pro", FontSize -> 11], 
      Cell[
       StyleData["FunctionName"], MenuSortingValue -> 10000, FontFamily -> 
       "Source Sans Pro Semibold", FontWeight -> "Bold"], 
      Cell[
       StyleData["IndexColumn"], 
       CellMargins -> {{66, 0}, {Inherited, Inherited}}, TabSpacings -> {2.}, 
       MenuSortingValue -> 10000, FontFamily -> "Source Sans Pro", 
       GridBoxOptions -> {
        GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
         GridBoxItemSize -> {"Columns" -> {{25}}}, 
         GridBoxSpacings -> {"Columns" -> {{2}}}}], 
      Cell[
       StyleData["IndexSubsection"], 
       CellMargins -> {{64, Inherited}, {9, 28}}, 
       CellGroupingRules -> {"SectionGrouping", 40}, MenuSortingValue -> 
       10000, FontFamily -> "Source Sans Pro", FontSize -> 24], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Subsection"], CellMargins -> {{64, Inherited}, {12, 32}},
           FontFamily -> "Source Sans Pro Semibold", FontSize -> 18, 
          FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["Subsection", "Printout"], 
          CellMargins -> {{64, Inherited}, {12, 32}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ResourcesSubsection"], 
          CellMargins -> {{64, Inherited}, {4, 16}}, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 15, FontSlant -> "Plain", 
          FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["ResourcesSubsection", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 16}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Subsubsection"], 
          CellMargins -> {{64, Inherited}, {6, 12}}, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 16, FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["Subsubsection", "Printout"], 
          CellMargins -> {{64, Inherited}, {6, 12}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularySection"], PageWidth -> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 24}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["VocabularySection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 24}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularyTable", StyleDefinitions -> StyleData["Text"]],
           SpanMaxSize -> 1, FontFamily -> "Source Sans Pro Light", FontColor -> 
          GrayLevel[0.8], 
          GridBoxOptions -> {
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
            GridBoxDividers -> {"Columns" -> {{False}}, "Rows" -> {False, {
                 Directive[
                  Thickness[0.5], "VocabDivColor"]}, False}}, 
            GridBoxItemStyle -> {
             "Columns" -> {"VocabularyCode", Inherited, Inherited}, 
              "Rows" -> {{Automatic}}}, 
            GridBoxSpacings -> {
             "Columns" -> {{0, 1, 2, 1, 2}}, "Rows" -> {{1}}}}], 
         Cell[
          StyleData["VocabularyTable", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "VocabularyTable3Column", StyleDefinitions -> StyleData["Text"]], 
          SpanMaxSize -> 1, FontFamily -> "Source Sans Pro Light", FontColor -> 
          GrayLevel[0.8], 
          GridBoxOptions -> {
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
            GridBoxDividers -> {"Columns" -> {{False}}, "Rows" -> {False, {
                 Directive[
                  Thickness[0.5], "VocabDivColor"]}, False}}, 
            GridBoxItemStyle -> {
             "Columns" -> {
               "VocabularyCode", Inherited, "VocabularyCode", Inherited, 
                Inherited}, "Rows" -> {{Automatic}}}, 
            GridBoxSpacings -> {
             "Columns" -> {{0, 1, 2, 1, 2}}, "Rows" -> {{1}}}}], 
         Cell[
          StyleData["VocabularyTable3Column", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularyText"], FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["VocabularyText", "Printout"], 
          CellMargins -> {{66, 10}, {7, 7}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularyCode", StyleDefinitions -> StyleData["Text"]], 
          Deletable -> False, FontFamily -> "Source Sans Pro", FontSize -> 14,
           FontWeight -> "Bold", FontColor -> GrayLevel[0.25], 
          GridBoxOptions -> {
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
            GridBoxDividers -> {
             "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {True, {True}, True}, "RowsIndexed" -> {}}}], 
         Cell[
          StyleData["VocabularyCode", "Printout"], FontColor -> 
          GrayLevel[0.25]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabDivColor"], FontColor -> GrayLevel[0.8]], 
         Cell[
          StyleData["VocabDivColor", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseSection"], PageWidth -> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 30}}, Evaluatable -> True, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, ShowCellLabel -> False, CellFrameMargins -> {{8, 8}, {4, 6}},
           CellFrameColor -> RGBColor[0.901961, 0.411765, 0.027451], 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro", FontSize -> 18, 
          FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["ExerciseSection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Exercise"], PageWidth -> 700, CellDingbat -> Cell[
            TextData[{"  ", 
              CounterBox["Section"], ".", 
              CounterBox["Exercise"]}], "ExerciseNumber", FontColor -> 
            RGBColor[
             0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
          ShowGroupOpener -> True, CellMargins -> {{108, Inherited}, {4, 8}}, 
          CellGroupingRules -> {"SectionGrouping", 67}, CounterIncrements -> 
          "Exercise", MenuSortingValue -> 10020, MenuCommandKey -> "2", 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Plain", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["Exercise", "Printout"], ShowGroupOpener -> False, 
          CellMargins -> {{110, Inherited}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseNumber"], FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Bold", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["ExerciseNumber", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseSubsection"], PageWidth -> 500, 
          CellFrame -> {{False, False}, {1, False}}, 
          CellMargins -> {{64, Inherited}, {8, 18}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, CellFrameColor -> 
          RGBColor[0.65, 0.6, 0.6], FontFamily -> "Source Sans Pro", FontSize -> 
          18, FontSlant -> "Italic", FontColor -> RGBColor[0.65, 0.6, 0.6]], 
         Cell[
          StyleData["ExerciseSubsection", "Printout"], 
          CellFrame -> {{False, False}, {1, False}}, CellFrameColor -> 
          RGBColor[0.65, 0.6, 0.6]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseNote"], PageWidth -> 700, 
          CellMargins -> {{64, Inherited}, {4, 8}}, PageBreakBelow -> False, 
          MenuSortingValue -> 10050, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25], $CellContext`ReturnCreatesNewCell -> 
          True], 
         Cell[
          StyleData["ExerciseNote", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["QASection"], PageWidth -> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 30}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Question", 0}}, FontFamily -> "Source Sans Pro", FontSize -> 18, 
          FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["QASection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Question"], PageWidth -> 700, 
          CellMargins -> {{64, Inherited}, {2, 12}}, PageBreakBelow -> False, 
          CounterIncrements -> "Question", MenuSortingValue -> 10030, 
          MenuCommandKey -> "3", FontFamily -> "Source Sans Pro", FontSize -> 
          14, FontWeight -> "Bold", FontSlant -> 
          "Plain", $CellContext`ReturnCreatesNewCell -> 
          True, $CellContext`DefaultReturnCreatedCellStyle -> "Answer"], 
         Cell[
          StyleData["Question", "Printout"], 
          CellMargins -> {{65, Inherited}, {2, 12}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Answer"], PageWidth -> 700, 
          CellMargins -> {{66, 10}, {4, 1}}, LineSpacing -> {1.125, 1., 2.}, 
          MenuSortingValue -> 10032, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25], $CellContext`ReturnCreatesNewCell -> 
          True, $CellContext`DefaultReturnCreatedCellStyle -> "Question"], 
         Cell[
          StyleData["Answer", "Printout"], 
          CellMargins -> {{66, 10}, {4, 1}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["QuestionNumber"], FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Bold", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["QuestionNumber", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TechNoteSection"], PageWidth -> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 30}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["TechNoteSection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TechNote"], PageWidth -> 700, CellDingbat -> Cell[
            TextData[{"\[FilledSmallSquare]"}], FontSize -> 12, FontColor -> 
            GrayLevel[0.5]], CellMargins -> {{78, Inherited}, {4, 8}}, 
          CellChangeTimes -> {{3.651515120816633*^9, 3.651515125814807*^9}, 
            3.6515155174947033`*^9}, LineSpacing -> {1.25, 1., 2.}, 
          MenuSortingValue -> 10040, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25], $CellContext`ReturnCreatesNewCell -> 
          True], 
         Cell[
          StyleData["TechNote", "Printout"], 
          CellMargins -> {{82, Inherited}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["MoreExploreSection"], PageWidth -> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 30}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["MoreExploreSection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["MoreExplore"], PageWidth -> 700, 
          CellMargins -> {{64, Inherited}, {4, 8}}, PageBreakBelow -> False, 
          MenuSortingValue -> 10050, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0], $CellContext`ReturnCreatesNewCell -> 
          True], 
         Cell[
          StyleData["MoreExplore", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["MoreExploreShortURL"], 
          CellMargins -> {{64, Inherited}, {4, 8}}, PageBreakBelow -> False, 
          FontFamily -> "Source Sans Pro Light", FontSize -> 14, FontSlant -> 
          "Plain", FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["MoreExploreShortURL", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Text"], CellMargins -> {{66, 10}, {4, 14}}, FontFamily -> 
          "Baskerville", FontSize -> 18, FontColor -> 
          GrayLevel[0], $CellContext`ReturnCreatesNewCell -> True], 
         Cell[
          StyleData["Text", "Printout"], CellMargins -> {{66, 10}, {7, 7}}]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ResourcesText"], CellMargins -> {{66, 10}, {2, 0}}, 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Plain", FontColor -> 
          GrayLevel[0], $CellContext`ReturnCreatesNewCell -> True], 
         Cell[
          StyleData["ResourcesText", "Printout"], 
          CellMargins -> {{66, 10}, {2, 0}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ResourcesLink"], CellMargins -> {{66, 10}, {2, 0}}, 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Italic", FontColor -> 
          GrayLevel[0], $CellContext`ReturnCreatesNewCell -> True], 
         Cell[
          StyleData["ResourcesLink", "Printout"], 
          CellMargins -> {{66, 10}, {2, 0}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CodeCaption"], CellFrame -> {{0, 0}, {0, 0}}, 
          CellMargins -> {{66, 10}, {4, 12}}, PageBreakBelow -> False, 
          CellFrameColor -> GrayLevel[0.4], MenuSortingValue -> 10010, 
          MenuCommandKey -> "1", FontFamily -> "Source Sans Pro", FontSize -> 
          16, FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["CodeCaption", "Printout"], 
          CellMargins -> {{66, 10}, {4, 12}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Input"], CellMargins -> {{99, 10}, {3, 7}}, SpanMaxSize -> 
          1, FontSize -> 15], 
         Cell[
          StyleData["Input", "Printout"], CellMargins -> {{99, 10}, {3, 7}}]},
         Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Output"], CellMargins -> {{99, 10}, {14, 7}}, FontSize -> 
          15], 
         Cell[
          StyleData["Output", "Printout"], 
          CellMargins -> {{99, 10}, {14, 7}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["InputOnly"], CellMargins -> {{99, 10}, {25, 10}}, 
          SpanMaxSize -> 1, MenuSortingValue -> 1500, FontSize -> 15], 
         Cell[
          StyleData["InputOnly", "Printout"], 
          CellMargins -> {{99, 10}, {15, 10}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CellLabel"], 
          CellLabelMargins -> {{12, Inherited}, {Inherited, Inherited}}, 
          LanguageCategory -> None, StyleMenuListing -> None, FontFamily -> 
          "Helvetica Neue", FontSize -> 9, FontWeight -> "Plain", FontSlant -> 
          "Plain", FontColor -> GrayLevel[0.5]], 
         Cell[
          StyleData["CellLabel", "Printout"], FontSize -> 8, FontColor -> 
          GrayLevel[0.5]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Message"], Editable -> False, 
          CellMargins -> {{66, Inherited}, {Inherited, Inherited}}, 
          CellGroupingRules -> "OutputGrouping", TextClipboardType -> 
          "PlainText", PageBreakWithin -> False, GroupPageBreakWithin -> 
          False, GeneratedCell -> True, CellAutoOverwrite -> True, 
          ShowCellLabel -> False, DefaultFormatType -> 
          DefaultOutputFormatType, ContextMenu -> 
          FEPrivate`FrontEndResource["ContextMenus", "Output"], 
          ShowAutoStyles -> False, ShowSyntaxStyles -> False, 
          AutoStyleOptions -> {
           "StringStyle" -> None, "SyntaxErrorStyle" -> None}, 
          HyphenationOptions -> {"HyphenationCharacter" -> "\[Continuation]"},
           AutoItalicWords -> {}, AutoQuoteCharacters -> {}, 
          PasteAutoQuoteCharacters -> {}, LanguageCategory -> None, 
          FormatType -> InputForm, ShowStringCharacters -> False, 
          CounterIncrements -> "Message", MenuSortingValue -> 1600, 
          StyleMenuListing -> None, FontFamily :> 
          CurrentValue["PanelFontFamily"], FontSize -> 11, FontColor -> 
          RGBColor[0.5072, 0.16933, 0.15221], $CellContext`StripStyleOnPaste -> 
          True], 
         Cell[
          StyleData["Message", "Printout"], 
          CellMargins -> {{100, Inherited}, {Inherited, Inherited}}, 
          CellFrameLabels -> {{None, None}, {None, None}}, FontColor -> 
          GrayLevel[0]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseInput", StyleDefinitions -> StyleData["Input"]], 
          CellMargins -> {{88, 10}, {4, 7}}, ShowCellLabel -> False, 
          SpanMaxSize -> 1, FontSize -> 
          14, $CellContext`GeneratedCellStyles -> {
           "Output" -> "ExerciseOutput"}], 
         Cell[
          StyleData["ExerciseInput", "Printout"], 
          CellMargins -> {{88, 10}, {4, 7}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "ExerciseOutput", StyleDefinitions -> StyleData["Output"]], 
          CellMargins -> {{88, 10}, {10, 4}}, ShowCellLabel -> False, 
          FontSize -> 14], 
         Cell[
          StyleData["ExerciseOutput", "Printout"], 
          CellMargins -> {{88, 10}, {10, 4}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Picture"], CellMargins -> {{66, 10}, {10, 10}}, 
          CellGroupingRules -> "GraphicsGrouping", StyleMenuListing -> None], 
         
         Cell[
          StyleData["Picture", "Printout"], 
          CellMargins -> {{66, 10}, {8, 8}}]}, Closed]], 
      Cell[
       StyleData["ExerciseSummaryCell"], PageWidth -> 700, CellFrame -> 0, 
       CellMargins -> {{64, Inherited}, {8, 10}}, 
       CellGroupingRules -> {"SectionGrouping", 64}, PageBreakBelow -> False, 
       ShowCellLabel -> False, CellFrameMargins -> 0, ShowStringCharacters -> 
       False, FontFamily -> "Source Sans Pro", FontSize -> 18, FontColor -> 
       RGBColor[1, 1, 1], 
       GridBoxOptions -> {GridBoxBackground -> {"Columns" -> {{
              RGBColor[0.990997, 0.539528, 0.155779], 
              RGBColor[0.989487, 0.434699, 0.0320439]}}, "Rows" -> {{None}}}, 
         GridBoxItemSize -> {"Columns" -> {
             Scaled[0.7], 
             Scaled[0.3]}, "Rows" -> {{Automatic}}}}], 
      Cell[
       StyleData["ExerciseSummaryHeading"], ShowStringCharacters -> False, 
       FontFamily -> "Source Sans Pro", FontSize -> 18, FontColor -> 
       RGBColor[1, 1, 1]], 
      Cell[
       StyleData["ExerciseSummarySubheading"], ShowStringCharacters -> False, 
       FontFamily -> "Source Sans Pro", FontSize -> 15, FontColor -> 
       RGBColor[1., 0.9294117647058824, 0.7215686274509804]], 
      Cell[
       StyleData["ExercisePreviewButtonText"], ShowStringCharacters -> False, 
       FontFamily -> "Source Sans Pro", FontSize -> 14, FontSlant -> "Plain", 
       FontColor -> RGBColor[0.6, 0.6, 0.6]], 
      Cell[
       StyleData["ExercisePreviewButtonTextHighlight"], ShowStringCharacters -> 
       False, FontFamily -> "Source Sans Pro", FontSize -> 14, FontSlant -> 
       "Plain", FontColor -> 
       RGBColor[
        0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]]}, 
     Closed]], 
   Cell[
    CellGroupData[{
      Cell[
      "Inline and special formatting", "Section", 
       CellChangeTimes -> {{3.646681732592888*^9, 3.646681749414035*^9}}], 
      Cell[
       StyleData["Graphics"], MenuSortingValue -> None], 
      Cell[
       StyleData["Graphics3D"], MenuSortingValue -> None], 
      Cell[
       StyleData["StandardForm"], 
       InputAutoReplacements -> {
        "->" -> "\[Rule]", ":>" -> "\[RuleDelayed]", "<=" -> "\[LessEqual]", 
         ">=" -> "\[GreaterEqual]", "!=" -> "\[NotEqual]", "==" -> "\[Equal]",
          "@>" -> "\\[InlinePart]", "<->" -> "\[UndirectedEdge]", ParentList},
        LineSpacing -> {1.25, 0, 2}, SingleLetterItalics -> False, 
       StyleMenuListing -> None, FontFamily -> "Source Sans Pro", 
       PrivateFontOptions -> {"OperatorSubstitution" -> True}], 
      Cell[
       StyleData["OutputForm"], PageWidth -> DirectedInfinity[1], 
       TextAlignment -> Left, LineSpacing -> {0.6, 1}, 
       AutoQuoteCharacters -> {}, PasteAutoQuoteCharacters -> {}, 
       StyleMenuListing -> None, FontFamily -> "Source Sans Pro", 
       PrivateFontOptions -> {"OperatorSubstitution" -> True}], 
      Cell[
       StyleData["InputForm"], PageWidth -> DirectedInfinity[1], 
       InputAutoReplacements -> {}, AllowInlineCells -> False, Hyphenation -> 
       False, AutoQuoteCharacters -> {}, PasteAutoQuoteCharacters -> {}, 
       AutoSpacing -> False, NumberMarks -> True, AutoNumberFormatting -> 
       False, StyleMenuListing -> None, FontFamily -> "Source Sans Pro", 
       PrivateFontOptions -> {"OperatorSubstitution" -> True}], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["DetailsLink"], FontFamily -> "Source Sans Pro", FontSize :> 
          If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.9]], FontColor -> GrayLevel[0], 
          ButtonBoxOptions -> {
           ButtonFunction :> (
             Function[$CellContext`t, 
              NotebookFind[$CellContext`t, "Notes", All, CellStyle]; 
              NotebookFind[$CellContext`t, "NotesSection", All, CellStyle, 
                AutoScroll -> Top]][
              Documentation`HelpLookup[
               StringJoin["ref/", #]]]& ), ButtonSource -> ButtonContents, 
            Evaluator -> Automatic}], 
         Cell[
          StyleData["DetailsLink", "Printout"], FontFamily -> 
          "Source Sans Pro", FontSize :> If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.88]], FontColor -> GrayLevel[0]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["LinkAlt"], FontFamily -> "Source Sans Pro", FontSize :> 
          If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.9]], FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["LinkAlt", "Printout"], FontFamily -> "Source Sans Pro", 
          FontSize :> If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.88]], FontColor -> GrayLevel[0]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Hyperlink"], MenuSortingValue -> None, FontColor -> 
          RGBColor[0.3, 0.35, 0.5]], 
         Cell[
          StyleData["Hyperlink", "Printout"]]}, Closed]], 
      Cell[
       StyleData[
       "IndexNavigationLink", StyleDefinitions -> StyleData["Hyperlink"]], 
       MenuSortingValue -> None, FontColor -> 
       RGBColor[
        0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
      Cell[
       StyleData["Crosslink"], 
       ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
            
            NotebookLocate[#2, "OpenInNewWindow" -> 
             CurrentValue["HyperlinkModifierKey"]]}]& ), Evaluator -> None, 
         Method -> "Queued"}], 
      Cell[
       StyleData["VocabularyLink"], FontColor -> GrayLevel[0], 
       ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
            
            NotebookLocate[#2, "OpenInNewWindow" -> 
             CurrentValue["HyperlinkModifierKey"]]}]& ), Evaluator -> None, 
         Method -> "Queued"}], 
      Cell[
       StyleData["InlineCode"], SpanMaxSize -> 1, FontColor -> GrayLevel[0]], 
      
      Cell[
       StyleData["InlineCodeText"], SpanMaxSize -> 1, FontFamily -> 
       "Source Sans Pro", FontSize -> 0.95 Inherited], 
      Cell[
       StyleData["NoLabel"], ShowCellLabel -> 
       False, $CellContext`GeneratedCellStyles -> {
        "Output" -> "ExerciseOutput"}], 
      Cell[
       StyleData["MenuName"], FontFamily -> "Verdana", FontWeight -> "Bold", 
       FontColor -> GrayLevel[0.286275]], 
      Cell[
       StyleData["KeyEvent"], CellFrame -> {{0.5, 0.5}, {0.5, 0.5}}, 
       CellFrameMargins -> {{2, 2}, {2, 2}}, CellFrameColor -> GrayLevel[0.7],
        FontFamily -> "Verdana", FontColor -> GrayLevel[0.4]], 
      Cell[
       StyleData["KeyEventDelimiter"], FontColor -> GrayLevel[0.5]], 
      Cell[
       CellGroupData[{
         Cell["Key Styles", "Subsubsection"], 
         Cell[
          StyleData["Key0"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {"Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-2, -2}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}], 
         Cell[
          StyleData["Key1"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #2, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {
                 "ColumnsIndexed" -> {2 -> GrayLevel[0.8352941176470589]}, 
                  "Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-2, -2}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}], 
         Cell[
          StyleData["Key2"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #2, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #3, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {
                 "ColumnsIndexed" -> {
                   2 -> GrayLevel[0.8352941176470589], 3 -> 
                    GrayLevel[0.8352941176470589]}, "Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-2, -2}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}], 
         Cell[
          StyleData["Key3"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #2, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   TemplateBox[{"\[ThickSpace]", #3, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #4, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {
                 "ColumnsIndexed" -> {
                   2 -> GrayLevel[0.8352941176470589], 3 -> 
                    GrayLevel[0.8352941176470589], 4 -> 
                    GrayLevel[0.8352941176470589]}, "Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-2, -2}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Entity styles", "Subsubsection"], 
         Cell[
          StyleData["Entity"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               PaneSelectorBox[{True -> GridBox[{{
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontFamily -> "Source Sans Pro", 
                    FontWeight -> "Plain", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}},
                    BaselinePosition -> {1, 1}], False -> 
                 PaneBox[#, 
                   BaseStyle -> {
                    FontColor -> RGBColor[0.395437, 0.20595, 0.061158]}, 
                   BaselinePosition -> Baseline]}, 
                Dynamic[
                 CurrentValue[Evaluatable]], ImageSize -> Automatic, 
                BaselinePosition -> Baseline, 
                BaseStyle -> {FontFamily -> "Helvetica"}], FrameStyle -> 
               RGBColor[1., 0.504768, 0.], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityFrameless"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              PaneSelectorBox[{True -> GridBox[{{
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontFamily -> "Source Sans Pro", 
                    FontWeight -> "Plain", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                  BaselinePosition -> {1, 1}], False -> 
                PaneBox[#, 
                  BaseStyle -> {
                   FontColor -> RGBColor[0.395437, 0.20595, 0.061158]}, 
                  BaselinePosition -> Baseline]}, 
               Dynamic[
                CurrentValue[Evaluatable]], ImageSize -> Automatic, 
               BaselinePosition -> Baseline, 
               BaseStyle -> {FontFamily -> "Helvetica"}], #3, 
              BaseStyle -> {
               ShowStringCharacters -> False, LineIndent -> 0, 
                PrivateFontOptions -> {
                 FontWeight -> "Plain", "OperatorSubstitution" -> False}}]& ),
             Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityFramelessHot"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {
           DisplayFunction -> (PaneSelectorBox[{True -> GridBox[{{
                   
                   StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0]], 
                   StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0], Selectable -> 
                    False]}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 1}], False -> 
               PaneBox[#, BaseStyle -> {FontColor -> GrayLevel[0]}, 
                 BaselinePosition -> Baseline]}, 
              Dynamic[
               CurrentValue[Evaluatable]], ImageSize -> Automatic, 
              BaselinePosition -> Baseline, 
              BaseStyle -> {
               FontWeight -> "Plain", FontFamily -> "Helvetica", 
                ShowStringCharacters -> False, LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityClass"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               PaneSelectorBox[{True -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}},
                    BaselinePosition -> {1, 2}], False -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]]}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}},
                    BaselinePosition -> {1, 2}]}, 
                Dynamic[
                 CurrentValue[Evaluatable]], ImageSize -> Automatic, 
                BaselinePosition -> Baseline, 
                BaseStyle -> {FontFamily -> "Helvetica"}], FrameStyle -> 
               RGBColor[1., 0.504768, 0.], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityClassFrameless"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              PaneSelectorBox[{True -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                  BaselinePosition -> {1, 2}], False -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]]}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                  BaselinePosition -> {1, 2}]}, 
               Dynamic[
                CurrentValue[Evaluatable]], ImageSize -> Automatic, 
               BaselinePosition -> Baseline, 
               BaseStyle -> {FontFamily -> "Helvetica"}], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityClassFramelessHot"], ShowStringCharacters -> False,
           TemplateBoxOptions -> {
           DisplayFunction -> (PaneSelectorBox[{True -> GridBox[{{
                   PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                   
                   StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0]], 
                   StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0], Selectable -> 
                    False]}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 2}], False -> GridBox[{{
                   PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                   StyleBox[#, FontColor -> GrayLevel[0]]}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 2}]}, 
              Dynamic[
               CurrentValue[Evaluatable]], ImageSize -> Automatic, 
              BaselinePosition -> Baseline, 
              BaseStyle -> {
               FontWeight -> "Plain", FontFamily -> "Helvetica", 
                ShowStringCharacters -> False, LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityProperty"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               
               PaneBox[#, 
                BaseStyle -> {
                 FontSlant -> Italic, FontWeight -> Plain, FontFamily -> 
                  "Source Sans Pro", FontColor -> 
                  RGBColor[0.395437, 0.20595, 0.061158]}, BaselinePosition -> 
                Baseline], FrameStyle -> 
               RGBColor[0.94227, 0.703639, 0.033387], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityPropertyClass"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               PaneBox[
                GridBox[{{
                   PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], #}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 2}], 
                BaseStyle -> {
                 FontSlant -> Italic, FontWeight -> Plain, FontFamily -> 
                  "Source Sans Pro", FontColor -> 
                  RGBColor[0.395437, 0.20595, 0.061158]}, BaselinePosition -> 
                Baseline], FrameStyle -> 
               RGBColor[0.94227, 0.703639, 0.033387], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityValue"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              
              GridBox[{{#, #2}}, GridBoxAlignment -> {"Rows" -> {{Baseline}}},
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
               GridBoxSpacings -> {"Columns" -> {{0}}}, 
               BaselinePosition -> {1, 1}], Background -> 
              RGBColor[{0.9921568627450981, 0.9529411764705882, 
                0.8509803921568627}], BaselinePosition -> Baseline, 
              FrameMargins -> {{1, 1}, {1, 1}}, ImageMargins -> 2, FrameStyle -> 
              RGBColor[{0.9333333333333333, 0.8470588235294118, 
                0.5529411764705883}], RoundingRadius -> 5]& )}]}, Closed]]}, 
     Closed]]}, Visible -> False, FrontEndVersion -> 
  "11.1 for Mac OS X x86 (32-bit, 64-bit Kernel) (March 16, 2017)", 
  StyleDefinitions -> "StylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "p:177"->{
  Cell[660, 23, 420, 10, 
  70, "SectionDoubleDigit", "ExpressionUUID" -> "53cc3f3b-
   aba3-4367-9eb2-285a9183af26",
   CounterAssignments->{{"Section", 29}, {"Subsection", 0}, {
     "Subsubsection", 0}, {"Exercise", 0}},
   CellTags->"p:177"]},
 "i:1"->{
  Cell[1476, 46, 214, 4, 
  70, "CodeCaption", "ExpressionUUID" -> "285f9fd7-5343-49c7-95b9-b79e5f10f9ee
   ",
   CellTags->"i:1"]},
 "i:2"->{
  Cell[3707, 124, 327, 11, 
  70, "Text", "ExpressionUUID" -> "b932171f-a912-4b24-9c2f-6110eaed014b",
   CellTags->"i:2"]},
 "i:3"->{
  Cell[5239, 179, 287, 10, 
  70, "Text", "ExpressionUUID" -> "22d5103c-bd42-47c0-ad0b-fb7cac4a5b7b",
   CellTags->"i:3"]},
 "i:4"->{
  Cell[6457, 223, 217, 5, 
  70, "CodeCaption", "ExpressionUUID" -> "8ed87a46-3596-41d7-894e-e5eeb2ece04c
   ",
   CellTags->"i:4"]},
 "i:5"->{
  Cell[8491, 282, 211, 4, 
  70, "CodeCaption", "ExpressionUUID" -> "a6589622-e13a-44b8-894b-2af27fd428ee
   ",
   CellTags->"i:5"]},
 "LastCellOfAPage"->{
  Cell[8956, 297, 780, 23, 
  70, "Output", "ExpressionUUID" -> "2d0e077f-ab53-43c6-8269-8627f9d6057d",
   Evaluatable->False,
   CellTags->"LastCellOfAPage"],
  Cell[18563, 595, 1132, 37, 
  70, "Output", "ExpressionUUID" -> "8c5aa34e-1f95-4ca4-a122-d1a14fd4fcbb",
   Evaluatable->False,
   CellTags->"LastCellOfAPage"],
  Cell[31709, 1023, 2437, 48, 
  70, "Output", "ExpressionUUID" -> "304ff744-271d-4572-aae7-92b3a0a526fb",
   Evaluatable->False,
   CellTags->"LastCellOfAPage"],
  Cell[42714, 1368, 278, 7, 
  70, "Output", "ExpressionUUID" -> "371d254d-6185-4969-8280-2259fea6685b",
   Evaluatable->False,
   CellTags->"LastCellOfAPage"],
  Cell[51402, 1652, 432, 12, 
  70, "Text", "ExpressionUUID" -> "96e18496-dabd-4a5d-9821-a0ae235dee6d",
   CellTags->"LastCellOfAPage"],
  Cell[199714, 5667, 336, 9, 
  70, "Output", "ExpressionUUID" -> "837306dd-ed2e-45be-8a6d-edd7e5379496",
   Evaluatable->False,
   CellTags->"LastCellOfAPage"],
  Cell[200278, 5688, 9419, 263, 
  70, "VocabularyTable", "ExpressionUUID" -> "58d7e8d8-9585-41ed-
   bfa3-552a4a8c459a",
   CellTags->"LastCellOfAPage"],
  Cell[312851, 8391, 1275, 40, 
  70, "Exercise", "ExpressionUUID" -> "1b9bcacb-716a-4a0e-8bc0-516ebe1c9c37",
   CellTags->"LastCellOfAPage"],
  Cell[405286, 10710, 391, 9, 
  70, "MoreExplore", "ExpressionUUID" -> "ed3c5927-ce9e-4081-b91d-cd5ab3c86fec
   ",
   CellTags->"LastCellOfAPage"]},
 "p:178"->{
  Cell[9751, 323, 231, 6, 
  70, "CodeCaption", "ExpressionUUID" -> "aea99943-33c1-415a-83ee-c34f01e89f56
   ",
   CellTags->"p:178"]},
 "i:6"->{
  Cell[13000, 413, 374, 11, 
  70, "Text", "ExpressionUUID" -> "8088e86b-9142-4a38-a7b0-df734de590ce",
   CellTags->"i:6"]},
 "p:179"->{
  Cell[19710, 635, 183, 4, 
  70, "CodeCaption", "ExpressionUUID" -> "6111076d-734b-4cb3-837a-5ed8cabb3e83
   ",
   CellTags->"p:179"]},
 "i:7"->{
  Cell[22321, 722, 366, 12, 
  70, "Text", "ExpressionUUID" -> "e685c3b9-f346-4627-bd31-21556e4835c1",
   CellTags->"i:7"]},
 "i:8"->{
  Cell[25283, 829, 295, 8, 
  70, "CodeCaption", "ExpressionUUID" -> "181af151-5b53-45be-8585-497ca037a29e
   ",
   CellTags->"i:8"]},
 "i:9"->{
  Cell[30891, 993, 279, 9, 
  70, "CodeCaption", "ExpressionUUID" -> "574c71a9-fe37-44fc-9492-261da57b158d
   ",
   CellTags->"i:9"]},
 "i:10"->{
  Cell[34161, 1074, 344, 12, 
  70, "Text", "ExpressionUUID" -> "d24fcf9b-ba11-4725-8a6d-63aa28717ba1",
   CellTags->{"i:10", "p:180"}]},
 "p:180"->{
  Cell[34161, 1074, 344, 12, 
  70, "Text", "ExpressionUUID" -> "d24fcf9b-ba11-4725-8a6d-63aa28717ba1",
   CellTags->{"i:10", "p:180"}]},
 "i:11"->{
  Cell[35597, 1126, 291, 9, 
  70, "Text", "ExpressionUUID" -> "afcb4d88-75a1-4880-ba3b-26a55fba6cf5",
   CellTags->"i:11"]},
 "i:12"->{
  Cell[36865, 1170, 436, 14, 
  70, "Text", "ExpressionUUID" -> "5c85405c-061f-482f-82cf-4812a6def897",
   CellTags->"i:12"]},
 "i:13"->{
  Cell[38752, 1226, 264, 8, 
  70, "Text", "ExpressionUUID" -> "2556d1ca-791a-4c5d-a54b-541c86b36199",
   CellTags->"i:13"]},
 "i:14"->{
  Cell[39019, 1236, 264, 8, 
  70, "CodeCaption", "ExpressionUUID" -> "a0922f10-2e01-4420-949f-16c3e0e58df6
   ",
   CellTags->"i:14"]},
 "i:15"->{
  Cell[41857, 1337, 315, 11, 
  70, "Text", "ExpressionUUID" -> "bfb50fa5-f987-482d-8da7-4667e9acb28e",
   CellTags->"i:15"]},
 "i:16"->{
  Cell[44310, 1424, 221, 5, 
  70, "CodeCaption", "ExpressionUUID" -> "98d3dd0e-1dc3-460d-a8f6-30f55c0af6e8
   ",
   CellTags->{"i:16", "p:181"}]},
 "p:181"->{
  Cell[44310, 1424, 221, 5, 
  70, "CodeCaption", "ExpressionUUID" -> "98d3dd0e-1dc3-460d-a8f6-30f55c0af6e8
   ",
   CellTags->{"i:16", "p:181"}]},
 "i:17"->{
  Cell[45239, 1455, 233, 6, 
  70, "CodeCaption", "ExpressionUUID" -> "35dd7317-d4c3-48a6-9852-8b87fb4a4a5f
   ",
   CellTags->"i:17"]},
 "i:18"->{
  Cell[46079, 1485, 231, 6, 
  70, "CodeCaption", "ExpressionUUID" -> "0bb4c6d9-c9b0-40dc-8cec-62385c592b50
   ",
   CellTags->"i:18"]},
 "i:19"->{
  Cell[48418, 1549, 343, 11, 
  70, "Text", "ExpressionUUID" -> "069e6e98-e64e-4ef6-a603-649cbe54f59a",
   CellTags->"i:19"]},
 "i:20"->{
  Cell[51837, 1666, 331, 12, 
  70, "Text", "ExpressionUUID" -> "b5f9767f-1b94-415a-84e8-14fbaa6fe50e",
   CellTags->{"i:20", "p:182"}]},
 "p:182"->{
  Cell[51837, 1666, 331, 12, 
  70, "Text", "ExpressionUUID" -> "b5f9767f-1b94-415a-84e8-14fbaa6fe50e",
   CellTags->{"i:20", "p:182"}]},
 "i:21"->{
  Cell[81477, 2458, 392, 12, 
  70, "CodeCaption", "ExpressionUUID" -> "2aa9eacb-c84d-4a97-9edd-3e74b32772aa
   ",
   CellTags->"i:21"]},
 "i:22"->{
  Cell[101398, 2995, 315, 9, 
  70, "Text", "ExpressionUUID" -> "c314740a-e723-47a2-8e52-8c5ff6eef3bf",
   CellTags->"i:22"]},
 "i:23"->{
  Cell[140512, 4033, 281, 10, 
  70, "Text", "ExpressionUUID" -> "0d530c04-16a7-45b7-b12e-a0a9f5eb72b9",
   CellTags->"i:23"]},
 "i:24"->{
  Cell[197982, 5608, 318, 9, 
  70, "Text", "ExpressionUUID" -> "ad70bb26-8682-4c53-9fef-94ebd4f544b5",
   CellTags->"i:24"]},
 "p:183"->{
  Cell[200099, 5682, 176, 4, 
  70, "VocabularySection", "ExpressionUUID" -> "41753a4f-
   c674-4830-8724-6eba7c3bc3b3",
   CellTags->"p:183"]},
 "i:25"->{
  Cell[239170, 6589, 834, 24, 
  70, "Exercise", "ExpressionUUID" -> "e0ad99d4-f544-461f-9d34-2ed72d1f6f48",
   CellTags->"i:25"]},
 "i:26"->{
  Cell[255225, 6966, 1315, 40, 
  70, "Exercise", "ExpressionUUID" -> "a44b2f7b-6b1d-4f9e-9a27-8ca4857bdaf7",
   CellTags->"i:26"]},
 "i:27"->{
  Cell[293349, 7922, 742, 20, 
  70, "Exercise", "ExpressionUUID" -> "dac10470-4f0c-4289-9d32-bb146550b47c",
   CellTags->"i:27"]},
 "p:185"->{
  Cell[403416, 10643, 161, 4, 
  70, "QASection", "ExpressionUUID" -> "e4cdd159-fc85-443c-ae48-fced46015f57",
   
   CellTags->"p:185"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"p:177", 495437, 12540},
 {"i:1", 495695, 12547},
 {"i:2", 495838, 12552},
 {"i:3", 495972, 12556},
 {"i:4", 496106, 12560},
 {"i:5", 496250, 12565},
 {"LastCellOfAPage", 496406, 12570},
 {"p:178", 497811, 12605},
 {"i:6", 497957, 12610},
 {"p:179", 498094, 12614},
 {"i:7", 498241, 12619},
 {"i:8", 498376, 12623},
 {"i:9", 498521, 12628},
 {"i:10", 498667, 12633},
 {"p:180", 498817, 12637},
 {"i:11", 498966, 12641},
 {"i:12", 499103, 12645},
 {"i:13", 499241, 12649},
 {"i:14", 499378, 12653},
 {"i:15", 499526, 12658},
 {"i:16", 499664, 12662},
 {"p:181", 499824, 12667},
 {"i:17", 499983, 12672},
 {"i:18", 500131, 12677},
 {"i:19", 500279, 12682},
 {"i:20", 500417, 12686},
 {"p:182", 500567, 12690},
 {"i:21", 500716, 12694},
 {"i:22", 500865, 12699},
 {"i:23", 501003, 12703},
 {"i:24", 501142, 12707},
 {"p:183", 501281, 12711},
 {"i:25", 501437, 12716},
 {"i:26", 501580, 12720},
 {"i:27", 501724, 12724},
 {"p:185", 501868, 12728}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[660, 23, 420, 10, 70, "SectionDoubleDigit", "ExpressionUUID" -> \
"53cc3f3b-aba3-4367-9eb2-285a9183af26",
 CounterAssignments->{{"Section", 29}, {"Subsection", 0}, {
   "Subsubsection", 0}, {"Exercise", 0}},
 CellTags->"p:177"],
Cell[1083, 35, 390, 9, 70, "Text", "ExpressionUUID" -> \
"59fe08c8-ff36-40b4-a954-47614a4263cb"],
Cell[1476, 46, 214, 4, 70, "CodeCaption", "ExpressionUUID" -> \
"285f9fd7-5343-49c7-95b9-b79e5f10f9ee",
 CellTags->"i:1"],
Cell[CellGroupData[{
Cell[1715, 54, 492, 15, 70, "Input", "ExpressionUUID" -> \
"2e664132-5289-460f-a6ba-f0ee1854192c"],
Cell[2210, 71, 379, 11, 70, "Output", "ExpressionUUID" -> \
"62cc5b4c-617d-49ee-8270-abdfb89e02c8",
 Evaluatable->False]
}, Open  ]],
Cell[2604, 85, 195, 4, 70, "CodeCaption", "ExpressionUUID" -> \
"91c51327-80a3-446d-92bd-cc54042c1c99"],
Cell[CellGroupData[{
Cell[2824, 93, 372, 10, 70, "Input", "ExpressionUUID" -> \
"f67800ee-983b-4026-8f70-167902572f03"],
Cell[3199, 105, 493, 16, 70, "Output", "ExpressionUUID" -> \
"28ecbafb-f638-4655-8daf-d184b1560de2",
 Evaluatable->False]
}, Open  ]],
Cell[3707, 124, 327, 11, 70, "Text", "ExpressionUUID" -> \
"b932171f-a912-4b24-9c2f-6110eaed014b",
 CellTags->"i:2"],
Cell[4037, 137, 414, 13, 70, "CodeCaption", "ExpressionUUID" -> \
"0fc91897-ebe6-4e40-9367-d23bdeeca945"],
Cell[CellGroupData[{
Cell[4476, 154, 347, 9, 70, "Input", "ExpressionUUID" -> \
"c52c3d0d-f152-4754-830f-b69d70d81698"],
Cell[4826, 165, 398, 11, 70, "Output", "ExpressionUUID" -> \
"ceb180c8-c808-48a2-8819-80649a49c37e",
 Evaluatable->False]
}, Open  ]],
Cell[5239, 179, 287, 10, 70, "Text", "ExpressionUUID" -> \
"22d5103c-bd42-47c0-ad0b-fb7cac4a5b7b",
 CellTags->"i:3"],
Cell[5529, 191, 193, 4, 70, "CodeCaption", "ExpressionUUID" -> \
"e881bec0-1c4f-4c62-ae39-1ac802f77a44"],
Cell[CellGroupData[{
Cell[5747, 199, 216, 5, 70, "Input", "ExpressionUUID" -> \
"e0b4f87b-51f7-4247-90b3-aba981ffa7e4"],
Cell[5966, 206, 476, 14, 70, "Output", "ExpressionUUID" -> \
"8a14fc90-ef70-42ed-a9b6-86b4cce7e0b1",
 Evaluatable->False]
}, Open  ]],
Cell[6457, 223, 217, 5, 70, "CodeCaption", "ExpressionUUID" -> \
"8ed87a46-3596-41d7-894e-e5eeb2ece04c",
 CellTags->"i:4"],
Cell[CellGroupData[{
Cell[6699, 232, 386, 11, 70, "Input", "ExpressionUUID" -> \
"2760a5bd-6f48-463b-aecf-bf24a9858edb"],
Cell[7088, 245, 987, 20, 70, "Output", "ExpressionUUID" -> \
"25155c1e-97a7-413b-b51a-fc98e0950438",
 Evaluatable->False]
}, Open  ]],
Cell[8090, 268, 398, 12, 70, "Text", "ExpressionUUID" -> \
"b755653b-e3cd-4b74-b7b4-830f334ca0af"],
Cell[8491, 282, 211, 4, 70, "CodeCaption", "ExpressionUUID" -> \
"a6589622-e13a-44b8-894b-2af27fd428ee",
 CellTags->"i:5"],
Cell[CellGroupData[{
Cell[8727, 290, 226, 5, 70, "Input", "ExpressionUUID" -> \
"04c3de2f-4927-4006-8c2e-b845fcaf10bb"],
Cell[8956, 297, 780, 23, 70, "Output", "ExpressionUUID" -> \
"2d0e077f-ab53-43c6-8269-8627f9d6057d",
 Evaluatable->False,
 CellTags->"LastCellOfAPage"]
}, Open  ]],
Cell[9751, 323, 231, 6, 70, "CodeCaption", "ExpressionUUID" -> \
"aea99943-33c1-415a-83ee-c34f01e89f56",
 CellTags->"p:178"],
Cell[CellGroupData[{
Cell[10007, 333, 355, 9, 70, "Input", "ExpressionUUID" -> \
"3e2e3b32-647b-4bd0-ae2e-07173f7ca1c2"],
Cell[10365, 344, 1192, 25, 70, "Output", "ExpressionUUID" -> \
"4a40fdfe-07c8-4e87-9957-6f6fb269f41f",
 Evaluatable->False]
}, Open  ]],
Cell[11572, 372, 170, 4, 70, "CodeCaption", "ExpressionUUID" -> \
"311e7dee-1cef-434f-886a-5623e9cc9961"],
Cell[CellGroupData[{
Cell[11767, 380, 355, 9, 70, "Input", "ExpressionUUID" -> \
"aa604c51-99a5-4fbb-9c4d-3edd8ff69bc2"],
Cell[12125, 391, 860, 19, 70, "Output", "ExpressionUUID" -> \
"6aa10a54-34bb-4c7d-bc0c-3f0ffdc56dd4",
 Evaluatable->False]
}, Open  ]],
Cell[13000, 413, 374, 11, 70, "Text", "ExpressionUUID" -> \
"8088e86b-9142-4a38-a7b0-df734de590ce",
 CellTags->"i:6"],
Cell[13377, 426, 199, 4, 70, "CodeCaption", "ExpressionUUID" -> \
"85897c72-bff7-4082-b024-113e147adff7"],
Cell[CellGroupData[{
Cell[13601, 434, 192, 4, 70, "Input", "ExpressionUUID" -> \
"f617bc74-63c1-49d0-95b4-eaccda96365a"],
Cell[13796, 440, 1152, 37, 70, "Output", "ExpressionUUID" -> \
"4ff52954-de25-4e73-baf8-784d071d584a",
 Evaluatable->False]
}, Open  ]],
Cell[14963, 480, 168, 4, 70, "CodeCaption", "ExpressionUUID" -> \
"a2d9a5d8-72e1-406f-80df-9e73a7c0432f"],
Cell[CellGroupData[{
Cell[15156, 488, 228, 5, 70, "Input", "ExpressionUUID" -> \
"0947e929-049a-4e6b-89b3-1c4e749475fd"],
Cell[15387, 495, 527, 11, 70, "Output", "ExpressionUUID" -> \
"3ed27447-f95a-4ffd-9ac5-34ed0e6508f6",
 Evaluatable->False]
}, Open  ]],
Cell[15929, 509, 183, 4, 70, "CodeCaption", "ExpressionUUID" -> \
"ed62b3c8-8fb4-4da1-a08b-9f8dbc3d95aa"],
Cell[CellGroupData[{
Cell[16137, 517, 269, 6, 70, "Input", "ExpressionUUID" -> \
"4eefaafc-0087-4ede-bb31-cb85ec0e9631"],
Cell[16409, 525, 1191, 34, 70, "Output", "ExpressionUUID" -> \
"d340123c-140f-4e1a-8c7d-251b8443b631",
 Evaluatable->False]
}, Open  ]],
Cell[17615, 562, 391, 11, 70, "Text", "ExpressionUUID" -> \
"8db4586b-31d6-4a0b-bad3-688dea443e1e"],
Cell[18009, 575, 173, 4, 70, "CodeCaption", "ExpressionUUID" -> \
"806fa3d3-37ae-432b-bee5-da90c2686fbf"],
Cell[CellGroupData[{
Cell[18207, 583, 353, 10, 70, "Input", "ExpressionUUID" -> \
"7b296465-b2cd-4ad3-b4b3-d50764526988"],
Cell[18563, 595, 1132, 37, 70, "Output", "ExpressionUUID" -> \
"8c5aa34e-1f95-4ca4-a122-d1a14fd4fcbb",
 Evaluatable->False,
 CellTags->"LastCellOfAPage"]
}, Open  ]],
Cell[19710, 635, 183, 4, 70, "CodeCaption", "ExpressionUUID" -> \
"6111076d-734b-4cb3-837a-5ed8cabb3e83",
 CellTags->"p:179"],
Cell[CellGroupData[{
Cell[19918, 643, 394, 11, 70, "Input", "ExpressionUUID" -> \
"918a3d0d-3f8f-44d2-b440-1207cd5bc7ee"],
Cell[20315, 656, 443, 10, 70, "Output", "ExpressionUUID" -> \
"00eed6b0-bbde-4485-9c86-5dc6511eb87d",
 Evaluatable->False]
}, Open  ]],
Cell[20773, 669, 178, 4, 70, "CodeCaption", "ExpressionUUID" -> \
"45226e35-25f2-4756-a409-300489071fb5"],
Cell[CellGroupData[{
Cell[20976, 677, 425, 12, 70, "Input", "ExpressionUUID" -> \
"86e1519a-add9-498d-9cdc-856b27671dc0"],
Cell[21404, 691, 902, 28, 70, "Output", "ExpressionUUID" -> \
"40a0043a-4ac9-4662-8e18-0f88df7104e7",
 Evaluatable->False]
}, Open  ]],
Cell[22321, 722, 366, 12, 70, "Text", "ExpressionUUID" -> \
"e685c3b9-f346-4627-bd31-21556e4835c1",
 CellTags->"i:7"],
Cell[22690, 736, 237, 7, 70, "CodeCaption", "ExpressionUUID" -> \
"c0f8bbaa-c958-4e0b-b325-9df6977d009e"],
Cell[CellGroupData[{
Cell[22952, 747, 421, 13, 70, "Input", "ExpressionUUID" -> \
"40236244-7d1f-4218-9bc0-59830a3c77d7"],
Cell[23376, 762, 1892, 64, 70, "Output", "ExpressionUUID" -> \
"612d2983-bc09-46dc-b658-cfdd8d15c9b7",
 Evaluatable->False]
}, Open  ]],
Cell[25283, 829, 295, 8, 70, "CodeCaption", "ExpressionUUID" -> \
"181af151-5b53-45be-8585-497ca037a29e",
 CellTags->"i:8"],
Cell[CellGroupData[{
Cell[25603, 841, 468, 14, 70, "Input", "ExpressionUUID" -> \
"5f46a310-d75c-4ecd-887d-88fc60c6649d"],
Cell[26074, 857, 796, 25, 70, "Output", "ExpressionUUID" -> \
"8b3998d0-a2fe-4e01-9281-de2a28d0098c",
 Evaluatable->False]
}, Open  ]],
Cell[26885, 885, 300, 10, 70, "CodeCaption", "ExpressionUUID" -> \
"1d181803-5ffa-40fc-8175-95dcd331d71e"],
Cell[CellGroupData[{
Cell[27210, 899, 511, 15, 70, "Input", "ExpressionUUID" -> \
"af4aeba1-de22-4bd6-88af-4aa7cac3fcaf"],
Cell[27724, 916, 3152, 74, 70, "Output", "ExpressionUUID" -> \
"e2f6bca7-1342-40e1-b68f-734d87bd3c47",
 Evaluatable->False]
}, Open  ]],
Cell[30891, 993, 279, 9, 70, "CodeCaption", "ExpressionUUID" -> \
"574c71a9-fe37-44fc-9492-261da57b158d",
 CellTags->"i:9"],
Cell[CellGroupData[{
Cell[31195, 1006, 511, 15, 70, "Input", "ExpressionUUID" -> \
"d1cef060-ff39-400e-9bcf-8f8f887ca43b"],
Cell[31709, 1023, 2437, 48, 70, "Output", "ExpressionUUID" -> \
"304ff744-271d-4572-aae7-92b3a0a526fb",
 Evaluatable->False,
 CellTags->"LastCellOfAPage"]
}, Open  ]],
Cell[34161, 1074, 344, 12, 70, "Text", "ExpressionUUID" -> \
"d24fcf9b-ba11-4725-8a6d-63aa28717ba1",
 CellTags->{"i:10", "p:180"}],
Cell[34508, 1088, 212, 6, 70, "CodeCaption", "ExpressionUUID" -> \
"bc790624-c91a-4d9e-a5be-23e617ad3ca4"],
Cell[CellGroupData[{
Cell[34745, 1098, 312, 7, 70, "Input", "ExpressionUUID" -> \
"db4bd512-7ea9-4d63-8833-2c633d792749"],
Cell[35060, 1107, 522, 16, 70, "Output", "ExpressionUUID" -> \
"aeddaf1d-8d5a-4426-a36b-629ce10f8cf4",
 Evaluatable->False]
}, Open  ]],
Cell[35597, 1126, 291, 9, 70, "Text", "ExpressionUUID" -> \
"afcb4d88-75a1-4880-ba3b-26a55fba6cf5",
 CellTags->"i:11"],
Cell[35891, 1137, 187, 4, 70, "CodeCaption", "ExpressionUUID" -> \
"4a73b5aa-065b-4de7-8b0c-8c0d7a72718b"],
Cell[CellGroupData[{
Cell[36103, 1145, 313, 7, 70, "Input", "ExpressionUUID" -> \
"e8772f08-f43b-40bd-8fee-181dec9255c1"],
Cell[36419, 1154, 431, 13, 70, "Output", "ExpressionUUID" -> \
"4be490bf-e441-40d5-8caa-9ab37b320eba",
 Evaluatable->False]
}, Open  ]],
Cell[36865, 1170, 436, 14, 70, "Text", "ExpressionUUID" -> \
"5c85405c-061f-482f-82cf-4812a6def897",
 CellTags->"i:12"],
Cell[37304, 1186, 214, 6, 70, "CodeCaption", "ExpressionUUID" -> \
"ba3f62ff-e574-47a8-bec6-d0f2fd1601d9"],
Cell[CellGroupData[{
Cell[37543, 1196, 274, 7, 70, "Input", "ExpressionUUID" -> \
"f618cfc0-ff7f-4a9f-8301-f1768237927b"],
Cell[37820, 1205, 917, 18, 70, "Output", "ExpressionUUID" -> \
"5eb0431e-2e93-47e5-bd94-0bbf696dcf73",
 Evaluatable->False]
}, Open  ]],
Cell[38752, 1226, 264, 8, 70, "Text", "ExpressionUUID" -> \
"2556d1ca-791a-4c5d-a54b-541c86b36199",
 CellTags->"i:13"],
Cell[39019, 1236, 264, 8, 70, "CodeCaption", "ExpressionUUID" -> \
"a0922f10-2e01-4420-949f-16c3e0e58df6",
 CellTags->"i:14"],
Cell[CellGroupData[{
Cell[39308, 1248, 331, 9, 70, "Input", "ExpressionUUID" -> \
"e6988bf2-8ace-4593-835d-36055399bc0f"],
Cell[39642, 1259, 763, 23, 70, "Output", "ExpressionUUID" -> \
"5e94eaff-61d9-4284-abb6-5decdc263734",
 Evaluatable->False]
}, Open  ]],
Cell[40420, 1285, 262, 9, 70, "CodeCaption", "ExpressionUUID" -> \
"1b9d14ca-4b22-4ad8-a315-f657811de3d1"],
Cell[CellGroupData[{
Cell[40707, 1298, 369, 11, 70, "Input", "ExpressionUUID" -> \
"be995fa3-6266-4d6a-9bd3-45559241e75a"],
Cell[41079, 1311, 763, 23, 70, "Output", "ExpressionUUID" -> \
"73a4431c-63da-481a-8b11-05822b1bfef3",
 Evaluatable->False]
}, Open  ]],
Cell[41857, 1337, 315, 11, 70, "Text", "ExpressionUUID" -> \
"bfb50fa5-f987-482d-8da7-4667e9acb28e",
 CellTags->"i:15"],
Cell[42175, 1350, 187, 4, 70, "CodeCaption", "ExpressionUUID" -> \
"b0760045-6040-4fee-9411-eb10d2919f4b"],
Cell[CellGroupData[{
Cell[42387, 1358, 324, 8, 70, "Input", "ExpressionUUID" -> \
"788b81f2-122a-4a45-a0cc-dd821d7710b9"],
Cell[42714, 1368, 278, 7, 70, "Output", "ExpressionUUID" -> \
"371d254d-6185-4969-8280-2259fea6685b",
 Evaluatable->False,
 CellTags->"LastCellOfAPage"]
}, Open  ]],
Cell[43007, 1378, 326, 10, 70, "Text", "ExpressionUUID" -> \
"2b3e2c10-2415-4fa0-b1fa-5863f9153088"],
Cell[43336, 1390, 204, 5, 70, "CodeCaption", "ExpressionUUID" -> \
"c20ad5ac-41df-44ac-b13b-ed7e466691ba"],
Cell[CellGroupData[{
Cell[43565, 1399, 443, 12, 70, "Input", "ExpressionUUID" -> \
"cef1ef9f-a65a-4186-81c3-454b45ff74d6"],
Cell[44011, 1413, 284, 8, 70, "Output", "ExpressionUUID" -> \
"ac59f959-98e2-41ee-961c-d3311b0cb112",
 Evaluatable->False]
}, Open  ]],
Cell[44310, 1424, 221, 5, 70, "CodeCaption", "ExpressionUUID" -> \
"98d3dd0e-1dc3-460d-a8f6-30f55c0af6e8",
 CellTags->{"i:16", "p:181"}],
Cell[CellGroupData[{
Cell[44556, 1433, 437, 11, 70, "Input", "ExpressionUUID" -> \
"c02516a0-6904-49b6-88dc-2b55a2ae98dd"],
Cell[44996, 1446, 228, 6, 70, "Output", "ExpressionUUID" -> \
"1483a7a6-8169-4121-aa3f-610410a23ff4",
 Evaluatable->False]
}, Open  ]],
Cell[45239, 1455, 233, 6, 70, "CodeCaption", "ExpressionUUID" -> \
"35dd7317-d4c3-48a6-9852-8b87fb4a4a5f",
 CellTags->"i:17"],
Cell[CellGroupData[{
Cell[45497, 1465, 346, 9, 70, "Input", "ExpressionUUID" -> \
"c6ce9567-510b-46cd-afeb-67906e094be3"],
Cell[45846, 1476, 218, 6, 70, "Output", "ExpressionUUID" -> \
"4285e7ce-6820-493a-9b75-8ff3adb5571f",
 Evaluatable->False]
}, Open  ]],
Cell[46079, 1485, 231, 6, 70, "CodeCaption", "ExpressionUUID" -> \
"0bb4c6d9-c9b0-40dc-8cec-62385c592b50",
 CellTags->"i:18"],
Cell[CellGroupData[{
Cell[46335, 1495, 339, 7, 70, "Input", "ExpressionUUID" -> \
"a10dae26-fa4a-4b69-b47e-eab79f168737"],
Cell[46677, 1504, 922, 16, 70, "Output", "ExpressionUUID" -> \
"f75bcf4d-9945-4572-9b37-d88a9daeffa9",
 Evaluatable->False]
}, Open  ]],
Cell[47614, 1523, 190, 4, 70, "CodeCaption", "ExpressionUUID" -> \
"0cb096d7-633f-4096-b75a-2e2e94264154"],
Cell[CellGroupData[{
Cell[47829, 1531, 284, 6, 70, "Input", "ExpressionUUID" -> \
"dd4b60d4-0379-4e6b-b2c4-a6b2c7b0a038"],
Cell[48116, 1539, 287, 7, 70, "Output", "ExpressionUUID" -> \
"67a51f55-d6ef-4a23-8811-b442deba91d0",
 Evaluatable->False]
}, Open  ]],
Cell[48418, 1549, 343, 11, 70, "Text", "ExpressionUUID" -> \
"069e6e98-e64e-4ef6-a603-649cbe54f59a",
 CellTags->"i:19"],
Cell[48764, 1562, 297, 9, 70, "CodeCaption", "ExpressionUUID" -> \
"d6974f09-b54e-4513-8d87-64e1d2886be2"],
Cell[CellGroupData[{
Cell[49086, 1575, 262, 7, 70, "Input", "ExpressionUUID" -> \
"342980af-eeaf-4852-a28a-aedcbd2c012a"],
Cell[49351, 1584, 295, 8, 70, "Output", "ExpressionUUID" -> \
"4a07e65a-bde6-4f5d-a895-80a6ecc7df63",
 Evaluatable->False]
}, Open  ]],
Cell[49661, 1595, 291, 9, 70, "CodeCaption", "ExpressionUUID" -> \
"6a5af1bb-6e14-42c9-9137-2c7dd5a5bca5"],
Cell[CellGroupData[{
Cell[49977, 1608, 244, 6, 70, "Input", "ExpressionUUID" -> \
"1d8bd867-158f-446c-881d-973a1814d0a3"],
Cell[50224, 1616, 450, 9, 70, "Output", "ExpressionUUID" -> \
"18d85d33-0918-4802-a91c-3e7ece0ade75",
 Evaluatable->False]
}, Open  ]],
Cell[50689, 1628, 187, 4, 70, "CodeCaption", "ExpressionUUID" -> \
"6be246c1-9777-47aa-9656-0d75505b2c34"],
Cell[CellGroupData[{
Cell[50901, 1636, 284, 7, 70, "Input", "ExpressionUUID" -> \
"b355488f-d76d-46ba-8222-f45f2287a94b"],
Cell[51188, 1645, 199, 4, 70, "Output", "ExpressionUUID" -> \
"49240d05-2812-49b0-8de9-7a1860402d3c",
 Evaluatable->False]
}, Open  ]],
Cell[51402, 1652, 432, 12, 70, "Text", "ExpressionUUID" -> \
"96e18496-dabd-4a5d-9821-a0ae235dee6d",
 CellTags->"LastCellOfAPage"],
Cell[51837, 1666, 331, 12, 70, "Text", "ExpressionUUID" -> \
"b5f9767f-1b94-415a-84e8-14fbaa6fe50e",
 CellTags->{"i:20", "p:182"}],
Cell[52171, 1680, 234, 7, 70, "CodeCaption", "ExpressionUUID" -> \
"9ec83a79-6597-42de-abdc-b7cf0ef11a31"],
Cell[CellGroupData[{
Cell[52430, 1691, 229, 5, 70, "Input", "ExpressionUUID" -> \
"b0505d91-ddef-4cd2-a143-796051b4d733"],
Cell[52662, 1698, 28800, 757, 70, "Output", "ExpressionUUID" -> \
"c2cfb4a8-8179-4b89-882a-7365d01e6630",
 Evaluatable->False]
}, Open  ]],
Cell[81477, 2458, 392, 12, 70, "CodeCaption", "ExpressionUUID" -> \
"2aa9eacb-c84d-4a97-9edd-3e74b32772aa",
 CellTags->"i:21"],
Cell[CellGroupData[{
Cell[81894, 2474, 224, 5, 70, "Input", "ExpressionUUID" -> \
"9ee833e6-24f3-49c7-a17d-29c51f462217"],
Cell[82121, 2481, 19262, 511, 70, "Output", "ExpressionUUID" -> \
"6a9f4898-7ae0-40dc-bbdb-fcbc584c50d2",
 Evaluatable->False]
}, Open  ]],
Cell[101398, 2995, 315, 9, 70, "Text", "ExpressionUUID" -> \
"c314740a-e723-47a2-8e52-8c5ff6eef3bf",
 CellTags->"i:22"],
Cell[101716, 3006, 202, 5, 70, "CodeCaption", "ExpressionUUID" -> \
"3f2ceb4e-9726-4a73-adb1-a2795248f570"],
Cell[CellGroupData[{
Cell[101943, 3015, 235, 6, 70, "Input", "ExpressionUUID" -> \
"5f8124f8-96d0-4075-9098-8c71e5aa81a9"],
Cell[102181, 3023, 38316, 1007, 70, "Output", "ExpressionUUID" -> \
"8edb56e2-edf1-4607-8790-cadfe4327496",
 Evaluatable->False]
}, Open  ]],
Cell[140512, 4033, 281, 10, 70, "Text", "ExpressionUUID" -> \
"0d530c04-16a7-45b7-b12e-a0a9f5eb72b9",
 CellTags->"i:23"],
Cell[140796, 4045, 183, 4, 70, "CodeCaption", "ExpressionUUID" -> \
"72392d92-8dcc-426c-9d40-11d61c212776"],
Cell[CellGroupData[{
Cell[141004, 4053, 229, 5, 70, "Input", "ExpressionUUID" -> \
"55e1d318-b402-4088-ae6c-071fdf3fdb31"],
Cell[141236, 4060, 1618, 45, 70, "Output", "ExpressionUUID" -> \
"cc62a685-a077-48ba-8ba1-e40d330ad392",
 Evaluatable->False]
}, Open  ]],
Cell[142869, 4108, 176, 4, 70, "CodeCaption", "ExpressionUUID" -> \
"2b29533a-fce2-41c7-afe4-46cc63caccb9"],
Cell[CellGroupData[{
Cell[143070, 4116, 258, 7, 70, "Input", "ExpressionUUID" -> \
"2c130951-5407-4713-8479-431a382d2386"],
Cell[143331, 4125, 30072, 827, 70, "Output", "ExpressionUUID" -> \
"93121874-33ae-4d27-b373-426c77af20a4",
 Evaluatable->False]
}, Open  ]],
Cell[173418, 4955, 176, 4, 70, "CodeCaption", "ExpressionUUID" -> \
"ae56cbd0-e626-4a72-8fe7-a080ec96bd29"],
Cell[CellGroupData[{
Cell[173619, 4963, 303, 8, 70, "Input", "ExpressionUUID" -> \
"e4e48deb-cfe5-4552-99d3-721f39db1637"],
Cell[173925, 4973, 24042, 632, 70, "Output", "ExpressionUUID" -> \
"9d24566d-dba3-4386-be5e-80249737f2b6",
 Evaluatable->False]
}, Open  ]],
Cell[197982, 5608, 318, 9, 70, "Text", "ExpressionUUID" -> \
"ad70bb26-8682-4c53-9fef-94ebd4f544b5",
 CellTags->"i:24"],
Cell[198303, 5619, 235, 7, 70, "CodeCaption", "ExpressionUUID" -> \
"3ce63356-866d-40f6-bbe5-3cf02d1b4a63"],
Cell[CellGroupData[{
Cell[198563, 5630, 222, 5, 70, "Input", "ExpressionUUID" -> \
"eaaa32e9-0e7c-4044-87bb-1fc6b809641b"],
Cell[198788, 5637, 430, 10, 70, "Output", "ExpressionUUID" -> \
"eb2f11b7-f5bd-4572-a796-a9bcff88b896",
 Evaluatable->False]
}, Open  ]],
Cell[199233, 5650, 257, 7, 70, "CodeCaption", "ExpressionUUID" -> \
"58d5e1fe-f710-4fae-bc8e-e8d5fc90e456"],
Cell[CellGroupData[{
Cell[199515, 5661, 196, 4, 70, "Input", "ExpressionUUID" -> \
"1484bc83-3465-47b6-9de0-4d3c5b415160"],
Cell[199714, 5667, 336, 9, 70, "Output", "ExpressionUUID" -> \
"837306dd-ed2e-45be-8a6d-edd7e5379496",
 Evaluatable->False,
 CellTags->"LastCellOfAPage"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[200099, 5682, 176, 4, 70, "VocabularySection", "ExpressionUUID" -> \
"41753a4f-c674-4830-8724-6eba7c3bc3b3",
 CellTags->"p:183"],
Cell[200278, 5688, 9419, 263, 70, "VocabularyTable", "ExpressionUUID" -> \
"58d7e8d8-9585-41ed-bfa3-552a4a8c459a",
 CellTags->"LastCellOfAPage"]
}, Open  ]],
Cell[CellGroupData[{
Cell[209734, 5956, 1780, 46, 70, "ExerciseSection", "ExpressionUUID" -> \
"0d0ad356-782b-4a09-86e7-7cc725aae97d"],
Cell[CellGroupData[{
Cell[211539, 6006, 1453, 45, 70, "ExerciseSummaryCell", "ExpressionUUID" -> \
"b7588562-5abc-4472-a3d0-6f51c618def1"],
Cell[CellGroupData[{
Cell[213017, 6055, 815, 24, 70, "Exercise", "ExpressionUUID" -> \
"8ecef57e-2b69-433c-bbd4-033508fe7a60"],
Cell[213835, 6081, 3988, 87, 70, "ExerciseOutput", "ExpressionUUID" -> \
"18d6579a-c045-4e19-b1a6-160ad83fa466"]
}, Closed]],
Cell[CellGroupData[{
Cell[217860, 6173, 728, 20, 70, "Exercise", "ExpressionUUID" -> \
"355ab225-cdf1-435b-864d-461f1533ddc0"],
Cell[218591, 6195, 2053, 54, 70, "ExerciseOutput", "ExpressionUUID" -> \
"b51fcd7a-4470-42a9-a99e-0c75dc477055"]
}, Closed]],
Cell[CellGroupData[{
Cell[220681, 6254, 761, 21, 70, "Exercise", "ExpressionUUID" -> \
"886fb4c0-5000-4cab-a545-01d412332f7e"],
Cell[221445, 6277, 5193, 93, 70, "ExerciseOutput", "ExpressionUUID" -> \
"47998158-0821-467d-9334-cf919786fd07"]
}, Closed]],
Cell[CellGroupData[{
Cell[226675, 6375, 853, 22, 70, "Exercise", "ExpressionUUID" -> \
"9ede4dd8-97fb-4236-a8da-15bae1d966bd"],
Cell[227531, 6399, 11602, 185, 70, "ExerciseOutput", "ExpressionUUID" -> \
"939647bd-e4d1-4815-ae33-86a28796221e"]
}, Closed]],
Cell[CellGroupData[{
Cell[239170, 6589, 834, 24, 70, "Exercise", "ExpressionUUID" -> \
"e0ad99d4-f544-461f-9d34-2ed72d1f6f48",
 CellTags->"i:25"],
Cell[240007, 6615, 6908, 140, 70, "ExerciseOutput", "ExpressionUUID" -> \
"7f56db5a-6c2d-4b3a-915a-bddd8e977176"]
}, Closed]],
Cell[CellGroupData[{
Cell[246952, 6760, 1263, 35, 70, "Exercise", "ExpressionUUID" -> \
"1db8ad4c-d2fe-46ad-a7ef-7b82ac1163dc"],
Cell[248218, 6797, 6970, 164, 70, "ExerciseOutput", "ExpressionUUID" -> \
"5291b86b-932a-4efe-86ef-539aad4873c2"]
}, Closed]],
Cell[CellGroupData[{
Cell[255225, 6966, 1315, 40, 70, "Exercise", "ExpressionUUID" -> \
"a44b2f7b-6b1d-4f9e-9a27-8ca4857bdaf7",
 CellTags->"i:26"],
Cell[256543, 7008, 3600, 92, 70, "ExerciseOutput", "ExpressionUUID" -> \
"d36fa6fe-b007-4382-974b-20f86067dae8"]
}, Closed]],
Cell[CellGroupData[{
Cell[260180, 7105, 964, 27, 70, "Exercise", "ExpressionUUID" -> \
"8010156d-4d40-41b0-9d5a-3472576ad1cc"],
Cell[261147, 7134, 3525, 67, 70, "ExerciseOutput", "ExpressionUUID" -> \
"1cdf46a4-fcd2-4687-a81c-e35dac81a7ec"]
}, Closed]],
Cell[CellGroupData[{
Cell[264709, 7206, 767, 21, 70, "Exercise", "ExpressionUUID" -> \
"f0b66fa9-2ae4-47c8-aeed-7b5ddac8c3d2"],
Cell[265479, 7229, 9870, 200, 70, "ExerciseOutput", "ExpressionUUID" -> \
"e56dd932-ab78-445d-9f62-a4d2291b54f7"]
}, Closed]],
Cell[CellGroupData[{
Cell[275386, 7434, 891, 26, 70, "Exercise", "ExpressionUUID" -> \
"6daf639b-a740-410c-956c-379e35641bab"],
Cell[276280, 7462, 3818, 74, 70, "ExerciseOutput", "ExpressionUUID" -> \
"690307c8-b6ba-4d94-8a4e-d61592455148"]
}, Closed]],
Cell[CellGroupData[{
Cell[280135, 7541, 732, 20, 70, "Exercise", "ExpressionUUID" -> \
"ce3045c2-1b54-4600-bc2b-840759fa7ee2"],
Cell[280870, 7563, 1695, 43, 70, "ExerciseOutput", "ExpressionUUID" -> \
"b4e2d642-23d2-47c5-aa5a-36ff12bf15c7"]
}, Closed]],
Cell[CellGroupData[{
Cell[282602, 7611, 729, 20, 70, "Exercise", "ExpressionUUID" -> \
"820bc882-4877-4521-9b33-d37eae1e5eda"],
Cell[283334, 7633, 1660, 43, 70, "ExerciseOutput", "ExpressionUUID" -> \
"5f0f692e-ec66-42eb-9284-4772e9e2d385"]
}, Closed]],
Cell[CellGroupData[{
Cell[285031, 7681, 920, 26, 70, "Exercise", "ExpressionUUID" -> \
"6168e1c7-80a5-4829-95bc-fe7289e4adf3"],
Cell[285954, 7709, 3167, 77, 70, "ExerciseOutput", "ExpressionUUID" -> \
"6a2a49de-3c9f-4628-aee4-493d7381deea"]
}, Closed]],
Cell[CellGroupData[{
Cell[289158, 7791, 720, 20, 70, "Exercise", "ExpressionUUID" -> \
"2e45159e-7fba-40d7-a83a-7cec404c3b8f"],
Cell[289881, 7813, 1349, 38, 70, "ExerciseOutput", "ExpressionUUID" -> \
"86e4340d-4404-4fd4-af1a-174563329b31"]
}, Closed]],
Cell[CellGroupData[{
Cell[291267, 7856, 796, 23, 70, "Exercise", "ExpressionUUID" -> \
"e88c73ef-3d83-450c-9ca5-09eae926203c"],
Cell[292066, 7881, 1246, 36, 70, "ExerciseOutput", "ExpressionUUID" -> \
"3520c54e-b565-4abe-b9c4-b636a4bc2791"]
}, Closed]],
Cell[CellGroupData[{
Cell[293349, 7922, 742, 20, 70, "Exercise", "ExpressionUUID" -> \
"dac10470-4f0c-4289-9d32-bb146550b47c",
 CellTags->"i:27"],
Cell[294094, 7944, 4133, 90, 70, "ExerciseOutput", "ExpressionUUID" -> \
"fc4b82aa-ee36-4355-b876-385ca0d6cd1c"]
}, Closed]],
Cell[CellGroupData[{
Cell[298264, 8039, 771, 21, 70, "Exercise", "ExpressionUUID" -> \
"69fed7e7-fdc9-47c2-bcb5-3ed14ab3f8ad"],
Cell[299038, 8062, 2594, 59, 70, "ExerciseOutput", "ExpressionUUID" -> \
"7fabdfad-12c8-40c2-8087-b05831cdb9bd"]
}, Closed]],
Cell[CellGroupData[{
Cell[301669, 8126, 809, 21, 70, "Exercise", "ExpressionUUID" -> \
"70d37fc4-3ff2-454f-a43b-e062d2b61756"],
Cell[302481, 8149, 4023, 75, 70, "ExerciseOutput", "ExpressionUUID" -> \
"b6765e1a-f15a-4447-85d2-f6a0fa643f44"]
}, Closed]],
Cell[CellGroupData[{
Cell[306541, 8229, 733, 20, 70, "Exercise", "ExpressionUUID" -> \
"093165f0-4d77-4f69-a1e3-2dde24f3c703"],
Cell[307277, 8251, 3143, 67, 70, "ExerciseOutput", "ExpressionUUID" -> \
"1cf95e1c-3203-4e28-bbbb-e4d0db3645b7"]
}, Closed]],
Cell[CellGroupData[{
Cell[310457, 8323, 718, 20, 70, "Exercise", "ExpressionUUID" -> \
"82b641d6-1472-4f7a-97a5-a895fa445c93"],
Cell[311178, 8345, 1636, 41, 70, "ExerciseOutput", "ExpressionUUID" -> \
"11b73d93-a762-4897-bce3-693ec062de47"]
}, Closed]],
Cell[CellGroupData[{
Cell[312851, 8391, 1275, 40, 70, "Exercise", "ExpressionUUID" -> \
"1b9bcacb-716a-4a0e-8bc0-516ebe1c9c37",
 CellTags->"LastCellOfAPage"],
Cell[314129, 8433, 2522, 68, 70, "ExerciseOutput", "ExpressionUUID" -> \
"cf8e51e8-8bc8-4e70-91ff-c05108a8920b"]
}, Closed]],
Cell[CellGroupData[{
Cell[316688, 8506, 860, 22, 70, "Exercise", "ExpressionUUID" -> \
"23dd6585-f043-4d0c-be0d-d5dbacf59b26"],
Cell[317551, 8530, 3056, 71, 70, "ExerciseOutput", "ExpressionUUID" -> \
"f65c0b09-679a-4026-a7fd-00ddb443e6d2"]
}, Closed]],
Cell[CellGroupData[{
Cell[320644, 8606, 733, 20, 70, "Exercise", "ExpressionUUID" -> \
"6ac63e59-b9bc-4dcc-acaa-9a877685d53b"],
Cell[321380, 8628, 2351, 63, 70, "ExerciseOutput", "ExpressionUUID" -> \
"0e1eed3f-ec4b-4520-8742-62bdf5b9a217"]
}, Closed]],
Cell[CellGroupData[{
Cell[323768, 8696, 729, 20, 70, "Exercise", "ExpressionUUID" -> \
"093fbcd6-4ffb-41c1-8206-8c5985f47306"],
Cell[324500, 8718, 3846, 87, 70, "ExerciseOutput", "ExpressionUUID" -> \
"635ab79f-bfdf-48ee-92da-16436d6d7b83"]
}, Closed]],
Cell[CellGroupData[{
Cell[328383, 8810, 770, 21, 70, "Exercise", "ExpressionUUID" -> \
"ac104319-0bf3-4f5c-b5b1-72c7f79847f8"],
Cell[329156, 8833, 3359, 82, 70, "ExerciseOutput", "ExpressionUUID" -> \
"1c555e6e-121c-4406-848b-98b54c35ebdc"]
}, Closed]],
Cell[CellGroupData[{
Cell[332552, 8920, 752, 21, 70, "Exercise", "ExpressionUUID" -> \
"c2b304ee-be20-441d-8e53-e657d2440e68"],
Cell[333307, 8943, 5676, 120, 70, "ExerciseOutput", "ExpressionUUID" -> \
"69a4f918-85bf-4646-bed2-ce842578248b"]
}, Closed]],
Cell[CellGroupData[{
Cell[339020, 9068, 755, 21, 70, "Exercise", "ExpressionUUID" -> \
"55716bfa-cc29-441c-9dc4-4c10382cfc6f"],
Cell[339778, 9091, 5116, 111, 70, "ExerciseOutput", "ExpressionUUID" -> \
"8b8f1d72-5873-4420-9c56-4823d73f6294"]
}, Closed]],
Cell[CellGroupData[{
Cell[344931, 9207, 874, 26, 70, "Exercise", "ExpressionUUID" -> \
"26c9fd4d-590a-44bc-a87e-89fe09409464"],
Cell[345808, 9235, 2534, 56, 70, "ExerciseOutput", "ExpressionUUID" -> \
"21ea5991-71df-4874-9591-3d4f6d5e1bde"]
}, Closed]],
Cell[CellGroupData[{
Cell[348379, 9296, 820, 22, 70, "Exercise", "ExpressionUUID" -> \
"355f2f02-862e-44ff-8fc1-33f129d01ae6"],
Cell[349202, 9320, 1095, 31, 70, "ExerciseOutput", "ExpressionUUID" -> \
"9c8a7be7-c464-4c17-93a8-f0acbb82c875"]
}, Closed]],
Cell[CellGroupData[{
Cell[350334, 9356, 728, 20, 70, "Exercise", "ExpressionUUID" -> \
"5f23e6df-23d6-4652-89b8-e1c1f06dd36d"],
Cell[351065, 9378, 1818, 45, 70, "ExerciseOutput", "ExpressionUUID" -> \
"5f632437-2f1e-44ba-8e3c-634842d9f311"]
}, Closed]],
Cell[CellGroupData[{
Cell[352920, 9428, 753, 21, 70, "Exercise", "ExpressionUUID" -> \
"cdbcb782-040a-44ca-b7c5-eb5101dd3238"],
Cell[353676, 9451, 2122, 52, 70, "ExerciseOutput", "ExpressionUUID" -> \
"82756bef-263c-4ecb-9e5f-a8e5f454647b"]
}, Closed]],
Cell[CellGroupData[{
Cell[355835, 9508, 726, 20, 70, "Exercise", "ExpressionUUID" -> \
"8f5e4edf-2d34-4d5d-867d-fcd181902929"],
Cell[356564, 9530, 36312, 830, 70, "ExerciseOutput", "ExpressionUUID" -> \
"2e4a7c97-8c54-4609-ad28-d367606c30d4"]
}, Closed]],
Cell[CellGroupData[{
Cell[392913, 10365, 782, 21, 70, "Exercise", "ExpressionUUID" -> \
"d511fba6-6114-4b03-9643-f0464f4428e4"],
Cell[393698, 10388, 7315, 176, 70, "ExerciseOutput", "ExpressionUUID" -> \
"bf637e7b-92e2-4d57-9a86-4fc5720a73f4"]
}, Closed]],
Cell[CellGroupData[{
Cell[401050, 10569, 930, 27, 70, "Exercise", "ExpressionUUID" -> \
"e7fbcf9d-9be2-4294-bc77-44b51bf3b28b"],
Cell[401983, 10598, 1372, 38, 70, "ExerciseOutput", "ExpressionUUID" -> \
"744e81e5-8bc8-491a-b1b3-b0590601e621"]
}, Closed]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[403416, 10643, 161, 4, 70, "QASection", "ExpressionUUID" -> \
"e4cdd159-fc85-443c-ae48-fced46015f57",
 CellTags->"p:185"],
Cell[403580, 10649, 271, 9, 70, "Question", "ExpressionUUID" -> \
"86631de9-084c-4c09-97bc-4900ddaffc20"],
Cell[403854, 10660, 388, 9, 70, "Answer", "ExpressionUUID" -> \
"9a8fa50e-c424-407d-a36d-a95b18fb8a9a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[404279, 10674, 156, 4, 70, "TechNoteSection", "ExpressionUUID" -> \
"04b2001a-1738-4641-9ac8-3ed9ec5a8934"],
Cell[404438, 10680, 643, 19, 70, "TechNote", "ExpressionUUID" -> \
"1cd79ff5-2f10-4d73-9ac3-1778092d0402"]
}, Open  ]],
Cell[CellGroupData[{
Cell[405118, 10704, 165, 4, 70, "MoreExploreSection", "ExpressionUUID" -> \
"fa40186b-026d-4d6a-8464-334e7aa122a9"],
Cell[405286, 10710, 391, 9, 70, "MoreExplore", "ExpressionUUID" -> \
"ed3c5927-ce9e-4081-b91d-cd5ab3c86fec",
 CellTags->"LastCellOfAPage"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
(* NotebookSignature TTcxBYwjxdPollIaGQ7bldrs *)
