(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    373462,       8718]
NotebookOptionsPosition[    266477,       6446]
NotebookOutlinePosition[    361383,       8422]
CellTagsIndexPosition[    360707,       8393]
WindowTitle->Associations: Elementary Introduction to the Wolfram Language
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[BoxData[
 InterpretationBox[Cell[
  "Associations", "SectionInline",ExpressionUUID->
   "7172ed7f-ff78-4674-9d82-bcdca8af6c05"],
  $Line = 0; Null]], "SectionDoubleDigit",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CounterAssignments->{{"Section", 33}, {"Subsection", 0}, {
   "Subsubsection", 0}, {"Exercise", 0}},
 CellTags->"p:205",
 CellLabel->"In[37]:=",ExpressionUUID->"045a4ebb-b383-44f9-93cf-65f018661b08"],

Cell[TextData[{
 StyleBox["Associations",
  FontSlant->"Italic"],
 " are a kind of generalization of lists, in which",
 " every element has a key as well as a value. ",
 ButtonBox["Counts",
  BaseStyle->"Link"],
 " is a typical function that produces an association. "
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:1",ExpressionUUID->"28d2130c-1f0c-47d7-b4ad-033d8ae709f5"],

Cell[TextData[{
 ButtonBox["Counts",
  BaseStyle->"Link"],
 " gives an association ",
 "that reports how many times each different element occurs",
 ":"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"87f1420e-e993-4eac-9e52-a3e99dd0c69f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Counts", "[", 
  RowBox[{"{", 
   RowBox[{
   "a", ",", "a", ",", "b", ",", "c", ",", "a", ",", "a", ",", "b", ",", "c", 
    ",", "c", ",", "a", ",", "a"}], "}"}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[1]:=",ExpressionUUID->"85d079eb-41f1-45c9-9cc8-a573f5b6829a"],

Cell[BoxData[
 RowBox[{"\[LeftAssociation]", 
  RowBox[{
   RowBox[{"a", "\[Rule]", "6"}], ",", 
   RowBox[{"b", "\[Rule]", "2"}], ",", 
   RowBox[{"c", "\[Rule]", "3"}]}], "\[RightAssociation]"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[1]=",ExpressionUUID->"3f5b2909-5a6e-4a24-a4f6-49ee51d4e18d"]
}, Open  ]],

Cell[TextData[{
 "You can get the value associated with a particular key using ",
 ButtonBox["[ ... ]",
  BaseStyle->"Link",
  ButtonData->"Key"],
 "."
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:2",ExpressionUUID->"77a6ce72-3d37-463c-9d60-21b99712442d"],

Cell[TextData[{
 "Find the value associated with ",
 Cell[BoxData[
 "c"], "InlineCode",ExpressionUUID->"3b7b1d6f-a70b-4d57-978f-2c79239f5a5b"],
 " in the association:"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"0a0940da-603b-43ed-8577-b6dc480fa9c7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"\[LeftAssociation]", 
   RowBox[{
    RowBox[{"a", "\[Rule]", "6"}], ",", 
    RowBox[{"b", "\[Rule]", "2"}], ",", 
    RowBox[{"c", "\[Rule]", "3"}]}], "\[RightAssociation]"}], "[", "c", 
  "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[2]:=",ExpressionUUID->"f70366f1-b430-49b8-ae5f-ceb3287baad4"],

Cell[BoxData["3"], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[2]=",ExpressionUUID->"184a512f-6e0f-4382-bac4-30a40cc4625d"]
}, Open  ]],

Cell["\<\
Operations that work on lists typically also work on \
associations\[LongDash]but apply themselves only to the values, not the keys. \
\>", "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"33739069-aa82-4c70-a252-33c72b9874a4"],

Cell["This adds 500 to each value in the association:", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"72929ed2-08ee-4a9a-bc57-a30859830cb1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"\[LeftAssociation]", 
   RowBox[{
    RowBox[{"a", "\[Rule]", "6"}], ",", 
    RowBox[{"b", "\[Rule]", "2"}], ",", 
    RowBox[{"c", "\[Rule]", "3"}]}], "\[RightAssociation]"}], "+", 
  "500"}]], "Input",
 Deletable->False,
 CellLabel->"In[3]:=",ExpressionUUID->"2a9d4af6-1a2c-4992-b6a8-b179d9ce2ad3"],

Cell[BoxData[
 RowBox[{"\[LeftAssociation]", 
  RowBox[{
   RowBox[{"a", "\[Rule]", "506"}], ",", 
   RowBox[{"b", "\[Rule]", "502"}], ",", 
   RowBox[{"c", "\[Rule]", "503"}]}], "\[RightAssociation]"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[3]=",ExpressionUUID->"c2b3fa39-192d-4601-82e4-e95e8ec3d826"]
}, Open  ]],

Cell[TextData[{
 Cell[BoxData[
  ButtonBox["/@",
   BaseStyle->"Link",
   ButtonData->"Map"]], "InlineCode",ExpressionUUID->
  "2b87b483-a7e7-4aa0-8264-1c6bf8b4581c"],
 " applies a function to each value in the association:"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"2ef631b8-5ac9-482a-9b31-5d87a1b9a17e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"f", "/@", 
  RowBox[{"\[LeftAssociation]", 
   RowBox[{
    RowBox[{"a", "\[Rule]", "6"}], ",", 
    RowBox[{"b", "\[Rule]", "2"}], ",", 
    RowBox[{"c", "\[Rule]", "3"}]}], "\[RightAssociation]"}]}]], "Input",
 Deletable->False,
 CellLabel->"In[4]:=",ExpressionUUID->"c9a92723-972e-4639-97c5-f967406efd06"],

Cell[BoxData[
 RowBox[{"\[LeftAssociation]", 
  RowBox[{
   RowBox[{"a", "\[Rule]", 
    RowBox[{"f", "[", "6", "]"}]}], ",", 
   RowBox[{"b", "\[Rule]", 
    RowBox[{"f", "[", "2", "]"}]}], ",", 
   RowBox[{"c", "\[Rule]", 
    RowBox[{"f", "[", "3", "]"}]}]}], "\[RightAssociation]"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[4]=",ExpressionUUID->"11b145d5-a7be-4450-be60-48b3ec751171"]
}, Open  ]],

Cell[TextData[{
 ButtonBox["Total",
  BaseStyle->"Link"],
 " gives the total of the values:"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:3",ExpressionUUID->"b57a215c-1d9d-417f-ab39-6144b6f37d91"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Total", "[", 
  RowBox[{"\[LeftAssociation]", 
   RowBox[{
    RowBox[{"a", "\[Rule]", "6"}], ",", 
    RowBox[{"b", "\[Rule]", "2"}], ",", 
    RowBox[{"c", "\[Rule]", "3"}]}], "\[RightAssociation]"}], "]"}]], "Input",\

 Deletable->False,
 CellLabel->"In[5]:=",ExpressionUUID->"cb4ada6b-2ae1-4848-96ca-36a5f617e77b"],

Cell[BoxData["11"], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[5]=",ExpressionUUID->"3ee7e145-cf47-427b-8aef-1a5124a88af5"]
}, Open  ]],

Cell[TextData[{
 ButtonBox["Sort",
  BaseStyle->"Link"],
 " operates on the values:"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:4",ExpressionUUID->"51bbca54-5c9b-44f5-a9e7-0c4479218754"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Sort", "[", 
  RowBox[{"\[LeftAssociation]", 
   RowBox[{
    RowBox[{"a", "\[Rule]", "6"}], ",", 
    RowBox[{"b", "\[Rule]", "2"}], ",", 
    RowBox[{"c", "\[Rule]", "3"}]}], "\[RightAssociation]"}], "]"}]], "Input",\

 Deletable->False,
 CellLabel->"In[6]:=",ExpressionUUID->"8539f924-cadd-4ed4-bb73-f3fb939b458f"],

Cell[BoxData[
 RowBox[{"\[LeftAssociation]", 
  RowBox[{
   RowBox[{"b", "\[Rule]", "2"}], ",", 
   RowBox[{"c", "\[Rule]", "3"}], ",", 
   RowBox[{"a", "\[Rule]", "6"}]}], "\[RightAssociation]"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[6]=",ExpressionUUID->"406ebab5-0702-418f-a12d-38e74fb53126"]
}, Open  ]],

Cell[TextData[{
 ButtonBox["KeySort",
  BaseStyle->"Link"],
 " operates on the keys:"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:5",ExpressionUUID->"5f024e3c-e4c6-4776-ac84-f0b52e0f5e33"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"KeySort", "[", 
  RowBox[{"\[LeftAssociation]", 
   RowBox[{
    RowBox[{"c", "\[Rule]", "1"}], ",", 
    RowBox[{"b", "\[Rule]", "2"}], ",", 
    RowBox[{"a", "\[Rule]", "4"}]}], "\[RightAssociation]"}], "]"}]], "Input",\

 Deletable->False,
 CellLabel->"In[7]:=",ExpressionUUID->"ab959cae-2698-4818-964c-02f12e277186"],

Cell[BoxData[
 RowBox[{"\[LeftAssociation]", 
  RowBox[{
   RowBox[{"a", "\[Rule]", "4"}], ",", 
   RowBox[{"b", "\[Rule]", "2"}], ",", 
   RowBox[{"c", "\[Rule]", "1"}]}], "\[RightAssociation]"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellTags->"LastCellOfAPage",
 CellLabel->"Out[7]=",ExpressionUUID->"b05a7ab2-1f80-4692-a847-4caae02f3158"]
}, Open  ]],

Cell[TextData[{
 "The functions ",
 ButtonBox["Keys",
  BaseStyle->"Link"],
 " and ",
 ButtonBox["Values",
  BaseStyle->"Link"],
 " extract the keys and values of an association. "
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->{
  "i:6", "p:206"},ExpressionUUID->"4cbc9a6f-a299-4a1d-a4ea-f62b7edccb3b"],

Cell["Get the list of keys in the association:", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"9ac44f19-7487-4553-bbb5-e7d345fc46c7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Keys", "[", 
  RowBox[{"\[LeftAssociation]", 
   RowBox[{
    RowBox[{"a", "\[Rule]", "6"}], ",", 
    RowBox[{"b", "\[Rule]", "2"}], ",", 
    RowBox[{"c", "\[Rule]", "3"}]}], "\[RightAssociation]"}], "]"}]], "Input",\

 Deletable->False,
 CellLabel->"In[8]:=",ExpressionUUID->"6032faf0-3af2-4a68-a9ea-31cdf3e4dfef"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"a", ",", "b", ",", "c"}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[8]=",ExpressionUUID->"602938f6-0cab-4850-88c6-cbe0d0f0a799"]
}, Open  ]],

Cell["Get the list of values in the association:", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"002d0791-efce-4300-bd18-5bab4e69cea9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Values", "[", 
  RowBox[{"\[LeftAssociation]", 
   RowBox[{
    RowBox[{"a", "\[Rule]", "6"}], ",", 
    RowBox[{"b", "\[Rule]", "2"}], ",", 
    RowBox[{"c", "\[Rule]", "3"}]}], "\[RightAssociation]"}], "]"}]], "Input",\

 Deletable->False,
 CellLabel->"In[9]:=",ExpressionUUID->"2bac463d-4013-4056-a5d6-c025cff13cf9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"6", ",", "2", ",", "3"}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[9]=",ExpressionUUID->"6bc5d544-48f1-4301-9e03-bba5b8150ad9"]
}, Open  ]],

Cell[TextData[{
 ButtonBox["Normal",
  BaseStyle->"Link"],
 " turns an association into a ",
 "normal",
 " list of rules. ",
 ButtonBox["Association",
  BaseStyle->"Link"],
 " makes an association from a list of rules."
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:7",ExpressionUUID->"63040308-be30-492b-b7f7-24fba7074f68"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Normal", "[", 
  RowBox[{"\[LeftAssociation]", 
   RowBox[{
    RowBox[{"a", "\[Rule]", "6"}], ",", 
    RowBox[{"b", "\[Rule]", "2"}], ",", 
    RowBox[{"c", "\[Rule]", "3"}]}], "\[RightAssociation]"}], "]"}]], "Input",\

 Deletable->False,
 CellLabel->"In[10]:=",ExpressionUUID->"b8069c3c-4f1a-4187-bdfc-ca680a2b821e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a", "\[Rule]", "6"}], ",", 
   RowBox[{"b", "\[Rule]", "2"}], ",", 
   RowBox[{"c", "\[Rule]", "3"}]}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[10]=",ExpressionUUID->"e8e72876-9743-498b-a761-a57b38608e14"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Association", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"a", "\[Rule]", "6"}], ",", 
    RowBox[{"b", "\[Rule]", "2"}], ",", 
    RowBox[{"c", "\[Rule]", "3"}]}], "}"}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[11]:=",ExpressionUUID->"c22ecb25-3e31-451a-96da-d00cec806d6a"],

Cell[BoxData[
 RowBox[{"\[LeftAssociation]", 
  RowBox[{
   RowBox[{"a", "\[Rule]", "6"}], ",", 
   RowBox[{"b", "\[Rule]", "2"}], ",", 
   RowBox[{"c", "\[Rule]", "3"}]}], "\[RightAssociation]"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[11]=",ExpressionUUID->"70758f60-c9e2-42a5-bb66-81695a3c7bd2"]
}, Open  ]],

Cell[TextData[{
 ButtonBox["LetterCounts",
  BaseStyle->"Link"],
 " ",
 "counts how many",
 " times letters occur in a string. "
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:8",ExpressionUUID->"ec25fe68-6ae8-4746-af43-54c030a38398"],

Cell["\<\
Count how many times each letter occurs in the Wikipedia article on computers:\
\>", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:9",ExpressionUUID->"3dd1011d-d518-4a41-8a86-1f9145b2a557"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LetterCounts", "[", 
  RowBox[{"WikipediaData", "[", "\"\<computers\>\"", "]"}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[12]:=",ExpressionUUID->"a14a82a6-e5ca-4b69-8ffd-79e39161805c"],

Cell[BoxData[
 RowBox[{"\[LeftAssociation]", 
  RowBox[{
   RowBox[{"\<\"e\"\>", "\[Rule]", "4833"}], ",", 
   RowBox[{"\<\"t\"\>", "\[Rule]", "3528"}], ",", 
   RowBox[{"\<\"a\"\>", "\[Rule]", "3207"}], ",", 
   RowBox[{"\<\"o\"\>", "\[Rule]", "3059"}], ",", 
   RowBox[{"\<\"r\"\>", "\[Rule]", "2907"}], ",", 
   RowBox[{"\<\"i\"\>", "\[Rule]", "2818"}], ",", 
   RowBox[{"\<\"n\"\>", "\[Rule]", "2747"}], ",", 
   RowBox[{"\<\"s\"\>", "\[Rule]", "2475"}], ",", 
   RowBox[{"\<\"c\"\>", "\[Rule]", "1800"}], ",", 
   RowBox[{"\<\"l\"\>", "\[Rule]", "1673"}], ",", 
   RowBox[{"\<\"m\"\>", "\[Rule]", "1494"}], ",", 
   RowBox[{"\<\"h\"\>", "\[Rule]", "1473"}], ",", 
   RowBox[{"\<\"u\"\>", "\[Rule]", "1357"}], ",", 
   RowBox[{"\<\"d\"\>", "\[Rule]", "1329"}], ",", 
   RowBox[{"\<\"p\"\>", "\[Rule]", "1153"}], ",", 
   RowBox[{"\<\"g\"\>", "\[Rule]", "818"}], ",", 
   RowBox[{"\<\"f\"\>", "\[Rule]", "766"}], ",", 
   RowBox[{"\<\"y\"\>", "\[Rule]", "594"}], ",", 
   RowBox[{"\<\"b\"\>", "\[Rule]", "545"}], ",", 
   RowBox[{"\<\"w\"\>", "\[Rule]", "456"}], ",", 
   RowBox[{"\<\"v\"\>", "\[Rule]", "391"}], ",", 
   RowBox[{"\<\"k\"\>", "\[Rule]", "174"}], ",", 
   RowBox[{"\<\"T\"\>", "\[Rule]", "150"}], ",", 
   RowBox[{"\<\"A\"\>", "\[Rule]", "110"}], ",", 
   RowBox[{"\<\"I\"\>", "\[Rule]", "101"}], ",", 
   RowBox[{"\<\"C\"\>", "\[Rule]", "84"}], ",", 
   RowBox[{"\<\"M\"\>", "\[Rule]", "82"}], ",", 
   RowBox[{"\<\"x\"\>", "\[Rule]", "77"}], ",", 
   RowBox[{"\<\"S\"\>", "\[Rule]", "68"}], ",", 
   RowBox[{"\<\"P\"\>", "\[Rule]", "64"}], ",", 
   RowBox[{"\<\"q\"\>", "\[Rule]", "58"}], ",", 
   RowBox[{"\<\"U\"\>", "\[Rule]", "55"}], ",", 
   RowBox[{"\<\"B\"\>", "\[Rule]", "45"}], ",", 
   RowBox[{"\<\"H\"\>", "\[Rule]", "43"}], ",", 
   RowBox[{"\<\"E\"\>", "\[Rule]", "42"}], ",", 
   RowBox[{"\<\"R\"\>", "\[Rule]", "41"}], ",", 
   RowBox[{"\<\"L\"\>", "\[Rule]", "41"}], ",", 
   RowBox[{"\<\"z\"\>", "\[Rule]", "38"}], ",", 
   RowBox[{"\<\"O\"\>", "\[Rule]", "38"}], ",", 
   RowBox[{"\<\"D\"\>", "\[Rule]", "37"}], ",", 
   RowBox[{"\<\"W\"\>", "\[Rule]", "30"}], ",", 
   RowBox[{"\<\"N\"\>", "\[Rule]", "29"}], ",", 
   RowBox[{"\<\"F\"\>", "\[Rule]", "28"}], ",", 
   RowBox[{"\<\"j\"\>", "\[Rule]", "25"}], ",", 
   RowBox[{"\<\"G\"\>", "\[Rule]", "23"}], ",", 
   RowBox[{"\<\"J\"\>", "\[Rule]", "17"}], ",", 
   RowBox[{"\<\"K\"\>", "\[Rule]", "14"}], ",", 
   RowBox[{"\<\"V\"\>", "\[Rule]", "10"}], ",", 
   RowBox[{"\<\"Z\"\>", "\[Rule]", "8"}], ",", 
   RowBox[{"\<\"Q\"\>", "\[Rule]", "4"}], ",", 
   RowBox[{"\<\"\:016b\"\>", "\[Rule]", "4"}], ",", 
   RowBox[{"\<\"\:012b\"\>", "\[Rule]", "4"}], ",", 
   RowBox[{"\<\"\[ODoubleDot]\"\>", "\[Rule]", "2"}], ",", 
   RowBox[{"\<\"\[ABar]\"\>", "\[Rule]", "2"}], ",", 
   RowBox[{"\<\"Y\"\>", "\[Rule]", "1"}], ",", 
   RowBox[{"\<\"X\"\>", "\[Rule]", "1"}], ",", 
   RowBox[{"\<\"\[EAcute]\"\>", "\[Rule]", "1"}], ",", 
   RowBox[{"\<\"\[AHat]\"\>", "\[Rule]", "1"}]}], 
  "\[RightAssociation]"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[12]=",ExpressionUUID->"a28de563-8b13-4054-9ca7-ee0e58e9edac"]
}, Open  ]],

Cell[TextData[{
 ButtonBox["KeyTake",
  BaseStyle->"Link"],
 " picks out elements of an association that appear in a list of keys you \
specify. Here we\[CloseCurlyQuote]re taking the elements whose keys are \
letters in the (lowercase) alphabet."
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:10",ExpressionUUID->"4969bf0f-7f89-48d6-b514-74d0d51157f6"],

Cell["\<\
Take only those elements in the association whose keys appear as letters in \
the alphabet:\
\>", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"69fdd92b-8306-429c-9036-197c7a0d3949"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"KeyTake", "[", 
  RowBox[{
   RowBox[{"LetterCounts", "[", 
    RowBox[{"WikipediaData", "[", "\"\<computers\>\"", "]"}], "]"}], ",", 
   RowBox[{"Alphabet", "[", "\[ThinSpace]", "]"}]}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[13]:=",ExpressionUUID->"cb6deaf1-e2c1-479b-95a3-ce2068af3ad1"],

Cell[BoxData[
 RowBox[{"\[LeftAssociation]", 
  RowBox[{
   RowBox[{"\<\"a\"\>", "\[Rule]", "3207"}], ",", 
   RowBox[{"\<\"b\"\>", "\[Rule]", "545"}], ",", 
   RowBox[{"\<\"c\"\>", "\[Rule]", "1800"}], ",", 
   RowBox[{"\<\"d\"\>", "\[Rule]", "1329"}], ",", 
   RowBox[{"\<\"e\"\>", "\[Rule]", "4833"}], ",", 
   RowBox[{"\<\"f\"\>", "\[Rule]", "766"}], ",", 
   RowBox[{"\<\"g\"\>", "\[Rule]", "818"}], ",", 
   RowBox[{"\<\"h\"\>", "\[Rule]", "1473"}], ",", 
   RowBox[{"\<\"i\"\>", "\[Rule]", "2818"}], ",", 
   RowBox[{"\<\"j\"\>", "\[Rule]", "25"}], ",", 
   RowBox[{"\<\"k\"\>", "\[Rule]", "174"}], ",", 
   RowBox[{"\<\"l\"\>", "\[Rule]", "1673"}], ",", 
   RowBox[{"\<\"m\"\>", "\[Rule]", "1494"}], ",", 
   RowBox[{"\<\"n\"\>", "\[Rule]", "2747"}], ",", 
   RowBox[{"\<\"o\"\>", "\[Rule]", "3059"}], ",", 
   RowBox[{"\<\"p\"\>", "\[Rule]", "1153"}], ",", 
   RowBox[{"\<\"q\"\>", "\[Rule]", "58"}], ",", 
   RowBox[{"\<\"r\"\>", "\[Rule]", "2907"}], ",", 
   RowBox[{"\<\"s\"\>", "\[Rule]", "2475"}], ",", 
   RowBox[{"\<\"t\"\>", "\[Rule]", "3528"}], ",", 
   RowBox[{"\<\"u\"\>", "\[Rule]", "1357"}], ",", 
   RowBox[{"\<\"v\"\>", "\[Rule]", "391"}], ",", 
   RowBox[{"\<\"w\"\>", "\[Rule]", "456"}], ",", 
   RowBox[{"\<\"x\"\>", "\[Rule]", "77"}], ",", 
   RowBox[{"\<\"y\"\>", "\[Rule]", "594"}], ",", 
   RowBox[{"\<\"z\"\>", "\[Rule]", "38"}]}], 
  "\[RightAssociation]"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellTags->"LastCellOfAPage",
 CellLabel->"Out[13]=",ExpressionUUID->"8ef2c91e-814d-4160-9eeb-29227fbcf8cf"]
}, Open  ]],

Cell[TextData[{
 ButtonBox["BarChart",
  BaseStyle->"Link"],
 " plots the values in an association. With the option ",
 Cell[BoxData[
  RowBox[{"ChartLabels", "\[Rule]", "Automatic"}]], "InlineCodeText",
  ExpressionUUID->"0b70f0f2-d7a2-4ab2-98af-f7597a7d9822"],
 ", it uses the keys as labels."
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->{
  "i:11", "p:207"},ExpressionUUID->"90fe1f66-f720-4a76-b0d7-386f63904f6b"],

Cell["\<\
Make a bar chart of how many times each letter appears; \
\[OpenCurlyDoubleQuote]e\[CloseCurlyDoubleQuote] is the most common:\
\>", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"2f93386c-c74c-46db-89f1-a3684ac45e6d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BarChart", "[", 
  RowBox[{
   RowBox[{"KeyTake", "[", 
    RowBox[{
     RowBox[{"LetterCounts", "[", 
      RowBox[{"WikipediaData", "[", "\"\<computers\>\"", "]"}], "]"}], ",", 
     RowBox[{"Alphabet", "[", "\[ThinSpace]", "]"}]}], "]"}], ",", 
   RowBox[{"ChartLabels", "\[Rule]", "Automatic"}]}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[14]:=",ExpressionUUID->"3b05f70b-47f5-44f4-a17b-1e965969d91b"],

Cell[BoxData[
 GraphicsBox[{{{{
      {Opacity[0], PointBox[{0.01582867783985098, 0.}]}}}}, {{}, {{{
       {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[0.518], 
        Thickness[Small]}], {{{
           {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
            0.518], Thickness[Small]}], 
            TagBox[
             TooltipBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 
                 RectangleBox[{0.5344506517690875, 0.}, {1.4655493482309123`, 
                  3207.}, "RoundingRadius" -> 0]},
                
                ImageSizeCache->{{28.966760233505166`, 
                 37.03724539240133}, {-27.026685415568345`, 
                 60.62092745240282}}],
               StatusArea[#, 3207]& ,
               TagBoxNote->"3207"],
              StyleBox["3207", {}, StripOnInput -> False]],
             Annotation[#, 
              Style[3207, {}], "Tooltip"]& ]}}}}, {{{
           {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
            0.518], Thickness[Small]}], 
            TagBox[
             TooltipBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 
                 RectangleBox[{1.5344506517690872`, 0.}, {2.4655493482309123`,
                   545.}, "RoundingRadius" -> 0]},
                
                ImageSizeCache->{{37.09746129415965, 45.16794645305582}, {
                 45.31099636009091, 60.62092745240282}}],
               StatusArea[#, 545]& ,
               TagBoxNote->"545"],
              StyleBox["545", {}, StripOnInput -> False]],
             Annotation[#, 
              Style[545, {}], "Tooltip"]& ]}}}}, {{{
           {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
            0.518], Thickness[Small]}], 
            TagBox[
             TooltipBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 
                 RectangleBox[{2.5344506517690872`, 0.}, {3.4655493482309123`,
                   1800.}, "RoundingRadius" -> 0]},
                
                ImageSizeCache->{{45.22816235481414, 53.29864751371031}, {
                 11.207393569537807`, 60.62092745240282}}],
               StatusArea[#, 1800]& ,
               TagBoxNote->"1800"],
              StyleBox["1800", {}, StripOnInput -> False]],
             Annotation[#, 
              Style[1800, {}], "Tooltip"]& ]}}}}, {{{
           {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
            0.518], Thickness[Small]}], 
            TagBox[
             TooltipBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 
                 RectangleBox[{3.5344506517690872`, 0.}, {4.465549348230912, 
                  1329.}, "RoundingRadius" -> 0]},
                
                ImageSizeCache->{{53.35886341546862, 61.429348574364795`}, {
                 24.006434935554147`, 60.62092745240282}}],
               StatusArea[#, 1329]& ,
               TagBoxNote->"1329"],
              StyleBox["1329", {}, StripOnInput -> False]],
             Annotation[#, 
              Style[1329, {}], "Tooltip"]& ]}}}}, {{{
           {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
            0.518], Thickness[Small]}], 
            TagBox[
             TooltipBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 
                 RectangleBox[{4.534450651769087, 0.}, {5.465549348230912, 
                  4833.}, "RoundingRadius" -> 0]},
                
                ImageSizeCache->{{61.48956447612311, 
                 69.56004963501928}, {-71.21191102308975, 60.62092745240281}}],
               StatusArea[#, 4833]& ,
               TagBoxNote->"4833"],
              StyleBox["4833", {}, StripOnInput -> False]],
             Annotation[#, 
              Style[4833, {}], "Tooltip"]& ]}}}}, {{{
           {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
            0.518], Thickness[Small]}], 
            TagBox[
             TooltipBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 
                 RectangleBox[{5.534450651769087, 0.}, {6.465549348230912, 
                  766.}, "RoundingRadius" -> 0]},
                
                ImageSizeCache->{{69.6202655367776, 77.69075069567376}, {
                 39.305501366694706`, 60.62092745240282}}],
               StatusArea[#, 766]& ,
               TagBoxNote->"766"],
              StyleBox["766", {}, StripOnInput -> False]],
             Annotation[#, 
              Style[766, {}], "Tooltip"]& ]}}}}, {{{
           {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
            0.518], Thickness[Small]}], 
            TagBox[
             TooltipBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 
                 RectangleBox[{6.534450651769087, 0.}, {7.465549348230912, 
                  818.}, "RoundingRadius" -> 0]},
                
                ImageSizeCache->{{77.75096659743208, 85.82145175632824}, {
                 37.89244372118972, 60.62092745240282}}],
               StatusArea[#, 818]& ,
               TagBoxNote->"818"],
              StyleBox["818", {}, StripOnInput -> False]],
             Annotation[#, 
              Style[818, {}], "Tooltip"]& ]}}}}, {{{
           {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
            0.518], Thickness[Small]}], 
            TagBox[
             TooltipBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 
                 RectangleBox[{7.534450651769087, 0.}, {8.465549348230912, 
                  1473.}, "RoundingRadius" -> 0]},
                
                ImageSizeCache->{{85.88166765808657, 93.95215281698273}, {
                 20.09335222492495, 60.62092745240282}}],
               StatusArea[#, 1473]& ,
               TagBoxNote->"1473"],
              StyleBox["1473", {}, StripOnInput -> False]],
             Annotation[#, 
              Style[1473, {}], "Tooltip"]& ]}}}}, {{{
           {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
            0.518], Thickness[Small]}], 
            TagBox[
             TooltipBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 
                 RectangleBox[{8.534450651769086, 0.}, {9.465549348230912, 
                  2818.}, "RoundingRadius" -> 0]},
                
                ImageSizeCache->{{94.01236871874104, 
                 102.08285387763722`}, {-16.455927259771407`, 
                 60.62092745240282}}],
               StatusArea[#, 2818]& ,
               TagBoxNote->"2818"],
              StyleBox["2818", {}, StripOnInput -> False]],
             Annotation[#, 
              Style[2818, {}], "Tooltip"]& ]}}}}, {{{
           {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
            0.518], Thickness[Small]}], 
            TagBox[
             TooltipBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 
                 RectangleBox[{9.534450651769086, 0.}, {10.465549348230912`, 
                  25.}, "RoundingRadius" -> 0]},
                
                ImageSizeCache->{{102.14306977939553`, 110.21355493829171`}, {
                 59.4415728151408, 60.62092745240282}}],
               StatusArea[#, 25]& ,
               TagBoxNote->"25"],
              StyleBox["25", {}, StripOnInput -> False]],
             Annotation[#, 
              Style[25, {}], "Tooltip"]& ]}}}}, {{{
           {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
            0.518], Thickness[Small]}], 
            TagBox[
             TooltipBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 
                 RectangleBox[{10.534450651769086`, 0.}, {11.465549348230912`,
                   174.}, "RoundingRadius" -> 0]},
                
                ImageSizeCache->{{110.27377084005002`, 118.3442559989462}, {
                 55.3926191770592, 60.62092745240282}}],
               StatusArea[#, 174]& ,
               TagBoxNote->"174"],
              StyleBox["174", {}, StripOnInput -> False]],
             Annotation[#, 
              Style[174, {}], "Tooltip"]& ]}}}}, {{{
           {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
            0.518], Thickness[Small]}], 
            TagBox[
             TooltipBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 
                 RectangleBox[{11.534450651769086`, 0.}, {12.465549348230912`,
                   1673.}, "RoundingRadius" -> 0]},
                
                ImageSizeCache->{{118.40447190070451`, 126.47495705960067`}, {
                 14.658515126828839`, 60.62092745240282}}],
               StatusArea[#, 1673]& ,
               TagBoxNote->"1673"],
              StyleBox["1673", {}, StripOnInput -> False]],
             Annotation[#, 
              Style[1673, {}], "Tooltip"]& ]}}}}, {{{
           {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
            0.518], Thickness[Small]}], 
            TagBox[
             TooltipBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 
                 RectangleBox[{12.534450651769086`, 0.}, {13.465549348230912`,
                   1494.}, "RoundingRadius" -> 0]},
                
                ImageSizeCache->{{126.53517296135898`, 134.60565812025516`}, {
                 19.522694329624855`, 60.62092745240282}}],
               StatusArea[#, 1494]& ,
               TagBoxNote->"1494"],
              StyleBox["1494", {}, StripOnInput -> False]],
             Annotation[#, 
              Style[1494, {}], "Tooltip"]& ]}}}}, {{{
           {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
            0.518], Thickness[Small]}], 
            TagBox[
             TooltipBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 
                 RectangleBox[{13.534450651769086`, 0.}, {14.465549348230912`,
                   2747.}, "RoundingRadius" -> 0]},
                
                ImageSizeCache->{{134.66587402201347`, 
                 142.73635918090966`}, {-14.526560089947289`, 
                 60.62092745240282}}],
               StatusArea[#, 2747]& ,
               TagBoxNote->"2747"],
              StyleBox["2747", {}, StripOnInput -> False]],
             Annotation[#, 
              Style[2747, {}], "Tooltip"]& ]}}}}, {{{
           {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
            0.518], Thickness[Small]}], 
            TagBox[
             TooltipBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 
                 RectangleBox[{14.534450651769086`, 0.}, {15.465549348230912`,
                   3059.}, "RoundingRadius" -> 0]},
                
                ImageSizeCache->{{142.79657508266797`, 
                 150.86706024156413`}, {-23.004905962977226`, 
                 60.62092745240282}}],
               StatusArea[#, 3059]& ,
               TagBoxNote->"3059"],
              StyleBox["3059", {}, StripOnInput -> False]],
             Annotation[#, 
              Style[3059, {}], "Tooltip"]& ]}}}}, {{{
           {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
            0.518], Thickness[Small]}], 
            TagBox[
             TooltipBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 
                 RectangleBox[{15.534450651769086`, 0.}, {16.465549348230912`,
                   1153.}, "RoundingRadius" -> 0]},
                
                ImageSizeCache->{{150.92727614332244`, 158.9977613022186}, {
                 28.78909158187873, 60.62092745240282}}],
               StatusArea[#, 1153]& ,
               TagBoxNote->"1153"],
              StyleBox["1153", {}, StripOnInput -> False]],
             Annotation[#, 
              Style[1153, {}], "Tooltip"]& ]}}}}, {{{
           {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
            0.518], Thickness[Small]}], 
            TagBox[
             TooltipBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 
                 RectangleBox[{16.534450651769088`, 0.}, {17.465549348230912`,
                   58.}, "RoundingRadius" -> 0]},
                
                ImageSizeCache->{{159.05797720397695`, 167.1284623628731}, {
                 58.54482469395494, 60.62092745240282}}],
               StatusArea[#, 58]& ,
               TagBoxNote->"58"],
              StyleBox["58", {}, StripOnInput -> False]],
             Annotation[#, 
              Style[58, {}], "Tooltip"]& ]}}}}, {{{
           {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
            0.518], Thickness[Small]}], 
            TagBox[
             TooltipBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 
                 RectangleBox[{17.534450651769088`, 0.}, {18.465549348230912`,
                   2907.}, "RoundingRadius" -> 0]},
                
                ImageSizeCache->{{167.18867826463142`, 
                 175.25916342352758`}, {-18.87442976842417, 
                 60.62092745240282}}],
               StatusArea[#, 2907]& ,
               TagBoxNote->"2907"],
              StyleBox["2907", {}, StripOnInput -> False]],
             Annotation[#, 
              Style[2907, {}], "Tooltip"]& ]}}}}, {{{
           {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
            0.518], Thickness[Small]}], 
            TagBox[
             TooltipBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 
                 RectangleBox[{18.534450651769088`, 0.}, {19.465549348230912`,
                   2475.}, "RoundingRadius" -> 0]},
                
                ImageSizeCache->{{175.31937932528592`, 
                 183.38986448418208`}, {-7.135181636536579, 
                 60.62092745240282}}],
               StatusArea[#, 2475]& ,
               TagBoxNote->"2475"],
              StyleBox["2475", {}, StripOnInput -> False]],
             Annotation[#, 
              Style[2475, {}], "Tooltip"]& ]}}}}, {{{
           {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
            0.518], Thickness[Small]}], 
            TagBox[
             TooltipBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 
                 RectangleBox[{19.534450651769088`, 0.}, {20.465549348230912`,
                   3528.}, "RoundingRadius" -> 0]},
                
                ImageSizeCache->{{183.4500803859404, 
                 191.52056554483656`}, {-35.749598958012605`, 
                 60.62092745240282}}],
               StatusArea[#, 3528]& ,
               TagBoxNote->"3528"],
              StyleBox["3528", {}, StripOnInput -> False]],
             Annotation[#, 
              Style[3528, {}], "Tooltip"]& ]}}}}, {{{
           {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
            0.518], Thickness[Small]}], 
            TagBox[
             TooltipBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 
                 RectangleBox[{20.534450651769088`, 0.}, {21.465549348230912`,
                   1357.}, "RoundingRadius" -> 0]},
                
                ImageSizeCache->{{191.5807814465949, 199.65126660549106`}, {
                 23.245557741820697`, 60.62092745240282}}],
               StatusArea[#, 1357]& ,
               TagBoxNote->"1357"],
              StyleBox["1357", {}, StripOnInput -> False]],
             Annotation[#, 
              Style[1357, {}], "Tooltip"]& ]}}}}, {{{
           {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
            0.518], Thickness[Small]}], 
            TagBox[
             TooltipBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 
                 RectangleBox[{21.534450651769088`, 0.}, {22.465549348230912`,
                   391.}, "RoundingRadius" -> 0]},
                
                ImageSizeCache->{{199.71148250724937`, 207.78196766614553`}, {
                 49.49582092562492, 60.62092745240282}}],
               StatusArea[#, 391]& ,
               TagBoxNote->"391"],
              StyleBox["391", {}, StripOnInput -> False]],
             Annotation[#, 
              Style[391, {}], "Tooltip"]& ]}}}}, {{{
           {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
            0.518], Thickness[Small]}], 
            TagBox[
             TooltipBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 
                 RectangleBox[{22.534450651769088`, 0.}, {23.465549348230912`,
                   456.}, "RoundingRadius" -> 0]},
                
                ImageSizeCache->{{207.84218356790387`, 215.91266872680004`}, {
                 47.72949886874368, 60.62092745240282}}],
               StatusArea[#, 456]& ,
               TagBoxNote->"456"],
              StyleBox["456", {}, StripOnInput -> False]],
             Annotation[#, 
              Style[456, {}], "Tooltip"]& ]}}}}, {{{
           {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
            0.518], Thickness[Small]}], 
            TagBox[
             TooltipBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 
                 RectangleBox[{23.534450651769088`, 0.}, {24.465549348230912`,
                   77.}, "RoundingRadius" -> 0]},
                
                ImageSizeCache->{{215.97288462855835`, 224.0433697874545}, {
                 58.02851516963582, 60.62092745240282}}],
               StatusArea[#, 77]& ,
               TagBoxNote->"77"],
              StyleBox["77", {}, StripOnInput -> False]],
             Annotation[#, 
              Style[77, {}], "Tooltip"]& ]}}}}, {{{
           {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
            0.518], Thickness[Small]}], 
            TagBox[
             TooltipBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 
                 RectangleBox[{24.534450651769088`, 0.}, {25.465549348230912`,
                   594.}, "RoundingRadius" -> 0]},
                
                ImageSizeCache->{{224.10358568921282`, 232.17407084810898`}, {
                 43.97946127105736, 60.62092745240282}}],
               StatusArea[#, 594]& ,
               TagBoxNote->"594"],
              StyleBox["594", {}, StripOnInput -> False]],
             Annotation[#, 
              Style[594, {}], "Tooltip"]& ]}}}}, {{{
           {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
            0.518], Thickness[Small]}], 
            TagBox[
             TooltipBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 RectangleBox[{25.534450651769088`, 0.}, {26.465549348230912`,
                   38.}, "RoundingRadius" -> 0]},
                
                ImageSizeCache->{{232.23428674986732`, 240.30477190876348`}, {
                 59.08830840376456, 60.62092745240282}}],
               StatusArea[#, 38]& ,
               TagBoxNote->"38"],
              StyleBox["38", {}, StripOnInput -> False]],
             Annotation[#, 
              Style[38, {}], "Tooltip"]& ]}}}}}}}}, {}, {}}, {}, {}, 
   StyleBox[{{{{
        {Thickness[Tiny], 
         LineBox[{{0.01582867783985098, 0.}, {26.994543761638734`, 0.}}], 
         StyleBox[{}, "GraphicsLabel",
          StripOnInput->False]}}}}, 
     StyleBox[{{{{
          {Thickness[Tiny], 
           LineBox[{{0.5344506517690875, 0.}, 
             Offset[{-1.102182119232618*^-15, -6.}, {0.5344506517690875, 
              0.}]}], LineBox[{{26.465549348230912`, 0.}, 
             Offset[{-1.102182119232618*^-15, -6.}, {26.465549348230912`, 
              0.}]}], {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {
             LineBox[{{1.4655493482309123`, 0.}, 
               Offset[{-7.347880794884119*^-16, -4.}, {1.4655493482309123`, 
                0.}]}], 
             LineBox[{{1.5344506517690872`, 0.}, 
               Offset[{-7.347880794884119*^-16, -4.}, {1.5344506517690872`, 
                0.}]}], 
             LineBox[{{2.4655493482309128`, 0.}, 
               Offset[{-7.347880794884119*^-16, -4.}, {2.4655493482309128`, 
                0.}]}], 
             LineBox[{{2.5344506517690872`, 0.}, 
               Offset[{-7.347880794884119*^-16, -4.}, {2.5344506517690872`, 
                0.}]}], 
             LineBox[{{3.4655493482309128`, 0.}, 
               Offset[{-7.347880794884119*^-16, -4.}, {3.4655493482309128`, 
                0.}]}], 
             LineBox[{{3.5344506517690872`, 0.}, 
               Offset[{-7.347880794884119*^-16, -4.}, {3.5344506517690872`, 
                0.}]}], 
             LineBox[{{4.465549348230912, 0.}, 
               Offset[{-7.347880794884119*^-16, -4.}, {4.465549348230912, 
                0.}]}], 
             LineBox[{{4.534450651769087, 0.}, 
               Offset[{-7.347880794884119*^-16, -4.}, {4.534450651769087, 
                0.}]}], 
             LineBox[{{5.465549348230911, 0.}, 
               Offset[{-7.347880794884119*^-16, -4.}, {5.465549348230911, 
                0.}]}], 
             LineBox[{{5.534450651769086, 0.}, 
               Offset[{-7.347880794884119*^-16, -4.}, {5.534450651769086, 
                0.}]}], 
             LineBox[{{6.465549348230911, 0.}, 
               Offset[{-7.347880794884119*^-16, -4.}, {6.465549348230911, 
                0.}]}], 
             LineBox[{{6.534450651769086, 0.}, 
               Offset[{-7.347880794884119*^-16, -4.}, {6.534450651769086, 
                0.}]}], 
             LineBox[{{7.465549348230911, 0.}, 
               Offset[{-7.347880794884119*^-16, -4.}, {7.465549348230911, 
                0.}]}], 
             LineBox[{{7.534450651769086, 0.}, 
               Offset[{-7.347880794884119*^-16, -4.}, {7.534450651769086, 
                0.}]}], 
             LineBox[{{8.465549348230912, 0.}, 
               Offset[{-7.347880794884119*^-16, -4.}, {8.465549348230912, 
                0.}]}], 
             LineBox[{{8.534450651769086, 0.}, 
               Offset[{-7.347880794884119*^-16, -4.}, {8.534450651769086, 
                0.}]}], 
             LineBox[{{9.465549348230912, 0.}, 
               Offset[{-7.347880794884119*^-16, -4.}, {9.465549348230912, 
                0.}]}], 
             LineBox[{{9.534450651769086, 0.}, 
               Offset[{-7.347880794884119*^-16, -4.}, {9.534450651769086, 
                0.}]}], 
             LineBox[{{10.465549348230912`, 0.}, 
               Offset[{-7.347880794884119*^-16, -4.}, {10.465549348230912`, 
                0.}]}], 
             LineBox[{{10.534450651769086`, 0.}, 
               Offset[{-7.347880794884119*^-16, -4.}, {10.534450651769086`, 
                0.}]}], 
             LineBox[{{11.465549348230912`, 0.}, 
               Offset[{-7.347880794884119*^-16, -4.}, {11.465549348230912`, 
                0.}]}], 
             LineBox[{{11.534450651769086`, 0.}, 
               Offset[{-7.347880794884119*^-16, -4.}, {11.534450651769086`, 
                0.}]}], 
             LineBox[{{12.465549348230912`, 0.}, 
               Offset[{-7.347880794884119*^-16, -4.}, {12.465549348230912`, 
                0.}]}], 
             LineBox[{{12.534450651769086`, 0.}, 
               Offset[{-7.347880794884119*^-16, -4.}, {12.534450651769086`, 
                0.}]}], 
             LineBox[{{13.465549348230912`, 0.}, 
               Offset[{-7.347880794884119*^-16, -4.}, {13.465549348230912`, 
                0.}]}], 
             LineBox[{{13.534450651769086`, 0.}, 
               Offset[{-7.347880794884119*^-16, -4.}, {13.534450651769086`, 
                0.}]}], 
             LineBox[{{14.465549348230912`, 0.}, 
               Offset[{-7.347880794884119*^-16, -4.}, {14.465549348230912`, 
                0.}]}], 
             LineBox[{{14.534450651769086`, 0.}, 
               Offset[{-7.347880794884119*^-16, -4.}, {14.534450651769086`, 
                0.}]}], 
             LineBox[{{15.465549348230912`, 0.}, 
               Offset[{-7.347880794884119*^-16, -4.}, {15.465549348230912`, 
                0.}]}], 
             LineBox[{{15.534450651769086`, 0.}, 
               Offset[{-7.347880794884119*^-16, -4.}, {15.534450651769086`, 
                0.}]}], 
             LineBox[{{16.465549348230912`, 0.}, 
               Offset[{-7.347880794884119*^-16, -4.}, {16.465549348230912`, 
                0.}]}], 
             LineBox[{{16.534450651769085`, 0.}, 
               Offset[{-7.347880794884119*^-16, -4.}, {16.534450651769085`, 
                0.}]}], 
             LineBox[{{17.465549348230912`, 0.}, 
               Offset[{-7.347880794884119*^-16, -4.}, {17.465549348230912`, 
                0.}]}], 
             LineBox[{{17.534450651769088`, 0.}, 
               Offset[{-7.347880794884119*^-16, -4.}, {17.534450651769088`, 
                0.}]}], 
             LineBox[{{18.465549348230912`, 0.}, 
               Offset[{-7.347880794884119*^-16, -4.}, {18.465549348230912`, 
                0.}]}], 
             LineBox[{{18.534450651769088`, 0.}, 
               Offset[{-7.347880794884119*^-16, -4.}, {18.534450651769088`, 
                0.}]}], 
             LineBox[{{19.465549348230912`, 0.}, 
               Offset[{-7.347880794884119*^-16, -4.}, {19.465549348230912`, 
                0.}]}], 
             LineBox[{{19.534450651769088`, 0.}, 
               Offset[{-7.347880794884119*^-16, -4.}, {19.534450651769088`, 
                0.}]}], 
             LineBox[{{20.465549348230912`, 0.}, 
               Offset[{-7.347880794884119*^-16, -4.}, {20.465549348230912`, 
                0.}]}], 
             LineBox[{{20.534450651769088`, 0.}, 
               Offset[{-7.347880794884119*^-16, -4.}, {20.534450651769088`, 
                0.}]}], 
             LineBox[{{21.465549348230912`, 0.}, 
               Offset[{-7.347880794884119*^-16, -4.}, {21.465549348230912`, 
                0.}]}], 
             LineBox[{{21.534450651769088`, 0.}, 
               Offset[{-7.347880794884119*^-16, -4.}, {21.534450651769088`, 
                0.}]}], 
             LineBox[{{22.465549348230912`, 0.}, 
               Offset[{-7.347880794884119*^-16, -4.}, {22.465549348230912`, 
                0.}]}], 
             LineBox[{{22.534450651769088`, 0.}, 
               Offset[{-7.347880794884119*^-16, -4.}, {22.534450651769088`, 
                0.}]}], 
             LineBox[{{23.465549348230912`, 0.}, 
               Offset[{-7.347880794884119*^-16, -4.}, {23.465549348230912`, 
                0.}]}], 
             LineBox[{{23.534450651769088`, 0.}, 
               Offset[{-7.347880794884119*^-16, -4.}, {23.534450651769088`, 
                0.}]}], 
             LineBox[{{24.465549348230912`, 0.}, 
               Offset[{-7.347880794884119*^-16, -4.}, {24.465549348230912`, 
                0.}]}], 
             LineBox[{{24.534450651769088`, 0.}, 
               Offset[{-7.347880794884119*^-16, -4.}, {24.534450651769088`, 
                0.}]}], 
             LineBox[{{25.465549348230912`, 0.}, 
               Offset[{-7.347880794884119*^-16, -4.}, {25.465549348230912`, 
                0.}]}], 
             LineBox[{{25.534450651769088`, 0.}, 
               Offset[{-7.347880794884119*^-16, -4.}, {25.534450651769088`, 
                0.}]}]}, {}}}}}}, 
       StyleBox[{{{
           {Thickness[Tiny], 
            InsetBox["\<\"a\"\>", 
             Offset[{0., -2.}, {0.9999999999999999, 0.}], {0, 1}, Automatic, {
             1, 0}], InsetBox["\<\"b\"\>", Offset[{0., -2.}, {2., 0.}], {0, 1},
              Automatic, {1, 0}], 
            InsetBox["\<\"c\"\>", Offset[{0., -2.}, {3., 0.}], {0, 1}, 
             Automatic, {1, 0}], 
            InsetBox["\<\"d\"\>", Offset[{0., -2.}, {4., 0.}], {0, 1}, 
             Automatic, {1, 0}], 
            InsetBox["\<\"e\"\>", 
             Offset[{0., -2.}, {4.999999999999999, 0.}], {0, 1}, Automatic, {
             1, 0}], InsetBox["\<\"f\"\>", 
             Offset[{0., -2.}, {5.999999999999999, 0.}], {0, 1}, Automatic, {
             1, 0}], InsetBox["\<\"g\"\>", 
             Offset[{0., -2.}, {6.999999999999999, 0.}], {0, 1}, Automatic, {
             1, 0}], InsetBox["\<\"h\"\>", 
             Offset[{0., -2.}, {7.999999999999999, 0.}], {0, 1}, Automatic, {
             1, 0}], InsetBox["\<\"i\"\>", Offset[{0., -2.}, {9., 0.}], {0, 1},
              Automatic, {1, 0}], 
            InsetBox["\<\"j\"\>", Offset[{0., -2.}, {10., 0.}], {0, 1}, 
             Automatic, {1, 0}], 
            InsetBox["\<\"k\"\>", Offset[{0., -2.}, {11., 0.}], {0, 1}, 
             Automatic, {1, 0}], 
            InsetBox["\<\"l\"\>", Offset[{0., -2.}, {12., 0.}], {0, 1}, 
             Automatic, {1, 0}], 
            InsetBox["\<\"m\"\>", Offset[{0., -2.}, {13., 0.}], {0, 1}, 
             Automatic, {1, 0}], 
            InsetBox["\<\"n\"\>", Offset[{0., -2.}, {14., 0.}], {0, 1}, 
             Automatic, {1, 0}], 
            InsetBox["\<\"o\"\>", Offset[{0., -2.}, {15., 0.}], {0, 1}, 
             Automatic, {1, 0}], 
            InsetBox["\<\"p\"\>", Offset[{0., -2.}, {16., 0.}], {0, 1}, 
             Automatic, {1, 0}], 
            InsetBox["\<\"q\"\>", Offset[{0., -2.}, {17., 0.}], {0, 1}, 
             Automatic, {1, 0}], 
            InsetBox["\<\"r\"\>", Offset[{0., -2.}, {18., 0.}], {0, 1}, 
             Automatic, {1, 0}], 
            InsetBox["\<\"s\"\>", Offset[{0., -2.}, {19., 0.}], {0, 1}, 
             Automatic, {1, 0}], 
            InsetBox["\<\"t\"\>", Offset[{0., -2.}, {20., 0.}], {0, 1}, 
             Automatic, {1, 0}], 
            InsetBox["\<\"u\"\>", Offset[{0., -2.}, {21., 0.}], {0, 1}, 
             Automatic, {1, 0}], 
            InsetBox["\<\"v\"\>", Offset[{0., -2.}, {22., 0.}], {0, 1}, 
             Automatic, {1, 0}], 
            InsetBox["\<\"w\"\>", Offset[{0., -2.}, {23., 0.}], {0, 1}, 
             Automatic, {1, 0}], 
            InsetBox["\<\"x\"\>", Offset[{0., -2.}, {24., 0.}], {0, 1}, 
             Automatic, {1, 0}], 
            InsetBox["\<\"y\"\>", Offset[{0., -2.}, {25., 0.}], {0, 1}, 
             Automatic, {1, 0}], 
            InsetBox["\<\"z\"\>", Offset[{0., -2.}, {26., 0.}], {0, 1}, 
             Automatic, {1, 0}]}}}}, "GraphicsLabel",
        StripOnInput->False]}, "GraphicsTicks",
      StripOnInput->False]}, "GraphicsAxes",
    StripOnInput->False,
    Antialiasing->False]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, True},
  AxesLabel->{None, None},
  AxesOrigin->{0.01582867783985098, 0.},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Identity[
       Part[#, 1]], 
      Identity[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Identity[
       Part[#, 1]], 
      Identity[
       Part[#, 2]]}& )},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {{{0.9999999999999999, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {0.9999999999999999, 
       FormBox["\"a\"", TraditionalForm], 0}, {1.9999999999999998`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {1.9999999999999998`, 
       FormBox["\"b\"", TraditionalForm], 0}, {3., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {3., 
       FormBox["\"c\"", TraditionalForm], 0}, {3.9999999999999996`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {3.9999999999999996`, 
       FormBox["\"d\"", TraditionalForm], 0}, {5., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {5., 
       FormBox["\"e\"", TraditionalForm], 0}, {6., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {6., 
       FormBox["\"f\"", TraditionalForm], 0}, {7., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {7., 
       FormBox["\"g\"", TraditionalForm], 0}, {8., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {8., 
       FormBox["\"h\"", TraditionalForm], 0}, {9., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {9., 
       FormBox["\"i\"", TraditionalForm], 0}, {10., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {10., 
       FormBox["\"j\"", TraditionalForm], 0}, {11., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {11., 
       FormBox["\"k\"", TraditionalForm], 0}, {12., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {12., 
       FormBox["\"l\"", TraditionalForm], 0}, {13., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {13., 
       FormBox["\"m\"", TraditionalForm], 0}, {14., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {14., 
       FormBox["\"n\"", TraditionalForm], 0}, {15., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {15., 
       FormBox["\"o\"", TraditionalForm], 0}, {16., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {16., 
       FormBox["\"p\"", TraditionalForm], 0}, {17., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {17., 
       FormBox["\"q\"", TraditionalForm], 0}, {18., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {18., 
       FormBox["\"r\"", TraditionalForm], 0}, {19., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {19., 
       FormBox["\"s\"", TraditionalForm], 0}, {20., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {20., 
       FormBox["\"t\"", TraditionalForm], 0}, {21., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {21., 
       FormBox["\"u\"", TraditionalForm], 0}, {22., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {22., 
       FormBox["\"v\"", TraditionalForm], 0}, {23., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {23., 
       FormBox["\"w\"", TraditionalForm], 0}, {24., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {24., 
       FormBox["\"x\"", TraditionalForm], 0}, {25., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {25., 
       FormBox["\"y\"", TraditionalForm], 0}, {26., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {26., 
       FormBox["\"z\"", TraditionalForm], 0}}, {{0.9999999999999999, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {1.9999999999999998`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {3., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {3.9999999999999996`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {5., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {6., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {7., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {8., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {9., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {10., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {11., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {12., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {13., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {14., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {15., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {16., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {17., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {18., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {19., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {20., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {21., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {22., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {23., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {24., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {25., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {26., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}}}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->{249.92578125, Automatic},
  PlotRange->{{All, All}, {All, All}},
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{None, Automatic}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[14]=",ExpressionUUID->"02313a68-5710-41fc-ba5c-7ee2c7fe56dc"]
}, Open  ]],

Cell["\<\
Here\[CloseCurlyQuote]s a direct way to apply a pure function to an \
association:\
\>", "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"39d1de50-0305-40e8-a816-e2ed7590578a"],

Cell["Apply a pure function to an association:", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"6e2f4db9-dd6a-4879-b9d5-a840b4da059a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"#", "[", "\"\<apples\>\"", "]"}], ",", 
     RowBox[{"#", "[", "\"\<oranges\>\"", "]"}]}], "]"}], "&"}], "[", 
  RowBox[{"\[LeftAssociation]", 
   RowBox[{
    RowBox[{"\"\<apples\>\"", "\[Rule]", "10"}], ",", 
    RowBox[{"\"\<oranges\>\"", "\[Rule]", "12"}], ",", 
    RowBox[{"\"\<pears\>\"", "\[Rule]", "4"}]}], "\[RightAssociation]"}], 
  "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[15]:=",ExpressionUUID->"c8260930-4ce5-493c-85dc-7b082cabbac5"],

Cell[BoxData[
 RowBox[{"f", "[", 
  RowBox[{"10", ",", "12"}], "]"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[15]=",ExpressionUUID->"4e348cfc-ddf0-4963-a381-b91ef3ae7c52"]
}, Open  ]],

Cell[TextData[{
 "It\[CloseCurlyQuote]s very common to have keys that are strings, and the \
Wolfram Language has a special way to ",
 "handle these when it comes to pure functions",
 ": you can just use ",
 Cell[BoxData[
 "#key"], "InlineCodeText",ExpressionUUID->
  "9de1da4a-a78e-4e51-8063-73fbb2a9d035"],
 " to refer to an element whose key is ",
 Cell[BoxData[
 "\"\<key\>\""], "InlineCodeText",ExpressionUUID->
  "acd773b3-9fff-40f2-9e35-71d72f7efd5e"],
 "."
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"c04a6457-a54c-4951-9cc4-06e4e4cc841a"],

Cell["\<\
Use the simpler notation for association elements whose keys are strings:\
\>", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"51b1be3c-4fa0-4e01-ad87-60cb49a8d5f3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{"#apples", ",", "#oranges"}], "]"}], "&"}], "[", 
   RowBox[{"\[LeftAssociation]", 
    RowBox[{
     RowBox[{"\"\<apples\>\"", "\[Rule]", "10"}], ",", 
     RowBox[{"\"\<oranges\>\"", "\[Rule]", "12"}], ",", 
     RowBox[{"\"\<pears\>\"", "\[Rule]", "4"}]}], "\[RightAssociation]"}], 
   "]"}], " "}]], "Input",
 Deletable->False,
 CellLabel->"In[16]:=",ExpressionUUID->"dbbda924-aef8-4e30-adab-8861b29021c2"],

Cell[BoxData[
 RowBox[{"f", "[", 
  RowBox[{"10", ",", "12"}], "]"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[16]=",ExpressionUUID->"09cacba9-930b-4300-9ad2-b26fa83ee214"]
}, Open  ]],

Cell[TextData[{
 "As a more realistic example, apply a pure function that extracts the value \
for \[OpenCurlyDoubleQuote]e\[CloseCurlyDoubleQuote] from the letter counts, \
and divides by the total. The ",
 ButtonBox["N",
  BaseStyle->"Link"],
 " gives the result as a decimal. "
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"7e23b4a7-ca60-4e96-8a18-90f664fc3cc1"],

Cell["\<\
Compute the fraction of letters in the \[OpenCurlyDoubleQuote]computers\
\[CloseCurlyDoubleQuote] article that are \[OpenCurlyDoubleQuote]e\
\[CloseCurlyDoubleQuote]:\
\>", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:12",ExpressionUUID->"acd37e4b-ba07-48bb-becb-39a85b221935"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"#e", "/", 
     RowBox[{"Total", "[", "#", "]"}]}], "&"}], " ", "@", 
   RowBox[{"LetterCounts", "[", 
    RowBox[{"WikipediaData", "[", "\"\<computers\>\"", "]"}], "]"}]}], "//", 
  "N"}]], "Input",
 Deletable->False,
 CellLabel->"In[17]:=",ExpressionUUID->"bc7b512a-0eca-401a-b446-8d85cd9e66ae"],

Cell[BoxData["0.11794996949359365`"], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellTags->"LastCellOfAPage",
 CellLabel->"Out[17]=",ExpressionUUID->"99ba9ebb-0a98-4110-b1d7-be9a3bdea238"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Vocabulary", "VocabularySection",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"p:208",ExpressionUUID->"e9534a74-b6e2-48ec-bfcb-71f86fc4e73d"],

Cell[BoxData[GridBox[{
   {
    RowBox[{
     RowBox[{
      RowBox[{
       ButtonBox["\[LeftAssociation]",
        BaseStyle->"CodeLink",
        ButtonData->"Association"], 
       SubscriptBox[
        StyleBox["key", "CodeVariableLrg"], "1"]}], "\[Rule]", 
      SubscriptBox[
       StyleBox["value", "CodeVariableLrg"], "1"]}], ",", 
     RowBox[{
      SubscriptBox[
       StyleBox["key", "CodeVariableLrg"], "2"], "\[Rule]", 
      SubscriptBox[
       StyleBox["value", "CodeVariableLrg"], "2"]}], ",", 
     RowBox[{
      StyleBox["...", "GrayPointSix"], 
      ButtonBox["\[RightAssociation]",
       BaseStyle->"CodeLink",
       ButtonData->"Association"]}]}], " ", Cell[
    "an association", "VocabularyText",ExpressionUUID->
     "41582e6d-6089-48dc-8fe7-f0a41588e987"]},
   {
    RowBox[{
     ButtonBox["Association",
      BaseStyle->"CodeLink"], "[", 
     StyleBox["rules", "CodeVariableLrg"], "]"}], " ", Cell[
    "turn a list of rules into an association", "VocabularyText",
     ExpressionUUID->"94ff51d3-6f23-4077-bb7e-dfd901fe15ba"]},
   {
    RowBox[{
     StyleBox["assoc", "CodeVariableLrg"], "[", 
     StyleBox["key", "CodeVariableLrg"], "]"}], " ", Cell[
    "extract an element of an association", "VocabularyText",ExpressionUUID->
     "218c31b3-3908-45e3-9426-a093ff42e68c"]},
   {
    RowBox[{
     ButtonBox["Keys",
      BaseStyle->"CodeLink"], "[", 
     StyleBox["assoc", "CodeVariableLrg"], "]"}], " ", Cell[
    "list of keys in an association", "VocabularyText",ExpressionUUID->
     "ced476c8-0c47-4719-8ddd-512d770b0108"]},
   {
    RowBox[{
     ButtonBox["Values",
      BaseStyle->"CodeLink"], "[", 
     StyleBox["assoc", "CodeVariableLrg"], "]"}], " ", Cell[
    "list of values in an association", "VocabularyText",ExpressionUUID->
     "6843521d-972c-45b6-b593-8b67c437289d"]},
   {
    RowBox[{
     ButtonBox["Normal",
      BaseStyle->"CodeLink"], "[", 
     StyleBox["assoc", "CodeVariableLrg"], "]"}], " ", Cell[
    "turn an association into a list of rules", "VocabularyText",
     ExpressionUUID->"9a66a5a9-3007-4ae7-bd4f-2fb095c1d516"]},
   {
    RowBox[{
     ButtonBox["KeySort",
      BaseStyle->"CodeLink"], "[", 
     StyleBox["assoc", "CodeVariableLrg"], "]"}], " ", Cell[
    "sort an association by its keys", "VocabularyText",ExpressionUUID->
     "e19b0d04-ad53-4820-8bd3-76946fc83236"]},
   {
    RowBox[{
     ButtonBox["KeyTake",
      BaseStyle->"CodeLink"], "[", 
     RowBox[{
      StyleBox["assoc", "CodeVariableLrg"], ",", 
      StyleBox["keys", "CodeVariableLrg"]}], "]"}], " ", Cell[
    "take elements with particular keys", "VocabularyText",ExpressionUUID->
     "8eb872ff-f4fd-47cf-aea3-9c0a866142d9"]},
   {
    StyleBox[
     RowBox[{"#", 
      StyleBox["key", "CodeVariableLrg"]}]], " ", Cell[TextData[{
     "function slot  for an element with key \[OpenCurlyDoubleQuote]",
     Cell[BoxData[
      StyleBox["key", "CodeVariable"]], "InlineCode",ExpressionUUID->
      "0253b662-2716-4975-a6e1-f362e2489d2d"],
     "\[CloseCurlyDoubleQuote]"
    }], "VocabularyText",ExpressionUUID->
     "74dc56e1-6d35-46b6-a9fc-9b769a3d1972"]},
   {
    RowBox[{
     ButtonBox["Counts",
      BaseStyle->"CodeLink"], "[", 
     StyleBox["list", "CodeVariableLrg"], "]"}], " ", Cell[
    "an association with counts of distinct elements", "VocabularyText",
     ExpressionUUID->"5e9611d4-6802-41ff-abe0-c9bd92e500bb"]},
   {
    RowBox[{
     ButtonBox["LetterCounts",
      BaseStyle->"CodeLink"], "[", 
     StyleBox["string", "CodeVariableLrg"], "]"}], " ", Cell[
    "an association with counts of distinct letters", "VocabularyText",
     ExpressionUUID->"9245b8d3-66e4-464f-8712-1d347dc7ba5e"]}
  }]], "VocabularyTable",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 GridBoxOptions->{
 GridBoxDividers->{
  "Columns" -> {{False}}, 
   "Rows" -> {False, {True, True, True, True, True, True, True, True, 
      Directive[
       Thickness[1.5], "VocabDivColor"], True, True}, 
     False}}},ExpressionUUID->"210cbb60-bfd4-432d-ac8d-3d382fabdacc"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 DynamicModuleBox[{$CellContext`open$$ = False}, 
  TagBox[GridBox[{
     {
      StyleBox["\<\"Exercises\"\>",
       StripOnInput->False,
       FontSlant->"Italic"], 
      PaneBox[
       TagBox[
        ButtonBox[
         DynamicBox[ToBoxes[
           If[$CellContext`open$$, 
            Row[{
              Style["-", "ExercisePreviewButtonTextHighlight"], 
              Style[" Preview Exercises", "ExercisePreviewButtonText"]}], 
            Row[{
              Style["+", "ExercisePreviewButtonTextHighlight"], 
              Style[" Preview Exercises", "ExercisePreviewButtonText"]}]], 
           StandardForm],
          ImageSizeCache->{115., {1., 10.}}],
         Appearance->None,
         ButtonFunction:>(
          If[$CellContext`open$$, $CellContext`open$$ = 
            False, $CellContext`open$$ = True]; NotebookFind[
            EvaluationNotebook[], "ExerciseSummaryCell", Next, CellStyle, 
            WrapAround -> True, AutoScroll -> False]; FrontEndTokenExecute[
            EvaluationNotebook[], "ExpandSelection"]; FrontEndExecute[
            FrontEndToken[
             EvaluationNotebook[], "OpenCloseGroup"]]),
         Evaluator->Automatic,
         Method->"Preemptive"],
        MouseAppearanceTag["LinkHand"]],
       Alignment->Right,
       ImageSize->Full]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {Left, Right}, "Rows" -> {{Center}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"],
  DynamicModuleValues:>{}]], "ExerciseSection",
 Editable->False,
 ShowCellBracket->False,
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{3.669991951589675*^9},
 ShowStringCharacters->
  False,ExpressionUUID->"ec0349fc-28e3-44f2-8e31-52b3ad6b3e5c"],

Cell[CellGroupData[{

Cell[BoxData[
 TagBox[GridBox[{
    {
     TagBox[GridBox[{
        {
         PaneBox[
          StyleBox["\<\"6 Exercises Available\"\>", "ExerciseSummaryHeading",
           StripOnInput->False],
          ImageMargins->{{20, 0}, {0, 10}}]}
       },
       DefaultBaseStyle->"Column",
       GridBoxAlignment->{"Columns" -> {{Left}}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
       
       GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{0}}}],
      "Column"], 
     PaneBox[
      ButtonBox[
       StyleBox["\<\"Get Started \[RightGuillemet]\"\>", 
        "ExerciseSummaryHeading",
        StripOnInput->False],
       Appearance->None,
       ButtonFunction:>
        NotebookLocate[{"EIWL1-34-associations-exercises.nb", ""}],
       Evaluator->Automatic,
       Method->"Preemptive"],
      FrameMargins->{{10, 0}, {10, 10}},
      ImageSize->Full]}
   },
   AutoDelete->False,
   GridBoxAlignment->{"Columns" -> {{Left}}},
   GridBoxItemSize->{"Columns" -> {
       Scaled[0.7], 
       Scaled[0.3]}, "Rows" -> {{Automatic}}}],
  "Grid"]], "ExerciseSummaryCell",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"6c05f642-48a9-488c-ac7c-c97ff6018dc4"],

Cell[CellGroupData[{

Cell[TextData[{
 "Make a list, in order, of the number of times each of the digits 0 through \
9 occurs in 3^100.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "34.1", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"97fd28e8-32d8-437f-9988-0e5ef976526c"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       RowBox[{"{", 
        RowBox[{
        "7", ",", "9", ",", "9", ",", "5", ",", "1", ",", "5", ",", "4", ",", 
         "7", ",", "1"}], "}"}]], "ExerciseOutput",ExpressionUUID->
       "77f271e9-dee7-4609-9490-45b019daa1eb"],
      Apply[TextCell, 
       Cell[
        BoxData[
         RowBox[{"{", 
           
           RowBox[{"7", ",", "9", ",", "9", ",", "5", ",", "1", ",", "5", ",",
              "4", ",", "7", ",", "1"}], "}"}]], "ExerciseOutput", Selectable -> 
        False, Copyable -> False, Editable -> False, ShowCellBracket -> 
        False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"66a612d2-db3e-4dfc-a586-86a91aaf2ac0"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Make a labeled bar chart of the number of times each of the digits 0 \
through 9 occurs in 2^1000.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "34.2", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"a59f920e-43d5-43aa-a5ef-cd4757afba6b"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       GraphicsBox[{{{{
            {Opacity[0], PointBox[{0.3429357798165137, 0.}]}}}}, {{}, {{{
             {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
              0.63], Thickness[Small]}], {{{
                 {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
                  0.63], Thickness[Small]}], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{0.5412844036697247, 0.}, {
                    1.4587155963302751`, 28.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{17.986988913212343`, 
                    38.08453245258489}, {-47.262648160592434`, 
                    58.807647468726316`}}],
                    StatusArea[#, 28]& ,
                    TagBoxNote->"28"],
                    StyleBox["28", {}, StripOnInput -> False]],
                   Annotation[#, 
                    Style[28, {}], "Tooltip"]& ]}}}}, {{{
                 {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
                  0.63], Thickness[Small]}], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{1.5412844036697246`, 0.}, {
                    2.458715596330275, 34.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{39.34831137112841, 
                    59.445854910500955`}, {-69.88485436687503, 
                    58.807647468726316`}}],
                    StatusArea[#, 34]& ,
                    TagBoxNote->"34"],
                    StyleBox["34", {}, StripOnInput -> False]],
                   Annotation[#, 
                    Style[34, {}], "Tooltip"]& ]}}}}, {{{
                 {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
                  0.63], Thickness[Small]}], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{2.541284403669725, 0.}, {
                    3.4587155963302756`, 23.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{60.709633829044485`, 
                    80.80717736841704}, {-28.410809655356942`, 
                    58.807647468726316`}}],
                    StatusArea[#, 23]& ,
                    TagBoxNote->"23"],
                    StyleBox["23", {}, StripOnInput -> False]],
                   Annotation[#, 
                    Style[23, {}], "Tooltip"]& ]}}}}, {{{
                 {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
                  0.63], Thickness[Small]}], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{3.5412844036697253`, 0.}, {
                    4.458715596330276, 25.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{82.07095628696058, 
                    102.16849982633312`}, {-35.95154505745114, 
                    58.807647468726316`}}],
                    StatusArea[#, 25]& ,
                    TagBoxNote->"25"],
                    StyleBox["25", {}, StripOnInput -> False]],
                   Annotation[#, 
                    Style[25, {}], "Tooltip"]& ]}}}}, {{{
                 {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
                  0.63], Thickness[Small]}], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{4.541284403669725, 0.}, {5.458715596330276, 
                    35.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{103.43227874487664`, 
                    123.52982228424918`}, {-73.65522206792213, 
                    58.807647468726316`}}],
                    StatusArea[#, 35]& ,
                    TagBoxNote->"35"],
                    StyleBox["35", {}, StripOnInput -> False]],
                   Annotation[#, 
                    Style[35, {}], "Tooltip"]& ]}}}}, {{{
                 {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
                  0.63], Thickness[Small]}], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{5.541284403669725, 0.}, {6.458715596330276, 
                    35.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{124.79360120279271`, 
                    144.89114474216524`}, {-73.65522206792213, 
                    58.807647468726316`}}],
                    StatusArea[#, 35]& ,
                    TagBoxNote->"35"],
                    StyleBox["35", {}, StripOnInput -> False]],
                   Annotation[#, 
                    Style[35, {}], "Tooltip"]& ]}}}}, {{{
                 {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
                  0.63], Thickness[Small]}], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{6.541284403669725, 0.}, {7.458715596330276, 
                    34.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{146.15492366070876`, 
                    166.2524672000813}, {-69.88485436687503, 
                    58.807647468726316`}}],
                    StatusArea[#, 34]& ,
                    TagBoxNote->"34"],
                    StyleBox["34", {}, StripOnInput -> False]],
                   Annotation[#, 
                    Style[34, {}], "Tooltip"]& ]}}}}, {{{
                 {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
                  0.63], Thickness[Small]}], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{7.541284403669725, 0.}, {8.458715596330276, 
                    35.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{167.51624611862485`, 
                    187.6137896579974}, {-73.65522206792213, 
                    58.807647468726316`}}],
                    StatusArea[#, 35]& ,
                    TagBoxNote->"35"],
                    StyleBox["35", {}, StripOnInput -> False]],
                   Annotation[#, 
                    Style[35, {}], "Tooltip"]& ]}}}}, {{{
                 {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
                  0.63], Thickness[Small]}], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{8.541284403669724, 0.}, {9.458715596330276, 
                    30.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{188.8775685765409, 
                    208.97511211591345`}, {-54.80338356268663, 
                    58.807647468726316`}}],
                    StatusArea[#, 30]& ,
                    TagBoxNote->"30"],
                    StyleBox["30", {}, StripOnInput -> False]],
                   Annotation[#, 
                    Style[30, {}], "Tooltip"]& ]}}}}, {{{
                 {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
                  0.63], Thickness[Small]}], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{9.541284403669724, 0.}, {
                    10.458715596330276`, 23.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{210.23889103445697`, 
                    230.33643457382954`}, {-28.410809655356942`, 
                    58.807647468726316`}}],
                    StatusArea[#, 23]& ,
                    TagBoxNote->"23"],
                    StyleBox["23", {}, StripOnInput -> False]],
                   Annotation[#, 
                    Style[23, {}], "Tooltip"]& ]}}}}}}}}, {}, {}}, {}, {}, 
         StyleBox[{{{{
              {Thickness[Tiny], 
               LineBox[{{0.3429357798165137, 0.}, {10.66103119266055, 0.}}], 
               StyleBox[{}, "GraphicsLabel",
                StripOnInput->False]}}}}, 
           StyleBox[{{{{
                {Thickness[Tiny], 
                 LineBox[{{0.5412844036697247, 0.}, 
                   Offset[{-1.102182119232618*^-15, -6.}, {0.5412844036697247,
                     0.}]}], 
                 LineBox[{{10.458715596330276`, 0.}, 
                   Offset[{-1.102182119232618*^-15, -6.}, {
                    10.458715596330276`, 
                    0.}]}], {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {
                   LineBox[{{1.4587155963302751`, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    1.4587155963302751`, 0.}]}], 
                   LineBox[{{1.5412844036697249`, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    1.5412844036697249`, 0.}]}], 
                   LineBox[{{2.458715596330275, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {2.458715596330275,
                     0.}]}], 
                   LineBox[{{2.541284403669725, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {2.541284403669725,
                     0.}]}], 
                   LineBox[{{3.4587155963302756`, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    3.4587155963302756`, 0.}]}], 
                   LineBox[{{3.5412844036697253`, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    3.5412844036697253`, 0.}]}], 
                   LineBox[{{4.458715596330276, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {4.458715596330276,
                     0.}]}], 
                   LineBox[{{4.541284403669724, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {4.541284403669724,
                     0.}]}], 
                   LineBox[{{5.458715596330275, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {5.458715596330275,
                     0.}]}], 
                   LineBox[{{5.541284403669724, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {5.541284403669724,
                     0.}]}], 
                   LineBox[{{6.458715596330275, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {6.458715596330275,
                     0.}]}], 
                   LineBox[{{6.541284403669724, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {6.541284403669724,
                     0.}]}], 
                   LineBox[{{7.458715596330275, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {7.458715596330275,
                     0.}]}], 
                   LineBox[{{7.541284403669724, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {7.541284403669724,
                     0.}]}], 
                   LineBox[{{8.458715596330276, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {8.458715596330276,
                     0.}]}], 
                   LineBox[{{8.541284403669724, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {8.541284403669724,
                     0.}]}], 
                   LineBox[{{9.458715596330276, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {9.458715596330276,
                     0.}]}], 
                   LineBox[{{9.541284403669724, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {9.541284403669724,
                     0.}]}]}, {}}}}}}, 
             StyleBox[{{{
                 {Thickness[Tiny], 
                  InsetBox["0", Offset[{0., -2.}, {1., 0.}], {0, 1}, 
                   Automatic, {1, 0}], 
                  InsetBox["1", Offset[{0., -2.}, {2., 0.}], {0, 1}, 
                   Automatic, {1, 0}], 
                  InsetBox["2", Offset[{0., -2.}, {3.0000000000000004, 0.}], {0, 1},
                    Automatic, {1, 0}], 
                  InsetBox["3", Offset[{0., -2.}, {4., 0.}], {0, 1}, 
                   Automatic, {1, 0}], 
                  InsetBox["4", Offset[{0., -2.}, {5., 0.}], {0, 1}, 
                   Automatic, {1, 0}], 
                  InsetBox["5", Offset[{0., -2.}, {6., 0.}], {0, 1}, 
                   Automatic, {1, 0}], 
                  InsetBox["6", Offset[{0., -2.}, {7., 0.}], {0, 1}, 
                   Automatic, {1, 0}], 
                  InsetBox["7", Offset[{0., -2.}, {8., 0.}], {0, 1}, 
                   Automatic, {1, 0}], 
                  InsetBox["8", Offset[{0., -2.}, {9., 0.}], {0, 1}, 
                   Automatic, {1, 0}], 
                  InsetBox["9", Offset[{0., -2.}, {10., 0.}], {0, 1}, 
                   Automatic, {1, 0}]}}}}, "GraphicsLabel",
              StripOnInput->False]}, "GraphicsTicks",
            StripOnInput->False]}, "GraphicsAxes",
          StripOnInput->False,
          Antialiasing->False]},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{False, True},
        AxesLabel->{None, None},
        AxesOrigin->{0.3429357798165137, 0.},
        CoordinatesToolOptions:>{"DisplayFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& )},
        FrameLabel->{{None, None}, {None, None}},
        FrameTicks->{{Automatic, Automatic}, {{{1., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {1., 
             FormBox["0", TraditionalForm], 0}, {2., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {2., 
             FormBox["1", TraditionalForm], 0}, {3., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {3., 
             FormBox["2", TraditionalForm], 0}, {4., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {4., 
             FormBox["3", TraditionalForm], 0}, {5., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {5., 
             FormBox["4", TraditionalForm], 0}, {6., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {6., 
             FormBox["5", TraditionalForm], 0}, {7., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {7., 
             FormBox["6", TraditionalForm], 0}, {8., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {8., 
             FormBox["7", TraditionalForm], 0}, {9., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {9., 
             FormBox["8", TraditionalForm], 0}, {10., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {10., 
             FormBox["9", TraditionalForm], 0}}, {{1., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {2., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {3., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {4., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {5., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {6., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {7., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {8., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {9., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {10., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}}}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        PlotRange->{{All, All}, {All, All}},
        PlotRangePadding->{{
           Scaled[0.02], 
           Scaled[0.02]}, {
           Scaled[0.02], 
           Scaled[0.05]}},
        Ticks->{None, Automatic}]], "ExerciseOutput",ExpressionUUID->
       "40ee8754-12e3-41bb-995c-b0338bc2454f"],
      Apply[TextCell, 
       Cell[
        BoxData[
         GraphicsBox[{{
            Opacity[0], 
            PointBox[{0.3429357798165137, 0.}]}, {{}, {
             RGBColor[0.982864, 0.7431472, 0.3262672], 
             EdgeForm[{
               Opacity[0.63], 
               Thickness[Small]}], {
              RGBColor[0.982864, 0.7431472, 0.3262672], 
              EdgeForm[{
                Opacity[0.63], 
                Thickness[Small]}], 
              TagBox[
               TooltipBox[
                TagBox[
                 DynamicBox[{
                   FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                   
                   RectangleBox[{0.5412844036697247, 0.}, {
                    1.4587155963302751`, 28.}, "RoundingRadius" -> 0]}, 
                  ImageSizeCache -> {{18.968157851375842`, 
                   38.97860119724006}, {-46.41148083543425, 
                   59.18961347997643}}], StatusArea[#, 28]& , TagBoxNote -> 
                 "28"], 
                StyleBox["28", {}, StripOnInput -> False]], Annotation[#, 
                Style[28, {}], "Tooltip"]& ]}, {
              RGBColor[0.982864, 0.7431472, 0.3262672], 
              EdgeForm[{
                Opacity[0.63], 
                Thickness[Small]}], 
              TagBox[
               TooltipBox[
                TagBox[
                 DynamicBox[{
                   FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                   
                   RectangleBox[{1.5412844036697246`, 0.}, {2.458715596330275,
                     34.}, "RoundingRadius" -> 0]}, 
                  ImageSizeCache -> {{40.23454109836784, 
                   60.24498444423206}, {-68.93314390302226, 
                   59.18961347997643}}], StatusArea[#, 34]& , TagBoxNote -> 
                 "34"], 
                StyleBox["34", {}, StripOnInput -> False]], Annotation[#, 
                Style[34, {}], "Tooltip"]& ]}, {
              RGBColor[0.982864, 0.7431472, 0.3262672], 
              EdgeForm[{
                Opacity[0.63], 
                Thickness[Small]}], 
              TagBox[
               TooltipBox[
                TagBox[
                 DynamicBox[{
                   FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                   
                   RectangleBox[{2.541284403669725, 0.}, {3.4587155963302756`,
                     23.}, "RoundingRadius" -> 0]}, 
                  ImageSizeCache -> {{61.50092434535984, 
                   81.51136769122405}, {-27.64342827911092, 
                   59.18961347997643}}], StatusArea[#, 23]& , TagBoxNote -> 
                 "23"], 
                StyleBox["23", {}, StripOnInput -> False]], Annotation[#, 
                Style[23, {}], "Tooltip"]& ]}, {
              RGBColor[0.982864, 0.7431472, 0.3262672], 
              EdgeForm[{
                Opacity[0.63], 
                Thickness[Small]}], 
              TagBox[
               TooltipBox[
                TagBox[
                 DynamicBox[{
                   FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                   
                   RectangleBox[{3.5412844036697253`, 0.}, {4.458715596330276,
                     25.}, "RoundingRadius" -> 0]}, 
                  ImageSizeCache -> {{82.76730759235184, 
                   102.77775093821604`}, {-35.15064930164024, 
                   59.18961347997643}}], StatusArea[#, 25]& , TagBoxNote -> 
                 "25"], 
                StyleBox["25", {}, StripOnInput -> False]], Annotation[#, 
                Style[25, {}], "Tooltip"]& ]}, {
              RGBColor[0.982864, 0.7431472, 0.3262672], 
              EdgeForm[{
                Opacity[0.63], 
                Thickness[Small]}], 
              TagBox[
               TooltipBox[
                TagBox[
                 DynamicBox[{
                   FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                   
                   RectangleBox[{4.541284403669725, 0.}, {5.458715596330276, 
                    35.}, "RoundingRadius" -> 0]}, 
                  ImageSizeCache -> {{104.03369083934383`, 
                   124.04413418520805`}, {-72.68675441428692, 
                   59.18961347997643}}], StatusArea[#, 35]& , TagBoxNote -> 
                 "35"], 
                StyleBox["35", {}, StripOnInput -> False]], Annotation[#, 
                Style[35, {}], "Tooltip"]& ]}, {
              RGBColor[0.982864, 0.7431472, 0.3262672], 
              EdgeForm[{
                Opacity[0.63], 
                Thickness[Small]}], 
              TagBox[
               TooltipBox[
                TagBox[
                 DynamicBox[{
                   FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                   
                   RectangleBox[{5.541284403669725, 0.}, {6.458715596330276, 
                    35.}, "RoundingRadius" -> 0]}, 
                  ImageSizeCache -> {{125.30007408633583`, 
                   145.31051743220004`}, {-72.68675441428692, 
                   59.18961347997643}}], StatusArea[#, 35]& , TagBoxNote -> 
                 "35"], 
                StyleBox["35", {}, StripOnInput -> False]], Annotation[#, 
                Style[35, {}], "Tooltip"]& ]}, {
              RGBColor[0.982864, 0.7431472, 0.3262672], 
              EdgeForm[{
                Opacity[0.63], 
                Thickness[Small]}], 
              TagBox[
               TooltipBox[
                TagBox[
                 DynamicBox[{
                   FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                   
                   RectangleBox[{6.541284403669725, 0.}, {7.458715596330276, 
                    34.}, "RoundingRadius" -> 0]}, 
                  ImageSizeCache -> {{146.56645733332783`, 
                   166.57690067919205`}, {-68.93314390302226, 
                   59.18961347997643}}], StatusArea[#, 34]& , TagBoxNote -> 
                 "34"], 
                StyleBox["34", {}, StripOnInput -> False]], Annotation[#, 
                Style[34, {}], "Tooltip"]& ]}, {
              RGBColor[0.982864, 0.7431472, 0.3262672], 
              EdgeForm[{
                Opacity[0.63], 
                Thickness[Small]}], 
              TagBox[
               TooltipBox[
                TagBox[
                 DynamicBox[{
                   FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                   
                   RectangleBox[{7.541284403669725, 0.}, {8.458715596330276, 
                    35.}, "RoundingRadius" -> 0]}, 
                  ImageSizeCache -> {{167.83284058031984`, 
                   187.84328392618406`}, {-72.68675441428692, 
                   59.18961347997643}}], StatusArea[#, 35]& , TagBoxNote -> 
                 "35"], 
                StyleBox["35", {}, StripOnInput -> False]], Annotation[#, 
                Style[35, {}], "Tooltip"]& ]}, {
              RGBColor[0.982864, 0.7431472, 0.3262672], 
              EdgeForm[{
                Opacity[0.63], 
                Thickness[Small]}], 
              TagBox[
               TooltipBox[
                TagBox[
                 DynamicBox[{
                   FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                   
                   RectangleBox[{8.541284403669724, 0.}, {9.458715596330276, 
                    30.}, "RoundingRadius" -> 0]}, 
                  ImageSizeCache -> {{189.09922382731182`, 
                   209.10966717317604`}, {-53.91870185796358, 
                   59.18961347997643}}], StatusArea[#, 30]& , TagBoxNote -> 
                 "30"], 
                StyleBox["30", {}, StripOnInput -> False]], Annotation[#, 
                Style[30, {}], "Tooltip"]& ]}, {
              RGBColor[0.982864, 0.7431472, 0.3262672], 
              EdgeForm[{
                Opacity[0.63], 
                Thickness[Small]}], 
              TagBox[
               TooltipBox[
                TagBox[
                 DynamicBox[{
                   FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                   
                   RectangleBox[{9.541284403669724, 0.}, {10.458715596330276`,
                     23.}, "RoundingRadius" -> 0]}, 
                  ImageSizeCache -> {{210.36560707430382`, 
                   230.37605042016804`}, {-27.64342827911092, 
                   59.18961347997643}}], StatusArea[#, 23]& , TagBoxNote -> 
                 "23"], 
                StyleBox["23", {}, StripOnInput -> False]], Annotation[#, 
                Style[23, {}], "Tooltip"]& ]}}, {}, {}}, {}, {}, 
           StyleBox[{{
              Thickness[Tiny], 
              LineBox[{{0.3429357798165137, 0.}, {10.66103119266055, 0.}}], 
              StyleBox[{}, "GraphicsLabel", StripOnInput -> False]}, 
             StyleBox[{{
                Thickness[Tiny], 
                LineBox[{{0.5412844036697247, 0.}, 
                  
                  Offset[{-1.102182119232618*^-15, -6.}, {0.5412844036697247, 
                   0.}]}], 
                LineBox[{{10.458715596330276`, 0.}, 
                  
                  Offset[{-1.102182119232618*^-15, -6.}, {10.458715596330276`,
                    0.}]}], {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {
                  LineBox[{{1.4587155963302751`, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    1.4587155963302751`, 0.}]}], 
                  LineBox[{{1.5412844036697249`, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    1.5412844036697249`, 0.}]}], 
                  LineBox[{{2.458715596330275, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {2.458715596330275,
                     0.}]}], 
                  LineBox[{{2.541284403669725, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {2.541284403669725,
                     0.}]}], 
                  LineBox[{{3.4587155963302756`, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    3.4587155963302756`, 0.}]}], 
                  LineBox[{{3.5412844036697253`, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    3.5412844036697253`, 0.}]}], 
                  LineBox[{{4.458715596330276, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {4.458715596330276,
                     0.}]}], 
                  LineBox[{{4.541284403669724, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {4.541284403669724,
                     0.}]}], 
                  LineBox[{{5.458715596330275, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {5.458715596330275,
                     0.}]}], 
                  LineBox[{{5.541284403669724, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {5.541284403669724,
                     0.}]}], 
                  LineBox[{{6.458715596330275, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {6.458715596330275,
                     0.}]}], 
                  LineBox[{{6.541284403669724, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {6.541284403669724,
                     0.}]}], 
                  LineBox[{{7.458715596330275, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {7.458715596330275,
                     0.}]}], 
                  LineBox[{{7.541284403669724, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {7.541284403669724,
                     0.}]}], 
                  LineBox[{{8.458715596330276, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {8.458715596330276,
                     0.}]}], 
                  LineBox[{{8.541284403669724, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {8.541284403669724,
                     0.}]}], 
                  LineBox[{{9.458715596330276, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {9.458715596330276,
                     0.}]}], 
                  LineBox[{{9.541284403669724, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {9.541284403669724,
                     0.}]}]}, {}}}, 
               StyleBox[{
                 Thickness[Tiny], 
                 InsetBox["0", 
                  Offset[{0., -2.}, {1., 0.}], {0, 1}, Automatic, {1, 0}], 
                 InsetBox["1", 
                  Offset[{0., -2.}, {2., 0.}], {0, 1}, Automatic, {1, 0}], 
                 InsetBox["2", 
                  Offset[{0., -2.}, {3.0000000000000004`, 0.}], {0, 1}, 
                  Automatic, {1, 0}], 
                 InsetBox["3", 
                  Offset[{0., -2.}, {4., 0.}], {0, 1}, Automatic, {1, 0}], 
                 InsetBox["4", 
                  Offset[{0., -2.}, {5., 0.}], {0, 1}, Automatic, {1, 0}], 
                 InsetBox["5", 
                  Offset[{0., -2.}, {6., 0.}], {0, 1}, Automatic, {1, 0}], 
                 InsetBox["6", 
                  Offset[{0., -2.}, {7., 0.}], {0, 1}, Automatic, {1, 0}], 
                 InsetBox["7", 
                  Offset[{0., -2.}, {8., 0.}], {0, 1}, Automatic, {1, 0}], 
                 InsetBox["8", 
                  Offset[{0., -2.}, {9., 0.}], {0, 1}, Automatic, {1, 0}], 
                 InsetBox["9", 
                  Offset[{0., -2.}, {10., 0.}], {0, 1}, Automatic, {1, 0}]}, 
                "GraphicsLabel", StripOnInput -> False]}, "GraphicsTicks", 
              StripOnInput -> False]}, "GraphicsAxes", StripOnInput -> False, 
            Antialiasing -> False]}, AspectRatio -> 
          NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {False, True},
           AxesLabel -> {None, None}, AxesOrigin -> {0.3429357798165137, 0.}, 
          CoordinatesToolOptions :> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}, FrameLabel -> {{None, None}, {None, None}}, 
          FrameTicks -> {{Automatic, Automatic}, {{{1., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {1., 
               FormBox["0", TraditionalForm], 0}, {2., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {2., 
               FormBox["1", TraditionalForm], 0}, {3., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {3., 
               FormBox["2", TraditionalForm], 0}, {4., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {4., 
               FormBox["3", TraditionalForm], 0}, {5., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {5., 
               FormBox["4", TraditionalForm], 0}, {6., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {6., 
               FormBox["5", TraditionalForm], 0}, {7., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {7., 
               FormBox["6", TraditionalForm], 0}, {8., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {8., 
               FormBox["7", TraditionalForm], 0}, {9., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {9., 
               FormBox["8", TraditionalForm], 0}, {10., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {10., 
               FormBox["9", TraditionalForm], 0}}, {{1., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {2., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {3., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {4., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {5., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {6., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {7., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {8., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {9., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {10., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}}}}, 
          GridLines -> {None, None}, GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], PlotRange -> {{All, All}, {All, All}}, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, Ticks -> {None, Automatic}]], "ExerciseOutput", 
        Selectable -> False, Copyable -> False, Editable -> False, 
        ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"abcd234d-39ad-44fd-a18c-bd80ce4620c2"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Make a labeled bar chart of the number of times each possible first letter \
occurs in words from ",
 Cell[BoxData[
  RowBox[{
   ButtonBox["WordList",
    BaseStyle->"CodeLink"], "[", " ", "]"}]], "InlineCode",ExpressionUUID->
  "ac4234a0-65ef-4401-9d66-56a27f9e501e"],
 ".",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "34.3", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"34e46618-2b96-4f4c-b09f-54125b232d9c"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       GraphicsBox[{{{{
            {Opacity[0], PointBox[{0.01582867783985098, 0.}]}}}}, {{}, {{{
             {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
              0.518], Thickness[Small]}], {{{
                 {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
                  0.518], Thickness[Small]}], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{0.5344506517690875, 0.}, {
                    1.4655493482309123`, 2443.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{30.67178047689664, 
                    41.80334327204321}, {-10.463160269697056`, 
                    87.10237589969347}}],
                    StatusArea[#, 2443]& ,
                    TagBoxNote->"2443"],
                    StyleBox["2443", {}, StripOnInput -> False]],
                   Annotation[#, 
                    Style[2443, {}], "Tooltip"]& ]}}}}, {{{
                 {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
                  0.518], Thickness[Small]}], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{1.5344506517690872`, 0.}, {
                    2.4655493482309123`, 2223.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{42.09007891888406, 
                    53.22164171403063}, {-1.722096840607449, 
                    87.10237589969347}}],
                    StatusArea[#, 2223]& ,
                    TagBoxNote->"2223"],
                    StyleBox["2223", {}, StripOnInput -> False]],
                   Annotation[#, 
                    Style[2223, {}], "Tooltip"]& ]}}}}, {{{
                 {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
                  0.518], Thickness[Small]}], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{2.5344506517690872`, 0.}, {
                    3.4655493482309123`, 3776.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{53.50837736087148, 
                    64.63994015601804}, {-63.426058228680915`, 
                    87.10237589969347}}],
                    StatusArea[#, 3776]& ,
                    TagBoxNote->"3776"],
                    StyleBox["3776", {}, StripOnInput -> False]],
                   Annotation[#, 
                    Style[3776, {}], "Tooltip"]& ]}}}}, {{{
                 {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
                  0.518], Thickness[Small]}], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{3.5344506517690872`, 0.}, {
                    4.465549348230912, 2504.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{64.9266758028589, 
                    76.05823859800546}, {-12.886818765944625`, 
                    87.10237589969347}}],
                    StatusArea[#, 2504]& ,
                    TagBoxNote->"2504"],
                    StyleBox["2504", {}, StripOnInput -> False]],
                   Annotation[#, 
                    Style[2504, {}], "Tooltip"]& ]}}}}, {{{
                 {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
                  0.518], Thickness[Small]}], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{4.534450651769087, 0.}, {5.465549348230912, 
                    1674.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{76.34497424484631, 87.47653703999288}, {
                    20.090829625620714`, 87.10237589969347}}],
                    StatusArea[#, 1674]& ,
                    TagBoxNote->"1674"],
                    StyleBox["1674", {}, StripOnInput -> False]],
                   Annotation[#, 
                    Style[1674, {}], "Tooltip"]& ]}}}}, {{{
                 {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
                  0.518], Thickness[Small]}], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{5.534450651769087, 0.}, {6.465549348230912, 
                    1716.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{87.76327268683373, 98.8948354819803}, {
                    18.42208115279452, 87.10237589969347}}],
                    StatusArea[#, 1716]& ,
                    TagBoxNote->"1716"],
                    StyleBox["1716", {}, StripOnInput -> False]],
                   Annotation[#, 
                    Style[1716, {}], "Tooltip"]& ]}}}}, {{{
                 {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
                  0.518], Thickness[Small]}], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{6.534450651769087, 0.}, {7.465549348230912, 
                    1223.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{99.18157112882116, 
                    110.31313392396771`}, {38.010009655254414`, 
                    87.10237589969347}}],
                    StatusArea[#, 1223]& ,
                    TagBoxNote->"1223"],
                    StyleBox["1223", {}, StripOnInput -> False]],
                   Annotation[#, 
                    Style[1223, {}], "Tooltip"]& ]}}}}, {{{
                 {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
                  0.518], Thickness[Small]}], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{7.534450651769087, 0.}, {8.465549348230912, 
                    1446.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{110.59986957080858`, 
                    121.73143236595513`}, {29.149749906677215`, 
                    87.10237589969347}}],
                    StatusArea[#, 1446]& ,
                    TagBoxNote->"1446"],
                    StyleBox["1446", {}, StripOnInput -> False]],
                   Annotation[#, 
                    Style[1446, {}], "Tooltip"]& ]}}}}, {{{
                 {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
                  0.518], Thickness[Small]}], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{8.534450651769086, 0.}, {9.465549348230912, 
                    1913.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{122.01816801279597`, 
                    133.14973080794255`}, {10.594856173109733`, 
                    87.10237589969347}}],
                    StatusArea[#, 1913]& ,
                    TagBoxNote->"1913"],
                    StyleBox["1913", {}, StripOnInput -> False]],
                   Annotation[#, 
                    Style[1913, {}], "Tooltip"]& ]}}}}, {{{
                 {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
                  0.518], Thickness[Small]}], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{9.534450651769086, 0.}, {
                    10.465549348230912`, 319.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{133.4364664547834, 144.56802924993}, {
                    73.92783392751353, 87.10237589969347}}],
                    StatusArea[#, 319]& ,
                    TagBoxNote->"319"],
                    StyleBox["319", {}, StripOnInput -> False]],
                   Annotation[#, 
                    Style[319, {}], "Tooltip"]& ]}}}}, {{{
                 {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
                  0.518], Thickness[Small]}], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{10.534450651769086`, 0.}, {
                    11.465549348230912`, 233.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{144.85476489677083`, 
                    155.98632769191738`}, {77.34479508615766, 
                    87.10237589969347}}],
                    StatusArea[#, 233]& ,
                    TagBoxNote->"233"],
                    StyleBox["233", {}, StripOnInput -> False]],
                   Annotation[#, 
                    Style[233, {}], "Tooltip"]& ]}}}}, {{{
                 {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
                  0.518], Thickness[Small]}], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{11.534450651769086`, 0.}, {
                    12.465549348230912`, 1207.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{156.27306333875822`, 
                    167.4046261339048}, {38.6457233591882, 
                    87.10237589969347}}],
                    StatusArea[#, 1207]& ,
                    TagBoxNote->"1207"],
                    StyleBox["1207", {}, StripOnInput -> False]],
                   Annotation[#, 
                    Style[1207, {}], "Tooltip"]& ]}}}}, {{{
                 {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
                  0.518], Thickness[Small]}], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{12.534450651769086`, 0.}, {
                    13.465549348230912`, 2049.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{167.69136178074564`, 
                    178.82292457589222`}, {5.191289689672516, 
                    87.10237589969347}}],
                    StatusArea[#, 2049]& ,
                    TagBoxNote->"2049"],
                    StyleBox["2049", {}, StripOnInput -> False]],
                   Annotation[#, 
                    Style[2049, {}], "Tooltip"]& ]}}}}, {{{
                 {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
                  0.518], Thickness[Small]}], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{13.534450651769086`, 0.}, {
                    14.465549348230912`, 853.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{179.10966022273308`, 
                    190.24122301787966`}, {52.7108890587233, 
                    87.10237589969347}}],
                    StatusArea[#, 853]& ,
                    TagBoxNote->"853"],
                    StyleBox["853", {}, StripOnInput -> False]],
                   Annotation[#, 
                    Style[853, {}], "Tooltip"]& ]}}}}, {{{
                 {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
                  0.518], Thickness[Small]}], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{14.534450651769086`, 0.}, {
                    15.465549348230912`, 995.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{190.5279586647205, 
                    201.65952145986708`}, {47.068929936310916`, 
                    87.10237589969347}}],
                    StatusArea[#, 995]& ,
                    TagBoxNote->"995"],
                    StyleBox["995", {}, StripOnInput -> False]],
                   Annotation[#, 
                    Style[995, {}], "Tooltip"]& ]}}}}, {{{
                 {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
                  0.518], Thickness[Small]}], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{15.534450651769086`, 0.}, {
                    16.465549348230912`, 3267.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{201.94625710670792`, 
                    213.0778199018545}, {-43.202416022287224`, 
                    87.10237589969347}}],
                    StatusArea[#, 3267]& ,
                    TagBoxNote->"3267"],
                    StyleBox["3267", {}, StripOnInput -> False]],
                   Annotation[#, 
                    Style[3267, {}], "Tooltip"]& ]}}}}, {{{
                 {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
                  0.518], Thickness[Small]}], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{16.534450651769088`, 0.}, {
                    17.465549348230912`, 197.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{213.36455554869534`, 
                    224.4961183438419}, {78.77515092000868, 
                    87.10237589969347}}],
                    StatusArea[#, 197]& ,
                    TagBoxNote->"197"],
                    StyleBox["197", {}, StripOnInput -> False]],
                   Annotation[#, 
                    Style[197, {}], "Tooltip"]& ]}}}}, {{{
                 {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
                  0.518], Thickness[Small]}], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{17.534450651769088`, 0.}, {
                    18.465549348230912`, 2092.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{224.78285399068275`, 
                    235.91441678582933`}, {3.482809110350459, 
                    87.10237589969347}}],
                    StatusArea[#, 2092]& ,
                    TagBoxNote->"2092"],
                    StyleBox["2092", {}, StripOnInput -> False]],
                   Annotation[#, 
                    Style[2092, {}], "Tooltip"]& ]}}}}, {{{
                 {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
                  0.518], Thickness[Small]}], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{18.534450651769088`, 0.}, {
                    19.465549348230912`, 4642.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{236.2011524326702, 
                    247.33271522781675`}, {-97.83406245409728, 
                    87.10237589969347}}],
                    StatusArea[#, 4642]& ,
                    TagBoxNote->"4642"],
                    StyleBox["4642", {}, StripOnInput -> False]],
                   Annotation[#, 
                    Style[4642, {}], "Tooltip"]& ]}}}}, {{{
                 {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
                  0.518], Thickness[Small]}], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{19.534450651769088`, 0.}, {
                    20.465549348230912`, 2038.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{247.61945087465762`, 
                    258.7510136698042}, {5.6283428611269954`, 
                    87.10237589969347}}],
                    StatusArea[#, 2038]& ,
                    TagBoxNote->"2038"],
                    StyleBox["2038", {}, StripOnInput -> False]],
                   Annotation[#, 
                    Style[2038, {}], "Tooltip"]& ]}}}}, {{{
                 {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
                  0.518], Thickness[Small]}], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{20.534450651769088`, 0.}, {
                    21.465549348230912`, 1556.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{259.03774931664503`, 
                    270.1693121117916}, {24.77921819213241, 
                    87.10237589969347}}],
                    StatusArea[#, 1556]& ,
                    TagBoxNote->"1556"],
                    StyleBox["1556", {}, StripOnInput -> False]],
                   Annotation[#, 
                    Style[1556, {}], "Tooltip"]& ]}}}}, {{{
                 {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
                  0.518], Thickness[Small]}], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{21.534450651769088`, 0.}, {
                    22.465549348230912`, 646.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{270.45604775863245`, 
                    281.58761055377903`}, {60.93543510336671, 
                    87.10237589969347}}],
                    StatusArea[#, 646]& ,
                    TagBoxNote->"646"],
                    StyleBox["646", {}, StripOnInput -> False]],
                   Annotation[#, 
                    Style[646, {}], "Tooltip"]& ]}}}}, {{{
                 {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
                  0.518], Thickness[Small]}], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{22.534450651769088`, 0.}, {
                    23.465549348230912`, 1007.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{281.87434620061987`, 
                    293.00590899576645`}, {46.592144658360574`, 
                    87.10237589969347}}],
                    StatusArea[#, 1007]& ,
                    TagBoxNote->"1007"],
                    StyleBox["1007", {}, StripOnInput -> False]],
                   Annotation[#, 
                    Style[1007, {}], "Tooltip"]& ]}}}}, {{{
                 {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
                  0.518], Thickness[Small]}], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{23.534450651769088`, 0.}, {
                    24.465549348230912`, 11.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{293.2926446426073, 
                    304.42420743775386`}, {86.16532272823899, 
                    87.10237589969347}}],
                    StatusArea[#, 11]& ,
                    TagBoxNote->"11"],
                    StyleBox["11", {}, StripOnInput -> False]],
                   Annotation[#, 
                    Style[11, {}], "Tooltip"]& ]}}}}, {{{
                 {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
                  0.518], Thickness[Small]}], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{24.534450651769088`, 0.}, {
                    25.465549348230912`, 109.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{304.7109430845947, 315.8425058797413}, {
                    82.27157629164452, 87.10237589969347}}],
                    StatusArea[#, 109]& ,
                    TagBoxNote->"109"],
                    StyleBox["109", {}, StripOnInput -> False]],
                   Annotation[#, 
                    Style[109, {}], "Tooltip"]& ]}}}}, {{{
                 {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
                  0.518], Thickness[Small]}], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{25.534450651769088`, 0.}, {
                    26.465549348230912`, 58.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{316.1292415265821, 327.2608043217287}, {
                    84.29791372293349, 87.10237589969347}}],
                    StatusArea[#, 58]& ,
                    TagBoxNote->"58"],
                    StyleBox["58", {}, StripOnInput -> False]],
                   Annotation[#, 
                    Style[58, {}], "Tooltip"]& ]}}}}}}}}, {}, {}}, {}, {}, 
         StyleBox[{{{{
              {Thickness[Tiny], 
               LineBox[{{0.01582867783985098, 0.}, {26.994543761638734`, 
                0.}}], 
               StyleBox[{}, "GraphicsLabel",
                StripOnInput->False]}}}}, 
           StyleBox[{{{{
                {Thickness[Tiny], 
                 LineBox[{{0.5344506517690875, 0.}, 
                   Offset[{-1.102182119232618*^-15, -6.}, {0.5344506517690875,
                     0.}]}], 
                 LineBox[{{26.465549348230912`, 0.}, 
                   Offset[{-1.102182119232618*^-15, -6.}, {
                    26.465549348230912`, 
                    0.}]}], {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {
                   LineBox[{{1.4655493482309123`, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    1.4655493482309123`, 0.}]}], 
                   LineBox[{{1.5344506517690872`, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    1.5344506517690872`, 0.}]}], 
                   LineBox[{{2.4655493482309128`, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    2.4655493482309128`, 0.}]}], 
                   LineBox[{{2.5344506517690872`, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    2.5344506517690872`, 0.}]}], 
                   LineBox[{{3.4655493482309128`, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    3.4655493482309128`, 0.}]}], 
                   LineBox[{{3.5344506517690872`, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    3.5344506517690872`, 0.}]}], 
                   LineBox[{{4.465549348230912, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {4.465549348230912,
                     0.}]}], 
                   LineBox[{{4.534450651769087, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {4.534450651769087,
                     0.}]}], 
                   LineBox[{{5.465549348230911, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {5.465549348230911,
                     0.}]}], 
                   LineBox[{{5.534450651769086, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {5.534450651769086,
                     0.}]}], 
                   LineBox[{{6.465549348230911, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {6.465549348230911,
                     0.}]}], 
                   LineBox[{{6.534450651769086, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {6.534450651769086,
                     0.}]}], 
                   LineBox[{{7.465549348230911, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {7.465549348230911,
                     0.}]}], 
                   LineBox[{{7.534450651769086, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {7.534450651769086,
                     0.}]}], 
                   LineBox[{{8.465549348230912, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {8.465549348230912,
                     0.}]}], 
                   LineBox[{{8.534450651769086, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {8.534450651769086,
                     0.}]}], 
                   LineBox[{{9.465549348230912, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {9.465549348230912,
                     0.}]}], 
                   LineBox[{{9.534450651769086, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {9.534450651769086,
                     0.}]}], 
                   LineBox[{{10.465549348230912`, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    10.465549348230912`, 0.}]}], 
                   LineBox[{{10.534450651769086`, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    10.534450651769086`, 0.}]}], 
                   LineBox[{{11.465549348230912`, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    11.465549348230912`, 0.}]}], 
                   LineBox[{{11.534450651769086`, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    11.534450651769086`, 0.}]}], 
                   LineBox[{{12.465549348230912`, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    12.465549348230912`, 0.}]}], 
                   LineBox[{{12.534450651769086`, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    12.534450651769086`, 0.}]}], 
                   LineBox[{{13.465549348230912`, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    13.465549348230912`, 0.}]}], 
                   LineBox[{{13.534450651769086`, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    13.534450651769086`, 0.}]}], 
                   LineBox[{{14.465549348230912`, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    14.465549348230912`, 0.}]}], 
                   LineBox[{{14.534450651769086`, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    14.534450651769086`, 0.}]}], 
                   LineBox[{{15.465549348230912`, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    15.465549348230912`, 0.}]}], 
                   LineBox[{{15.534450651769086`, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    15.534450651769086`, 0.}]}], 
                   LineBox[{{16.465549348230912`, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    16.465549348230912`, 0.}]}], 
                   LineBox[{{16.534450651769085`, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    16.534450651769085`, 0.}]}], 
                   LineBox[{{17.465549348230912`, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    17.465549348230912`, 0.}]}], 
                   LineBox[{{17.534450651769088`, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    17.534450651769088`, 0.}]}], 
                   LineBox[{{18.465549348230912`, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    18.465549348230912`, 0.}]}], 
                   LineBox[{{18.534450651769088`, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    18.534450651769088`, 0.}]}], 
                   LineBox[{{19.465549348230912`, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    19.465549348230912`, 0.}]}], 
                   LineBox[{{19.534450651769088`, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    19.534450651769088`, 0.}]}], 
                   LineBox[{{20.465549348230912`, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    20.465549348230912`, 0.}]}], 
                   LineBox[{{20.534450651769088`, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    20.534450651769088`, 0.}]}], 
                   LineBox[{{21.465549348230912`, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    21.465549348230912`, 0.}]}], 
                   LineBox[{{21.534450651769088`, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    21.534450651769088`, 0.}]}], 
                   LineBox[{{22.465549348230912`, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    22.465549348230912`, 0.}]}], 
                   LineBox[{{22.534450651769088`, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    22.534450651769088`, 0.}]}], 
                   LineBox[{{23.465549348230912`, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    23.465549348230912`, 0.}]}], 
                   LineBox[{{23.534450651769088`, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    23.534450651769088`, 0.}]}], 
                   LineBox[{{24.465549348230912`, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    24.465549348230912`, 0.}]}], 
                   LineBox[{{24.534450651769088`, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    24.534450651769088`, 0.}]}], 
                   LineBox[{{25.465549348230912`, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    25.465549348230912`, 0.}]}], 
                   LineBox[{{25.534450651769088`, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    25.534450651769088`, 0.}]}]}, {}}}}}}, 
             StyleBox[{{{
                 {Thickness[Tiny], 
                  InsetBox["\<\"a\"\>", 
                   Offset[{0., -2.}, {0.9999999999999999, 0.}], {0, 1}, 
                   Automatic, {1, 0}], 
                  InsetBox["\<\"b\"\>", Offset[{0., -2.}, {2., 0.}], {0, 1}, 
                   Automatic, {1, 0}], 
                  InsetBox["\<\"c\"\>", Offset[{0., -2.}, {3., 0.}], {0, 1}, 
                   Automatic, {1, 0}], 
                  InsetBox["\<\"d\"\>", Offset[{0., -2.}, {4., 0.}], {0, 1}, 
                   Automatic, {1, 0}], 
                  InsetBox["\<\"e\"\>", 
                   Offset[{0., -2.}, {4.999999999999999, 0.}], {0, 1}, 
                   Automatic, {1, 0}], 
                  InsetBox["\<\"f\"\>", 
                   Offset[{0., -2.}, {5.999999999999999, 0.}], {0, 1}, 
                   Automatic, {1, 0}], 
                  InsetBox["\<\"g\"\>", 
                   Offset[{0., -2.}, {6.999999999999999, 0.}], {0, 1}, 
                   Automatic, {1, 0}], 
                  InsetBox["\<\"h\"\>", 
                   Offset[{0., -2.}, {7.999999999999999, 0.}], {0, 1}, 
                   Automatic, {1, 0}], 
                  InsetBox["\<\"i\"\>", Offset[{0., -2.}, {9., 0.}], {0, 1}, 
                   Automatic, {1, 0}], 
                  InsetBox["\<\"j\"\>", Offset[{0., -2.}, {10., 0.}], {0, 1}, 
                   Automatic, {1, 0}], 
                  InsetBox["\<\"k\"\>", Offset[{0., -2.}, {11., 0.}], {0, 1}, 
                   Automatic, {1, 0}], 
                  InsetBox["\<\"l\"\>", Offset[{0., -2.}, {12., 0.}], {0, 1}, 
                   Automatic, {1, 0}], 
                  InsetBox["\<\"m\"\>", Offset[{0., -2.}, {13., 0.}], {0, 1}, 
                   Automatic, {1, 0}], 
                  InsetBox["\<\"n\"\>", Offset[{0., -2.}, {14., 0.}], {0, 1}, 
                   Automatic, {1, 0}], 
                  InsetBox["\<\"o\"\>", Offset[{0., -2.}, {15., 0.}], {0, 1}, 
                   Automatic, {1, 0}], 
                  InsetBox["\<\"p\"\>", Offset[{0., -2.}, {16., 0.}], {0, 1}, 
                   Automatic, {1, 0}], 
                  InsetBox["\<\"q\"\>", Offset[{0., -2.}, {17., 0.}], {0, 1}, 
                   Automatic, {1, 0}], 
                  InsetBox["\<\"r\"\>", Offset[{0., -2.}, {18., 0.}], {0, 1}, 
                   Automatic, {1, 0}], 
                  InsetBox["\<\"s\"\>", Offset[{0., -2.}, {19., 0.}], {0, 1}, 
                   Automatic, {1, 0}], 
                  InsetBox["\<\"t\"\>", Offset[{0., -2.}, {20., 0.}], {0, 1}, 
                   Automatic, {1, 0}], 
                  InsetBox["\<\"u\"\>", Offset[{0., -2.}, {21., 0.}], {0, 1}, 
                   Automatic, {1, 0}], 
                  InsetBox["\<\"v\"\>", Offset[{0., -2.}, {22., 0.}], {0, 1}, 
                   Automatic, {1, 0}], 
                  InsetBox["\<\"w\"\>", Offset[{0., -2.}, {23., 0.}], {0, 1}, 
                   Automatic, {1, 0}], 
                  InsetBox["\<\"x\"\>", Offset[{0., -2.}, {24., 0.}], {0, 1}, 
                   Automatic, {1, 0}], 
                  InsetBox["\<\"y\"\>", Offset[{0., -2.}, {25., 0.}], {0, 1}, 
                   Automatic, {1, 0}], 
                  InsetBox["\<\"z\"\>", Offset[{0., -2.}, {26., 0.}], {0, 1}, 
                   Automatic, {1, 0}]}}}}, "GraphicsLabel",
              StripOnInput->False]}, "GraphicsTicks",
            StripOnInput->False]}, "GraphicsAxes",
          StripOnInput->False,
          Antialiasing->False]},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{False, True},
        AxesLabel->{None, None},
        AxesOrigin->{0.01582867783985098, 0.},
        CoordinatesToolOptions:>{"DisplayFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& )},
        FrameLabel->{{None, None}, {None, None}},
        FrameTicks->{{Automatic, Automatic}, {{{0.9999999999999999, 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {0.9999999999999999, 
             FormBox["\"a\"", TraditionalForm], 0}, {1.9999999999999998`, 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {
            1.9999999999999998`, 
             FormBox["\"b\"", TraditionalForm], 0}, {3., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {3., 
             FormBox["\"c\"", TraditionalForm], 0}, {3.9999999999999996`, 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {
            3.9999999999999996`, 
             FormBox["\"d\"", TraditionalForm], 0}, {5., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {5., 
             FormBox["\"e\"", TraditionalForm], 0}, {6., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {6., 
             FormBox["\"f\"", TraditionalForm], 0}, {7., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {7., 
             FormBox["\"g\"", TraditionalForm], 0}, {8., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {8., 
             FormBox["\"h\"", TraditionalForm], 0}, {9., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {9., 
             FormBox["\"i\"", TraditionalForm], 0}, {10., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {10., 
             FormBox["\"j\"", TraditionalForm], 0}, {11., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {11., 
             FormBox["\"k\"", TraditionalForm], 0}, {12., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {12., 
             FormBox["\"l\"", TraditionalForm], 0}, {13., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {13., 
             FormBox["\"m\"", TraditionalForm], 0}, {14., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {14., 
             FormBox["\"n\"", TraditionalForm], 0}, {15., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {15., 
             FormBox["\"o\"", TraditionalForm], 0}, {16., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {16., 
             FormBox["\"p\"", TraditionalForm], 0}, {17., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {17., 
             FormBox["\"q\"", TraditionalForm], 0}, {18., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {18., 
             FormBox["\"r\"", TraditionalForm], 0}, {19., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {19., 
             FormBox["\"s\"", TraditionalForm], 0}, {20., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {20., 
             FormBox["\"t\"", TraditionalForm], 0}, {21., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {21., 
             FormBox["\"u\"", TraditionalForm], 0}, {22., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {22., 
             FormBox["\"v\"", TraditionalForm], 0}, {23., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {23., 
             FormBox["\"w\"", TraditionalForm], 0}, {24., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {24., 
             FormBox["\"x\"", TraditionalForm], 0}, {25., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {25., 
             FormBox["\"y\"", TraditionalForm], 0}, {26., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {26., 
             FormBox["\"z\"", TraditionalForm], 0}}, {{0.9999999999999999, 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {
            1.9999999999999998`, 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {3., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {
            3.9999999999999996`, 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {5., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {6., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {7., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {8., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {9., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {10., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {11., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {12., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {13., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {14., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {15., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {16., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {17., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {18., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {19., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {20., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {21., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {22., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {23., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {24., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {25., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {26., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}}}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        ImageSize->{340.46875, Automatic},
        PlotRange->{{All, All}, {All, All}},
        PlotRangePadding->{{
           Scaled[0.02], 
           Scaled[0.02]}, {
           Scaled[0.02], 
           Scaled[0.05]}},
        Ticks->{None, Automatic}]], "ExerciseOutput",ExpressionUUID->
       "d77e31da-a4e4-456e-a54e-15f19a41e69f"],
      Apply[TextCell, 
       Cell[
        BoxData[
         GraphicsBox[{{
            Opacity[0], 
            PointBox[{0.01582867783985098, 0.}]}, {{}, {
             RGBColor[0.982864, 0.7431472, 0.3262672], 
             EdgeForm[{
               Opacity[0.518], 
               Thickness[Small]}], {
              RGBColor[0.982864, 0.7431472, 0.3262672], 
              EdgeForm[{
                Opacity[0.518], 
                Thickness[Small]}], 
              TagBox[
               TooltipBox[
                TagBox[
                 DynamicBox[{
                   FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                   
                   RectangleBox[{0.5344506517690875, 0.}, {
                    1.4655493482309123`, 2443.}, "RoundingRadius" -> 0]}, 
                  ImageSizeCache -> {{32.63411835322364, 
                   43.6980651274133}, {-10.08189799629345, 
                   86.86630792219366}}], StatusArea[#, 2443]& , TagBoxNote -> 
                 "2443"], 
                StyleBox["2443", {}, StripOnInput -> False]], Annotation[#, 
                Style[2443, {}], "Tooltip"]& ]}, {
              RGBColor[0.982864, 0.7431472, 0.3262672], 
              EdgeForm[{
                Opacity[0.518], 
                Thickness[Small]}], 
              TagBox[
               TooltipBox[
                TagBox[
                 DynamicBox[{
                   FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                   
                   RectangleBox[{1.5344506517690872`, 0.}, {
                    2.4655493482309123`, 2223.}, "RoundingRadius" -> 0]}, 
                  ImageSizeCache -> {{43.97979718870334, 
                   55.043743962893004`}, {-1.396427139941764, 
                   86.86630792219366}}], StatusArea[#, 2223]& , TagBoxNote -> 
                 "2223"], 
                StyleBox["2223", {}, StripOnInput -> False]], Annotation[#, 
                Style[2223, {}], "Tooltip"]& ]}, {
              RGBColor[0.982864, 0.7431472, 0.3262672], 
              EdgeForm[{
                Opacity[0.518], 
                Thickness[Small]}], 
              TagBox[
               TooltipBox[
                TagBox[
                 DynamicBox[{
                   FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                   
                   RectangleBox[{2.5344506517690872`, 0.}, {
                    3.4655493482309123`, 3776.}, "RoundingRadius" -> 0]}, 
                  ImageSizeCache -> {{55.32547602418303, 
                   66.38942279837269}, {-62.70795550318796, 
                   86.86630792219366}}], StatusArea[#, 3776]& , TagBoxNote -> 
                 "3776"], 
                StyleBox["3776", {}, StripOnInput -> False]], Annotation[#, 
                Style[3776, {}], "Tooltip"]& ]}, {
              RGBColor[0.982864, 0.7431472, 0.3262672], 
              EdgeForm[{
                Opacity[0.518], 
                Thickness[Small]}], 
              TagBox[
               TooltipBox[
                TagBox[
                 DynamicBox[{
                   FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                   
                   RectangleBox[{3.5344506517690872`, 0.}, {4.465549348230912,
                     2504.}, "RoundingRadius" -> 0]}, 
                  ImageSizeCache -> {{66.67115485966272, 
                   77.7351016338524}, {-12.490142188281865`, 
                   86.86630792219366}}], StatusArea[#, 2504]& , TagBoxNote -> 
                 "2504"], 
                StyleBox["2504", {}, StripOnInput -> False]], Annotation[#, 
                Style[2504, {}], "Tooltip"]& ]}, {
              RGBColor[0.982864, 0.7431472, 0.3262672], 
              EdgeForm[{
                Opacity[0.518], 
                Thickness[Small]}], 
              TagBox[
               TooltipBox[
                TagBox[
                 DynamicBox[{
                   FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                   
                   RectangleBox[{4.534450651769087, 0.}, {5.465549348230912, 
                    1674.}, "RoundingRadius" -> 0]}, 
                  ImageSizeCache -> {{78.01683369514242, 89.08078046933208}, {
                   20.277770587954024`, 86.86630792219366}}], 
                 StatusArea[#, 1674]& , TagBoxNote -> "1674"], 
                StyleBox["1674", {}, StripOnInput -> False]], Annotation[#, 
                Style[1674, {}], "Tooltip"]& ]}, {
              RGBColor[0.982864, 0.7431472, 0.3262672], 
              EdgeForm[{
                Opacity[0.518], 
                Thickness[Small]}], 
              TagBox[
               TooltipBox[
                TagBox[
                 DynamicBox[{
                   FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                   
                   RectangleBox[{5.534450651769087, 0.}, {6.465549348230912, 
                    1716.}, "RoundingRadius" -> 0]}, 
                  ImageSizeCache -> {{89.36251253062213, 
                   100.42645930481179`}, {18.61963524265053, 
                   86.86630792219366}}], StatusArea[#, 1716]& , TagBoxNote -> 
                 "1716"], 
                StyleBox["1716", {}, StripOnInput -> False]], Annotation[#, 
                Style[1716, {}], "Tooltip"]& ]}, {
              RGBColor[0.982864, 0.7431472, 0.3262672], 
              EdgeForm[{
                Opacity[0.518], 
                Thickness[Small]}], 
              TagBox[
               TooltipBox[
                TagBox[
                 DynamicBox[{
                   FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                   
                   RectangleBox[{6.534450651769087, 0.}, {7.465549348230912, 
                    1223.}, "RoundingRadius" -> 0]}, 
                  ImageSizeCache -> {{100.70819136610183`, 
                   111.77213814029147`}, {38.08298584347498, 
                   86.86630792219366}}], StatusArea[#, 1223]& , TagBoxNote -> 
                 "1223"], 
                StyleBox["1223", {}, StripOnInput -> False]], Annotation[#, 
                Style[1223, {}], "Tooltip"]& ]}, {
              RGBColor[0.982864, 0.7431472, 0.3262672], 
              EdgeForm[{
                Opacity[0.518], 
                Thickness[Small]}], 
              TagBox[
               TooltipBox[
                TagBox[
                 DynamicBox[{
                   FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                   
                   RectangleBox[{7.534450651769087, 0.}, {8.465549348230912, 
                    1446.}, "RoundingRadius" -> 0]}, 
                  ImageSizeCache -> {{112.05387020158152`, 
                   123.11781697577118`}, {29.279076748173047`, 
                   86.86630792219366}}], StatusArea[#, 1446]& , TagBoxNote -> 
                 "1446"], 
                StyleBox["1446", {}, StripOnInput -> False]], Annotation[#, 
                Style[1446, {}], "Tooltip"]& ]}, {
              RGBColor[0.982864, 0.7431472, 0.3262672], 
              EdgeForm[{
                Opacity[0.518], 
                Thickness[Small]}], 
              TagBox[
               TooltipBox[
                TagBox[
                 DynamicBox[{
                   FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                   
                   RectangleBox[{8.534450651769086, 0.}, {9.465549348230912, 
                    1913.}, "RoundingRadius" -> 0]}, 
                  ImageSizeCache -> {{123.3995490370612, 
                   134.46349581125088`}, {10.842190884917429`, 
                   86.86630792219366}}], StatusArea[#, 1913]& , TagBoxNote -> 
                 "1913"], 
                StyleBox["1913", {}, StripOnInput -> False]], Annotation[#, 
                Style[1913, {}], "Tooltip"]& ]}, {
              RGBColor[0.982864, 0.7431472, 0.3262672], 
              EdgeForm[{
                Opacity[0.518], 
                Thickness[Small]}], 
              TagBox[
               TooltipBox[
                TagBox[
                 DynamicBox[{
                   FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                   
                   RectangleBox[{9.534450651769086, 0.}, {10.465549348230912`,
                     319.}, "RoundingRadius" -> 0]}, 
                  ImageSizeCache -> {{134.7452278725409, 
                   145.80917464673058`}, {73.77237518048372, 
                   86.86630792219366}}], StatusArea[#, 319]& , TagBoxNote -> 
                 "319"], 
                StyleBox["319", {}, StripOnInput -> False]], Annotation[#, 
                Style[319, {}], "Tooltip"]& ]}, {
              RGBColor[0.982864, 0.7431472, 0.3262672], 
              EdgeForm[{
                Opacity[0.518], 
                Thickness[Small]}], 
              TagBox[
               TooltipBox[
                TagBox[
                 DynamicBox[{
                   FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                   
                   RectangleBox[{10.534450651769086`, 0.}, {
                    11.465549348230912`, 233.}, "RoundingRadius" -> 0]}, 
                  ImageSizeCache -> {{146.0909067080206, 
                   157.15485348221026`}, {77.16760469705756, 
                   86.86630792219366}}], StatusArea[#, 233]& , TagBoxNote -> 
                 "233"], 
                StyleBox["233", {}, StripOnInput -> False]], Annotation[#, 
                Style[233, {}], "Tooltip"]& ]}, {
              RGBColor[0.982864, 0.7431472, 0.3262672], 
              EdgeForm[{
                Opacity[0.518], 
                Thickness[Small]}], 
              TagBox[
               TooltipBox[
                TagBox[
                 DynamicBox[{
                   FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                   
                   RectangleBox[{11.534450651769086`, 0.}, {
                    12.465549348230912`, 1207.}, "RoundingRadius" -> 0]}, 
                  ImageSizeCache -> {{157.43658554350029`, 
                   168.50053231768996`}, {38.71465645120965, 
                   86.86630792219366}}], StatusArea[#, 1207]& , TagBoxNote -> 
                 "1207"], 
                StyleBox["1207", {}, StripOnInput -> False]], Annotation[#, 
                Style[1207, {}], "Tooltip"]& ]}, {
              RGBColor[0.982864, 0.7431472, 0.3262672], 
              EdgeForm[{
                Opacity[0.518], 
                Thickness[Small]}], 
              TagBox[
               TooltipBox[
                TagBox[
                 DynamicBox[{
                   FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                   
                   RectangleBox[{12.534450651769086`, 0.}, {
                    13.465549348230912`, 2049.}, "RoundingRadius" -> 0]}, 
                  ImageSizeCache -> {{168.78226437898, 179.84621115316966`}, {
                   5.472990719172756, 86.86630792219366}}], 
                 StatusArea[#, 2049]& , TagBoxNote -> "2049"], 
                StyleBox["2049", {}, StripOnInput -> False]], Annotation[#, 
                Style[2049, {}], "Tooltip"]& ]}, {
              RGBColor[0.982864, 0.7431472, 0.3262672], 
              EdgeForm[{
                Opacity[0.518], 
                Thickness[Small]}], 
              TagBox[
               TooltipBox[
                TagBox[
                 DynamicBox[{
                   FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                   
                   RectangleBox[{13.534450651769086`, 0.}, {
                    14.465549348230912`, 853.}, "RoundingRadius" -> 0]}, 
                  ImageSizeCache -> {{180.1279432144597, 
                   191.19188998864936`}, {52.69036864733918, 
                   86.86630792219366}}], StatusArea[#, 853]& , TagBoxNote -> 
                 "853"], 
                StyleBox["853", {}, StripOnInput -> False]], Annotation[#, 
                Style[853, {}], "Tooltip"]& ]}, {
              RGBColor[0.982864, 0.7431472, 0.3262672], 
              EdgeForm[{
                Opacity[0.518], 
                Thickness[Small]}], 
              TagBox[
               TooltipBox[
                TagBox[
                 DynamicBox[{
                   FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                   
                   RectangleBox[{14.534450651769086`, 0.}, {
                    15.465549348230912`, 995.}, "RoundingRadius" -> 0]}, 
                  ImageSizeCache -> {{191.4736220499394, 
                   202.53756882412907`}, {47.084292003693996`, 
                   86.86630792219366}}], StatusArea[#, 995]& , TagBoxNote -> 
                 "995"], 
                StyleBox["995", {}, StripOnInput -> False]], Annotation[#, 
                Style[995, {}], "Tooltip"]& ]}, {
              RGBColor[0.982864, 0.7431472, 0.3262672], 
              EdgeForm[{
                Opacity[0.518], 
                Thickness[Small]}], 
              TagBox[
               TooltipBox[
                TagBox[
                 DynamicBox[{
                   FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                   
                   RectangleBox[{15.534450651769086`, 0.}, {
                    16.465549348230912`, 3267.}, "RoundingRadius" -> 0]}, 
                  ImageSizeCache -> {{202.8193008854191, 
                   213.88324765960877`}, {-42.61293429462883, 
                   86.86630792219366}}], StatusArea[#, 3267]& , TagBoxNote -> 
                 "3267"], 
                StyleBox["3267", {}, StripOnInput -> False]], Annotation[#, 
                Style[3267, {}], "Tooltip"]& ]}, {
              RGBColor[0.982864, 0.7431472, 0.3262672], 
              EdgeForm[{
                Opacity[0.518], 
                Thickness[Small]}], 
              TagBox[
               TooltipBox[
                TagBox[
                 DynamicBox[{
                   FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                   
                   RectangleBox[{16.534450651769088`, 0.}, {
                    17.465549348230912`, 197.}, "RoundingRadius" -> 0]}, 
                  ImageSizeCache -> {{214.1649797208988, 
                   225.22892649508844`}, {78.58886356446055, 
                   86.86630792219366}}], StatusArea[#, 197]& , TagBoxNote -> 
                 "197"], 
                StyleBox["197", {}, StripOnInput -> False]], Annotation[#, 
                Style[197, {}], "Tooltip"]& ]}, {
              RGBColor[0.982864, 0.7431472, 0.3262672], 
              EdgeForm[{
                Opacity[0.518], 
                Thickness[Small]}], 
              TagBox[
               TooltipBox[
                TagBox[
                 DynamicBox[{
                   FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                   
                   RectangleBox[{17.534450651769088`, 0.}, {
                    18.465549348230912`, 2092.}, "RoundingRadius" -> 0]}, 
                  ImageSizeCache -> {{225.5106585563785, 
                   236.57460533056815`}, {3.7753759608858246`, 
                   86.86630792219366}}], StatusArea[#, 2092]& , TagBoxNote -> 
                 "2092"], 
                StyleBox["2092", {}, StripOnInput -> False]], Annotation[#, 
                Style[2092, {}], "Tooltip"]& ]}, {
              RGBColor[0.982864, 0.7431472, 0.3262672], 
              EdgeForm[{
                Opacity[0.518], 
                Thickness[Small]}], 
              TagBox[
               TooltipBox[
                TagBox[
                 DynamicBox[{
                   FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                   
                   RectangleBox[{18.534450651769088`, 0.}, {
                    19.465549348230912`, 4642.}, "RoundingRadius" -> 0]}, 
                  ImageSizeCache -> {{236.8563373918582, 
                   247.92028416604785`}, {-96.89712714682686, 
                   86.86630792219366}}], StatusArea[#, 4642]& , TagBoxNote -> 
                 "4642"], 
                StyleBox["4642", {}, StripOnInput -> False]], Annotation[#, 
                Style[4642, {}], "Tooltip"]& ]}, {
              RGBColor[0.982864, 0.7431472, 0.3262672], 
              EdgeForm[{
                Opacity[0.518], 
                Thickness[Small]}], 
              TagBox[
               TooltipBox[
                TagBox[
                 DynamicBox[{
                   FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                   
                   RectangleBox[{19.534450651769088`, 0.}, {
                    20.465549348230912`, 2038.}, "RoundingRadius" -> 0]}, 
                  ImageSizeCache -> {{248.2020162273379, 
                   259.26596300152755`}, {5.907264261990335, 
                   86.86630792219366}}], StatusArea[#, 2038]& , TagBoxNote -> 
                 "2038"], 
                StyleBox["2038", {}, StripOnInput -> False]], Annotation[#, 
                Style[2038, {}], "Tooltip"]& ]}, {
              RGBColor[0.982864, 0.7431472, 0.3262672], 
              EdgeForm[{
                Opacity[0.518], 
                Thickness[Small]}], 
              TagBox[
               TooltipBox[
                TagBox[
                 DynamicBox[{
                   FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                   
                   RectangleBox[{20.534450651769088`, 0.}, {
                    21.465549348230912`, 1556.}, "RoundingRadius" -> 0]}, 
                  ImageSizeCache -> {{259.54769506281764`, 
                   270.61164183700726`}, {24.936341319997204`, 
                   86.86630792219366}}], StatusArea[#, 1556]& , TagBoxNote -> 
                 "1556"], 
                StyleBox["1556", {}, StripOnInput -> False]], Annotation[#, 
                Style[1556, {}], "Tooltip"]& ]}, {
              RGBColor[0.982864, 0.7431472, 0.3262672], 
              EdgeForm[{
                Opacity[0.518], 
                Thickness[Small]}], 
              TagBox[
               TooltipBox[
                TagBox[
                 DynamicBox[{
                   FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                   
                   RectangleBox[{21.534450651769088`, 0.}, {
                    22.465549348230912`, 646.}, "RoundingRadius" -> 0]}, 
                  ImageSizeCache -> {{270.8933738982973, 
                   281.95732067248696`}, {60.86260713490644, 
                   86.86630792219366}}], StatusArea[#, 646]& , TagBoxNote -> 
                 "646"], 
                StyleBox["646", {}, StripOnInput -> False]], Annotation[#, 
                Style[646, {}], "Tooltip"]& ]}, {
              RGBColor[0.982864, 0.7431472, 0.3262672], 
              EdgeForm[{
                Opacity[0.518], 
                Thickness[Small]}], 
              TagBox[
               TooltipBox[
                TagBox[
                 DynamicBox[{
                   FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                   
                   RectangleBox[{22.534450651769088`, 0.}, {
                    23.465549348230912`, 1007.}, "RoundingRadius" -> 0]}, 
                  ImageSizeCache -> {{282.239052733777, 
                   293.30299950796666`}, {46.610539047893, 
                   86.86630792219366}}], StatusArea[#, 1007]& , TagBoxNote -> 
                 "1007"], 
                StyleBox["1007", {}, StripOnInput -> False]], Annotation[#, 
                Style[1007, {}], "Tooltip"]& ]}, {
              RGBColor[0.982864, 0.7431472, 0.3262672], 
              EdgeForm[{
                Opacity[0.518], 
                Thickness[Small]}], 
              TagBox[
               TooltipBox[
                TagBox[
                 DynamicBox[{
                   FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                   
                   RectangleBox[{23.534450651769088`, 0.}, {
                    24.465549348230912`, 11.}, "RoundingRadius" -> 0]}, 
                  ImageSizeCache -> {{293.58473156925663`, 
                   304.64867834344636`}, {85.93203437937608, 
                   86.86630792219366}}], StatusArea[#, 11]& , TagBoxNote -> 
                 "11"], 
                StyleBox["11", {}, StripOnInput -> False]], Annotation[#, 
                Style[11, {}], "Tooltip"]& ]}, {
              RGBColor[0.982864, 0.7431472, 0.3262672], 
              EdgeForm[{
                Opacity[0.518], 
                Thickness[Small]}], 
              TagBox[
               TooltipBox[
                TagBox[
                 DynamicBox[{
                   FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                   
                   RectangleBox[{24.534450651769088`, 0.}, {
                    25.465549348230912`, 109.}, "RoundingRadius" -> 0]}, 
                  ImageSizeCache -> {{304.93041040473634`, 
                   315.99435717892607`}, {82.06305190700122, 
                   86.86630792219366}}], StatusArea[#, 109]& , TagBoxNote -> 
                 "109"], 
                StyleBox["109", {}, StripOnInput -> False]], Annotation[#, 
                Style[109, {}], "Tooltip"]& ]}, {
              RGBColor[0.982864, 0.7431472, 0.3262672], 
              EdgeForm[{
                Opacity[0.518], 
                Thickness[Small]}], 
              TagBox[
               TooltipBox[
                TagBox[
                 DynamicBox[{
                   FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                   
                   RectangleBox[{25.534450651769088`, 0.}, {
                    26.465549348230912`, 58.}, "RoundingRadius" -> 0]}, 
                  ImageSizeCache -> {{316.27608924021604`, 
                   327.34003601440577`}, {84.07650196915549, 
                   86.86630792219366}}], StatusArea[#, 58]& , TagBoxNote -> 
                 "58"], 
                StyleBox["58", {}, StripOnInput -> False]], Annotation[#, 
                Style[58, {}], "Tooltip"]& ]}}, {}, {}}, {}, {}, 
           StyleBox[{{
              Thickness[Tiny], 
              LineBox[{{0.01582867783985098, 0.}, {26.994543761638734`, 0.}}], 
              StyleBox[{}, "GraphicsLabel", StripOnInput -> False]}, 
             StyleBox[{{
                Thickness[Tiny], 
                LineBox[{{0.5344506517690875, 0.}, 
                  
                  Offset[{-1.102182119232618*^-15, -6.}, {0.5344506517690875, 
                   0.}]}], 
                LineBox[{{26.465549348230912`, 0.}, 
                  
                  Offset[{-1.102182119232618*^-15, -6.}, {26.465549348230912`,
                    0.}]}], {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {
                  LineBox[{{1.4655493482309123`, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    1.4655493482309123`, 0.}]}], 
                  LineBox[{{1.5344506517690872`, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    1.5344506517690872`, 0.}]}], 
                  LineBox[{{2.4655493482309128`, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    2.4655493482309128`, 0.}]}], 
                  LineBox[{{2.5344506517690872`, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    2.5344506517690872`, 0.}]}], 
                  LineBox[{{3.4655493482309128`, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    3.4655493482309128`, 0.}]}], 
                  LineBox[{{3.5344506517690872`, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    3.5344506517690872`, 0.}]}], 
                  LineBox[{{4.465549348230912, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {4.465549348230912,
                     0.}]}], 
                  LineBox[{{4.534450651769087, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {4.534450651769087,
                     0.}]}], 
                  LineBox[{{5.465549348230911, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {5.465549348230911,
                     0.}]}], 
                  LineBox[{{5.534450651769086, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {5.534450651769086,
                     0.}]}], 
                  LineBox[{{6.465549348230911, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {6.465549348230911,
                     0.}]}], 
                  LineBox[{{6.534450651769086, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {6.534450651769086,
                     0.}]}], 
                  LineBox[{{7.465549348230911, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {7.465549348230911,
                     0.}]}], 
                  LineBox[{{7.534450651769086, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {7.534450651769086,
                     0.}]}], 
                  LineBox[{{8.465549348230912, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {8.465549348230912,
                     0.}]}], 
                  LineBox[{{8.534450651769086, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {8.534450651769086,
                     0.}]}], 
                  LineBox[{{9.465549348230912, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {9.465549348230912,
                     0.}]}], 
                  LineBox[{{9.534450651769086, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {9.534450651769086,
                     0.}]}], 
                  LineBox[{{10.465549348230912`, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    10.465549348230912`, 0.}]}], 
                  LineBox[{{10.534450651769086`, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    10.534450651769086`, 0.}]}], 
                  LineBox[{{11.465549348230912`, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    11.465549348230912`, 0.}]}], 
                  LineBox[{{11.534450651769086`, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    11.534450651769086`, 0.}]}], 
                  LineBox[{{12.465549348230912`, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    12.465549348230912`, 0.}]}], 
                  LineBox[{{12.534450651769086`, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    12.534450651769086`, 0.}]}], 
                  LineBox[{{13.465549348230912`, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    13.465549348230912`, 0.}]}], 
                  LineBox[{{13.534450651769086`, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    13.534450651769086`, 0.}]}], 
                  LineBox[{{14.465549348230912`, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    14.465549348230912`, 0.}]}], 
                  LineBox[{{14.534450651769086`, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    14.534450651769086`, 0.}]}], 
                  LineBox[{{15.465549348230912`, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    15.465549348230912`, 0.}]}], 
                  LineBox[{{15.534450651769086`, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    15.534450651769086`, 0.}]}], 
                  LineBox[{{16.465549348230912`, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    16.465549348230912`, 0.}]}], 
                  LineBox[{{16.534450651769085`, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    16.534450651769085`, 0.}]}], 
                  LineBox[{{17.465549348230912`, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    17.465549348230912`, 0.}]}], 
                  LineBox[{{17.534450651769088`, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    17.534450651769088`, 0.}]}], 
                  LineBox[{{18.465549348230912`, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    18.465549348230912`, 0.}]}], 
                  LineBox[{{18.534450651769088`, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    18.534450651769088`, 0.}]}], 
                  LineBox[{{19.465549348230912`, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    19.465549348230912`, 0.}]}], 
                  LineBox[{{19.534450651769088`, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    19.534450651769088`, 0.}]}], 
                  LineBox[{{20.465549348230912`, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    20.465549348230912`, 0.}]}], 
                  LineBox[{{20.534450651769088`, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    20.534450651769088`, 0.}]}], 
                  LineBox[{{21.465549348230912`, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    21.465549348230912`, 0.}]}], 
                  LineBox[{{21.534450651769088`, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    21.534450651769088`, 0.}]}], 
                  LineBox[{{22.465549348230912`, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    22.465549348230912`, 0.}]}], 
                  LineBox[{{22.534450651769088`, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    22.534450651769088`, 0.}]}], 
                  LineBox[{{23.465549348230912`, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    23.465549348230912`, 0.}]}], 
                  LineBox[{{23.534450651769088`, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    23.534450651769088`, 0.}]}], 
                  LineBox[{{24.465549348230912`, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    24.465549348230912`, 0.}]}], 
                  LineBox[{{24.534450651769088`, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    24.534450651769088`, 0.}]}], 
                  LineBox[{{25.465549348230912`, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    25.465549348230912`, 0.}]}], 
                  LineBox[{{25.534450651769088`, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    25.534450651769088`, 0.}]}]}, {}}}, 
               StyleBox[{
                 Thickness[Tiny], 
                 InsetBox["\"a\"", 
                  Offset[{0., -2.}, {0.9999999999999999, 0.}], {0, 1}, 
                  Automatic, {1, 0}], 
                 InsetBox["\"b\"", 
                  Offset[{0., -2.}, {2., 0.}], {0, 1}, Automatic, {1, 0}], 
                 InsetBox["\"c\"", 
                  Offset[{0., -2.}, {3., 0.}], {0, 1}, Automatic, {1, 0}], 
                 InsetBox["\"d\"", 
                  Offset[{0., -2.}, {4., 0.}], {0, 1}, Automatic, {1, 0}], 
                 InsetBox["\"e\"", 
                  Offset[{0., -2.}, {4.999999999999999, 0.}], {0, 1}, 
                  Automatic, {1, 0}], 
                 InsetBox["\"f\"", 
                  Offset[{0., -2.}, {5.999999999999999, 0.}], {0, 1}, 
                  Automatic, {1, 0}], 
                 InsetBox["\"g\"", 
                  Offset[{0., -2.}, {6.999999999999999, 0.}], {0, 1}, 
                  Automatic, {1, 0}], 
                 InsetBox["\"h\"", 
                  Offset[{0., -2.}, {7.999999999999999, 0.}], {0, 1}, 
                  Automatic, {1, 0}], 
                 InsetBox["\"i\"", 
                  Offset[{0., -2.}, {9., 0.}], {0, 1}, Automatic, {1, 0}], 
                 InsetBox["\"j\"", 
                  Offset[{0., -2.}, {10., 0.}], {0, 1}, Automatic, {1, 0}], 
                 InsetBox["\"k\"", 
                  Offset[{0., -2.}, {11., 0.}], {0, 1}, Automatic, {1, 0}], 
                 InsetBox["\"l\"", 
                  Offset[{0., -2.}, {12., 0.}], {0, 1}, Automatic, {1, 0}], 
                 InsetBox["\"m\"", 
                  Offset[{0., -2.}, {13., 0.}], {0, 1}, Automatic, {1, 0}], 
                 InsetBox["\"n\"", 
                  Offset[{0., -2.}, {14., 0.}], {0, 1}, Automatic, {1, 0}], 
                 InsetBox["\"o\"", 
                  Offset[{0., -2.}, {15., 0.}], {0, 1}, Automatic, {1, 0}], 
                 InsetBox["\"p\"", 
                  Offset[{0., -2.}, {16., 0.}], {0, 1}, Automatic, {1, 0}], 
                 InsetBox["\"q\"", 
                  Offset[{0., -2.}, {17., 0.}], {0, 1}, Automatic, {1, 0}], 
                 InsetBox["\"r\"", 
                  Offset[{0., -2.}, {18., 0.}], {0, 1}, Automatic, {1, 0}], 
                 InsetBox["\"s\"", 
                  Offset[{0., -2.}, {19., 0.}], {0, 1}, Automatic, {1, 0}], 
                 InsetBox["\"t\"", 
                  Offset[{0., -2.}, {20., 0.}], {0, 1}, Automatic, {1, 0}], 
                 InsetBox["\"u\"", 
                  Offset[{0., -2.}, {21., 0.}], {0, 1}, Automatic, {1, 0}], 
                 InsetBox["\"v\"", 
                  Offset[{0., -2.}, {22., 0.}], {0, 1}, Automatic, {1, 0}], 
                 InsetBox["\"w\"", 
                  Offset[{0., -2.}, {23., 0.}], {0, 1}, Automatic, {1, 0}], 
                 InsetBox["\"x\"", 
                  Offset[{0., -2.}, {24., 0.}], {0, 1}, Automatic, {1, 0}], 
                 InsetBox["\"y\"", 
                  Offset[{0., -2.}, {25., 0.}], {0, 1}, Automatic, {1, 0}], 
                 InsetBox["\"z\"", 
                  Offset[{0., -2.}, {26., 0.}], {0, 1}, Automatic, {1, 0}]}, 
                "GraphicsLabel", StripOnInput -> False]}, "GraphicsTicks", 
              StripOnInput -> False]}, "GraphicsAxes", StripOnInput -> False, 
            Antialiasing -> False]}, AspectRatio -> 
          NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {False, True},
           AxesLabel -> {None, None}, AxesOrigin -> {0.01582867783985098, 0.},
           CoordinatesToolOptions :> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}, FrameLabel -> {{None, None}, {None, None}}, 
          FrameTicks -> {{Automatic, Automatic}, {{{0.9999999999999999, 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {
              0.9999999999999999, 
               FormBox["\"a\"", TraditionalForm], 0}, {1.9999999999999998`, 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {
              1.9999999999999998`, 
               FormBox["\"b\"", TraditionalForm], 0}, {3., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {3., 
               FormBox["\"c\"", TraditionalForm], 0}, {3.9999999999999996`, 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {
              3.9999999999999996`, 
               FormBox["\"d\"", TraditionalForm], 0}, {5., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {5., 
               FormBox["\"e\"", TraditionalForm], 0}, {6., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {6., 
               FormBox["\"f\"", TraditionalForm], 0}, {7., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {7., 
               FormBox["\"g\"", TraditionalForm], 0}, {8., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {8., 
               FormBox["\"h\"", TraditionalForm], 0}, {9., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {9., 
               FormBox["\"i\"", TraditionalForm], 0}, {10., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {10., 
               FormBox["\"j\"", TraditionalForm], 0}, {11., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {11., 
               FormBox["\"k\"", TraditionalForm], 0}, {12., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {12., 
               FormBox["\"l\"", TraditionalForm], 0}, {13., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {13., 
               FormBox["\"m\"", TraditionalForm], 0}, {14., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {14., 
               FormBox["\"n\"", TraditionalForm], 0}, {15., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {15., 
               FormBox["\"o\"", TraditionalForm], 0}, {16., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {16., 
               FormBox["\"p\"", TraditionalForm], 0}, {17., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {17., 
               FormBox["\"q\"", TraditionalForm], 0}, {18., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {18., 
               FormBox["\"r\"", TraditionalForm], 0}, {19., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {19., 
               FormBox["\"s\"", TraditionalForm], 0}, {20., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {20., 
               FormBox["\"t\"", TraditionalForm], 0}, {21., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {21., 
               FormBox["\"u\"", TraditionalForm], 0}, {22., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {22., 
               FormBox["\"v\"", TraditionalForm], 0}, {23., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {23., 
               FormBox["\"w\"", TraditionalForm], 0}, {24., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {24., 
               FormBox["\"x\"", TraditionalForm], 0}, {25., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {25., 
               FormBox["\"y\"", TraditionalForm], 0}, {26., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {26., 
               FormBox["\"z\"", TraditionalForm], 0}}, {{0.9999999999999999, 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {
              1.9999999999999998`, 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {3., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {
              3.9999999999999996`, 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {5., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {6., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {7., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {8., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {9., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {10., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {11., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {12., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {13., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {14., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {15., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {16., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {17., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {18., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {19., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {20., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {21., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {22., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {23., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {24., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {25., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {26., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}}}}, 
          GridLines -> {None, None}, GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], ImageSize -> {340.46875, Automatic}, 
          PlotRange -> {{All, All}, {All, All}}, PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, Ticks -> {None, Automatic}]], "ExerciseOutput", 
        Selectable -> False, Copyable -> False, Editable -> False, 
        ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"c5058505-d6e4-4299-b223-a0cb8753b5e6"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Make an association giving the 5 most common first letters of words in ",
 Cell[BoxData[
  RowBox[{
   ButtonBox["WordList",
    BaseStyle->"CodeLink"], "[", " ", "]"}]], "InlineCode",ExpressionUUID->
  "f8cb96e8-884c-464d-984b-77b800f9d8ff"],
 " and their counts.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "34.4", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"85559db1-9271-48ba-8f7b-6c0bab6f701a"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       RowBox[{"\[LeftAssociation]", 
        RowBox[{
         RowBox[{"\<\"s\"\>", "\[Rule]", "4642"}], ",", 
         RowBox[{"\<\"c\"\>", "\[Rule]", "3776"}], ",", 
         RowBox[{"\<\"p\"\>", "\[Rule]", "3267"}], ",", 
         RowBox[{"\<\"d\"\>", "\[Rule]", "2504"}], ",", 
         RowBox[{"\<\"a\"\>", "\[Rule]", "2443"}]}], "\[RightAssociation]"}]],
        "ExerciseOutput",ExpressionUUID->
       "e2ac7767-efc2-489b-a94d-ff86b64b7e06"],
      Apply[TextCell, 
       Cell[
        BoxData[
         RowBox[{"\[LeftAssociation]", 
           RowBox[{
             RowBox[{"\"s\"", "\[Rule]", "4642"}], ",", 
             RowBox[{"\"c\"", "\[Rule]", "3776"}], ",", 
             RowBox[{"\"p\"", "\[Rule]", "3267"}], ",", 
             RowBox[{"\"d\"", "\[Rule]", "2504"}], ",", 
             RowBox[{"\"a\"", "\[Rule]", "2443"}]}], "\[RightAssociation]"}]],
         "ExerciseOutput", Selectable -> False, Copyable -> False, Editable -> 
        False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"6f457bf7-1aad-4c95-9899-a47960cbed46"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Find the numerical ratio of the number of occurrences of \
\[OpenCurlyDoubleQuote]q\[CloseCurlyDoubleQuote] and \[OpenCurlyDoubleQuote]u\
\[CloseCurlyDoubleQuote] in the Wikipedia entry for computers.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "34.5", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"1baa3575-1e72-4b8c-813e-32a55bf9e532"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Sample", " ", "expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
      "0.042678440029433405`"], "ExerciseOutput",ExpressionUUID->
       "a1e5a71e-46bc-420e-9bf2-9e30b9c2b9cd"],
      Apply[TextCell, 
       Cell[
        BoxData["0.042678440029433405`"], "ExerciseOutput", Selectable -> 
        False, Copyable -> False, Editable -> False, ShowCellBracket -> 
        False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"cae20154-1351-4b43-bde3-c8f97a7c83b9"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Find the 10 most common words in ",
 Cell[BoxData[
  RowBox[{
   ButtonBox["ExampleData",
    BaseStyle->"CodeLink"], "[", 
   RowBox[{"{", 
    RowBox[{"\"\<Text\>\"", ",", "\"\<AliceInWonderland\>\""}], "}"}], "]"}]],
   "InlineCode",ExpressionUUID->"728f9323-21fa-4e7a-a6f9-e939fb3c6389"],
 ".",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "34.6", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"7c26bc7c-c5a8-40b1-be47-19257ca75c54"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       RowBox[{"{", 
        RowBox[{"\<\"the\"\>", ",", "\<\"and\"\>", ",", "\<\"a\"\>", 
         ",", "\<\"to\"\>", ",", "\<\"she\"\>", ",", "\<\"of\"\>", 
         ",", "\<\"was\"\>", ",", "\<\"Alice\"\>", ",", "\<\"in\"\>", 
         ",", "\<\"it\"\>"}], "}"}]], "ExerciseOutput",ExpressionUUID->
       "d411c278-c26d-492b-886e-99a955cd9268"],
      Apply[TextCell, 
       Cell[
        BoxData[
         RowBox[{"{", 
           
           RowBox[{"\"the\"", ",", "\"and\"", ",", "\"a\"", ",", "\"to\"", 
             ",", "\"she\"", ",", "\"of\"", ",", "\"was\"", ",", "\"Alice\"", 
             ",", "\"in\"", ",", "\"it\""}], "}"}]], "ExerciseOutput", 
        Selectable -> False, Copyable -> False, Editable -> False, 
        ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"0b6fee00-3b39-4ace-b27d-ab258ead43a9"]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Q&A", "QASection",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"e7bfa04f-01d6-4cc7-8f26-416793093c2f"],

Cell["Why are associations called \[OpenCurlyDoubleQuote]associations\
\[CloseCurlyDoubleQuote]?", "Question",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:13",ExpressionUUID->"7e523aef-e59e-4b96-bdaf-68749e5fa8f2"],

Cell[TextData[{
 "Because they ",
 StyleBox["associate",
  FontSlant->"Italic"],
 " values with keys. Other names used for the same concept are associative \
arrays, dictionaries, hashmaps, structs, key-value maps and symbolically \
indexed lists."
}], "Answer",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"93c59968-f537-4686-98cc-f4b42a01f996"],

Cell["Can an association have several elements with the same key?", "Question",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"a772557f-a3cf-45da-9ad4-99b009ab9175"],

Cell["No. Keys in an association are always unique. ", "Answer",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"ce12d6bb-176b-4a2b-b51a-2e28d113383e"],

Cell["\<\
What happens if I ask for a key that\[CloseCurlyQuote]s not in an association?\
\>", "Question",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:14",ExpressionUUID->"41b3ba08-3e1a-4f50-b3d3-58d12153a300"],

Cell[TextData[{
 "Normally you get ",
 Cell[BoxData[
  RowBox[{
   ButtonBox["Missing",
    BaseStyle->"CodeLink"], "[", "\[NegativeThinSpace]", "...", "]"}]], 
  "InlineCode",ExpressionUUID->"156e2a0a-60dd-48ab-95db-9794a351ef38"],
 ". But if you use ",
 ButtonBox["Lookup",
  BaseStyle->"Link"],
 " to look up the key, you can specify what to return if the key is absent."
}], "Answer",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->
  "LastCellOfAPage",ExpressionUUID->"e0fae259-a345-40e9-b618-14e25049983c"],

Cell["How can I do operations on the keys of an association?", "Question",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->{
  "i:15", "p:209"},ExpressionUUID->"65246525-65b2-41fc-b574-e034268c880c"],

Cell[TextData[{
 "Use ",
 ButtonBox["KeyMap",
  BaseStyle->"Link"],
 ", or use functions like ",
 ButtonBox["KeySelect",
  BaseStyle->"Link"],
 " and ",
 ButtonBox["KeyDrop",
  BaseStyle->"Link"],
 ". ",
 ButtonBox["AssociationMap",
  BaseStyle->"Link"],
 " creates an association by mapping a function over keys."
}], "Answer",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"2d9a45f8-1f3c-4122-9088-2167d5c6b6c5"],

Cell["How can I combine several associations into one?", "Question",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:16",ExpressionUUID->"2f77829f-df0f-43d3-9148-0172f31e1828"],

Cell[TextData[{
 "Use ",
 ButtonBox["Merge",
  BaseStyle->"Link"],
 ". You have to give a function to say what to do if the same key occurs in \
multiple associations."
}], "Answer",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"16bcbe7a-32c5-41e6-976d-9cd674aa89c6"],

Cell[TextData[{
 "Can one use ",
 ButtonBox["[[...]]",
  BaseStyle->"Link",
  ButtonData->"Part"],
 " to extract part of an association, like one extracts part of a list?"
}], "Question",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:17",ExpressionUUID->"50d24b8d-7b32-4cb8-95a1-accfc6476334"],

Cell[TextData[{
 "Yes, if you explicitly say ",
 Cell[BoxData[
  RowBox[{
   StyleBox["assoc", "CodeVariable"], "[", 
   RowBox[{"[", 
    RowBox[{
     ButtonBox["Key",
      BaseStyle->"CodeLink"], "[", 
     StyleBox["key", "CodeVariable"], "]"}], "]"}], "]"}]], "InlineCode",
  ExpressionUUID->"abbb6f76-cd30-4717-b00c-786f634d1e7f"],
 ". ",
 Cell[BoxData[
  RowBox[{
   StyleBox["assoc", "CodeVariable"], "[", 
   RowBox[{"[", "2", "]"}], "]"}]], "InlineCode",ExpressionUUID->
  "e4edea00-1ee8-4715-8eb8-364270e9d24a"],
 ", for example, will extract the second element of ",
 Cell[BoxData[
  StyleBox["assoc", "CodeVariable"]], "InlineCode",ExpressionUUID->
  "ad403210-431b-4915-aaf7-0e32061a0613"],
 ", whatever key it has. ",
 Cell[BoxData[
  RowBox[{
   StyleBox["assoc", "CodeVariable"], "[", 
   RowBox[{"[", 
    StyleBox["key", "CodeVariable"], "]"}], "]"}]], "InlineCode",
  ExpressionUUID->"c795bffc-3830-4ceb-963c-3d4b78aa375c"],
 " is a special case that works the same as ",
 Cell[BoxData[
  RowBox[{"assoc", "[", 
   StyleBox["key", "CodeVariable"], "]"}]], "InlineCode",ExpressionUUID->
  "93f070a5-14ea-463b-8feb-50cc2518b9bf"],
 "."
}], "Answer",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"67e22a1f-555c-4c42-9957-34ccadafcf66"],

Cell["\<\
What happens in pure functions if the keys in an association aren\
\[CloseCurlyQuote]t strings?\
\>", "Question",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"423b6f05-c9fe-4751-9d0d-09e2f8a59561"],

Cell[TextData[{
 "You can\[CloseCurlyQuote]t use ",
 Cell[BoxData[
  StyleBox[
   RowBox[{"#", 
    StyleBox["key", "CodeVariable"]}]]], "InlineCode",ExpressionUUID->
  "d00bf490-c9ca-4a68-890a-c0763bb074ce"],
 " anymore; you have to explicitly use ",
 Cell[BoxData[
  RowBox[{"#", "[", 
   StyleBox["key", "CodeVariable"], "]"}]], "InlineCode",ExpressionUUID->
  "8860b290-26a2-4625-a671-91a2b43421ef"],
 ". "
}], "Answer",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"45916c58-8497-4ff6-9013-545718eba656"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Tech Notes", "TechNoteSection",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"43f96dfb-ab7b-4a8a-924f-1f8877a8ce2a"],

Cell["\<\
Most functions effectively operate on associations as if they were operating \
on lists of their values. Functions that thread themselves over lists \
typically do the same over associations.\
\>", "TechNote",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:18",ExpressionUUID->"d6f78771-f067-4e78-baed-b1c0b363237b"],

Cell[TextData[{
 "Associations are like tables in a relational database. ",
 ButtonBox["JoinAcross",
  BaseStyle->"Link"],
 " does the analog of a database join."
}], "TechNote",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:19",ExpressionUUID->"74902152-640b-4f83-bc86-be30be34d964"]
}, Open  ]],

Cell[CellGroupData[{

Cell["More to Explore", "MoreExploreSection",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"f18410cf-a694-4d61-a6c7-843816a5b030"],

Cell[TextData[ButtonBox["Guide to Associations in the Wolfram Language\
\[NonBreakingSpace]\[RightGuillemet]",
 BaseStyle->"Link",
 ButtonData->{"paclet:guide/Associations", None}]], "MoreExplore",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->
  "LastCellOfAPage",ExpressionUUID->"d479c202-7d93-4fff-abcc-4a5239603cc8"]
}, Open  ]]
},
Saveable->False,
WindowToolbars->{},
BlinkingCellInsertionPoint->False,
CellInsertionPointCell->None,
WindowSize->{830, 800},
WindowMargins->Automatic,
WindowPersistentStyles->{
 WindowFrame, WindowMargins, WindowSize, Magnification},
WindowTitle->"Associations: Elementary Introduction to the Wolfram Language",
DockedCells->{
  Cell[
   BoxData[
    TagBox[
     GridBox[{{
        TemplateBox[{
         "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]", 
          "\"\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\"", 
          GraphicsBox[
           TagBox[
            RasterBox[CompressedData["
1:eJztl01IVFEUxyctMFzUysjIyUDCTauiIJFM6ENpM4NEtJrBUaSYZMYPhCRm
rYuoICgiW0VEBVIUEbTNEMTAIqRsk6JGCVFBHx7//+4JLo/36DqvB4Ie+Mk7
7+t3733nHpzq9NlEW0ksFsuX4U8i1duQy6X6kpuRtGTzHe3ZTOuxbFemPZPb
ny7FyZ2gEqwHInICfJToguOIReywPVHHlYDzcY4hJHZ486giyBOXtfms5Pms
Bs9zUBDTow6DJOgBT8DP/+B5CepAPbgqZm+zT70Bt9VXCx6H8DwE28Gw5ufB
IT2eA1N6PKquC0V4xtUxqfkE6ARD4BHYAx5Y938Gu8GdZXq4VsNWngIfwDzY
Aa6Bm55nOKYq8NXRw29eb+Uz4JSVd4Nn4IbPs2fARUdPQcfLWAQJ8Mq6Tkdd
gGcEHHT0sHYn9Jg1dcnnnhf6vnee8xzXVkcP9wdr97eY7z0NnlrX74qpxffg
iOZ2VDp6kvqOe6AVXAb7xNQB462YNfsCfoBzoE1MzTEqHD096mgE98WsEec4
Jqamvvk8cx2kwWuw19HDXnIAbNAx03ka9IO8mO+3ScyebRZTi01i1rqguHjY
r3aJWaugOA5O6vEC+K6ebWDW0cNgv6oBnwKus87KwKDmv8BRMOBz77/6G/sV
e8lkwHWuTwm4pQ7WzGIRHgb7FXsJ9/mI5z2si42gXMw8/ByuHgb7FXsJ9yX3
IPfHFjF1xTl5v0exnrCx5gnn+fu7JC7h/z/0Y52+P+rfWX9iCXVYErg=
             "], {{0,
              34}, {26, 0}}, {0, 255}, ColorFunction -> RGBColor], 
            BoxForm`ImageTag[
            "Byte", ColorSpace -> "RGB", Interleaving -> True, Magnification -> 
             1], Selectable -> False], DefaultBaseStyle -> "ImageGraphics", 
           ImageSize -> Magnification[1], ImageSizeRaw -> {26, 34}, 
           PlotRange -> {{0, 26}, {0, 34}}], 
          GraphicsBox[
           TagBox[
            RasterBox[CompressedData["
1:eJztXUuS47gRLX8WXtYRaJ+gl17SS+8U4/CeM+H2hDdtRY8jHF6ZR9AReATt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             "], {{0, 34}, {383, 0}}, {0, 255}, 
             ColorFunction -> RGBColor], 
            BoxForm`ImageTag[
            "Byte", ColorSpace -> "RGB", Interleaving -> True, Magnification -> 
             1], Selectable -> False], DefaultBaseStyle -> "ImageGraphics", 
           ImageSize -> Magnification[1], ImageSizeRaw -> {383, 34}, 
           PlotRange -> {{0, 383}, {0, 34}}]}, "RowWithSeparators"], 
        PaneBox[
         StyleBox["\[VeryThinSpace]", ShowStringCharacters -> False], 
         Alignment -> Right, ImageSize -> {174, 47}], 
        PaneBox[
         PaneBox[
          TemplateBox[{"\[ThinSpace]", "\" \"", 
            TagBox[
             TooltipBox[
              PaneSelectorBox[{False -> ButtonBox[
                  PaneBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAPiDmBmIUBO/j//z8jEDcA8W8g3oBFnhmIZ/9HgE9o8mxAvBZJ/hsQuyPJ
8wPxfiT5N0BsjiQvCsTnkOSfALEWkrwSEN9Bkr8OxDJobniAJP8ZZCYWfxCj
RpGQXcS4mVi/ExuGxMYFmlp4nAIAG14fWQ==
                    "], {{0, 14}, {9, 
                    0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                     ImageSizeRaw -> {9, 14}, PlotRange -> {{0, 9}, {0, 14}}, 
                    ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                   Alignment -> Center], 
                  ButtonFunction :> (
                   NotebookLocate[{
                    "EIWL1-33-expressions-and-their-structure.nb", ""}, 
                    FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Enabled -> True, Appearance -> 
                  None, Evaluator -> Automatic, Method -> "Preemptive"], True -> 
                ButtonBox[
                  PaneBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAPiDmBmIUBO/j//z8jEDcA8W8g3oBFnhmIZ/9HgE9o8mxAvBZJ/hsQuyPJ
8wPxfiT5N0BsjiQvCsTnkOSfALEWkrwSEN9Bkr8OxDJobniAJP8ZZCYWfxCj
RpGQXcS4mVi/ExuGxMYFmlp4nAIAG14fWQ==
                    "], {{0, 14}, {9, 
                    0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                     ImageSizeRaw -> {9, 14}, PlotRange -> {{0, 9}, {0, 14}}, 
                    ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                   Alignment -> Center], 
                  ButtonFunction :> (
                   NotebookLocate[{
                    "EIWL1-33-expressions-and-their-structure.nb", ""}, 
                    FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Enabled -> True, Appearance -> 
                  None, Background -> RGBColor[0.835294, 0.364706, 0.0196078],
                   Evaluator -> Automatic, Method -> "Preemptive"]}, 
               Dynamic[
                CurrentValue["MouseOver"]], ImageSize -> Automatic, 
               FrameMargins -> 0], "\"Expressions and Their Structure\"", 
              TooltipDelay -> 0.15, LabelStyle -> "TextStyling"], 
             Annotation[#, "Expressions and Their Structure", "Tooltip"]& ], 
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {5, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[5], Selectable -> False], 
            TagBox[
             TooltipBox[
              PaneSelectorBox[{False -> ButtonBox[
                  PaneBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAfiDmBmAWI////vwKIfwFxMQMOAJT7+R8B6nGoSf+PCjpwqMskUl0SEP9F
UtcHxIxY1EWjqZuOQ10Mmr2TcNj7BEnNP1LNIeQeIDsZn78IhQ8x4fwfNb4a
cPgTFu8l2ORBAAC+1hnm
                    "], {{0, 15}, {9, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                     ImageSizeRaw -> {9, 15}, PlotRange -> {{0, 9}, {0, 15}}, 
                    ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                   Alignment -> Center], 
                  ButtonFunction :> (
                   NotebookLocate[{
                    "EIWL1-35-natural-language-understanding.nb", ""}, 
                    FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Appearance -> None, Evaluator -> 
                  Automatic, Method -> "Preemptive"], True -> ButtonBox[
                  PaneBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAfiDmBmAWI////vwKIfwFxMQMOAJT7+R8B6nGoSf+PCjpwqMskUl0SEP9F
UtcHxIxY1EWjqZuOQ10Mmr2TcNj7BEnNP1LNIeQeIDsZn78IhQ8x4fwfNb4a
cPgTFu8l2ORBAAC+1hnm
                    "], {{0, 15}, {9, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                     ImageSizeRaw -> {9, 15}, PlotRange -> {{0, 9}, {0, 15}}, 
                    ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                   Alignment -> Center], 
                  ButtonFunction :> (
                   NotebookLocate[{
                    "EIWL1-35-natural-language-understanding.nb", ""}, 
                    FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Appearance -> None, Background -> 
                  RGBColor[0.835294, 0.364706, 0.0196078], Evaluator -> 
                  Automatic, Method -> "Preemptive"]}, 
               Dynamic[
                CurrentValue["MouseOver"]], ImageSize -> Automatic, 
               FrameMargins -> 0], "\"Natural Language Understanding\"", 
              TooltipDelay -> 0.15, LabelStyle -> "TextStyling"], 
             Annotation[#, "Natural Language Understanding", "Tooltip"]& ]}, 
           "RowWithSeparators"], Alignment -> Right], ImageSize -> {100, 30}, 
         FrameMargins -> {{0, 6}, {0, 0}}, Alignment -> Right], 
        ActionMenuBox[
         PaneSelectorBox[{True -> PanelBox[
             GraphicsBox[
              TagBox[
               RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UBAkIQ3ELED8////Jf/pA0D2/KWTXSB7ZtPBPrA9DKOAYgAMR1Eg9gPiABpi
P6g912mcLmAAZM9XOtkFsicKiNcD8QYaYpD5UQOdXoYD+E/HMooO9iDbR7c6
BQDxtyEt
                "], {{0, 16}, {27, 0}}, {0, 255}, ColorFunction -> 
                RGBColor], 
               BoxForm`ImageTag[
               "Byte", ColorSpace -> "RGB", Interleaving -> True, 
                Magnification -> 1], Selectable -> False], DefaultBaseStyle -> 
              "ImageGraphics", ImageSize -> Magnification[1], 
              ImageSizeRaw -> {27, 16}, PlotRange -> {{0, 27}, {0, 16}}], 
             Appearance -> None, Background -> 
             RGBColor[0.835294, 0.364706, 0.0196078], ImageSize -> {35, 30}, 
             Alignment -> Center], False -> PanelBox[
             GraphicsBox[
              TagBox[
               RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UBAkIQ3ELED8////Jf/pA0D2/KWTXSB7ZtPBPrA9DKOAYgAMR1Eg9gPiABpi
P6g912mcLmAAZM9XOtkFsicKiNcD8QYaYpD5UQOdXoYD+E/HMooO9iDbR7c6
BQDxtyEt
                "], {{0, 16}, {27, 0}}, {0, 255}, ColorFunction -> 
                RGBColor], 
               BoxForm`ImageTag[
               "Byte", ColorSpace -> "RGB", Interleaving -> True, 
                Magnification -> 1], Selectable -> False], DefaultBaseStyle -> 
              "ImageGraphics", ImageSize -> Magnification[1], 
              ImageSizeRaw -> {27, 16}, PlotRange -> {{0, 27}, {0, 16}}], 
             Appearance -> None, Background -> 
             RGBColor[0.952941, 0.509804, 0], ImageSize -> {35, 30}, 
             Alignment -> Center]}, 
          Dynamic[
           CurrentValue["MouseOver"]]], {
         "Preface" :> 
          NotebookLocate[{"EIWL1-0a-preface.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "What Is the Wolfram Language?" :> 
          NotebookLocate[{"EIWL1-0b-what-is-the-wolfram-language.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "Practicalities of Using the Wolfram Language" :> 
          NotebookLocate[{
            "EIWL1-0c-practicalities-of-using-the-wolfram-language.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "Other Resources" :> 
          NotebookLocate[{"EIWL1-0d-other-resources.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]1\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Starting Out: Elementary Arithmetic" :> 
          NotebookLocate[{
            "EIWL1-01-starting-out-elementary-arithmetic.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]2\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Introducing Functions" :> 
          NotebookLocate[{"EIWL1-02-introducing-functions.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]3\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]First Look at Lists" :> 
          NotebookLocate[{"EIWL1-03-first-look-at-lists.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]4\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Displaying Lists" :> 
          NotebookLocate[{"EIWL1-04-displaying-lists.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]5\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Operations on Lists" :> 
          NotebookLocate[{"EIWL1-05-operations-on-lists.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]6\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Making Tables" :> 
          NotebookLocate[{"EIWL1-06-making-tables.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]7\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Colors and Styles" :> 
          NotebookLocate[{"EIWL1-07-colors-and-styles.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]8\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Basic Graphics Objects" :> 
          NotebookLocate[{"EIWL1-08-basic-graphics-objects.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]9\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Interactive Manipulation" :> 
          NotebookLocate[{"EIWL1-09-interactive-manipulation.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "10\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Images" :> 
          NotebookLocate[{"EIWL1-10-images.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "11\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Strings and \
Text" :> NotebookLocate[{"EIWL1-11-strings-and-text.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "12\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Sound" :> 
          NotebookLocate[{"EIWL1-12-sound.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "13\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Arrays, or \
Lists of Lists" :> 
          NotebookLocate[{"EIWL1-13-arrays-or-lists-of-lists.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "14\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Coordinates \
and Graphics" :> 
          NotebookLocate[{"EIWL1-14-coordinates-and-graphics.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "15\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]The Scope \
of the Wolfram Language" :> 
          NotebookLocate[{
            "EIWL1-15-the-scope-of-the-wolfram-language.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "16\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Real\
\[VeryThinSpace]\[Hyphen]\[VeryThinSpace]\[NegativeVeryThinSpace]World Data" :> 
          NotebookLocate[{"EIWL1-16-real-world-data.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "17\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Units" :> 
          NotebookLocate[{"EIWL1-17-units.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "18\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]\
Geocomputation" :> 
          NotebookLocate[{"EIWL1-18-geocomputation.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "19\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Dates and \
Times" :> NotebookLocate[{"EIWL1-19-dates-and-times.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "20\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Options" :> 
          NotebookLocate[{"EIWL1-20-options.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "21\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Graphs and \
Networks" :> NotebookLocate[{"EIWL1-21-graphs-and-networks.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "22\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Machine \
Learning" :> 
          NotebookLocate[{"EIWL1-22-machine-learning.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "23\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]More about \
Numbers" :> NotebookLocate[{"EIWL1-23-more-about-numbers.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "24\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]More Forms \
of Visualization" :> 
          NotebookLocate[{"EIWL1-24-more-forms-of-visualization.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "25\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Ways to \
Apply Functions" :> 
          NotebookLocate[{"EIWL1-25-ways-to-apply-functions.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "26\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Pure \
Anonymous Functions" :> 
          NotebookLocate[{"EIWL1-26-pure-anonymous-functions.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "27\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Applying \
Functions Repeatedly" :> 
          NotebookLocate[{"EIWL1-27-applying-functions-repeatedly.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "28\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Tests and \
Conditionals" :> 
          NotebookLocate[{"EIWL1-28-tests-and-conditionals.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "29\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]More about \
Pure Functions" :> 
          NotebookLocate[{"EIWL1-29-more-about-pure-functions.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "30\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Rearranging \
Lists" :> NotebookLocate[{"EIWL1-30-rearranging-lists.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "31\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Parts of \
Lists" :> NotebookLocate[{"EIWL1-31-parts-of-lists.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "32\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Patterns" :> 
          NotebookLocate[{"EIWL1-32-patterns.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "33\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Expressions \
and Their Structure" :> 
          NotebookLocate[{"EIWL1-33-expressions-and-their-structure.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "34\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]\
Associations" :> 
          NotebookLocate[{"EIWL1-34-associations.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "35\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Natural \
Language Understanding" :> 
          NotebookLocate[{"EIWL1-35-natural-language-understanding.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "36\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Creating \
Websites and Apps" :> 
          NotebookLocate[{"EIWL1-36-creating-websites-and-apps.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "37\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Layout and \
Display" :> NotebookLocate[{"EIWL1-37-layout-and-display.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "38\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Assigning \
Names to Things" :> 
          NotebookLocate[{"EIWL1-38-assigning-names-to-things.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "39\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Immediate \
and Delayed Values" :> 
          NotebookLocate[{"EIWL1-39-immediate-and-delayed-values.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "40\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Defining \
Your Own Functions" :> 
          NotebookLocate[{"EIWL1-40-defining-your-own-functions.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "41\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]More about \
Patterns" :> 
          NotebookLocate[{"EIWL1-41-more-about-patterns.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "42\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]String \
Patterns and Templates " :> 
          NotebookLocate[{"EIWL1-42-string-patterns-and-templates.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "43\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Storing \
Things" :> NotebookLocate[{"EIWL1-43-storing-things.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "44\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Importing \
and Exporting" :> 
          NotebookLocate[{"EIWL1-44-importing-and-exporting.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "45\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Datasets" :> 
          NotebookLocate[{"EIWL1-45-datasets.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "46\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Writing \
Good Code" :> 
          NotebookLocate[{"EIWL1-46-writing-good-code.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "47\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Debugging \
Your Code" :> 
          NotebookLocate[{"EIWL1-47-debugging-your-code.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "What We Haven\[CloseCurlyQuote]t Discussed" :> 
          NotebookLocate[{"EIWL1-what-we-havent-discussed.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "Afterword: Being a Programmer" :> 
          NotebookLocate[{"EIWL1-being-a-programmer.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "Answers to Exercises" :> 
          NotebookLocate[{"EIWL1-answers-to-exercises.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "Index" :> 
          NotebookLocate[{"EIWL1-book-index.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}]}, Appearance -> None]}}, 
      GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Center}}}, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"]], 
   "Text", ShowCellBracket -> False, CellFrame -> {{0, 0}, {3, 0}}, 
   Selectable -> False, CellFrameColor -> 
   RGBColor[0.835294, 0.364706, 0.0196078], CellMargins -> {{0, 0}, {0, -1}}, 
   CellFrameMargins -> {{27, 0}, {1, 7}}, Background -> 
   RGBColor[0.952941, 0.509804, 0], CellTags -> "DockedCellLogoCell"], 
  Cell["FIRST EDITION (2015)", "Text", FontFamily -> "Source Sans Pro", 
   CellFrame -> {{0, 0}, {3, 0}}, ShowCellBracket -> False, 
   CellMargins -> {{0, 0}, {-1, -1}}, CellFrameMargins -> {{66, 0}, {2, 4}}, 
   CellFrameColor -> RGBColor[0.952941, 0.509804, 0], FontSize -> 10, 
   FontTracking -> "Extended", FontColor -> RGBColor[1, 0.929412, 0.721569], 
   Background -> RGBColor[0.862745, 0.309804, 0], CellTags -> 
   "DockedCellLogoCell"]},
PrintingStartingPageNumber->288,
PageHeaders->{{
   Cell[
    TextData[{
      StyleBox[
       CounterBox["Page"], "PageNumber"], 
      StyleBox[
      "    An Elementary Introduction to the Wolfram Language", "Header"]}], 
    "Header", CellMargins -> {{37, Inherited}, {Inherited, Inherited}}], None,
    None}, {None, None, 
   Cell[
    TextData[{
      StyleBox[
       CounterBox["Section"], "Header"], 
      StyleBox[" | Associations \[LongDash] wolfr.am/eiwl-", "Header"], 
      StyleBox[
       CounterBox["Section"], "Header"], 
      StyleBox["    ", "Header"], 
      StyleBox[
       CounterBox["Page"], "PageNumber"]}], "Header", 
    CellMargins -> {{Inherited, 17}, {Inherited, Inherited}}]}},
PrintingOptions->{"FirstPageHeader"->True},
ShowCellBracket->Automatic,
ShowSyntaxStyles->False,
Magnification->1.,
FrontEndVersion->"11.1 for Mac OS X x86 (32-bit, 64-bit Kernel) (March 16, \
2017)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "Default.nb"]], 
   Cell[
    CellGroupData[{
      Cell[
      "Style Environments", "Section", 
       CellChangeTimes -> {{3.64661165091824*^9, 3.646611654013329*^9}, 
         3.6485723794335403`*^9, 3.651347081728628*^9, 3.651347179462186*^9, 
         3.651347384135805*^9, 3.651348171662589*^9}], 
      Cell[
       StyleData[All, "Working"], CellInsertionPointCell -> 
       FEPrivate`FrontEndResource["FEExpressions", "CellInsertionMenu"], 
       CreateCellID -> True, $CellContext`GhostCellInEmptyNotebook -> False], 
      
      Cell[
       StyleData[All, "Printout"], 
       PrintingOptions -> {
        "PageSize" -> {504, 720}, "PrintRegistrationMarks" -> True}, 
       Magnification -> 0.6]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell["Styles for Headers and Footers", "Section"], 
      Cell[
       StyleData["Header"], StyleMenuListing -> None, FontFamily -> "Verdana",
        FontSize -> 7, FontSlant -> "Plain", FontColor -> GrayLevel[0.6]], 
      Cell[
       StyleData["PageNumber"], CellMargins -> {{0, 0}, {4, 1}}, 
       StyleMenuListing -> None, FontFamily -> "Verdana", FontSize -> 7, 
       FontWeight -> "Bold", FontSlant -> "Plain", FontColor -> 
       GrayLevel[0]]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell[
      "WPL Specific", "Section", 
       CellChangeTimes -> {{3.6556608433734913`*^9, 3.6556608489412746`*^9}}], 
      Cell[
       StyleData["Link"], FontFamily -> "Source Sans Pro", FontSize :> 
       If[CurrentValue[
           EvaluationCell[], "FontFamily"] === "Source Sans Pro", Inherited, 
         If[CurrentValue[
            EvaluationCell[], "FontFamily"] === "WolframCodeSans", Inherited, 
          Inherited 0.9]], FontColor -> GrayLevel[0]], 
      Cell[
       StyleData["CodeLink"], 
       ButtonBoxOptions -> {
        Appearance -> None, ButtonFunction :> (FEPrivate`FrontEndExecute[
           FrontEndToken["OpenHelpLink", {
             Part[#, 1], Null}]]& ), ButtonSource -> ButtonContents, 
         Evaluator -> None, Method -> "Preemptive"}]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell[
      "Custom Styles", "Section", 
       CellChangeTimes -> {{3.646611660445352*^9, 3.646611669493331*^9}}], 
      Cell[
       StyleData["Notebook"], PageWidth -> 700, 
       PrintingOptions -> {
        "InnerOuterMargins" -> {35, 16}, "PaperOrientation" -> "Portrait", 
         "PaperSize" -> {504, 720}, 
         "PrintingMargins" -> {{20, 20}, {54, 54}}}, CellLabelAutoDelete -> 
       False, ShowSyntaxStyles -> False, MenuSortingValue -> None, 
       GraphicsBoxOptions -> {ImageSize -> 240}, 
       Graphics3DBoxOptions -> {ImageSize -> 240}], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Title"], CellMargins -> {{64, Inherited}, {50, 72}}, 
          MenuCommandKey -> None, FontFamily -> "Verdana", FontSize -> 42, 
          FontWeight -> "Bold", FontColor -> GrayLevel[0.4]], 
         Cell[
          StyleData["Title", "Printout"], 
          CellMargins -> {{64, Inherited}, {50, 72}}]}, Closed]], 
      Cell[
       StyleData["Chapter"], MenuCommandKey -> None], 
      Cell[
       StyleData["Subchapter"], MenuCommandKey -> None], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Section"], CellFrame -> {{0, 0}, {0, 0}}, CellDingbat -> 
          Cell[
            TextData[
             CounterBox["Section"], 
             StyleBox[
             "|\[NegativeThinSpace]", FontColor -> 
              RGBColor[
               0.9019607843137255, 0.4117647058823529, 0.027450980392156862`],
               FontFamily -> "Courier", FontSize -> 36, FontWeight -> Plain]],
             "SectionNumber"], CellMargins -> {{96, Inherited}, {12, 44}}, 
          Evaluatable -> True, CellGroupingRules -> {"SectionGrouping", 60}, 
          PageBreakAbove -> True, ShowCellLabel -> False, 
          CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
          CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
          CounterIncrements -> "Section", 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", 
          FontSize -> 26, FontSlant -> "Plain", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          InterpretationBoxOptions -> {Editable -> True}], 
         Cell[
          StyleData["Section", "Printout"], 
          CellMargins -> {{96, Inherited}, {12, 2}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionDoubleDigit"], CellFrame -> {{0, 0}, {0, 0}}, 
          CellDingbat -> Cell[
            TextData[
             CounterBox["Section"], 
             StyleBox[
             "|\[NegativeThinSpace]", FontColor -> 
              RGBColor[
               0.9019607843137255, 0.4117647058823529, 0.027450980392156862`],
               FontFamily -> "Courier", FontSize -> 36, FontWeight -> Plain]],
             "SectionNumber"], CellMargins -> {{112, Inherited}, {12, 44}}, 
          Evaluatable -> True, CellGroupingRules -> {"SectionGrouping", 60}, 
          PageBreakAbove -> True, ShowCellLabel -> False, 
          CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
          CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
          CounterIncrements -> "Section", 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", 
          FontSize -> 26, FontSlant -> "Plain", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          InterpretationBoxOptions -> {Editable -> True}], 
         Cell[
          StyleData["SectionDoubleDigit", "Printout"], 
          CellMargins -> {{112, Inherited}, {12, 2}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionNumber"], CellBaseline -> Baseline, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 26, FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["SectionNumber", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionInline"], FontFamily -> 
          "Source Sans Pro Semibold", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["SectionInline", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionNoDingbat"], 
          CellMargins -> {{64, Inherited}, {12, 44}}, Evaluatable -> True, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakAbove -> 
          True, ShowCellLabel -> False, 
          CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
          CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
          CounterIncrements -> "Section", 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", 
          FontSize -> 26, FontSlant -> "Plain", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          InterpretationBoxOptions -> {Editable -> True}], 
         Cell[
          StyleData["SectionNoDingbat", "Printout"], 
          CellMargins -> {{64, Inherited}, {12, 2}}]}, Closed]], 
      Cell[
       StyleData["AnswerKeyNumberedSection"], 
       CellMargins -> {{64, Inherited}, {8, 28}}, Evaluatable -> True, 
       CellGroupingRules -> {"SectionGrouping", 60}, PageBreakAbove -> True, 
       ShowCellLabel -> False, 
       CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
       CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
       CounterIncrements -> "Section", 
       CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
         "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", FontSize -> 
       18, FontSlant -> "Plain", FontColor -> 
       RGBColor[
        0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
       InterpretationBoxOptions -> {Editable -> True}], 
      Cell[
       StyleData["AnswerKeySectionNumber"], CellBaseline -> Baseline, 
       FontFamily -> "Source Sans Pro Semibold", FontSize -> 18, FontColor -> 
       RGBColor[
        0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
      Cell[
       StyleData["IndexLinkGuide"], 
       CellMargins -> {{64, Inherited}, {48, 28}}, Evaluatable -> True, 
       CellGroupingRules -> {"SectionGrouping", 60}, PageBreakAbove -> True, 
       ShowCellLabel -> False, 
       CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
       CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
       CounterIncrements -> "Section", 
       CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
         "Exercise", 0}}, FontFamily -> "Source Sans Pro", FontSize -> 14, 
       FontSlant -> "Plain", FontColor -> 
       RGBColor[
        0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
       InterpretationBoxOptions -> {Editable -> True}], 
      Cell[
       StyleData["Index"], MenuSortingValue -> 10000, FontFamily -> 
       "Source Sans Pro", FontSize -> 11], 
      Cell[
       StyleData["IndexSubentry"], MenuSortingValue -> 10000, FontFamily -> 
       "Source Sans Pro", FontSize -> 11], 
      Cell[
       StyleData["FunctionName"], MenuSortingValue -> 10000, FontFamily -> 
       "Source Sans Pro Semibold", FontWeight -> "Bold"], 
      Cell[
       StyleData["IndexColumn"], 
       CellMargins -> {{66, 0}, {Inherited, Inherited}}, TabSpacings -> {2.}, 
       MenuSortingValue -> 10000, FontFamily -> "Source Sans Pro", 
       GridBoxOptions -> {
        GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
         GridBoxItemSize -> {"Columns" -> {{25}}}, 
         GridBoxSpacings -> {"Columns" -> {{2}}}}], 
      Cell[
       StyleData["IndexSubsection"], 
       CellMargins -> {{64, Inherited}, {9, 28}}, 
       CellGroupingRules -> {"SectionGrouping", 40}, MenuSortingValue -> 
       10000, FontFamily -> "Source Sans Pro", FontSize -> 24], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Subsection"], CellMargins -> {{64, Inherited}, {12, 32}},
           FontFamily -> "Source Sans Pro Semibold", FontSize -> 18, 
          FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["Subsection", "Printout"], 
          CellMargins -> {{64, Inherited}, {12, 32}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ResourcesSubsection"], 
          CellMargins -> {{64, Inherited}, {4, 16}}, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 15, FontSlant -> "Plain", 
          FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["ResourcesSubsection", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 16}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Subsubsection"], 
          CellMargins -> {{64, Inherited}, {6, 12}}, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 16, FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["Subsubsection", "Printout"], 
          CellMargins -> {{64, Inherited}, {6, 12}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularySection"], PageWidth -> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 24}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["VocabularySection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 24}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularyTable", StyleDefinitions -> StyleData["Text"]],
           SpanMaxSize -> 1, FontFamily -> "Source Sans Pro Light", FontColor -> 
          GrayLevel[0.8], 
          GridBoxOptions -> {
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
            GridBoxDividers -> {"Columns" -> {{False}}, "Rows" -> {False, {
                 Directive[
                  Thickness[0.5], "VocabDivColor"]}, False}}, 
            GridBoxItemStyle -> {
             "Columns" -> {"VocabularyCode", Inherited, Inherited}, 
              "Rows" -> {{Automatic}}}, 
            GridBoxSpacings -> {
             "Columns" -> {{0, 1, 2, 1, 2}}, "Rows" -> {{1}}}}], 
         Cell[
          StyleData["VocabularyTable", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "VocabularyTable3Column", StyleDefinitions -> StyleData["Text"]], 
          SpanMaxSize -> 1, FontFamily -> "Source Sans Pro Light", FontColor -> 
          GrayLevel[0.8], 
          GridBoxOptions -> {
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
            GridBoxDividers -> {"Columns" -> {{False}}, "Rows" -> {False, {
                 Directive[
                  Thickness[0.5], "VocabDivColor"]}, False}}, 
            GridBoxItemStyle -> {
             "Columns" -> {
               "VocabularyCode", Inherited, "VocabularyCode", Inherited, 
                Inherited}, "Rows" -> {{Automatic}}}, 
            GridBoxSpacings -> {
             "Columns" -> {{0, 1, 2, 1, 2}}, "Rows" -> {{1}}}}], 
         Cell[
          StyleData["VocabularyTable3Column", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularyText"], FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["VocabularyText", "Printout"], 
          CellMargins -> {{66, 10}, {7, 7}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularyCode", StyleDefinitions -> StyleData["Text"]], 
          Deletable -> False, FontFamily -> "Source Sans Pro", FontSize -> 14,
           FontWeight -> "Bold", FontColor -> GrayLevel[0.25], 
          GridBoxOptions -> {
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
            GridBoxDividers -> {
             "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {True, {True}, True}, "RowsIndexed" -> {}}}], 
         Cell[
          StyleData["VocabularyCode", "Printout"], FontColor -> 
          GrayLevel[0.25]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabDivColor"], FontColor -> GrayLevel[0.8]], 
         Cell[
          StyleData["VocabDivColor", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseSection"], PageWidth -> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 30}}, Evaluatable -> True, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, ShowCellLabel -> False, CellFrameMargins -> {{8, 8}, {4, 6}},
           CellFrameColor -> RGBColor[0.901961, 0.411765, 0.027451], 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro", FontSize -> 18, 
          FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["ExerciseSection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Exercise"], PageWidth -> 700, CellDingbat -> Cell[
            TextData[{"  ", 
              CounterBox["Section"], ".", 
              CounterBox["Exercise"]}], "ExerciseNumber", FontColor -> 
            RGBColor[
             0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
          ShowGroupOpener -> True, CellMargins -> {{108, Inherited}, {4, 8}}, 
          CellGroupingRules -> {"SectionGrouping", 67}, CounterIncrements -> 
          "Exercise", MenuSortingValue -> 10020, MenuCommandKey -> "2", 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Plain", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["Exercise", "Printout"], ShowGroupOpener -> False, 
          CellMargins -> {{110, Inherited}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseNumber"], FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Bold", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["ExerciseNumber", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseSubsection"], PageWidth -> 500, 
          CellFrame -> {{False, False}, {1, False}}, 
          CellMargins -> {{64, Inherited}, {8, 18}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, CellFrameColor -> 
          RGBColor[0.65, 0.6, 0.6], FontFamily -> "Source Sans Pro", FontSize -> 
          18, FontSlant -> "Italic", FontColor -> RGBColor[0.65, 0.6, 0.6]], 
         Cell[
          StyleData["ExerciseSubsection", "Printout"], 
          CellFrame -> {{False, False}, {1, False}}, CellFrameColor -> 
          RGBColor[0.65, 0.6, 0.6]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseNote"], PageWidth -> 700, 
          CellMargins -> {{64, Inherited}, {4, 8}}, PageBreakBelow -> False, 
          MenuSortingValue -> 10050, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25], $CellContext`ReturnCreatesNewCell -> 
          True], 
         Cell[
          StyleData["ExerciseNote", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["QASection"], PageWidth -> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 30}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Question", 0}}, FontFamily -> "Source Sans Pro", FontSize -> 18, 
          FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["QASection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Question"], PageWidth -> 700, 
          CellMargins -> {{64, Inherited}, {2, 12}}, PageBreakBelow -> False, 
          CounterIncrements -> "Question", MenuSortingValue -> 10030, 
          MenuCommandKey -> "3", FontFamily -> "Source Sans Pro", FontSize -> 
          14, FontWeight -> "Bold", FontSlant -> 
          "Plain", $CellContext`ReturnCreatesNewCell -> 
          True, $CellContext`DefaultReturnCreatedCellStyle -> "Answer"], 
         Cell[
          StyleData["Question", "Printout"], 
          CellMargins -> {{65, Inherited}, {2, 12}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Answer"], PageWidth -> 700, 
          CellMargins -> {{66, 10}, {4, 1}}, LineSpacing -> {1.125, 1., 2.}, 
          MenuSortingValue -> 10032, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25], $CellContext`ReturnCreatesNewCell -> 
          True, $CellContext`DefaultReturnCreatedCellStyle -> "Question"], 
         Cell[
          StyleData["Answer", "Printout"], 
          CellMargins -> {{66, 10}, {4, 1}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["QuestionNumber"], FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Bold", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["QuestionNumber", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TechNoteSection"], PageWidth -> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 30}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["TechNoteSection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TechNote"], PageWidth -> 700, CellDingbat -> Cell[
            TextData[{"\[FilledSmallSquare]"}], FontSize -> 12, FontColor -> 
            GrayLevel[0.5]], CellMargins -> {{78, Inherited}, {4, 8}}, 
          CellChangeTimes -> {{3.651515120816633*^9, 3.651515125814807*^9}, 
            3.6515155174947033`*^9}, LineSpacing -> {1.25, 1., 2.}, 
          MenuSortingValue -> 10040, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25], $CellContext`ReturnCreatesNewCell -> 
          True], 
         Cell[
          StyleData["TechNote", "Printout"], 
          CellMargins -> {{82, Inherited}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["MoreExploreSection"], PageWidth -> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 30}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["MoreExploreSection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["MoreExplore"], PageWidth -> 700, 
          CellMargins -> {{64, Inherited}, {4, 8}}, PageBreakBelow -> False, 
          MenuSortingValue -> 10050, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0], $CellContext`ReturnCreatesNewCell -> 
          True], 
         Cell[
          StyleData["MoreExplore", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["MoreExploreShortURL"], 
          CellMargins -> {{64, Inherited}, {4, 8}}, PageBreakBelow -> False, 
          FontFamily -> "Source Sans Pro Light", FontSize -> 14, FontSlant -> 
          "Plain", FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["MoreExploreShortURL", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Text"], CellMargins -> {{66, 10}, {4, 14}}, FontFamily -> 
          "Baskerville", FontSize -> 18, FontColor -> 
          GrayLevel[0], $CellContext`ReturnCreatesNewCell -> True], 
         Cell[
          StyleData["Text", "Printout"], CellMargins -> {{66, 10}, {7, 7}}]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ResourcesText"], CellMargins -> {{66, 10}, {2, 0}}, 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Plain", FontColor -> 
          GrayLevel[0], $CellContext`ReturnCreatesNewCell -> True], 
         Cell[
          StyleData["ResourcesText", "Printout"], 
          CellMargins -> {{66, 10}, {2, 0}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ResourcesLink"], CellMargins -> {{66, 10}, {2, 0}}, 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Italic", FontColor -> 
          GrayLevel[0], $CellContext`ReturnCreatesNewCell -> True], 
         Cell[
          StyleData["ResourcesLink", "Printout"], 
          CellMargins -> {{66, 10}, {2, 0}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CodeCaption"], CellFrame -> {{0, 0}, {0, 0}}, 
          CellMargins -> {{66, 10}, {4, 12}}, PageBreakBelow -> False, 
          CellFrameColor -> GrayLevel[0.4], MenuSortingValue -> 10010, 
          MenuCommandKey -> "1", FontFamily -> "Source Sans Pro", FontSize -> 
          16, FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["CodeCaption", "Printout"], 
          CellMargins -> {{66, 10}, {4, 12}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Input"], CellMargins -> {{99, 10}, {3, 7}}, SpanMaxSize -> 
          1, FontSize -> 15], 
         Cell[
          StyleData["Input", "Printout"], CellMargins -> {{99, 10}, {3, 7}}]},
         Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Output"], CellMargins -> {{99, 10}, {14, 7}}, FontSize -> 
          15], 
         Cell[
          StyleData["Output", "Printout"], 
          CellMargins -> {{99, 10}, {14, 7}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["InputOnly"], CellMargins -> {{99, 10}, {25, 10}}, 
          SpanMaxSize -> 1, MenuSortingValue -> 1500, FontSize -> 15], 
         Cell[
          StyleData["InputOnly", "Printout"], 
          CellMargins -> {{99, 10}, {15, 10}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CellLabel"], 
          CellLabelMargins -> {{12, Inherited}, {Inherited, Inherited}}, 
          LanguageCategory -> None, StyleMenuListing -> None, FontFamily -> 
          "Helvetica Neue", FontSize -> 9, FontWeight -> "Plain", FontSlant -> 
          "Plain", FontColor -> GrayLevel[0.5]], 
         Cell[
          StyleData["CellLabel", "Printout"], FontSize -> 8, FontColor -> 
          GrayLevel[0.5]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Message"], Editable -> False, 
          CellMargins -> {{66, Inherited}, {Inherited, Inherited}}, 
          CellGroupingRules -> "OutputGrouping", TextClipboardType -> 
          "PlainText", PageBreakWithin -> False, GroupPageBreakWithin -> 
          False, GeneratedCell -> True, CellAutoOverwrite -> True, 
          ShowCellLabel -> False, DefaultFormatType -> 
          DefaultOutputFormatType, ContextMenu -> 
          FEPrivate`FrontEndResource["ContextMenus", "Output"], 
          ShowAutoStyles -> False, ShowSyntaxStyles -> False, 
          AutoStyleOptions -> {
           "StringStyle" -> None, "SyntaxErrorStyle" -> None}, 
          HyphenationOptions -> {"HyphenationCharacter" -> "\[Continuation]"},
           AutoItalicWords -> {}, AutoQuoteCharacters -> {}, 
          PasteAutoQuoteCharacters -> {}, LanguageCategory -> None, 
          FormatType -> InputForm, ShowStringCharacters -> False, 
          CounterIncrements -> "Message", MenuSortingValue -> 1600, 
          StyleMenuListing -> None, FontFamily :> 
          CurrentValue["PanelFontFamily"], FontSize -> 11, FontColor -> 
          RGBColor[0.5072, 0.16933, 0.15221], $CellContext`StripStyleOnPaste -> 
          True], 
         Cell[
          StyleData["Message", "Printout"], 
          CellMargins -> {{100, Inherited}, {Inherited, Inherited}}, 
          CellFrameLabels -> {{None, None}, {None, None}}, FontColor -> 
          GrayLevel[0]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseInput", StyleDefinitions -> StyleData["Input"]], 
          CellMargins -> {{88, 10}, {4, 7}}, ShowCellLabel -> False, 
          SpanMaxSize -> 1, FontSize -> 
          14, $CellContext`GeneratedCellStyles -> {
           "Output" -> "ExerciseOutput"}], 
         Cell[
          StyleData["ExerciseInput", "Printout"], 
          CellMargins -> {{88, 10}, {4, 7}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "ExerciseOutput", StyleDefinitions -> StyleData["Output"]], 
          CellMargins -> {{88, 10}, {10, 4}}, ShowCellLabel -> False, 
          FontSize -> 14], 
         Cell[
          StyleData["ExerciseOutput", "Printout"], 
          CellMargins -> {{88, 10}, {10, 4}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Picture"], CellMargins -> {{66, 10}, {10, 10}}, 
          CellGroupingRules -> "GraphicsGrouping", StyleMenuListing -> None], 
         
         Cell[
          StyleData["Picture", "Printout"], 
          CellMargins -> {{66, 10}, {8, 8}}]}, Closed]], 
      Cell[
       StyleData["ExerciseSummaryCell"], PageWidth -> 700, CellFrame -> 0, 
       CellMargins -> {{64, Inherited}, {8, 10}}, 
       CellGroupingRules -> {"SectionGrouping", 64}, PageBreakBelow -> False, 
       ShowCellLabel -> False, CellFrameMargins -> 0, ShowStringCharacters -> 
       False, FontFamily -> "Source Sans Pro", FontSize -> 18, FontColor -> 
       RGBColor[1, 1, 1], 
       GridBoxOptions -> {GridBoxBackground -> {"Columns" -> {{
              RGBColor[0.990997, 0.539528, 0.155779], 
              RGBColor[0.989487, 0.434699, 0.0320439]}}, "Rows" -> {{None}}}, 
         GridBoxItemSize -> {"Columns" -> {
             Scaled[0.7], 
             Scaled[0.3]}, "Rows" -> {{Automatic}}}}], 
      Cell[
       StyleData["ExerciseSummaryHeading"], ShowStringCharacters -> False, 
       FontFamily -> "Source Sans Pro", FontSize -> 18, FontColor -> 
       RGBColor[1, 1, 1]], 
      Cell[
       StyleData["ExerciseSummarySubheading"], ShowStringCharacters -> False, 
       FontFamily -> "Source Sans Pro", FontSize -> 15, FontColor -> 
       RGBColor[1., 0.9294117647058824, 0.7215686274509804]], 
      Cell[
       StyleData["ExercisePreviewButtonText"], ShowStringCharacters -> False, 
       FontFamily -> "Source Sans Pro", FontSize -> 14, FontSlant -> "Plain", 
       FontColor -> RGBColor[0.6, 0.6, 0.6]], 
      Cell[
       StyleData["ExercisePreviewButtonTextHighlight"], ShowStringCharacters -> 
       False, FontFamily -> "Source Sans Pro", FontSize -> 14, FontSlant -> 
       "Plain", FontColor -> 
       RGBColor[
        0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]]}, 
     Closed]], 
   Cell[
    CellGroupData[{
      Cell[
      "Inline and special formatting", "Section", 
       CellChangeTimes -> {{3.646681732592888*^9, 3.646681749414035*^9}}], 
      Cell[
       StyleData["Graphics"], MenuSortingValue -> None], 
      Cell[
       StyleData["Graphics3D"], MenuSortingValue -> None], 
      Cell[
       StyleData["StandardForm"], 
       InputAutoReplacements -> {
        "->" -> "\[Rule]", ":>" -> "\[RuleDelayed]", "<=" -> "\[LessEqual]", 
         ">=" -> "\[GreaterEqual]", "!=" -> "\[NotEqual]", "==" -> "\[Equal]",
          "@>" -> "\\[InlinePart]", "<->" -> "\[UndirectedEdge]", ParentList},
        LineSpacing -> {1.25, 0, 2}, SingleLetterItalics -> False, 
       StyleMenuListing -> None, FontFamily -> "Source Sans Pro", 
       PrivateFontOptions -> {"OperatorSubstitution" -> True}], 
      Cell[
       StyleData["OutputForm"], PageWidth -> DirectedInfinity[1], 
       TextAlignment -> Left, LineSpacing -> {0.6, 1}, 
       AutoQuoteCharacters -> {}, PasteAutoQuoteCharacters -> {}, 
       StyleMenuListing -> None, FontFamily -> "Source Sans Pro", 
       PrivateFontOptions -> {"OperatorSubstitution" -> True}], 
      Cell[
       StyleData["InputForm"], PageWidth -> DirectedInfinity[1], 
       InputAutoReplacements -> {}, AllowInlineCells -> False, Hyphenation -> 
       False, AutoQuoteCharacters -> {}, PasteAutoQuoteCharacters -> {}, 
       AutoSpacing -> False, NumberMarks -> True, AutoNumberFormatting -> 
       False, StyleMenuListing -> None, FontFamily -> "Source Sans Pro", 
       PrivateFontOptions -> {"OperatorSubstitution" -> True}], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["DetailsLink"], FontFamily -> "Source Sans Pro", FontSize :> 
          If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.9]], FontColor -> GrayLevel[0], 
          ButtonBoxOptions -> {
           ButtonFunction :> (
             Function[$CellContext`t, 
              NotebookFind[$CellContext`t, "Notes", All, CellStyle]; 
              NotebookFind[$CellContext`t, "NotesSection", All, CellStyle, 
                AutoScroll -> Top]][
              Documentation`HelpLookup[
               StringJoin["ref/", #]]]& ), ButtonSource -> ButtonContents, 
            Evaluator -> Automatic}], 
         Cell[
          StyleData["DetailsLink", "Printout"], FontFamily -> 
          "Source Sans Pro", FontSize :> If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.88]], FontColor -> GrayLevel[0]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["LinkAlt"], FontFamily -> "Source Sans Pro", FontSize :> 
          If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.9]], FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["LinkAlt", "Printout"], FontFamily -> "Source Sans Pro", 
          FontSize :> If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.88]], FontColor -> GrayLevel[0]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Hyperlink"], MenuSortingValue -> None, FontColor -> 
          RGBColor[0.3, 0.35, 0.5]], 
         Cell[
          StyleData["Hyperlink", "Printout"]]}, Closed]], 
      Cell[
       StyleData[
       "IndexNavigationLink", StyleDefinitions -> StyleData["Hyperlink"]], 
       MenuSortingValue -> None, FontColor -> 
       RGBColor[
        0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
      Cell[
       StyleData["Crosslink"], 
       ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
            
            NotebookLocate[#2, "OpenInNewWindow" -> 
             CurrentValue["HyperlinkModifierKey"]]}]& ), Evaluator -> None, 
         Method -> "Queued"}], 
      Cell[
       StyleData["VocabularyLink"], FontColor -> GrayLevel[0], 
       ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
            
            NotebookLocate[#2, "OpenInNewWindow" -> 
             CurrentValue["HyperlinkModifierKey"]]}]& ), Evaluator -> None, 
         Method -> "Queued"}], 
      Cell[
       StyleData["InlineCode"], SpanMaxSize -> 1, FontColor -> GrayLevel[0]], 
      
      Cell[
       StyleData["InlineCodeText"], SpanMaxSize -> 1, FontFamily -> 
       "Source Sans Pro", FontSize -> 0.95 Inherited], 
      Cell[
       StyleData["NoLabel"], ShowCellLabel -> 
       False, $CellContext`GeneratedCellStyles -> {
        "Output" -> "ExerciseOutput"}], 
      Cell[
       StyleData["MenuName"], FontFamily -> "Verdana", FontWeight -> "Bold", 
       FontColor -> GrayLevel[0.286275]], 
      Cell[
       StyleData["KeyEvent"], CellFrame -> {{0.5, 0.5}, {0.5, 0.5}}, 
       CellFrameMargins -> {{2, 2}, {2, 2}}, CellFrameColor -> GrayLevel[0.7],
        FontFamily -> "Verdana", FontColor -> GrayLevel[0.4]], 
      Cell[
       StyleData["KeyEventDelimiter"], FontColor -> GrayLevel[0.5]], 
      Cell[
       CellGroupData[{
         Cell["Key Styles", "Subsubsection"], 
         Cell[
          StyleData["Key0"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {"Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-2, -2}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}], 
         Cell[
          StyleData["Key1"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #2, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {
                 "ColumnsIndexed" -> {2 -> GrayLevel[0.8352941176470589]}, 
                  "Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-2, -2}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}], 
         Cell[
          StyleData["Key2"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #2, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #3, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {
                 "ColumnsIndexed" -> {
                   2 -> GrayLevel[0.8352941176470589], 3 -> 
                    GrayLevel[0.8352941176470589]}, "Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-2, -2}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}], 
         Cell[
          StyleData["Key3"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #2, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   TemplateBox[{"\[ThickSpace]", #3, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #4, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {
                 "ColumnsIndexed" -> {
                   2 -> GrayLevel[0.8352941176470589], 3 -> 
                    GrayLevel[0.8352941176470589], 4 -> 
                    GrayLevel[0.8352941176470589]}, "Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-2, -2}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Entity styles", "Subsubsection"], 
         Cell[
          StyleData["Entity"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               PaneSelectorBox[{True -> GridBox[{{
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontFamily -> "Source Sans Pro", 
                    FontWeight -> "Plain", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}},
                    BaselinePosition -> {1, 1}], False -> 
                 PaneBox[#, 
                   BaseStyle -> {
                    FontColor -> RGBColor[0.395437, 0.20595, 0.061158]}, 
                   BaselinePosition -> Baseline]}, 
                Dynamic[
                 CurrentValue[Evaluatable]], ImageSize -> Automatic, 
                BaselinePosition -> Baseline, 
                BaseStyle -> {FontFamily -> "Helvetica"}], FrameStyle -> 
               RGBColor[1., 0.504768, 0.], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityFrameless"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              PaneSelectorBox[{True -> GridBox[{{
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontFamily -> "Source Sans Pro", 
                    FontWeight -> "Plain", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                  BaselinePosition -> {1, 1}], False -> 
                PaneBox[#, 
                  BaseStyle -> {
                   FontColor -> RGBColor[0.395437, 0.20595, 0.061158]}, 
                  BaselinePosition -> Baseline]}, 
               Dynamic[
                CurrentValue[Evaluatable]], ImageSize -> Automatic, 
               BaselinePosition -> Baseline, 
               BaseStyle -> {FontFamily -> "Helvetica"}], #3, 
              BaseStyle -> {
               ShowStringCharacters -> False, LineIndent -> 0, 
                PrivateFontOptions -> {
                 FontWeight -> "Plain", "OperatorSubstitution" -> False}}]& ),
             Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityFramelessHot"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {
           DisplayFunction -> (PaneSelectorBox[{True -> GridBox[{{
                   
                   StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0]], 
                   StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0], Selectable -> 
                    False]}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 1}], False -> 
               PaneBox[#, BaseStyle -> {FontColor -> GrayLevel[0]}, 
                 BaselinePosition -> Baseline]}, 
              Dynamic[
               CurrentValue[Evaluatable]], ImageSize -> Automatic, 
              BaselinePosition -> Baseline, 
              BaseStyle -> {
               FontWeight -> "Plain", FontFamily -> "Helvetica", 
                ShowStringCharacters -> False, LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityClass"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               PaneSelectorBox[{True -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}},
                    BaselinePosition -> {1, 2}], False -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]]}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}},
                    BaselinePosition -> {1, 2}]}, 
                Dynamic[
                 CurrentValue[Evaluatable]], ImageSize -> Automatic, 
                BaselinePosition -> Baseline, 
                BaseStyle -> {FontFamily -> "Helvetica"}], FrameStyle -> 
               RGBColor[1., 0.504768, 0.], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityClassFrameless"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              PaneSelectorBox[{True -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                  BaselinePosition -> {1, 2}], False -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]]}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                  BaselinePosition -> {1, 2}]}, 
               Dynamic[
                CurrentValue[Evaluatable]], ImageSize -> Automatic, 
               BaselinePosition -> Baseline, 
               BaseStyle -> {FontFamily -> "Helvetica"}], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityClassFramelessHot"], ShowStringCharacters -> False,
           TemplateBoxOptions -> {
           DisplayFunction -> (PaneSelectorBox[{True -> GridBox[{{
                   PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                   
                   StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0]], 
                   StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0], Selectable -> 
                    False]}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 2}], False -> GridBox[{{
                   PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                   StyleBox[#, FontColor -> GrayLevel[0]]}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 2}]}, 
              Dynamic[
               CurrentValue[Evaluatable]], ImageSize -> Automatic, 
              BaselinePosition -> Baseline, 
              BaseStyle -> {
               FontWeight -> "Plain", FontFamily -> "Helvetica", 
                ShowStringCharacters -> False, LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityProperty"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               
               PaneBox[#, 
                BaseStyle -> {
                 FontSlant -> Italic, FontWeight -> Plain, FontFamily -> 
                  "Source Sans Pro", FontColor -> 
                  RGBColor[0.395437, 0.20595, 0.061158]}, BaselinePosition -> 
                Baseline], FrameStyle -> 
               RGBColor[0.94227, 0.703639, 0.033387], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityPropertyClass"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               PaneBox[
                GridBox[{{
                   PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], #}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 2}], 
                BaseStyle -> {
                 FontSlant -> Italic, FontWeight -> Plain, FontFamily -> 
                  "Source Sans Pro", FontColor -> 
                  RGBColor[0.395437, 0.20595, 0.061158]}, BaselinePosition -> 
                Baseline], FrameStyle -> 
               RGBColor[0.94227, 0.703639, 0.033387], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityValue"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              
              GridBox[{{#, #2}}, GridBoxAlignment -> {"Rows" -> {{Baseline}}},
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
               GridBoxSpacings -> {"Columns" -> {{0}}}, 
               BaselinePosition -> {1, 1}], Background -> 
              RGBColor[{0.9921568627450981, 0.9529411764705882, 
                0.8509803921568627}], BaselinePosition -> Baseline, 
              FrameMargins -> {{1, 1}, {1, 1}}, ImageMargins -> 2, FrameStyle -> 
              RGBColor[{0.9333333333333333, 0.8470588235294118, 
                0.5529411764705883}], RoundingRadius -> 5]& )}]}, Closed]]}, 
     Closed]]}, Visible -> False, FrontEndVersion -> 
  "11.1 for Mac OS X x86 (32-bit, 64-bit Kernel) (March 16, 2017)", 
  StyleDefinitions -> "StylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "p:205"->{
  Cell[655, 23, 439, 11, 
  70, "SectionDoubleDigit", "ExpressionUUID" -> "045a4ebb-
   b383-44f9-93cf-65f018661b08",
   CounterAssignments->{{"Section", 33}, {"Subsection", 0}, {
     "Subsubsection", 0}, {"Exercise", 0}},
   CellTags->"p:205"]},
 "i:1"->{
  Cell[1097, 36, 415, 12, 
  70, "Text", "ExpressionUUID" -> "28d2130c-1f0c-47d7-b4ad-033d8ae709f5",
   CellTags->"i:1"]},
 "i:2"->{
  Cell[2503, 85, 298, 10, 
  70, "Text", "ExpressionUUID" -> "77a6ce72-3d37-463c-9d60-21b99712442d",
   CellTags->"i:2"]},
 "i:3"->{
  Cell[6051, 208, 246, 8, 
  70, "CodeCaption", "ExpressionUUID" -> "b57a215c-1d9d-417f-ab39-6144b6f37d91
   ",
   CellTags->"i:3"]},
 "i:4"->{
  Cell[6855, 238, 238, 8, 
  70, "CodeCaption", "ExpressionUUID" -> "51bbca54-5c9b-44f5-a9e7-0c4479218754
   ",
   CellTags->"i:4"]},
 "i:5"->{
  Cell[7829, 273, 239, 8, 
  70, "CodeCaption", "ExpressionUUID" -> "5f024e3c-e4c6-4776-ac84-f0b52e0f5e33
   ",
   CellTags->"i:5"]},
 "LastCellOfAPage"->{
  Cell[8440, 296, 382, 10, 
  70, "Output", "ExpressionUUID" -> "b05a7ab2-1f80-4692-a847-4caae02f3158",
   Evaluatable->False,
   CellTags->"LastCellOfAPage"],
  Cell[17477, 572, 1577, 34, 
  70, "Output", "ExpressionUUID" -> "8ef2c91e-814d-4160-9eeb-29227fbcf8cf",
   Evaluatable->False,
   CellTags->"LastCellOfAPage"],
  Cell[75552, 1979, 222, 5, 
  70, "Output", "ExpressionUUID" -> "99ba9ebb-0a98-4110-b1d7-be9a3bdea238",
   Evaluatable->False,
   CellTags->"LastCellOfAPage"],
  Cell[260902, 6253, 538, 16, 
  70, "Answer", "ExpressionUUID" -> "e0fae259-a345-40e9-b618-14e25049983c",
   CellTags->"LastCellOfAPage"],
  Cell[266114, 6435, 347, 8, 
  70, "MoreExplore", "ExpressionUUID" -> "d479c202-7d93-4fff-abcc-4a5239603cc8
   ",
   CellTags->"LastCellOfAPage"]},
 "i:6"->{
  Cell[8837, 309, 341, 13, 
  70, "Text", "ExpressionUUID" -> "4cbc9a6f-a299-4a1d-a4ea-f62b7edccb3b",
   CellTags->{"i:6", "p:206"}]},
 "p:206"->{
  Cell[8837, 309, 341, 13, 
  70, "Text", "ExpressionUUID" -> "4cbc9a6f-a299-4a1d-a4ea-f62b7edccb3b",
   CellTags->{"i:6", "p:206"}]},
 "i:7"->{
  Cell[10773, 380, 366, 13, 
  70, "Text", "ExpressionUUID" -> "63040308-be30-492b-b7f7-24fba7074f68",
   CellTags->"i:7"]},
 "i:8"->{
  Cell[12549, 444, 275, 10, 
  70, "Text", "ExpressionUUID" -> "ec25fe68-6ae8-4746-af43-54c030a38398",
   CellTags->"i:8"]},
 "i:9"->{
  Cell[12827, 456, 244, 6, 
  70, "CodeCaption", "ExpressionUUID" -> "3dd1011d-d518-4a41-8a86-1f9145b2a557
   ",
   CellTags->"i:9"]},
 "i:10"->{
  Cell[16483, 540, 395, 10, 
  70, "Text", "ExpressionUUID" -> "4969bf0f-7f89-48d6-b514-74d0d51157f6",
   CellTags->"i:10"]},
 "i:11"->{
  Cell[19069, 609, 457, 13, 
  70, "Text", "ExpressionUUID" -> "90fe1f66-f720-4a76-b0d7-386f63904f6b",
   CellTags->{"i:11", "p:207"}]},
 "p:207"->{
  Cell[19069, 609, 457, 13, 
  70, "Text", "ExpressionUUID" -> "90fe1f66-f720-4a76-b0d7-386f63904f6b",
   CellTags->{"i:11", "p:207"}]},
 "i:12"->{
  Cell[74834, 1955, 333, 8, 
  70, "CodeCaption", "ExpressionUUID" -> "acd37e4b-ba07-48bb-becb-39a85b221935
   ",
   CellTags->"i:12"]},
 "p:208"->{
  Cell[75823, 1990, 176, 4, 
  70, "VocabularySection", "ExpressionUUID" -> "e9534a74-b6e2-48ec-
   bfcb-71f86fc4e73d",
   CellTags->"p:208"]},
 "i:13"->{
  Cell[259634, 6213, 246, 5, 
  70, "Question", "ExpressionUUID" -> "7e523aef-e59e-4b96-bdaf-68749e5fa8f2",
   CellTags->"i:13"]},
 "i:14"->{
  Cell[260657, 6245, 242, 6, 
  70, "Question", "ExpressionUUID" -> "41b3ba08-3e1a-4f50-b3d3-58d12153a300",
   CellTags->"i:14"]},
 "i:15"->{
  Cell[261443, 6271, 224, 5, 
  70, "Question", "ExpressionUUID" -> "65246525-65b2-41fc-b574-e034268c880c",
   CellTags->{"i:15", "p:209"}]},
 "p:209"->{
  Cell[261443, 6271, 224, 5, 
  70, "Question", "ExpressionUUID" -> "65246525-65b2-41fc-b574-e034268c880c",
   CellTags->{"i:15", "p:209"}]},
 "i:16"->{
  Cell[262121, 6298, 204, 4, 
  70, "Question", "ExpressionUUID" -> "2f77829f-df0f-43d3-9148-0172f31e1828",
   CellTags->"i:16"]},
 "i:17"->{
  Cell[262633, 6316, 323, 10, 
  70, "Question", "ExpressionUUID" -> "50d24b8d-7b32-4cb8-95a1-accfc6476334",
   CellTags->"i:17"]},
 "i:18"->{
  Cell[265237, 6405, 355, 8, 
  70, "TechNote", "ExpressionUUID" -> "d6f78771-f067-4e78-baed-b1c0b363237b",
   CellTags->"i:18"]},
 "i:19"->{
  Cell[265595, 6415, 314, 9, 
  70, "TechNote", "ExpressionUUID" -> "74902152-640b-4f83-bc86-be30be34d964",
   CellTags->"i:19"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"p:205", 356339, 8265},
 {"i:1", 356597, 8272},
 {"i:2", 356730, 8276},
 {"i:3", 356863, 8280},
 {"i:4", 357007, 8285},
 {"i:5", 357151, 8290},
 {"LastCellOfAPage", 357307, 8295},
 {"i:6", 358089, 8315},
 {"p:206", 358236, 8319},
 {"i:7", 358381, 8323},
 {"i:8", 358516, 8327},
 {"i:9", 358651, 8331},
 {"i:10", 358797, 8336},
 {"i:11", 358934, 8340},
 {"p:207", 359083, 8344},
 {"i:12", 359231, 8348},
 {"p:208", 359380, 8353},
 {"i:13", 359535, 8358},
 {"i:14", 359677, 8362},
 {"i:15", 359819, 8366},
 {"p:209", 359973, 8370},
 {"i:16", 360126, 8374},
 {"i:17", 360268, 8378},
 {"i:18", 360411, 8382},
 {"i:19", 360553, 8386}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[655, 23, 439, 11, 70, "SectionDoubleDigit", "ExpressionUUID" -> \
"045a4ebb-b383-44f9-93cf-65f018661b08",
 CounterAssignments->{{"Section", 33}, {"Subsection", 0}, {
   "Subsubsection", 0}, {"Exercise", 0}},
 CellTags->"p:205"],
Cell[1097, 36, 415, 12, 70, "Text", "ExpressionUUID" -> \
"28d2130c-1f0c-47d7-b4ad-033d8ae709f5",
 CellTags->"i:1"],
Cell[1515, 50, 291, 10, 70, "CodeCaption", "ExpressionUUID" -> \
"87f1420e-e993-4eac-9e52-a3e99dd0c69f"],
Cell[CellGroupData[{
Cell[1831, 64, 302, 7, 70, "Input", "ExpressionUUID" -> \
"85d079eb-41f1-45c9-9cc8-a573f5b6829a"],
Cell[2136, 73, 352, 9, 70, "Output", "ExpressionUUID" -> \
"3f5b2909-5a6e-4a24-a4f6-49ee51d4e18d",
 Evaluatable->False]
}, Open  ]],
Cell[2503, 85, 298, 10, 70, "Text", "ExpressionUUID" -> \
"77a6ce72-3d37-463c-9d60-21b99712442d",
 CellTags->"i:2"],
Cell[2804, 97, 306, 9, 70, "CodeCaption", "ExpressionUUID" -> \
"0a0940da-603b-43ed-8577-b6dc480fa9c7"],
Cell[CellGroupData[{
Cell[3135, 110, 339, 9, 70, "Input", "ExpressionUUID" -> \
"f70366f1-b430-49b8-ae5f-ceb3287baad4"],
Cell[3477, 121, 172, 4, 70, "Output", "ExpressionUUID" -> \
"184a512f-6e0f-4382-bac4-30a40cc4625d",
 Evaluatable->False]
}, Open  ]],
Cell[3664, 128, 277, 7, 70, "Text", "ExpressionUUID" -> \
"33739069-aa82-4c70-a252-33c72b9874a4"],
Cell[3944, 137, 190, 4, 70, "CodeCaption", "ExpressionUUID" -> \
"72929ed2-08ee-4a9a-bc57-a30859830cb1"],
Cell[CellGroupData[{
Cell[4159, 145, 336, 9, 70, "Input", "ExpressionUUID" -> \
"2a9d4af6-1a2c-4992-b6a8-b179d9ce2ad3"],
Cell[4498, 156, 358, 9, 70, "Output", "ExpressionUUID" -> \
"c2b3fa39-192d-4601-82e4-e95e8ec3d826",
 Evaluatable->False]
}, Open  ]],
Cell[4871, 168, 363, 11, 70, "CodeCaption", "ExpressionUUID" -> \
"2ef631b8-5ac9-482a-9b31-5d87a1b9a17e"],
Cell[CellGroupData[{
Cell[5259, 183, 332, 8, 70, "Input", "ExpressionUUID" -> \
"c9a92723-972e-4639-97c5-f967406efd06"],
Cell[5594, 193, 442, 12, 70, "Output", "ExpressionUUID" -> \
"11b145d5-a7be-4450-be60-48b3ec751171",
 Evaluatable->False]
}, Open  ]],
Cell[6051, 208, 246, 8, 70, "CodeCaption", "ExpressionUUID" -> \
"b57a215c-1d9d-417f-ab39-6144b6f37d91",
 CellTags->"i:3"],
Cell[CellGroupData[{
Cell[6322, 220, 342, 9, 70, "Input", "ExpressionUUID" -> \
"cb4ada6b-2ae1-4848-96ca-36a5f617e77b"],
Cell[6667, 231, 173, 4, 70, "Output", "ExpressionUUID" -> \
"3ee7e145-cf47-427b-8aef-1a5124a88af5",
 Evaluatable->False]
}, Open  ]],
Cell[6855, 238, 238, 8, 70, "CodeCaption", "ExpressionUUID" -> \
"51bbca54-5c9b-44f5-a9e7-0c4479218754",
 CellTags->"i:4"],
Cell[CellGroupData[{
Cell[7118, 250, 341, 9, 70, "Input", "ExpressionUUID" -> \
"8539f924-cadd-4ed4-bb73-f3fb939b458f"],
Cell[7462, 261, 352, 9, 70, "Output", "ExpressionUUID" -> \
"406ebab5-0702-418f-a12d-38e74fb53126",
 Evaluatable->False]
}, Open  ]],
Cell[7829, 273, 239, 8, 70, "CodeCaption", "ExpressionUUID" -> \
"5f024e3c-e4c6-4776-ac84-f0b52e0f5e33",
 CellTags->"i:5"],
Cell[CellGroupData[{
Cell[8093, 285, 344, 9, 70, "Input", "ExpressionUUID" -> \
"ab959cae-2698-4818-964c-02f12e277186"],
Cell[8440, 296, 382, 10, 70, "Output", "ExpressionUUID" -> \
"b05a7ab2-1f80-4692-a847-4caae02f3158",
 Evaluatable->False,
 CellTags->"LastCellOfAPage"]
}, Open  ]],
Cell[8837, 309, 341, 13, 70, "Text", "ExpressionUUID" -> \
"4cbc9a6f-a299-4a1d-a4ea-f62b7edccb3b",
 CellTags->{"i:6", "p:206"}],
Cell[9181, 324, 183, 4, 70, "CodeCaption", "ExpressionUUID" -> \
"9ac44f19-7487-4553-bbb5-e7d345fc46c7"],
Cell[CellGroupData[{
Cell[9389, 332, 341, 9, 70, "Input", "ExpressionUUID" -> \
"6032faf0-3af2-4a68-a9ea-31cdf3e4dfef"],
Cell[9733, 343, 227, 6, 70, "Output", "ExpressionUUID" -> \
"602938f6-0cab-4850-88c6-cbe0d0f0a799",
 Evaluatable->False]
}, Open  ]],
Cell[9975, 352, 185, 4, 70, "CodeCaption", "ExpressionUUID" -> \
"002d0791-efce-4300-bd18-5bab4e69cea9"],
Cell[CellGroupData[{
Cell[10185, 360, 343, 9, 70, "Input", "ExpressionUUID" -> \
"2bac463d-4013-4056-a5d6-c025cff13cf9"],
Cell[10531, 371, 227, 6, 70, "Output", "ExpressionUUID" -> \
"6bc5d544-48f1-4301-9e03-bba5b8150ad9",
 Evaluatable->False]
}, Open  ]],
Cell[10773, 380, 366, 13, 70, "Text", "ExpressionUUID" -> \
"63040308-be30-492b-b7f7-24fba7074f68",
 CellTags->"i:7"],
Cell[CellGroupData[{
Cell[11164, 397, 344, 9, 70, "Input", "ExpressionUUID" -> \
"b8069c3c-4f1a-4187-bdfc-ca680a2b821e"],
Cell[11511, 408, 318, 9, 70, "Output", "ExpressionUUID" -> \
"e8e72876-9743-498b-a761-a57b38608e14",
 Evaluatable->False]
}, Open  ]],
Cell[CellGroupData[{
Cell[11866, 422, 312, 8, 70, "Input", "ExpressionUUID" -> \
"c22ecb25-3e31-451a-96da-d00cec806d6a"],
Cell[12181, 432, 353, 9, 70, "Output", "ExpressionUUID" -> \
"70758f60-c9e2-42a5-bb66-81695a3c7bd2",
 Evaluatable->False]
}, Open  ]],
Cell[12549, 444, 275, 10, 70, "Text", "ExpressionUUID" -> \
"ec25fe68-6ae8-4746-af43-54c030a38398",
 CellTags->"i:8"],
Cell[12827, 456, 244, 6, 70, "CodeCaption", "ExpressionUUID" -> \
"3dd1011d-d518-4a41-8a86-1f9145b2a557",
 CellTags->"i:9"],
Cell[CellGroupData[{
Cell[13096, 466, 219, 4, 70, "Input", "ExpressionUUID" -> \
"a14a82a6-e5ca-4b69-8ffd-79e39161805c"],
Cell[13318, 472, 3150, 65, 70, "Output", "ExpressionUUID" -> \
"a28de563-8b13-4054-9ca7-ee0e58e9edac",
 Evaluatable->False]
}, Open  ]],
Cell[16483, 540, 395, 10, 70, "Text", "ExpressionUUID" -> \
"4969bf0f-7f89-48d6-b514-74d0d51157f6",
 CellTags->"i:10"],
Cell[16881, 552, 242, 7, 70, "CodeCaption", "ExpressionUUID" -> \
"69fdd92b-8306-429c-9036-197c7a0d3949"],
Cell[CellGroupData[{
Cell[17148, 563, 326, 7, 70, "Input", "ExpressionUUID" -> \
"cb6deaf1-e2c1-479b-95a3-ce2068af3ad1"],
Cell[17477, 572, 1577, 34, 70, "Output", "ExpressionUUID" -> \
"8ef2c91e-814d-4160-9eeb-29227fbcf8cf",
 Evaluatable->False,
 CellTags->"LastCellOfAPage"]
}, Open  ]],
Cell[19069, 609, 457, 13, 70, "Text", "ExpressionUUID" -> \
"90fe1f66-f720-4a76-b0d7-386f63904f6b",
 CellTags->{"i:11", "p:207"}],
Cell[19529, 624, 277, 7, 70, "CodeCaption", "ExpressionUUID" -> \
"2f93386c-c74c-46db-89f1-a3684ac45e6d"],
Cell[CellGroupData[{
Cell[19831, 635, 441, 10, 70, "Input", "ExpressionUUID" -> \
"3b05f70b-47f5-44f4-a17b-1e965969d91b"],
Cell[20275, 647, 51323, 1197, 70, "Output", "ExpressionUUID" -> \
"02313a68-5710-41fc-ba5c-7ee2c7fe56dc",
 Evaluatable->False]
}, Open  ]],
Cell[71613, 1847, 226, 7, 70, "Text", "ExpressionUUID" -> \
"39d1de50-0305-40e8-a816-e2ed7590578a"],
Cell[71842, 1856, 183, 4, 70, "CodeCaption", "ExpressionUUID" -> \
"6e2f4db9-dd6a-4879-b9d5-a840b4da059a"],
Cell[CellGroupData[{
Cell[72050, 1864, 542, 14, 70, "Input", "ExpressionUUID" -> \
"c8260930-4ce5-493c-85dc-7b082cabbac5"],
Cell[72595, 1880, 225, 6, 70, "Output", "ExpressionUUID" -> \
"4e348cfc-ddf0-4963-a381-b91ef3ae7c52",
 Evaluatable->False]
}, Open  ]],
Cell[72835, 1889, 596, 17, 70, "Text", "ExpressionUUID" -> \
"c04a6457-a54c-4951-9cc4-06e4e4cc841a"],
Cell[73434, 1908, 224, 6, 70, "CodeCaption", "ExpressionUUID" -> \
"51b1be3c-4fa0-4e01-ad87-60cb49a8d5f3"],
Cell[CellGroupData[{
Cell[73683, 1918, 493, 13, 70, "Input", "ExpressionUUID" -> \
"dbbda924-aef8-4e30-adab-8861b29021c2"],
Cell[74179, 1933, 225, 6, 70, "Output", "ExpressionUUID" -> \
"09cacba9-930b-4300-9ad2-b26fa83ee214",
 Evaluatable->False]
}, Open  ]],
Cell[74419, 1942, 412, 11, 70, "Text", "ExpressionUUID" -> \
"7e23b4a7-ca60-4e96-8a18-90f664fc3cc1"],
Cell[74834, 1955, 333, 8, 70, "CodeCaption", "ExpressionUUID" -> \
"acd37e4b-ba07-48bb-becb-39a85b221935",
 CellTags->"i:12"],
Cell[CellGroupData[{
Cell[75192, 1967, 357, 10, 70, "Input", "ExpressionUUID" -> \
"bc7b512a-0eca-401a-b446-8d85cd9e66ae"],
Cell[75552, 1979, 222, 5, 70, "Output", "ExpressionUUID" -> \
"99ba9ebb-0a98-4110-b1d7-be9a3bdea238",
 Evaluatable->False,
 CellTags->"LastCellOfAPage"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[75823, 1990, 176, 4, 70, "VocabularySection", "ExpressionUUID" -> \
"e9534a74-b6e2-48ec-bfcb-71f86fc4e73d",
 CellTags->"p:208"],
Cell[76002, 1996, 4048, 109, 70, "VocabularyTable", "ExpressionUUID" -> \
"210cbb60-bfd4-432d-ac8d-3d382fabdacc"]
}, Open  ]],
Cell[CellGroupData[{
Cell[80087, 2110, 1780, 46, 70, "ExerciseSection", "ExpressionUUID" -> \
"ec0349fc-28e3-44f2-8e31-52b3ad6b3e5c"],
Cell[CellGroupData[{
Cell[81892, 2160, 1243, 38, 70, "ExerciseSummaryCell", "ExpressionUUID" -> \
"6c05f642-48a9-488c-ac7c-c97ff6018dc4"],
Cell[CellGroupData[{
Cell[83160, 2202, 760, 21, 70, "Exercise", "ExpressionUUID" -> \
"97fd28e8-32d8-437f-9988-0e5ef976526c"],
Cell[83923, 2225, 1371, 39, 70, "ExerciseOutput", "ExpressionUUID" -> \
"66a612d2-db3e-4dfc-a586-86a91aaf2ac0"]
}, Closed]],
Cell[CellGroupData[{
Cell[85331, 2269, 763, 21, 70, "Exercise", "ExpressionUUID" -> \
"a59f920e-43d5-43aa-a5ef-cd4757afba6b"],
Cell[86097, 2292, 47252, 1061, 70, "ExerciseOutput", "ExpressionUUID" -> \
"abcd234d-39ad-44fd-a18c-bd80ce4620c2"]
}, Closed]],
Cell[CellGroupData[{
Cell[133386, 3358, 939, 27, 70, "Exercise", "ExpressionUUID" -> \
"34e46618-2b96-4f4c-b09f-54125b232d9c"],
Cell[134328, 3387, 117732, 2597, 70, "ExerciseOutput", "ExpressionUUID" -> \
"c5058505-d6e4-4299-b223-a0cb8753b5e6"]
}, Closed]],
Cell[CellGroupData[{
Cell[252097, 5989, 929, 26, 70, "Exercise", "ExpressionUUID" -> \
"85559db1-9271-48ba-8f7b-6c0bab6f701a"],
Cell[253029, 6017, 1794, 46, 70, "ExerciseOutput", "ExpressionUUID" -> \
"6f457bf7-1aad-4c95-9899-a47960cbed46"]
}, Closed]],
Cell[CellGroupData[{
Cell[254860, 6068, 865, 22, 70, "Exercise", "ExpressionUUID" -> \
"1baa3575-1e72-4b8c-813e-32a55bf9e532"],
Cell[255728, 6092, 1129, 32, 70, "ExerciseOutput", "ExpressionUUID" -> \
"cae20154-1351-4b43-bde3-c8f97a7c83b9"]
}, Closed]],
Cell[CellGroupData[{
Cell[256894, 6129, 961, 28, 70, "Exercise", "ExpressionUUID" -> \
"7c26bc7c-c5a8-40b1-be47-19257ca75c54"],
Cell[257858, 6159, 1568, 41, 70, "ExerciseOutput", "ExpressionUUID" -> \
"0b6fee00-3b39-4ace-b27d-ab258ead43a9"]
}, Closed]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[259487, 6207, 144, 4, 70, "QASection", "ExpressionUUID" -> \
"e7bfa04f-01d6-4cc7-8f26-416793093c2f"],
Cell[259634, 6213, 246, 5, 70, "Question", "ExpressionUUID" -> \
"7e523aef-e59e-4b96-bdaf-68749e5fa8f2",
 CellTags->"i:13"],
Cell[259883, 6220, 382, 11, 70, "Answer", "ExpressionUUID" -> \
"93c59968-f537-4686-98cc-f4b42a01f996"],
Cell[260268, 6233, 199, 4, 70, "Question", "ExpressionUUID" -> \
"a772557f-a3cf-45da-9ad4-99b009ab9175"],
Cell[260470, 6239, 184, 4, 70, "Answer", "ExpressionUUID" -> \
"ce12d6bb-176b-4a2b-b51a-2e28d113383e"],
Cell[260657, 6245, 242, 6, 70, "Question", "ExpressionUUID" -> \
"41b3ba08-3e1a-4f50-b3d3-58d12153a300",
 CellTags->"i:14"],
Cell[260902, 6253, 538, 16, 70, "Answer", "ExpressionUUID" -> \
"e0fae259-a345-40e9-b618-14e25049983c",
 CellTags->"LastCellOfAPage"],
Cell[261443, 6271, 224, 5, 70, "Question", "ExpressionUUID" -> \
"65246525-65b2-41fc-b574-e034268c880c",
 CellTags->{"i:15", "p:209"}],
Cell[261670, 6278, 448, 18, 70, "Answer", "ExpressionUUID" -> \
"2d9a45f8-1f3c-4122-9088-2167d5c6b6c5"],
Cell[262121, 6298, 204, 4, 70, "Question", "ExpressionUUID" -> \
"2f77829f-df0f-43d3-9148-0172f31e1828",
 CellTags->"i:16"],
Cell[262328, 6304, 302, 10, 70, "Answer", "ExpressionUUID" -> \
"16bcbe7a-32c5-41e6-976d-9cd674aa89c6"],
Cell[262633, 6316, 323, 10, 70, "Question", "ExpressionUUID" -> \
"50d24b8d-7b32-4cb8-95a1-accfc6476334",
 CellTags->"i:17"],
Cell[262959, 6328, 1288, 38, 70, "Answer", "ExpressionUUID" -> \
"67e22a1f-555c-4c42-9957-34ccadafcf66"],
Cell[264250, 6368, 243, 7, 70, "Question", "ExpressionUUID" -> \
"423b6f05-c9fe-4751-9d0d-09e2f8a59561"],
Cell[264496, 6377, 544, 17, 70, "Answer", "ExpressionUUID" -> \
"45916c58-8497-4ff6-9013-545718eba656"]
}, Open  ]],
Cell[CellGroupData[{
Cell[265077, 6399, 157, 4, 70, "TechNoteSection", "ExpressionUUID" -> \
"43f96dfb-ab7b-4a8a-924f-1f8877a8ce2a"],
Cell[265237, 6405, 355, 8, 70, "TechNote", "ExpressionUUID" -> \
"d6f78771-f067-4e78-baed-b1c0b363237b",
 CellTags->"i:18"],
Cell[265595, 6415, 314, 9, 70, "TechNote", "ExpressionUUID" -> \
"74902152-640b-4f83-bc86-be30be34d964",
 CellTags->"i:19"]
}, Open  ]],
Cell[CellGroupData[{
Cell[265946, 6429, 165, 4, 70, "MoreExploreSection", "ExpressionUUID" -> \
"f18410cf-a694-4d61-a6c7-843816a5b030"],
Cell[266114, 6435, 347, 8, 70, "MoreExplore", "ExpressionUUID" -> \
"d479c202-7d93-4fff-abcc-4a5239603cc8",
 CellTags->"LastCellOfAPage"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
(* NotebookSignature VTsw56Of8GbzoluTYzofxelu *)
