(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    296761,       7022]
NotebookOptionsPosition[    185831,       4631]
NotebookOutlinePosition[    281947,       6653]
CellTagsIndexPosition[    281072,       6616]
WindowTitle->String Patterns and Templates: Elementary Introduction to the \
Wolfram Language
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[BoxData[
 RowBox[{
  InterpretationBox[Cell[
   "String Patterns and Templates", "SectionInline",ExpressionUUID->
    "9c90522e-077f-4121-af2f-3dd5c4225a97"],
   $Line = 0; Null], " "}]], "SectionDoubleDigit",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CounterAssignments->{{"Section", 41}, {"Subsection", 0}, {
   "Subsubsection", 0}, {"Exercise", 0}},
 CellTags->"p:255",
 CellLabel->"In[23]:=",ExpressionUUID->"1394128b-543a-405b-b06c-c27b47fc2e8e"],

Cell[TextData[{
 "String patterns work very much like other patterns in the Wolfram Language, \
except that they operate on sequences of characters in strings rather than \
parts of expressions. In a string pattern, you can combine pattern constructs \
like ",
 Cell[BoxData[
  ButtonBox["_",
   BaseStyle->"Link",
   ButtonData->"Blank"]], "InlineCodeText",ExpressionUUID->
  "ba8eca89-e862-4172-9c8f-c2eff0db2bd8"],
 " with strings like ",
 Cell[BoxData[
 "\"\<abc\>\""], "InlineCodeText",ExpressionUUID->
  "359a82d1-4298-405d-8771-60e90560c444"],
 " using ",
 Cell[BoxData[
  ButtonBox["~~",
   BaseStyle->"Link",
   ButtonData->"StringExpression"]], "InlineCodeText",ExpressionUUID->
  "ea239724-5d15-4bc8-8a23-12000403e131"],
 "."
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:1",ExpressionUUID->"c0261fd0-d513-4a89-a19d-d6062c6b6508"],

Cell[TextData[{
 "This picks out all instances of ",
 Cell[BoxData[
 "+"], "InlineCode",ExpressionUUID->"ff7f9449-65f8-46a8-9e82-fc920594c73c"],
 " followed by a single character:"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:2",ExpressionUUID->"e3c2d860-7d83-439e-977b-64f2466b66e3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringCases", "[", 
  RowBox[{"\"\<+string +patterns are +quite +easy\>\"", ",", " ", 
   RowBox[{"\"\<+\>\"", "~~", "_"}]}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[1]:=",ExpressionUUID->"a2f1622f-78f3-4902-ade2-51e8062328f7"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"+s\"\>", ",", "\<\"+p\"\>", ",", "\<\"+q\"\>", 
   ",", "\<\"+e\"\>"}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[1]=",ExpressionUUID->"19918ecd-9f82-4b8c-bd4e-44f90da2914d"]
}, Open  ]],

Cell[TextData[{
 "This picks out three characters after each ",
 Cell[BoxData[
 "+"], "InlineCode",ExpressionUUID->"06840071-c388-48dc-8620-c44762a97673"],
 ":"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"d370bb39-857f-4572-9075-3594589483d0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringCases", "[", 
  RowBox[{"\"\<+string +patterns are +quite +easy\>\"", ",", " ", 
   RowBox[{"\"\<+\>\"", "~~", "_", "~~", "_", "~~", "_"}]}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[2]:=",ExpressionUUID->"4f1a20bb-3897-4cb6-9969-e3615c89f89c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"+str\"\>", ",", "\<\"+pat\"\>", ",", "\<\"+qui\"\>", 
   ",", "\<\"+eas\"\>"}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[2]=",ExpressionUUID->"a691e690-410e-4dec-8d80-8860ad74e3d7"]
}, Open  ]],

Cell[TextData[{
 "Use the name ",
 Cell[BoxData[
 "x"], "InlineCode",ExpressionUUID->"fba7677e-f931-4558-9894-f732a00b2cfa"],
 " for the character after each ",
 Cell[BoxData[
 "+"], "InlineCode",ExpressionUUID->"1684e9df-c91b-41ff-9ad4-600c3594e468"],
 ", and return that character framed: "
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"bd11ef34-5403-4400-855d-5a4093c8b039"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringCases", "[", 
  RowBox[{"\"\<+string +patterns are +quite +easy\>\"", ",", " ", 
   RowBox[{
    RowBox[{"\"\<+\>\"", "~~", "x_"}], "\[Rule]", 
    RowBox[{"Framed", "[", "x", "]"}]}]}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[3]:=",ExpressionUUID->"38be39d5-7b61-4aed-b27a-24866eacfd2f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FrameBox["\<\"s\"\>",
    StripOnInput->False], ",", 
   FrameBox["\<\"p\"\>",
    StripOnInput->False], ",", 
   FrameBox["\<\"q\"\>",
    StripOnInput->False], ",", 
   FrameBox["\<\"e\"\>",
    StripOnInput->False]}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[3]=",ExpressionUUID->"a7b08dc2-00e2-474f-96f7-5456df14b61b"]
}, Open  ]],

Cell[TextData[{
 "In a string pattern, ",
 Cell[BoxData[
  ButtonBox["_",
   BaseStyle->"Link",
   ButtonData->"Blank"]], "InlineCodeText",ExpressionUUID->
  "b9ca320e-1340-4fab-82ec-cc0d5edd76ed"],
 " stands for any single character. ",
 Cell[BoxData[
  ButtonBox[
   RowBox[{"_", "\[ThinSpace]", "_"}],
   BaseStyle->"Link",
   ButtonData->"BlankSequence"]], "InlineCodeText",ExpressionUUID->
  "19d7750e-cbd2-4732-8064-b020b4549125"],
 " (\[OpenCurlyDoubleQuote]double blank\[CloseCurlyDoubleQuote]) stands for \
any sequence of one or more characters, and ",
 Cell[BoxData[
  ButtonBox[
   RowBox[{"_", "\[ThinSpace]", "_", "\[ThinSpace]", "_"}],
   BaseStyle->"Link",
   ButtonData->"BlankNullSequence"]], "InlineCodeText",ExpressionUUID->
  "b38253cd-14ab-4f8e-8ea7-7bbae9e3265e"],
 " (\[OpenCurlyDoubleQuote]triple blank\[CloseCurlyDoubleQuote]) stands for \
any sequence of zero or more characters. ",
 Cell[BoxData[
  ButtonBox[
   RowBox[{"_", "\[ThinSpace]", "_"}],
   BaseStyle->"Link",
   ButtonData->"BlankSequence"]], "InlineCodeText",ExpressionUUID->
  "65aaf0f0-aa6d-4edb-b93c-8c862e0108b2"],
 " and ",
 Cell[BoxData[
  ButtonBox[
   RowBox[{"_", "\[ThinSpace]", "_", "\[ThinSpace]", "_"}],
   BaseStyle->"Link",
   ButtonData->"BlankNullSequence"]], "InlineCodeText",ExpressionUUID->
  "e8fd23fb-2fae-4a9b-b73a-2e7442453120"],
 " will normally grab as much of the string as they can."
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:3",ExpressionUUID->"1aa02fa6-a322-4d89-93ea-ddc8ab1d708c"],

Cell[TextData[{
 "Pick out the sequence of characters between ",
 Cell[BoxData[
 "["], "InlineCode",ExpressionUUID->"bc2c6d76-3141-4d8a-bf96-8d28417d35ad"],
 " and ",
 Cell[BoxData[
 "]"], "InlineCode",ExpressionUUID->"0f200d2f-f379-4dc8-bbdf-48464e9bc270"],
 ":"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"b235e84a-a6b2-4ee9-9903-7c9b3ee7e173"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringCases", "[", 
  RowBox[{"\"\<the [important] word\>\"", ",", " ", 
   RowBox[{
    RowBox[{"\"\<[\>\"", "~~", "x__", "~~", "\"\<]\>\""}], "\[Rule]", 
    RowBox[{"Framed", "[", "x", "]"}]}]}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[4]:=",ExpressionUUID->"62626fa1-558d-4535-86aa-71671b852031"],

Cell[BoxData[
 RowBox[{"{", 
  FrameBox["\<\"important\"\>",
   StripOnInput->False], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[4]=",ExpressionUUID->"82781b3a-c2cc-4bb4-ba87-fcd162b2937e"]
}, Open  ]],

Cell[TextData[{
 Cell[BoxData[
  ButtonBox[
   RowBox[{"_", "\[ThinSpace]", "_"}],
   BaseStyle->"Link",
   ButtonData->"BlankSequence"]], "InlineCode",ExpressionUUID->
  "e6d57eea-72a6-4193-923d-2ea9883e069d"],
 " normally matches as long a sequence of characters as it can:"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"ad83f1c2-1326-45b4-9174-39e1f66cdaf2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringCases", "[", 
  RowBox[{"\"\<now [several] important [words]\>\"", ",", " ", 
   RowBox[{
    RowBox[{"\"\<[\>\"", "~~", "x__", "~~", "\"\<]\>\""}], "\[Rule]", 
    RowBox[{"Framed", "[", "x", "]"}]}]}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[5]:=",ExpressionUUID->"a4add623-4591-47b2-a264-9ce829cf8096"],

Cell[BoxData[
 RowBox[{"{", 
  FrameBox["\<\"several] important [words\"\>",
   StripOnInput->False], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[5]=",ExpressionUUID->"b9418834-08db-401e-a2a9-d98707065cdf"]
}, Open  ]],

Cell[TextData[{
 ButtonBox["Shortest",
  BaseStyle->"Link"],
 " forces the shortest match:"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:4",ExpressionUUID->"80d2363c-44df-4c29-8db3-f2e98ace43e2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringCases", "[", 
  RowBox[{"\"\<now [several] important [words]\>\"", ",", " ", 
   RowBox[{
    RowBox[{"\"\<[\>\"", "~~", 
     RowBox[{"Shortest", "[", "x__", "]"}], "~~", "\"\<]\>\""}], "\[Rule]", 
    RowBox[{"Framed", "[", "x", "]"}]}]}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[6]:=",ExpressionUUID->"7a2bd344-a9df-482e-879f-c5d83a6704c6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FrameBox["\<\"several\"\>",
    StripOnInput->False], ",", 
   FrameBox["\<\"words\"\>",
    StripOnInput->False]}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[6]=",ExpressionUUID->"c136f2c3-8092-47c2-a63c-cbfe38181aa9"]
}, Open  ]],

Cell[TextData[{
 ButtonBox["StringCases",
  BaseStyle->"Link"],
 " picks out cases of a particular pattern in a string. ",
 ButtonBox["StringReplace",
  BaseStyle->"Link"],
 " makes replacements."
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"f858eef0-bb49-4075-bce5-a303274a323b"],

Cell["Make replacements for characters in the string:", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:5",ExpressionUUID->"babf1288-c3df-4765-b351-dddd20afdf54"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringReplace", "[", 
  RowBox[{"\"\<now [several] important [words]\>\"", ",", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\"\<[\>\"", "\[Rule]", "\"\<<<\>\""}], ",", 
     RowBox[{"\"\<]\>\"", "\[Rule]", "\"\<>>\>\""}]}], "}"}]}], 
  "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[7]:=",ExpressionUUID->"6e7e69f1-a81c-4a27-a492-ee0b30290d59"],

Cell[BoxData["\<\"now <<several>> important <<words>>\"\>"], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellTags->"LastCellOfAPage",
 CellLabel->"Out[7]=",ExpressionUUID->"fb47eaeb-1d83-4510-b91b-611d94da68d8"]
}, Open  ]],

Cell[TextData[{
 "Make replacements for patterns, using ",
 Cell[BoxData[
  ButtonBox["\[RuleDelayed]",
   BaseStyle->"Link",
   ButtonData->"RuleDelayed"]], "InlineCode",ExpressionUUID->
  "47362797-de87-476a-b2e4-de7ef617d892"],
 " to compute ",
 ButtonBox["ToUpperCase",
  BaseStyle->"Link"],
 " in each case:"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"p:256",ExpressionUUID->"cd5a5355-e6cc-4b78-8eb7-522108d60bf5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringReplace", "[", 
  RowBox[{"\"\<now [several] important [words]\>\"", ",", " ", 
   RowBox[{
    RowBox[{"\"\<[\>\"", "~~", 
     RowBox[{"Shortest", "[", "x__", "]"}], "~~", "\"\<]\>\""}], 
    "\[RuleDelayed]", 
    RowBox[{"ToUpperCase", "[", "x", "]"}]}]}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[8]:=",ExpressionUUID->"3654b4da-08fa-4d54-ae2b-14acebef1168"],

Cell[BoxData["\<\"now SEVERAL important WORDS\"\>"], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[8]=",ExpressionUUID->"0f52fa2a-bfec-40c0-8928-7af6a7cf5418"]
}, Open  ]],

Cell[TextData[{
 "Use ",
 ButtonBox["NestList",
  BaseStyle->"Link"],
 " to apply a string replacement repeatedly:"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:6",ExpressionUUID->"4dafc477-d41a-43be-80f2-9d9886b724f1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"NestList", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"StringReplace", "[", 
     RowBox[{"#", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\"\<A\>\"", "\[Rule]", "\"\<AB\>\""}], ",", 
        RowBox[{"\"\<B\>\"", "\[Rule]", "\"\<BA\>\""}]}], "}"}]}], "]"}], 
    "&"}], ",", "\"\<A\>\"", ",", "5"}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[9]:=",ExpressionUUID->"4a5944b3-27cb-4e8a-998d-21bf77f4ec5b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"A\"\>", ",", "\<\"AB\"\>", ",", "\<\"ABBA\"\>", 
   ",", "\<\"ABBABAAB\"\>", ",", "\<\"ABBABAABBAABABBA\"\>", 
   ",", "\<\"ABBABAABBAABABBABAABABBAABBABAAB\"\>"}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[9]=",ExpressionUUID->"aad01564-0e97-4920-9296-49378ad6a342"]
}, Open  ]],

Cell[TextData[{
 ButtonBox["StringMatchQ",
  BaseStyle->"Link"],
 " tests whether a string matches a pattern."
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:7",ExpressionUUID->"e83a12b3-4394-4f27-a43b-43c5a5f14f7b"],

Cell[TextData[{
 "Select common words that match the pattern of beginning with ",
 Cell[BoxData[
 "a"], "InlineCode",ExpressionUUID->"4a9ed9de-4ae5-4587-bace-a10a0aadda10"],
 " and ending with ",
 Cell[BoxData[
 "b"], "InlineCode",ExpressionUUID->"fdb7ac0f-5c2a-465c-b0da-80c8efe7d034"],
 ":"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"107309f6-fb19-486c-9f54-613ca60993b4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Select", "[", 
  RowBox[{
   RowBox[{"WordList", "[", " ", "]"}], ",", 
   RowBox[{
    RowBox[{"StringMatchQ", "[", 
     RowBox[{"#", ",", 
      RowBox[{"\"\<a\>\"", "~~", "___", "~~", "\"\<b\>\""}]}], "]"}], "&"}]}],
   "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[10]:=",ExpressionUUID->"000626ed-14c7-4d06-94cd-ffe36c600e7f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"absorb\"\>", ",", "\<\"adsorb\"\>", ",", "\<\"adverb\"\>", 
   ",", "\<\"alb\"\>", ",", "\<\"aplomb\"\>"}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[10]=",ExpressionUUID->"a71c5ff9-9990-4302-a3cf-46816d0ed128"]
}, Open  ]],

Cell[TextData[{
 "You can use ",
 Cell[BoxData[
  ButtonBox["|",
   BaseStyle->"Link",
   ButtonData->"Alternatives"]], "InlineCodeText",ExpressionUUID->
  "72a6c799-b014-4ccd-bd3c-66a77bdf27eb"],
 " and ",
 Cell[BoxData[
  ButtonBox["..",
   BaseStyle->"Link",
   ButtonData->"Repeated"]], "InlineCodeText",ExpressionUUID->
  "f2f8557c-ad89-471f-b7c9-36f2b6de0e88"],
 " in string patterns just like in ordinary patterns. "
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:8",ExpressionUUID->"399502b8-f9ee-4a31-b846-25a34ddf7a1e"],

Cell["Pick out any sequence of A or B repeated:", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"5d4f0f08-c277-4f83-9a01-914da0235741"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringCases", "[", 
  RowBox[{"\"\<the AAA and the BBB and the ABABBBABABABA\>\"", ",", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"\"\<A\>\"", "|", "\"\<B\>\""}], ")"}], ".."}]}], "]"}]], "Input",\

 Deletable->False,
 CellLabel->"In[11]:=",ExpressionUUID->"239ca419-433c-412d-bc2d-4e0fa79bc1f0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"AAA\"\>", ",", "\<\"BBB\"\>", ",", "\<\"ABABBBABABABA\"\>"}], 
  "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[11]=",ExpressionUUID->"24751ca6-4702-4b42-90e1-9ecb539daa31"]
}, Open  ]],

Cell[TextData[{
 "In a string pattern, ",
 ButtonBox["LetterCharacter",
  BaseStyle->"Link"],
 " stands for any letter character, ",
 ButtonBox["DigitCharacter",
  BaseStyle->"Link"],
 " for any digit character, and ",
 ButtonBox["Whitespace",
  BaseStyle->"Link"],
 " for any sequence of \[OpenCurlyDoubleQuote]white\[CloseCurlyDoubleQuote] \
characters such as spaces."
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:9",ExpressionUUID->"e8a4ab66-255e-4d0b-90bc-e02a2d27e17a"],

Cell["Pick out sequences of digit characters:", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"f5b875f4-a878-4842-95a5-0a2bde4811eb"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringCases", "[", 
  RowBox[{"\"\<12 and 123 and 4567 and 0x456\>\"", ",", 
   RowBox[{"DigitCharacter", ".."}]}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[12]:=",ExpressionUUID->"b2faf823-4096-4224-8916-6879ff95c7e9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"12\"\>", ",", "\<\"123\"\>", ",", "\<\"4567\"\>", 
   ",", "\<\"0\"\>", ",", "\<\"456\"\>"}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[12]=",ExpressionUUID->"ab7ab4f0-8dad-4827-a1f2-855d1e4246da"]
}, Open  ]],

Cell["\<\
Pick out sequences of digit characters \[OpenCurlyDoubleQuote]flanked\
\[CloseCurlyDoubleQuote] by whitespace:\
\>", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"38ecabc2-a356-452d-bc53-89f6b4e21eb6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringCases", "[", 
  RowBox[{"\"\<12 and 123 and 4567 and 0x456\>\"", ",", 
   RowBox[{"Whitespace", "~~", 
    RowBox[{"DigitCharacter", ".."}], "~~", "Whitespace"}]}], "]"}]], "Input",\

 Deletable->False,
 CellLabel->"In[13]:=",ExpressionUUID->"cdab55df-ca14-4039-b3d7-e696d0585cda"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\" 123 \"\>", ",", "\<\" 4567 \"\>"}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[13]=",ExpressionUUID->"1ce6199f-f80e-4302-b545-ea4c50b57d23"]
}, Open  ]],

Cell[TextData[{
 "It\[CloseCurlyQuote]s common in practice to want to go back and forth \
between strings and lists. You can split a string into a list of pieces using \
",
 ButtonBox["StringSplit",
  BaseStyle->"Link"],
 "."
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:10",ExpressionUUID->"e9679f15-5e5b-4aee-af04-7714652fb909"],

Cell["\<\
Split a string into a list of pieces, by default breaking at spaces:\
\>", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"f2e216f8-697b-4fdb-a379-cb8e8603aa1b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringSplit", "[", "\"\<a string to split\>\"", "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[14]:=",ExpressionUUID->"8f7eb4e8-ce38-4fb8-8e3d-f0c1d292ccf5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"a\"\>", ",", "\<\"string\"\>", ",", "\<\"to\"\>", 
   ",", "\<\"split\"\>"}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[14]=",ExpressionUUID->"861082ab-6cd6-478c-9544-f841b9122982"]
}, Open  ]],

Cell["This uses a string pattern to decide where to split:", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"632e1ee0-73d8-417f-9a75-b052158d6704"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringSplit", "[", 
  RowBox[{"\"\<you+can+split--at+any--delimiter\>\"", ",", 
   RowBox[{"\"\<+\>\"", "|", "\"\<--\>\""}]}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[15]:=",ExpressionUUID->"28c2900e-2d92-4ed1-90e8-daf80ce7f220"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"you\"\>", ",", "\<\"can\"\>", ",", "\<\"split\"\>", 
   ",", "\<\"at\"\>", ",", "\<\"any\"\>", ",", "\<\"delimiter\"\>"}], 
  "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellTags->"LastCellOfAPage",
 CellLabel->"Out[15]=",ExpressionUUID->"b7919ce3-345b-4b26-ae87-8a71c7ca5ad6"]
}, Open  ]],

Cell[TextData[{
 "Within strings, there\[CloseCurlyQuote]s a special newline character which \
indicates where the string should break onto a new line. The newline \
character is represented within strings as ",
 Cell[BoxData[
 "\\n"], "InlineCodeText",ExpressionUUID->
  "b93c4ae5-83d8-49c5-a5ae-b5651fe60209"],
 ". "
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->{
  "i:11", "p:257"},ExpressionUUID->"afa9afd6-b208-46e9-9e01-8bbd409a0f2b"],

Cell["Split at newlines:", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"5acb54bb-cc3f-48a2-8233-a043a502151e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringSplit", "[", 
  RowBox[{"\"\<first line\nsecond line\nthird line\>\"", ",", "\"\<\\n\>\""}],
   "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[16]:=",ExpressionUUID->"cb32c59c-3f72-4442-8624-a89ccddcc820"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"first line\"\>", ",", "\<\"second line\"\>", 
   ",", "\<\"third line\"\>"}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[16]=",ExpressionUUID->"62fbd2ee-fcea-4240-855a-71918851f340"]
}, Open  ]],

Cell[TextData[{
 ButtonBox["StringJoin",
  BaseStyle->"Link"],
 " joins any list of strings together. In practice, though, one often wants \
to insert something between the strings before joining them. ",
 ButtonBox["StringRiffle",
  BaseStyle->"Link"],
 " does this."
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:12",ExpressionUUID->"119027c5-c5ec-4814-9ae5-39b5c7a7d43b"],

Cell[TextData[{
 "Join strings, riffling the string ",
 Cell[BoxData[
 "\"\<---\>\""], "InlineCode",ExpressionUUID->
  "f3436153-ca17-4e17-bca8-0f8695277fcf"],
 " in between them:"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 ShowSyntaxStyles->
  False,ExpressionUUID->"be330ba1-39d3-45e0-9a69-23ae1626228a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringRiffle", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "\"\<a\>\"", ",", "\"\<list\>\"", ",", "\"\<of\>\"", ",", 
     "\"\<strings\>\""}], "}"}], ",", "\"\<---\>\""}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[17]:=",ExpressionUUID->"7b917683-f643-434c-88db-35412e860b20"],

Cell[BoxData["\<\"a---list---of---strings\"\>"], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[17]=",ExpressionUUID->"ad67ceb6-712c-47f5-97d1-0a6679c2438d"]
}, Open  ]],

Cell[TextData[{
 "In assembling strings, one often wants to turn arbitrary Wolfram Language \
expressions into strings. One can do this using ",
 ButtonBox["TextString",
  BaseStyle->"Link"],
 "."
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:13",ExpressionUUID->"79886491-4db1-4a28-8f1f-9cd3e0bf48b3"],

Cell[TextData[{
 ButtonBox["TextString",
  BaseStyle->"Link"],
 " turns numbers and other Wolfram Language expressions into strings:"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"5c124477-62db-4918-a9d8-d0d68de1e4b1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringJoin", "[", 
  RowBox[{"\"\<two to the \>\"", ",", 
   RowBox[{"TextString", "[", "50", "]"}], ",", "\"\< is \>\"", ",", 
   RowBox[{"TextString", "[", 
    RowBox[{"2", "^", "50"}], "]"}]}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[18]:=",ExpressionUUID->"ba609915-f759-498c-ac18-2ee481c318bf"],

Cell[BoxData["\<\"two to the 50 is 1125899906842624\"\>"], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[18]=",ExpressionUUID->"be41a906-1121-4ac5-bf76-99f8371770bc"]
}, Open  ]],

Cell[TextData[{
 "A more convenient way to create strings from expressions is to use ",
 StyleBox["string templates",
  FontSlant->"Italic"],
 ". String templates work like pure functions in that they have slots into \
which arguments can be inserted. "
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:14",ExpressionUUID->"01bc5af0-a0c0-42ba-be0e-ca909f3aa779"],

Cell[TextData[{
 "In a string template each ",
 Cell[BoxData[
  ButtonBox["``",
   BaseStyle->"Link",
   ButtonData->"TemplateSlot"]], "InlineCode",ExpressionUUID->
  "a639a442-7af3-4158-bb9c-440f74689431"],
 " is a slot for a successive argument: "
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:15",ExpressionUUID->"df7f9595-c740-478d-8507-c65acabba86f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"StringTemplate", "[", "\"\<first `` then ``\>\"", "]"}], "[", 
  RowBox[{"100", ",", "200"}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[19]:=",ExpressionUUID->"5f89fa22-cca4-4d9c-8b7b-ea582bb57d30"],

Cell[BoxData["\<\"first 100 then 200\"\>"], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[19]=",ExpressionUUID->"bf004be7-efd3-49f3-81c2-01bcd1e3ed10"]
}, Open  ]],

Cell["Named slots pick elements from an association:", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:16",ExpressionUUID->"ccec5401-fe14-46cd-9fb3-911a028f4acb"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
  "StringTemplate", "[", "\"\<first: `a`; second `b`; first again `a`\>\"", 
   "]"}], "[", 
  RowBox[{"\[LeftAssociation]", 
   RowBox[{
    RowBox[{"\"\<a\>\"", "\[Rule]", "\"\<AAAA\>\""}], ",", " ", 
    RowBox[{"\"\<b\>\"", "\[Rule]", "\"\<BB BBB\>\""}]}], 
   "\[RightAssociation]"}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[20]:=",ExpressionUUID->"9d7b408a-18fc-43d4-a2bd-f97ec52747a2"],

Cell[BoxData["\<\"first: AAAA; second BB BBB; first again AAAA\"\>"], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[20]=",ExpressionUUID->"2f228083-002d-43bd-95e1-a59463575720"]
}, Open  ]],

Cell[TextData[{
 "You can insert any expression within a string template by enclosing it with \
",
 ButtonBox["<*",
  BaseStyle->"Link",
  ButtonData->"TemplateExpression"],
 StyleBox[ButtonBox["...",
  BaseStyle->"Link",
  ButtonData->"TemplateExpression"],
  FontColor->GrayLevel[0.6]],
 ButtonBox["*>",
  BaseStyle->"Link",
  ButtonData->"TemplateExpression"],
 ". The value of the expression is computed when the template is applied."
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"62e5237a-3355-4fcc-a0fb-e86e9be10c6c"],

Cell[TextData[{
 "Evaluate the ",
 ButtonBox["<*",
  BaseStyle->"Link",
  ButtonData->"TemplateExpression"],
 StyleBox[ButtonBox["...",
  BaseStyle->"Link",
  ButtonData->"TemplateExpression"],
  FontColor->GrayLevel[0.6]],
 ButtonBox["*>",
  BaseStyle->"Link",
  ButtonData->"TemplateExpression"],
 " when the template is applied; no arguments are needed:"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"060d4607-a6c4-4356-b47d-6ba91ad8b101"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"StringTemplate", "[", "\"\<2 to the 50 is <* 2^50 *>\>\"", "]"}], 
  "[", " ", "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[21]:=",ExpressionUUID->"1165fd87-9098-4150-b79f-fb064d8ba886"],

Cell[BoxData["\<\"2 to the 50 is 1125899906842624\"\>"], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellTags->"LastCellOfAPage",
 CellLabel->"Out[21]=",ExpressionUUID->"71c3b31f-b2e5-4eaf-a2db-577770427081"]
}, Open  ]],

Cell[TextData[{
 "Use slots in the template (",
 Cell[BoxData[
 "`"], "InlineCode",ExpressionUUID->"97001e1a-d6fd-4075-a055-91cc369ead52"],
 " is the backquote character):"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->{
  "i:17", "p:258"},ExpressionUUID->"13810c7f-fd59-4b48-a33a-18b98f0f577b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
  "StringTemplate", "[", "\"\<`1` to the `2` is <* #1^#2 *>\>\"", "]"}], "[", 
  
  RowBox[{"2", ",", "50"}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[22]:=",ExpressionUUID->"c4e55f36-aa6c-4d68-bde7-4c67f5100b7f"],

Cell[BoxData["\<\"2 to the 50 is 1125899906842624\"\>"], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[22]=",ExpressionUUID->"9baf9cc1-df45-4fec-8930-ee9a9edb246e"]
}, Open  ]],

Cell["\<\
The expression in the template is evaluated when the template is applied:\
\>", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:18",ExpressionUUID->"2054f04c-0e73-4d19-9a64-da44c4afed99"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"StringTemplate", "[", "\"\<the time now is <* Now *>\>\"", "]"}], 
  "[", " ", "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[23]:=",ExpressionUUID->"951fc1e6-8fa9-4928-92c6-dc5dee250287"],

Cell[BoxData["\<\"the time now is Wed 16 Sep 2015 16:50:43\"\>"], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[23]=",ExpressionUUID->"ffcaeb73-8224-4b4c-9702-dce3002107ee"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Vocabulary", "VocabularySection",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"4fab7a79-aec7-4e24-ab06-2251f289496c"],

Cell[BoxData[GridBox[{
   {
    RowBox[{
     SubscriptBox[
      StyleBox["patt", "CodeVariableLrg"], "1"], 
     ButtonBox["~~",
      BaseStyle->"CodeLink",
      ButtonData->"StringExpression"], 
     SubscriptBox[
      StyleBox["patt", "CodeVariableLrg"], "2"]}], " ", Cell[
    "sequence of string patterns ", "VocabularyText",ExpressionUUID->
     "174e9a1d-eada-41cc-babe-0db6cb1e56d6"]},
   {
    RowBox[{
     ButtonBox["Shortest",
      BaseStyle->"CodeLink"], "[", 
     StyleBox["patt", "CodeVariableLrg"], "]"}], " ", Cell[
    "shortest sequence that matches ", "VocabularyText",ExpressionUUID->
     "b9f8e0a4-cb1c-40ad-9922-092f3f27c482"]},
   {
    RowBox[{
     ButtonBox["StringCases",
      BaseStyle->"CodeLink"], "[", 
     RowBox[{
      StyleBox["string", "CodeVariableLrg"], ",", 
      StyleBox["patt", "CodeVariableLrg"]}], "]"}], " ", Cell[
    "cases within a string matching a pattern ", "VocabularyText",
     ExpressionUUID->"9f049b33-34a0-45c3-8618-274f6620a019"]},
   {
    RowBox[{
     ButtonBox["StringReplace",
      BaseStyle->"CodeLink"], "[", 
     RowBox[{
      StyleBox["string", "CodeVariableLrg"], ",", 
      RowBox[{
       StyleBox["patt", "CodeVariableLrg"], "\[Rule]", 
       StyleBox["val", "CodeVariableLrg"]}]}], "]"}], " ", Cell[
    "replace a pattern within a string  ", "VocabularyText",ExpressionUUID->
     "0485434d-8fac-4825-8eb9-f44455222e72"]},
   {
    RowBox[{
     ButtonBox["StringMatchQ",
      BaseStyle->"CodeLink"], "[", 
     RowBox[{
      StyleBox["string", "CodeVariableLrg"], ",", 
      StyleBox["patt", "CodeVariableLrg"]}], "]"}], " ", Cell[
    "test whether a string matches a pattern ", "VocabularyText",
     ExpressionUUID->"29b10db4-c260-467f-a675-2e26dbf444a7"]},
   {
    ButtonBox["LetterCharacter",
     BaseStyle->"CodeLink"], " ", Cell[
    "pattern construct matching a letter ", "VocabularyText",ExpressionUUID->
     "f88345ce-3e0b-45f9-b950-e3e8b792ae75"]},
   {
    ButtonBox["DigitCharacter",
     BaseStyle->"CodeLink"], " ", Cell[
    "pattern construct matching a digit ", "VocabularyText",ExpressionUUID->
     "bfcf2a4c-2b7a-41c9-98a0-9bc49366f2da"]},
   {
    ButtonBox["Whitespace",
     BaseStyle->"CodeLink"], " ", Cell[
    "pattern construct matching spaces etc.", "VocabularyText",
     ExpressionUUID->"2038d8d1-bfb5-4be2-b530-3fb86acfa185"]},
   {"\\n", " ", Cell[
    "newline character ", "VocabularyText",ExpressionUUID->
     "8bc99c6b-3f83-4014-91bc-0b8213cf7a58"]},
   {
    RowBox[{
     ButtonBox["StringSplit",
      BaseStyle->"CodeLink"], "[", 
     StyleBox["string", "CodeVariableLrg"], "]"}], " ", Cell[
    "split a string into a list of pieces ", "VocabularyText",ExpressionUUID->
     "7e114462-7eff-4184-9982-1b613a1be2a2"]},
   {
    RowBox[{
     ButtonBox["StringJoin",
      BaseStyle->"CodeLink"], "[", 
     RowBox[{"{", 
      RowBox[{
       SubscriptBox[
        StyleBox["string", "CodeVariableLrg"], "1"], ",", 
       SubscriptBox[
        StyleBox["string", "CodeVariableLrg"], "2"], ",", 
       StyleBox["...", "GrayPointSix"]}], "}"}], "]"}], " ", Cell[
    "join strings together ", "VocabularyText",ExpressionUUID->
     "1257f759-8a7f-4e2c-ad10-71a65d214e15"]},
   {
    RowBox[{
     ButtonBox["StringRiffle",
      BaseStyle->"CodeLink"], "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        SubscriptBox[
         StyleBox["string", "CodeVariableLrg"], "1"], ",", 
        SubscriptBox[
         StyleBox["string", "CodeVariableLrg"], "2"], ",", 
        StyleBox["...", "GrayPointSix"]}], "}"}], ",", 
      StyleBox["m", "CodeVariableLrg"]}], "]"}], " ", Cell[TextData[{
     "join strings, inserting ",
     Cell[BoxData[
      StyleBox["m", "CodeVariable"]], "InlineCode",ExpressionUUID->
      "adef6c6a-1192-4ded-8e86-cda28900fc86"],
     " between them "
    }], "VocabularyText",ExpressionUUID->
     "9a82e75a-f116-4b74-ad4d-f0cea760c642"]},
   {
    RowBox[{
     ButtonBox["TextString",
      BaseStyle->"CodeLink"], "[", 
     StyleBox["expr", "CodeVariableLrg"], "]"}], " ", Cell[
    "make a text string out of anything ", "VocabularyText",ExpressionUUID->
     "3bab081f-e904-49b6-b744-886ff0832cab"]},
   {
    RowBox[{
     ButtonBox["StringTemplate",
      BaseStyle->"CodeLink"], "[", 
     StyleBox["string", "CodeVariableLrg"], "]"}], " ", Cell[
    "create a string template to apply ", "VocabularyText",ExpressionUUID->
     "63b062f5-d56e-418a-b234-fa37c9a8aacf"]},
   {
    ButtonBox["``",
     BaseStyle->"CodeLink",
     ButtonData->"TemplateSlot"], " ", Cell[
    "slot in a string template ", "VocabularyText",ExpressionUUID->
     "6f40f76d-1312-4d80-8905-86d9e3492a98"]},
   {
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"<", "\[NegativeThinSpace]\[NegativeThinSpace]", "*"}], 
       StyleBox["...", "GrayPointSix"]}], "*"}], "\[NegativeThinSpace]", 
     ">"}], " ", Cell[
    "expression to evaluate in a string template ", "VocabularyText",
     ExpressionUUID->"84bbcd36-3655-4fc7-a534-f18314ca0580"]}
  }]], "VocabularyTable",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 GridBoxOptions->{
 GridBoxDividers->{
  "Columns" -> {{False}}, "Rows" -> {False, {True, True, True, True, 
      Directive[
       Thickness[1.5], "VocabDivColor"], True, True, True, 
      Directive[
       Thickness[1.5], "VocabDivColor"], True, True, True, 
      Directive[
       Thickness[1.5], "VocabDivColor"], True, True, True}, False}}},
 CellTags->
  "LastCellOfAPage",ExpressionUUID->"9420134a-aaf2-4a1a-aeff-61d6e4394785"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 DynamicModuleBox[{$CellContext`open$$ = False}, 
  TagBox[GridBox[{
     {
      StyleBox["\<\"Exercises\"\>",
       StripOnInput->False,
       FontSlant->"Italic"], 
      PaneBox[
       TagBox[
        ButtonBox[
         DynamicBox[ToBoxes[
           If[$CellContext`open$$, 
            Row[{
              Style["-", "ExercisePreviewButtonTextHighlight"], 
              Style[" Preview Exercises", "ExercisePreviewButtonText"]}], 
            Row[{
              Style["+", "ExercisePreviewButtonTextHighlight"], 
              Style[" Preview Exercises", "ExercisePreviewButtonText"]}]], 
           StandardForm],
          ImageSizeCache->{115., {1., 10.}}],
         Appearance->None,
         ButtonFunction:>(
          If[$CellContext`open$$, $CellContext`open$$ = 
            False, $CellContext`open$$ = True]; NotebookFind[
            EvaluationNotebook[], "ExerciseSummaryCell", Next, CellStyle, 
            WrapAround -> True, AutoScroll -> False]; FrontEndTokenExecute[
            EvaluationNotebook[], "ExpandSelection"]; FrontEndExecute[
            FrontEndToken[
             EvaluationNotebook[], "OpenCloseGroup"]]),
         Evaluator->Automatic,
         Method->"Preemptive"],
        MouseAppearanceTag["LinkHand"]],
       Alignment->Right,
       ImageSize->Full]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {Left, Right}, "Rows" -> {{Center}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"],
  DynamicModuleValues:>{}]], "ExerciseSection",
 Editable->False,
 ShowCellBracket->False,
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{3.669991951589675*^9},
 ShowStringCharacters->
  False,ExpressionUUID->"b6a4c764-01c3-4c0d-9c1e-31ab8e73e47b"],

Cell[CellGroupData[{

Cell[BoxData[
 TagBox[GridBox[{
    {
     TagBox[GridBox[{
        {
         PaneBox[
          StyleBox["\<\"8 Exercises Available\"\>", "ExerciseSummaryHeading",
           StripOnInput->False],
          ImageMargins->{{20, 0}, {0, 10}}]}
       },
       DefaultBaseStyle->"Column",
       GridBoxAlignment->{"Columns" -> {{Left}}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
       
       GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{0}}}],
      "Column"], 
     PaneBox[
      ButtonBox[
       StyleBox["\<\"Get Started \[RightGuillemet]\"\>", 
        "ExerciseSummaryHeading",
        StripOnInput->False],
       Appearance->None,
       ButtonFunction:>
        NotebookLocate[{
         "EIWL1-42-string-patterns-and-templates-exercises.nb", ""}],
       Evaluator->Automatic,
       Method->"Preemptive"],
      FrameMargins->{{10, 0}, {10, 10}},
      ImageSize->Full]}
   },
   AutoDelete->False,
   GridBoxAlignment->{"Columns" -> {{Left}}},
   GridBoxItemSize->{"Columns" -> {
       Scaled[0.7], 
       Scaled[0.3]}, "Rows" -> {{Automatic}}}],
  "Grid"]], "ExerciseSummaryCell",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"66a93ea4-12b4-4e0d-a5f3-836cb56b95b8"],

Cell[CellGroupData[{

Cell[TextData[{
 "Replace each space in ",
 Cell[BoxData[
 "\"\<1 2 3 4\>\""], "InlineCode",ExpressionUUID->
  "081865ef-cc4b-40ba-b504-dc086f887f13"],
 " with ",
 Cell[BoxData[
 "\"\<---\>\""], "InlineCode",ExpressionUUID->
  "25dc3468-781a-49f5-ad1b-97a2b4df878f"],
 ".",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "42.1", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"95d016c3-11a9-4a53-a8e4-0e3e3315258d"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[
      BoxData["\<\"1---2---3---4\"\>"], "ExerciseOutput",ExpressionUUID->
       "2e7e37b3-2279-4fc5-9936-9e25c1f527a6"],
      Apply[TextCell, 
       Cell[
        BoxData["\"1---2---3---4\""], "ExerciseOutput", Selectable -> False, 
        Copyable -> False, Editable -> False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"8dbd4fd4-2f57-42d1-ab52-eb2b3763e773"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Get a sorted list of all sequences of 4 digits (representing possible \
dates) in the Wikipedia article on computers.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "42.2", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"59a85369-69ec-4df3-aeac-dbb2a66eda51"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Sample", " ", "expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       RowBox[{"{", 
        RowBox[{"\<\"1000\"\>", ",", "\<\"1235\"\>", ",", "\<\"1357\"\>", 
         ",", "\<\"1357\"\>", ",", "\<\"1500\"\>", ",", "\<\"1595\"\>", 
         ",", "\<\"1613\"\>", ",", "\<\"1620\"\>", ",", "\<\"1630\"\>", 
         ",", "\<\"1770\"\>", ",", "\<\"1833\"\>", ",", "\<\"1872\"\>", 
         ",", "\<\"1872\"\>", ",", "\<\"1876\"\>", ",", "\<\"1876\"\>", 
         ",", "\<\"1888\"\>", ",", "\<\"1901\"\>", ",", "\<\"1906\"\>", 
         ",", "\<\"1920\"\>", ",", "\<\"1927\"\>", ",", "\<\"1930\"\>", 
         ",", "\<\"1931\"\>", ",", "\<\"1934\"\>", ",", "\<\"1936\"\>", 
         ",", "\<\"1936\"\>", ",", "\<\"1938\"\>", ",", "\<\"1939\"\>", 
         ",", "\<\"1941\"\>", ",", "\<\"1942\"\>", ",", "\<\"1943\"\>", 
         ",", "\<\"1943\"\>", ",", "\<\"1943\"\>", ",", "\<\"1944\"\>", 
         ",", "\<\"1945\"\>", ",", "\<\"1945\"\>", ",", "\<\"1945\"\>", 
         ",", "\<\"1945\"\>", ",", "\<\"1947\"\>", ",", "\<\"1947\"\>", 
         ",", "\<\"1947\"\>", ",", "\<\"1948\"\>", ",", "\<\"1950\"\>", 
         ",", "\<\"1950\"\>", ",", "\<\"1951\"\>", ",", "\<\"1951\"\>", 
         ",", "\<\"1952\"\>", ",", "\<\"1953\"\>", ",", "\<\"1953\"\>", 
         ",", "\<\"1955\"\>", ",", "\<\"1955\"\>", ",", "\<\"1955\"\>", 
         ",", "\<\"1957\"\>", ",", "\<\"1958\"\>", ",", "\<\"1958\"\>", 
         ",", "\<\"1959\"\>", ",", "\<\"1970\"\>", ",", "\<\"1970\"\>", 
         ",", "\<\"1990\"\>", ",", "\<\"2000\"\>", ",", "\<\"2000\"\>", 
         ",", "\<\"2013\"\>", ",", "\<\"2400\"\>", ",", "\<\"2400\"\>", 
         ",", "\<\"2468\"\>", ",", "\<\"4004\"\>", ",", "\<\"5000\"\>"}], 
        "}"}]], "ExerciseOutput",ExpressionUUID->
       "80a8cc69-1302-4335-9f15-ad4d39acb581"],
      Apply[TextCell, 
       Cell[
        BoxData[
         RowBox[{"{", 
           
           RowBox[{"\"1000\"", ",", "\"1235\"", ",", "\"1357\"", ",", 
             "\"1357\"", ",", "\"1500\"", ",", "\"1595\"", ",", "\"1613\"", 
             ",", "\"1620\"", ",", "\"1630\"", ",", "\"1770\"", ",", 
             "\"1833\"", ",", "\"1872\"", ",", "\"1872\"", ",", "\"1876\"", 
             ",", "\"1876\"", ",", "\"1888\"", ",", "\"1901\"", ",", 
             "\"1906\"", ",", "\"1920\"", ",", "\"1927\"", ",", "\"1930\"", 
             ",", "\"1931\"", ",", "\"1934\"", ",", "\"1936\"", ",", 
             "\"1936\"", ",", "\"1938\"", ",", "\"1939\"", ",", "\"1941\"", 
             ",", "\"1942\"", ",", "\"1943\"", ",", "\"1943\"", ",", 
             "\"1943\"", ",", "\"1944\"", ",", "\"1945\"", ",", "\"1945\"", 
             ",", "\"1945\"", ",", "\"1945\"", ",", "\"1947\"", ",", 
             "\"1947\"", ",", "\"1947\"", ",", "\"1948\"", ",", "\"1950\"", 
             ",", "\"1950\"", ",", "\"1951\"", ",", "\"1951\"", ",", 
             "\"1952\"", ",", "\"1953\"", ",", "\"1953\"", ",", "\"1955\"", 
             ",", "\"1955\"", ",", "\"1955\"", ",", "\"1957\"", ",", 
             "\"1958\"", ",", "\"1958\"", ",", "\"1959\"", ",", "\"1970\"", 
             ",", "\"1970\"", ",", "\"1990\"", ",", "\"2000\"", ",", 
             "\"2000\"", ",", "\"2013\"", ",", "\"2400\"", ",", "\"2400\"", 
             ",", "\"2468\"", ",", "\"4004\"", ",", "\"5000\""}], "}"}]], 
        "ExerciseOutput", Selectable -> False, Copyable -> False, Editable -> 
        False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"67a9793b-bd46-410a-b4ae-bb31a05b90c1"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Extract \[OpenCurlyDoubleQuote]headings\[CloseCurlyDoubleQuote] in the \
Wikipedia article about computers, as indicated by strings starting and \
ending with ",
 Cell[BoxData[
 "\"\<===\>\""], "InlineCode",ExpressionUUID->
  "fb5a1ea5-3856-42a4-b9f7-0cb47b3ff9e2"],
 ".",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "42.3", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"f752ba63-be45-4362-900b-40e08c2d6eac"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Sample", " ", "expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       RowBox[{"{", 
        RowBox[{"\<\" Pre-twentieth century \"\>", 
         ",", "\<\" First general-purpose computing device \"\>", 
         ",", "\<\" Later Analog computers \"\>", 
         ",", "\<\" Digital computer development \"\>", 
         ",", "\<\"= Electromechanical \"\>", 
         ",", "\<\"= Vacuum tubes and digital electronic circuits \"\>", 
         ",", "\<\"= Stored programs \"\>", ",", "\<\"= Transistors \"\>", 
         ",", "\<\"= Integrated circuits \"\>", 
         ",", "\<\" Mobile computers become dominant \"\>", 
         ",", "\<\" Stored program architecture \"\>", 
         ",", "\<\" Machine code \"\>", ",", "\<\" Programming language \"\>",
          ",", "\<\"= Low-level languages \"\>", 
         ",", "\<\"= High-level languages/Third Generation Language \"\>", 
         ",", "\<\" Fourth Generation Languages \"\>", 
         ",", "\<\" Program design \"\>", ",", "\<\" Bugs \"\>", 
         ",", "\<\" Control unit \"\>", 
         ",", "\<\" Central Processing unit (CPU) \"\>", 
         ",", "\<\" Arithmetic logic unit (ALU) \"\>", 
         ",", "\<\" Memory \"\>", ",", "\<\" Input/output (I/O) \"\>", 
         ",", "\<\" Multitasking \"\>", ",", "\<\" Multiprocessing \"\>", 
         ",", "\<\" Computer architecture paradigms \"\>", 
         ",", "\<\" Unconventional computing \"\>", 
         ",", "\<\" Artificial intelligence \"\>", 
         ",", "\<\" History of computing hardware \"\>", 
         ",", "\<\" Other hardware topics \"\>", ",", "\<\" Firmware \"\>", 
         ",", "\<\" Liveware \"\>", ",", "\<\" Based on uses \"\>", 
         ",", "\<\" Based on sizes \"\>"}], "}"}]], "ExerciseOutput",
       ExpressionUUID->"457e6639-3b4d-4fbb-a109-3b09597d47fc"],
      Apply[TextCell, 
       Cell[
        BoxData[
         RowBox[{"{", 
           RowBox[{
            "\" Pre-twentieth century \"", ",", 
             "\" First general-purpose computing device \"", ",", 
             "\" Later Analog computers \"", ",", 
             "\" Digital computer development \"", ",", 
             "\"= Electromechanical \"", ",", 
             "\"= Vacuum tubes and digital electronic circuits \"", ",", 
             "\"= Stored programs \"", ",", "\"= Transistors \"", ",", 
             "\"= Integrated circuits \"", ",", 
             "\" Mobile computers become dominant \"", ",", 
             "\" Stored program architecture \"", ",", "\" Machine code \"", 
             ",", "\" Programming language \"", ",", 
             "\"= Low-level languages \"", ",", 
             "\"= High-level languages/Third Generation Language \"", ",", 
             "\" Fourth Generation Languages \"", ",", "\" Program design \"",
              ",", "\" Bugs \"", ",", "\" Control unit \"", ",", 
             "\" Central Processing unit (CPU) \"", ",", 
             "\" Arithmetic logic unit (ALU) \"", ",", "\" Memory \"", ",", 
             "\" Input/output (I/O) \"", ",", "\" Multitasking \"", ",", 
             "\" Multiprocessing \"", ",", 
             "\" Computer architecture paradigms \"", ",", 
             "\" Unconventional computing \"", ",", 
             "\" Artificial intelligence \"", ",", 
             "\" History of computing hardware \"", ",", 
             "\" Other hardware topics \"", ",", "\" Firmware \"", ",", 
             "\" Liveware \"", ",", "\" Based on uses \"", ",", 
             "\" Based on sizes \""}], "}"}]], "ExerciseOutput", Selectable -> 
        False, Copyable -> False, Editable -> False, ShowCellBracket -> 
        False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"980e2540-9c24-493f-9caa-7042dac41798"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Use a string template to make a grid of results of the form ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"i", "+", "j"}], "=", 
   StyleBox["...", "GrayPointSix"]}]], "InlineCode",ExpressionUUID->
  "2412443e-5950-4c9b-8f35-bca3cdf09295"],
 " for ",
 Cell[BoxData[
 "i"], "InlineCode",ExpressionUUID->"59a55c1b-5b2c-451c-9dbe-f5cbc4ff365b"],
 " and ",
 Cell[BoxData[
 "j"], "InlineCode",ExpressionUUID->"947d9db1-38f1-4408-a492-32eb7b91518d"],
 " up to 9.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "42.4", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"68a1c274-23d1-49e4-94ba-ad144d272044"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       TagBox[GridBox[{
          {"\<\"1+1=2\"\>", "\<\"1+2=3\"\>", "\<\"1+3=4\"\>", \
"\<\"1+4=5\"\>", "\<\"1+5=6\"\>", "\<\"1+6=7\"\>", "\<\"1+7=8\"\>", \
"\<\"1+8=9\"\>", "\<\"1+9=10\"\>"},
          {"\<\"2+1=3\"\>", "\<\"2+2=4\"\>", "\<\"2+3=5\"\>", \
"\<\"2+4=6\"\>", "\<\"2+5=7\"\>", "\<\"2+6=8\"\>", "\<\"2+7=9\"\>", \
"\<\"2+8=10\"\>", "\<\"2+9=11\"\>"},
          {"\<\"3+1=4\"\>", "\<\"3+2=5\"\>", "\<\"3+3=6\"\>", \
"\<\"3+4=7\"\>", "\<\"3+5=8\"\>", "\<\"3+6=9\"\>", "\<\"3+7=10\"\>", \
"\<\"3+8=11\"\>", "\<\"3+9=12\"\>"},
          {"\<\"4+1=5\"\>", "\<\"4+2=6\"\>", "\<\"4+3=7\"\>", \
"\<\"4+4=8\"\>", "\<\"4+5=9\"\>", "\<\"4+6=10\"\>", "\<\"4+7=11\"\>", \
"\<\"4+8=12\"\>", "\<\"4+9=13\"\>"},
          {"\<\"5+1=6\"\>", "\<\"5+2=7\"\>", "\<\"5+3=8\"\>", \
"\<\"5+4=9\"\>", "\<\"5+5=10\"\>", "\<\"5+6=11\"\>", "\<\"5+7=12\"\>", \
"\<\"5+8=13\"\>", "\<\"5+9=14\"\>"},
          {"\<\"6+1=7\"\>", "\<\"6+2=8\"\>", "\<\"6+3=9\"\>", \
"\<\"6+4=10\"\>", "\<\"6+5=11\"\>", "\<\"6+6=12\"\>", "\<\"6+7=13\"\>", \
"\<\"6+8=14\"\>", "\<\"6+9=15\"\>"},
          {"\<\"7+1=8\"\>", "\<\"7+2=9\"\>", "\<\"7+3=10\"\>", \
"\<\"7+4=11\"\>", "\<\"7+5=12\"\>", "\<\"7+6=13\"\>", "\<\"7+7=14\"\>", \
"\<\"7+8=15\"\>", "\<\"7+9=16\"\>"},
          {"\<\"8+1=9\"\>", "\<\"8+2=10\"\>", "\<\"8+3=11\"\>", "\<\"8+4=12\"\
\>", "\<\"8+5=13\"\>", "\<\"8+6=14\"\>", "\<\"8+7=15\"\>", "\<\"8+8=16\"\>", \
"\<\"8+9=17\"\>"},
          {"\<\"9+1=10\"\>", "\<\"9+2=11\"\>", "\<\"9+3=12\"\>", \
"\<\"9+4=13\"\>", "\<\"9+5=14\"\>", "\<\"9+6=15\"\>", "\<\"9+7=16\"\>", \
"\<\"9+8=17\"\>", "\<\"9+9=18\"\>"}
         },
         AutoDelete->False,
         GridBoxItemSize->{
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
        "Grid"]], "ExerciseOutput",ExpressionUUID->
       "f2226d99-40cd-488b-905a-845cf42673da"],
      Apply[TextCell, 
       Cell[
        BoxData[
         TagBox[
          
          GridBox[{{
            "\"1+1=2\"", "\"1+2=3\"", "\"1+3=4\"", "\"1+4=5\"", "\"1+5=6\"", 
             "\"1+6=7\"", "\"1+7=8\"", "\"1+8=9\"", "\"1+9=10\""}, {
            "\"2+1=3\"", "\"2+2=4\"", "\"2+3=5\"", "\"2+4=6\"", "\"2+5=7\"", 
             "\"2+6=8\"", "\"2+7=9\"", "\"2+8=10\"", "\"2+9=11\""}, {
            "\"3+1=4\"", "\"3+2=5\"", "\"3+3=6\"", "\"3+4=7\"", "\"3+5=8\"", 
             "\"3+6=9\"", "\"3+7=10\"", "\"3+8=11\"", "\"3+9=12\""}, {
            "\"4+1=5\"", "\"4+2=6\"", "\"4+3=7\"", "\"4+4=8\"", "\"4+5=9\"", 
             "\"4+6=10\"", "\"4+7=11\"", "\"4+8=12\"", "\"4+9=13\""}, {
            "\"5+1=6\"", "\"5+2=7\"", "\"5+3=8\"", "\"5+4=9\"", "\"5+5=10\"", 
             "\"5+6=11\"", "\"5+7=12\"", "\"5+8=13\"", "\"5+9=14\""}, {
            "\"6+1=7\"", "\"6+2=8\"", "\"6+3=9\"", "\"6+4=10\"", "\"6+5=11\"",
              "\"6+6=12\"", "\"6+7=13\"", "\"6+8=14\"", "\"6+9=15\""}, {
            "\"7+1=8\"", "\"7+2=9\"", "\"7+3=10\"", "\"7+4=11\"", 
             "\"7+5=12\"", "\"7+6=13\"", "\"7+7=14\"", "\"7+8=15\"", 
             "\"7+9=16\""}, {
            "\"8+1=9\"", "\"8+2=10\"", "\"8+3=11\"", "\"8+4=12\"", 
             "\"8+5=13\"", "\"8+6=14\"", "\"8+7=15\"", "\"8+8=16\"", 
             "\"8+9=17\""}, {
            "\"9+1=10\"", "\"9+2=11\"", "\"9+3=12\"", "\"9+4=13\"", 
             "\"9+5=14\"", "\"9+6=15\"", "\"9+7=16\"", "\"9+8=17\"", 
             "\"9+9=18\""}}, AutoDelete -> False, 
           GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"]], 
        "ExerciseOutput", Selectable -> False, Copyable -> False, Editable -> 
        False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"2fee0f78-b126-47d0-a34b-961d478ae7d3"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Find names of integers below 50 that have an \[OpenCurlyDoubleQuote]i\
\[CloseCurlyDoubleQuote] somewhere before an \[OpenCurlyDoubleQuote]e\
\[CloseCurlyDoubleQuote].",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "42.5", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"e304175a-c338-4c2c-baa3-71a727d93b7e"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       RowBox[{"{", 
        RowBox[{"\<\"five\"\>", ",", "\<\"nine\"\>", ",", "\<\"thirteen\"\>", 
         ",", "\<\"fifteen\"\>", ",", "\<\"sixteen\"\>", 
         ",", "\<\"eighteen\"\>", ",", "\<\"nineteen\"\>", 
         ",", "\<\"twenty\[Hyphen]five\"\>", 
         ",", "\<\"twenty\[Hyphen]nine\"\>", 
         ",", "\<\"thirty\[Hyphen]one\"\>", 
         ",", "\<\"thirty\[Hyphen]three\"\>", 
         ",", "\<\"thirty\[Hyphen]five\"\>", 
         ",", "\<\"thirty\[Hyphen]seven\"\>", 
         ",", "\<\"thirty\[Hyphen]eight\"\>", 
         ",", "\<\"thirty\[Hyphen]nine\"\>", 
         ",", "\<\"forty\[Hyphen]five\"\>", 
         ",", "\<\"forty\[Hyphen]nine\"\>"}], "}"}]], "ExerciseOutput",
       ExpressionUUID->"36a20f0c-c9e7-4d75-9ed8-97c865ff5a3a"],
      Apply[TextCell, 
       Cell[
        BoxData[
         RowBox[{"{", 
           
           RowBox[{"\"five\"", ",", "\"nine\"", ",", "\"thirteen\"", ",", 
             "\"fifteen\"", ",", "\"sixteen\"", ",", "\"eighteen\"", ",", 
             "\"nineteen\"", ",", "\"twenty\[Hyphen]five\"", ",", 
             "\"twenty\[Hyphen]nine\"", ",", "\"thirty\[Hyphen]one\"", ",", 
             "\"thirty\[Hyphen]three\"", ",", "\"thirty\[Hyphen]five\"", ",", 
             "\"thirty\[Hyphen]seven\"", ",", "\"thirty\[Hyphen]eight\"", ",",
              "\"thirty\[Hyphen]nine\"", ",", "\"forty\[Hyphen]five\"", ",", 
             "\"forty\[Hyphen]nine\""}], "}"}]], "ExerciseOutput", Selectable -> 
        False, Copyable -> False, Editable -> False, ShowCellBracket -> 
        False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"1dea5220-f073-4670-9fb2-f96933f562bc"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Make any 2-letter word uppercase in the first sentence from the Wikipedia \
article on computers.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "42.6", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"584b32b9-3d38-457f-a9a4-46bff699f2e0"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Sample", " ", "expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[
      BoxData["\<\"A computer IS a general-purpose device that can BE \
programmed TO carry out a set OF arithmetic OR logical operations \
automatically.\"\>"], "ExerciseOutput",ExpressionUUID->
       "66637203-2b3b-42a2-9c72-d3944006f49d"],
      Apply[TextCell, 
       Cell[
        BoxData[
        "\"A computer IS a general-purpose device that can BE programmed TO \
carry out a set OF arithmetic OR logical operations automatically.\""], 
        "ExerciseOutput", Selectable -> False, Copyable -> False, Editable -> 
        False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"5874400e-cab6-4afe-b846-ade5f0285de7"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Make a labeled bar chart of the number of countries whose ",
 ButtonBox["TextString",
  BaseStyle->"Link"],
 " names start with each possible letter.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "42.7", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"c2ecd62a-a38b-4f6c-abf2-01a2938876d5"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       GraphicsBox[{{{{{
             {Opacity[0], PointBox[{0.036279069767441774`, 0.}]}}}}}, {{}, {{{{
              {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
               0.5249999999999999], Thickness[Small]}], {{{{
                   {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{
                    Opacity[0.5249999999999999], Thickness[Small]}], 
                    TagBox[
                    TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{0.5348837209302325, 0.}, {
                    1.4651162790697674`, 14.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{21.632859025963327`, 
                    36.83968556693968}, {8.087041005343124, 
                    119.46482175935049`}}],
                    StatusArea[#, 14]& ,
                    TagBoxNote->"14"],
                    StyleBox["14", {}, StripOnInput -> False]],
                    Annotation[#, 
                    Style[14, {}], "Tooltip"]& ]}}}}}, {{{{
                   {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{
                    Opacity[0.5249999999999999], Thickness[Small]}], 
                    TagBox[
                    TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{1.5348837209302326`, 0.}, {
                    2.4651162790697674`, 19.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{37.44269755751291, 
                    52.64952409848926}, {-31.51216640680238, 
                    119.46482175935049`}}],
                    StatusArea[#, 19]& ,
                    TagBoxNote->"19"],
                    StyleBox["19", {}, StripOnInput -> False]],
                    Annotation[#, 
                    Style[19, {}], "Tooltip"]& ]}}}}}, {{{{
                   {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{
                    Opacity[0.5249999999999999], Thickness[Small]}], 
                    TagBox[
                    TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{2.5348837209302326`, 0.}, {
                    3.4651162790697674`, 20.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{53.25253608906249, 
                    68.45936263003884}, {-39.43200788923147, 
                    119.46482175935049`}}],
                    StatusArea[#, 20]& ,
                    TagBoxNote->"20"],
                    StyleBox["20", {}, StripOnInput -> False]],
                    Annotation[#, 
                    Style[20, {}], "Tooltip"]& ]}}}}}, {{{{
                   {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{
                    Opacity[0.5249999999999999], Thickness[Small]}], 
                    TagBox[
                    TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{3.5348837209302326`, 0.}, {
                    4.465116279069767, 5.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{69.06237462061208, 84.26920116158843}, {
                    79.365614347205, 119.46482175935049`}}],
                    StatusArea[#, 5]& ,
                    TagBoxNote->"5"],
                    StyleBox["5", {}, StripOnInput -> False]],
                    Annotation[#, 
                    Style[5, {}], "Tooltip"]& ]}}}}}, {{{{
                   {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{
                    Opacity[0.5249999999999999], Thickness[Small]}], 
                    TagBox[
                    TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{4.534883720930233, 0.}, {5.465116279069767, 
                    8.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{84.87221315216163, 
                    100.07903969313801`}, {55.606089899917706`, 
                    119.46482175935049`}}],
                    StatusArea[#, 8]& ,
                    TagBoxNote->"8"],
                    StyleBox["8", {}, StripOnInput -> False]],
                    Annotation[#, 
                    Style[8, {}], "Tooltip"]& ]}}}}}, {{{{
                   {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{
                    Opacity[0.5249999999999999], Thickness[Small]}], 
                    TagBox[
                    TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{5.534883720930233, 0.}, {6.465116279069767, 
                    7.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{100.68205168371122`, 
                    115.88887822468757`}, {63.525931382346805`, 
                    119.46482175935049`}}],
                    StatusArea[#, 7]& ,
                    TagBoxNote->"7"],
                    StyleBox["7", {}, StripOnInput -> False]],
                    Annotation[#, 
                    Style[7, {}], "Tooltip"]& ]}}}}}, {{{{
                   {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{
                    Opacity[0.5249999999999999], Thickness[Small]}], 
                    TagBox[
                    TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{6.534883720930233, 0.}, {7.465116279069767, 
                    17.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{116.49189021526081`, 
                    131.69871675623716`}, {-15.672483441944166`, 
                    119.46482175935049`}}],
                    StatusArea[#, 17]& ,
                    TagBoxNote->"17"],
                    StyleBox["17", {}, StripOnInput -> False]],
                    Annotation[#, 
                    Style[17, {}], "Tooltip"]& ]}}}}}, {{{{
                   {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{
                    Opacity[0.5249999999999999], Thickness[Small]}], 
                    TagBox[
                    TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{7.534883720930233, 0.}, {8.465116279069768, 
                    4.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{132.3017287468104, 
                    147.50855528778678`}, {87.28545582963409, 
                    119.46482175935049`}}],
                    StatusArea[#, 4]& ,
                    TagBoxNote->"4"],
                    StyleBox["4", {}, StripOnInput -> False]],
                    Annotation[#, 
                    Style[4, {}], "Tooltip"]& ]}}}}}, {{{{
                   {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{
                    Opacity[0.5249999999999999], Thickness[Small]}], 
                    TagBox[
                    TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{8.534883720930234, 0.}, {9.465116279069768, 
                    10.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{148.11156727835998`, 
                    163.31839381933634`}, {39.76640693505951, 
                    119.46482175935049`}}],
                    StatusArea[#, 10]& ,
                    TagBoxNote->"10"],
                    StyleBox["10", {}, StripOnInput -> False]],
                    Annotation[#, 
                    Style[10, {}], "Tooltip"]& ]}}}}}, {{{{
                   {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{
                    Opacity[0.5249999999999999], Thickness[Small]}], 
                    TagBox[
                    TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{9.534883720930234, 0.}, {
                    10.465116279069768`, 4.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{163.92140580990957`, 
                    179.12823235088592`}, {87.28545582963409, 
                    119.46482175935049`}}],
                    StatusArea[#, 4]& ,
                    TagBoxNote->"4"],
                    StyleBox["4", {}, StripOnInput -> False]],
                    Annotation[#, 
                    Style[4, {}], "Tooltip"]& ]}}}}}, {{{{
                   {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{
                    Opacity[0.5249999999999999], Thickness[Small]}], 
                    TagBox[
                    TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{10.534883720930234`, 0.}, {
                    11.465116279069768`, 6.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{179.73124434145916`, 
                    194.9380708824355}, {71.4457728647759, 
                    119.46482175935049`}}],
                    StatusArea[#, 6]& ,
                    TagBoxNote->"6"],
                    StyleBox["6", {}, StripOnInput -> False]],
                    Annotation[#, 
                    Style[6, {}], "Tooltip"]& ]}}}}}, {{{{
                   {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{
                    Opacity[0.5249999999999999], Thickness[Small]}], 
                    TagBox[
                    TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{11.534883720930234`, 0.}, {
                    12.465116279069768`, 9.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{195.54108287300872`, 
                    210.7479094139851}, {47.68624841748861, 
                    119.46482175935049`}}],
                    StatusArea[#, 9]& ,
                    TagBoxNote->"9"],
                    StyleBox["9", {}, StripOnInput -> False]],
                    Annotation[#, 
                    Style[9, {}], "Tooltip"]& ]}}}}}, {{{{
                   {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{
                    Opacity[0.5249999999999999], Thickness[Small]}], 
                    TagBox[
                    TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{12.534883720930234`, 0.}, {
                    13.465116279069768`, 23.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{211.3509214045583, 
                    226.55774794553466`}, {-63.19153233651875, 
                    119.46482175935049`}}],
                    StatusArea[#, 23]& ,
                    TagBoxNote->"23"],
                    StyleBox["23", {}, StripOnInput -> False]],
                    Annotation[#, 
                    Style[23, {}], "Tooltip"]& ]}}}}}, {{{{
                   {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{
                    Opacity[0.5249999999999999], Thickness[Small]}], 
                    TagBox[
                    TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{13.534883720930234`, 0.}, {
                    14.465116279069768`, 14.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{227.1607599361079, 
                    242.36758647708425`}, {8.087041005343124, 
                    119.46482175935049`}}],
                    StatusArea[#, 14]& ,
                    TagBoxNote->"14"],
                    StyleBox["14", {}, StripOnInput -> False]],
                    Annotation[#, 
                    Style[14, {}], "Tooltip"]& ]}}}}}, {{{{
                   {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{
                    Opacity[0.5249999999999999], Thickness[Small]}], 
                    TagBox[
                    TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{14.534883720930234`, 0.}, {
                    15.465116279069768`, 1.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{242.97059846765748`, 
                    258.1774250086338}, {111.0449802769214, 
                    119.46482175935049`}}],
                    StatusArea[#, 1]& ,
                    TagBoxNote->"1"],
                    StyleBox["1", {}, StripOnInput -> False]],
                    Annotation[#, 
                    Style[1, {}], "Tooltip"]& ]}}}}}, {{{{
                   {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{
                    Opacity[0.5249999999999999], Thickness[Small]}], 
                    TagBox[
                    TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{15.534883720930234`, 0.}, {
                    16.46511627906977, 11.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{258.78043699920704`, 
                    273.9872635401834}, {31.846565452630415`, 
                    119.46482175935049`}}],
                    StatusArea[#, 11]& ,
                    TagBoxNote->"11"],
                    StyleBox["11", {}, StripOnInput -> False]],
                    Annotation[#, 
                    Style[11, {}], "Tooltip"]& ]}}}}}, {{{{
                   {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{
                    Opacity[0.5249999999999999], Thickness[Small]}], 
                    TagBox[
                    TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{16.53488372093023, 0.}, {17.46511627906977, 
                    1.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{274.59027553075657`, 
                    289.797102071733}, {111.0449802769214, 
                    119.46482175935049`}}],
                    StatusArea[#, 1]& ,
                    TagBoxNote->"1"],
                    StyleBox["1", {}, StripOnInput -> False]],
                    Annotation[#, 
                    Style[1, {}], "Tooltip"]& ]}}}}}, {{{{
                   {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{
                    Opacity[0.5249999999999999], Thickness[Small]}], 
                    TagBox[
                    TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{17.53488372093023, 0.}, {18.46511627906977, 
                    5.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{290.40011406230616`, 
                    305.60694060328257`}, {79.365614347205, 
                    119.46482175935049`}}],
                    StatusArea[#, 5]& ,
                    TagBoxNote->"5"],
                    StyleBox["5", {}, StripOnInput -> False]],
                    Annotation[#, 
                    Style[5, {}], "Tooltip"]& ]}}}}}, {{{{
                   {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{
                    Opacity[0.5249999999999999], Thickness[Small]}], 
                    TagBox[
                    TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{18.53488372093023, 0.}, {19.46511627906977, 
                    31.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{306.20995259385575`, 
                    321.4167791348321}, {-126.55026419595154`, 
                    119.46482175935049`}}],
                    StatusArea[#, 31]& ,
                    TagBoxNote->"31"],
                    StyleBox["31", {}, StripOnInput -> False]],
                    Annotation[#, 
                    Style[31, {}], "Tooltip"]& ]}}}}}, {{{{
                   {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{
                    Opacity[0.5249999999999999], Thickness[Small]}], 
                    TagBox[
                    TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{19.53488372093023, 0.}, {20.46511627906977, 
                    13.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{322.01979112540533`, 
                    337.2266176663817}, {16.006882487772216`, 
                    119.46482175935049`}}],
                    StatusArea[#, 13]& ,
                    TagBoxNote->"13"],
                    StyleBox["13", {}, StripOnInput -> False]],
                    Annotation[#, 
                    Style[13, {}], "Tooltip"]& ]}}}}}, {{{{
                   {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{
                    Opacity[0.5249999999999999], Thickness[Small]}], 
                    TagBox[
                    TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{20.53488372093023, 0.}, {21.46511627906977, 
                    8.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{337.8296296569549, 353.0364561979313}, {
                    55.606089899917706`, 119.46482175935049`}}],
                    StatusArea[#, 8]& ,
                    TagBoxNote->"8"],
                    StyleBox["8", {}, StripOnInput -> False]],
                    Annotation[#, 
                    Style[8, {}], "Tooltip"]& ]}}}}}, {{{{
                   {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{
                    Opacity[0.5249999999999999], Thickness[Small]}], 
                    TagBox[
                    TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{21.53488372093023, 0.}, {22.46511627906977, 
                    4.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{353.63946818850445`, 
                    368.84629472948086`}, {87.28545582963409, 
                    119.46482175935049`}}],
                    StatusArea[#, 4]& ,
                    TagBoxNote->"4"],
                    StyleBox["4", {}, StripOnInput -> False]],
                    Annotation[#, 
                    Style[4, {}], "Tooltip"]& ]}}}}}, {{{{
                   {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{
                    Opacity[0.5249999999999999], Thickness[Small]}], 
                    TagBox[
                    TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{22.53488372093023, 0.}, {23.46511627906977, 
                    3.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{369.44930672005404`, 
                    384.65613326103045`}, {95.2052973120632, 
                    119.46482175935049`}}],
                    StatusArea[#, 3]& ,
                    TagBoxNote->"3"],
                    StyleBox["3", {}, StripOnInput -> False]],
                    Annotation[#, 
                    Style[3, {}], "Tooltip"]& ]}}}}}, {{{{
                   {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{
                    Opacity[0.5249999999999999], Thickness[Small]}], 
                    TagBox[
                    TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{23.53488372093023, 0.}, {24.46511627906977, 
                    1.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{385.2591452516036, 
                    400.46597179258004`}, {111.0449802769214, 
                    119.46482175935049`}}],
                    StatusArea[#, 1]& ,
                    TagBoxNote->"1"],
                    StyleBox["1", {}, StripOnInput -> False]],
                    Annotation[#, 
                    Style[1, {}], "Tooltip"]& ]}}}}}, {{{{
                   {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{
                    Opacity[0.5249999999999999], Thickness[Small]}], 
                    TagBox[
                    TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{24.53488372093023, 0.}, {25.46511627906977, 
                    2.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{401.0689837831532, 416.2758103241296}, {
                    103.12513879449229`, 119.46482175935049`}}],
                    StatusArea[#, 2]& ,
                    TagBoxNote->"2"],
                    StyleBox["2", {}, StripOnInput -> False]],
                    Annotation[#, 
                    Style[2, {}], "Tooltip"]& ]}}}}}}}}}}, {}, {}}, {}, {}, 
         StyleBox[{{{{{
               {Thickness[Tiny], 
                LineBox[{{0.036279069767441774`, 0.}, {25.973693023255816`, 
                 0.}}], 
                StyleBox[{}, "GraphicsLabel",
                 StripOnInput->False]}}}}}, 
           StyleBox[{{{{{
                 {Thickness[Tiny], 
                  LineBox[{{0.5348837209302325, 0.}, 
                    Offset[{-1.102182119232618*^-15, -6.}, {
                    0.5348837209302325, 0.}]}], 
                  LineBox[{{25.46511627906977, 0.}, 
                    Offset[{-1.102182119232618*^-15, -6.}, {25.46511627906977,
                     0.}]}], {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {
                    LineBox[{{1.4651162790697674`, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    1.4651162790697674`, 0.}]}], 
                    LineBox[{{1.5348837209302326`, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    1.5348837209302326`, 0.}]}], 
                    LineBox[{{2.4651162790697674`, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    2.4651162790697674`, 0.}]}], 
                    LineBox[{{2.5348837209302326`, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    2.5348837209302326`, 0.}]}], 
                    LineBox[{{3.4651162790697674`, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    3.4651162790697674`, 0.}]}], 
                    LineBox[{{3.5348837209302326`, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    3.5348837209302326`, 0.}]}], 
                    LineBox[{{4.465116279069767, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {4.465116279069767,
                     0.}]}], 
                    LineBox[{{4.534883720930233, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {4.534883720930233,
                     0.}]}], 
                    LineBox[{{5.465116279069767, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {5.465116279069767,
                     0.}]}], 
                    LineBox[{{5.534883720930233, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {5.534883720930233,
                     0.}]}], 
                    LineBox[{{6.465116279069767, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {6.465116279069767,
                     0.}]}], 
                    LineBox[{{6.534883720930233, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {6.534883720930233,
                     0.}]}], 
                    LineBox[{{7.465116279069767, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {7.465116279069767,
                     0.}]}], 
                    LineBox[{{7.534883720930233, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {7.534883720930233,
                     0.}]}], 
                    LineBox[{{8.465116279069768, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {8.465116279069768,
                     0.}]}], 
                    LineBox[{{8.534883720930232, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {8.534883720930232,
                     0.}]}], 
                    LineBox[{{9.465116279069766, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {9.465116279069766,
                     0.}]}], 
                    LineBox[{{9.534883720930232, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {9.534883720930232,
                     0.}]}], 
                    LineBox[{{10.465116279069766`, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    10.465116279069766`, 0.}]}], 
                    LineBox[{{10.534883720930232`, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    10.534883720930232`, 0.}]}], 
                    LineBox[{{11.465116279069766`, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    11.465116279069766`, 0.}]}], 
                    LineBox[{{11.534883720930232`, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    11.534883720930232`, 0.}]}], 
                    LineBox[{{12.465116279069766`, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    12.465116279069766`, 0.}]}], 
                    LineBox[{{12.534883720930232`, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    12.534883720930232`, 0.}]}], 
                    LineBox[{{13.465116279069766`, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    13.465116279069766`, 0.}]}], 
                    LineBox[{{13.534883720930232`, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    13.534883720930232`, 0.}]}], 
                    LineBox[{{14.465116279069766`, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    14.465116279069766`, 0.}]}], 
                    LineBox[{{14.534883720930232`, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    14.534883720930232`, 0.}]}], 
                    LineBox[{{15.465116279069766`, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    15.465116279069766`, 0.}]}], 
                    LineBox[{{15.534883720930232`, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    15.534883720930232`, 0.}]}], 
                    LineBox[{{16.46511627906977, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {16.46511627906977,
                     0.}]}], 
                    LineBox[{{16.53488372093023, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {16.53488372093023,
                     0.}]}], 
                    LineBox[{{17.46511627906977, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {17.46511627906977,
                     0.}]}], 
                    LineBox[{{17.53488372093023, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {17.53488372093023,
                     0.}]}], 
                    LineBox[{{18.46511627906977, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {18.46511627906977,
                     0.}]}], 
                    LineBox[{{18.53488372093023, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {18.53488372093023,
                     0.}]}], 
                    LineBox[{{19.46511627906977, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {19.46511627906977,
                     0.}]}], 
                    LineBox[{{19.53488372093023, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {19.53488372093023,
                     0.}]}], 
                    LineBox[{{20.46511627906977, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {20.46511627906977,
                     0.}]}], 
                    LineBox[{{20.53488372093023, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {20.53488372093023,
                     0.}]}], 
                    LineBox[{{21.46511627906977, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {21.46511627906977,
                     0.}]}], 
                    LineBox[{{21.53488372093023, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {21.53488372093023,
                     0.}]}], 
                    LineBox[{{22.46511627906977, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {22.46511627906977,
                     0.}]}], 
                    LineBox[{{22.53488372093023, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {22.53488372093023,
                     0.}]}], 
                    LineBox[{{23.46511627906977, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {23.46511627906977,
                     0.}]}], 
                    LineBox[{{23.53488372093023, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {23.53488372093023,
                     0.}]}], 
                    LineBox[{{24.46511627906977, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {24.46511627906977,
                     0.}]}], 
                    LineBox[{{24.53488372093023, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {24.53488372093023,
                     0.}]}]}, {}}}}}}}, 
             StyleBox[{{{{
                  {Thickness[Tiny], 
                   InsetBox["\<\"A\"\>", Offset[{0., -2.}, {1., 0.}], {0, 1}, 
                    Automatic, {1, 0}], 
                   InsetBox["\<\"B\"\>", Offset[{0., -2.}, {2., 0.}], {0, 1}, 
                    Automatic, {1, 0}], 
                   InsetBox["\<\"C\"\>", Offset[{0., -2.}, {3., 0.}], {0, 1}, 
                    Automatic, {1, 0}], 
                   InsetBox["\<\"D\"\>", Offset[{0., -2.}, {4., 0.}], {0, 1}, 
                    Automatic, {1, 0}], 
                   InsetBox["\<\"E\"\>", Offset[{0., -2.}, {5., 0.}], {0, 1}, 
                    Automatic, {1, 0}], 
                   InsetBox["\<\"F\"\>", Offset[{0., -2.}, {6., 0.}], {0, 1}, 
                    Automatic, {1, 0}], 
                   InsetBox["\<\"G\"\>", Offset[{0., -2.}, {7., 0.}], {0, 1}, 
                    Automatic, {1, 0}], 
                   InsetBox["\<\"H\"\>", Offset[{0., -2.}, {8., 0.}], {0, 1}, 
                    Automatic, {1, 0}], 
                   InsetBox["\<\"I\"\>", Offset[{0., -2.}, {9., 0.}], {0, 1}, 
                    Automatic, {1, 0}], 
                   InsetBox["\<\"J\"\>", Offset[{0., -2.}, {10., 0.}], {0, 1},
                     Automatic, {1, 0}], 
                   InsetBox["\<\"K\"\>", Offset[{0., -2.}, {11., 0.}], {0, 1},
                     Automatic, {1, 0}], 
                   InsetBox["\<\"L\"\>", Offset[{0., -2.}, {12., 0.}], {0, 1},
                     Automatic, {1, 0}], 
                   InsetBox["\<\"M\"\>", Offset[{0., -2.}, {13., 0.}], {0, 1},
                     Automatic, {1, 0}], 
                   InsetBox["\<\"N\"\>", Offset[{0., -2.}, {14., 0.}], {0, 1},
                     Automatic, {1, 0}], 
                   InsetBox["\<\"O\"\>", Offset[{0., -2.}, {15., 0.}], {0, 1},
                     Automatic, {1, 0}], 
                   InsetBox["\<\"P\"\>", Offset[{0., -2.}, {16., 0.}], {0, 1},
                     Automatic, {1, 0}], 
                   InsetBox["\<\"Q\"\>", Offset[{0., -2.}, {17., 0.}], {0, 1},
                     Automatic, {1, 0}], 
                   InsetBox["\<\"R\"\>", Offset[{0., -2.}, {18., 0.}], {0, 1},
                     Automatic, {1, 0}], 
                   InsetBox["\<\"S\"\>", Offset[{0., -2.}, {19., 0.}], {0, 1},
                     Automatic, {1, 0}], 
                   InsetBox["\<\"T\"\>", Offset[{0., -2.}, {20., 0.}], {0, 1},
                     Automatic, {1, 0}], 
                   InsetBox["\<\"U\"\>", Offset[{0., -2.}, {21., 0.}], {0, 1},
                     Automatic, {1, 0}], 
                   InsetBox["\<\"V\"\>", Offset[{0., -2.}, {22., 0.}], {0, 1},
                     Automatic, {1, 0}], 
                   InsetBox["\<\"W\"\>", Offset[{0., -2.}, {23., 0.}], {0, 1},
                     Automatic, {1, 0}], 
                   InsetBox["\<\"Y\"\>", Offset[{0., -2.}, {24., 0.}], {0, 1},
                     Automatic, {1, 0}], 
                   InsetBox["\<\"Z\"\>", Offset[{0., -2.}, {25., 0.}], {0, 1},
                     Automatic, {1, 0}]}}}}}, "GraphicsLabel",
              StripOnInput->False]}, "GraphicsTicks",
            StripOnInput->False]}, "GraphicsAxes",
          StripOnInput->False,
          Antialiasing->False]},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{False, True},
        AxesLabel->{None, None},
        AxesOrigin->{0.036279069767441774`, 0.},
        CoordinatesToolOptions:>{"DisplayFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& )},
        FrameLabel->{{None, None}, {None, None}},
        FrameTicks->{{Automatic, Automatic}, {{{1., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {1., 
             FormBox["\"A\"", TraditionalForm], 0}, {2., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {2., 
             FormBox["\"B\"", TraditionalForm], 0}, {3., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {3., 
             FormBox["\"C\"", TraditionalForm], 0}, {4., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {4., 
             FormBox["\"D\"", TraditionalForm], 0}, {5., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {5., 
             FormBox["\"E\"", TraditionalForm], 0}, {6., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {6., 
             FormBox["\"F\"", TraditionalForm], 0}, {7., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {7., 
             FormBox["\"G\"", TraditionalForm], 0}, {8., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {8., 
             FormBox["\"H\"", TraditionalForm], 0}, {9., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {9., 
             FormBox["\"I\"", TraditionalForm], 0}, {10., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {10., 
             FormBox["\"J\"", TraditionalForm], 0}, {11., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {11., 
             FormBox["\"K\"", TraditionalForm], 0}, {12., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {12., 
             FormBox["\"L\"", TraditionalForm], 0}, {13., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {13., 
             FormBox["\"M\"", TraditionalForm], 0}, {14., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {14., 
             FormBox["\"N\"", TraditionalForm], 0}, {15., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {15., 
             FormBox["\"O\"", TraditionalForm], 0}, {16., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {16., 
             FormBox["\"P\"", TraditionalForm], 0}, {17., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {17., 
             FormBox["\"Q\"", TraditionalForm], 0}, {18., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {18., 
             FormBox["\"R\"", TraditionalForm], 0}, {19., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {19., 
             FormBox["\"S\"", TraditionalForm], 0}, {20., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {20., 
             FormBox["\"T\"", TraditionalForm], 0}, {21., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {21., 
             FormBox["\"U\"", TraditionalForm], 0}, {22., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {22., 
             FormBox["\"V\"", TraditionalForm], 0}, {23., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {23., 
             FormBox["\"W\"", TraditionalForm], 0}, {24., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {24., 
             FormBox["\"Y\"", TraditionalForm], 0}, {25., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {25., 
             FormBox["\"Z\"", TraditionalForm], 0}}, {{1., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {2., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {3., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {4., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {5., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {6., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {7., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {8., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {9., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {10., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {11., 
             FormBox[
              InterpretationBox[
               StyleBox[
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {12., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {13., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {14., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {15., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {16., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {17., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {18., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {19., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {20., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {21., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {22., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {23., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {24., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {25., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}}}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        ImageSize->{433.609375, Automatic},
        PlotRange->{{All, All}, {All, All}},
        PlotRangePadding->{{
           Scaled[0.02], 
           Scaled[0.02]}, {
           Scaled[0.02], 
           Scaled[0.05]}},
        Ticks->{None, Automatic}]], "ExerciseOutput",ExpressionUUID->
       "e3f2ee32-6778-4007-aa8d-8f32ad1e6b19"],
      Apply[TextCell, 
       Cell[
        BoxData[
         GraphicsBox[{{{
             Opacity[0], 
             PointBox[{0.036279069767441774`, 0.}]}}, {{}, {{
              RGBColor[0.982864, 0.7431472, 0.3262672], 
              EdgeForm[{
                Opacity[0.5249999999999999], 
                Thickness[Small]}], {{
                RGBColor[0.982864, 0.7431472, 0.3262672], 
                EdgeForm[{
                  Opacity[0.5249999999999999], 
                  Thickness[Small]}], 
                TagBox[
                 TooltipBox[
                  TagBox[
                   DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{0.5348837209302325, 0.}, {
                    1.4651162790697674`, 14.}, "RoundingRadius" -> 0]}, 
                    ImageSizeCache -> {{21.632859025963327`, 
                    36.83968556693968}, {8.087041005343124, 
                    119.46482175935049`}}], StatusArea[#, 14]& , TagBoxNote -> 
                   "14"], 
                  StyleBox["14", {}, StripOnInput -> False]], Annotation[#, 
                  Style[14, {}], "Tooltip"]& ]}}, {{
                RGBColor[0.982864, 0.7431472, 0.3262672], 
                EdgeForm[{
                  Opacity[0.5249999999999999], 
                  Thickness[Small]}], 
                TagBox[
                 TooltipBox[
                  TagBox[
                   DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{1.5348837209302326`, 0.}, {
                    2.4651162790697674`, 19.}, "RoundingRadius" -> 0]}, 
                    ImageSizeCache -> {{37.44269755751291, 
                    52.64952409848926}, {-31.51216640680238, 
                    119.46482175935049`}}], StatusArea[#, 19]& , TagBoxNote -> 
                   "19"], 
                  StyleBox["19", {}, StripOnInput -> False]], Annotation[#, 
                  Style[19, {}], "Tooltip"]& ]}}, {{
                RGBColor[0.982864, 0.7431472, 0.3262672], 
                EdgeForm[{
                  Opacity[0.5249999999999999], 
                  Thickness[Small]}], 
                TagBox[
                 TooltipBox[
                  TagBox[
                   DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{2.5348837209302326`, 0.}, {
                    3.4651162790697674`, 20.}, "RoundingRadius" -> 0]}, 
                    ImageSizeCache -> {{53.25253608906249, 
                    68.45936263003884}, {-39.43200788923147, 
                    119.46482175935049`}}], StatusArea[#, 20]& , TagBoxNote -> 
                   "20"], 
                  StyleBox["20", {}, StripOnInput -> False]], Annotation[#, 
                  Style[20, {}], "Tooltip"]& ]}}, {{
                RGBColor[0.982864, 0.7431472, 0.3262672], 
                EdgeForm[{
                  Opacity[0.5249999999999999], 
                  Thickness[Small]}], 
                TagBox[
                 TooltipBox[
                  TagBox[
                   DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{3.5348837209302326`, 0.}, {
                    4.465116279069767, 5.}, "RoundingRadius" -> 0]}, 
                    ImageSizeCache -> {{69.06237462061208, 
                    84.26920116158843}, {79.365614347205, 
                    119.46482175935049`}}], StatusArea[#, 5]& , TagBoxNote -> 
                   "5"], 
                  StyleBox["5", {}, StripOnInput -> False]], Annotation[#, 
                  Style[5, {}], "Tooltip"]& ]}}, {{
                RGBColor[0.982864, 0.7431472, 0.3262672], 
                EdgeForm[{
                  Opacity[0.5249999999999999], 
                  Thickness[Small]}], 
                TagBox[
                 TooltipBox[
                  TagBox[
                   DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{4.534883720930233, 0.}, {5.465116279069767, 
                    8.}, "RoundingRadius" -> 0]}, 
                    ImageSizeCache -> {{84.87221315216163, 
                    100.07903969313801`}, {55.606089899917706`, 
                    119.46482175935049`}}], StatusArea[#, 8]& , TagBoxNote -> 
                   "8"], 
                  StyleBox["8", {}, StripOnInput -> False]], Annotation[#, 
                  Style[8, {}], "Tooltip"]& ]}}, {{
                RGBColor[0.982864, 0.7431472, 0.3262672], 
                EdgeForm[{
                  Opacity[0.5249999999999999], 
                  Thickness[Small]}], 
                TagBox[
                 TooltipBox[
                  TagBox[
                   DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{5.534883720930233, 0.}, {6.465116279069767, 
                    7.}, "RoundingRadius" -> 0]}, 
                    ImageSizeCache -> {{100.68205168371122`, 
                    115.88887822468757`}, {63.525931382346805`, 
                    119.46482175935049`}}], StatusArea[#, 7]& , TagBoxNote -> 
                   "7"], 
                  StyleBox["7", {}, StripOnInput -> False]], Annotation[#, 
                  Style[7, {}], "Tooltip"]& ]}}, {{
                RGBColor[0.982864, 0.7431472, 0.3262672], 
                EdgeForm[{
                  Opacity[0.5249999999999999], 
                  Thickness[Small]}], 
                TagBox[
                 TooltipBox[
                  TagBox[
                   DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{6.534883720930233, 0.}, {7.465116279069767, 
                    17.}, "RoundingRadius" -> 0]}, 
                    ImageSizeCache -> {{116.49189021526081`, 
                    131.69871675623716`}, {-15.672483441944166`, 
                    119.46482175935049`}}], StatusArea[#, 17]& , TagBoxNote -> 
                   "17"], 
                  StyleBox["17", {}, StripOnInput -> False]], Annotation[#, 
                  Style[17, {}], "Tooltip"]& ]}}, {{
                RGBColor[0.982864, 0.7431472, 0.3262672], 
                EdgeForm[{
                  Opacity[0.5249999999999999], 
                  Thickness[Small]}], 
                TagBox[
                 TooltipBox[
                  TagBox[
                   DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{7.534883720930233, 0.}, {8.465116279069768, 
                    4.}, "RoundingRadius" -> 0]}, 
                    ImageSizeCache -> {{132.3017287468104, 
                    147.50855528778678`}, {87.28545582963409, 
                    119.46482175935049`}}], StatusArea[#, 4]& , TagBoxNote -> 
                   "4"], 
                  StyleBox["4", {}, StripOnInput -> False]], Annotation[#, 
                  Style[4, {}], "Tooltip"]& ]}}, {{
                RGBColor[0.982864, 0.7431472, 0.3262672], 
                EdgeForm[{
                  Opacity[0.5249999999999999], 
                  Thickness[Small]}], 
                TagBox[
                 TooltipBox[
                  TagBox[
                   DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{8.534883720930234, 0.}, {9.465116279069768, 
                    10.}, "RoundingRadius" -> 0]}, 
                    ImageSizeCache -> {{148.11156727835998`, 
                    163.31839381933634`}, {39.76640693505951, 
                    119.46482175935049`}}], StatusArea[#, 10]& , TagBoxNote -> 
                   "10"], 
                  StyleBox["10", {}, StripOnInput -> False]], Annotation[#, 
                  Style[10, {}], "Tooltip"]& ]}}, {{
                RGBColor[0.982864, 0.7431472, 0.3262672], 
                EdgeForm[{
                  Opacity[0.5249999999999999], 
                  Thickness[Small]}], 
                TagBox[
                 TooltipBox[
                  TagBox[
                   DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{9.534883720930234, 0.}, {
                    10.465116279069768`, 4.}, "RoundingRadius" -> 0]}, 
                    ImageSizeCache -> {{163.92140580990957`, 
                    179.12823235088592`}, {87.28545582963409, 
                    119.46482175935049`}}], StatusArea[#, 4]& , TagBoxNote -> 
                   "4"], 
                  StyleBox["4", {}, StripOnInput -> False]], Annotation[#, 
                  Style[4, {}], "Tooltip"]& ]}}, {{
                RGBColor[0.982864, 0.7431472, 0.3262672], 
                EdgeForm[{
                  Opacity[0.5249999999999999], 
                  Thickness[Small]}], 
                TagBox[
                 TooltipBox[
                  TagBox[
                   DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{10.534883720930234`, 0.}, {
                    11.465116279069768`, 6.}, "RoundingRadius" -> 0]}, 
                    ImageSizeCache -> {{179.73124434145916`, 
                    194.9380708824355}, {71.4457728647759, 
                    119.46482175935049`}}], StatusArea[#, 6]& , TagBoxNote -> 
                   "6"], 
                  StyleBox["6", {}, StripOnInput -> False]], Annotation[#, 
                  Style[6, {}], "Tooltip"]& ]}}, {{
                RGBColor[0.982864, 0.7431472, 0.3262672], 
                EdgeForm[{
                  Opacity[0.5249999999999999], 
                  Thickness[Small]}], 
                TagBox[
                 TooltipBox[
                  TagBox[
                   DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{11.534883720930234`, 0.}, {
                    12.465116279069768`, 9.}, "RoundingRadius" -> 0]}, 
                    ImageSizeCache -> {{195.54108287300872`, 
                    210.7479094139851}, {47.68624841748861, 
                    119.46482175935049`}}], StatusArea[#, 9]& , TagBoxNote -> 
                   "9"], 
                  StyleBox["9", {}, StripOnInput -> False]], Annotation[#, 
                  Style[9, {}], "Tooltip"]& ]}}, {{
                RGBColor[0.982864, 0.7431472, 0.3262672], 
                EdgeForm[{
                  Opacity[0.5249999999999999], 
                  Thickness[Small]}], 
                TagBox[
                 TooltipBox[
                  TagBox[
                   DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{12.534883720930234`, 0.}, {
                    13.465116279069768`, 23.}, "RoundingRadius" -> 0]}, 
                    ImageSizeCache -> {{211.3509214045583, 
                    226.55774794553466`}, {-63.19153233651875, 
                    119.46482175935049`}}], StatusArea[#, 23]& , TagBoxNote -> 
                   "23"], 
                  StyleBox["23", {}, StripOnInput -> False]], Annotation[#, 
                  Style[23, {}], "Tooltip"]& ]}}, {{
                RGBColor[0.982864, 0.7431472, 0.3262672], 
                EdgeForm[{
                  Opacity[0.5249999999999999], 
                  Thickness[Small]}], 
                TagBox[
                 TooltipBox[
                  TagBox[
                   DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{13.534883720930234`, 0.}, {
                    14.465116279069768`, 14.}, "RoundingRadius" -> 0]}, 
                    ImageSizeCache -> {{227.1607599361079, 
                    242.36758647708425`}, {8.087041005343124, 
                    119.46482175935049`}}], StatusArea[#, 14]& , TagBoxNote -> 
                   "14"], 
                  StyleBox["14", {}, StripOnInput -> False]], Annotation[#, 
                  Style[14, {}], "Tooltip"]& ]}}, {{
                RGBColor[0.982864, 0.7431472, 0.3262672], 
                EdgeForm[{
                  Opacity[0.5249999999999999], 
                  Thickness[Small]}], 
                TagBox[
                 TooltipBox[
                  TagBox[
                   DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{14.534883720930234`, 0.}, {
                    15.465116279069768`, 1.}, "RoundingRadius" -> 0]}, 
                    ImageSizeCache -> {{242.97059846765748`, 
                    258.1774250086338}, {111.0449802769214, 
                    119.46482175935049`}}], StatusArea[#, 1]& , TagBoxNote -> 
                   "1"], 
                  StyleBox["1", {}, StripOnInput -> False]], Annotation[#, 
                  Style[1, {}], "Tooltip"]& ]}}, {{
                RGBColor[0.982864, 0.7431472, 0.3262672], 
                EdgeForm[{
                  Opacity[0.5249999999999999], 
                  Thickness[Small]}], 
                TagBox[
                 TooltipBox[
                  TagBox[
                   DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{15.534883720930234`, 0.}, {
                    16.46511627906977, 11.}, "RoundingRadius" -> 0]}, 
                    ImageSizeCache -> {{258.78043699920704`, 
                    273.9872635401834}, {31.846565452630415`, 
                    119.46482175935049`}}], StatusArea[#, 11]& , TagBoxNote -> 
                   "11"], 
                  StyleBox["11", {}, StripOnInput -> False]], Annotation[#, 
                  Style[11, {}], "Tooltip"]& ]}}, {{
                RGBColor[0.982864, 0.7431472, 0.3262672], 
                EdgeForm[{
                  Opacity[0.5249999999999999], 
                  Thickness[Small]}], 
                TagBox[
                 TooltipBox[
                  TagBox[
                   DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{16.53488372093023, 0.}, {17.46511627906977, 
                    1.}, "RoundingRadius" -> 0]}, 
                    ImageSizeCache -> {{274.59027553075657`, 
                    289.797102071733}, {111.0449802769214, 
                    119.46482175935049`}}], StatusArea[#, 1]& , TagBoxNote -> 
                   "1"], 
                  StyleBox["1", {}, StripOnInput -> False]], Annotation[#, 
                  Style[1, {}], "Tooltip"]& ]}}, {{
                RGBColor[0.982864, 0.7431472, 0.3262672], 
                EdgeForm[{
                  Opacity[0.5249999999999999], 
                  Thickness[Small]}], 
                TagBox[
                 TooltipBox[
                  TagBox[
                   DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{17.53488372093023, 0.}, {18.46511627906977, 
                    5.}, "RoundingRadius" -> 0]}, 
                    ImageSizeCache -> {{290.40011406230616`, 
                    305.60694060328257`}, {79.365614347205, 
                    119.46482175935049`}}], StatusArea[#, 5]& , TagBoxNote -> 
                   "5"], 
                  StyleBox["5", {}, StripOnInput -> False]], Annotation[#, 
                  Style[5, {}], "Tooltip"]& ]}}, {{
                RGBColor[0.982864, 0.7431472, 0.3262672], 
                EdgeForm[{
                  Opacity[0.5249999999999999], 
                  Thickness[Small]}], 
                TagBox[
                 TooltipBox[
                  TagBox[
                   DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{18.53488372093023, 0.}, {19.46511627906977, 
                    31.}, "RoundingRadius" -> 0]}, 
                    ImageSizeCache -> {{306.20995259385575`, 
                    321.4167791348321}, {-126.55026419595154`, 
                    119.46482175935049`}}], StatusArea[#, 31]& , TagBoxNote -> 
                   "31"], 
                  StyleBox["31", {}, StripOnInput -> False]], Annotation[#, 
                  Style[31, {}], "Tooltip"]& ]}}, {{
                RGBColor[0.982864, 0.7431472, 0.3262672], 
                EdgeForm[{
                  Opacity[0.5249999999999999], 
                  Thickness[Small]}], 
                TagBox[
                 TooltipBox[
                  TagBox[
                   DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    RectangleBox[{19.53488372093023, 0.}, {20.46511627906977, 
                    13.}, "RoundingRadius" -> 0]}, 
                    ImageSizeCache -> {{322.01979112540533`, 
                    337.2266176663817}, {16.006882487772216`, 
                    119.46482175935049`}}], StatusArea[#, 13]& , TagBoxNote -> 
                   "13"], 
                  StyleBox["13", {}, StripOnInput -> False]], Annotation[#, 
                  Style[13, {}], "Tooltip"]& ]}}, {{
                RGBColor[0.982864, 0.7431472, 0.3262672], 
                EdgeForm[{
                  Opacity[0.5249999999999999], 
                  Thickness[Small]}], 
                TagBox[
                 TooltipBox[
                  TagBox[
                   DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{20.53488372093023, 0.}, {21.46511627906977, 
                    8.}, "RoundingRadius" -> 0]}, 
                    ImageSizeCache -> {{337.8296296569549, 
                    353.0364561979313}, {55.606089899917706`, 
                    119.46482175935049`}}], StatusArea[#, 8]& , TagBoxNote -> 
                   "8"], 
                  StyleBox["8", {}, StripOnInput -> False]], Annotation[#, 
                  Style[8, {}], "Tooltip"]& ]}}, {{
                RGBColor[0.982864, 0.7431472, 0.3262672], 
                EdgeForm[{
                  Opacity[0.5249999999999999], 
                  Thickness[Small]}], 
                TagBox[
                 TooltipBox[
                  TagBox[
                   DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{21.53488372093023, 0.}, {22.46511627906977, 
                    4.}, "RoundingRadius" -> 0]}, 
                    ImageSizeCache -> {{353.63946818850445`, 
                    368.84629472948086`}, {87.28545582963409, 
                    119.46482175935049`}}], StatusArea[#, 4]& , TagBoxNote -> 
                   "4"], 
                  StyleBox["4", {}, StripOnInput -> False]], Annotation[#, 
                  Style[4, {}], "Tooltip"]& ]}}, {{
                RGBColor[0.982864, 0.7431472, 0.3262672], 
                EdgeForm[{
                  Opacity[0.5249999999999999], 
                  Thickness[Small]}], 
                TagBox[
                 TooltipBox[
                  TagBox[
                   DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{22.53488372093023, 0.}, {23.46511627906977, 
                    3.}, "RoundingRadius" -> 0]}, 
                    ImageSizeCache -> {{369.44930672005404`, 
                    384.65613326103045`}, {95.2052973120632, 
                    119.46482175935049`}}], StatusArea[#, 3]& , TagBoxNote -> 
                   "3"], 
                  StyleBox["3", {}, StripOnInput -> False]], Annotation[#, 
                  Style[3, {}], "Tooltip"]& ]}}, {{
                RGBColor[0.982864, 0.7431472, 0.3262672], 
                EdgeForm[{
                  Opacity[0.5249999999999999], 
                  Thickness[Small]}], 
                TagBox[
                 TooltipBox[
                  TagBox[
                   DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{23.53488372093023, 0.}, {24.46511627906977, 
                    1.}, "RoundingRadius" -> 0]}, 
                    ImageSizeCache -> {{385.2591452516036, 
                    400.46597179258004`}, {111.0449802769214, 
                    119.46482175935049`}}], StatusArea[#, 1]& , TagBoxNote -> 
                   "1"], 
                  StyleBox["1", {}, StripOnInput -> False]], Annotation[#, 
                  Style[1, {}], "Tooltip"]& ]}}, {{
                RGBColor[0.982864, 0.7431472, 0.3262672], 
                EdgeForm[{
                  Opacity[0.5249999999999999], 
                  Thickness[Small]}], 
                TagBox[
                 TooltipBox[
                  TagBox[
                   DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{24.53488372093023, 0.}, {25.46511627906977, 
                    2.}, "RoundingRadius" -> 0]}, 
                    ImageSizeCache -> {{401.0689837831532, 
                    416.2758103241296}, {103.12513879449229`, 
                    119.46482175935049`}}], StatusArea[#, 2]& , TagBoxNote -> 
                   "2"], 
                  StyleBox["2", {}, StripOnInput -> False]], Annotation[#, 
                  Style[2, {}], "Tooltip"]& ]}}}}, {}, {}}, {}, {}, 
           StyleBox[{{{
               Thickness[Tiny], 
               
               LineBox[{{0.036279069767441774`, 0.}, {25.973693023255816`, 
                0.}}], 
               StyleBox[{}, "GraphicsLabel", StripOnInput -> False]}}, 
             StyleBox[{{{
                 Thickness[Tiny], 
                 LineBox[{{0.5348837209302325, 0.}, 
                   
                   Offset[{-1.102182119232618*^-15, -6.}, {0.5348837209302325,
                     0.}]}], 
                 LineBox[{{25.46511627906977, 0.}, 
                   
                   Offset[{-1.102182119232618*^-15, -6.}, {25.46511627906977, 
                    0.}]}], {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {
                   LineBox[{{1.4651162790697674`, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    1.4651162790697674`, 0.}]}], 
                   LineBox[{{1.5348837209302326`, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    1.5348837209302326`, 0.}]}], 
                   LineBox[{{2.4651162790697674`, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    2.4651162790697674`, 0.}]}], 
                   LineBox[{{2.5348837209302326`, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    2.5348837209302326`, 0.}]}], 
                   LineBox[{{3.4651162790697674`, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    3.4651162790697674`, 0.}]}], 
                   LineBox[{{3.5348837209302326`, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    3.5348837209302326`, 0.}]}], 
                   LineBox[{{4.465116279069767, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {4.465116279069767,
                     0.}]}], 
                   LineBox[{{4.534883720930233, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {4.534883720930233,
                     0.}]}], 
                   LineBox[{{5.465116279069767, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {5.465116279069767,
                     0.}]}], 
                   LineBox[{{5.534883720930233, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {5.534883720930233,
                     0.}]}], 
                   LineBox[{{6.465116279069767, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {6.465116279069767,
                     0.}]}], 
                   LineBox[{{6.534883720930233, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {6.534883720930233,
                     0.}]}], 
                   LineBox[{{7.465116279069767, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {7.465116279069767,
                     0.}]}], 
                   LineBox[{{7.534883720930233, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {7.534883720930233,
                     0.}]}], 
                   LineBox[{{8.465116279069768, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {8.465116279069768,
                     0.}]}], 
                   LineBox[{{8.534883720930232, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {8.534883720930232,
                     0.}]}], 
                   LineBox[{{9.465116279069766, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {9.465116279069766,
                     0.}]}], 
                   LineBox[{{9.534883720930232, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {9.534883720930232,
                     0.}]}], 
                   LineBox[{{10.465116279069766`, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    10.465116279069766`, 0.}]}], 
                   LineBox[{{10.534883720930232`, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    10.534883720930232`, 0.}]}], 
                   LineBox[{{11.465116279069766`, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    11.465116279069766`, 0.}]}], 
                   LineBox[{{11.534883720930232`, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    11.534883720930232`, 0.}]}], 
                   LineBox[{{12.465116279069766`, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    12.465116279069766`, 0.}]}], 
                   LineBox[{{12.534883720930232`, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    12.534883720930232`, 0.}]}], 
                   LineBox[{{13.465116279069766`, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    13.465116279069766`, 0.}]}], 
                   LineBox[{{13.534883720930232`, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    13.534883720930232`, 0.}]}], 
                   LineBox[{{14.465116279069766`, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    14.465116279069766`, 0.}]}], 
                   LineBox[{{14.534883720930232`, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    14.534883720930232`, 0.}]}], 
                   LineBox[{{15.465116279069766`, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    15.465116279069766`, 0.}]}], 
                   LineBox[{{15.534883720930232`, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    15.534883720930232`, 0.}]}], 
                   LineBox[{{16.46511627906977, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {16.46511627906977,
                     0.}]}], 
                   LineBox[{{16.53488372093023, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {16.53488372093023,
                     0.}]}], 
                   LineBox[{{17.46511627906977, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {17.46511627906977,
                     0.}]}], 
                   LineBox[{{17.53488372093023, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {17.53488372093023,
                     0.}]}], 
                   LineBox[{{18.46511627906977, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {18.46511627906977,
                     0.}]}], 
                   LineBox[{{18.53488372093023, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {18.53488372093023,
                     0.}]}], 
                   LineBox[{{19.46511627906977, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {19.46511627906977,
                     0.}]}], 
                   LineBox[{{19.53488372093023, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {19.53488372093023,
                     0.}]}], 
                   LineBox[{{20.46511627906977, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {20.46511627906977,
                     0.}]}], 
                   LineBox[{{20.53488372093023, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {20.53488372093023,
                     0.}]}], 
                   LineBox[{{21.46511627906977, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {21.46511627906977,
                     0.}]}], 
                   LineBox[{{21.53488372093023, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {21.53488372093023,
                     0.}]}], 
                   LineBox[{{22.46511627906977, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {22.46511627906977,
                     0.}]}], 
                   LineBox[{{22.53488372093023, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {22.53488372093023,
                     0.}]}], 
                   LineBox[{{23.46511627906977, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {23.46511627906977,
                     0.}]}], 
                   LineBox[{{23.53488372093023, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {23.53488372093023,
                     0.}]}], 
                   LineBox[{{24.46511627906977, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {24.46511627906977,
                     0.}]}], 
                   LineBox[{{24.53488372093023, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {24.53488372093023,
                     0.}]}]}, {}}}}, 
               StyleBox[{{
                  Thickness[Tiny], 
                  InsetBox["\"A\"", 
                   Offset[{0., -2.}, {1., 0.}], {0, 1}, Automatic, {1, 0}], 
                  InsetBox["\"B\"", 
                   Offset[{0., -2.}, {2., 0.}], {0, 1}, Automatic, {1, 0}], 
                  InsetBox["\"C\"", 
                   Offset[{0., -2.}, {3., 0.}], {0, 1}, Automatic, {1, 0}], 
                  InsetBox["\"D\"", 
                   Offset[{0., -2.}, {4., 0.}], {0, 1}, Automatic, {1, 0}], 
                  InsetBox["\"E\"", 
                   Offset[{0., -2.}, {5., 0.}], {0, 1}, Automatic, {1, 0}], 
                  InsetBox["\"F\"", 
                   Offset[{0., -2.}, {6., 0.}], {0, 1}, Automatic, {1, 0}], 
                  InsetBox["\"G\"", 
                   Offset[{0., -2.}, {7., 0.}], {0, 1}, Automatic, {1, 0}], 
                  InsetBox["\"H\"", 
                   Offset[{0., -2.}, {8., 0.}], {0, 1}, Automatic, {1, 0}], 
                  InsetBox["\"I\"", 
                   Offset[{0., -2.}, {9., 0.}], {0, 1}, Automatic, {1, 0}], 
                  InsetBox["\"J\"", 
                   Offset[{0., -2.}, {10., 0.}], {0, 1}, Automatic, {1, 0}], 
                  InsetBox["\"K\"", 
                   Offset[{0., -2.}, {11., 0.}], {0, 1}, Automatic, {1, 0}], 
                  InsetBox["\"L\"", 
                   Offset[{0., -2.}, {12., 0.}], {0, 1}, Automatic, {1, 0}], 
                  InsetBox["\"M\"", 
                   Offset[{0., -2.}, {13., 0.}], {0, 1}, Automatic, {1, 0}], 
                  InsetBox["\"N\"", 
                   Offset[{0., -2.}, {14., 0.}], {0, 1}, Automatic, {1, 0}], 
                  InsetBox["\"O\"", 
                   Offset[{0., -2.}, {15., 0.}], {0, 1}, Automatic, {1, 0}], 
                  InsetBox["\"P\"", 
                   Offset[{0., -2.}, {16., 0.}], {0, 1}, Automatic, {1, 0}], 
                  InsetBox["\"Q\"", 
                   Offset[{0., -2.}, {17., 0.}], {0, 1}, Automatic, {1, 0}], 
                  InsetBox["\"R\"", 
                   Offset[{0., -2.}, {18., 0.}], {0, 1}, Automatic, {1, 0}], 
                  InsetBox["\"S\"", 
                   Offset[{0., -2.}, {19., 0.}], {0, 1}, Automatic, {1, 0}], 
                  InsetBox["\"T\"", 
                   Offset[{0., -2.}, {20., 0.}], {0, 1}, Automatic, {1, 0}], 
                  InsetBox["\"U\"", 
                   Offset[{0., -2.}, {21., 0.}], {0, 1}, Automatic, {1, 0}], 
                  InsetBox["\"V\"", 
                   Offset[{0., -2.}, {22., 0.}], {0, 1}, Automatic, {1, 0}], 
                  InsetBox["\"W\"", 
                   Offset[{0., -2.}, {23., 0.}], {0, 1}, Automatic, {1, 0}], 
                  InsetBox["\"Y\"", 
                   Offset[{0., -2.}, {24., 0.}], {0, 1}, Automatic, {1, 0}], 
                  InsetBox["\"Z\"", 
                   Offset[{0., -2.}, {25., 0.}], {0, 1}, Automatic, {1, 0}]}},
                 "GraphicsLabel", StripOnInput -> False]}, "GraphicsTicks", 
              StripOnInput -> False]}, "GraphicsAxes", StripOnInput -> False, 
            Antialiasing -> False]}, AspectRatio -> 
          NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {False, True},
           AxesLabel -> {None, None}, 
          AxesOrigin -> {0.036279069767441774`, 0.}, 
          CoordinatesToolOptions :> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}, FrameLabel -> {{None, None}, {None, None}}, 
          FrameTicks -> {{Automatic, Automatic}, {{{1., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {1., 
               FormBox["\"A\"", TraditionalForm], 0}, {2., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {2., 
               FormBox["\"B\"", TraditionalForm], 0}, {3., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {3., 
               FormBox["\"C\"", TraditionalForm], 0}, {4., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {4., 
               FormBox["\"D\"", TraditionalForm], 0}, {5., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {5., 
               FormBox["\"E\"", TraditionalForm], 0}, {6., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {6., 
               FormBox["\"F\"", TraditionalForm], 0}, {7., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {7., 
               FormBox["\"G\"", TraditionalForm], 0}, {8., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {8., 
               FormBox["\"H\"", TraditionalForm], 0}, {9., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {9., 
               FormBox["\"I\"", TraditionalForm], 0}, {10., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {10., 
               FormBox["\"J\"", TraditionalForm], 0}, {11., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {11., 
               FormBox["\"K\"", TraditionalForm], 0}, {12., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {12., 
               FormBox["\"L\"", TraditionalForm], 0}, {13., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {13., 
               FormBox["\"M\"", TraditionalForm], 0}, {14., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {14., 
               FormBox["\"N\"", TraditionalForm], 0}, {15., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {15., 
               FormBox["\"O\"", TraditionalForm], 0}, {16., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {16., 
               FormBox["\"P\"", TraditionalForm], 0}, {17., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {17., 
               FormBox["\"Q\"", TraditionalForm], 0}, {18., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {18., 
               FormBox["\"R\"", TraditionalForm], 0}, {19., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {19., 
               FormBox["\"S\"", TraditionalForm], 0}, {20., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {20., 
               FormBox["\"T\"", TraditionalForm], 0}, {21., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {21., 
               FormBox["\"U\"", TraditionalForm], 0}, {22., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {22., 
               FormBox["\"V\"", TraditionalForm], 0}, {23., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {23., 
               FormBox["\"W\"", TraditionalForm], 0}, {24., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {24., 
               FormBox["\"Y\"", TraditionalForm], 0}, {25., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {25., 
               FormBox["\"Z\"", TraditionalForm], 0}}, {{1., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {2., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {3., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {4., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {5., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {6., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {7., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {8., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {9., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {10., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {11., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {12., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {13., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {14., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {15., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {16., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {17., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {18., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {19., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {20., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {21., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {22., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {23., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {24., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {25., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}}}}, 
          GridLines -> {None, None}, GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], ImageSize -> {433.609375, Automatic}, 
          PlotRange -> {{All, All}, {All, All}}, PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, Ticks -> {None, Automatic}]], "ExerciseOutput", 
        Selectable -> False, Copyable -> False, Editable -> False, 
        ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"e165341e-c03a-4e8e-919a-79eaa012022d"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Find simpler code for \n",
 Cell[BoxData[
  RowBox[{
   ButtonBox["Grid",
    BaseStyle->"CodeLink"], "[", 
   RowBox[{
    ButtonBox["Table",
     BaseStyle->"CodeLink"], "[", 
    RowBox[{
     RowBox[{
      ButtonBox["StringJoin",
       BaseStyle->"CodeLink"], "[", 
      RowBox[{
       RowBox[{
        ButtonBox["TextString",
         BaseStyle->"CodeLink"], "[", "i", "]"}], ",", "\"\<^\>\"", ",", 
       RowBox[{
        ButtonBox["TextString",
         BaseStyle->"CodeLink"], "[", "j", "]"}], ",", "\"\<=\>\"", ",", 
       RowBox[{
        ButtonBox["TextString",
         BaseStyle->"CodeLink"], "[", 
        RowBox[{"i", "^", "j"}], "]"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "5"}], "}"}]}], "]"}], "]"}]], "InlineCode",
  ExpressionUUID->"91688236-d36e-4bfe-b398-ddb1243b5757"],
 ".",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "42.8", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"a482e2d5-c76b-4104-8b58-7f39aef22e45"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       TagBox[GridBox[{
          {"\<\"1^1=1\"\>", "\<\"1^2=1\"\>", "\<\"1^3=1\"\>", \
"\<\"1^4=1\"\>", "\<\"1^5=1\"\>"},
          {"\<\"2^1=2\"\>", "\<\"2^2=4\"\>", "\<\"2^3=8\"\>", \
"\<\"2^4=16\"\>", "\<\"2^5=32\"\>"},
          {"\<\"3^1=3\"\>", "\<\"3^2=9\"\>", "\<\"3^3=27\"\>", \
"\<\"3^4=81\"\>", "\<\"3^5=243\"\>"},
          {"\<\"4^1=4\"\>", "\<\"4^2=16\"\>", "\<\"4^3=64\"\>", \
"\<\"4^4=256\"\>", "\<\"4^5=1024\"\>"},
          {"\<\"5^1=5\"\>", "\<\"5^2=25\"\>", "\<\"5^3=125\"\>", "\<\"5^4=625\
\"\>", "\<\"5^5=3125\"\>"}
         },
         AutoDelete->False,
         GridBoxItemSize->{
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
        "Grid"]], "ExerciseOutput",ExpressionUUID->
       "99c3235a-af2e-42f2-b626-f209bbba774d"],
      Apply[TextCell, 
       Cell[
        BoxData[
         TagBox[
          
          GridBox[{{
            "\"1^1=1\"", "\"1^2=1\"", "\"1^3=1\"", "\"1^4=1\"", 
             "\"1^5=1\""}, {
            "\"2^1=2\"", "\"2^2=4\"", "\"2^3=8\"", "\"2^4=16\"", 
             "\"2^5=32\""}, {
            "\"3^1=3\"", "\"3^2=9\"", "\"3^3=27\"", "\"3^4=81\"", 
             "\"3^5=243\""}, {
            "\"4^1=4\"", "\"4^2=16\"", "\"4^3=64\"", "\"4^4=256\"", 
             "\"4^5=1024\""}, {
            "\"5^1=5\"", "\"5^2=25\"", "\"5^3=125\"", "\"5^4=625\"", 
             "\"5^5=3125\""}}, AutoDelete -> False, 
           GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"]], 
        "ExerciseOutput", Selectable -> False, Copyable -> False, Editable -> 
        False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"50c55d36-6029-43bb-9cb3-785088e78eb0"]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Q&A", "QASection",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"e84c7316-5a80-46f7-9928-7178ccbc8397"],

Cell[TextData[{
 "How should one read ",
 ButtonBox["~~",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/StringExpression"],
 " out loud?"
}], "Question",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"52cd1f62-d157-4e6b-8f9d-143360e6547c"],

Cell[TextData[{
 "It\[CloseCurlyQuote]s usually read \[OpenCurlyDoubleQuote]tilde tilde\
\[CloseCurlyDoubleQuote]. The underlying function is ",
 ButtonBox["StringExpression",
  BaseStyle->"Link"],
 "."
}], "Answer",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:19",ExpressionUUID->"dcb4f2b2-8f13-4f29-8287-b3fb87b6fd54"],

Cell["Can I write rules for understanding natural language?", "Question",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"c4bdce89-f292-4d98-8499-72ea3e1276d5"],

Cell[TextData[{
 "Yes, but we didn\[CloseCurlyQuote]t cover that here. The key function is ",
 ButtonBox["GrammarRules",
  BaseStyle->"Link"],
 "."
}], "Answer",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:20",ExpressionUUID->"0bfb3bc0-aa78-471b-9f80-504be374d5a6"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Tech Notes", "TechNoteSection",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"94e1847b-c6a1-4d5c-a4b9-f001d679a9a9"],

Cell[TextData[{
 "There\[CloseCurlyQuote]s a correspondence between patterns for strings, and \
patterns for sequences in lists. ",
 ButtonBox["SequenceCases",
  BaseStyle->"Link"],
 " is the analog for lists of ",
 ButtonBox["StringCases",
  BaseStyle->"Link"],
 " for strings."
}], "TechNote",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:21",ExpressionUUID->"d2f0c9be-1ed2-4599-a43d-107e814d91e4"],

Cell[TextData[{
 "The option ",
 ButtonBox["Overlaps",
  BaseStyle->"Link"],
 " specifies whether or not to allow overlaps in string matching. Different \
functions have different defaults. "
}], "TechNote",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:22",ExpressionUUID->"f6660831-fa83-495c-9de4-663a2a7439dd"],

Cell[TextData[{
 "String patterns by default match longest sequences, so you need to specify ",
 ButtonBox["Shortest",
  BaseStyle->"Link"],
 " if you want it. Expression patterns by default match shortest sequences."
}], "TechNote",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:23",ExpressionUUID->"5591d17d-519e-4ea3-9794-f0c47cc7ccf5"],

Cell[TextData[{
 "Among string pattern constructs are ",
 ButtonBox["Whitespace",
  BaseStyle->"Link"],
 ", ",
 ButtonBox["NumberString",
  BaseStyle->"Link"],
 ", ",
 ButtonBox["WordBoundary",
  BaseStyle->"Link"],
 ", ",
 ButtonBox["StartOfLine",
  BaseStyle->"Link"],
 ", ",
 ButtonBox["EndOfLine",
  BaseStyle->"Link"],
 ", ",
 ButtonBox["StartOfString",
  BaseStyle->"Link"],
 " and ",
 ButtonBox["EndOfString",
  BaseStyle->"Link"],
 "."
}], "TechNote",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:24",ExpressionUUID->"6e7c29c2-2ecf-40bb-9b12-471c7ce79c3c"],

Cell[TextData[{
 "Anywhere in a Wolfram Language symbolic string pattern, you can use ",
 ButtonBox["RegularExpression",
  BaseStyle->"Link"],
 " to include regular expression syntaxes like ",
 Cell[BoxData[
  RowBox[{
   StyleBox["x", "CodeVariable"], "*"}]], "InlineCode",ExpressionUUID->
  "5211c7b3-9c78-483c-9900-e9b6edb10ef3"],
 " and ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"[", 
    StyleBox["abc", "CodeVariable"], "]"}], "[", 
   StyleBox["def", "CodeVariable"], "]"}]], "InlineCode",ExpressionUUID->
  "8b991a1d-4230-4456-b16d-defcef68a624"],
 "."
}], "TechNote",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:25",ExpressionUUID->"d2b0e5ed-4ffd-43be-b5f4-fa4886426a61"],

Cell[TextData[{
 "You can compare strings using operations like ",
 ButtonBox["SequenceAlignment",
  BaseStyle->"Link"],
 ". This is particularly useful in bioinformatics. "
}], "TechNote",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:26",ExpressionUUID->"fc55a690-bf5b-4c0e-ae10-8e95c3af129d"],

Cell[TextData[{
 ButtonBox["FileTemplate",
  BaseStyle->"Link"],
 ", ",
 ButtonBox["XMLTemplate",
  BaseStyle->"Link"],
 " and ",
 ButtonBox["NotebookTemplate",
  BaseStyle->"Link"],
 " let you do the analog of ",
 ButtonBox["StringTemplate",
  BaseStyle->"Link"],
 " for files, XML (and HTML) documents, and notebooks."
}], "TechNote",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:27",ExpressionUUID->"3b754f5f-da04-486e-ae89-d9275faa5b88"],

Cell[TextData[{
 "The Wolfram Language includes the function ",
 ButtonBox["TextSearch",
  BaseStyle->"Link"],
 ", for searching text in large collections of files."
}], "TechNote",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:28",ExpressionUUID->"34fc8e7d-1d9e-4258-9094-3fc88fdefdf0"]
}, Open  ]],

Cell[CellGroupData[{

Cell["More to Explore", "MoreExploreSection",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"0eed336d-1aa9-4f99-b2bc-17928578fe67"],

Cell[TextData[ButtonBox["Guide to String Patterns in the Wolfram Language\
\[NonBreakingSpace]\[RightGuillemet]",
 BaseStyle->"Link",
 ButtonData->{"paclet:guide/StringPatterns", None}]], "MoreExplore",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->
  "LastCellOfAPage",ExpressionUUID->"5cf5696e-4642-4c76-8ec0-63d83b4ed9f0"]
}, Open  ]]
},
Saveable->False,
WindowToolbars->{},
BlinkingCellInsertionPoint->False,
CellInsertionPointCell->None,
WindowSize->{830, 800},
WindowMargins->Automatic,
WindowPersistentStyles->{
 WindowFrame, WindowMargins, WindowSize, Magnification},
WindowTitle->"String Patterns and Templates: Elementary Introduction to the \
Wolfram Language",
DockedCells->{
  Cell[
   BoxData[
    TagBox[
     GridBox[{{
        TemplateBox[{
         "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]", 
          "\"\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\"", 
          GraphicsBox[
           TagBox[
            RasterBox[CompressedData["
1:eJztl01IVFEUxyctMFzUysjIyUDCTauiIJFM6ENpM4NEtJrBUaSYZMYPhCRm
rYuoICgiW0VEBVIUEbTNEMTAIqRsk6JGCVFBHx7//+4JLo/36DqvB4Ie+Mk7
7+t3733nHpzq9NlEW0ksFsuX4U8i1duQy6X6kpuRtGTzHe3ZTOuxbFemPZPb
ny7FyZ2gEqwHInICfJToguOIReywPVHHlYDzcY4hJHZ486giyBOXtfms5Pms
Bs9zUBDTow6DJOgBT8DP/+B5CepAPbgqZm+zT70Bt9VXCx6H8DwE28Gw5ufB
IT2eA1N6PKquC0V4xtUxqfkE6ARD4BHYAx5Y938Gu8GdZXq4VsNWngIfwDzY
Aa6Bm55nOKYq8NXRw29eb+Uz4JSVd4Nn4IbPs2fARUdPQcfLWAQJ8Mq6Tkdd
gGcEHHT0sHYn9Jg1dcnnnhf6vnee8xzXVkcP9wdr97eY7z0NnlrX74qpxffg
iOZ2VDp6kvqOe6AVXAb7xNQB462YNfsCfoBzoE1MzTEqHD096mgE98WsEec4
Jqamvvk8cx2kwWuw19HDXnIAbNAx03ka9IO8mO+3ScyebRZTi01i1rqguHjY
r3aJWaugOA5O6vEC+K6ebWDW0cNgv6oBnwKus87KwKDmv8BRMOBz77/6G/sV
e8lkwHWuTwm4pQ7WzGIRHgb7FXsJ9/mI5z2si42gXMw8/ByuHgb7FXsJ9yX3
IPfHFjF1xTl5v0exnrCx5gnn+fu7JC7h/z/0Y52+P+rfWX9iCXVYErg=
             "], {{0,
              34}, {26, 0}}, {0, 255}, ColorFunction -> RGBColor], 
            BoxForm`ImageTag[
            "Byte", ColorSpace -> "RGB", Interleaving -> True, Magnification -> 
             1], Selectable -> False], DefaultBaseStyle -> "ImageGraphics", 
           ImageSize -> Magnification[1], ImageSizeRaw -> {26, 34}, 
           PlotRange -> {{0, 26}, {0, 34}}], 
          GraphicsBox[
           TagBox[
            RasterBox[CompressedData["
1:eJztXUuS47gRLX8WXtYRaJ+gl17SS+8U4/CeM+H2hDdtRY8jHF6ZR9AReATt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             "], {{0, 34}, {383, 0}}, {0, 255}, 
             ColorFunction -> RGBColor], 
            BoxForm`ImageTag[
            "Byte", ColorSpace -> "RGB", Interleaving -> True, Magnification -> 
             1], Selectable -> False], DefaultBaseStyle -> "ImageGraphics", 
           ImageSize -> Magnification[1], ImageSizeRaw -> {383, 34}, 
           PlotRange -> {{0, 383}, {0, 34}}]}, "RowWithSeparators"], 
        PaneBox[
         StyleBox["\[VeryThinSpace]", ShowStringCharacters -> False], 
         Alignment -> Right, ImageSize -> {174, 47}], 
        PaneBox[
         PaneBox[
          TemplateBox[{"\[ThinSpace]", "\" \"", 
            TagBox[
             TooltipBox[
              PaneSelectorBox[{False -> ButtonBox[
                  PaneBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAPiDmBmIUBO/j//z8jEDcA8W8g3oBFnhmIZ/9HgE9o8mxAvBZJ/hsQuyPJ
8wPxfiT5N0BsjiQvCsTnkOSfALEWkrwSEN9Bkr8OxDJobniAJP8ZZCYWfxCj
RpGQXcS4mVi/ExuGxMYFmlp4nAIAG14fWQ==
                    "], {{0, 14}, {9, 
                    0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                     ImageSizeRaw -> {9, 14}, PlotRange -> {{0, 9}, {0, 14}}, 
                    ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                   Alignment -> Center], 
                  ButtonFunction :> (
                   NotebookLocate[{"EIWL1-41-more-about-patterns.nb", ""}, 
                    FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Enabled -> True, Appearance -> 
                  None, Evaluator -> Automatic, Method -> "Preemptive"], True -> 
                ButtonBox[
                  PaneBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAPiDmBmIUBO/j//z8jEDcA8W8g3oBFnhmIZ/9HgE9o8mxAvBZJ/hsQuyPJ
8wPxfiT5N0BsjiQvCsTnkOSfALEWkrwSEN9Bkr8OxDJobniAJP8ZZCYWfxCj
RpGQXcS4mVi/ExuGxMYFmlp4nAIAG14fWQ==
                    "], {{0, 14}, {9, 
                    0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                     ImageSizeRaw -> {9, 14}, PlotRange -> {{0, 9}, {0, 14}}, 
                    ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                   Alignment -> Center], 
                  ButtonFunction :> (
                   NotebookLocate[{"EIWL1-41-more-about-patterns.nb", ""}, 
                    FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Enabled -> True, Appearance -> 
                  None, Background -> RGBColor[0.835294, 0.364706, 0.0196078],
                   Evaluator -> Automatic, Method -> "Preemptive"]}, 
               Dynamic[
                CurrentValue["MouseOver"]], ImageSize -> Automatic, 
               FrameMargins -> 0], "\"More about Patterns\"", TooltipDelay -> 
              0.15, LabelStyle -> "TextStyling"], 
             Annotation[#, "More about Patterns", "Tooltip"]& ], 
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {5, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[5], Selectable -> False], 
            TagBox[
             TooltipBox[
              PaneSelectorBox[{False -> ButtonBox[
                  PaneBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAfiDmBmAWI////vwKIfwFxMQMOAJT7+R8B6nGoSf+PCjpwqMskUl0SEP9F
UtcHxIxY1EWjqZuOQ10Mmr2TcNj7BEnNP1LNIeQeIDsZn78IhQ8x4fwfNb4a
cPgTFu8l2ORBAAC+1hnm
                    "], {{0, 15}, {9, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                     ImageSizeRaw -> {9, 15}, PlotRange -> {{0, 9}, {0, 15}}, 
                    ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                   Alignment -> Center], 
                  ButtonFunction :> (
                   NotebookLocate[{"EIWL1-43-storing-things.nb", ""}, 
                    FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Appearance -> None, Evaluator -> 
                  Automatic, Method -> "Preemptive"], True -> ButtonBox[
                  PaneBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAfiDmBmAWI////vwKIfwFxMQMOAJT7+R8B6nGoSf+PCjpwqMskUl0SEP9F
UtcHxIxY1EWjqZuOQ10Mmr2TcNj7BEnNP1LNIeQeIDsZn78IhQ8x4fwfNb4a
cPgTFu8l2ORBAAC+1hnm
                    "], {{0, 15}, {9, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                     ImageSizeRaw -> {9, 15}, PlotRange -> {{0, 9}, {0, 15}}, 
                    ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                   Alignment -> Center], 
                  ButtonFunction :> (
                   NotebookLocate[{"EIWL1-43-storing-things.nb", ""}, 
                    FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Appearance -> None, Background -> 
                  RGBColor[0.835294, 0.364706, 0.0196078], Evaluator -> 
                  Automatic, Method -> "Preemptive"]}, 
               Dynamic[
                CurrentValue["MouseOver"]], ImageSize -> Automatic, 
               FrameMargins -> 0], "\"Storing Things\"", TooltipDelay -> 0.15,
               LabelStyle -> "TextStyling"], 
             Annotation[#, "Storing Things", "Tooltip"]& ]}, 
           "RowWithSeparators"], Alignment -> Right], ImageSize -> {100, 30}, 
         FrameMargins -> {{0, 6}, {0, 0}}, Alignment -> Right], 
        ActionMenuBox[
         PaneSelectorBox[{True -> PanelBox[
             GraphicsBox[
              TagBox[
               RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UBAkIQ3ELED8////Jf/pA0D2/KWTXSB7ZtPBPrA9DKOAYgAMR1Eg9gPiABpi
P6g912mcLmAAZM9XOtkFsicKiNcD8QYaYpD5UQOdXoYD+E/HMooO9iDbR7c6
BQDxtyEt
                "], {{0, 16}, {27, 0}}, {0, 255}, ColorFunction -> 
                RGBColor], 
               BoxForm`ImageTag[
               "Byte", ColorSpace -> "RGB", Interleaving -> True, 
                Magnification -> 1], Selectable -> False], DefaultBaseStyle -> 
              "ImageGraphics", ImageSize -> Magnification[1], 
              ImageSizeRaw -> {27, 16}, PlotRange -> {{0, 27}, {0, 16}}], 
             Appearance -> None, Background -> 
             RGBColor[0.835294, 0.364706, 0.0196078], ImageSize -> {35, 30}, 
             Alignment -> Center], False -> PanelBox[
             GraphicsBox[
              TagBox[
               RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UBAkIQ3ELED8////Jf/pA0D2/KWTXSB7ZtPBPrA9DKOAYgAMR1Eg9gPiABpi
P6g912mcLmAAZM9XOtkFsicKiNcD8QYaYpD5UQOdXoYD+E/HMooO9iDbR7c6
BQDxtyEt
                "], {{0, 16}, {27, 0}}, {0, 255}, ColorFunction -> 
                RGBColor], 
               BoxForm`ImageTag[
               "Byte", ColorSpace -> "RGB", Interleaving -> True, 
                Magnification -> 1], Selectable -> False], DefaultBaseStyle -> 
              "ImageGraphics", ImageSize -> Magnification[1], 
              ImageSizeRaw -> {27, 16}, PlotRange -> {{0, 27}, {0, 16}}], 
             Appearance -> None, Background -> 
             RGBColor[0.952941, 0.509804, 0], ImageSize -> {35, 30}, 
             Alignment -> Center]}, 
          Dynamic[
           CurrentValue["MouseOver"]]], {
         "Preface" :> 
          NotebookLocate[{"EIWL1-0a-preface.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "What Is the Wolfram Language?" :> 
          NotebookLocate[{"EIWL1-0b-what-is-the-wolfram-language.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "Practicalities of Using the Wolfram Language" :> 
          NotebookLocate[{
            "EIWL1-0c-practicalities-of-using-the-wolfram-language.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "Other Resources" :> 
          NotebookLocate[{"EIWL1-0d-other-resources.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]1\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Starting Out: Elementary Arithmetic" :> 
          NotebookLocate[{
            "EIWL1-01-starting-out-elementary-arithmetic.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]2\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Introducing Functions" :> 
          NotebookLocate[{"EIWL1-02-introducing-functions.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]3\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]First Look at Lists" :> 
          NotebookLocate[{"EIWL1-03-first-look-at-lists.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]4\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Displaying Lists" :> 
          NotebookLocate[{"EIWL1-04-displaying-lists.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]5\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Operations on Lists" :> 
          NotebookLocate[{"EIWL1-05-operations-on-lists.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]6\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Making Tables" :> 
          NotebookLocate[{"EIWL1-06-making-tables.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]7\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Colors and Styles" :> 
          NotebookLocate[{"EIWL1-07-colors-and-styles.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]8\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Basic Graphics Objects" :> 
          NotebookLocate[{"EIWL1-08-basic-graphics-objects.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]9\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Interactive Manipulation" :> 
          NotebookLocate[{"EIWL1-09-interactive-manipulation.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "10\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Images" :> 
          NotebookLocate[{"EIWL1-10-images.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "11\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Strings and \
Text" :> NotebookLocate[{"EIWL1-11-strings-and-text.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "12\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Sound" :> 
          NotebookLocate[{"EIWL1-12-sound.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "13\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Arrays, or \
Lists of Lists" :> 
          NotebookLocate[{"EIWL1-13-arrays-or-lists-of-lists.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "14\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Coordinates \
and Graphics" :> 
          NotebookLocate[{"EIWL1-14-coordinates-and-graphics.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "15\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]The Scope \
of the Wolfram Language" :> 
          NotebookLocate[{
            "EIWL1-15-the-scope-of-the-wolfram-language.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "16\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Real\
\[VeryThinSpace]\[Hyphen]\[VeryThinSpace]\[NegativeVeryThinSpace]World Data" :> 
          NotebookLocate[{"EIWL1-16-real-world-data.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "17\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Units" :> 
          NotebookLocate[{"EIWL1-17-units.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "18\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]\
Geocomputation" :> 
          NotebookLocate[{"EIWL1-18-geocomputation.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "19\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Dates and \
Times" :> NotebookLocate[{"EIWL1-19-dates-and-times.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "20\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Options" :> 
          NotebookLocate[{"EIWL1-20-options.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "21\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Graphs and \
Networks" :> 
          NotebookLocate[{"EIWL1-21-graphs-and-networks.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "22\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Machine \
Learning" :> 
          NotebookLocate[{"EIWL1-22-machine-learning.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "23\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]More about \
Numbers" :> NotebookLocate[{"EIWL1-23-more-about-numbers.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "24\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]More Forms \
of Visualization" :> 
          NotebookLocate[{"EIWL1-24-more-forms-of-visualization.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "25\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Ways to \
Apply Functions" :> 
          NotebookLocate[{"EIWL1-25-ways-to-apply-functions.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "26\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Pure \
Anonymous Functions" :> 
          NotebookLocate[{"EIWL1-26-pure-anonymous-functions.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "27\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Applying \
Functions Repeatedly" :> 
          NotebookLocate[{"EIWL1-27-applying-functions-repeatedly.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "28\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Tests and \
Conditionals" :> 
          NotebookLocate[{"EIWL1-28-tests-and-conditionals.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "29\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]More about \
Pure Functions" :> 
          NotebookLocate[{"EIWL1-29-more-about-pure-functions.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "30\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Rearranging \
Lists" :> NotebookLocate[{"EIWL1-30-rearranging-lists.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "31\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Parts of \
Lists" :> NotebookLocate[{"EIWL1-31-parts-of-lists.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "32\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Patterns" :> 
          NotebookLocate[{"EIWL1-32-patterns.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "33\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Expressions \
and Their Structure" :> 
          NotebookLocate[{"EIWL1-33-expressions-and-their-structure.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "34\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]\
Associations" :> 
          NotebookLocate[{"EIWL1-34-associations.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "35\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Natural \
Language Understanding" :> 
          NotebookLocate[{"EIWL1-35-natural-language-understanding.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "36\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Creating \
Websites and Apps" :> 
          NotebookLocate[{"EIWL1-36-creating-websites-and-apps.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "37\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Layout and \
Display" :> NotebookLocate[{"EIWL1-37-layout-and-display.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "38\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Assigning \
Names to Things" :> 
          NotebookLocate[{"EIWL1-38-assigning-names-to-things.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "39\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Immediate \
and Delayed Values" :> 
          NotebookLocate[{"EIWL1-39-immediate-and-delayed-values.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "40\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Defining \
Your Own Functions" :> 
          NotebookLocate[{"EIWL1-40-defining-your-own-functions.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "41\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]More about \
Patterns" :> 
          NotebookLocate[{"EIWL1-41-more-about-patterns.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "42\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]String \
Patterns and Templates " :> 
          NotebookLocate[{"EIWL1-42-string-patterns-and-templates.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "43\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Storing \
Things" :> NotebookLocate[{"EIWL1-43-storing-things.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "44\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Importing \
and Exporting" :> 
          NotebookLocate[{"EIWL1-44-importing-and-exporting.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "45\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Datasets" :> 
          NotebookLocate[{"EIWL1-45-datasets.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "46\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Writing \
Good Code" :> 
          NotebookLocate[{"EIWL1-46-writing-good-code.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "47\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Debugging \
Your Code" :> 
          NotebookLocate[{"EIWL1-47-debugging-your-code.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "What We Haven\[CloseCurlyQuote]t Discussed" :> 
          NotebookLocate[{"EIWL1-what-we-havent-discussed.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "Afterword: Being a Programmer" :> 
          NotebookLocate[{"EIWL1-being-a-programmer.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "Answers to Exercises" :> 
          NotebookLocate[{"EIWL1-answers-to-exercises.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "Index" :> 
          NotebookLocate[{"EIWL1-book-index.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}]}, Appearance -> None]}}, 
      GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Center}}}, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"]], 
   "Text", ShowCellBracket -> False, CellFrame -> {{0, 0}, {3, 0}}, 
   Selectable -> False, CellFrameColor -> 
   RGBColor[0.835294, 0.364706, 0.0196078], CellMargins -> {{0, 0}, {0, -1}}, 
   CellFrameMargins -> {{27, 0}, {1, 7}}, Background -> 
   RGBColor[0.952941, 0.509804, 0], CellTags -> "DockedCellLogoCell"], 
  Cell["FIRST EDITION (2015)", "Text", FontFamily -> "Source Sans Pro", 
   CellFrame -> {{0, 0}, {3, 0}}, ShowCellBracket -> False, 
   CellMargins -> {{0, 0}, {-1, -1}}, CellFrameMargins -> {{66, 0}, {2, 4}}, 
   CellFrameColor -> RGBColor[0.952941, 0.509804, 0], FontSize -> 10, 
   FontTracking -> "Extended", FontColor -> RGBColor[1, 0.929412, 0.721569], 
   Background -> RGBColor[0.862745, 0.309804, 0], CellTags -> 
   "DockedCellLogoCell"]},
PrintingStartingPageNumber->339,
PageHeaders->{{
   Cell[
    TextData[{
      StyleBox[
       CounterBox["Page"], "PageNumber"], 
      StyleBox[
      "    An Elementary Introduction to the Wolfram Language", "Header"]}], 
    "Header", CellMargins -> {{37, Inherited}, {Inherited, Inherited}}], None,
    None}, {None, None, 
   Cell[
    TextData[{
      StyleBox[
       CounterBox["Section"], "Header"], 
      StyleBox[
      " | String Patterns and Templates \[LongDash] wolfr.am/eiwl-", 
       "Header"], 
      StyleBox[
       CounterBox["Section"], "Header"], 
      StyleBox["    ", "Header"], 
      StyleBox[
       CounterBox["Page"], "PageNumber"]}], "Header", 
    CellMargins -> {{Inherited, 17}, {Inherited, Inherited}}]}},
PrintingOptions->{"FirstPageHeader"->True},
ShowCellBracket->Automatic,
ShowSyntaxStyles->False,
Magnification->1.,
FrontEndVersion->"11.1 for Mac OS X x86 (32-bit, 64-bit Kernel) (March 16, \
2017)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "Default.nb"]], 
   Cell[
    CellGroupData[{
      Cell[
      "Style Environments", "Section", 
       CellChangeTimes -> {{3.64661165091824*^9, 3.646611654013329*^9}, 
         3.6485723794335403`*^9, 3.651347081728628*^9, 3.651347179462186*^9, 
         3.651347384135805*^9, 3.651348171662589*^9}], 
      Cell[
       StyleData[All, "Working"], CellInsertionPointCell -> 
       FEPrivate`FrontEndResource["FEExpressions", "CellInsertionMenu"], 
       CreateCellID -> True, $CellContext`GhostCellInEmptyNotebook -> False], 
      
      Cell[
       StyleData[All, "Printout"], 
       PrintingOptions -> {
        "PageSize" -> {504, 720}, "PrintRegistrationMarks" -> True}, 
       Magnification -> 0.6]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell["Styles for Headers and Footers", "Section"], 
      Cell[
       StyleData["Header"], StyleMenuListing -> None, FontFamily -> "Verdana",
        FontSize -> 7, FontSlant -> "Plain", FontColor -> GrayLevel[0.6]], 
      Cell[
       StyleData["PageNumber"], CellMargins -> {{0, 0}, {4, 1}}, 
       StyleMenuListing -> None, FontFamily -> "Verdana", FontSize -> 7, 
       FontWeight -> "Bold", FontSlant -> "Plain", FontColor -> 
       GrayLevel[0]]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell[
      "WPL Specific", "Section", 
       CellChangeTimes -> {{3.6556608433734913`*^9, 3.6556608489412746`*^9}}], 
      Cell[
       StyleData["Link"], FontFamily -> "Source Sans Pro", FontSize :> 
       If[CurrentValue[
           EvaluationCell[], "FontFamily"] === "Source Sans Pro", Inherited, 
         If[CurrentValue[
            EvaluationCell[], "FontFamily"] === "WolframCodeSans", Inherited, 
          Inherited 0.9]], FontColor -> GrayLevel[0]], 
      Cell[
       StyleData["CodeLink"], 
       ButtonBoxOptions -> {
        Appearance -> None, ButtonFunction :> (FEPrivate`FrontEndExecute[
           FrontEndToken["OpenHelpLink", {
             Part[#, 1], Null}]]& ), ButtonSource -> ButtonContents, 
         Evaluator -> None, Method -> "Preemptive"}]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell[
      "Custom Styles", "Section", 
       CellChangeTimes -> {{3.646611660445352*^9, 3.646611669493331*^9}}], 
      Cell[
       StyleData["Notebook"], PageWidth -> 700, 
       PrintingOptions -> {
        "InnerOuterMargins" -> {35, 16}, "PaperOrientation" -> "Portrait", 
         "PaperSize" -> {504, 720}, 
         "PrintingMargins" -> {{20, 20}, {54, 54}}}, CellLabelAutoDelete -> 
       False, ShowSyntaxStyles -> False, MenuSortingValue -> None, 
       GraphicsBoxOptions -> {ImageSize -> 240}, 
       Graphics3DBoxOptions -> {ImageSize -> 240}], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Title"], CellMargins -> {{64, Inherited}, {50, 72}}, 
          MenuCommandKey -> None, FontFamily -> "Verdana", FontSize -> 42, 
          FontWeight -> "Bold", FontColor -> GrayLevel[0.4]], 
         Cell[
          StyleData["Title", "Printout"], 
          CellMargins -> {{64, Inherited}, {50, 72}}]}, Closed]], 
      Cell[
       StyleData["Chapter"], MenuCommandKey -> None], 
      Cell[
       StyleData["Subchapter"], MenuCommandKey -> None], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Section"], CellFrame -> {{0, 0}, {0, 0}}, CellDingbat -> 
          Cell[
            TextData[
             CounterBox["Section"], 
             StyleBox[
             "|\[NegativeThinSpace]", FontColor -> 
              RGBColor[
               0.9019607843137255, 0.4117647058823529, 0.027450980392156862`],
               FontFamily -> "Courier", FontSize -> 36, FontWeight -> Plain]],
             "SectionNumber"], CellMargins -> {{96, Inherited}, {12, 44}}, 
          Evaluatable -> True, CellGroupingRules -> {"SectionGrouping", 60}, 
          PageBreakAbove -> True, ShowCellLabel -> False, 
          CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
          CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
          CounterIncrements -> "Section", 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", 
          FontSize -> 26, FontSlant -> "Plain", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          InterpretationBoxOptions -> {Editable -> True}], 
         Cell[
          StyleData["Section", "Printout"], 
          CellMargins -> {{96, Inherited}, {12, 2}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionDoubleDigit"], CellFrame -> {{0, 0}, {0, 0}}, 
          CellDingbat -> Cell[
            TextData[
             CounterBox["Section"], 
             StyleBox[
             "|\[NegativeThinSpace]", FontColor -> 
              RGBColor[
               0.9019607843137255, 0.4117647058823529, 0.027450980392156862`],
               FontFamily -> "Courier", FontSize -> 36, FontWeight -> Plain]],
             "SectionNumber"], CellMargins -> {{112, Inherited}, {12, 44}}, 
          Evaluatable -> True, CellGroupingRules -> {"SectionGrouping", 60}, 
          PageBreakAbove -> True, ShowCellLabel -> False, 
          CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
          CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
          CounterIncrements -> "Section", 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", 
          FontSize -> 26, FontSlant -> "Plain", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          InterpretationBoxOptions -> {Editable -> True}], 
         Cell[
          StyleData["SectionDoubleDigit", "Printout"], 
          CellMargins -> {{112, Inherited}, {12, 2}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionNumber"], CellBaseline -> Baseline, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 26, FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["SectionNumber", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionInline"], FontFamily -> 
          "Source Sans Pro Semibold", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["SectionInline", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionNoDingbat"], 
          CellMargins -> {{64, Inherited}, {12, 44}}, Evaluatable -> True, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakAbove -> 
          True, ShowCellLabel -> False, 
          CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
          CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
          CounterIncrements -> "Section", 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", 
          FontSize -> 26, FontSlant -> "Plain", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          InterpretationBoxOptions -> {Editable -> True}], 
         Cell[
          StyleData["SectionNoDingbat", "Printout"], 
          CellMargins -> {{64, Inherited}, {12, 2}}]}, Closed]], 
      Cell[
       StyleData["AnswerKeyNumberedSection"], 
       CellMargins -> {{64, Inherited}, {8, 28}}, Evaluatable -> True, 
       CellGroupingRules -> {"SectionGrouping", 60}, PageBreakAbove -> True, 
       ShowCellLabel -> False, 
       CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
       CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
       CounterIncrements -> "Section", 
       CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
         "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", FontSize -> 
       18, FontSlant -> "Plain", FontColor -> 
       RGBColor[
        0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
       InterpretationBoxOptions -> {Editable -> True}], 
      Cell[
       StyleData["AnswerKeySectionNumber"], CellBaseline -> Baseline, 
       FontFamily -> "Source Sans Pro Semibold", FontSize -> 18, FontColor -> 
       RGBColor[
        0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
      Cell[
       StyleData["IndexLinkGuide"], 
       CellMargins -> {{64, Inherited}, {48, 28}}, Evaluatable -> True, 
       CellGroupingRules -> {"SectionGrouping", 60}, PageBreakAbove -> True, 
       ShowCellLabel -> False, 
       CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
       CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
       CounterIncrements -> "Section", 
       CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
         "Exercise", 0}}, FontFamily -> "Source Sans Pro", FontSize -> 14, 
       FontSlant -> "Plain", FontColor -> 
       RGBColor[
        0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
       InterpretationBoxOptions -> {Editable -> True}], 
      Cell[
       StyleData["Index"], MenuSortingValue -> 10000, FontFamily -> 
       "Source Sans Pro", FontSize -> 11], 
      Cell[
       StyleData["IndexSubentry"], MenuSortingValue -> 10000, FontFamily -> 
       "Source Sans Pro", FontSize -> 11], 
      Cell[
       StyleData["FunctionName"], MenuSortingValue -> 10000, FontFamily -> 
       "Source Sans Pro Semibold", FontWeight -> "Bold"], 
      Cell[
       StyleData["IndexColumn"], 
       CellMargins -> {{66, 0}, {Inherited, Inherited}}, TabSpacings -> {2.}, 
       MenuSortingValue -> 10000, FontFamily -> "Source Sans Pro", 
       GridBoxOptions -> {
        GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
         GridBoxItemSize -> {"Columns" -> {{25}}}, 
         GridBoxSpacings -> {"Columns" -> {{2}}}}], 
      Cell[
       StyleData["IndexSubsection"], 
       CellMargins -> {{64, Inherited}, {9, 28}}, 
       CellGroupingRules -> {"SectionGrouping", 40}, MenuSortingValue -> 
       10000, FontFamily -> "Source Sans Pro", FontSize -> 24], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Subsection"], CellMargins -> {{64, Inherited}, {12, 32}},
           FontFamily -> "Source Sans Pro Semibold", FontSize -> 18, 
          FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["Subsection", "Printout"], 
          CellMargins -> {{64, Inherited}, {12, 32}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ResourcesSubsection"], 
          CellMargins -> {{64, Inherited}, {4, 16}}, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 15, FontSlant -> "Plain", 
          FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["ResourcesSubsection", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 16}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Subsubsection"], 
          CellMargins -> {{64, Inherited}, {6, 12}}, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 16, FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["Subsubsection", "Printout"], 
          CellMargins -> {{64, Inherited}, {6, 12}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularySection"], PageWidth -> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 24}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["VocabularySection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 24}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularyTable", StyleDefinitions -> StyleData["Text"]],
           SpanMaxSize -> 1, FontFamily -> "Source Sans Pro Light", FontColor -> 
          GrayLevel[0.8], 
          GridBoxOptions -> {
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
            GridBoxDividers -> {"Columns" -> {{False}}, "Rows" -> {False, {
                 Directive[
                  Thickness[0.5], "VocabDivColor"]}, False}}, 
            GridBoxItemStyle -> {
             "Columns" -> {"VocabularyCode", Inherited, Inherited}, 
              "Rows" -> {{Automatic}}}, 
            GridBoxSpacings -> {
             "Columns" -> {{0, 1, 2, 1, 2}}, "Rows" -> {{1}}}}], 
         Cell[
          StyleData["VocabularyTable", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "VocabularyTable3Column", StyleDefinitions -> StyleData["Text"]], 
          SpanMaxSize -> 1, FontFamily -> "Source Sans Pro Light", FontColor -> 
          GrayLevel[0.8], 
          GridBoxOptions -> {
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
            GridBoxDividers -> {"Columns" -> {{False}}, "Rows" -> {False, {
                 Directive[
                  Thickness[0.5], "VocabDivColor"]}, False}}, 
            GridBoxItemStyle -> {
             "Columns" -> {
               "VocabularyCode", Inherited, "VocabularyCode", Inherited, 
                Inherited}, "Rows" -> {{Automatic}}}, 
            GridBoxSpacings -> {
             "Columns" -> {{0, 1, 2, 1, 2}}, "Rows" -> {{1}}}}], 
         Cell[
          StyleData["VocabularyTable3Column", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularyText"], FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["VocabularyText", "Printout"], 
          CellMargins -> {{66, 10}, {7, 7}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularyCode", StyleDefinitions -> StyleData["Text"]], 
          Deletable -> False, FontFamily -> "Source Sans Pro", FontSize -> 14,
           FontWeight -> "Bold", FontColor -> GrayLevel[0.25], 
          GridBoxOptions -> {
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
            GridBoxDividers -> {
             "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {True, {True}, True}, "RowsIndexed" -> {}}}], 
         Cell[
          StyleData["VocabularyCode", "Printout"], FontColor -> 
          GrayLevel[0.25]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabDivColor"], FontColor -> GrayLevel[0.8]], 
         Cell[
          StyleData["VocabDivColor", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseSection"], PageWidth -> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 30}}, Evaluatable -> True, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, ShowCellLabel -> False, CellFrameMargins -> {{8, 8}, {4, 6}},
           CellFrameColor -> RGBColor[0.901961, 0.411765, 0.027451], 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro", FontSize -> 18, 
          FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["ExerciseSection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Exercise"], PageWidth -> 700, CellDingbat -> Cell[
            TextData[{"  ", 
              CounterBox["Section"], ".", 
              CounterBox["Exercise"]}], "ExerciseNumber", FontColor -> 
            RGBColor[
             0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
          ShowGroupOpener -> True, CellMargins -> {{108, Inherited}, {4, 8}}, 
          CellGroupingRules -> {"SectionGrouping", 67}, CounterIncrements -> 
          "Exercise", MenuSortingValue -> 10020, MenuCommandKey -> "2", 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Plain", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["Exercise", "Printout"], ShowGroupOpener -> False, 
          CellMargins -> {{110, Inherited}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseNumber"], FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Bold", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["ExerciseNumber", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseSubsection"], PageWidth -> 500, 
          CellFrame -> {{False, False}, {1, False}}, 
          CellMargins -> {{64, Inherited}, {8, 18}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, CellFrameColor -> 
          RGBColor[0.65, 0.6, 0.6], FontFamily -> "Source Sans Pro", FontSize -> 
          18, FontSlant -> "Italic", FontColor -> RGBColor[0.65, 0.6, 0.6]], 
         Cell[
          StyleData["ExerciseSubsection", "Printout"], 
          CellFrame -> {{False, False}, {1, False}}, CellFrameColor -> 
          RGBColor[0.65, 0.6, 0.6]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseNote"], PageWidth -> 700, 
          CellMargins -> {{64, Inherited}, {4, 8}}, PageBreakBelow -> False, 
          MenuSortingValue -> 10050, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25], $CellContext`ReturnCreatesNewCell -> 
          True], 
         Cell[
          StyleData["ExerciseNote", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["QASection"], PageWidth -> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 30}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Question", 0}}, FontFamily -> "Source Sans Pro", FontSize -> 18, 
          FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["QASection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Question"], PageWidth -> 700, 
          CellMargins -> {{64, Inherited}, {2, 12}}, PageBreakBelow -> False, 
          CounterIncrements -> "Question", MenuSortingValue -> 10030, 
          MenuCommandKey -> "3", FontFamily -> "Source Sans Pro", FontSize -> 
          14, FontWeight -> "Bold", FontSlant -> 
          "Plain", $CellContext`ReturnCreatesNewCell -> 
          True, $CellContext`DefaultReturnCreatedCellStyle -> "Answer"], 
         Cell[
          StyleData["Question", "Printout"], 
          CellMargins -> {{65, Inherited}, {2, 12}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Answer"], PageWidth -> 700, 
          CellMargins -> {{66, 10}, {4, 1}}, LineSpacing -> {1.125, 1., 2.}, 
          MenuSortingValue -> 10032, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25], $CellContext`ReturnCreatesNewCell -> 
          True, $CellContext`DefaultReturnCreatedCellStyle -> "Question"], 
         Cell[
          StyleData["Answer", "Printout"], 
          CellMargins -> {{66, 10}, {4, 1}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["QuestionNumber"], FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Bold", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["QuestionNumber", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TechNoteSection"], PageWidth -> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 30}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["TechNoteSection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TechNote"], PageWidth -> 700, CellDingbat -> Cell[
            TextData[{"\[FilledSmallSquare]"}], FontSize -> 12, FontColor -> 
            GrayLevel[0.5]], CellMargins -> {{78, Inherited}, {4, 8}}, 
          CellChangeTimes -> {{3.651515120816633*^9, 3.651515125814807*^9}, 
            3.6515155174947033`*^9}, LineSpacing -> {1.25, 1., 2.}, 
          MenuSortingValue -> 10040, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25], $CellContext`ReturnCreatesNewCell -> 
          True], 
         Cell[
          StyleData["TechNote", "Printout"], 
          CellMargins -> {{82, Inherited}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["MoreExploreSection"], PageWidth -> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 30}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["MoreExploreSection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["MoreExplore"], PageWidth -> 700, 
          CellMargins -> {{64, Inherited}, {4, 8}}, PageBreakBelow -> False, 
          MenuSortingValue -> 10050, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0], $CellContext`ReturnCreatesNewCell -> 
          True], 
         Cell[
          StyleData["MoreExplore", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["MoreExploreShortURL"], 
          CellMargins -> {{64, Inherited}, {4, 8}}, PageBreakBelow -> False, 
          FontFamily -> "Source Sans Pro Light", FontSize -> 14, FontSlant -> 
          "Plain", FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["MoreExploreShortURL", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Text"], CellMargins -> {{66, 10}, {4, 14}}, FontFamily -> 
          "Baskerville", FontSize -> 18, FontColor -> 
          GrayLevel[0], $CellContext`ReturnCreatesNewCell -> True], 
         Cell[
          StyleData["Text", "Printout"], CellMargins -> {{66, 10}, {7, 7}}]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ResourcesText"], CellMargins -> {{66, 10}, {2, 0}}, 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Plain", FontColor -> 
          GrayLevel[0], $CellContext`ReturnCreatesNewCell -> True], 
         Cell[
          StyleData["ResourcesText", "Printout"], 
          CellMargins -> {{66, 10}, {2, 0}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ResourcesLink"], CellMargins -> {{66, 10}, {2, 0}}, 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Italic", FontColor -> 
          GrayLevel[0], $CellContext`ReturnCreatesNewCell -> True], 
         Cell[
          StyleData["ResourcesLink", "Printout"], 
          CellMargins -> {{66, 10}, {2, 0}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CodeCaption"], CellFrame -> {{0, 0}, {0, 0}}, 
          CellMargins -> {{66, 10}, {4, 12}}, PageBreakBelow -> False, 
          CellFrameColor -> GrayLevel[0.4], MenuSortingValue -> 10010, 
          MenuCommandKey -> "1", FontFamily -> "Source Sans Pro", FontSize -> 
          16, FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["CodeCaption", "Printout"], 
          CellMargins -> {{66, 10}, {4, 12}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Input"], CellMargins -> {{99, 10}, {3, 7}}, SpanMaxSize -> 
          1, FontSize -> 15], 
         Cell[
          StyleData["Input", "Printout"], CellMargins -> {{99, 10}, {3, 7}}]},
         Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Output"], CellMargins -> {{99, 10}, {14, 7}}, FontSize -> 
          15], 
         Cell[
          StyleData["Output", "Printout"], 
          CellMargins -> {{99, 10}, {14, 7}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["InputOnly"], CellMargins -> {{99, 10}, {25, 10}}, 
          SpanMaxSize -> 1, MenuSortingValue -> 1500, FontSize -> 15], 
         Cell[
          StyleData["InputOnly", "Printout"], 
          CellMargins -> {{99, 10}, {15, 10}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CellLabel"], 
          CellLabelMargins -> {{12, Inherited}, {Inherited, Inherited}}, 
          LanguageCategory -> None, StyleMenuListing -> None, FontFamily -> 
          "Helvetica Neue", FontSize -> 9, FontWeight -> "Plain", FontSlant -> 
          "Plain", FontColor -> GrayLevel[0.5]], 
         Cell[
          StyleData["CellLabel", "Printout"], FontSize -> 8, FontColor -> 
          GrayLevel[0.5]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Message"], Editable -> False, 
          CellMargins -> {{66, Inherited}, {Inherited, Inherited}}, 
          CellGroupingRules -> "OutputGrouping", TextClipboardType -> 
          "PlainText", PageBreakWithin -> False, GroupPageBreakWithin -> 
          False, GeneratedCell -> True, CellAutoOverwrite -> True, 
          ShowCellLabel -> False, DefaultFormatType -> 
          DefaultOutputFormatType, ContextMenu -> 
          FEPrivate`FrontEndResource["ContextMenus", "Output"], 
          ShowAutoStyles -> False, ShowSyntaxStyles -> False, 
          AutoStyleOptions -> {
           "StringStyle" -> None, "SyntaxErrorStyle" -> None}, 
          HyphenationOptions -> {"HyphenationCharacter" -> "\[Continuation]"},
           AutoItalicWords -> {}, AutoQuoteCharacters -> {}, 
          PasteAutoQuoteCharacters -> {}, LanguageCategory -> None, 
          FormatType -> InputForm, ShowStringCharacters -> False, 
          CounterIncrements -> "Message", MenuSortingValue -> 1600, 
          StyleMenuListing -> None, FontFamily :> 
          CurrentValue["PanelFontFamily"], FontSize -> 11, FontColor -> 
          RGBColor[0.5072, 0.16933, 0.15221], $CellContext`StripStyleOnPaste -> 
          True], 
         Cell[
          StyleData["Message", "Printout"], 
          CellMargins -> {{100, Inherited}, {Inherited, Inherited}}, 
          CellFrameLabels -> {{None, None}, {None, None}}, FontColor -> 
          GrayLevel[0]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseInput", StyleDefinitions -> StyleData["Input"]], 
          CellMargins -> {{88, 10}, {4, 7}}, ShowCellLabel -> False, 
          SpanMaxSize -> 1, FontSize -> 
          14, $CellContext`GeneratedCellStyles -> {
           "Output" -> "ExerciseOutput"}], 
         Cell[
          StyleData["ExerciseInput", "Printout"], 
          CellMargins -> {{88, 10}, {4, 7}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "ExerciseOutput", StyleDefinitions -> StyleData["Output"]], 
          CellMargins -> {{88, 10}, {10, 4}}, ShowCellLabel -> False, 
          FontSize -> 14], 
         Cell[
          StyleData["ExerciseOutput", "Printout"], 
          CellMargins -> {{88, 10}, {10, 4}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Picture"], CellMargins -> {{66, 10}, {10, 10}}, 
          CellGroupingRules -> "GraphicsGrouping", StyleMenuListing -> None], 
         
         Cell[
          StyleData["Picture", "Printout"], 
          CellMargins -> {{66, 10}, {8, 8}}]}, Closed]], 
      Cell[
       StyleData["ExerciseSummaryCell"], PageWidth -> 700, CellFrame -> 0, 
       CellMargins -> {{64, Inherited}, {8, 10}}, 
       CellGroupingRules -> {"SectionGrouping", 64}, PageBreakBelow -> False, 
       ShowCellLabel -> False, CellFrameMargins -> 0, ShowStringCharacters -> 
       False, FontFamily -> "Source Sans Pro", FontSize -> 18, FontColor -> 
       RGBColor[1, 1, 1], 
       GridBoxOptions -> {GridBoxBackground -> {"Columns" -> {{
              RGBColor[0.990997, 0.539528, 0.155779], 
              RGBColor[0.989487, 0.434699, 0.0320439]}}, "Rows" -> {{None}}}, 
         GridBoxItemSize -> {"Columns" -> {
             Scaled[0.7], 
             Scaled[0.3]}, "Rows" -> {{Automatic}}}}], 
      Cell[
       StyleData["ExerciseSummaryHeading"], ShowStringCharacters -> False, 
       FontFamily -> "Source Sans Pro", FontSize -> 18, FontColor -> 
       RGBColor[1, 1, 1]], 
      Cell[
       StyleData["ExerciseSummarySubheading"], ShowStringCharacters -> False, 
       FontFamily -> "Source Sans Pro", FontSize -> 15, FontColor -> 
       RGBColor[1., 0.9294117647058824, 0.7215686274509804]], 
      Cell[
       StyleData["ExercisePreviewButtonText"], ShowStringCharacters -> False, 
       FontFamily -> "Source Sans Pro", FontSize -> 14, FontSlant -> "Plain", 
       FontColor -> RGBColor[0.6, 0.6, 0.6]], 
      Cell[
       StyleData["ExercisePreviewButtonTextHighlight"], ShowStringCharacters -> 
       False, FontFamily -> "Source Sans Pro", FontSize -> 14, FontSlant -> 
       "Plain", FontColor -> 
       RGBColor[
        0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]]}, 
     Closed]], 
   Cell[
    CellGroupData[{
      Cell[
      "Inline and special formatting", "Section", 
       CellChangeTimes -> {{3.646681732592888*^9, 3.646681749414035*^9}}], 
      Cell[
       StyleData["Graphics"], MenuSortingValue -> None], 
      Cell[
       StyleData["Graphics3D"], MenuSortingValue -> None], 
      Cell[
       StyleData["StandardForm"], 
       InputAutoReplacements -> {
        "->" -> "\[Rule]", ":>" -> "\[RuleDelayed]", "<=" -> "\[LessEqual]", 
         ">=" -> "\[GreaterEqual]", "!=" -> "\[NotEqual]", "==" -> "\[Equal]",
          "@>" -> "\\[InlinePart]", "<->" -> "\[UndirectedEdge]", ParentList},
        LineSpacing -> {1.25, 0, 2}, SingleLetterItalics -> False, 
       StyleMenuListing -> None, FontFamily -> "Source Sans Pro", 
       PrivateFontOptions -> {"OperatorSubstitution" -> True}], 
      Cell[
       StyleData["OutputForm"], PageWidth -> DirectedInfinity[1], 
       TextAlignment -> Left, LineSpacing -> {0.6, 1}, 
       AutoQuoteCharacters -> {}, PasteAutoQuoteCharacters -> {}, 
       StyleMenuListing -> None, FontFamily -> "Source Sans Pro", 
       PrivateFontOptions -> {"OperatorSubstitution" -> True}], 
      Cell[
       StyleData["InputForm"], PageWidth -> DirectedInfinity[1], 
       InputAutoReplacements -> {}, AllowInlineCells -> False, Hyphenation -> 
       False, AutoQuoteCharacters -> {}, PasteAutoQuoteCharacters -> {}, 
       AutoSpacing -> False, NumberMarks -> True, AutoNumberFormatting -> 
       False, StyleMenuListing -> None, FontFamily -> "Source Sans Pro", 
       PrivateFontOptions -> {"OperatorSubstitution" -> True}], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["DetailsLink"], FontFamily -> "Source Sans Pro", FontSize :> 
          If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.9]], FontColor -> GrayLevel[0], 
          ButtonBoxOptions -> {
           ButtonFunction :> (
             Function[$CellContext`t, 
              NotebookFind[$CellContext`t, "Notes", All, CellStyle]; 
              NotebookFind[$CellContext`t, "NotesSection", All, CellStyle, 
                AutoScroll -> Top]][
              Documentation`HelpLookup[
               StringJoin["ref/", #]]]& ), ButtonSource -> ButtonContents, 
            Evaluator -> Automatic}], 
         Cell[
          StyleData["DetailsLink", "Printout"], FontFamily -> 
          "Source Sans Pro", FontSize :> If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.88]], FontColor -> GrayLevel[0]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["LinkAlt"], FontFamily -> "Source Sans Pro", FontSize :> 
          If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.9]], FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["LinkAlt", "Printout"], FontFamily -> "Source Sans Pro", 
          FontSize :> If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.88]], FontColor -> GrayLevel[0]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Hyperlink"], MenuSortingValue -> None, FontColor -> 
          RGBColor[0.3, 0.35, 0.5]], 
         Cell[
          StyleData["Hyperlink", "Printout"]]}, Closed]], 
      Cell[
       StyleData[
       "IndexNavigationLink", StyleDefinitions -> StyleData["Hyperlink"]], 
       MenuSortingValue -> None, FontColor -> 
       RGBColor[
        0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
      Cell[
       StyleData["Crosslink"], 
       ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
            
            NotebookLocate[#2, "OpenInNewWindow" -> 
             CurrentValue["HyperlinkModifierKey"]]}]& ), Evaluator -> None, 
         Method -> "Queued"}], 
      Cell[
       StyleData["VocabularyLink"], FontColor -> GrayLevel[0], 
       ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
            
            NotebookLocate[#2, "OpenInNewWindow" -> 
             CurrentValue["HyperlinkModifierKey"]]}]& ), Evaluator -> None, 
         Method -> "Queued"}], 
      Cell[
       StyleData["InlineCode"], SpanMaxSize -> 1, FontColor -> GrayLevel[0]], 
      
      Cell[
       StyleData["InlineCodeText"], SpanMaxSize -> 1, FontFamily -> 
       "Source Sans Pro", FontSize -> 0.95 Inherited], 
      Cell[
       StyleData["NoLabel"], ShowCellLabel -> 
       False, $CellContext`GeneratedCellStyles -> {
        "Output" -> "ExerciseOutput"}], 
      Cell[
       StyleData["MenuName"], FontFamily -> "Verdana", FontWeight -> "Bold", 
       FontColor -> GrayLevel[0.286275]], 
      Cell[
       StyleData["KeyEvent"], CellFrame -> {{0.5, 0.5}, {0.5, 0.5}}, 
       CellFrameMargins -> {{2, 2}, {2, 2}}, CellFrameColor -> GrayLevel[0.7],
        FontFamily -> "Verdana", FontColor -> GrayLevel[0.4]], 
      Cell[
       StyleData["KeyEventDelimiter"], FontColor -> GrayLevel[0.5]], 
      Cell[
       CellGroupData[{
         Cell["Key Styles", "Subsubsection"], 
         Cell[
          StyleData["Key0"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {"Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-2, -2}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}], 
         Cell[
          StyleData["Key1"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #2, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {
                 "ColumnsIndexed" -> {2 -> GrayLevel[0.8352941176470589]}, 
                  "Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-2, -2}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}], 
         Cell[
          StyleData["Key2"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #2, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #3, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {
                 "ColumnsIndexed" -> {
                   2 -> GrayLevel[0.8352941176470589], 3 -> 
                    GrayLevel[0.8352941176470589]}, "Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-2, -2}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}], 
         Cell[
          StyleData["Key3"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #2, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   TemplateBox[{"\[ThickSpace]", #3, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #4, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {
                 "ColumnsIndexed" -> {
                   2 -> GrayLevel[0.8352941176470589], 3 -> 
                    GrayLevel[0.8352941176470589], 4 -> 
                    GrayLevel[0.8352941176470589]}, "Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-2, -2}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Entity styles", "Subsubsection"], 
         Cell[
          StyleData["Entity"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               PaneSelectorBox[{True -> GridBox[{{
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontFamily -> "Source Sans Pro", 
                    FontWeight -> "Plain", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}},
                    BaselinePosition -> {1, 1}], False -> 
                 PaneBox[#, 
                   BaseStyle -> {
                    FontColor -> RGBColor[0.395437, 0.20595, 0.061158]}, 
                   BaselinePosition -> Baseline]}, 
                Dynamic[
                 CurrentValue[Evaluatable]], ImageSize -> Automatic, 
                BaselinePosition -> Baseline, 
                BaseStyle -> {FontFamily -> "Helvetica"}], FrameStyle -> 
               RGBColor[1., 0.504768, 0.], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityFrameless"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              PaneSelectorBox[{True -> GridBox[{{
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontFamily -> "Source Sans Pro", 
                    FontWeight -> "Plain", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                  BaselinePosition -> {1, 1}], False -> 
                PaneBox[#, 
                  BaseStyle -> {
                   FontColor -> RGBColor[0.395437, 0.20595, 0.061158]}, 
                  BaselinePosition -> Baseline]}, 
               Dynamic[
                CurrentValue[Evaluatable]], ImageSize -> Automatic, 
               BaselinePosition -> Baseline, 
               BaseStyle -> {FontFamily -> "Helvetica"}], #3, 
              BaseStyle -> {
               ShowStringCharacters -> False, LineIndent -> 0, 
                PrivateFontOptions -> {
                 FontWeight -> "Plain", "OperatorSubstitution" -> False}}]& ),
             Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityFramelessHot"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {
           DisplayFunction -> (PaneSelectorBox[{True -> GridBox[{{
                   
                   StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0]], 
                   StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0], Selectable -> 
                    False]}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 1}], False -> 
               PaneBox[#, BaseStyle -> {FontColor -> GrayLevel[0]}, 
                 BaselinePosition -> Baseline]}, 
              Dynamic[
               CurrentValue[Evaluatable]], ImageSize -> Automatic, 
              BaselinePosition -> Baseline, 
              BaseStyle -> {
               FontWeight -> "Plain", FontFamily -> "Helvetica", 
                ShowStringCharacters -> False, LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityClass"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               PaneSelectorBox[{True -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}},
                    BaselinePosition -> {1, 2}], False -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]]}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}},
                    BaselinePosition -> {1, 2}]}, 
                Dynamic[
                 CurrentValue[Evaluatable]], ImageSize -> Automatic, 
                BaselinePosition -> Baseline, 
                BaseStyle -> {FontFamily -> "Helvetica"}], FrameStyle -> 
               RGBColor[1., 0.504768, 0.], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityClassFrameless"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              PaneSelectorBox[{True -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                  BaselinePosition -> {1, 2}], False -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]]}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                  BaselinePosition -> {1, 2}]}, 
               Dynamic[
                CurrentValue[Evaluatable]], ImageSize -> Automatic, 
               BaselinePosition -> Baseline, 
               BaseStyle -> {FontFamily -> "Helvetica"}], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityClassFramelessHot"], ShowStringCharacters -> False,
           TemplateBoxOptions -> {
           DisplayFunction -> (PaneSelectorBox[{True -> GridBox[{{
                   PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                   
                   StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0]], 
                   StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0], Selectable -> 
                    False]}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 2}], False -> GridBox[{{
                   PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                   StyleBox[#, FontColor -> GrayLevel[0]]}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 2}]}, 
              Dynamic[
               CurrentValue[Evaluatable]], ImageSize -> Automatic, 
              BaselinePosition -> Baseline, 
              BaseStyle -> {
               FontWeight -> "Plain", FontFamily -> "Helvetica", 
                ShowStringCharacters -> False, LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityProperty"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               
               PaneBox[#, 
                BaseStyle -> {
                 FontSlant -> Italic, FontWeight -> Plain, FontFamily -> 
                  "Source Sans Pro", FontColor -> 
                  RGBColor[0.395437, 0.20595, 0.061158]}, BaselinePosition -> 
                Baseline], FrameStyle -> 
               RGBColor[0.94227, 0.703639, 0.033387], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityPropertyClass"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               PaneBox[
                GridBox[{{
                   PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], #}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 2}], 
                BaseStyle -> {
                 FontSlant -> Italic, FontWeight -> Plain, FontFamily -> 
                  "Source Sans Pro", FontColor -> 
                  RGBColor[0.395437, 0.20595, 0.061158]}, BaselinePosition -> 
                Baseline], FrameStyle -> 
               RGBColor[0.94227, 0.703639, 0.033387], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityValue"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              
              GridBox[{{#, #2}}, GridBoxAlignment -> {"Rows" -> {{Baseline}}},
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
               GridBoxSpacings -> {"Columns" -> {{0}}}, 
               BaselinePosition -> {1, 1}], Background -> 
              RGBColor[{0.9921568627450981, 0.9529411764705882, 
                0.8509803921568627}], BaselinePosition -> Baseline, 
              FrameMargins -> {{1, 1}, {1, 1}}, ImageMargins -> 2, FrameStyle -> 
              RGBColor[{0.9333333333333333, 0.8470588235294118, 
                0.5529411764705883}], RoundingRadius -> 5]& )}]}, Closed]]}, 
     Closed]]}, Visible -> False, FrontEndVersion -> 
  "11.1 for Mac OS X x86 (32-bit, 64-bit Kernel) (March 16, 2017)", 
  StyleDefinitions -> "StylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "p:255"->{
  Cell[674, 24, 477, 12, 
  70, "SectionDoubleDigit", "ExpressionUUID" -> "1394128b-543a-405b-b06c-
   c27b47fc2e8e",
   CounterAssignments->{{"Section", 41}, {"Subsection", 0}, {
     "Subsubsection", 0}, {"Exercise", 0}},
   CellTags->"p:255"]},
 "i:1"->{
  Cell[1154, 38, 883, 25, 
  70, "Text", "ExpressionUUID" -> "c0261fd0-d513-4a89-a19d-d6062c6b6508",
   CellTags->"i:1"]},
 "i:2"->{
  Cell[2040, 65, 334, 9, 
  70, "CodeCaption", "ExpressionUUID" -> "e3c2d860-7d83-439e-977b-64f2466b66e3
   ",
   CellTags->"i:2"]},
 "i:3"->{
  Cell[5098, 167, 1549, 42, 
  70, "Text", "ExpressionUUID" -> "1aa02fa6-a322-4d89-93ea-ddc8ab1d708c",
   CellTags->"i:3"]},
 "i:4"->{
  Cell[8746, 281, 245, 8, 
  70, "CodeCaption", "ExpressionUUID" -> "80d2363c-44df-4c29-8db3-f2e98ace43e2
   ",
   CellTags->"i:4"]},
 "i:5"->{
  Cell[10071, 329, 205, 4, 
  70, "CodeCaption", "ExpressionUUID" -> "babf1288-c3df-4765-b351-dddd20afdf54
   ",
   CellTags->"i:5"]},
 "LastCellOfAPage"->{
  Cell[10683, 348, 244, 5, 
  70, "Output", "ExpressionUUID" -> "fb47eaeb-1d83-4510-b91b-611d94da68d8",
   Evaluatable->False,
   CellTags->"LastCellOfAPage"],
  Cell[19753, 652, 362, 9, 
  70, "Output", "ExpressionUUID" -> "b7919ce3-345b-4b26-ae87-8a71c7ca5ad6",
   Evaluatable->False,
   CellTags->"LastCellOfAPage"],
  Cell[27408, 908, 241, 5, 
  70, "Output", "ExpressionUUID" -> "71c3b31f-b2e5-4eaf-a2db-577770427081",
   Evaluatable->False,
   CellTags->"LastCellOfAPage"],
  Cell[29445, 979, 5542, 149, 
  70, "VocabularyTable", "ExpressionUUID" -> "9420134a-aaf2-4a1a-
   aeff-61d6e4394785",
   CellTags->"LastCellOfAPage"],
  Cell[185463, 4620, 352, 8, 
  70, "MoreExplore", "ExpressionUUID" -> "5cf5696e-4642-4c76-8ec0-63d83b4ed9f0
   ",
   CellTags->"LastCellOfAPage"]},
 "p:256"->{
  Cell[10942, 356, 469, 15, 
  70, "CodeCaption", "ExpressionUUID" -> "cd5a5355-e6cc-4b78-8eb7-522108d60bf5
   ",
   CellTags->"p:256"]},
 "i:6"->{
  Cell[12064, 393, 269, 9, 
  70, "CodeCaption", "ExpressionUUID" -> "4dafc477-d41a-43be-80f2-9d9886b724f1
   ",
   CellTags->"i:6"]},
 "i:7"->{
  Cell[13196, 431, 257, 8, 
  70, "Text", "ExpressionUUID" -> "e83a12b3-4394-4f27-a43b-43c5a5f14f7b",
   CellTags->"i:7"]},
 "i:8"->{
  Cell[14606, 479, 570, 18, 
  70, "Text", "ExpressionUUID" -> "399502b8-f9ee-4a31-b846-25a34ddf7a1e",
   CellTags->"i:8"]},
 "i:9"->{
  Cell[15999, 527, 518, 16, 
  70, "Text", "ExpressionUUID" -> "e8a4ab66-255e-4d0b-90bc-e02a2d27e17a",
   CellTags->"i:9"]},
 "i:10"->{
  Cell[18157, 599, 373, 11, 
  70, "Text", "ExpressionUUID" -> "e9679f15-5e5b-4aee-af04-7714652fb909",
   CellTags->"i:10"]},
 "i:11"->{
  Cell[20130, 664, 480, 13, 
  70, "Text", "ExpressionUUID" -> "afa9afd6-b208-46e9-9e01-8bbd409a0f2b",
   CellTags->{"i:11", "p:257"}]},
 "p:257"->{
  Cell[20130, 664, 480, 13, 
  70, "Text", "ExpressionUUID" -> "afa9afd6-b208-46e9-9e01-8bbd409a0f2b",
   CellTags->{"i:11", "p:257"}]},
 "i:12"->{
  Cell[21341, 704, 416, 12, 
  70, "Text", "ExpressionUUID" -> "119027c5-c5ec-4814-9ae5-39b5c7a7d43b",
   CellTags->"i:12"]},
 "i:13"->{
  Cell[22669, 750, 344, 10, 
  70, "Text", "ExpressionUUID" -> "79886491-4db1-4a28-8f1f-9cd3e0bf48b3",
   CellTags->"i:13"]},
 "i:14"->{
  Cell[23880, 790, 401, 10, 
  70, "Text", "ExpressionUUID" -> "01bc5af0-a0c0-42ba-be0e-ca909f3aa779",
   CellTags->"i:14"]},
 "i:15"->{
  Cell[24284, 802, 404, 12, 
  70, "CodeCaption", "ExpressionUUID" -> "df7f9595-c740-478d-8507-c65acabba86f
   ",
   CellTags->"i:15"]},
 "i:16"->{
  Cell[25172, 832, 205, 4, 
  70, "CodeCaption", "ExpressionUUID" -> "ccec5401-fe14-46cd-9fb3-911a028f4acb
   ",
   CellTags->"i:16"]},
 "i:17"->{
  Cell[27664, 916, 341, 10, 
  70, "CodeCaption", "ExpressionUUID" -> "13810c7f-fd59-4b48-a33a-18b98f0f577b
   ",
   CellTags->{"i:17", "p:258"}]},
 "p:258"->{
  Cell[27664, 916, 341, 10, 
  70, "CodeCaption", "ExpressionUUID" -> "13810c7f-fd59-4b48-a33a-18b98f0f577b
   ",
   CellTags->{"i:17", "p:258"}]},
 "i:18"->{
  Cell[28518, 946, 240, 6, 
  70, "CodeCaption", "ExpressionUUID" -> "2054f04c-0e73-4d19-9a64-da44c4afed99
   ",
   CellTags->"i:18"]},
 "i:19"->{
  Cell[180630, 4442, 352, 10, 
  70, "Answer", "ExpressionUUID" -> "dcb4f2b2-8f13-4f29-8287-b3fb87b6fd54",
   CellTags->"i:19"]},
 "i:20"->{
  Cell[181181, 4460, 297, 9, 
  70, "Answer", "ExpressionUUID" -> "0bfb3bc0-aa78-471b-9f80-504be374d5a6",
   CellTags->"i:20"]},
 "i:21"->{
  Cell[181675, 4480, 431, 13, 
  70, "TechNote", "ExpressionUUID" -> "d2f0c9be-1ed2-4599-a43d-107e814d91e4",
   CellTags->"i:21"]},
 "i:22"->{
  Cell[182109, 4495, 343, 10, 
  70, "TechNote", "ExpressionUUID" -> "f6660831-fa83-495c-9de4-663a2a7439dd",
   CellTags->"i:22"]},
 "i:23"->{
  Cell[182455, 4507, 369, 9, 
  70, "TechNote", "ExpressionUUID" -> "5591d17d-519e-4ea3-9794-f0c47cc7ccf5",
   CellTags->"i:23"]},
 "i:24"->{
  Cell[182827, 4518, 595, 27, 
  70, "TechNote", "ExpressionUUID" -> "6e7c29c2-2ecf-40bb-9b12-471c7ce79c3c",
   CellTags->"i:24"]},
 "i:25"->{
  Cell[183425, 4547, 710, 21, 
  70, "TechNote", "ExpressionUUID" -> "d2b0e5ed-4ffd-43be-b5f4-fa4886426a61",
   CellTags->"i:25"]},
 "i:26"->{
  Cell[184138, 4570, 325, 9, 
  70, "TechNote", "ExpressionUUID" -> "fc55a690-bf5b-4c0e-ae10-8e95c3af129d",
   CellTags->"i:26"]},
 "i:27"->{
  Cell[184466, 4581, 472, 17, 
  70, "TechNote", "ExpressionUUID" -> "3b754f5f-da04-486e-ae89-d9275faa5b88",
   CellTags->"i:27"]},
 "i:28"->{
  Cell[184941, 4600, 317, 9, 
  70, "TechNote", "ExpressionUUID" -> "34fc8e7d-1d9e-4258-9094-3fc88fdefdf0",
   CellTags->"i:28"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"p:255", 275570, 6451},
 {"i:1", 275828, 6458},
 {"i:2", 275961, 6462},
 {"i:3", 276104, 6467},
 {"i:4", 276239, 6471},
 {"i:5", 276383, 6476},
 {"LastCellOfAPage", 276540, 6481},
 {"p:256", 277334, 6502},
 {"i:6", 277482, 6507},
 {"i:7", 277627, 6512},
 {"i:8", 277761, 6516},
 {"i:9", 277896, 6520},
 {"i:10", 278032, 6524},
 {"i:11", 278169, 6528},
 {"p:257", 278318, 6532},
 {"i:12", 278466, 6536},
 {"i:13", 278603, 6540},
 {"i:14", 278740, 6544},
 {"i:15", 278877, 6548},
 {"i:16", 279025, 6553},
 {"i:17", 279172, 6558},
 {"p:258", 279332, 6563},
 {"i:18", 279491, 6568},
 {"i:19", 279638, 6573},
 {"i:20", 279779, 6577},
 {"i:21", 279919, 6581},
 {"i:22", 280062, 6585},
 {"i:23", 280205, 6589},
 {"i:24", 280347, 6593},
 {"i:25", 280490, 6597},
 {"i:26", 280633, 6601},
 {"i:27", 280775, 6605},
 {"i:28", 280918, 6609}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[674, 24, 477, 12, 70, "SectionDoubleDigit", "ExpressionUUID" -> \
"1394128b-543a-405b-b06c-c27b47fc2e8e",
 CounterAssignments->{{"Section", 41}, {"Subsection", 0}, {
   "Subsubsection", 0}, {"Exercise", 0}},
 CellTags->"p:255"],
Cell[1154, 38, 883, 25, 70, "Text", "ExpressionUUID" -> \
"c0261fd0-d513-4a89-a19d-d6062c6b6508",
 CellTags->"i:1"],
Cell[2040, 65, 334, 9, 70, "CodeCaption", "ExpressionUUID" -> \
"e3c2d860-7d83-439e-977b-64f2466b66e3",
 CellTags->"i:2"],
Cell[CellGroupData[{
Cell[2399, 78, 263, 5, 70, "Input", "ExpressionUUID" -> \
"a2f1622f-78f3-4902-ade2-51e8062328f7"],
Cell[2665, 85, 277, 7, 70, "Output", "ExpressionUUID" -> \
"19918ecd-9f82-4b8c-bd4e-44f90da2914d",
 Evaluatable->False]
}, Open  ]],
Cell[2957, 95, 299, 9, 70, "CodeCaption", "ExpressionUUID" -> \
"d370bb39-857f-4572-9075-3594589483d0"],
Cell[CellGroupData[{
Cell[3281, 108, 285, 5, 70, "Input", "ExpressionUUID" -> \
"4f1a20bb-3897-4cb6-9969-e3615c89f89c"],
Cell[3569, 115, 285, 7, 70, "Output", "ExpressionUUID" -> \
"a691e690-410e-4dec-8d80-8860ad74e3d7",
 Evaluatable->False]
}, Open  ]],
Cell[3869, 125, 431, 12, 70, "CodeCaption", "ExpressionUUID" -> \
"bd11ef34-5403-4400-855d-5a4093c8b039"],
Cell[CellGroupData[{
Cell[4325, 141, 330, 7, 70, "Input", "ExpressionUUID" -> \
"38be39d5-7b61-4aed-b27a-24866eacfd2f"],
Cell[4658, 150, 425, 14, 70, "Output", "ExpressionUUID" -> \
"a7b08dc2-00e2-474f-96f7-5456df14b61b",
 Evaluatable->False]
}, Open  ]],
Cell[5098, 167, 1549, 42, 70, "Text", "ExpressionUUID" -> \
"1aa02fa6-a322-4d89-93ea-ddc8ab1d708c",
 CellTags->"i:3"],
Cell[6650, 211, 402, 12, 70, "CodeCaption", "ExpressionUUID" -> \
"b235e84a-a6b2-4ee9-9903-7c9b3ee7e173"],
Cell[CellGroupData[{
Cell[7077, 227, 336, 7, 70, "Input", "ExpressionUUID" -> \
"62626fa1-558d-4535-86aa-71671b852031"],
Cell[7416, 236, 247, 7, 70, "Output", "ExpressionUUID" -> \
"82781b3a-c2cc-4bb4-ba87-fcd162b2937e",
 Evaluatable->False]
}, Open  ]],
Cell[7678, 246, 415, 12, 70, "CodeCaption", "ExpressionUUID" -> \
"ad83f1c2-1326-45b4-9174-39e1f66cdaf2"],
Cell[CellGroupData[{
Cell[8118, 262, 347, 7, 70, "Input", "ExpressionUUID" -> \
"a4add623-4591-47b2-a264-9ce829cf8096"],
Cell[8468, 271, 263, 7, 70, "Output", "ExpressionUUID" -> \
"b9418834-08db-401e-a2a9-d98707065cdf",
 Evaluatable->False]
}, Open  ]],
Cell[8746, 281, 245, 8, 70, "CodeCaption", "ExpressionUUID" -> \
"80d2363c-44df-4c29-8db3-f2e98ace43e2",
 CellTags->"i:4"],
Cell[CellGroupData[{
Cell[9016, 293, 385, 8, 70, "Input", "ExpressionUUID" -> \
"7a2bd344-a9df-482e-879f-c5d83a6704c6"],
Cell[9404, 303, 321, 10, 70, "Output", "ExpressionUUID" -> \
"c136f2c3-8092-47c2-a63c-cbfe38181aa9",
 Evaluatable->False]
}, Open  ]],
Cell[9740, 316, 328, 11, 70, "Text", "ExpressionUUID" -> \
"f858eef0-bb49-4075-bce5-a303274a323b"],
Cell[10071, 329, 205, 4, 70, "CodeCaption", "ExpressionUUID" -> \
"babf1288-c3df-4765-b351-dddd20afdf54",
 CellTags->"i:5"],
Cell[CellGroupData[{
Cell[10301, 337, 379, 9, 70, "Input", "ExpressionUUID" -> \
"6e7e69f1-a81c-4a27-a492-ee0b30290d59"],
Cell[10683, 348, 244, 5, 70, "Output", "ExpressionUUID" -> \
"fb47eaeb-1d83-4510-b91b-611d94da68d8",
 Evaluatable->False,
 CellTags->"LastCellOfAPage"]
}, Open  ]],
Cell[10942, 356, 469, 15, 70, "CodeCaption", "ExpressionUUID" -> \
"cd5a5355-e6cc-4b78-8eb7-522108d60bf5",
 CellTags->"p:256"],
Cell[CellGroupData[{
Cell[11436, 375, 404, 9, 70, "Input", "ExpressionUUID" -> \
"3654b4da-08fa-4d54-ae2b-14acebef1168"],
Cell[11843, 386, 206, 4, 70, "Output", "ExpressionUUID" -> \
"0f52fa2a-bfec-40c0-8928-7af6a7cf5418",
 Evaluatable->False]
}, Open  ]],
Cell[12064, 393, 269, 9, 70, "CodeCaption", "ExpressionUUID" -> \
"4dafc477-d41a-43be-80f2-9d9886b724f1",
 CellTags->"i:6"],
Cell[CellGroupData[{
Cell[12358, 406, 450, 12, 70, "Input", "ExpressionUUID" -> \
"4a5944b3-27cb-4e8a-998d-21bf77f4ec5b"],
Cell[12811, 420, 370, 8, 70, "Output", "ExpressionUUID" -> \
"aad01564-0e97-4920-9296-49378ad6a342",
 Evaluatable->False]
}, Open  ]],
Cell[13196, 431, 257, 8, 70, "Text", "ExpressionUUID" -> \
"e83a12b3-4394-4f27-a43b-43c5a5f14f7b",
 CellTags->"i:7"],
Cell[13456, 441, 431, 12, 70, "CodeCaption", "ExpressionUUID" -> \
"107309f6-fb19-486c-9f54-613ca60993b4"],
Cell[CellGroupData[{
Cell[13912, 457, 362, 10, 70, "Input", "ExpressionUUID" -> \
"000626ed-14c7-4d06-94cd-ffe36c600e7f"],
Cell[14277, 469, 314, 7, 70, "Output", "ExpressionUUID" -> \
"a71c5ff9-9990-4302-a3cf-46816d0ed128",
 Evaluatable->False]
}, Open  ]],
Cell[14606, 479, 570, 18, 70, "Text", "ExpressionUUID" -> \
"399502b8-f9ee-4a31-b846-25a34ddf7a1e",
 CellTags->"i:8"],
Cell[15179, 499, 184, 4, 70, "CodeCaption", "ExpressionUUID" -> \
"5d4f0f08-c277-4f83-9a01-914da0235741"],
Cell[CellGroupData[{
Cell[15388, 507, 322, 8, 70, "Input", "ExpressionUUID" -> \
"239ca419-433c-412d-bc2d-4e0fa79bc1f0"],
Cell[15713, 517, 271, 7, 70, "Output", "ExpressionUUID" -> \
"24751ca6-4702-4b42-90e1-9ecb539daa31",
 Evaluatable->False]
}, Open  ]],
Cell[15999, 527, 518, 16, 70, "Text", "ExpressionUUID" -> \
"e8a4ab66-255e-4d0b-90bc-e02a2d27e17a",
 CellTags->"i:9"],
Cell[16520, 545, 182, 4, 70, "CodeCaption", "ExpressionUUID" -> \
"f5b875f4-a878-4842-95a5-0a2bde4811eb"],
Cell[CellGroupData[{
Cell[16727, 553, 254, 5, 70, "Input", "ExpressionUUID" -> \
"b2faf823-4096-4224-8916-6879ff95c7e9"],
Cell[16984, 560, 300, 7, 70, "Output", "ExpressionUUID" -> \
"ab7ab4f0-8dad-4827-a1f2-855d1e4246da",
 Evaluatable->False]
}, Open  ]],
Cell[17299, 570, 261, 7, 70, "CodeCaption", "ExpressionUUID" -> \
"38ecabc2-a356-452d-bc53-89f6b4e21eb6"],
Cell[CellGroupData[{
Cell[17585, 581, 311, 7, 70, "Input", "ExpressionUUID" -> \
"cdab55df-ca14-4039-b3d7-e696d0585cda"],
Cell[17899, 590, 243, 6, 70, "Output", "ExpressionUUID" -> \
"1ce6199f-f80e-4302-b545-ea4c50b57d23",
 Evaluatable->False]
}, Open  ]],
Cell[18157, 599, 373, 11, 70, "Text", "ExpressionUUID" -> \
"e9679f15-5e5b-4aee-af04-7714652fb909",
 CellTags->"i:10"],
Cell[18533, 612, 219, 6, 70, "CodeCaption", "ExpressionUUID" -> \
"f2e216f8-697b-4fdb-a379-cb8e8603aa1b"],
Cell[CellGroupData[{
Cell[18777, 622, 186, 3, 70, "Input", "ExpressionUUID" -> \
"8f7eb4e8-ce38-4fb8-8e3d-f0c1d292ccf5"],
Cell[18966, 627, 284, 7, 70, "Output", "ExpressionUUID" -> \
"861082ab-6cd6-478c-9544-f841b9122982",
 Evaluatable->False]
}, Open  ]],
Cell[19265, 637, 195, 4, 70, "CodeCaption", "ExpressionUUID" -> \
"632e1ee0-73d8-417f-9a75-b052158d6704"],
Cell[CellGroupData[{
Cell[19485, 645, 265, 5, 70, "Input", "ExpressionUUID" -> \
"28c2900e-2d92-4ed1-90e8-daf80ce7f220"],
Cell[19753, 652, 362, 9, 70, "Output", "ExpressionUUID" -> \
"b7919ce3-345b-4b26-ae87-8a71c7ca5ad6",
 Evaluatable->False,
 CellTags->"LastCellOfAPage"]
}, Open  ]],
Cell[20130, 664, 480, 13, 70, "Text", "ExpressionUUID" -> \
"afa9afd6-b208-46e9-9e01-8bbd409a0f2b",
 CellTags->{"i:11", "p:257"}],
Cell[20613, 679, 161, 4, 70, "CodeCaption", "ExpressionUUID" -> \
"5acb54bb-cc3f-48a2-8233-a043a502151e"],
Cell[CellGroupData[{
Cell[20799, 687, 240, 5, 70, "Input", "ExpressionUUID" -> \
"cb32c59c-3f72-4442-8624-a89ccddcc820"],
Cell[21042, 694, 284, 7, 70, "Output", "ExpressionUUID" -> \
"62fbd2ee-fcea-4240-855a-71918851f340",
 Evaluatable->False]
}, Open  ]],
Cell[21341, 704, 416, 12, 70, "Text", "ExpressionUUID" -> \
"119027c5-c5ec-4814-9ae5-39b5c7a7d43b",
 CellTags->"i:12"],
Cell[21760, 718, 345, 11, 70, "CodeCaption", "ExpressionUUID" -> \
"be330ba1-39d3-45e0-9a69-23ae1626228a"],
Cell[CellGroupData[{
Cell[22130, 733, 318, 8, 70, "Input", "ExpressionUUID" -> \
"7b917683-f643-434c-88db-35412e860b20"],
Cell[22451, 743, 203, 4, 70, "Output", "ExpressionUUID" -> \
"ad67ceb6-712c-47f5-97d1-0a6679c2438d",
 Evaluatable->False]
}, Open  ]],
Cell[22669, 750, 344, 10, 70, "Text", "ExpressionUUID" -> \
"79886491-4db1-4a28-8f1f-9cd3e0bf48b3",
 CellTags->"i:13"],
Cell[23016, 762, 272, 8, 70, "CodeCaption", "ExpressionUUID" -> \
"5c124477-62db-4918-a9d8-d0d68de1e4b1"],
Cell[CellGroupData[{
Cell[23313, 774, 336, 7, 70, "Input", "ExpressionUUID" -> \
"ba609915-f759-498c-ac18-2ee481c318bf"],
Cell[23652, 783, 213, 4, 70, "Output", "ExpressionUUID" -> \
"be41a906-1121-4ac5-bf76-99f8371770bc",
 Evaluatable->False]
}, Open  ]],
Cell[23880, 790, 401, 10, 70, "Text", "ExpressionUUID" -> \
"01bc5af0-a0c0-42ba-be0e-ca909f3aa779",
 CellTags->"i:14"],
Cell[24284, 802, 404, 12, 70, "CodeCaption", "ExpressionUUID" -> \
"df7f9595-c740-478d-8507-c65acabba86f",
 CellTags->"i:15"],
Cell[CellGroupData[{
Cell[24713, 818, 243, 5, 70, "Input", "ExpressionUUID" -> \
"5f89fa22-cca4-4d9c-8b7b-ea582bb57d30"],
Cell[24959, 825, 198, 4, 70, "Output", "ExpressionUUID" -> \
"bf004be7-efd3-49f3-81c2-01bcd1e3ed10",
 Evaluatable->False]
}, Open  ]],
Cell[25172, 832, 205, 4, 70, "CodeCaption", "ExpressionUUID" -> \
"ccec5401-fe14-46cd-9fb3-911a028f4acb",
 CellTags->"i:16"],
Cell[CellGroupData[{
Cell[25402, 840, 439, 11, 70, "Input", "ExpressionUUID" -> \
"9d7b408a-18fc-43d4-a2bd-f97ec52747a2"],
Cell[25844, 853, 224, 4, 70, "Output", "ExpressionUUID" -> \
"2f228083-002d-43bd-95e1-a59463575720",
 Evaluatable->False]
}, Open  ]],
Cell[26083, 860, 570, 18, 70, "Text", "ExpressionUUID" -> \
"62e5237a-3355-4fcc-a0fb-e86e9be10c6c"],
Cell[26656, 880, 496, 17, 70, "CodeCaption", "ExpressionUUID" -> \
"060d4607-a6c4-4356-b47d-6ba91ad8b101"],
Cell[CellGroupData[{
Cell[27177, 901, 228, 5, 70, "Input", "ExpressionUUID" -> \
"1165fd87-9098-4150-b79f-fb064d8ba886"],
Cell[27408, 908, 241, 5, 70, "Output", "ExpressionUUID" -> \
"71c3b31f-b2e5-4eaf-a2db-577770427081",
 Evaluatable->False,
 CellTags->"LastCellOfAPage"]
}, Open  ]],
Cell[27664, 916, 341, 10, 70, "CodeCaption", "ExpressionUUID" -> \
"13810c7f-fd59-4b48-a33a-18b98f0f577b",
 CellTags->{"i:17", "p:258"}],
Cell[CellGroupData[{
Cell[28030, 930, 259, 7, 70, "Input", "ExpressionUUID" -> \
"c4e55f36-aa6c-4d68-bde7-4c67f5100b7f"],
Cell[28292, 939, 211, 4, 70, "Output", "ExpressionUUID" -> \
"9baf9cc1-df45-4fec-8930-ee9a9edb246e",
 Evaluatable->False]
}, Open  ]],
Cell[28518, 946, 240, 6, 70, "CodeCaption", "ExpressionUUID" -> \
"2054f04c-0e73-4d19-9a64-da44c4afed99",
 CellTags->"i:18"],
Cell[CellGroupData[{
Cell[28783, 956, 228, 5, 70, "Input", "ExpressionUUID" -> \
"951fc1e6-8fa9-4928-92c6-dc5dee250287"],
Cell[29014, 963, 220, 4, 70, "Output", "ExpressionUUID" -> \
"ffcaeb73-8224-4b4c-9702-dce3002107ee",
 Evaluatable->False]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[29283, 973, 159, 4, 70, "VocabularySection", "ExpressionUUID" -> \
"4fab7a79-aec7-4e24-ab06-2251f289496c"],
Cell[29445, 979, 5542, 149, 70, "VocabularyTable", "ExpressionUUID" -> \
"9420134a-aaf2-4a1a-aeff-61d6e4394785",
 CellTags->"LastCellOfAPage"]
}, Open  ]],
Cell[CellGroupData[{
Cell[35024, 1133, 1780, 46, 70, "ExerciseSection", "ExpressionUUID" -> \
"b6a4c764-01c3-4c0d-9c1e-31ab8e73e47b"],
Cell[CellGroupData[{
Cell[36829, 1183, 1270, 39, 70, "ExerciseSummaryCell", "ExpressionUUID" -> \
"66a93ea4-12b4-4e0d-a5f3-836cb56b95b8"],
Cell[CellGroupData[{
Cell[38124, 1226, 918, 28, 70, "Exercise", "ExpressionUUID" -> \
"95d016c3-11a9-4a53-a8e4-0e3e3315258d"],
Cell[39045, 1256, 1101, 31, 70, "ExerciseOutput", "ExpressionUUID" -> \
"8dbd4fd4-2f57-42d1-ab52-eb2b3763e773"]
}, Closed]],
Cell[CellGroupData[{
Cell[40183, 1292, 782, 21, 70, "Exercise", "ExpressionUUID" -> \
"59a85369-69ec-4df3-aeac-dbb2a66eda51"],
Cell[40968, 1315, 4152, 76, 70, "ExerciseOutput", "ExpressionUUID" -> \
"67a9793b-bd46-410a-b4ae-bb31a05b90c1"]
}, Closed]],
Cell[CellGroupData[{
Cell[45157, 1396, 935, 26, 70, "Exercise", "ExpressionUUID" -> \
"f752ba63-be45-4362-900b-40e08c2d6eac"],
Cell[46095, 1424, 4366, 87, 70, "ExerciseOutput", "ExpressionUUID" -> \
"980e2540-9c24-493f-9caa-7042dac41798"]
}, Closed]],
Cell[CellGroupData[{
Cell[50498, 1516, 1115, 32, 70, "Exercise", "ExpressionUUID" -> \
"68a1c274-23d1-49e4-94ba-ad144d272044"],
Cell[51616, 1550, 4377, 90, 70, "ExerciseOutput", "ExpressionUUID" -> \
"2fee0f78-b126-47d0-a34b-961d478ae7d3"]
}, Closed]],
Cell[CellGroupData[{
Cell[56030, 1645, 832, 22, 70, "Exercise", "ExpressionUUID" -> \
"e304175a-c338-4c2c-baa3-71a727d93b7e"],
Cell[56865, 1669, 2358, 55, 70, "ExerciseOutput", "ExpressionUUID" -> \
"1dea5220-f073-4670-9fb2-f96933f562bc"]
}, Closed]],
Cell[CellGroupData[{
Cell[59260, 1729, 762, 21, 70, "Exercise", "ExpressionUUID" -> \
"584b32b9-3d38-457f-a9a4-46bff699f2e0"],
Cell[60025, 1752, 1376, 36, 70, "ExerciseOutput", "ExpressionUUID" -> \
"5874400e-cab6-4afe-b846-ade5f0285de7"]
}, Closed]],
Cell[CellGroupData[{
Cell[61438, 1793, 814, 23, 70, "Exercise", "ExpressionUUID" -> \
"c2ecd62a-a38b-4f6c-abf2-01a2938876d5"],
Cell[62255, 1818, 113882, 2482, 70, "ExerciseOutput", "ExpressionUUID" -> \
"e165341e-c03a-4e8e-919a-79eaa012022d"]
}, Closed]],
Cell[CellGroupData[{
Cell[176174, 4305, 1551, 48, 70, "Exercise", "ExpressionUUID" -> \
"a482e2d5-c76b-4104-8b58-7f39aef22e45"],
Cell[177728, 4355, 2417, 62, 70, "ExerciseOutput", "ExpressionUUID" -> \
"50c55d36-6029-43bb-9cb3-785088e78eb0"]
}, Closed]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[180206, 4424, 144, 4, 70, "QASection", "ExpressionUUID" -> \
"e84c7316-5a80-46f7-9928-7178ccbc8397"],
Cell[180353, 4430, 274, 10, 70, "Question", "ExpressionUUID" -> \
"52cd1f62-d157-4e6b-8f9d-143360e6547c"],
Cell[180630, 4442, 352, 10, 70, "Answer", "ExpressionUUID" -> \
"dcb4f2b2-8f13-4f29-8287-b3fb87b6fd54",
 CellTags->"i:19"],
Cell[180985, 4454, 193, 4, 70, "Question", "ExpressionUUID" -> \
"c4bdce89-f292-4d98-8499-72ea3e1276d5"],
Cell[181181, 4460, 297, 9, 70, "Answer", "ExpressionUUID" -> \
"0bfb3bc0-aa78-471b-9f80-504be374d5a6",
 CellTags->"i:20"]
}, Open  ]],
Cell[CellGroupData[{
Cell[181515, 4474, 157, 4, 70, "TechNoteSection", "ExpressionUUID" -> \
"94e1847b-c6a1-4d5c-a4b9-f001d679a9a9"],
Cell[181675, 4480, 431, 13, 70, "TechNote", "ExpressionUUID" -> \
"d2f0c9be-1ed2-4599-a43d-107e814d91e4",
 CellTags->"i:21"],
Cell[182109, 4495, 343, 10, 70, "TechNote", "ExpressionUUID" -> \
"f6660831-fa83-495c-9de4-663a2a7439dd",
 CellTags->"i:22"],
Cell[182455, 4507, 369, 9, 70, "TechNote", "ExpressionUUID" -> \
"5591d17d-519e-4ea3-9794-f0c47cc7ccf5",
 CellTags->"i:23"],
Cell[182827, 4518, 595, 27, 70, "TechNote", "ExpressionUUID" -> \
"6e7c29c2-2ecf-40bb-9b12-471c7ce79c3c",
 CellTags->"i:24"],
Cell[183425, 4547, 710, 21, 70, "TechNote", "ExpressionUUID" -> \
"d2b0e5ed-4ffd-43be-b5f4-fa4886426a61",
 CellTags->"i:25"],
Cell[184138, 4570, 325, 9, 70, "TechNote", "ExpressionUUID" -> \
"fc55a690-bf5b-4c0e-ae10-8e95c3af129d",
 CellTags->"i:26"],
Cell[184466, 4581, 472, 17, 70, "TechNote", "ExpressionUUID" -> \
"3b754f5f-da04-486e-ae89-d9275faa5b88",
 CellTags->"i:27"],
Cell[184941, 4600, 317, 9, 70, "TechNote", "ExpressionUUID" -> \
"34fc8e7d-1d9e-4258-9094-3fc88fdefdf0",
 CellTags->"i:28"]
}, Open  ]],
Cell[CellGroupData[{
Cell[185295, 4614, 165, 4, 70, "MoreExploreSection", "ExpressionUUID" -> \
"0eed336d-1aa9-4f99-b2bc-17928578fe67"],
Cell[185463, 4620, 352, 8, 70, "MoreExplore", "ExpressionUUID" -> \
"5cf5696e-4642-4c76-8ec0-63d83b4ed9f0",
 CellTags->"LastCellOfAPage"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
(* NotebookSignature dTcof4ko6KhUojeyB3uqOgVE *)
