(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    658551,      16191]
NotebookOptionsPosition[    533348,      13447]
NotebookOutlinePosition[    632429,      15553]
CellTagsIndexPosition[    631253,      15506]
WindowTitle->Datasets: Elementary Introduction to the Wolfram Language
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[BoxData[
 InterpretationBox[Cell[
  "Datasets", "SectionInline",ExpressionUUID->
   "aac476de-0eae-46bb-9415-04e8100c3277"],
  $Line = 0; Null]], "SectionDoubleDigit",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CounterAssignments->{{"Section", 44}, {"Subsection", 0}, {
   "Subsubsection", 0}, {"Exercise", 0}},
 CellTags->"p:271",
 CellLabel->"In[1]:=",ExpressionUUID->"cc19c375-305f-43a2-80f2-fda7d353deee"],

Cell[TextData[{
 "Especially in larger organizations, computing often centers around dealing \
with large amounts of structured data. The Wolfram Language has a very \
powerful way to deal with structured data, using what it calls ",
 StyleBox["datasets",
  FontSlant->"Italic"],
 ". "
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:1",ExpressionUUID->"2796ab3a-2022-4335-b56e-a22c0a7a08ef"],

Cell["\<\
A simple example of a dataset is formed from an association of associations.\
\>", "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:2",ExpressionUUID->"b416472a-5cd4-4ca1-bd84-8fc2c03f472d"],

Cell["\<\
Create a simple dataset that can be viewed as having 2 rows and 3 columns:\
\>", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"6b956a11-633c-4729-8a55-778fc94b6fbb"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"data", "=", 
  RowBox[{"Dataset", "[", 
   RowBox[{"\[LeftAssociation]", 
    RowBox[{
     RowBox[{"\"\<a\>\"", "\[Rule]", 
      RowBox[{"\[LeftAssociation]", 
       RowBox[{
        RowBox[{"\"\<x\>\"", "\[Rule]", "1"}], ",", 
        RowBox[{"\"\<y\>\"", "\[Rule]", "2"}], ",", 
        RowBox[{"\"\<z\>\"", "\[Rule]", "3"}]}], "\[RightAssociation]"}]}], 
     ",", 
     RowBox[{"\"\<b\>\"", "\[Rule]", 
      RowBox[{"\[LeftAssociation]", 
       RowBox[{
        RowBox[{"\"\<x\>\"", "\[Rule]", "5"}], ",", 
        RowBox[{"\"\<y\>\"", "\[Rule]", "10"}], ",", 
        RowBox[{"\"\<z\>\"", "\[Rule]", "7"}]}], "\[RightAssociation]"}]}]}], 
    "\[RightAssociation]"}], "]"}]}]], "Input",
 Deletable->False,
 CellLabel->"In[1]:=",ExpressionUUID->"62c29e5d-02e8-4e38-900c-e78f30e2951e"],

Cell[BoxData[
 TagBox[
  TemplateBox[{GridBox[{{
       ItemBox["", Frame -> {False, True, True, False}], 
       StyleBox["\"x\"", 
        GrayLevel[0.3]], 
       StyleBox["\"y\"", 
        GrayLevel[0.3]], 
       StyleBox["\"z\"", 
        GrayLevel[0.3]]}, {
       StyleBox[
        StyleBox["\"a\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 1, 2, 3}, {
       StyleBox[
        StyleBox["\"b\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 5, 10, 7}, {
       ItemBox[
        RowBox[{"2 levels", 
          AdjustmentBox[" | ", BoxBaselineShift -> -0.3], 
          RowBox[{"2", "rows"}]}], 
        BaseStyle -> {
         FontFamily -> "Helvetica", FontSize -> 10, FontColor -> 
          GrayLevel[0.4], Editable -> False, Selectable -> False}, 
        ItemSize -> {Automatic, Automatic}, Alignment -> {Left, Center}, 
        Background -> RGBColor[0.92, 0.92, 0.9]], "\[SpanFromLeft]", 
       "\[SpanFromLeft]", "\[SpanFromLeft]"}}, 
     GridBoxFrame -> {"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}}, 
     FrameStyle -> RGBColor[0, 0, 0, 0.4], GridBoxDividers -> {"Columns" -> {
         RGBColor[0, 0, 0, 0.4], 
         RGBColor[0, 0, 0, 0.3], {
          RGBColor[0, 0, 0, 0.09]}, 
         RGBColor[0, 0, 0, 0.4]}, "Rows" -> {
         RGBColor[0, 0, 0, 0.4], 
         RGBColor[0, 0, 0, 0.3], {
          RGBColor[0, 0, 0, 0.08]}, 
         RGBColor[0, 0, 0, 0.4]}}, RowSpacings -> {1.5, 1.2}, 
     GridBoxBackground -> {"Columns" -> {
         RGBColor[0.92, 0.92, 0.9]}, "Rows" -> {
         RGBColor[0.92, 0.92, 0.9]}}, 
     GridBoxAlignment -> {"Columns" -> {{Left}}}, ColumnSpacings -> 2.5, 
     GridFrameMargins -> {{2, 3}, {1, 3}}, 
     GridBoxItemSize -> {"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
      RowMinHeight -> 1.3],
    "Dataset[Association[(_String -> _Association)..]]"},
   "Dataset",
   DisplayFunction->(TagBox[
     StyleBox[#, {
      ShowAutoStyles -> False, LineBreakWithin -> False, FontWeight -> 
       "Light", FontFamily -> "Helvetica Neue", NumberMarks -> False, 
       SpanMaxSize -> 3, SpanMinSize -> 1., Editable -> False, Selectable -> 
       True, Background -> RGBColor[0.985, 0.98, 0.973], 
       LinebreakAdjustments -> {0.4, 5, 100, 0, 0.5}, LineIndent -> 0, 
       LineSpacing -> {1.1, 5}}], Deploy]& ),
   InterpretationFunction->(#2& )],
  False,
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[1]=",ExpressionUUID->"a4532548-e265-4d4c-8ddb-d30133dbf1f0"]
}, Open  ]],

Cell["\<\
The Wolfram Language displays most datasets in tabular form. You can extract \
parts from datasets just like you would from associations.\
\>", "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:3",ExpressionUUID->"2e0f0e04-9c10-4516-896d-9d34ba4ae91a"],

Cell[TextData[{
 "Get the element from \[OpenCurlyDoubleQuote]row ",
 Cell[BoxData[
 "b"], "InlineCode",ExpressionUUID->"dbc9b861-bd03-4aa9-875a-f00d0811418c"],
 "\[CloseCurlyDoubleQuote] and \[OpenCurlyDoubleQuote]column ",
 Cell[BoxData[
 "z"], "InlineCode",ExpressionUUID->"7b2ac92a-e6ca-4b14-bca0-286752119ee8"],
 "\[CloseCurlyDoubleQuote]:"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:4",ExpressionUUID->"847886a6-e4eb-4ae8-beb1-89ff98caed6d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"data", "[", 
  RowBox[{"\"\<b\>\"", ",", "\"\<z\>\""}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[2]:=",ExpressionUUID->"2500d645-bfe1-4021-9463-d6926270dd6a"],

Cell[BoxData["7"], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[2]=",ExpressionUUID->"5d4957a6-0181-4420-a19e-a4df0fc150da"]
}, Open  ]],

Cell[TextData[{
 "You can first extract the whole \[OpenCurlyDoubleQuote]",
 Cell[BoxData[
 "b"], "InlineCode",ExpressionUUID->"b18991ca-0ae0-4c66-9637-de3b27ee55f5"],
 " row\[CloseCurlyDoubleQuote], then get the \[OpenCurlyDoubleQuote]",
 Cell[BoxData[
 "z"], "InlineCode",ExpressionUUID->"8dd7b476-6c81-460d-9d90-1360af265d1f"],
 "\[CloseCurlyDoubleQuote] element of the result: "
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"40a3c7dc-1f32-497f-880e-7dfb7a865819"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "[", "\"\<b\>\"", "]"}], "[", "\"\<z\>\"", "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[3]:=",ExpressionUUID->"e7f1a697-f063-46a8-a997-71b26aca7b80"],

Cell[BoxData["7"], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[3]=",ExpressionUUID->"1bf536c7-3fb7-4246-bd44-725d2ca5af45"]
}, Open  ]],

Cell[TextData[{
 "You can also just get the whole \[OpenCurlyDoubleQuote]",
 Cell[BoxData[
 "b"], "InlineCodeText",ExpressionUUID->
  "926f665f-10e8-46a8-a45e-3d009b0e45b2"],
 " row\[CloseCurlyDoubleQuote] of the dataset. The result is a new dataset, \
which for ease of reading happens to be displayed in this case as a column."
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"67a20283-5757-463d-82c5-fe97bb5ef5f6"],

Cell[TextData[{
 "Generate a new dataset from the \[OpenCurlyDoubleQuote]",
 Cell[BoxData[
 "b"], "InlineCode",ExpressionUUID->"cb9d5b16-a65d-4533-95ca-a3855d7b7bd3"],
 " row\[CloseCurlyDoubleQuote] of the original dataset: "
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"cca0a430-542f-4740-a8f8-c49411e682ff"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"data", "[", "\"\<b\>\"", "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[4]:=",ExpressionUUID->"a7fdab4c-c5a8-4522-b950-898ef10595a3"],

Cell[BoxData[
 TagBox[
  TemplateBox[{GridBox[{{
       StyleBox["\"x\"", 
        GrayLevel[0.3]], 5}, {
       StyleBox["\"y\"", 
        GrayLevel[0.3]], 10}, {
       StyleBox["\"z\"", 
        GrayLevel[0.3]], 7}, {
       ItemBox[
        RowBox[{"1 level", 
          AdjustmentBox[" | ", BoxBaselineShift -> -0.3], 
          RowBox[{"3", "elements"}]}], 
        BaseStyle -> {
         FontFamily -> "Helvetica", FontSize -> 10, FontColor -> 
          GrayLevel[0.4], Editable -> False, Selectable -> False}, 
        ItemSize -> {Automatic, Automatic}, Alignment -> {Left, Center}, 
        Background -> RGBColor[0.92, 0.92, 0.9]], "\[SpanFromLeft]"}}, 
     GridBoxFrame -> {"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}}, 
     FrameStyle -> RGBColor[0, 0, 0, 0.4], GridBoxDividers -> {"Columns" -> {
         RGBColor[0, 0, 0, 0.4], 
         RGBColor[0, 0, 0, 0.3], {
          RGBColor[0, 0, 0, 0.09]}, 
         RGBColor[0, 0, 0, 0.4]}, "Rows" -> {
         RGBColor[0, 0, 0, 0.4], {
          RGBColor[0, 0, 0, 0.08]}, 
         RGBColor[0, 0, 0, 0.4]}}, RowSpacings -> 1.2, 
     GridBoxBackground -> {"Columns" -> {
         RGBColor[0.92, 0.92, 0.9]}}, 
     GridBoxAlignment -> {"Columns" -> {{Left}}}, ColumnSpacings -> 2.5, 
     GridFrameMargins -> {{2, 3}, {1, 3}}, 
     GridBoxItemSize -> {"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
      RowMinHeight -> 1.3],"Dataset[<|\"x\" -> _, \"y\" -> _, \"z\" -> _|>]"},
   
   "Dataset",
   DisplayFunction->(TagBox[
     StyleBox[#, {
      ShowAutoStyles -> False, LineBreakWithin -> False, FontWeight -> 
       "Light", FontFamily -> "Helvetica Neue", NumberMarks -> False, 
       SpanMaxSize -> 3, SpanMinSize -> 1., Editable -> False, Selectable -> 
       True, Background -> RGBColor[0.985, 0.98, 0.973], 
       LinebreakAdjustments -> {0.4, 5, 100, 0, 0.5}, LineIndent -> 0, 
       LineSpacing -> {1.1, 5}}], Deploy]& ),
   InterpretationFunction->(#2& )],
  False,
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[4]=",ExpressionUUID->"47783376-343d-4782-a934-510133f75565"]
}, Open  ]],

Cell[TextData[{
 "Here is the dataset that corresponds to the \[OpenCurlyDoubleQuote]",
 Cell[BoxData[
 "z"], "InlineCodeText",ExpressionUUID->
  "00b2aa43-a75e-4ae8-b8f7-1e5b4cf94c89"],
 " column\[CloseCurlyDoubleQuote] for all \[OpenCurlyDoubleQuote]rows\
\[CloseCurlyDoubleQuote]."
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"c2f619ed-c165-43da-b518-4c384c92137c"],

Cell[TextData[{
 "Generate a dataset consisting of the \[OpenCurlyDoubleQuote]",
 Cell[BoxData[
 "z"], "InlineCode",ExpressionUUID->"3dc4fdce-f716-4d45-aea3-590703109653"],
 " column\[CloseCurlyDoubleQuote] for all rows: "
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"a9b1f89a-9a6c-412d-a2be-0d8b45cd1626"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"data", "[", 
  RowBox[{"All", ",", "\"\<z\>\""}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[5]:=",ExpressionUUID->"3e3df6ec-8b54-45b0-aa1f-7e846091a9e3"],

Cell[BoxData[
 TagBox[
  TemplateBox[{GridBox[{{
       StyleBox[
        StyleBox["\"a\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 3}, {
       StyleBox[
        StyleBox["\"b\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 7}, {
       ItemBox[
        RowBox[{"1 level", 
          AdjustmentBox[" | ", BoxBaselineShift -> -0.3], 
          RowBox[{"2", "elements"}]}], 
        BaseStyle -> {
         FontFamily -> "Helvetica", FontSize -> 10, FontColor -> 
          GrayLevel[0.4], Editable -> False, Selectable -> False}, 
        ItemSize -> {Automatic, Automatic}, Alignment -> {Left, Center}, 
        Background -> RGBColor[0.92, 0.92, 0.9]], "\[SpanFromLeft]"}}, 
     GridBoxFrame -> {"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}}, 
     FrameStyle -> RGBColor[0, 0, 0, 0.4], GridBoxDividers -> {"Columns" -> {
         RGBColor[0, 0, 0, 0.4], 
         RGBColor[0, 0, 0, 0.3], {
          RGBColor[0, 0, 0, 0.09]}, 
         RGBColor[0, 0, 0, 0.4]}, "Rows" -> {
         RGBColor[0, 0, 0, 0.4], {
          RGBColor[0, 0, 0, 0.08]}, 
         RGBColor[0, 0, 0, 0.4]}}, RowSpacings -> 1.2, 
     GridBoxBackground -> {"Columns" -> {
         RGBColor[0.92, 0.92, 0.9]}}, 
     GridBoxAlignment -> {"Columns" -> {{Left}}}, ColumnSpacings -> 2.5, 
     GridFrameMargins -> {{2, 3}, {1, 3}}, 
     GridBoxItemSize -> {"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
      RowMinHeight -> 1.3],"Dataset[Association[(_String -> _Integer)..]]"},
   "Dataset",
   DisplayFunction->(TagBox[
     StyleBox[#, {
      ShowAutoStyles -> False, LineBreakWithin -> False, FontWeight -> 
       "Light", FontFamily -> "Helvetica Neue", NumberMarks -> False, 
       SpanMaxSize -> 3, SpanMinSize -> 1., Editable -> False, Selectable -> 
       True, Background -> RGBColor[0.985, 0.98, 0.973], 
       LinebreakAdjustments -> {0.4, 5, 100, 0, 0.5}, LineIndent -> 0, 
       LineSpacing -> {1.1, 5}}], Deploy]& ),
   InterpretationFunction->(#2& )],
  False,
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[5]=",ExpressionUUID->"ddcc842e-7afd-4d97-a479-e0759dc9a0f2"]
}, Open  ]],

Cell["\<\
Extracting parts of datasets is just the beginning. Anywhere you can ask for \
a part you can also give a function that will be applied to all parts at that \
level. \
\>", "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->
  "LastCellOfAPage",ExpressionUUID->"6973e92e-363d-48a2-839a-86b186bd1db4"],

Cell[TextData[{
 "Get totals for each row by applying ",
 ButtonBox["Total",
  BaseStyle->"Link"],
 " to all columns for all the rows:"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->{
  "i:5", "p:272"},ExpressionUUID->"3bad4a51-60e4-4d45-9308-b6509362a956"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"data", "[", 
  RowBox[{"All", ",", "Total"}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[6]:=",ExpressionUUID->"741bda11-46ff-4b93-a375-fc10d45362eb"],

Cell[BoxData[
 TagBox[
  TemplateBox[{GridBox[{{
       StyleBox[
        StyleBox["\"a\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 6}, {
       StyleBox[
        StyleBox["\"b\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 22}, {
       ItemBox[
        RowBox[{"1 level", 
          AdjustmentBox[" | ", BoxBaselineShift -> -0.3], 
          RowBox[{"2", "elements"}]}], 
        BaseStyle -> {
         FontFamily -> "Helvetica", FontSize -> 10, FontColor -> 
          GrayLevel[0.4], Editable -> False, Selectable -> False}, 
        ItemSize -> {Automatic, Automatic}, Alignment -> {Left, Center}, 
        Background -> RGBColor[0.92, 0.92, 0.9]], "\[SpanFromLeft]"}}, 
     GridBoxFrame -> {"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}}, 
     FrameStyle -> RGBColor[0, 0, 0, 0.4], GridBoxDividers -> {"Columns" -> {
         RGBColor[0, 0, 0, 0.4], 
         RGBColor[0, 0, 0, 0.3], {
          RGBColor[0, 0, 0, 0.09]}, 
         RGBColor[0, 0, 0, 0.4]}, "Rows" -> {
         RGBColor[0, 0, 0, 0.4], {
          RGBColor[0, 0, 0, 0.08]}, 
         RGBColor[0, 0, 0, 0.4]}}, RowSpacings -> 1.2, 
     GridBoxBackground -> {"Columns" -> {
         RGBColor[0.92, 0.92, 0.9]}}, 
     GridBoxAlignment -> {"Columns" -> {{Left}}}, ColumnSpacings -> 2.5, 
     GridFrameMargins -> {{2, 3}, {1, 3}}, 
     GridBoxItemSize -> {"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
      RowMinHeight -> 1.3],"Dataset[Association[(_String -> _Integer)..]]"},
   "Dataset",
   DisplayFunction->(TagBox[
     StyleBox[#, {
      ShowAutoStyles -> False, LineBreakWithin -> False, FontWeight -> 
       "Light", FontFamily -> "Helvetica Neue", NumberMarks -> False, 
       SpanMaxSize -> 3, SpanMinSize -> 1., Editable -> False, Selectable -> 
       True, Background -> RGBColor[0.985, 0.98, 0.973], 
       LinebreakAdjustments -> {0.4, 5, 100, 0, 0.5}, LineIndent -> 0, 
       LineSpacing -> {1.1, 5}}], Deploy]& ),
   InterpretationFunction->(#2& )],
  False,
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[6]=",ExpressionUUID->"489e1845-524f-479c-9c12-6e8f2ef7872e"]
}, Open  ]],

Cell[TextData[{
 "If we use ",
 Cell[BoxData[
 "f"], "InlineCodeText",ExpressionUUID->
  "e1ac7848-d671-44de-a6d0-03a1b17ee89a"],
 " instead of ",
 ButtonBox["Total",
  BaseStyle->"Link"],
 ", we can see what\[CloseCurlyQuote]s going on: the function is being \
applied to each of the \[OpenCurlyDoubleQuote]row\[CloseCurlyDoubleQuote] \
associations. "
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"f3b35c82-ab2e-44bb-8c69-4e3a584ede26"],

Cell[TextData[{
 "Apply the function ",
 Cell[BoxData[
 "f"], "InlineCode",ExpressionUUID->"b740d7c0-bbce-4401-b95a-d098a1848361"],
 " to each row:"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"e39c6ec6-24ab-41b4-886c-4374e7e04e57"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"data", "[", 
  RowBox[{"All", ",", "f"}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[7]:=",ExpressionUUID->"c1a76092-f540-4e08-abe1-6e0159116fe0"],

Cell[BoxData[
 TagBox[
  TemplateBox[{GridBox[{{
       StyleBox[
        StyleBox["\"a\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 
       InterpretationBox[
        TagBox[
         RowBox[{"f", "[", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"\"x\"", "\[Rule]", "1"}], ",", 
               RowBox[{"\"y\"", "\[Rule]", "2"}], ",", 
               RowBox[{"\"z\"", "\[Rule]", "3"}]}], "\[RightAssociation]"}], 
           "]"}], Short[#, 5]& ], 
        $CellContext`f[
         Association["x" -> 1, "y" -> 2, "z" -> 3]]]}, {
       StyleBox[
        StyleBox["\"b\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 
       InterpretationBox[
        TagBox[
         RowBox[{"f", "[", 
           RowBox[{"\[LeftAssociation]", 
             RowBox[{
               RowBox[{"\"x\"", "\[Rule]", "5"}], ",", 
               RowBox[{"\"y\"", "\[Rule]", "10"}], ",", 
               RowBox[{"\"z\"", "\[Rule]", "7"}]}], "\[RightAssociation]"}], 
           "]"}], Short[#, 5]& ], 
        $CellContext`f[
         Association["x" -> 5, "y" -> 10, "z" -> 7]]]}, {
       ItemBox[
        RowBox[{"1 level", 
          AdjustmentBox[" | ", BoxBaselineShift -> -0.3], 
          RowBox[{"2", "elements"}]}], 
        BaseStyle -> {
         FontFamily -> "Helvetica", FontSize -> 10, FontColor -> 
          GrayLevel[0.4], Editable -> False, Selectable -> False}, 
        ItemSize -> {Automatic, Automatic}, Alignment -> {Left, Center}, 
        Background -> RGBColor[0.92, 0.92, 0.9]], "\[SpanFromLeft]"}}, 
     GridBoxFrame -> {"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}}, 
     FrameStyle -> RGBColor[0, 0, 0, 0.4], GridBoxDividers -> {"Columns" -> {
         RGBColor[0, 0, 0, 0.4], 
         RGBColor[0, 0, 0, 0.3], {
          RGBColor[0, 0, 0, 0.09]}, 
         RGBColor[0, 0, 0, 0.4]}, "Rows" -> {
         RGBColor[0, 0, 0, 0.4], {
          RGBColor[0, 0, 0, 0.08]}, 
         RGBColor[0, 0, 0, 0.4]}}, RowSpacings -> 1.2, 
     GridBoxBackground -> {"Columns" -> {
         RGBColor[0.92, 0.92, 0.9]}}, 
     GridBoxAlignment -> {"Columns" -> {{Left}}}, ColumnSpacings -> 2.5, 
     GridFrameMargins -> {{2, 3}, {1, 3}}, 
     GridBoxItemSize -> {"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
      RowMinHeight -> 1.3],"Dataset[_Association]"},
   "Dataset",
   DisplayFunction->(TagBox[
     StyleBox[#, {
      ShowAutoStyles -> False, LineBreakWithin -> False, FontWeight -> 
       "Light", FontFamily -> "Helvetica Neue", NumberMarks -> False, 
       SpanMaxSize -> 3, SpanMinSize -> 1., Editable -> False, Selectable -> 
       True, Background -> RGBColor[0.985, 0.98, 0.973], 
       LinebreakAdjustments -> {0.4, 5, 100, 0, 0.5}, LineIndent -> 0, 
       LineSpacing -> {1.1, 5}}], Deploy]& ),
   InterpretationFunction->(#2& )],
  False,
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[7]=",ExpressionUUID->"b22143c7-dd6f-40af-9a87-775af8f3c01f"]
}, Open  ]],

Cell[TextData[{
 "Apply a function that adds the ",
 Cell[BoxData[
 "x"], "InlineCode",ExpressionUUID->"752f5718-7a8c-44af-9d31-40cbe92da998"],
 " and ",
 Cell[BoxData[
 "z"], "InlineCode",ExpressionUUID->"06a92994-c61e-4424-87b1-9574eb059871"],
 " elements of each association:"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"c5f3527f-fd4f-40a8-92e1-4f0b6e8375e7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"data", "[", 
  RowBox[{"All", ",", 
   RowBox[{
    RowBox[{"#x", "+", "#z"}], "&"}]}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[8]:=",ExpressionUUID->"42dcdd97-b419-495d-bfe5-d12bdb032861"],

Cell[BoxData[
 TagBox[
  TemplateBox[{GridBox[{{
       StyleBox[
        StyleBox["\"a\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 4}, {
       StyleBox[
        StyleBox["\"b\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 12}, {
       ItemBox[
        RowBox[{"1 level", 
          AdjustmentBox[" | ", BoxBaselineShift -> -0.3], 
          RowBox[{"2", "elements"}]}], 
        BaseStyle -> {
         FontFamily -> "Helvetica", FontSize -> 10, FontColor -> 
          GrayLevel[0.4], Editable -> False, Selectable -> False}, 
        ItemSize -> {Automatic, Automatic}, Alignment -> {Left, Center}, 
        Background -> RGBColor[0.92, 0.92, 0.9]], "\[SpanFromLeft]"}}, 
     GridBoxFrame -> {"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}}, 
     FrameStyle -> RGBColor[0, 0, 0, 0.4], GridBoxDividers -> {"Columns" -> {
         RGBColor[0, 0, 0, 0.4], 
         RGBColor[0, 0, 0, 0.3], {
          RGBColor[0, 0, 0, 0.09]}, 
         RGBColor[0, 0, 0, 0.4]}, "Rows" -> {
         RGBColor[0, 0, 0, 0.4], {
          RGBColor[0, 0, 0, 0.08]}, 
         RGBColor[0, 0, 0, 0.4]}}, RowSpacings -> 1.2, 
     GridBoxBackground -> {"Columns" -> {
         RGBColor[0.92, 0.92, 0.9]}}, 
     GridBoxAlignment -> {"Columns" -> {{Left}}}, ColumnSpacings -> 2.5, 
     GridFrameMargins -> {{2, 3}, {1, 3}}, 
     GridBoxItemSize -> {"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
      RowMinHeight -> 1.3],"Dataset[Association[(_String -> _Integer)..]]"},
   "Dataset",
   DisplayFunction->(TagBox[
     StyleBox[#, {
      ShowAutoStyles -> False, LineBreakWithin -> False, FontWeight -> 
       "Light", FontFamily -> "Helvetica Neue", NumberMarks -> False, 
       SpanMaxSize -> 3, SpanMinSize -> 1., Editable -> False, Selectable -> 
       True, Background -> RGBColor[0.985, 0.98, 0.973], 
       LinebreakAdjustments -> {0.4, 5, 100, 0, 0.5}, LineIndent -> 0, 
       LineSpacing -> {1.1, 5}}], Deploy]& ),
   InterpretationFunction->(#2& )],
  False,
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[8]=",ExpressionUUID->"1af4fd3d-5128-497d-b447-6eee5ea53ebf"]
}, Open  ]],

Cell[TextData[{
 "You can use any function; here\[CloseCurlyQuote]s ",
 ButtonBox["PieChart",
  BaseStyle->"Link"],
 ":"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:6",ExpressionUUID->"4140d15c-cd8d-472f-ba50-a01ef9ec4d23"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"data", "[", 
  RowBox[{"All", ",", "PieChart"}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[9]:=",ExpressionUUID->"923e34d9-04d7-40ff-963c-a80e2298c50e"],

Cell[BoxData[
 TagBox[
  TemplateBox[{GridBox[{{
       StyleBox[
        StyleBox["\"a\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 
       InterpretationBox[
        GraphicsBox[{{}, {}, 
          
          DynamicModuleBox[{
           DynamicChart`click$1465$1551 = False, DynamicChart`click$1474$1551 = 
            False, DynamicChart`click$1477$1551 = False}, {{
             Directive[
              RGBColor[0.5, 0.5, 1.], 
              EdgeForm[
               Directive[
                GrayLevel[0], 
                Opacity[0.5]]]], {{{{{{}, {{
                    Directive[
                    EdgeForm[
                    Directive[
                    GrayLevel[0], 
                    Opacity[0.5]]], 
                    RGBColor[0.982864, 0.7431472, 0.3262672]], 
                    GeometricTransformationBox[
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[2.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    DiskBox[{0, 0}, 1., {2.0943951023931957`, 
                    3.141592653589793}]}], StatusArea[#, 1]& , TagBoxNote -> 
                    "1"], 
                    StyleBox["1", {
                    GrayLevel[0], FontFamily -> "Arial"}, StripOnInput -> 
                    False]], Annotation[#, 
                    Style[1, {
                    GrayLevel[0], FontFamily -> "Arial"}], "Tooltip"]& ], 
                    
                    EventHandlerTag[{
                    "MouseClicked" :> 
                    FEPrivate`Set[DynamicChart`click$1465$1551, 
                    FEPrivate`Not[DynamicChart`click$1465$1551]], 
                    PassEventsDown -> True, Method -> "Preemptive", 
                    PassEventsUp -> True}]], 
                    Dynamic[
                    If[
                    DynamicChart`click$1465$1551, {{{1., 0}, {
                    0, 1.}}, {-0.17320508075688776`, 0.09999999999999999}}, {{
                    1, 0}, {0, 1}}, {{1, 0}, {0, 1}}], 
                    TrackedSymbols :> {DynamicChart`click$1465$1551}]]}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    GrayLevel[0], 
                    Opacity[0.5]]], 
                    RGBColor[0.784, 0.47519999999999996`, 0.2]], 
                    GeometricTransformationBox[
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[2.5], 
                    Opacity[0.66]}], {}, {}], 
                    DiskBox[{0, 0}, 1., {0., 2.0943951023931957`}]}], 
                    StatusArea[#, 2]& , TagBoxNote -> "2"], 
                    StyleBox["2", {
                    GrayLevel[0], FontFamily -> "Arial"}, StripOnInput -> 
                    False]], Annotation[#, 
                    Style[2, {
                    GrayLevel[0], FontFamily -> "Arial"}], "Tooltip"]& ], 
                    
                    EventHandlerTag[{
                    "MouseClicked" :> 
                    FEPrivate`Set[DynamicChart`click$1474$1551, 
                    FEPrivate`Not[DynamicChart`click$1474$1551]], 
                    PassEventsDown -> True, Method -> "Preemptive", 
                    PassEventsUp -> True}]], 
                    Dynamic[
                    If[
                    DynamicChart`click$1474$1551, {{{1., 0}, {0, 1.}}, {
                    0.09999999999999998, 0.17320508075688776`}}, {{1, 0}, {0, 
                    1}}, {{1, 0}, {0, 1}}], 
                    TrackedSymbols :> {DynamicChart`click$1474$1551}]]}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    GrayLevel[0], 
                    Opacity[0.5]]], 
                    RGBColor[0.4992, 0.5552, 0.8309304]], 
                    GeometricTransformationBox[
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[2.5], 
                    Opacity[0.66]}], {}, {}], 
                    DiskBox[{0, 0}, 1., {-3.141592653589793, 0.}]}], 
                    StatusArea[#, 3]& , TagBoxNote -> "3"], 
                    StyleBox["3", {
                    GrayLevel[0], FontFamily -> "Arial"}, StripOnInput -> 
                    False]], Annotation[#, 
                    Style[3, {
                    GrayLevel[0], FontFamily -> "Arial"}], "Tooltip"]& ], 
                    
                    EventHandlerTag[{
                    "MouseClicked" :> 
                    FEPrivate`Set[DynamicChart`click$1477$1551, 
                    FEPrivate`Not[DynamicChart`click$1477$1551]], 
                    PassEventsDown -> True, Method -> "Preemptive", 
                    PassEventsUp -> True}]], 
                    Dynamic[
                    If[
                    DynamicChart`click$1477$1551, {{{1., 0}, {0, 1.}}, {
                    1.2246467991473533`*^-17, -0.2}}, {{1, 0}, {0, 1}}, {{1, 
                    0}, {0, 1}}], 
                    TrackedSymbols :> {
                    DynamicChart`click$1477$1551}]]}}}}}, {}}, {{}}}}, {{{{
                GeometricTransformationBox[
                 TagBox[
                  TagBox[
                   TooltipBox[
                    TagBox[{{}, {}}, StatusArea[#, 1]& , TagBoxNote -> "1"], 
                    StyleBox["1", {
                    GrayLevel[0], FontFamily -> "Arial"}, StripOnInput -> 
                    False]], Annotation[#, 
                    Style[1, {
                    GrayLevel[0], FontFamily -> "Arial"}], "Tooltip"]& ], 
                  
                  EventHandlerTag[{
                   "MouseClicked" :> 
                    FEPrivate`Set[DynamicChart`click$1465$1551, 
                    FEPrivate`Not[DynamicChart`click$1465$1551]], 
                    PassEventsDown -> True, Method -> "Preemptive", 
                    PassEventsUp -> True}]], 
                 Dynamic[
                  If[
                  DynamicChart`click$1465$1551, {{{1., 0}, {
                    0, 1.}}, {-0.17320508075688776`, 0.09999999999999999}}, {{
                   1, 0}, {0, 1}}, {{1, 0}, {0, 1}}], 
                  TrackedSymbols :> {DynamicChart`click$1465$1551}]], 
                GeometricTransformationBox[
                 TagBox[
                  TagBox[
                   TooltipBox[
                    TagBox[{{}, {}}, StatusArea[#, 2]& , TagBoxNote -> "2"], 
                    StyleBox["2", {
                    GrayLevel[0], FontFamily -> "Arial"}, StripOnInput -> 
                    False]], Annotation[#, 
                    Style[2, {
                    GrayLevel[0], FontFamily -> "Arial"}], "Tooltip"]& ], 
                  
                  EventHandlerTag[{
                   "MouseClicked" :> 
                    FEPrivate`Set[DynamicChart`click$1474$1551, 
                    FEPrivate`Not[DynamicChart`click$1474$1551]], 
                    PassEventsDown -> True, Method -> "Preemptive", 
                    PassEventsUp -> True}]], 
                 Dynamic[
                  If[
                  DynamicChart`click$1474$1551, {{{1., 0}, {0, 1.}}, {
                    0.09999999999999998, 0.17320508075688776`}}, {{1, 0}, {0, 
                   1}}, {{1, 0}, {0, 1}}], 
                  TrackedSymbols :> {DynamicChart`click$1474$1551}]], 
                GeometricTransformationBox[
                 TagBox[
                  TagBox[
                   TooltipBox[
                    TagBox[{{}, {}}, StatusArea[#, 3]& , TagBoxNote -> "3"], 
                    StyleBox["3", {
                    GrayLevel[0], FontFamily -> "Arial"}, StripOnInput -> 
                    False]], Annotation[#, 
                    Style[3, {
                    GrayLevel[0], FontFamily -> "Arial"}], "Tooltip"]& ], 
                  
                  EventHandlerTag[{
                   "MouseClicked" :> 
                    FEPrivate`Set[DynamicChart`click$1477$1551, 
                    FEPrivate`Not[DynamicChart`click$1477$1551]], 
                    PassEventsDown -> True, Method -> "Preemptive", 
                    PassEventsUp -> True}]], 
                 Dynamic[
                  If[
                  DynamicChart`click$1477$1551, {{{1., 0}, {0, 1.}}, {
                    1.2246467991473533`*^-17, -0.2}}, {{1, 0}, {0, 1}}, {{1, 
                   0}, {0, 1}}], 
                  TrackedSymbols :> {
                   DynamicChart`click$1477$1551}]]}, {}}}, {}}}, 
           DynamicModuleValues :> {}], {{{}, {}}}, {{{{}, {}, {}, {}}}, {}}}, \
{PlotRangeClipping -> True, Frame -> True, FrameStyle -> GrayLevel[0.85], 
          Ticks -> None, FrameTicks -> None, Axes -> None, ImageSize -> 96, 
          ContentSelectable -> False, GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], LabelStyle -> {
            GrayLevel[0], FontFamily -> "Arial"}, 
          PlotRange -> {{-1.2, 1.2}, {-1.2, 1.2}}, PlotRangePadding -> 
          Scaled[0.02]}], 
        Graphics[{{}, {}, 
          
          DynamicModule[{
           DynamicChart`click$1465 = False, DynamicChart`click$1474 = False, 
            DynamicChart`click$1477 = False}, {{
             Directive[
              RGBColor[0.5, 0.5, 1.], 
              EdgeForm[
               Directive[
                GrayLevel[0], 
                Opacity[0.5]]]], {{{{{{}, {{
                    Directive[
                    EdgeForm[
                    Directive[
                    GrayLevel[0], 
                    Opacity[0.5]]], 
                    RGBColor[0.982864, 0.7431472, 0.3262672]], 
                    GeometricTransformation[
                    EventHandler[
                    Tooltip[
                    StatusArea[
                    RawBoxes[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[2.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    DiskBox[{0, 0}, 1., {2.0943951023931957`, 
                    3.141592653589793}]}]], 1], 
                    Style[1, {
                    GrayLevel[0], FontFamily -> "Arial"}]], {
                    "MouseClicked" :> FEPrivate`Set[DynamicChart`click$1465, 
                    FEPrivate`Not[DynamicChart`click$1465]]}, PassEventsDown -> 
                    True], 
                    Dynamic[
                    If[
                    DynamicChart`click$1465, {{{1., 0}, {
                    0, 1.}}, {-0.17320508075688776`, 0.09999999999999999}}, {{
                    1, 0}, {0, 1}}, {{1, 0}, {0, 1}}], 
                    TrackedSymbols :> {DynamicChart`click$1465}]]}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    GrayLevel[0], 
                    Opacity[0.5]]], 
                    RGBColor[0.784, 0.47519999999999996`, 0.2]], 
                    GeometricTransformation[
                    EventHandler[
                    Tooltip[
                    StatusArea[
                    RawBoxes[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[2.5], 
                    Opacity[0.66]}], {}, {}], 
                    DiskBox[{0, 0}, 1., {0., 2.0943951023931957`}]}]], 2], 
                    Style[2, {
                    GrayLevel[0], FontFamily -> "Arial"}]], {
                    "MouseClicked" :> FEPrivate`Set[DynamicChart`click$1474, 
                    FEPrivate`Not[DynamicChart`click$1474]]}, PassEventsDown -> 
                    True], 
                    Dynamic[
                    If[
                    DynamicChart`click$1474, {{{1., 0}, {0, 1.}}, {
                    0.09999999999999998, 0.17320508075688776`}}, {{1, 0}, {0, 
                    1}}, {{1, 0}, {0, 1}}], 
                    TrackedSymbols :> {DynamicChart`click$1474}]]}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    GrayLevel[0], 
                    Opacity[0.5]]], 
                    RGBColor[0.4992, 0.5552, 0.8309304]], 
                    GeometricTransformation[
                    EventHandler[
                    Tooltip[
                    StatusArea[
                    RawBoxes[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[2.5], 
                    Opacity[0.66]}], {}, {}], 
                    DiskBox[{0, 0}, 1., {-3.141592653589793, 0.}]}]], 3], 
                    Style[3, {
                    GrayLevel[0], FontFamily -> "Arial"}]], {
                    "MouseClicked" :> FEPrivate`Set[DynamicChart`click$1477, 
                    FEPrivate`Not[DynamicChart`click$1477]]}, PassEventsDown -> 
                    True], 
                    Dynamic[
                    If[
                    DynamicChart`click$1477, {{{1., 0}, {0, 1.}}, {
                    1.2246467991473533`*^-17, -0.2}}, {{1, 0}, {0, 1}}, {{1, 
                    0}, {0, 1}}], 
                    TrackedSymbols :> {
                    DynamicChart`click$1477}]]}}}}}, {}}, {{}}}}, {{{{
                GeometricTransformation[
                 EventHandler[
                  Tooltip[
                   StatusArea[{{}, {}}, 1], 
                   Style[1, {
                    GrayLevel[0], FontFamily -> "Arial"}]], {
                  "MouseClicked" :> FEPrivate`Set[DynamicChart`click$1465, 
                    FEPrivate`Not[DynamicChart`click$1465]]}, PassEventsDown -> 
                  True], 
                 Dynamic[
                  If[
                  DynamicChart`click$1465, {{{1., 0}, {
                    0, 1.}}, {-0.17320508075688776`, 0.09999999999999999}}, {{
                   1, 0}, {0, 1}}, {{1, 0}, {0, 1}}], 
                  TrackedSymbols :> {DynamicChart`click$1465}]], 
                GeometricTransformation[
                 EventHandler[
                  Tooltip[
                   StatusArea[{{}, {}}, 2], 
                   Style[2, {
                    GrayLevel[0], FontFamily -> "Arial"}]], {
                  "MouseClicked" :> FEPrivate`Set[DynamicChart`click$1474, 
                    FEPrivate`Not[DynamicChart`click$1474]]}, PassEventsDown -> 
                  True], 
                 Dynamic[
                  If[
                  DynamicChart`click$1474, {{{1., 0}, {0, 1.}}, {
                    0.09999999999999998, 0.17320508075688776`}}, {{1, 0}, {0, 
                   1}}, {{1, 0}, {0, 1}}], 
                  TrackedSymbols :> {DynamicChart`click$1474}]], 
                GeometricTransformation[
                 EventHandler[
                  Tooltip[
                   StatusArea[{{}, {}}, 3], 
                   Style[3, {
                    GrayLevel[0], FontFamily -> "Arial"}]], {
                  "MouseClicked" :> FEPrivate`Set[DynamicChart`click$1477, 
                    FEPrivate`Not[DynamicChart`click$1477]]}, PassEventsDown -> 
                  True], 
                 Dynamic[
                  If[
                  DynamicChart`click$1477, {{{1., 0}, {0, 1.}}, {
                    1.2246467991473533`*^-17, -0.2}}, {{1, 0}, {0, 1}}, {{1, 
                   0}, {0, 1}}], 
                  TrackedSymbols :> {DynamicChart`click$1477}]]}, {}}}, {}}}, 
           DynamicModuleValues :> {}], {{{}, {}}}, {{{{}, {}, {}, {}}}, {}}}, \
{ContentSelectable -> False, GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], LabelStyle -> {
            GrayLevel[0], FontFamily -> "Arial"}, 
          PlotRange -> {{-1.2, 1.2}, {-1.2, 1.2}}, PlotRangePadding -> 
          Scaled[0.02]}]]}, {
       StyleBox[
        StyleBox["\"b\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 
       InterpretationBox[
        GraphicsBox[{{}, {}, 
          
          DynamicModuleBox[{
           DynamicChart`click$1516$1552 = False, DynamicChart`click$1519$1552 = 
            False, DynamicChart`click$1522$1552 = False}, {{
             Directive[
              RGBColor[0.5, 0.5, 1.], 
              EdgeForm[
               Directive[
                GrayLevel[0], 
                Opacity[0.5]]]], {{{{{{}, {{
                    Directive[
                    EdgeForm[
                    Directive[
                    GrayLevel[0], 
                    Opacity[0.5]]], 
                    RGBColor[0.982864, 0.7431472, 0.3262672]], 
                    GeometricTransformationBox[
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[2.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    DiskBox[{0, 0}, 1., {1.7135959928671598`, 
                    3.141592653589793}]}], StatusArea[#, 5]& , TagBoxNote -> 
                    "5"], 
                    StyleBox["5", {
                    GrayLevel[0], FontFamily -> "Arial"}, StripOnInput -> 
                    False]], Annotation[#, 
                    Style[5, {
                    GrayLevel[0], FontFamily -> "Arial"}], "Tooltip"]& ], 
                    
                    EventHandlerTag[{
                    "MouseClicked" :> 
                    FEPrivate`Set[DynamicChart`click$1516$1552, 
                    FEPrivate`Not[DynamicChart`click$1516$1552]], 
                    PassEventsDown -> True, Method -> "Preemptive", 
                    PassEventsUp -> True}]], 
                    Dynamic[
                    If[
                    DynamicChart`click$1516$1552, {{{1., 0}, {
                    0, 1.}}, {-0.15114991487085164`, 
                    0.13097214678905705`}}, {{1, 0}, {0, 1}}, {{1, 0}, {0, 
                    1}}], TrackedSymbols :> {
                    DynamicChart`click$1516$1552}]]}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    GrayLevel[0], 
                    Opacity[0.5]]], 
                    RGBColor[0.784, 0.47519999999999996`, 0.2]], 
                    GeometricTransformationBox[
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[2.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    DiskBox[{0, 0}, 1., {-1.1423973285781068`, 
                    1.7135959928671598`}]}], StatusArea[#, 10]& , TagBoxNote -> 
                    "10"], 
                    StyleBox["10", {
                    GrayLevel[0], FontFamily -> "Arial"}, StripOnInput -> 
                    False]], Annotation[#, 
                    Style[10, {
                    GrayLevel[0], FontFamily -> "Arial"}], "Tooltip"]& ], 
                    
                    EventHandlerTag[{
                    "MouseClicked" :> 
                    FEPrivate`Set[DynamicChart`click$1519$1552, 
                    FEPrivate`Not[DynamicChart`click$1519$1552]], 
                    PassEventsDown -> True, Method -> "Preemptive", 
                    PassEventsUp -> True}]], 
                    Dynamic[
                    If[
                    DynamicChart`click$1519$1552, {{{1., 0}, {0, 1.}}, {
                    0.1918985947228995, 0.056346511368285904`}}, {{1, 0}, {0, 
                    1}}, {{1, 0}, {0, 1}}], 
                    TrackedSymbols :> {DynamicChart`click$1519$1552}]]}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    GrayLevel[0], 
                    Opacity[0.5]]], 
                    RGBColor[0.4992, 0.5552, 0.8309304]], 
                    GeometricTransformationBox[
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[2.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    DiskBox[{0, 0}, 
                    1., {-3.141592653589793, -1.1423973285781068`}]}], 
                    StatusArea[#, 7]& , TagBoxNote -> "7"], 
                    StyleBox["7", {
                    GrayLevel[0], FontFamily -> "Arial"}, StripOnInput -> 
                    False]], Annotation[#, 
                    Style[7, {
                    GrayLevel[0], FontFamily -> "Arial"}], "Tooltip"]& ], 
                    
                    EventHandlerTag[{
                    "MouseClicked" :> 
                    FEPrivate`Set[DynamicChart`click$1522$1552, 
                    FEPrivate`Not[DynamicChart`click$1522$1552]], 
                    PassEventsDown -> True, Method -> "Preemptive", 
                    PassEventsUp -> True}]], 
                    Dynamic[
                    If[
                    DynamicChart`click$1522$1552, {{{1., 0}, {
                    0, 1.}}, {-0.10812816349111953`, -0.16825070656623622`}}, \
{{1, 0}, {0, 1}}, {{1, 0}, {0, 1}}], 
                    TrackedSymbols :> {
                    DynamicChart`click$1522$1552}]]}}}}}, {}}, {{}}}}, {{{{
                GeometricTransformationBox[
                 TagBox[
                  TagBox[
                   TooltipBox[
                    TagBox[{{}, {}}, StatusArea[#, 5]& , TagBoxNote -> "5"], 
                    StyleBox["5", {
                    GrayLevel[0], FontFamily -> "Arial"}, StripOnInput -> 
                    False]], Annotation[#, 
                    Style[5, {
                    GrayLevel[0], FontFamily -> "Arial"}], "Tooltip"]& ], 
                  
                  EventHandlerTag[{
                   "MouseClicked" :> 
                    FEPrivate`Set[DynamicChart`click$1516$1552, 
                    FEPrivate`Not[DynamicChart`click$1516$1552]], 
                    PassEventsDown -> True, Method -> "Preemptive", 
                    PassEventsUp -> True}]], 
                 Dynamic[
                  If[
                  DynamicChart`click$1516$1552, {{{1., 0}, {
                    0, 1.}}, {-0.15114991487085164`, 
                    0.13097214678905705`}}, {{1, 0}, {0, 1}}, {{1, 0}, {0, 
                   1}}], TrackedSymbols :> {DynamicChart`click$1516$1552}]], 
                GeometricTransformationBox[
                 TagBox[
                  TagBox[
                   TooltipBox[
                    TagBox[{{}, {}}, StatusArea[#, 10]& , TagBoxNote -> "10"], 
                    StyleBox["10", {
                    GrayLevel[0], FontFamily -> "Arial"}, StripOnInput -> 
                    False]], Annotation[#, 
                    Style[10, {
                    GrayLevel[0], FontFamily -> "Arial"}], "Tooltip"]& ], 
                  
                  EventHandlerTag[{
                   "MouseClicked" :> 
                    FEPrivate`Set[DynamicChart`click$1519$1552, 
                    FEPrivate`Not[DynamicChart`click$1519$1552]], 
                    PassEventsDown -> True, Method -> "Preemptive", 
                    PassEventsUp -> True}]], 
                 Dynamic[
                  If[
                  DynamicChart`click$1519$1552, {{{1., 0}, {0, 1.}}, {
                    0.1918985947228995, 0.056346511368285904`}}, {{1, 0}, {0, 
                   1}}, {{1, 0}, {0, 1}}], 
                  TrackedSymbols :> {DynamicChart`click$1519$1552}]], 
                GeometricTransformationBox[
                 TagBox[
                  TagBox[
                   TooltipBox[
                    TagBox[{{}, {}}, StatusArea[#, 7]& , TagBoxNote -> "7"], 
                    StyleBox["7", {
                    GrayLevel[0], FontFamily -> "Arial"}, StripOnInput -> 
                    False]], Annotation[#, 
                    Style[7, {
                    GrayLevel[0], FontFamily -> "Arial"}], "Tooltip"]& ], 
                  
                  EventHandlerTag[{
                   "MouseClicked" :> 
                    FEPrivate`Set[DynamicChart`click$1522$1552, 
                    FEPrivate`Not[DynamicChart`click$1522$1552]], 
                    PassEventsDown -> True, Method -> "Preemptive", 
                    PassEventsUp -> True}]], 
                 Dynamic[
                  If[
                  DynamicChart`click$1522$1552, {{{1., 0}, {
                    0, 1.}}, {-0.10812816349111953`, -0.16825070656623622`}}, \
{{1, 0}, {0, 1}}, {{1, 0}, {0, 1}}], 
                  TrackedSymbols :> {
                   DynamicChart`click$1522$1552}]]}, {}}}, {}}}, 
           DynamicModuleValues :> {}], {{{}, {}}}, {{{{}, {}, {}, {}}}, {}}}, \
{PlotRangeClipping -> True, Frame -> True, FrameStyle -> GrayLevel[0.85], 
          Ticks -> None, FrameTicks -> None, Axes -> None, ImageSize -> 96, 
          ContentSelectable -> False, GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], LabelStyle -> {
            GrayLevel[0], FontFamily -> "Arial"}, 
          PlotRange -> {{-1.2, 1.2}, {-1.2, 1.2}}, PlotRangePadding -> 
          Scaled[0.02]}], 
        Graphics[{{}, {}, 
          
          DynamicModule[{
           DynamicChart`click$1516 = False, DynamicChart`click$1519 = False, 
            DynamicChart`click$1522 = False}, {{
             Directive[
              RGBColor[0.5, 0.5, 1.], 
              EdgeForm[
               Directive[
                GrayLevel[0], 
                Opacity[0.5]]]], {{{{{{}, {{
                    Directive[
                    EdgeForm[
                    Directive[
                    GrayLevel[0], 
                    Opacity[0.5]]], 
                    RGBColor[0.982864, 0.7431472, 0.3262672]], 
                    GeometricTransformation[
                    EventHandler[
                    Tooltip[
                    StatusArea[
                    RawBoxes[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[2.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    DiskBox[{0, 0}, 1., {1.7135959928671598`, 
                    3.141592653589793}]}]], 5], 
                    Style[5, {
                    GrayLevel[0], FontFamily -> "Arial"}]], {
                    "MouseClicked" :> FEPrivate`Set[DynamicChart`click$1516, 
                    FEPrivate`Not[DynamicChart`click$1516]]}, PassEventsDown -> 
                    True], 
                    Dynamic[
                    If[
                    DynamicChart`click$1516, {{{1., 0}, {
                    0, 1.}}, {-0.15114991487085164`, 
                    0.13097214678905705`}}, {{1, 0}, {0, 1}}, {{1, 0}, {0, 
                    1}}], TrackedSymbols :> {DynamicChart`click$1516}]]}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    GrayLevel[0], 
                    Opacity[0.5]]], 
                    RGBColor[0.784, 0.47519999999999996`, 0.2]], 
                    GeometricTransformation[
                    EventHandler[
                    Tooltip[
                    StatusArea[
                    RawBoxes[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[2.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    DiskBox[{0, 0}, 1., {-1.1423973285781068`, 
                    1.7135959928671598`}]}]], 10], 
                    Style[10, {
                    GrayLevel[0], FontFamily -> "Arial"}]], {
                    "MouseClicked" :> FEPrivate`Set[DynamicChart`click$1519, 
                    FEPrivate`Not[DynamicChart`click$1519]]}, PassEventsDown -> 
                    True], 
                    Dynamic[
                    If[
                    DynamicChart`click$1519, {{{1., 0}, {0, 1.}}, {
                    0.1918985947228995, 0.056346511368285904`}}, {{1, 0}, {0, 
                    1}}, {{1, 0}, {0, 1}}], 
                    TrackedSymbols :> {DynamicChart`click$1519}]]}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    GrayLevel[0], 
                    Opacity[0.5]]], 
                    RGBColor[0.4992, 0.5552, 0.8309304]], 
                    GeometricTransformation[
                    EventHandler[
                    Tooltip[
                    StatusArea[
                    RawBoxes[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[2.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    DiskBox[{0, 0}, 
                    1., {-3.141592653589793, -1.1423973285781068`}]}]], 7], 
                    Style[7, {
                    GrayLevel[0], FontFamily -> "Arial"}]], {
                    "MouseClicked" :> FEPrivate`Set[DynamicChart`click$1522, 
                    FEPrivate`Not[DynamicChart`click$1522]]}, PassEventsDown -> 
                    True], 
                    Dynamic[
                    If[
                    DynamicChart`click$1522, {{{1., 0}, {
                    0, 1.}}, {-0.10812816349111953`, -0.16825070656623622`}}, \
{{1, 0}, {0, 1}}, {{1, 0}, {0, 1}}], 
                    TrackedSymbols :> {
                    DynamicChart`click$1522}]]}}}}}, {}}, {{}}}}, {{{{
                GeometricTransformation[
                 EventHandler[
                  Tooltip[
                   StatusArea[{{}, {}}, 5], 
                   Style[5, {
                    GrayLevel[0], FontFamily -> "Arial"}]], {
                  "MouseClicked" :> FEPrivate`Set[DynamicChart`click$1516, 
                    FEPrivate`Not[DynamicChart`click$1516]]}, PassEventsDown -> 
                  True], 
                 Dynamic[
                  If[
                  DynamicChart`click$1516, {{{1., 0}, {
                    0, 1.}}, {-0.15114991487085164`, 
                    0.13097214678905705`}}, {{1, 0}, {0, 1}}, {{1, 0}, {0, 
                   1}}], TrackedSymbols :> {DynamicChart`click$1516}]], 
                GeometricTransformation[
                 EventHandler[
                  Tooltip[
                   StatusArea[{{}, {}}, 10], 
                   Style[10, {
                    GrayLevel[0], FontFamily -> "Arial"}]], {
                  "MouseClicked" :> FEPrivate`Set[DynamicChart`click$1519, 
                    FEPrivate`Not[DynamicChart`click$1519]]}, PassEventsDown -> 
                  True], 
                 Dynamic[
                  If[
                  DynamicChart`click$1519, {{{1., 0}, {0, 1.}}, {
                    0.1918985947228995, 0.056346511368285904`}}, {{1, 0}, {0, 
                   1}}, {{1, 0}, {0, 1}}], 
                  TrackedSymbols :> {DynamicChart`click$1519}]], 
                GeometricTransformation[
                 EventHandler[
                  Tooltip[
                   StatusArea[{{}, {}}, 7], 
                   Style[7, {
                    GrayLevel[0], FontFamily -> "Arial"}]], {
                  "MouseClicked" :> FEPrivate`Set[DynamicChart`click$1522, 
                    FEPrivate`Not[DynamicChart`click$1522]]}, PassEventsDown -> 
                  True], 
                 Dynamic[
                  If[
                  DynamicChart`click$1522, {{{1., 0}, {
                    0, 1.}}, {-0.10812816349111953`, -0.16825070656623622`}}, \
{{1, 0}, {0, 1}}, {{1, 0}, {0, 1}}], 
                  TrackedSymbols :> {DynamicChart`click$1522}]]}, {}}}, {}}}, 
           DynamicModuleValues :> {}], {{{}, {}}}, {{{{}, {}, {}, {}}}, {}}}, \
{ContentSelectable -> False, GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], LabelStyle -> {
            GrayLevel[0], FontFamily -> "Arial"}, 
          PlotRange -> {{-1.2, 1.2}, {-1.2, 1.2}}, PlotRangePadding -> 
          Scaled[0.02]}]]}, {
       ItemBox[
        RowBox[{"1 level", 
          AdjustmentBox[" | ", BoxBaselineShift -> -0.3], 
          RowBox[{"2", "elements"}]}], 
        BaseStyle -> {
         FontFamily -> "Helvetica", FontSize -> 10, FontColor -> 
          GrayLevel[0.4], Editable -> False, Selectable -> False}, 
        ItemSize -> {Automatic, Automatic}, Alignment -> {Left, Center}, 
        Background -> RGBColor[0.92, 0.92, 0.9]], "\[SpanFromLeft]"}}, 
     GridBoxFrame -> {"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}}, 
     FrameStyle -> RGBColor[0, 0, 0, 0.4], GridBoxDividers -> {"Columns" -> {
         RGBColor[0, 0, 0, 0.4], 
         RGBColor[0, 0, 0, 0.3], {
          RGBColor[0, 0, 0, 0.09]}, 
         RGBColor[0, 0, 0, 0.4]}, "Rows" -> {
         RGBColor[0, 0, 0, 0.4], {
          RGBColor[0, 0, 0, 0.08]}, 
         RGBColor[0, 0, 0, 0.4]}}, RowSpacings -> 1.2, 
     GridBoxBackground -> {"Columns" -> {
         RGBColor[0.92, 0.92, 0.9]}}, 
     GridBoxAlignment -> {"Columns" -> {{Left}}}, ColumnSpacings -> 2.5, 
     GridFrameMargins -> {{2, 3}, {1, 3}}, 
     GridBoxItemSize -> {"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
      RowMinHeight -> 1.3],"Dataset[Association[(_String -> _Graphics)..]]"},
   "Dataset",
   DisplayFunction->(TagBox[
     StyleBox[#, {
      ShowAutoStyles -> False, LineBreakWithin -> False, FontWeight -> 
       "Light", FontFamily -> "Helvetica Neue", NumberMarks -> False, 
       SpanMaxSize -> 3, SpanMinSize -> 1., Editable -> False, Selectable -> 
       True, Background -> RGBColor[0.985, 0.98, 0.973], 
       LinebreakAdjustments -> {0.4, 5, 100, 0, 0.5}, LineIndent -> 0, 
       LineSpacing -> {1.1, 5}}], Deploy]& ),
   InterpretationFunction->(#2& )],
  False,
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[9]=",ExpressionUUID->"9349c531-df93-49b9-adcd-38830722cb67"]
}, Open  ]],

Cell["You can give a function to apply to all rows too.", "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"79b5422a-6451-438c-912f-c2858349b26b"],

Cell[TextData[{
 "This extracts the value of each \[OpenCurlyDoubleQuote]",
 Cell[BoxData[
 "z"], "InlineCode",ExpressionUUID->"0af2a081-adf0-4ab1-9499-adc192099e4d"],
 " column\[CloseCurlyDoubleQuote], then applies ",
 Cell[BoxData[
 "f"], "InlineCode",ExpressionUUID->"2e0515cd-d2dd-4b7c-ba29-d9b8c780ac40"],
 " to the association of results:"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"027ac5c2-f05c-40b5-a2c8-3e802b9c9989"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"data", "[", 
  RowBox[{"f", ",", "\"\<z\>\""}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[10]:=",ExpressionUUID->"900774a1-1566-4273-a6cd-2c7b45f72e62"],

Cell[BoxData[
 RowBox[{"f", "[", 
  RowBox[{"\[LeftAssociation]", 
   RowBox[{
    RowBox[{"\<\"a\"\>", "\[Rule]", "3"}], ",", 
    RowBox[{"\<\"b\"\>", "\[Rule]", "7"}]}], "\[RightAssociation]"}], 
  "]"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[10]=",ExpressionUUID->"93a10bda-3c38-43dc-bf92-1f23031cf17a"]
}, Open  ]],

Cell[TextData[{
 "Apply ",
 Cell[BoxData[
 "f"], "InlineCode",ExpressionUUID->"6c3f0b27-9bb2-424d-87d9-c3b4a6f4c2a6"],
 " to the totals of all columns:"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"a3a22487-c08e-4d54-bc5b-0522ef264a2b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"data", "[", 
  RowBox[{"f", ",", "Total"}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[11]:=",ExpressionUUID->"2afd332c-154e-4e33-8cdd-c5f56a45478d"],

Cell[BoxData[
 RowBox[{"f", "[", 
  RowBox[{"\[LeftAssociation]", 
   RowBox[{
    RowBox[{"\<\"a\"\>", "\[Rule]", "6"}], ",", 
    RowBox[{"\<\"b\"\>", "\[Rule]", "22"}]}], "\[RightAssociation]"}], 
  "]"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellTags->"LastCellOfAPage",
 CellLabel->"Out[11]=",ExpressionUUID->"46275763-ac98-4a54-860d-488d44cadfd0"]
}, Open  ]],

Cell["Find the maximum of these totals:", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->{
  "i:7", "p:273"},ExpressionUUID->"d82b1ffa-93e4-4633-a488-dfbf8a910fd6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"data", "[", 
  RowBox[{"Max", ",", "Total"}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[12]:=",ExpressionUUID->"b3b54bc9-a83f-4803-aa0b-17e76799019e"],

Cell[BoxData["22"], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[12]=",ExpressionUUID->"4aa40155-9de0-44d6-a471-f29c72d60242"]
}, Open  ]],

Cell[TextData[{
 "You can always \[OpenCurlyDoubleQuote]chain\[CloseCurlyDoubleQuote] \
queries, for example first finding the totals for all rows, then picking out \
the result for the \[OpenCurlyDoubleQuote]",
 Cell[BoxData[
 "b"], "InlineCodeText",ExpressionUUID->
  "8d2e431b-ccfb-482c-bd06-80daa0bb8d54"],
 " row\[CloseCurlyDoubleQuote]."
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:8",ExpressionUUID->"ff98b7e0-138a-45af-989d-ed8d050058f1"],

Cell[TextData[{
 "Find totals for all rows, then pick out the total for the \
\[OpenCurlyDoubleQuote]",
 Cell[BoxData[
 "b"], "InlineCode",ExpressionUUID->"803040d7-8616-4fe2-abb9-f1c086b27f1a"],
 " row\[CloseCurlyDoubleQuote]:"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"a6635119-7749-4ac7-95d3-598391ed7cdd"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "[", 
   RowBox[{"All", ",", "Total"}], "]"}], "[", "\"\<b\>\"", "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[13]:=",ExpressionUUID->"f20154f4-6a41-49af-adfe-c14887a8f821"],

Cell[BoxData["22"], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[13]=",ExpressionUUID->"11b49846-53ad-45fe-a741-ba9ab6963177"]
}, Open  ]],

Cell["It\[CloseCurlyQuote]s equivalent to this:", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"a169fc75-0a38-4045-a3a4-aeda08a0fce7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"data", "[", 
  RowBox[{"\"\<b\>\"", ",", "Total"}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[14]:=",ExpressionUUID->"104e98a3-3122-4786-840d-4b2da3dfc687"],

Cell[BoxData["22"], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[14]=",ExpressionUUID->"cb82f2cc-1c41-4c84-9d07-1fce75c3d8d7"]
}, Open  ]],

Cell[TextData[{
 "Particularly when one\[CloseCurlyQuote]s dealing with large datasets, it\
\[CloseCurlyQuote]s common to want to select parts based on a criterion. The ",
 StyleBox["operator form",
  FontSlant->"Italic"],
 " of ",
 ButtonBox["Select",
  BaseStyle->"Link"],
 " provides a very convenient way to do this. "
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:9",ExpressionUUID->"b9eadf98-12c8-4cee-ba34-02522b3964a9"],

Cell["Select numbers greater than 5 from a list:", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:10",ExpressionUUID->"d7cbc34c-71c2-4865-a6f1-367a4f38ae80"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Select", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "1", ",", "3", ",", "6", ",", "8", ",", "2", ",", "5", ",", "9", ",", 
     "7"}], "}"}], ",", 
   RowBox[{
    RowBox[{"#", ">", "5"}], "&"}]}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[15]:=",ExpressionUUID->"36514890-116a-4f18-9729-92e8d3c5ace1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"6", ",", "8", ",", "9", ",", "7"}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[15]=",ExpressionUUID->"a4d7233f-0698-4e01-87ca-f05647a1b76a"]
}, Open  ]],

Cell[TextData[{
 "Another way to get the same answer, using the operator form of ",
 ButtonBox["Select",
  BaseStyle->"Link"],
 ":"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"3e584423-7ae2-45f5-ab32-44545e37b1df"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Select", "[", 
   RowBox[{
    RowBox[{"#", ">", "5"}], "&"}], "]"}], "[", 
  RowBox[{"{", 
   RowBox[{
   "1", ",", "3", ",", "6", ",", "8", ",", "2", ",", "5", ",", "9", ",", 
    "7"}], "}"}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[16]:=",ExpressionUUID->"beab4963-4ecf-4497-943a-fa5a1969dac0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"6", ",", "8", ",", "9", ",", "7"}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[16]=",ExpressionUUID->"419fafec-bb14-4557-9600-928ae03d6931"]
}, Open  ]],

Cell[TextData[{
 "The operator form of ",
 ButtonBox["Select",
  BaseStyle->"Link"],
 " is a function which can be applied to actually perform the ",
 ButtonBox["Select",
  BaseStyle->"Link"],
 " operation."
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"827a4b06-e6e1-4411-a2bd-9a4641c44481"],

Cell[TextData[{
 "Make a dataset by selecting only rows whose \[OpenCurlyDoubleQuote]",
 Cell[BoxData[
 "z"], "InlineCode",ExpressionUUID->"5eb63543-0674-45a9-987d-4665c2bee7e9"],
 " column\[CloseCurlyDoubleQuote] is greater than 5:"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"cefa1cbd-d66d-4a62-9103-8a3767c42b31"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"data", "[", 
  RowBox[{"Select", "[", 
   RowBox[{
    RowBox[{"#z", ">", "5"}], "&"}], "]"}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[17]:=",ExpressionUUID->"186f24eb-b211-4ca1-98bd-e1c5ac4b81a2"],

Cell[BoxData[
 TagBox[
  TemplateBox[{GridBox[{{
       ItemBox["", Frame -> {False, True, True, False}], 
       StyleBox["\"x\"", 
        GrayLevel[0.3]], 
       StyleBox["\"y\"", 
        GrayLevel[0.3]], 
       StyleBox["\"z\"", 
        GrayLevel[0.3]]}, {
       StyleBox[
        StyleBox["\"b\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 5, 10, 7}, {
       ItemBox[
        RowBox[{"2 levels", 
          AdjustmentBox[" | ", BoxBaselineShift -> -0.3], 
          RowBox[{"1", "rows"}]}], 
        BaseStyle -> {
         FontFamily -> "Helvetica", FontSize -> 10, FontColor -> 
          GrayLevel[0.4], Editable -> False, Selectable -> False}, 
        ItemSize -> {Automatic, Automatic}, Alignment -> {Left, Center}, 
        Background -> RGBColor[0.92, 0.92, 0.9]], "\[SpanFromLeft]", 
       "\[SpanFromLeft]", "\[SpanFromLeft]"}}, 
     GridBoxFrame -> {"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}}, 
     FrameStyle -> RGBColor[0, 0, 0, 0.4], GridBoxDividers -> {"Columns" -> {
         RGBColor[0, 0, 0, 0.4], 
         RGBColor[0, 0, 0, 0.3], {
          RGBColor[0, 0, 0, 0.09]}, 
         RGBColor[0, 0, 0, 0.4]}, "Rows" -> {
         RGBColor[0, 0, 0, 0.4], 
         RGBColor[0, 0, 0, 0.3], {
          RGBColor[0, 0, 0, 0.08]}, 
         RGBColor[0, 0, 0, 0.4]}}, RowSpacings -> {1.5, 1.2}, 
     GridBoxBackground -> {"Columns" -> {
         RGBColor[0.92, 0.92, 0.9]}, "Rows" -> {
         RGBColor[0.92, 0.92, 0.9]}}, 
     GridBoxAlignment -> {"Columns" -> {{Left}}}, ColumnSpacings -> 2.5, 
     GridFrameMargins -> {{2, 3}, {1, 3}}, 
     GridBoxItemSize -> {"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
      RowMinHeight -> 1.3],
    "Dataset[Association[(_String -> _Association)..]]"},
   "Dataset",
   DisplayFunction->(TagBox[
     StyleBox[#, {
      ShowAutoStyles -> False, LineBreakWithin -> False, FontWeight -> 
       "Light", FontFamily -> "Helvetica Neue", NumberMarks -> False, 
       SpanMaxSize -> 3, SpanMinSize -> 1., Editable -> False, Selectable -> 
       True, Background -> RGBColor[0.985, 0.98, 0.973], 
       LinebreakAdjustments -> {0.4, 5, 100, 0, 0.5}, LineIndent -> 0, 
       LineSpacing -> {1.1, 5}}], Deploy]& ),
   InterpretationFunction->(#2& )],
  False,
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[17]=",ExpressionUUID->"32734c09-762f-4de3-bcfc-c785750d4f27"]
}, Open  ]],

Cell["\<\
For each row, select columns whose values are greater than 5, leaving a \
ragged structure:\
\>", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"5f8be866-29d8-45a2-a54d-c93d4fbae989"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"data", "[", 
  RowBox[{"All", ",", 
   RowBox[{"Select", "[", 
    RowBox[{
     RowBox[{"#", ">", "5"}], "&"}], "]"}]}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[18]:=",ExpressionUUID->"223fea74-c7fd-415f-8bfe-ad381260634e"],

Cell[BoxData[
 TagBox[
  TemplateBox[{GridBox[{{
       StyleBox[
        StyleBox["\"a\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 
       StyleBox[
        RowBox[{
          StyleBox["\[LeftAssociation]", 
           GrayLevel[0.45]], "\[ThinSpace]", "\[ThinSpace]", 
          StyleBox["\[RightAssociation]", 
           GrayLevel[0.45]]}], LineBreakWithin -> Automatic]}, {
       StyleBox[
        StyleBox["\"b\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 
       StyleBox[
        RowBox[{
          StyleBox["\[LeftAssociation]", 
           GrayLevel[0.45]], "\[ThinSpace]", 
          RowBox[{
            StyleBox[
             StyleBox["\"y\"", FontColor -> GrayLevel[0.4]], 
             GrayLevel[0.3]], 
            StyleBox["\[Rule]", 
             GrayLevel[0.5]], 10}], ",", 
          RowBox[{
            StyleBox[
             StyleBox["\"z\"", FontColor -> GrayLevel[0.4]], 
             GrayLevel[0.3]], 
            StyleBox["\[Rule]", 
             GrayLevel[0.5]], 7}], "\[ThinSpace]", 
          StyleBox["\[RightAssociation]", 
           GrayLevel[0.45]]}], LineBreakWithin -> Automatic]}, {
       ItemBox[
        RowBox[{"2 levels", 
          AdjustmentBox[" | ", BoxBaselineShift -> -0.3], 
          RowBox[{"2", "rows"}]}], 
        BaseStyle -> {
         FontFamily -> "Helvetica", FontSize -> 10, FontColor -> 
          GrayLevel[0.4], Editable -> False, Selectable -> False}, 
        ItemSize -> {Automatic, Automatic}, Alignment -> {Left, Center}, 
        Background -> RGBColor[0.92, 0.92, 0.9]], "\[SpanFromLeft]"}}, 
     GridBoxFrame -> {"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}}, 
     FrameStyle -> RGBColor[0, 0, 0, 0.4], GridBoxDividers -> {"Columns" -> {
         RGBColor[0, 0, 0, 0.4], 
         RGBColor[0, 0, 0, 0.3], {
          RGBColor[0, 0, 0, 0.09]}, 
         RGBColor[0, 0, 0, 0.4]}, "Rows" -> {
         RGBColor[0, 0, 0, 0.4], {
          RGBColor[0, 0, 0, 0.08]}, 
         RGBColor[0, 0, 0, 0.4]}}, RowSpacings -> 1.2, 
     GridBoxBackground -> {"Columns" -> {
         RGBColor[0.92, 0.92, 0.9]}}, 
     GridBoxAlignment -> {"Columns" -> {{Left}}}, ColumnSpacings -> 2.5, 
     GridFrameMargins -> {{2, 3}, {1, 3}}, 
     GridBoxItemSize -> {"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
      RowMinHeight -> 1.3],
    "Dataset[Association[(_String -> _Association)..]]"},
   "Dataset",
   DisplayFunction->(TagBox[
     StyleBox[#, {
      ShowAutoStyles -> False, LineBreakWithin -> False, FontWeight -> 
       "Light", FontFamily -> "Helvetica Neue", NumberMarks -> False, 
       SpanMaxSize -> 3, SpanMinSize -> 1., Editable -> False, Selectable -> 
       True, Background -> RGBColor[0.985, 0.98, 0.973], 
       LinebreakAdjustments -> {0.4, 5, 100, 0, 0.5}, LineIndent -> 0, 
       LineSpacing -> {1.1, 5}}], Deploy]& ),
   InterpretationFunction->(#2& )],
  False,
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellTags->"LastCellOfAPage",
 CellLabel->"Out[18]=",ExpressionUUID->"8c5f0ad6-5aab-4240-8cc0-ef6ff56c3b30"]
}, Open  ]],

Cell[TextData[{
 ButtonBox["Normal",
  BaseStyle->"Link"],
 " turns the dataset into an ordinary association of associations: "
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->{
  "i:11", "p:274"},ExpressionUUID->"572c48e2-ce18-492b-847e-243f6b22a7eb"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Normal", "[", "%", "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[19]:=",ExpressionUUID->"c56c6565-0c05-4690-b4dc-b8a3189dceb5"],

Cell[BoxData[
 RowBox[{"\[LeftAssociation]", 
  RowBox[{
   RowBox[{"\<\"a\"\>", "\[Rule]", 
    RowBox[{"\[LeftAssociation]", "\[RightAssociation]"}]}], ",", 
   RowBox[{"\<\"b\"\>", "\[Rule]", 
    RowBox[{"\[LeftAssociation]", 
     RowBox[{
      RowBox[{"\<\"y\"\>", "\[Rule]", "10"}], ",", 
      RowBox[{"\<\"z\"\>", "\[Rule]", "7"}]}], "\[RightAssociation]"}]}]}], 
  "\[RightAssociation]"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[19]=",ExpressionUUID->"e5ead18f-a0f6-446a-9da1-40e89907c1de"]
}, Open  ]],

Cell["Many Wolfram Language functions have operator forms. ", "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"737e6bd6-6b78-4101-91a9-a45bf66502fe"],

Cell["\<\
Sort according to the values of a function applied to each element:\
\>", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:12",ExpressionUUID->"4bebf4d1-6780-4e6f-a019-008665b748b4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SortBy", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "1", ",", "3", ",", "6", ",", "8", ",", "2", ",", "5", ",", "9", ",", 
     "7"}], "}"}], ",", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"EvenQ", "[", "#", "]"}], ",", "#", ",", 
      RowBox[{"10", "+", "#"}]}], "]"}], "&"}]}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[20]:=",ExpressionUUID->"28d90355-8492-4ca5-bfd4-a8290c872d69"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "2", ",", "6", ",", "8", ",", "1", ",", "3", ",", "5", ",", "7", ",", "9"}],
   "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[20]=",ExpressionUUID->"52d3be4f-5eb3-46db-91f8-30814e3c81c8"]
}, Open  ]],

Cell[TextData[{
 ButtonBox["SortBy",
  BaseStyle->"Link"],
 " has an operator form:"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"4380fe6a-134f-415d-a3d9-15fea9f58fc1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SortBy", "[", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"EvenQ", "[", "#", "]"}], ",", "#", ",", 
      RowBox[{"10", "+", "#"}]}], "]"}], "&"}], "]"}], "[", 
  RowBox[{"{", 
   RowBox[{
   "1", ",", "3", ",", "6", ",", "8", ",", "2", ",", "5", ",", "9", ",", 
    "7"}], "}"}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[21]:=",ExpressionUUID->"93ffa31e-eaa3-4ab9-a226-5d6c0ca9ad6f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "2", ",", "6", ",", "8", ",", "1", ",", "3", ",", "5", ",", "7", ",", "9"}],
   "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[21]=",ExpressionUUID->"4279b39a-1f88-479a-8647-bf6b61d9c1f6"]
}, Open  ]],

Cell[TextData[{
 "Sort rows according to the value of the difference of the ",
 Cell[BoxData[
 "x"], "InlineCode",ExpressionUUID->"4af1afec-07f4-4697-a20e-ae47d8f4f561"],
 " and ",
 Cell[BoxData[
 "y"], "InlineCode",ExpressionUUID->"30104e5e-a065-4c11-a7f7-a2635b2df13c"],
 " columns:"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"4fbd0656-4f09-4ec4-ae12-1ffe0d6210f0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"data", "[", 
  RowBox[{"SortBy", "[", 
   RowBox[{
    RowBox[{"#x", "-", "#y"}], "&"}], "]"}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[22]:=",ExpressionUUID->"697b1e75-efde-4bc6-8dbd-8abe08482176"],

Cell[BoxData[
 TagBox[
  TemplateBox[{GridBox[{{
       ItemBox["", Frame -> {False, True, True, False}], 
       StyleBox["\"x\"", 
        GrayLevel[0.3]], 
       StyleBox["\"y\"", 
        GrayLevel[0.3]], 
       StyleBox["\"z\"", 
        GrayLevel[0.3]]}, {
       StyleBox[
        StyleBox["\"b\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 5, 10, 7}, {
       StyleBox[
        StyleBox["\"a\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 1, 2, 3}, {
       ItemBox[
        RowBox[{"2 levels", 
          AdjustmentBox[" | ", BoxBaselineShift -> -0.3], 
          RowBox[{"2", "rows"}]}], 
        BaseStyle -> {
         FontFamily -> "Helvetica", FontSize -> 10, FontColor -> 
          GrayLevel[0.4], Editable -> False, Selectable -> False}, 
        ItemSize -> {Automatic, Automatic}, Alignment -> {Left, Center}, 
        Background -> RGBColor[0.92, 0.92, 0.9]], "\[SpanFromLeft]", 
       "\[SpanFromLeft]", "\[SpanFromLeft]"}}, 
     GridBoxFrame -> {"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}}, 
     FrameStyle -> RGBColor[0, 0, 0, 0.4], GridBoxDividers -> {"Columns" -> {
         RGBColor[0, 0, 0, 0.4], 
         RGBColor[0, 0, 0, 0.3], {
          RGBColor[0, 0, 0, 0.09]}, 
         RGBColor[0, 0, 0, 0.4]}, "Rows" -> {
         RGBColor[0, 0, 0, 0.4], 
         RGBColor[0, 0, 0, 0.3], {
          RGBColor[0, 0, 0, 0.08]}, 
         RGBColor[0, 0, 0, 0.4]}}, RowSpacings -> {1.5, 1.2}, 
     GridBoxBackground -> {"Columns" -> {
         RGBColor[0.92, 0.92, 0.9]}, "Rows" -> {
         RGBColor[0.92, 0.92, 0.9]}}, 
     GridBoxAlignment -> {"Columns" -> {{Left}}}, ColumnSpacings -> 2.5, 
     GridFrameMargins -> {{2, 3}, {1, 3}}, 
     GridBoxItemSize -> {"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
      RowMinHeight -> 1.3],
    "Dataset[Association[(_String -> _Association)..]]"},
   "Dataset",
   DisplayFunction->(TagBox[
     StyleBox[#, {
      ShowAutoStyles -> False, LineBreakWithin -> False, FontWeight -> 
       "Light", FontFamily -> "Helvetica Neue", NumberMarks -> False, 
       SpanMaxSize -> 3, SpanMinSize -> 1., Editable -> False, Selectable -> 
       True, Background -> RGBColor[0.985, 0.98, 0.973], 
       LinebreakAdjustments -> {0.4, 5, 100, 0, 0.5}, LineIndent -> 0, 
       LineSpacing -> {1.1, 5}}], Deploy]& ),
   InterpretationFunction->(#2& )],
  False,
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[22]=",ExpressionUUID->"748f56e2-54aa-407b-bf39-84b71868675d"]
}, Open  ]],

Cell["Sort the rows, and find the total of all columns:", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"50003b98-ff85-46ec-bf4e-04325771d12c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"data", "[", 
  RowBox[{
   RowBox[{"SortBy", "[", 
    RowBox[{
     RowBox[{"#x", "-", "#y"}], "&"}], "]"}], ",", "Total"}], "]"}]], "Input",\

 Deletable->False,
 CellLabel->"In[23]:=",ExpressionUUID->"f2d0b126-8801-4e40-a711-9376f916e64e"],

Cell[BoxData[
 TagBox[
  TemplateBox[{GridBox[{{
       StyleBox[
        StyleBox["\"b\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 22}, {
       StyleBox[
        StyleBox["\"a\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 6}, {
       ItemBox[
        RowBox[{"1 level", 
          AdjustmentBox[" | ", BoxBaselineShift -> -0.3], 
          RowBox[{"2", "elements"}]}], 
        BaseStyle -> {
         FontFamily -> "Helvetica", FontSize -> 10, FontColor -> 
          GrayLevel[0.4], Editable -> False, Selectable -> False}, 
        ItemSize -> {Automatic, Automatic}, Alignment -> {Left, Center}, 
        Background -> RGBColor[0.92, 0.92, 0.9]], "\[SpanFromLeft]"}}, 
     GridBoxFrame -> {"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}}, 
     FrameStyle -> RGBColor[0, 0, 0, 0.4], GridBoxDividers -> {"Columns" -> {
         RGBColor[0, 0, 0, 0.4], 
         RGBColor[0, 0, 0, 0.3], {
          RGBColor[0, 0, 0, 0.09]}, 
         RGBColor[0, 0, 0, 0.4]}, "Rows" -> {
         RGBColor[0, 0, 0, 0.4], {
          RGBColor[0, 0, 0, 0.08]}, 
         RGBColor[0, 0, 0, 0.4]}}, RowSpacings -> 1.2, 
     GridBoxBackground -> {"Columns" -> {
         RGBColor[0.92, 0.92, 0.9]}}, 
     GridBoxAlignment -> {"Columns" -> {{Left}}}, ColumnSpacings -> 2.5, 
     GridFrameMargins -> {{2, 3}, {1, 3}}, 
     GridBoxItemSize -> {"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
      RowMinHeight -> 1.3],"Dataset[Association[(_String -> _Integer)..]]"},
   "Dataset",
   DisplayFunction->(TagBox[
     StyleBox[#, {
      ShowAutoStyles -> False, LineBreakWithin -> False, FontWeight -> 
       "Light", FontFamily -> "Helvetica Neue", NumberMarks -> False, 
       SpanMaxSize -> 3, SpanMinSize -> 1., Editable -> False, Selectable -> 
       True, Background -> RGBColor[0.985, 0.98, 0.973], 
       LinebreakAdjustments -> {0.4, 5, 100, 0, 0.5}, LineIndent -> 0, 
       LineSpacing -> {1.1, 5}}], Deploy]& ),
   InterpretationFunction->(#2& )],
  False,
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellTags->"LastCellOfAPage",
 CellLabel->"Out[23]=",ExpressionUUID->"0ca64217-b931-4a26-a002-b74e8c8d7b37"]
}, Open  ]],

Cell["\<\
Sometimes you want to apply a function to each element in the dataset.\
\>", "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"faeb792f-2496-43f0-bbfa-7aaa2d65bfdb"],

Cell[TextData[{
 "Apply ",
 Cell[BoxData[
 "f"], "InlineCode",ExpressionUUID->"b48694d2-728f-4ccc-8728-ef1bab47a29c"],
 " to each element in the dataset:"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"b3c72b2f-a416-415d-a967-2d2d9874735a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"data", "[", 
  RowBox[{"All", ",", "All", ",", "f"}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[24]:=",ExpressionUUID->"7ce7353c-90ea-4ebf-84db-8153365218be"],

Cell[BoxData[
 TagBox[
  TemplateBox[{GridBox[{{
       ItemBox["", Frame -> {False, True, True, False}], 
       StyleBox["\"x\"", 
        GrayLevel[0.3]], 
       StyleBox["\"y\"", 
        GrayLevel[0.3]], 
       StyleBox["\"z\"", 
        GrayLevel[0.3]]}, {
       StyleBox[
        StyleBox["\"a\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 
       InterpretationBox[
        TagBox[
         RowBox[{"f", "[", "1", "]"}], Short[#, 5]& ], 
        $CellContext`f[1]], 
       InterpretationBox[
        TagBox[
         RowBox[{"f", "[", "2", "]"}], Short[#, 5]& ], 
        $CellContext`f[2]], 
       InterpretationBox[
        TagBox[
         RowBox[{"f", "[", "3", "]"}], Short[#, 5]& ], 
        $CellContext`f[3]]}, {
       StyleBox[
        StyleBox["\"b\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 
       InterpretationBox[
        TagBox[
         RowBox[{"f", "[", "5", "]"}], Short[#, 5]& ], 
        $CellContext`f[5]], 
       InterpretationBox[
        TagBox[
         RowBox[{"f", "[", "10", "]"}], Short[#, 5]& ], 
        $CellContext`f[10]], 
       InterpretationBox[
        TagBox[
         RowBox[{"f", "[", "7", "]"}], Short[#, 5]& ], 
        $CellContext`f[7]]}, {
       ItemBox[
        RowBox[{"2 levels", 
          AdjustmentBox[" | ", BoxBaselineShift -> -0.3], 
          RowBox[{"2", "rows"}]}], 
        BaseStyle -> {
         FontFamily -> "Helvetica", FontSize -> 10, FontColor -> 
          GrayLevel[0.4], Editable -> False, Selectable -> False}, 
        ItemSize -> {Automatic, Automatic}, Alignment -> {Left, Center}, 
        Background -> RGBColor[0.92, 0.92, 0.9]], "\[SpanFromLeft]", 
       "\[SpanFromLeft]", "\[SpanFromLeft]"}}, 
     GridBoxFrame -> {"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}}, 
     FrameStyle -> RGBColor[0, 0, 0, 0.4], GridBoxDividers -> {"Columns" -> {
         RGBColor[0, 0, 0, 0.4], 
         RGBColor[0, 0, 0, 0.3], {
          RGBColor[0, 0, 0, 0.09]}, 
         RGBColor[0, 0, 0, 0.4]}, "Rows" -> {
         RGBColor[0, 0, 0, 0.4], 
         RGBColor[0, 0, 0, 0.3], {
          RGBColor[0, 0, 0, 0.08]}, 
         RGBColor[0, 0, 0, 0.4]}}, RowSpacings -> {1.5, 1.2}, 
     GridBoxBackground -> {"Columns" -> {
         RGBColor[0.92, 0.92, 0.9]}, "Rows" -> {
         RGBColor[0.92, 0.92, 0.9]}}, 
     GridBoxAlignment -> {"Columns" -> {{Left}}}, ColumnSpacings -> 2.5, 
     GridFrameMargins -> {{2, 3}, {1, 3}}, 
     GridBoxItemSize -> {"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
      RowMinHeight -> 1.3],
    "Dataset[Association[(_String -> _Association)..]]"},
   "Dataset",
   DisplayFunction->(TagBox[
     StyleBox[#, {
      ShowAutoStyles -> False, LineBreakWithin -> False, FontWeight -> 
       "Light", FontFamily -> "Helvetica Neue", NumberMarks -> False, 
       SpanMaxSize -> 3, SpanMinSize -> 1., Editable -> False, Selectable -> 
       True, Background -> RGBColor[0.985, 0.98, 0.973], 
       LinebreakAdjustments -> {0.4, 5, 100, 0, 0.5}, LineIndent -> 0, 
       LineSpacing -> {1.1, 5}}], Deploy]& ),
   InterpretationFunction->(#2& )],
  False,
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[24]=",ExpressionUUID->"24e16fb4-dbdd-46fb-b57e-3de2e24013fb"]
}, Open  ]],

Cell["Sort\[NonBreakingSpace]the\[NonBreakingSpace]rows\[NonBreakingSpace]\
before\[NonBreakingSpace]totaling\[NonBreakingSpace]the\[NonBreakingSpace]\
squares\[NonBreakingSpace]of\[NonBreakingSpace]their\[NonBreakingSpace]\
elements:", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"d1ae8501-e20d-48d5-80e7-e44bb2950a56"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"data", "[", 
  RowBox[{
   RowBox[{"SortBy", "[", 
    RowBox[{
     RowBox[{"#x", "-", "#y"}], "&"}], "]"}], ",", "Total", ",", 
   RowBox[{
    RowBox[{"#", "^", "2"}], "&"}]}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[25]:=",ExpressionUUID->"276d30ed-bf4e-42d4-85c9-8a8ac964ee47"],

Cell[BoxData[
 TagBox[
  TemplateBox[{GridBox[{{
       StyleBox[
        StyleBox["\"b\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 174}, {
       StyleBox[
        StyleBox["\"a\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 14}, {
       ItemBox[
        RowBox[{"1 level", 
          AdjustmentBox[" | ", BoxBaselineShift -> -0.3], 
          RowBox[{"2", "elements"}]}], 
        BaseStyle -> {
         FontFamily -> "Helvetica", FontSize -> 10, FontColor -> 
          GrayLevel[0.4], Editable -> False, Selectable -> False}, 
        ItemSize -> {Automatic, Automatic}, Alignment -> {Left, Center}, 
        Background -> RGBColor[0.92, 0.92, 0.9]], "\[SpanFromLeft]"}}, 
     GridBoxFrame -> {"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}}, 
     FrameStyle -> RGBColor[0, 0, 0, 0.4], GridBoxDividers -> {"Columns" -> {
         RGBColor[0, 0, 0, 0.4], 
         RGBColor[0, 0, 0, 0.3], {
          RGBColor[0, 0, 0, 0.09]}, 
         RGBColor[0, 0, 0, 0.4]}, "Rows" -> {
         RGBColor[0, 0, 0, 0.4], {
          RGBColor[0, 0, 0, 0.08]}, 
         RGBColor[0, 0, 0, 0.4]}}, RowSpacings -> 1.2, 
     GridBoxBackground -> {"Columns" -> {
         RGBColor[0.92, 0.92, 0.9]}}, 
     GridBoxAlignment -> {"Columns" -> {{Left}}}, ColumnSpacings -> 2.5, 
     GridFrameMargins -> {{2, 3}, {1, 3}}, 
     GridBoxItemSize -> {"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
      RowMinHeight -> 1.3],"Dataset[Association[(_String -> _Rational)..]]"},
   "Dataset",
   DisplayFunction->(TagBox[
     StyleBox[#, {
      ShowAutoStyles -> False, LineBreakWithin -> False, FontWeight -> 
       "Light", FontFamily -> "Helvetica Neue", NumberMarks -> False, 
       SpanMaxSize -> 3, SpanMinSize -> 1., Editable -> False, Selectable -> 
       True, Background -> RGBColor[0.985, 0.98, 0.973], 
       LinebreakAdjustments -> {0.4, 5, 100, 0, 0.5}, LineIndent -> 0, 
       LineSpacing -> {1.1, 5}}], Deploy]& ),
   InterpretationFunction->(#2& )],
  False,
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[25]=",ExpressionUUID->"2727301d-ee49-45a0-973e-3b5a0baf4fea"]
}, Open  ]],

Cell[TextData[{
 "Datasets can contain arbitrary mixtures of lists and associations. Here\
\[CloseCurlyQuote]s a dataset that can be thought of as a ",
 StyleBox["list of records",
  FontSlant->"Italic"],
 " with named ",
 StyleBox["fields",
  FontSlant->"Italic"],
 "."
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->{
  "i:13", "p:275"},ExpressionUUID->"aaafc508-8ccd-429f-bbc7-0d7775b5a9a2"],

Cell["A dataset formed from a list of associations:", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"b1de8000-15d6-476e-894b-d77998484518"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Dataset", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"\[LeftAssociation]", 
     RowBox[{
      RowBox[{"\"\<x\>\"", "\[Rule]", "2"}], ",", 
      RowBox[{"\"\<y\>\"", "\[Rule]", "4"}], ",", 
      RowBox[{"\"\<z\>\"", "\[Rule]", "6"}]}], "\[RightAssociation]"}], ",", 
    RowBox[{"\[LeftAssociation]", 
     RowBox[{
      RowBox[{"\"\<x\>\"", "\[Rule]", "11"}], ",", 
      RowBox[{"\"\<y\>\"", "\[Rule]", "7"}], ",", 
      RowBox[{"\"\<z\>\"", "\[Rule]", "1"}]}], "\[RightAssociation]"}]}], 
   "}"}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[26]:=",ExpressionUUID->"b681b44b-981a-4667-9e70-3b6f5b169df4"],

Cell[BoxData[
 TagBox[
  TemplateBox[{GridBox[{{
       StyleBox["\"x\"", 
        GrayLevel[0.3]], 
       StyleBox["\"y\"", 
        GrayLevel[0.3]], 
       StyleBox["\"z\"", 
        GrayLevel[0.3]]}, {2, 4, 6}, {11, 7, 1}, {
       ItemBox[
        RowBox[{"2 levels", 
          AdjustmentBox[" | ", BoxBaselineShift -> -0.3], 
          RowBox[{"2", "rows"}]}], 
        BaseStyle -> {
         FontFamily -> "Helvetica", FontSize -> 10, FontColor -> 
          GrayLevel[0.4], Editable -> False, Selectable -> False}, 
        ItemSize -> {Automatic, Automatic}, Alignment -> {Left, Center}, 
        Background -> RGBColor[0.92, 0.92, 0.9]], "\[SpanFromLeft]", 
       "\[SpanFromLeft]"}}, 
     GridBoxFrame -> {"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}}, 
     FrameStyle -> RGBColor[0, 0, 0, 0.4], GridBoxDividers -> {"Columns" -> {
         RGBColor[0, 0, 0, 0.4], {
          RGBColor[0, 0, 0, 0.09]}, 
         RGBColor[0, 0, 0, 0.4]}, "Rows" -> {
         RGBColor[0, 0, 0, 0.4], 
         RGBColor[0, 0, 0, 0.3], {
          RGBColor[0, 0, 0, 0.08]}, 
         RGBColor[0, 0, 0, 0.4]}}, RowSpacings -> {1.5, 1.2}, 
     GridBoxBackground -> {"Columns" -> {}, "Rows" -> {
         RGBColor[0.92, 0.92, 0.9]}}, 
     GridBoxAlignment -> {"Columns" -> {{Left}}}, ColumnSpacings -> 2.5, 
     GridFrameMargins -> {{2, 3}, {1, 3}}, 
     GridBoxItemSize -> {"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
      RowMinHeight -> 1.3],"Dataset[{__Association}]"},
   "Dataset",
   DisplayFunction->(TagBox[
     StyleBox[#, {
      ShowAutoStyles -> False, LineBreakWithin -> False, FontWeight -> 
       "Light", FontFamily -> "Helvetica Neue", NumberMarks -> False, 
       SpanMaxSize -> 3, SpanMinSize -> 1., Editable -> False, Selectable -> 
       True, Background -> RGBColor[0.985, 0.98, 0.973], 
       LinebreakAdjustments -> {0.4, 5, 100, 0, 0.5}, LineIndent -> 0, 
       LineSpacing -> {1.1, 5}}], Deploy]& ),
   InterpretationFunction->(#2& )],
  False,
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[26]=",ExpressionUUID->"8b3174f6-6c26-4896-b23d-44cdbb80a9ff"]
}, Open  ]],

Cell["It\[CloseCurlyQuote]s OK for entries to be missing:", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:14",ExpressionUUID->"8b3ce44b-c5b9-45c8-8ca3-9b3efd7ad228"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Dataset", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"\[LeftAssociation]", 
     RowBox[{
      RowBox[{"\"\<x\>\"", "\[Rule]", "2"}], ",", 
      RowBox[{"\"\<y\>\"", "\[Rule]", "4"}], ",", 
      RowBox[{"\"\<z\>\"", "\[Rule]", "6"}]}], "\[RightAssociation]"}], ",", 
    RowBox[{"\[LeftAssociation]", 
     RowBox[{
      RowBox[{"\"\<x\>\"", "\[Rule]", "11"}], ",", 
      RowBox[{"\"\<y\>\"", "\[Rule]", "7"}]}], "\[RightAssociation]"}]}], 
   "}"}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[27]:=",ExpressionUUID->"ca0ad249-b62a-43fb-a3dc-68eb2ff7d1c3"],

Cell[BoxData[
 TagBox[
  TemplateBox[{GridBox[{{
       StyleBox["\"x\"", 
        GrayLevel[0.3]], 
       StyleBox["\"y\"", 
        GrayLevel[0.3]], 
       StyleBox["\"z\"", 
        GrayLevel[0.3]]}, {2, 4, 6}, {11, 7, 
       InterpretationBox[
        StyleBox[
        "KeyAbsent", FontFamily -> "Arial", FontSize -> 11, FontWeight -> 
         Bold, 
         GrayLevel[0.7]], 
        Missing["KeyAbsent", "z"]]}, {
       ItemBox[
        RowBox[{"2 levels", 
          AdjustmentBox[" | ", BoxBaselineShift -> -0.3], 
          RowBox[{"2", "rows"}]}], 
        BaseStyle -> {
         FontFamily -> "Helvetica", FontSize -> 10, FontColor -> 
          GrayLevel[0.4], Editable -> False, Selectable -> False}, 
        ItemSize -> {Automatic, Automatic}, Alignment -> {Left, Center}, 
        Background -> RGBColor[0.92, 0.92, 0.9]], "\[SpanFromLeft]", 
       "\[SpanFromLeft]"}}, 
     GridBoxFrame -> {"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}}, 
     FrameStyle -> RGBColor[0, 0, 0, 0.4], GridBoxDividers -> {"Columns" -> {
         RGBColor[0, 0, 0, 0.4], {
          RGBColor[0, 0, 0, 0.09]}, 
         RGBColor[0, 0, 0, 0.4]}, "Rows" -> {
         RGBColor[0, 0, 0, 0.4], 
         RGBColor[0, 0, 0, 0.3], {
          RGBColor[0, 0, 0, 0.08]}, 
         RGBColor[0, 0, 0, 0.4]}}, RowSpacings -> {1.5, 1.2}, 
     GridBoxBackground -> {"Columns" -> {}, "Rows" -> {
         RGBColor[0.92, 0.92, 0.9]}}, 
     GridBoxAlignment -> {"Columns" -> {{Left}}}, ColumnSpacings -> 2.5, 
     GridFrameMargins -> {{2, 3}, {1, 3}}, 
     GridBoxItemSize -> {"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
      RowMinHeight -> 1.3],"Dataset[{__Association}]"},
   "Dataset",
   DisplayFunction->(TagBox[
     StyleBox[#, {
      ShowAutoStyles -> False, LineBreakWithin -> False, FontWeight -> 
       "Light", FontFamily -> "Helvetica Neue", NumberMarks -> False, 
       SpanMaxSize -> 3, SpanMinSize -> 1., Editable -> False, Selectable -> 
       True, Background -> RGBColor[0.985, 0.98, 0.973], 
       LinebreakAdjustments -> {0.4, 5, 100, 0, 0.5}, LineIndent -> 0, 
       LineSpacing -> {1.1, 5}}], Deploy]& ),
   InterpretationFunction->(#2& )],
  False,
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[27]=",ExpressionUUID->"42f5d16e-1d12-41e9-91dc-b6c59ad56152"]
}, Open  ]],

Cell["\<\
Now that we\[CloseCurlyQuote]ve seen some simple examples, it\
\[CloseCurlyQuote]s time to look at something slightly more realistic. Let\
\[CloseCurlyQuote]s import a dataset giving properties of planets and moons. \
The dataset has a hierarchical structure, with each planet having a mass and \
radius of its own, and then also having a collection of moons, each of which \
have their own properties. This general structure is extremely common in \
practice (think students and grades, customers and orders, etc.).\
\>", "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->{
  "i:15", "LastCellOfAPage"},ExpressionUUID->"e766c2f4-bb10-4674-86ea-\
79092efbc8b4"],

Cell["\<\
Get a hierarchical dataset of planets and moons from the cloud:\
\>", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:16",ExpressionUUID->"ea197806-bbae-4297-bf04-646ef8c24b10"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"planets", "=", 
  RowBox[{
  "CloudGet", "[", "\"\<http://wolfr.am/7FxLgPm5\>\"", "]"}]}]], "Input",
 Deletable->False,
 CellLabel->"In[28]:=",ExpressionUUID->"503c7240-2d18-4663-9c2e-fe56325e3a30"],

Cell[BoxData[
 TagBox[
  TemplateBox[{GridBox[{{
       ItemBox["", Frame -> {False, True, True, False}], 
       StyleBox["\"Mass\"", 
        GrayLevel[0.3]], 
       StyleBox["\"Radius\"", 
        GrayLevel[0.3]], 
       StyleBox["\"Moons\"", 
        GrayLevel[0.3]]}, {
       StyleBox[
        StyleBox["\"Mercury\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 
       TemplateBox[{
        "0.05527344653273921600664787001557157621`5.995678626217358", 
         SubscriptBox[
          StyleBox["\"M\"", Italic, StripOnInput -> False], "\"\[Earth]\""], 
         "Earth masses", "\"EarthMass\""}, "Quantity", SyntaxForm -> Mod], 
       TemplateBox[{"2439.7`5.", "\"km\"", "kilometers", "\"Kilometers\""}, 
        "Quantity", SyntaxForm -> Mod], 
       StyleBox[
        RowBox[{
          StyleBox["\[LeftAssociation]", 
           GrayLevel[0.45]], "\[ThinSpace]", "\[ThinSpace]", 
          StyleBox["\[RightAssociation]", 
           GrayLevel[0.45]]}], LineBreakWithin -> Automatic]}, {
       StyleBox[
        StyleBox["\"Venus\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 
       TemplateBox[{
        "0.81499633987389501748987382971485302911`5.995678626217358", 
         SubscriptBox[
          StyleBox["\"M\"", Italic, StripOnInput -> False], "\"\[Earth]\""], 
         "Earth masses", "\"EarthMass\""}, "Quantity", SyntaxForm -> Mod], 
       TemplateBox[{"6051.85`5.", "\"km\"", "kilometers", "\"Kilometers\""}, 
        "Quantity", SyntaxForm -> Mod], 
       StyleBox[
        RowBox[{
          StyleBox["\[LeftAssociation]", 
           GrayLevel[0.45]], "\[ThinSpace]", "\[ThinSpace]", 
          StyleBox["\[RightAssociation]", 
           GrayLevel[0.45]]}], LineBreakWithin -> Automatic]}, {
       StyleBox[
        StyleBox["\"Earth\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 
       TemplateBox[{
        "0.99999999999999999999999999999993500728`7.698970004336019", 
         SubscriptBox[
          StyleBox["\"M\"", Italic, StripOnInput -> False], "\"\[Earth]\""], 
         "Earth masses", "\"EarthMass\""}, "Quantity", SyntaxForm -> Mod], 
       TemplateBox[{
        "6367.44465709999999999999999991326382620115`8.299868708313456", 
         "\"km\"", "kilometers", "\"Kilometers\""}, "Quantity", SyntaxForm -> 
        Mod], 
       StyleBox[
        RowBox[{
          StyleBox["\[LeftAssociation]", 
           GrayLevel[0.45]], "\[ThinSpace]", 
          StyleBox[
           RowBox[{
             StyleBox[
              StyleBox["\"Moon\"", FontColor -> GrayLevel[0.4]], 
              GrayLevel[0.3]], 
             StyleBox["\[Rule]", 
              GrayLevel[0.5]], 
             StyleBox[
              RowBox[{
                StyleBox["\[LeftAssociation]", 
                 GrayLevel[0.45]], "\[ThinSpace]", 
                RowBox[{
                  StyleBox["\"Mass\"", 
                   GrayLevel[0.3]], 
                  StyleBox["\[Rule]", 
                   GrayLevel[0.5]], 
                  
                  TemplateBox[{
                   "0.01230016133804645640112692149922730729`4.\
995248844409004", 
                    SubscriptBox[
                    StyleBox["\"M\"", Italic, StripOnInput -> False], 
                    "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, 
                   "Quantity", SyntaxForm -> Mod]}], ",", 
                RowBox[{
                  StyleBox["\"Radius\"", 
                   GrayLevel[0.3]], 
                  StyleBox["\[Rule]", 
                   GrayLevel[0.5]], 
                  
                  TemplateBox[{
                   "1737.5`5.", "\"km\"", "kilometers", "\"Kilometers\""}, 
                   "Quantity", SyntaxForm -> Mod]}], "\[ThinSpace]", 
                StyleBox["\[RightAssociation]", 
                 GrayLevel[0.45]]}], LineBreakWithin -> Automatic]}], 
           SpanMinSize -> 1], "\[ThinSpace]", 
          StyleBox["\[RightAssociation]", 
           GrayLevel[0.45]]}], LineBreakWithin -> Automatic]}, {
       StyleBox[
        StyleBox["\"Mars\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 
       TemplateBox[{
        "0.10744669475660102796983342114576670217`5.995678626217358", 
         SubscriptBox[
          StyleBox["\"M\"", Italic, StripOnInput -> False], "\"\[Earth]\""], 
         "Earth masses", "\"EarthMass\""}, "Quantity", SyntaxForm -> Mod], 
       TemplateBox[{
        "3385.595`4.298042852900571", "\"km\"", "kilometers", 
         "\"Kilometers\""}, "Quantity", SyntaxForm -> Mod], 
       StyleBox[
        RowBox[{
          StyleBox["\[LeftAssociation]", 
           GrayLevel[0.45]], "\[ThinSpace]", 
          StyleBox[
           RowBox[{
             StyleBox[
              StyleBox["\"Phobos\"", FontColor -> GrayLevel[0.4]], 
              GrayLevel[0.3]], 
             StyleBox["\[Rule]", 
              GrayLevel[0.5]], 
             StyleBox[
              RowBox[{
                StyleBox["\[LeftAssociation]", 
                 GrayLevel[0.45]], "\[ThinSpace]", 
                RowBox[{
                  StyleBox["\"Mass\"", 
                   GrayLevel[0.3]], 
                  StyleBox["\[Rule]", 
                   GrayLevel[0.5]], 
                  
                  TemplateBox[{
                   "1.79580111160409192458079582453`3.9585678353197324*^-9", 
                    SubscriptBox[
                    StyleBox["\"M\"", Italic, StripOnInput -> False], 
                    "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, 
                   "Quantity", SyntaxForm -> Mod]}], ",", 
                RowBox[{
                  StyleBox["\"Radius\"", 
                   GrayLevel[0.3]], 
                  StyleBox["\[Rule]", 
                   GrayLevel[0.5]], 
                  
                  TemplateBox[{
                   "11.1`3.", "\"km\"", "kilometers", "\"Kilometers\""}, 
                   "Quantity", SyntaxForm -> Mod]}], "\[ThinSpace]", 
                StyleBox["\[RightAssociation]", 
                 GrayLevel[0.45]]}], LineBreakWithin -> Automatic]}], 
           SpanMinSize -> 1], ",", 
          StyleBox[
           RowBox[{
             StyleBox[
              StyleBox["\"Deimos\"", FontColor -> GrayLevel[0.4]], 
              GrayLevel[0.3]], 
             StyleBox["\[Rule]", 
              GrayLevel[0.5]], 
             StyleBox[
              RowBox[{
                StyleBox["\[LeftAssociation]", 
                 GrayLevel[0.45]], "\[ThinSpace]", 
                RowBox[{
                  StyleBox["\"Mass\"", 
                   GrayLevel[0.3]], 
                  StyleBox["\[Rule]", 
                   GrayLevel[0.5]], 
                  
                  TemplateBox[{
                   "2.4586268362280107377607989774`1.999565488660274*^-10", 
                    SubscriptBox[
                    StyleBox["\"M\"", Italic, StripOnInput -> False], 
                    "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, 
                   "Quantity", SyntaxForm -> Mod]}], ",", 
                RowBox[{
                  StyleBox["\"Radius\"", 
                   GrayLevel[0.3]], 
                  StyleBox["\[Rule]", 
                   GrayLevel[0.5]], 
                  
                  TemplateBox[{
                   "6.2`2.", "\"km\"", "kilometers", "\"Kilometers\""}, 
                   "Quantity", SyntaxForm -> Mod]}], "\[ThinSpace]", 
                StyleBox["\[RightAssociation]", 
                 GrayLevel[0.45]]}], LineBreakWithin -> Automatic]}], 
           SpanMinSize -> 1], "\[ThinSpace]", 
          StyleBox["\[RightAssociation]", 
           GrayLevel[0.45]]}], LineBreakWithin -> Automatic]}, {
       StyleBox[
        StyleBox["\"Jupiter\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 
       TemplateBox[{
        "317.82767572397877056533250585469087303499`5.995678626217358", 
         SubscriptBox[
          StyleBox["\"M\"", Italic, StripOnInput -> False], "\"\[Earth]\""], 
         "Earth masses", "\"EarthMass\""}, "Quantity", SyntaxForm -> Mod], 
       TemplateBox[{"69173.`5.", "\"km\"", "kilometers", "\"Kilometers\""}, 
        "Quantity", SyntaxForm -> Mod], 
       StyleBox[
        RowBox[{
          StyleBox["\[LeftAssociation]", 
           GrayLevel[0.45]], "\[ThinSpace]", 
          StyleBox[
           RowBox[{
             StyleBox[
              StyleBox["\"Ganymede\"", FontColor -> GrayLevel[0.4]], 
              GrayLevel[0.3]], 
             StyleBox["\[Rule]", 
              GrayLevel[0.5]], 
             StyleBox[
              RowBox[{
                StyleBox["\[LeftAssociation]", 
                 GrayLevel[0.45]], "\[ThinSpace]", 
                RowBox[{
                  StyleBox["\"Mass\"", 
                   GrayLevel[0.3]], 
                  StyleBox["\[Rule]", 
                   GrayLevel[0.5]], 
                  
                  TemplateBox[{
                   "0.02480662655568138400530235916802739469`4.\
995248844409004", 
                    SubscriptBox[
                    StyleBox["\"M\"", Italic, StripOnInput -> False], 
                    "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, 
                   "Quantity", SyntaxForm -> Mod]}], ",", 
                RowBox[{
                  StyleBox["\"Radius\"", 
                   GrayLevel[0.3]], 
                  StyleBox["\[Rule]", 
                   GrayLevel[0.5]], 
                  
                  TemplateBox[{
                   "2631.2`5.", "\"km\"", "kilometers", "\"Kilometers\""}, 
                   "Quantity", SyntaxForm -> Mod]}], "\[ThinSpace]", 
                StyleBox["\[RightAssociation]", 
                 GrayLevel[0.45]]}], LineBreakWithin -> Automatic]}], 
           SpanMinSize -> 1], ",", 
          StyleBox[
           RowBox[{
             StyleBox[
              StyleBox["\"Callisto\"", FontColor -> GrayLevel[0.4]], 
              GrayLevel[0.3]], 
             StyleBox["\[Rule]", 
              GrayLevel[0.5]], 
             StyleBox[
              RowBox[{
                StyleBox["\[LeftAssociation]", 
                 GrayLevel[0.45]], "\[ThinSpace]", 
                RowBox[{
                  StyleBox["\"Mass\"", 
                   GrayLevel[0.3]], 
                  StyleBox["\[Rule]", 
                   GrayLevel[0.5]], 
                  
                  TemplateBox[{
                   "0.01801142102085363161376325378730590253`4.\
995248844409004", 
                    SubscriptBox[
                    StyleBox["\"M\"", Italic, StripOnInput -> False], 
                    "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, 
                   "Quantity", SyntaxForm -> Mod]}], ",", 
                RowBox[{
                  StyleBox["\"Radius\"", 
                   GrayLevel[0.3]], 
                  StyleBox["\[Rule]", 
                   GrayLevel[0.5]], 
                  
                  TemplateBox[{
                   "2410.3`5.", "\"km\"", "kilometers", "\"Kilometers\""}, 
                   "Quantity", SyntaxForm -> Mod]}], "\[ThinSpace]", 
                StyleBox["\[RightAssociation]", 
                 GrayLevel[0.45]]}], LineBreakWithin -> Automatic]}], 
           SpanMinSize -> 1], ",", 
          StyleBox[
           SubscriptBox["\[CenterEllipsis]", "36"], 
           GrayLevel[0.5]], "\[ThinSpace]", 
          StyleBox["\[RightAssociation]", 
           GrayLevel[0.45]]}], LineBreakWithin -> Automatic]}, {
       StyleBox[
        StyleBox["\"Saturn\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 
       TemplateBox[{
        "95.160767091703882720845887476006418039`5.995678626217358", 
         SubscriptBox[
          StyleBox["\"M\"", Italic, StripOnInput -> False], "\"\[Earth]\""], 
         "Earth masses", "\"EarthMass\""}, "Quantity", SyntaxForm -> Mod], 
       TemplateBox[{"57316.`5.", "\"km\"", "kilometers", "\"Kilometers\""}, 
        "Quantity", SyntaxForm -> Mod], 
       StyleBox[
        RowBox[{
          StyleBox["\[LeftAssociation]", 
           GrayLevel[0.45]], "\[ThinSpace]", 
          StyleBox[
           RowBox[{
             StyleBox[
              StyleBox["\"Titan\"", FontColor -> GrayLevel[0.4]], 
              GrayLevel[0.3]], 
             StyleBox["\[Rule]", 
              GrayLevel[0.5]], 
             StyleBox[
              RowBox[{
                StyleBox["\[LeftAssociation]", 
                 GrayLevel[0.45]], "\[ThinSpace]", 
                RowBox[{
                  StyleBox["\"Mass\"", 
                   GrayLevel[0.3]], 
                  StyleBox["\[Rule]", 
                   GrayLevel[0.5]], 
                  
                  TemplateBox[{
                   "0.02252450905587139155679247739684866761`4.\
958212681028252", 
                    SubscriptBox[
                    StyleBox["\"M\"", Italic, StripOnInput -> False], 
                    "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, 
                   "Quantity", SyntaxForm -> Mod]}], ",", 
                RowBox[{
                  StyleBox["\"Radius\"", 
                   GrayLevel[0.3]], 
                  StyleBox["\[Rule]", 
                   GrayLevel[0.5]], 
                  
                  TemplateBox[{
                   "2575.5`5.", "\"km\"", "kilometers", "\"Kilometers\""}, 
                   "Quantity", SyntaxForm -> Mod]}], "\[ThinSpace]", 
                StyleBox["\[RightAssociation]", 
                 GrayLevel[0.45]]}], LineBreakWithin -> Automatic]}], 
           SpanMinSize -> 1], ",", 
          StyleBox[
           RowBox[{
             StyleBox[
              StyleBox["\"Rhea\"", FontColor -> GrayLevel[0.4]], 
              GrayLevel[0.3]], 
             StyleBox["\[Rule]", 
              GrayLevel[0.5]], 
             StyleBox[
              RowBox[{
                StyleBox["\[LeftAssociation]", 
                 GrayLevel[0.45]], "\[ThinSpace]", 
                RowBox[{
                  StyleBox["\"Mass\"", 
                   GrayLevel[0.3]], 
                  StyleBox["\[Rule]", 
                   GrayLevel[0.5]], 
                  
                  TemplateBox[{
                   "0.00038653126189556083098653701837709315`4.\
6987529113637905", 
                    SubscriptBox[
                    StyleBox["\"M\"", Italic, StripOnInput -> False], 
                    "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, 
                   "Quantity", SyntaxForm -> Mod]}], ",", 
                RowBox[{
                  StyleBox["\"Radius\"", 
                   GrayLevel[0.3]], 
                  StyleBox["\[Rule]", 
                   GrayLevel[0.5]], 
                  
                  TemplateBox[{
                   "764.5`4.", "\"km\"", "kilometers", "\"Kilometers\""}, 
                   "Quantity", SyntaxForm -> Mod]}], "\[ThinSpace]", 
                StyleBox["\[RightAssociation]", 
                 GrayLevel[0.45]]}], LineBreakWithin -> Automatic]}], 
           SpanMinSize -> 1], ",", 
          StyleBox[
           SubscriptBox["\[CenterEllipsis]", "31"], 
           GrayLevel[0.5]], "\[ThinSpace]", 
          StyleBox["\[RightAssociation]", 
           GrayLevel[0.45]]}], LineBreakWithin -> Automatic]}, {
       StyleBox[
        StyleBox["\"Uranus\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 
       TemplateBox[{
        "14.53573563343991942933712887578694351569`5.995678626217358", 
         SubscriptBox[
          StyleBox["\"M\"", Italic, StripOnInput -> False], "\"\[Earth]\""], 
         "Earth masses", "\"EarthMass\""}, "Quantity", SyntaxForm -> Mod], 
       TemplateBox[{"25266.`5.", "\"km\"", "kilometers", "\"Kilometers\""}, 
        "Quantity", SyntaxForm -> Mod], 
       StyleBox[
        RowBox[{
          StyleBox["\[LeftAssociation]", 
           GrayLevel[0.45]], "\[ThinSpace]", 
          StyleBox[
           RowBox[{
             StyleBox[
              StyleBox["\"Titania\"", FontColor -> GrayLevel[0.4]], 
              GrayLevel[0.3]], 
             StyleBox["\[Rule]", 
              GrayLevel[0.5]], 
             StyleBox[
              RowBox[{
                StyleBox["\[LeftAssociation]", 
                 GrayLevel[0.45]], "\[ThinSpace]", 
                RowBox[{
                  StyleBox["\"Mass\"", 
                   GrayLevel[0.3]], 
                  StyleBox["\[Rule]", 
                   GrayLevel[0.5]], 
                  
                  TemplateBox[{
                   "0.00059032132098413359856644486002186379`3.\
9585678353197364", 
                    SubscriptBox[
                    StyleBox["\"M\"", Italic, StripOnInput -> False], 
                    "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, 
                   "Quantity", SyntaxForm -> Mod]}], ",", 
                RowBox[{
                  StyleBox["\"Radius\"", 
                   GrayLevel[0.3]], 
                  StyleBox["\[Rule]", 
                   GrayLevel[0.5]], 
                  
                  TemplateBox[{
                   "788.9`4.", "\"km\"", "kilometers", "\"Kilometers\""}, 
                   "Quantity", SyntaxForm -> Mod]}], "\[ThinSpace]", 
                StyleBox["\[RightAssociation]", 
                 GrayLevel[0.45]]}], LineBreakWithin -> Automatic]}], 
           SpanMinSize -> 1], ",", 
          StyleBox[
           RowBox[{
             StyleBox[
              StyleBox["\"Oberon\"", FontColor -> GrayLevel[0.4]], 
              GrayLevel[0.3]], 
             StyleBox["\[Rule]", 
              GrayLevel[0.5]], 
             StyleBox[
              RowBox[{
                StyleBox["\[LeftAssociation]", 
                 GrayLevel[0.45]], "\[ThinSpace]", 
                RowBox[{
                  StyleBox["\"Mass\"", 
                   GrayLevel[0.3]], 
                  StyleBox["\[Rule]", 
                   GrayLevel[0.5]], 
                  
                  TemplateBox[{
                   "0.00050452026200556424424866999566956869`3.\
9585678353197364", 
                    SubscriptBox[
                    StyleBox["\"M\"", Italic, StripOnInput -> False], 
                    "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, 
                   "Quantity", SyntaxForm -> Mod]}], ",", 
                RowBox[{
                  StyleBox["\"Radius\"", 
                   GrayLevel[0.3]], 
                  StyleBox["\[Rule]", 
                   GrayLevel[0.5]], 
                  TemplateBox[{
                   "761.4`4.", "\"km\"", "kilometers", "\"Kilometers\""}, 
                   "Quantity", SyntaxForm -> Mod]}], "\[ThinSpace]", 
                StyleBox["\[RightAssociation]", 
                 GrayLevel[0.45]]}], LineBreakWithin -> Automatic]}], 
           SpanMinSize -> 1], ",", 
          StyleBox[
           SubscriptBox["\[CenterEllipsis]", "19"], 
           GrayLevel[0.5]], "\[ThinSpace]", 
          StyleBox["\[RightAssociation]", 
           GrayLevel[0.45]]}], LineBreakWithin -> Automatic]}, {
       StyleBox[
        StyleBox["\"Neptune\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 
       TemplateBox[{
        "17.14778875571887378293146513915216149975`5.995678626217358", 
         SubscriptBox[
          StyleBox["\"M\"", Italic, StripOnInput -> False], "\"\[Earth]\""], 
         "Earth masses", "\"EarthMass\""}, "Quantity", SyntaxForm -> Mod], 
       TemplateBox[{"24552.5`5.", "\"km\"", "kilometers", "\"Kilometers\""}, 
        "Quantity", SyntaxForm -> Mod], 
       StyleBox[
        RowBox[{
          StyleBox["\[LeftAssociation]", 
           GrayLevel[0.45]], "\[ThinSpace]", 
          StyleBox[
           RowBox[{
             StyleBox[
              StyleBox["\"Triton\"", FontColor -> GrayLevel[0.4]], 
              GrayLevel[0.3]], 
             StyleBox["\[Rule]", 
              GrayLevel[0.5]], 
             StyleBox[
              RowBox[{
                StyleBox["\[LeftAssociation]", 
                 GrayLevel[0.45]], "\[ThinSpace]", 
                RowBox[{
                  StyleBox["\"Mass\"", 
                   GrayLevel[0.3]], 
                  StyleBox["\[Rule]", 
                   GrayLevel[0.5]], 
                  
                  TemplateBox[{
                   "0.00358231965249997605351902530501892712`4.\
6987529113637905", 
                    SubscriptBox[
                    StyleBox["\"M\"", Italic, StripOnInput -> False], 
                    "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, 
                   "Quantity", SyntaxForm -> Mod]}], ",", 
                RowBox[{
                  StyleBox["\"Radius\"", 
                   GrayLevel[0.3]], 
                  StyleBox["\[Rule]", 
                   GrayLevel[0.5]], 
                  
                  TemplateBox[{
                   "1353.4`5.", "\"km\"", "kilometers", "\"Kilometers\""}, 
                   "Quantity", SyntaxForm -> Mod]}], "\[ThinSpace]", 
                StyleBox["\[RightAssociation]", 
                 GrayLevel[0.45]]}], LineBreakWithin -> Automatic]}], 
           SpanMinSize -> 1], ",", 
          StyleBox[
           RowBox[{
             StyleBox[
              StyleBox["\"Proteus\"", FontColor -> GrayLevel[0.4]], 
              GrayLevel[0.3]], 
             StyleBox["\[Rule]", 
              GrayLevel[0.5]], 
             StyleBox[
              RowBox[{
                StyleBox["\[LeftAssociation]", 
                 GrayLevel[0.45]], "\[ThinSpace]", 
                RowBox[{
                  StyleBox["\"Mass\"", 
                   GrayLevel[0.3]], 
                  StyleBox["\[Rule]", 
                   GrayLevel[0.5]], 
                  
                  TemplateBox[{
                   "8.429577724210322529465614221201`2.9956743262932886*^-6", 
                    
                    SubscriptBox[
                    StyleBox["\"M\"", Italic, StripOnInput -> False], 
                    "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, 
                   "Quantity", SyntaxForm -> Mod]}], ",", 
                RowBox[{
                  StyleBox["\"Radius\"", 
                   GrayLevel[0.3]], 
                  StyleBox["\[Rule]", 
                   GrayLevel[0.5]], 
                  
                  TemplateBox[{
                   "210.`3.", "\"km\"", "kilometers", "\"Kilometers\""}, 
                   "Quantity", SyntaxForm -> Mod]}], "\[ThinSpace]", 
                StyleBox["\[RightAssociation]", 
                 GrayLevel[0.45]]}], LineBreakWithin -> Automatic]}], 
           SpanMinSize -> 1], ",", 
          StyleBox[
           SubscriptBox["\[CenterEllipsis]", "6"], 
           GrayLevel[0.5]], "\[ThinSpace]", 
          StyleBox["\[RightAssociation]", 
           GrayLevel[0.45]]}], LineBreakWithin -> Automatic]}, {
       ItemBox[
        RowBox[{"4 levels", 
          AdjustmentBox[" | ", BoxBaselineShift -> -0.3], 
          RowBox[{"8", "rows"}]}], 
        BaseStyle -> {
         FontFamily -> "Helvetica", FontSize -> 10, FontColor -> 
          GrayLevel[0.4], Editable -> False, Selectable -> False}, 
        ItemSize -> {Automatic, Automatic}, Alignment -> {Left, Center}, 
        Background -> RGBColor[0.92, 0.92, 0.9]], "\[SpanFromLeft]", 
       "\[SpanFromLeft]", "\[SpanFromLeft]"}}, 
     GridBoxFrame -> {"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}}, 
     FrameStyle -> RGBColor[0, 0, 0, 0.4], GridBoxDividers -> {"Columns" -> {
         RGBColor[0, 0, 0, 0.4], 
         RGBColor[0, 0, 0, 0.3], {
          RGBColor[0, 0, 0, 0.09]}, 
         RGBColor[0, 0, 0, 0.4]}, "Rows" -> {
         RGBColor[0, 0, 0, 0.4], 
         RGBColor[0, 0, 0, 0.3], {
          RGBColor[0, 0, 0, 0.08]}, 
         RGBColor[0, 0, 0, 0.4]}}, RowSpacings -> {1.5, 1.2}, 
     GridBoxBackground -> {"Columns" -> {
         RGBColor[0.92, 0.92, 0.9]}, "Rows" -> {
         RGBColor[0.92, 0.92, 0.9]}}, 
     GridBoxAlignment -> {"Columns" -> {{Left}}}, ColumnSpacings -> 2.5, 
     GridFrameMargins -> {{2, 3}, {1, 3}}, 
     GridBoxItemSize -> {"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
      RowMinHeight -> 1.3],
    "Dataset[Association[(_String -> _Association)..]]"},
   "Dataset",
   DisplayFunction->(TagBox[
     StyleBox[#, {
      ShowAutoStyles -> False, LineBreakWithin -> False, FontWeight -> 
       "Light", FontFamily -> "Helvetica Neue", NumberMarks -> False, 
       SpanMaxSize -> 3, SpanMinSize -> 1., Editable -> False, Selectable -> 
       True, Background -> RGBColor[0.985, 0.98, 0.973], 
       LinebreakAdjustments -> {0.4, 5, 100, 0, 0.5}, LineIndent -> 0, 
       LineSpacing -> {1.1, 5}}], Deploy]& ),
   InterpretationFunction->(#2& )],
  False,
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 Editable->False,
 PageWidth->1200,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[28]=",ExpressionUUID->"f16fbb9a-bace-4a6d-95db-ceb220b228b5"]
}, Open  ]],

Cell["Find the radii of all the planets:", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"p:276",ExpressionUUID->"514fe8d7-dcf9-40ab-9724-a4eefe282359"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"planets", "[", 
  RowBox[{"All", ",", "\"\<Radius\>\""}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[29]:=",ExpressionUUID->"54ad1f83-90bd-47ca-8eb9-cf81f4e1ae02"],

Cell[BoxData[
 TagBox[
  TemplateBox[{GridBox[{{
       StyleBox[
        StyleBox["\"Mercury\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 
       TemplateBox[{"2439.7`5.", "\"km\"", "kilometers", "\"Kilometers\""}, 
        "Quantity", SyntaxForm -> Mod]}, {
       StyleBox[
        StyleBox["\"Venus\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 
       TemplateBox[{"6051.85`5.", "\"km\"", "kilometers", "\"Kilometers\""}, 
        "Quantity", SyntaxForm -> Mod]}, {
       StyleBox[
        StyleBox["\"Earth\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 
       TemplateBox[{
        "6367.44465709999999999999999991326382620115`8.299868708313456", 
         "\"km\"", "kilometers", "\"Kilometers\""}, "Quantity", SyntaxForm -> 
        Mod]}, {
       StyleBox[
        StyleBox["\"Mars\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 
       TemplateBox[{
        "3385.595`4.298042852900571", "\"km\"", "kilometers", 
         "\"Kilometers\""}, "Quantity", SyntaxForm -> Mod]}, {
       StyleBox[
        StyleBox["\"Jupiter\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 
       TemplateBox[{"69173.`5.", "\"km\"", "kilometers", "\"Kilometers\""}, 
        "Quantity", SyntaxForm -> Mod]}, {
       StyleBox[
        StyleBox["\"Saturn\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 
       TemplateBox[{"57316.`5.", "\"km\"", "kilometers", "\"Kilometers\""}, 
        "Quantity", SyntaxForm -> Mod]}, {
       StyleBox[
        StyleBox["\"Uranus\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 
       TemplateBox[{"25266.`5.", "\"km\"", "kilometers", "\"Kilometers\""}, 
        "Quantity", SyntaxForm -> Mod]}, {
       StyleBox[
        StyleBox["\"Neptune\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 
       TemplateBox[{"24552.5`5.", "\"km\"", "kilometers", "\"Kilometers\""}, 
        "Quantity", SyntaxForm -> Mod]}, {
       ItemBox[
        RowBox[{"1 level", 
          AdjustmentBox[" | ", BoxBaselineShift -> -0.3], 
          RowBox[{"8", "elements"}]}], 
        BaseStyle -> {
         FontFamily -> "Helvetica", FontSize -> 10, FontColor -> 
          GrayLevel[0.4], Editable -> False, Selectable -> False}, 
        ItemSize -> {Automatic, Automatic}, Alignment -> {Left, Center}, 
        Background -> RGBColor[0.92, 0.92, 0.9]], "\[SpanFromLeft]"}}, 
     GridBoxFrame -> {"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}}, 
     FrameStyle -> RGBColor[0, 0, 0, 0.4], GridBoxDividers -> {"Columns" -> {
         RGBColor[0, 0, 0, 0.4], 
         RGBColor[0, 0, 0, 0.3], {
          RGBColor[0, 0, 0, 0.09]}, 
         RGBColor[0, 0, 0, 0.4]}, "Rows" -> {
         RGBColor[0, 0, 0, 0.4], {
          RGBColor[0, 0, 0, 0.08]}, 
         RGBColor[0, 0, 0, 0.4]}}, RowSpacings -> 1.2, 
     GridBoxBackground -> {"Columns" -> {
         RGBColor[0.92, 0.92, 0.9]}}, 
     GridBoxAlignment -> {"Columns" -> {{Left}}}, ColumnSpacings -> 2.5, 
     GridFrameMargins -> {{2, 3}, {1, 3}}, 
     GridBoxItemSize -> {"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
      RowMinHeight -> 1.3],
    "Dataset[Association[(_String -> Quantity[_, \"Kilometers\"])..]]"},
   "Dataset",
   DisplayFunction->(TagBox[
     StyleBox[#, {
      ShowAutoStyles -> False, LineBreakWithin -> False, FontWeight -> 
       "Light", FontFamily -> "Helvetica Neue", NumberMarks -> False, 
       SpanMaxSize -> 3, SpanMinSize -> 1., Editable -> False, Selectable -> 
       True, Background -> RGBColor[0.985, 0.98, 0.973], 
       LinebreakAdjustments -> {0.4, 5, 100, 0, 0.5}, LineIndent -> 0, 
       LineSpacing -> {1.1, 5}}], Deploy]& ),
   InterpretationFunction->(#2& )],
  False,
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[29]=",ExpressionUUID->"cbdd1fa5-d129-4df1-a12a-6c382b4f6652"]
}, Open  ]],

Cell["Make a bar chart of planet radii:", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:17",ExpressionUUID->"79c5c140-961a-4c40-a886-45ac913443e7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BarChart", "[", 
  RowBox[{
   RowBox[{"planets", "[", 
    RowBox[{"All", ",", "\"\<Radius\>\""}], "]"}], ",", 
   RowBox[{"ChartLabels", "\[Rule]", "Automatic"}]}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[30]:=",ExpressionUUID->"40dd9746-da3b-4976-b373-c21831f2f3de"],

Cell[BoxData[
 GraphicsBox[{{{{
      {Opacity[0], PointBox[{0.38380952380952377`, 0.}]}}}}, {{}, {{{
       {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[0.644], 
        Thickness[Small]}], {{{
           {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
            0.644], Thickness[Small]}], 
            TagBox[
             TooltipBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 
                 RectangleBox[{0.5421245421245421, 0.}, {1.4578754578754578`, 
                  2439.7}, "RoundingRadius" -> 0]},
                
                ImageSizeCache->{{37.376883106183655`, 70.42479556675544}, {
                 74.74281885410298, 81.42386706805941}}],
               StatusArea[#, 2439.7`5.]& ,
               TagBoxNote->"2439.7`5."],
              StyleBox["2439.7`5.", {}, StripOnInput -> False]],
             Annotation[#, 
              Style[2439.7`5., {}], "Tooltip"]& ]}}}}, {{{
           {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
            0.644], Thickness[Small]}], 
            TagBox[
             TooltipBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 
                 RectangleBox[{1.542124542124542, 0.}, {2.4578754578754576`, 
                  6051.85}, "RoundingRadius" -> 0]},
                
                ImageSizeCache->{{72.91920351312804, 105.96711597369983`}, {
                 65.59133575944267, 81.42386706805941}}],
               StatusArea[#, 6051.85`5.]& ,
               TagBoxNote->"6051.85`5."],
              StyleBox["6051.85`5.", {}, StripOnInput -> False]],
             Annotation[#, 
              Style[6051.85`5., {}], "Tooltip"]& ]}}}}, {{{
           {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
            0.644], Thickness[Small]}], 
            TagBox[
             TooltipBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 
                 RectangleBox[{2.542124542124542, 0.}, {3.4578754578754576`, 
                  6367.4446571}, "RoundingRadius" -> 0]},
                
                ImageSizeCache->{{108.46152392007244`, 141.50943638064422`}, {
                 64.7917678651925, 81.42386706805941}}],
               StatusArea[#, 6367.4446571000000000001`8.299868708313456]& ,
               
               TagBoxNote->
                "6367.44465709999999999999999991326382620115`8.\
299868708313456"],
              StyleBox[
              "6367.44465709999999999999999991326382620115`8.299868708313456",\
 {}, StripOnInput -> False]],
             Annotation[#, 
              Style[6367.4446571000000000001`8.299868708313456, {}], 
              "Tooltip"]& ]}}}}, {{{
           {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
            0.644], Thickness[Small]}], 
            TagBox[
             TooltipBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 
                 RectangleBox[{3.542124542124542, 0.}, {4.457875457875458, 
                  3385.595}, "RoundingRadius" -> 0]},
                
                ImageSizeCache->{{144.00384432701682`, 177.05175678758863`}, {
                 72.34636740501483, 81.42386706805941}}],
               StatusArea[#, 3385.595`4.298042852900571]& ,
               TagBoxNote->"3385.595`4.298042852900571"],
              StyleBox[
              "3385.595`4.298042852900571", {}, StripOnInput -> False]],
             Annotation[#, 
              Style[3385.595`4.298042852900571, {}], "Tooltip"]& ]}}}}, {{{
           {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
            0.644], Thickness[Small]}], 
            TagBox[
             TooltipBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 
                 RectangleBox[{4.542124542124542, 0.}, {5.457875457875458, 
                  69173.}, "RoundingRadius" -> 0]},
                
                ImageSizeCache->{{179.5461647339612, 
                 212.594077194533}, {-94.32786392509898, 81.42386706805941}}],
               
               StatusArea[#, 69173.`5.]& ,
               TagBoxNote->"69173.`5."],
              StyleBox["69173.`5.", {}, StripOnInput -> False]],
             Annotation[#, 
              Style[69173.`5., {}], "Tooltip"]& ]}}}}, {{{
           {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
            0.644], Thickness[Small]}], 
            TagBox[
             TooltipBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 
                 RectangleBox[{5.542124542124542, 0.}, {6.457875457875458, 
                  57316.}, "RoundingRadius" -> 0]},
                
                ImageSizeCache->{{215.08848514090562`, 
                 248.1363976014774}, {-64.28782266064785, 81.42386706805941}}],
               StatusArea[#, 57316.`5.]& ,
               TagBoxNote->"57316.`5."],
              StyleBox["57316.`5.", {}, StripOnInput -> False]],
             Annotation[#, 
              Style[57316.`5., {}], "Tooltip"]& ]}}}}, {{{
           {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
            0.644], Thickness[Small]}], 
            TagBox[
             TooltipBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 
                 RectangleBox[{6.542124542124542, 0.}, {7.457875457875458, 
                  25266.}, "RoundingRadius" -> 0]},
                
                ImageSizeCache->{{250.63080554785, 283.67871800842175`}, {
                 16.911749113465277`, 81.42386706805941}}],
               StatusArea[#, 25266.`5.]& ,
               TagBoxNote->"25266.`5."],
              StyleBox["25266.`5.", {}, StripOnInput -> False]],
             Annotation[#, 
              Style[25266.`5., {}], "Tooltip"]& ]}}}}, {{{
           {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
            0.644], Thickness[Small]}], 
            TagBox[
             TooltipBox[
              TagBox[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 
                 RectangleBox[{7.542124542124542, 0.}, {8.457875457875458, 
                  24552.5}, "RoundingRadius" -> 0]},
                
                ImageSizeCache->{{286.1731259547944, 319.22103841536614`}, {
                 18.719421327531727`, 81.42386706805941}}],
               StatusArea[#, 24552.5`5.]& ,
               TagBoxNote->"24552.5`5."],
              StyleBox["24552.5`5.", {}, StripOnInput -> False]],
             Annotation[#, 
              Style[24552.5`5., {}], "Tooltip"]& ]}}}}}}}}, {}, {}}, {}, {}, 
   StyleBox[{{{{
        {Thickness[Tiny], 
         LineBox[{{0.38380952380952377`, 0.}, {8.619356776556776, 0.}}], 
         StyleBox[{}, "GraphicsLabel",
          StripOnInput->False]}}}}, 
     StyleBox[{{{{
          {Thickness[Tiny], 
           LineBox[{{0.5421245421245421, 0.}, 
             Offset[{-1.102182119232618*^-15, -6.}, {0.5421245421245421, 
              0.}]}], LineBox[{{8.457875457875458, 0.}, 
             Offset[{-1.102182119232618*^-15, -6.}, {8.457875457875458, 
              0.}]}], {{}, {}, {}, {}, {}, {}, {}, {}, {
             LineBox[{{1.4578754578754578`, 0.}, 
               Offset[{-7.347880794884119*^-16, -4.}, {1.4578754578754578`, 
                0.}]}], 
             LineBox[{{1.542124542124542, 0.}, 
               Offset[{-7.347880794884119*^-16, -4.}, {1.542124542124542, 
                0.}]}], 
             LineBox[{{2.4578754578754576`, 0.}, 
               Offset[{-7.347880794884119*^-16, -4.}, {2.4578754578754576`, 
                0.}]}], 
             LineBox[{{2.542124542124542, 0.}, 
               Offset[{-7.347880794884119*^-16, -4.}, {2.542124542124542, 
                0.}]}], 
             LineBox[{{3.457875457875457, 0.}, 
               Offset[{-7.347880794884119*^-16, -4.}, {3.457875457875457, 
                0.}]}], 
             LineBox[{{3.5421245421245415`, 0.}, 
               Offset[{-7.347880794884119*^-16, -4.}, {3.5421245421245415`, 
                0.}]}], 
             LineBox[{{4.457875457875458, 0.}, 
               Offset[{-7.347880794884119*^-16, -4.}, {4.457875457875458, 
                0.}]}], 
             LineBox[{{4.542124542124542, 0.}, 
               Offset[{-7.347880794884119*^-16, -4.}, {4.542124542124542, 
                0.}]}], 
             LineBox[{{5.457875457875458, 0.}, 
               Offset[{-7.347880794884119*^-16, -4.}, {5.457875457875458, 
                0.}]}], 
             LineBox[{{5.542124542124542, 0.}, 
               Offset[{-7.347880794884119*^-16, -4.}, {5.542124542124542, 
                0.}]}], 
             LineBox[{{6.457875457875458, 0.}, 
               Offset[{-7.347880794884119*^-16, -4.}, {6.457875457875458, 
                0.}]}], 
             LineBox[{{6.542124542124542, 0.}, 
               Offset[{-7.347880794884119*^-16, -4.}, {6.542124542124542, 
                0.}]}], 
             LineBox[{{7.457875457875458, 0.}, 
               Offset[{-7.347880794884119*^-16, -4.}, {7.457875457875458, 
                0.}]}], 
             LineBox[{{7.542124542124542, 0.}, 
               Offset[{-7.347880794884119*^-16, -4.}, {7.542124542124542, 
                0.}]}]}, {}}}}}}, 
       StyleBox[{{{
           {Thickness[Tiny], 
            InsetBox["\<\"Mercury\"\>", Offset[{0., -2.}, {1., 0.}], {0, 1}, 
             Automatic, {1, 0}], 
            InsetBox["\<\"Venus\"\>", Offset[{0., -2.}, {2., 0.}], {0, 1}, 
             Automatic, {1, 0}], 
            InsetBox["\<\"Earth\"\>", 
             Offset[{0., -2.}, {2.9999999999999996, 0.}], {0, 1}, Automatic, {
             1, 0}], InsetBox["\<\"Mars\"\>", 
             Offset[{0., -2.}, {3.9999999999999996, 0.}], {0, 1}, Automatic, {
             1, 0}], InsetBox["\<\"Jupiter\"\>", 
             Offset[{0., -2.}, {5., 0.}], {0, 1}, Automatic, {1, 0}], 
            InsetBox["\<\"Saturn\"\>", Offset[{0., -2.}, {6., 0.}], {0, 1}, 
             Automatic, {1, 0}], 
            InsetBox["\<\"Uranus\"\>", Offset[{0., -2.}, {7., 0.}], {0, 1}, 
             Automatic, {1, 0}], 
            InsetBox["\<\"Neptune\"\>", Offset[{0., -2.}, {8., 0.}], {0, 1}, 
             Automatic, {1, 0}]}}}}, "GraphicsLabel",
        StripOnInput->False]}, "GraphicsTicks",
      StripOnInput->False]}, "GraphicsAxes",
    StripOnInput->False,
    Antialiasing->False]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, True},
  AxesLabel->{None, None},
  AxesOrigin->{0.38380952380952377`, 0.},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Identity[
       Part[#, 1]], 
      Identity[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Identity[
       Part[#, 1]], 
      Identity[
       Part[#, 2]]}& )},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {{{1., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {1., 
       FormBox["\"Mercury\"", TraditionalForm], 0}, {1.9999999999999998`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {1.9999999999999998`, 
       FormBox["\"Venus\"", TraditionalForm], 0}, {3., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {3., 
       FormBox["\"Earth\"", TraditionalForm], 0}, {4., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {4., 
       FormBox["\"Mars\"", TraditionalForm], 0}, {5., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {5., 
       FormBox["\"Jupiter\"", TraditionalForm], 0}, {6., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {6., 
       FormBox["\"Saturn\"", TraditionalForm], 0}, {7., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {7., 
       FormBox["\"Uranus\"", TraditionalForm], 0}, {8., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {8., 
       FormBox["\"Neptune\"", TraditionalForm], 0}}, {{1., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {1.9999999999999998`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {3., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {4., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {5., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {6., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {7., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {8., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}}}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->{331.80859375, Automatic},
  PlotRange->{{All, All}, {All, All}},
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{None, Automatic}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellTags->"LastCellOfAPage",
 CellLabel->"Out[30]=",ExpressionUUID->"820322f8-c9ef-473b-9503-bb8da54e8a48"]
}, Open  ]],

Cell["\<\
If we ask about the moons of Mars, we get a dataset, which we can then query \
further.\
\>", "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"ce38b2e0-5f0b-46c6-b05a-e97bd879b605"],

Cell["Get a dataset about the moons of Mars:", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"ac6257a2-2510-455f-b971-b9eaa8896a52"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"planets", "[", 
  RowBox[{"\"\<Mars\>\"", ",", "\"\<Moons\>\""}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[31]:=",ExpressionUUID->"3c440acd-fd4c-4795-8876-21c68997dfa8"],

Cell[BoxData[
 TagBox[
  TemplateBox[{GridBox[{{
       ItemBox["", Frame -> {False, True, True, False}], 
       StyleBox["\"Mass\"", 
        GrayLevel[0.3]], 
       StyleBox["\"Radius\"", 
        GrayLevel[0.3]]}, {
       StyleBox[
        StyleBox["\"Phobos\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 
       TemplateBox[{
        "1.79580111160409192458079582453`3.9585678353197324*^-9", 
         SubscriptBox[
          StyleBox["\"M\"", Italic, StripOnInput -> False], "\"\[Earth]\""], 
         "Earth masses", "\"EarthMass\""}, "Quantity", SyntaxForm -> Mod], 
       TemplateBox[{"11.1`3.", "\"km\"", "kilometers", "\"Kilometers\""}, 
        "Quantity", SyntaxForm -> Mod]}, {
       StyleBox[
        StyleBox["\"Deimos\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 
       TemplateBox[{"2.4586268362280107377607989774`1.999565488660274*^-10", 
         SubscriptBox[
          StyleBox["\"M\"", Italic, StripOnInput -> False], "\"\[Earth]\""], 
         "Earth masses", "\"EarthMass\""}, "Quantity", SyntaxForm -> Mod], 
       TemplateBox[{"6.2`2.", "\"km\"", "kilometers", "\"Kilometers\""}, 
        "Quantity", SyntaxForm -> Mod]}, {
       ItemBox[
        RowBox[{"2 levels", 
          AdjustmentBox[" | ", BoxBaselineShift -> -0.3], 
          RowBox[{"2", "rows"}]}], 
        BaseStyle -> {
         FontFamily -> "Helvetica", FontSize -> 10, FontColor -> 
          GrayLevel[0.4], Editable -> False, Selectable -> False}, 
        ItemSize -> {Automatic, Automatic}, Alignment -> {Left, Center}, 
        Background -> RGBColor[0.92, 0.92, 0.9]], "\[SpanFromLeft]", 
       "\[SpanFromLeft]"}}, 
     GridBoxFrame -> {"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}}, 
     FrameStyle -> RGBColor[0, 0, 0, 0.4], GridBoxDividers -> {"Columns" -> {
         RGBColor[0, 0, 0, 0.4], 
         RGBColor[0, 0, 0, 0.3], {
          RGBColor[0, 0, 0, 0.09]}, 
         RGBColor[0, 0, 0, 0.4]}, "Rows" -> {
         RGBColor[0, 0, 0, 0.4], 
         RGBColor[0, 0, 0, 0.3], {
          RGBColor[0, 0, 0, 0.08]}, 
         RGBColor[0, 0, 0, 0.4]}}, RowSpacings -> {1.5, 1.2}, 
     GridBoxBackground -> {"Columns" -> {
         RGBColor[0.92, 0.92, 0.9]}, "Rows" -> {
         RGBColor[0.92, 0.92, 0.9]}}, 
     GridBoxAlignment -> {"Columns" -> {{Left}}}, ColumnSpacings -> 2.5, 
     GridFrameMargins -> {{2, 3}, {1, 3}}, 
     GridBoxItemSize -> {"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
      RowMinHeight -> 1.3],
    "Dataset[Association[(_String -> _Association)..]]"},
   "Dataset",
   DisplayFunction->(TagBox[
     StyleBox[#, {
      ShowAutoStyles -> False, LineBreakWithin -> False, FontWeight -> 
       "Light", FontFamily -> "Helvetica Neue", NumberMarks -> False, 
       SpanMaxSize -> 3, SpanMinSize -> 1., Editable -> False, Selectable -> 
       True, Background -> RGBColor[0.985, 0.98, 0.973], 
       LinebreakAdjustments -> {0.4, 5, 100, 0, 0.5}, LineIndent -> 0, 
       LineSpacing -> {1.1, 5}}], Deploy]& ),
   InterpretationFunction->(#2& )],
  False,
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[31]=",ExpressionUUID->"54adfa5d-7aab-4859-82bb-029d5a07d7a5"]
}, Open  ]],

Cell["\<\
\[OpenCurlyDoubleQuote]Drill down\[CloseCurlyDoubleQuote] to make a table of \
radii of all the moons of Mars:\
\>", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"2af3a5df-37cf-4211-b426-61d58ec6477c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"planets", "[", 
  RowBox[{
  "\"\<Mars\>\"", ",", "\"\<Moons\>\"", ",", "All", ",", "\"\<Radius\>\""}], 
  "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[32]:=",ExpressionUUID->"bfef0abd-9aa7-46a4-bfdd-4ad9224cd20e"],

Cell[BoxData[
 TagBox[
  TemplateBox[{GridBox[{{
       StyleBox[
        StyleBox["\"Phobos\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 
       TemplateBox[{"11.1`3.", "\"km\"", "kilometers", "\"Kilometers\""}, 
        "Quantity", SyntaxForm -> Mod]}, {
       StyleBox[
        StyleBox["\"Deimos\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 
       TemplateBox[{"6.2`2.", "\"km\"", "kilometers", "\"Kilometers\""}, 
        "Quantity", SyntaxForm -> Mod]}, {
       ItemBox[
        RowBox[{"1 level", 
          AdjustmentBox[" | ", BoxBaselineShift -> -0.3], 
          RowBox[{"2", "elements"}]}], 
        BaseStyle -> {
         FontFamily -> "Helvetica", FontSize -> 10, FontColor -> 
          GrayLevel[0.4], Editable -> False, Selectable -> False}, 
        ItemSize -> {Automatic, Automatic}, Alignment -> {Left, Center}, 
        Background -> RGBColor[0.92, 0.92, 0.9]], "\[SpanFromLeft]"}}, 
     GridBoxFrame -> {"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}}, 
     FrameStyle -> RGBColor[0, 0, 0, 0.4], GridBoxDividers -> {"Columns" -> {
         RGBColor[0, 0, 0, 0.4], 
         RGBColor[0, 0, 0, 0.3], {
          RGBColor[0, 0, 0, 0.09]}, 
         RGBColor[0, 0, 0, 0.4]}, "Rows" -> {
         RGBColor[0, 0, 0, 0.4], {
          RGBColor[0, 0, 0, 0.08]}, 
         RGBColor[0, 0, 0, 0.4]}}, RowSpacings -> 1.2, 
     GridBoxBackground -> {"Columns" -> {
         RGBColor[0.92, 0.92, 0.9]}}, 
     GridBoxAlignment -> {"Columns" -> {{Left}}}, ColumnSpacings -> 2.5, 
     GridFrameMargins -> {{2, 3}, {1, 3}}, 
     GridBoxItemSize -> {"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
      RowMinHeight -> 1.3],
    "Dataset[Association[(_String -> Quantity[_, \"Kilometers\"])..]]"},
   "Dataset",
   DisplayFunction->(TagBox[
     StyleBox[#, {
      ShowAutoStyles -> False, LineBreakWithin -> False, FontWeight -> 
       "Light", FontFamily -> "Helvetica Neue", NumberMarks -> False, 
       SpanMaxSize -> 3, SpanMinSize -> 1., Editable -> False, Selectable -> 
       True, Background -> RGBColor[0.985, 0.98, 0.973], 
       LinebreakAdjustments -> {0.4, 5, 100, 0, 0.5}, LineIndent -> 0, 
       LineSpacing -> {1.1, 5}}], Deploy]& ),
   InterpretationFunction->(#2& )],
  False,
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[32]=",ExpressionUUID->"0136d980-ce1f-49f2-a9fb-8d8b969a4786"]
}, Open  ]],

Cell["\<\
We can do computations about the moons of all planets. First, let\
\[CloseCurlyQuote]s just find out how many moons are listed for each planet.\
\>", "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"p:277",ExpressionUUID->"c4336ec3-aad7-4288-8558-6675ae6db986"],

Cell["\<\
Make a dataset of the number of moons listed for each planet:\
\>", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"01ab01d9-db46-4817-97d7-162bd6a5533f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"planets", "[", 
  RowBox[{"All", ",", "\"\<Moons\>\"", ",", "Length"}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[33]:=",ExpressionUUID->"c2a768d2-06b1-4cf6-9b93-e25ce7217556"],

Cell[BoxData[
 TagBox[
  TemplateBox[{GridBox[{{
       StyleBox[
        StyleBox["\"Mercury\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 0}, {
       StyleBox[
        StyleBox["\"Venus\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 0}, {
       StyleBox[
        StyleBox["\"Earth\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 1}, {
       StyleBox[
        StyleBox["\"Mars\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 2}, {
       StyleBox[
        StyleBox["\"Jupiter\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 38}, {
       StyleBox[
        StyleBox["\"Saturn\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 33}, {
       StyleBox[
        StyleBox["\"Uranus\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 21}, {
       StyleBox[
        StyleBox["\"Neptune\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 8}, {
       ItemBox[
        RowBox[{"1 level", 
          AdjustmentBox[" | ", BoxBaselineShift -> -0.3], 
          RowBox[{"8", "elements"}]}], 
        BaseStyle -> {
         FontFamily -> "Helvetica", FontSize -> 10, FontColor -> 
          GrayLevel[0.4], Editable -> False, Selectable -> False}, 
        ItemSize -> {Automatic, Automatic}, Alignment -> {Left, Center}, 
        Background -> RGBColor[0.92, 0.92, 0.9]], "\[SpanFromLeft]"}}, 
     GridBoxFrame -> {"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}}, 
     FrameStyle -> RGBColor[0, 0, 0, 0.4], GridBoxDividers -> {"Columns" -> {
         RGBColor[0, 0, 0, 0.4], 
         RGBColor[0, 0, 0, 0.3], {
          RGBColor[0, 0, 0, 0.09]}, 
         RGBColor[0, 0, 0, 0.4]}, "Rows" -> {
         RGBColor[0, 0, 0, 0.4], {
          RGBColor[0, 0, 0, 0.08]}, 
         RGBColor[0, 0, 0, 0.4]}}, RowSpacings -> 1.2, 
     GridBoxBackground -> {"Columns" -> {
         RGBColor[0.92, 0.92, 0.9]}}, 
     GridBoxAlignment -> {"Columns" -> {{Left}}}, ColumnSpacings -> 2.5, 
     GridFrameMargins -> {{2, 3}, {1, 3}}, 
     GridBoxItemSize -> {"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
      RowMinHeight -> 1.3],"Dataset[Association[(_String -> _Integer)..]]"},
   "Dataset",
   DisplayFunction->(TagBox[
     StyleBox[#, {
      ShowAutoStyles -> False, LineBreakWithin -> False, FontWeight -> 
       "Light", FontFamily -> "Helvetica Neue", NumberMarks -> False, 
       SpanMaxSize -> 3, SpanMinSize -> 1., Editable -> False, Selectable -> 
       True, Background -> RGBColor[0.985, 0.98, 0.973], 
       LinebreakAdjustments -> {0.4, 5, 100, 0, 0.5}, LineIndent -> 0, 
       LineSpacing -> {1.1, 5}}], Deploy]& ),
   InterpretationFunction->(#2& )],
  False,
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[33]=",ExpressionUUID->"3b80f848-4e88-48c9-ade1-afc0a7135197"]
}, Open  ]],

Cell["Find the total mass of all moons for each planet:", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"0d881082-bb3f-42a0-823a-b366d1013fe9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"planets", "[", 
  RowBox[{"All", ",", "\"\<Moons\>\"", ",", "Total", ",", "\"\<Mass\>\""}], 
  "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[34]:=",ExpressionUUID->"14a91c81-27b7-46da-b4f1-e59a9994e955"],

Cell[BoxData[
 TagBox[
  TemplateBox[{GridBox[{{
       StyleBox[
        StyleBox["\"Mercury\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 
       TemplateBox[{"0", 
         SubscriptBox[
          StyleBox["\"M\"", Italic, StripOnInput -> False], "\"\[Earth]\""], 
         "Earth masses", "\"EarthMass\""}, "Quantity", SyntaxForm -> Mod]}, {
       StyleBox[
        StyleBox["\"Venus\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 
       TemplateBox[{"0", 
         SubscriptBox[
          StyleBox["\"M\"", Italic, StripOnInput -> False], "\"\[Earth]\""], 
         "Earth masses", "\"EarthMass\""}, "Quantity", SyntaxForm -> Mod]}, {
       StyleBox[
        StyleBox["\"Earth\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 
       TemplateBox[{
        "0.01230016133804645640112692149922730729`4.995248844409004", 
         SubscriptBox[
          StyleBox["\"M\"", Italic, StripOnInput -> False], "\"\[Earth]\""], 
         "Earth masses", "\"EarthMass\""}, "Quantity", SyntaxForm -> Mod]}, {
       StyleBox[
        StyleBox["\"Mars\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 
       TemplateBox[{"2.04166379522689299835687572227`2.885324039235817*^-9", 
         SubscriptBox[
          StyleBox["\"M\"", Italic, StripOnInput -> False], "\"\[Earth]\""], 
         "Earth masses", "\"EarthMass\""}, "Quantity", SyntaxForm -> Mod]}, {
       StyleBox[
        StyleBox["\"Jupiter\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 
       TemplateBox[{
        "0.06580733862818021716336684549470626106`4.983164919320384", 
         SubscriptBox[
          StyleBox["\"M\"", Italic, StripOnInput -> False], "\"\[Earth]\""], 
         "Earth masses", "\"EarthMass\""}, "Quantity", SyntaxForm -> Mod]}, {
       StyleBox[
        StyleBox["\"Saturn\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 
       TemplateBox[{
        "0.02352739951889508060941283216744272444`4.924394335943824", 
         SubscriptBox[
          StyleBox["\"M\"", Italic, StripOnInput -> False], "\"\[Earth]\""], 
         "Earth masses", "\"EarthMass\""}, "Quantity", SyntaxForm -> Mod]}, {
       StyleBox[
        StyleBox["\"Uranus\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 
       TemplateBox[{
        "0.00153072639173862894057189795708694655`3.364747904287189", 
         SubscriptBox[
          StyleBox["\"M\"", Italic, StripOnInput -> False], "\"\[Earth]\""], 
         "Earth masses", "\"EarthMass\""}, "Quantity", SyntaxForm -> Mod]}, {
       StyleBox[
        StyleBox["\"Neptune\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 
       TemplateBox[{
        "0.00359781903677978896202707241196317041`4.537123375643805", 
         SubscriptBox[
          StyleBox["\"M\"", Italic, StripOnInput -> False], "\"\[Earth]\""], 
         "Earth masses", "\"EarthMass\""}, "Quantity", SyntaxForm -> Mod]}, {
       ItemBox[
        RowBox[{"1 level", 
          AdjustmentBox[" | ", BoxBaselineShift -> -0.3], 
          RowBox[{"8", "elements"}]}], 
        BaseStyle -> {
         FontFamily -> "Helvetica", FontSize -> 10, FontColor -> 
          GrayLevel[0.4], Editable -> False, Selectable -> False}, 
        ItemSize -> {Automatic, Automatic}, Alignment -> {Left, Center}, 
        Background -> RGBColor[0.92, 0.92, 0.9]], "\[SpanFromLeft]"}}, 
     GridBoxFrame -> {"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}}, 
     FrameStyle -> RGBColor[0, 0, 0, 0.4], GridBoxDividers -> {"Columns" -> {
         RGBColor[0, 0, 0, 0.4], 
         RGBColor[0, 0, 0, 0.3], {
          RGBColor[0, 0, 0, 0.09]}, 
         RGBColor[0, 0, 0, 0.4]}, "Rows" -> {
         RGBColor[0, 0, 0, 0.4], {
          RGBColor[0, 0, 0, 0.08]}, 
         RGBColor[0, 0, 0, 0.4]}}, RowSpacings -> 1.2, 
     GridBoxBackground -> {"Columns" -> {
         RGBColor[0.92, 0.92, 0.9]}}, 
     GridBoxAlignment -> {"Columns" -> {{Left}}}, ColumnSpacings -> 2.5, 
     GridFrameMargins -> {{2, 3}, {1, 3}}, 
     GridBoxItemSize -> {"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
      RowMinHeight -> 1.3],
    "Dataset[Association[(_String -> Quantity[_, \"EarthMass\"])..]]"},
   "Dataset",
   DisplayFunction->(TagBox[
     StyleBox[#, {
      ShowAutoStyles -> False, LineBreakWithin -> False, FontWeight -> 
       "Light", FontFamily -> "Helvetica Neue", NumberMarks -> False, 
       SpanMaxSize -> 3, SpanMinSize -> 1., Editable -> False, Selectable -> 
       True, Background -> RGBColor[0.985, 0.98, 0.973], 
       LinebreakAdjustments -> {0.4, 5, 100, 0, 0.5}, LineIndent -> 0, 
       LineSpacing -> {1.1, 5}}], Deploy]& ),
   InterpretationFunction->(#2& )],
  False,
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellTags->"LastCellOfAPage",
 CellLabel->"Out[34]=",ExpressionUUID->"25d5d210-10ca-469e-9f56-63f16620f998"]
}, Open  ]],

Cell["\<\
Get the same result, but only for planets with more than 10 moons:\
\>", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"8c968d56-b267-4e6b-8701-42c1d24a8bf5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"planets", "[", 
  RowBox[{
   RowBox[{"Select", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Length", "[", "#Moons", "]"}], ">", "10"}], "&"}], "]"}], ",", 
   "\"\<Moons\>\"", ",", "Total", ",", "\"\<Mass\>\""}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[35]:=",ExpressionUUID->"4918fbe2-4c3c-43ab-a559-7218b4eec33a"],

Cell[BoxData[
 TagBox[
  TemplateBox[{GridBox[{{
       StyleBox[
        StyleBox["\"Jupiter\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 
       TemplateBox[{
        "0.06580733862818021716336684549470626106`4.983164919320384", 
         SubscriptBox[
          StyleBox["\"M\"", Italic, StripOnInput -> False], "\"\[Earth]\""], 
         "Earth masses", "\"EarthMass\""}, "Quantity", SyntaxForm -> Mod]}, {
       StyleBox[
        StyleBox["\"Saturn\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 
       TemplateBox[{
        "0.02352739951889508060941283216744272444`4.924394335943824", 
         SubscriptBox[
          StyleBox["\"M\"", Italic, StripOnInput -> False], "\"\[Earth]\""], 
         "Earth masses", "\"EarthMass\""}, "Quantity", SyntaxForm -> Mod]}, {
       StyleBox[
        StyleBox["\"Uranus\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 
       TemplateBox[{
        "0.00153072639173862894057189795708694655`3.364747904287189", 
         SubscriptBox[
          StyleBox["\"M\"", Italic, StripOnInput -> False], "\"\[Earth]\""], 
         "Earth masses", "\"EarthMass\""}, "Quantity", SyntaxForm -> Mod]}, {
       ItemBox[
        RowBox[{"1 level", 
          AdjustmentBox[" | ", BoxBaselineShift -> -0.3], 
          RowBox[{"3", "elements"}]}], 
        BaseStyle -> {
         FontFamily -> "Helvetica", FontSize -> 10, FontColor -> 
          GrayLevel[0.4], Editable -> False, Selectable -> False}, 
        ItemSize -> {Automatic, Automatic}, Alignment -> {Left, Center}, 
        Background -> RGBColor[0.92, 0.92, 0.9]], "\[SpanFromLeft]"}}, 
     GridBoxFrame -> {"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}}, 
     FrameStyle -> RGBColor[0, 0, 0, 0.4], GridBoxDividers -> {"Columns" -> {
         RGBColor[0, 0, 0, 0.4], 
         RGBColor[0, 0, 0, 0.3], {
          RGBColor[0, 0, 0, 0.09]}, 
         RGBColor[0, 0, 0, 0.4]}, "Rows" -> {
         RGBColor[0, 0, 0, 0.4], {
          RGBColor[0, 0, 0, 0.08]}, 
         RGBColor[0, 0, 0, 0.4]}}, RowSpacings -> 1.2, 
     GridBoxBackground -> {"Columns" -> {
         RGBColor[0.92, 0.92, 0.9]}}, 
     GridBoxAlignment -> {"Columns" -> {{Left}}}, ColumnSpacings -> 2.5, 
     GridFrameMargins -> {{2, 3}, {1, 3}}, 
     GridBoxItemSize -> {"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
      RowMinHeight -> 1.3],
    "Dataset[Association[(_String -> Quantity[_, \"EarthMass\"])..]]"},
   "Dataset",
   DisplayFunction->(TagBox[
     StyleBox[#, {
      ShowAutoStyles -> False, LineBreakWithin -> False, FontWeight -> 
       "Light", FontFamily -> "Helvetica Neue", NumberMarks -> False, 
       SpanMaxSize -> 3, SpanMinSize -> 1., Editable -> False, Selectable -> 
       True, Background -> RGBColor[0.985, 0.98, 0.973], 
       LinebreakAdjustments -> {0.4, 5, 100, 0, 0.5}, LineIndent -> 0, 
       LineSpacing -> {1.1, 5}}], Deploy]& ),
   InterpretationFunction->(#2& )],
  False,
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[35]=",ExpressionUUID->"dc351da0-8d09-4871-865d-ec7c73b4b5d2"]
}, Open  ]],

Cell["Make a pie chart of the result:", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"p:278",ExpressionUUID->"a0ecd7af-cb0a-4a5e-9e46-c9281e9d6268"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PieChart", "[", 
  RowBox[{"%", ",", 
   RowBox[{"ChartLegends", "\[Rule]", "Automatic"}]}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[36]:=",ExpressionUUID->"b442e1a3-80e5-447c-8344-3d7b0167c4ed"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{}, {}, 
     DynamicModuleBox[{
      DynamicChart`click$43585$43671 = False, DynamicChart`click$43588$43671 = 
       False, DynamicChart`click$43591$43671 = False}, {{
        Directive[
         RGBColor[0.5, 0.5, 1.], 
         EdgeForm[
          Directive[
           GrayLevel[0], 
           Opacity[0.5]]]], {{{{{{}, {{
               Directive[
                EdgeForm[
                 Directive[
                  GrayLevel[0], 
                  Opacity[0.5]]], 
                RGBColor[0.982864, 0.7431472, 0.3262672]], 
               GeometricTransformationBox[
                TagBox[
                 TagBox[
                  TooltipBox[
                   TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[2.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    DiskBox[{0, 0}, 1., {-1.4088678021156014`, 
                    3.141592653589793}]}], 
                    StatusArea[#, 0.0658073386281802172`4.983164919320384]& , 
                    TagBoxNote -> 
                    "0.06580733862818021716336684549470626106`4.\
983164919320384"], 
                   StyleBox[
                   "0.06580733862818021716336684549470626106`4.\
983164919320384", {
                    GrayLevel[0], FontFamily -> "Arial"}, StripOnInput -> 
                    False]], Annotation[#, 
                   Style[0.0658073386281802172`4.983164919320384, {
                    GrayLevel[0], FontFamily -> "Arial"}], "Tooltip"]& ], 
                 
                 EventHandlerTag[{
                  "MouseClicked" :> 
                   FEPrivate`Set[DynamicChart`click$43585$43671, 
                    FEPrivate`Not[DynamicChart`click$43585$43671]], 
                   PassEventsDown -> True, Method -> "Preemptive", 
                   PassEventsUp -> True}]], 
                Dynamic[
                 If[
                 DynamicChart`click$43585$43671, {{{1., 0}, {0, 1.}}, {
                   0.12952051564555245`, 0.15239565619436207`}}, {{1, 0}, {0, 
                  1}}, {{1, 0}, {0, 1}}], 
                 TrackedSymbols :> {DynamicChart`click$43585$43671}]]}, {
               Directive[
                EdgeForm[
                 Directive[
                  GrayLevel[0], 
                  Opacity[0.5]]], 
                RGBColor[0.784, 0.47519999999999996`, 0.2]], 
               GeometricTransformationBox[
                TagBox[
                 TagBox[
                  TooltipBox[
                   TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[2.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    DiskBox[{0, 0}, 
                    1., {-3.035745645348551, -1.4088678021156014`}]}], 
                    StatusArea[#, 0.0235273995188950806`4.924394335943824]& , 
                    TagBoxNote -> 
                    "0.02352739951889508060941283216744272444`4.\
924394335943824"], 
                   StyleBox[
                   "0.02352739951889508060941283216744272444`4.\
924394335943824", {
                    GrayLevel[0], FontFamily -> "Arial"}, StripOnInput -> 
                    False]], Annotation[#, 
                   Style[0.0235273995188950806`4.924394335943824, {
                    GrayLevel[0], FontFamily -> "Arial"}], "Tooltip"]& ], 
                 
                 EventHandlerTag[{
                  "MouseClicked" :> 
                   FEPrivate`Set[DynamicChart`click$43588$43671, 
                    FEPrivate`Not[DynamicChart`click$43588$43671]], 
                   PassEventsDown -> True, Method -> "Preemptive", 
                   PassEventsUp -> True}]], 
                Dynamic[
                 If[
                 DynamicChart`click$43588$43671, {{{1., 0}, {
                    0, 1.}}, {-0.12127762350090424`, -0.15903376383011542`}}, \
{{1, 0}, {0, 1}}, {{1, 0}, {0, 1}}], 
                 TrackedSymbols :> {DynamicChart`click$43588$43671}]]}, {
               Directive[
                EdgeForm[
                 Directive[
                  GrayLevel[0], 
                  Opacity[0.5]]], 
                RGBColor[0.4992, 0.5552, 0.8309304]], 
               GeometricTransformationBox[
                TagBox[
                 TagBox[
                  TooltipBox[
                   TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[2.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    DiskBox[{0, 0}, 
                    1., {-3.141592653589793, -3.035745645348551}]}], 
                    StatusArea[#, 0.0015307263917386289`3.364747904287189]& , 
                    TagBoxNote -> 
                    "0.00153072639173862894057189795708694655`3.\
364747904287189"], 
                   StyleBox[
                   "0.00153072639173862894057189795708694655`3.\
364747904287189", {
                    GrayLevel[0], FontFamily -> "Arial"}, StripOnInput -> 
                    False]], Annotation[#, 
                   Style[0.0015307263917386289`3.364747904287189, {
                    GrayLevel[0], FontFamily -> "Arial"}], "Tooltip"]& ], 
                 
                 EventHandlerTag[{
                  "MouseClicked" :> 
                   FEPrivate`Set[DynamicChart`click$43591$43671, 
                    FEPrivate`Not[DynamicChart`click$43591$43671]], 
                   PassEventsDown -> True, Method -> "Preemptive", 
                   PassEventsUp -> True}]], 
                Dynamic[
                 If[
                 DynamicChart`click$43591$43671, {{{1., 0}, {
                    0, 1.}}, {-0.19971997564026964`, \
-0.010579760406082361`}}, {{1, 0}, {0, 1}}, {{1, 0}, {0, 1}}], 
                 TrackedSymbols :> {
                  DynamicChart`click$43591$43671}]]}}}}}, {}}, {{}}}}, {{{{
           GeometricTransformationBox[
            TagBox[
             TagBox[
              TooltipBox[
               
               TagBox[{{}, {}}, 
                StatusArea[#, 0.0658073386281802172`4.983164919320384]& , 
                TagBoxNote -> 
                "0.06580733862818021716336684549470626106`4.983164919320384"], 
               StyleBox[
               "0.06580733862818021716336684549470626106`4.983164919320384", {
                
                 GrayLevel[0], FontFamily -> "Arial"}, StripOnInput -> 
                False]], Annotation[#, 
               Style[0.0658073386281802172`4.983164919320384, {
                 GrayLevel[0], FontFamily -> "Arial"}], "Tooltip"]& ], 
             
             EventHandlerTag[{
              "MouseClicked" :> 
               FEPrivate`Set[DynamicChart`click$43585$43671, 
                 FEPrivate`Not[DynamicChart`click$43585$43671]], 
               PassEventsDown -> True, Method -> "Preemptive", PassEventsUp -> 
               True}]], 
            Dynamic[
             If[
             DynamicChart`click$43585$43671, {{{1., 0}, {0, 1.}}, {
               0.12952051564555245`, 0.15239565619436207`}}, {{1, 0}, {0, 
              1}}, {{1, 0}, {0, 1}}], 
             TrackedSymbols :> {DynamicChart`click$43585$43671}]], 
           GeometricTransformationBox[
            TagBox[
             TagBox[
              TooltipBox[
               
               TagBox[{{}, {}}, 
                StatusArea[#, 0.0235273995188950806`4.924394335943824]& , 
                TagBoxNote -> 
                "0.02352739951889508060941283216744272444`4.924394335943824"], 
               StyleBox[
               "0.02352739951889508060941283216744272444`4.924394335943824", {
                
                 GrayLevel[0], FontFamily -> "Arial"}, StripOnInput -> 
                False]], Annotation[#, 
               Style[0.0235273995188950806`4.924394335943824, {
                 GrayLevel[0], FontFamily -> "Arial"}], "Tooltip"]& ], 
             
             EventHandlerTag[{
              "MouseClicked" :> 
               FEPrivate`Set[DynamicChart`click$43588$43671, 
                 FEPrivate`Not[DynamicChart`click$43588$43671]], 
               PassEventsDown -> True, Method -> "Preemptive", PassEventsUp -> 
               True}]], 
            Dynamic[
             If[
             DynamicChart`click$43588$43671, {{{1., 0}, {
                0, 1.}}, {-0.12127762350090424`, -0.15903376383011542`}}, {{1,
               0}, {0, 1}}, {{1, 0}, {0, 1}}], 
             TrackedSymbols :> {DynamicChart`click$43588$43671}]], 
           GeometricTransformationBox[
            TagBox[
             TagBox[
              TooltipBox[
               
               TagBox[{{}, {}}, 
                StatusArea[#, 0.0015307263917386289`3.364747904287189]& , 
                TagBoxNote -> 
                "0.00153072639173862894057189795708694655`3.364747904287189"], 
               StyleBox[
               "0.00153072639173862894057189795708694655`3.364747904287189", {
                
                 GrayLevel[0], FontFamily -> "Arial"}, StripOnInput -> 
                False]], Annotation[#, 
               Style[0.0015307263917386289`3.364747904287189, {
                 GrayLevel[0], FontFamily -> "Arial"}], "Tooltip"]& ], 
             
             EventHandlerTag[{
              "MouseClicked" :> 
               FEPrivate`Set[DynamicChart`click$43591$43671, 
                 FEPrivate`Not[DynamicChart`click$43591$43671]], 
               PassEventsDown -> True, Method -> "Preemptive", PassEventsUp -> 
               True}]], 
            Dynamic[
             If[
             DynamicChart`click$43591$43671, {{{1., 0}, {
                0, 1.}}, {-0.19971997564026964`, -0.010579760406082361`}}, {{
              1, 0}, {0, 1}}, {{1, 0}, {0, 1}}], 
             TrackedSymbols :> {
              DynamicChart`click$43591$43671}]]}, {}}}, {}}}, 
      DynamicModuleValues :> {}], {{{}, {}}}, {{{{}, {}, {}, {}}}, {}}}, {
    ContentSelectable -> False, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], LabelStyle -> {
       GrayLevel[0], FontFamily -> "Arial"}, 
     PlotRange -> {{-1.2, 1.2}, {-1.2, 1.2}}, PlotRangePadding -> 
     Scaled[0.02]}],FormBox[
    FormBox[
     TemplateBox[{"\"Jupiter\"", "\"Saturn\"", "\"Uranus\""}, "SwatchLegend", 
      DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{
                    Directive[
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    EdgeForm[
                    Directive[
                    GrayLevel[0], 
                    Opacity[0.5]]], 
                    RGBColor[0.982864, 0.7431472, 0.3262672]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{
                    Directive[
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    EdgeForm[
                    Directive[
                    GrayLevel[0], 
                    Opacity[0.5]]], 
                    RGBColor[0.784, 0.47519999999999996`, 0.2]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{
                    Directive[
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    EdgeForm[
                    Directive[
                    GrayLevel[0], 
                    Opacity[0.5]]], 
                    RGBColor[0.4992, 0.5552, 0.8309304]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.5}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          GrayLevel[0], FontFamily -> "Arial", FontFamily -> "Arial"}, 
         Background -> Automatic, StripOnInput -> False], TraditionalForm]& ),
       InterpretationFunction :> (RowBox[{"SwatchLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"EdgeForm", "[", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "GrayLevel[0]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}]}], "]"}], "]"}], 
                   ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.982864, 0.7431472, 0.3262672], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.6552426666666666, 0.4954314666666667, 
                    0.21751146666666665`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.982864, 0.7431472, 0.3262672]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.982864, 0.7431472, 0.3262672]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.982864, 0.7431472, 0.3262672], Editable -> 
                    False, Selectable -> False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"EdgeForm", "[", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "GrayLevel[0]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}]}], "]"}], "]"}], 
                   ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.784, 0.47519999999999996`, 0.2], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.5226666666666667, 0.31679999999999997`, 
                    0.13333333333333336`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.784, 0.47519999999999996, 0.2]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.784, 0.47519999999999996`, 0.2]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.784, 0.47519999999999996`, 0.2], Editable -> 
                    False, Selectable -> False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"EdgeForm", "[", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "GrayLevel[0]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}]}], "]"}], "]"}], 
                   ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.4992, 0.5552, 0.8309304], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.3328, 0.37013333333333337`, 0.5539536], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.4992, 0.5552, 0.8309304]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.4992, 0.5552, 0.8309304]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.4992, 0.5552, 0.8309304], Editable -> False, 
                    Selectable -> False]}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{"{", 
                 RowBox[{"None", ",", "None", ",", "None"}], "}"}], "}"}]}], 
           ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "GrayLevel[0]"], Appearance -> None, 
                   BaseStyle -> {}, BaselinePosition -> Baseline, 
                   DefaultBaseStyle -> {}, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  GrayLevel[0], Editable -> False, Selectable -> False], ",", 
                 
                 RowBox[{"FontFamily", "\[Rule]", "\"Arial\""}]}], "}"}]}], 
           ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[36]=",ExpressionUUID->"135f560c-2ca6-48f8-a737-631daf1c50db"]
}, Open  ]],

Cell["\<\
Get a dataset with moons that are more than 1% of the mass of the Earth.\
\>", "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"8c254ac4-13e6-4d84-8052-451351432a31"],

Cell["\<\
For all moons, select ones whose mass is greater than 0.01 times the mass of \
the Earth:\
\>", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"0f394454-1845-4666-b565-07bfdd86130c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"planets", "[", 
  RowBox[{"All", ",", "\"\<Moons\>\"", ",", 
   RowBox[{"Select", "[", 
    RowBox[{
     RowBox[{"#Mass", ">", 
      NamespaceBox["LinguisticAssistant",
       DynamicModuleBox[{Typeset`query$$ = "1/100 earth mass", 
        Typeset`boxes$$ = TemplateBox[{"0.01", 
          SubscriptBox[
           StyleBox["\"M\"", Italic, StripOnInput -> False], "\"\[Earth]\""], 
          "Earth masses", "\"EarthMass\""}, "Quantity", SyntaxForm -> Mod], 
        Typeset`allassumptions$$ = {}, Typeset`assumptions$$ = {}, 
        Typeset`open$$ = {1, 2}, Typeset`querystate$$ = {
        "Online" -> True, "Allowed" -> True, "mparse.jsp" -> 
         1.23332`6.542620767742447, "Messages" -> {}}}, 
        DynamicBox[ToBoxes[
          AlphaIntegration`LinguisticAssistantBoxes["", 4, Automatic, 
           Dynamic[Typeset`query$$], 
           Dynamic[Typeset`boxes$$], 
           Dynamic[Typeset`allassumptions$$], 
           Dynamic[Typeset`assumptions$$], 
           Dynamic[Typeset`open$$], 
           Dynamic[Typeset`querystate$$]], StandardForm],
         ImageSizeCache->{94., {10., 18.}},
         TrackedSymbols:>{
          Typeset`query$$, Typeset`boxes$$, Typeset`allassumptions$$, 
           Typeset`assumptions$$, Typeset`open$$, Typeset`querystate$$}],
        DynamicModuleValues:>{},
        UndoTrackedVariables:>{Typeset`open$$}],
       BaseStyle->{"Deploy"},
       DeleteWithContents->True,
       Editable->False,
       SelectWithContents->True]}], "&"}], "]"}]}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[37]:=",ExpressionUUID->"ecab95d0-a2e4-4e27-b804-f504cd12c522"],

Cell[BoxData[
 TagBox[
  TemplateBox[{GridBox[{{
       StyleBox[
        StyleBox["\"Mercury\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 
       StyleBox[
        RowBox[{
          StyleBox["\[LeftAssociation]", 
           GrayLevel[0.45]], "\[ThinSpace]", "\[ThinSpace]", 
          StyleBox["\[RightAssociation]", 
           GrayLevel[0.45]]}], LineBreakWithin -> Automatic]}, {
       StyleBox[
        StyleBox["\"Venus\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 
       StyleBox[
        RowBox[{
          StyleBox["\[LeftAssociation]", 
           GrayLevel[0.45]], "\[ThinSpace]", "\[ThinSpace]", 
          StyleBox["\[RightAssociation]", 
           GrayLevel[0.45]]}], LineBreakWithin -> Automatic]}, {
       StyleBox[
        StyleBox["\"Earth\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 
       StyleBox[
        RowBox[{
          StyleBox["\[LeftAssociation]", 
           GrayLevel[0.45]], "\[ThinSpace]", 
          StyleBox[
           RowBox[{
             StyleBox[
              StyleBox["\"Moon\"", FontColor -> GrayLevel[0.4]], 
              GrayLevel[0.3]], 
             StyleBox["\[Rule]", 
              GrayLevel[0.5]], 
             StyleBox[
              RowBox[{
                StyleBox["\[LeftAssociation]", 
                 GrayLevel[0.45]], "\[ThinSpace]", 
                RowBox[{
                  StyleBox["\"Mass\"", 
                   GrayLevel[0.3]], 
                  StyleBox["\[Rule]", 
                   GrayLevel[0.5]], 
                  
                  TemplateBox[{
                   "0.01230016133804645640112692149922730729`4.\
995248844409004", 
                    SubscriptBox[
                    StyleBox["\"M\"", Italic, StripOnInput -> False], 
                    "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, 
                   "Quantity", SyntaxForm -> Mod]}], ",", 
                RowBox[{
                  StyleBox["\"Radius\"", 
                   GrayLevel[0.3]], 
                  StyleBox["\[Rule]", 
                   GrayLevel[0.5]], 
                  
                  TemplateBox[{
                   "1737.5`5.", "\"km\"", "kilometers", "\"Kilometers\""}, 
                   "Quantity", SyntaxForm -> Mod]}], "\[ThinSpace]", 
                StyleBox["\[RightAssociation]", 
                 GrayLevel[0.45]]}], LineBreakWithin -> Automatic]}], 
           SpanMinSize -> 1], "\[ThinSpace]", 
          StyleBox["\[RightAssociation]", 
           GrayLevel[0.45]]}], LineBreakWithin -> Automatic]}, {
       StyleBox[
        StyleBox["\"Mars\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 
       StyleBox[
        RowBox[{
          StyleBox["\[LeftAssociation]", 
           GrayLevel[0.45]], "\[ThinSpace]", "\[ThinSpace]", 
          StyleBox["\[RightAssociation]", 
           GrayLevel[0.45]]}], LineBreakWithin -> Automatic]}, {
       StyleBox[
        StyleBox["\"Jupiter\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 
       StyleBox[
        RowBox[{
          StyleBox["\[LeftAssociation]", 
           GrayLevel[0.45]], "\[ThinSpace]", 
          StyleBox[
           RowBox[{
             StyleBox[
              StyleBox["\"Ganymede\"", FontColor -> GrayLevel[0.4]], 
              GrayLevel[0.3]], 
             StyleBox["\[Rule]", 
              GrayLevel[0.5]], 
             StyleBox[
              RowBox[{
                StyleBox["\[LeftAssociation]", 
                 GrayLevel[0.45]], "\[ThinSpace]", 
                RowBox[{
                  StyleBox["\"Mass\"", 
                   GrayLevel[0.3]], 
                  StyleBox["\[Rule]", 
                   GrayLevel[0.5]], 
                  
                  TemplateBox[{
                   "0.02480662655568138400530235916802739469`4.\
995248844409004", 
                    SubscriptBox[
                    StyleBox["\"M\"", Italic, StripOnInput -> False], 
                    "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, 
                   "Quantity", SyntaxForm -> Mod]}], ",", 
                RowBox[{
                  StyleBox["\"Radius\"", 
                   GrayLevel[0.3]], 
                  StyleBox["\[Rule]", 
                   GrayLevel[0.5]], 
                  
                  TemplateBox[{
                   "2631.2`5.", "\"km\"", "kilometers", "\"Kilometers\""}, 
                   "Quantity", SyntaxForm -> Mod]}], "\[ThinSpace]", 
                StyleBox["\[RightAssociation]", 
                 GrayLevel[0.45]]}], LineBreakWithin -> Automatic]}], 
           SpanMinSize -> 1], ",", 
          StyleBox[
           RowBox[{
             StyleBox[
              StyleBox["\"Callisto\"", FontColor -> GrayLevel[0.4]], 
              GrayLevel[0.3]], 
             StyleBox["\[Rule]", 
              GrayLevel[0.5]], 
             StyleBox[
              RowBox[{
                StyleBox["\[LeftAssociation]", 
                 GrayLevel[0.45]], "\[ThinSpace]", 
                RowBox[{
                  StyleBox["\"Mass\"", 
                   GrayLevel[0.3]], 
                  StyleBox["\[Rule]", 
                   GrayLevel[0.5]], 
                  
                  TemplateBox[{
                   "0.01801142102085363161376325378730590253`4.\
995248844409004", 
                    SubscriptBox[
                    StyleBox["\"M\"", Italic, StripOnInput -> False], 
                    "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, 
                   "Quantity", SyntaxForm -> Mod]}], ",", 
                RowBox[{
                  StyleBox["\"Radius\"", 
                   GrayLevel[0.3]], 
                  StyleBox["\[Rule]", 
                   GrayLevel[0.5]], 
                  
                  TemplateBox[{
                   "2410.3`5.", "\"km\"", "kilometers", "\"Kilometers\""}, 
                   "Quantity", SyntaxForm -> Mod]}], "\[ThinSpace]", 
                StyleBox["\[RightAssociation]", 
                 GrayLevel[0.45]]}], LineBreakWithin -> Automatic]}], 
           SpanMinSize -> 1], ",", 
          StyleBox[
           SubscriptBox["\[CenterEllipsis]", "1"], 
           GrayLevel[0.5]], "\[ThinSpace]", 
          StyleBox["\[RightAssociation]", 
           GrayLevel[0.45]]}], LineBreakWithin -> Automatic]}, {
       StyleBox[
        StyleBox["\"Saturn\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 
       StyleBox[
        RowBox[{
          StyleBox["\[LeftAssociation]", 
           GrayLevel[0.45]], "\[ThinSpace]", 
          StyleBox[
           RowBox[{
             StyleBox[
              StyleBox["\"Titan\"", FontColor -> GrayLevel[0.4]], 
              GrayLevel[0.3]], 
             StyleBox["\[Rule]", 
              GrayLevel[0.5]], 
             StyleBox[
              RowBox[{
                StyleBox["\[LeftAssociation]", 
                 GrayLevel[0.45]], "\[ThinSpace]", 
                RowBox[{
                  StyleBox["\"Mass\"", 
                   GrayLevel[0.3]], 
                  StyleBox["\[Rule]", 
                   GrayLevel[0.5]], 
                  
                  TemplateBox[{
                   "0.02252450905587139155679247739684866761`4.\
958212681028252", 
                    SubscriptBox[
                    StyleBox["\"M\"", Italic, StripOnInput -> False], 
                    "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, 
                   "Quantity", SyntaxForm -> Mod]}], ",", 
                RowBox[{
                  StyleBox["\"Radius\"", 
                   GrayLevel[0.3]], 
                  StyleBox["\[Rule]", 
                   GrayLevel[0.5]], 
                  
                  TemplateBox[{
                   "2575.5`5.", "\"km\"", "kilometers", "\"Kilometers\""}, 
                   "Quantity", SyntaxForm -> Mod]}], "\[ThinSpace]", 
                StyleBox["\[RightAssociation]", 
                 GrayLevel[0.45]]}], LineBreakWithin -> Automatic]}], 
           SpanMinSize -> 1], "\[ThinSpace]", 
          StyleBox["\[RightAssociation]", 
           GrayLevel[0.45]]}], LineBreakWithin -> Automatic]}, {
       StyleBox[
        StyleBox["\"Uranus\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 
       StyleBox[
        RowBox[{
          StyleBox["\[LeftAssociation]", 
           GrayLevel[0.45]], "\[ThinSpace]", "\[ThinSpace]", 
          StyleBox["\[RightAssociation]", 
           GrayLevel[0.45]]}], LineBreakWithin -> Automatic]}, {
       StyleBox[
        StyleBox["\"Neptune\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 
       StyleBox[
        RowBox[{
          StyleBox["\[LeftAssociation]", 
           GrayLevel[0.45]], "\[ThinSpace]", "\[ThinSpace]", 
          StyleBox["\[RightAssociation]", 
           GrayLevel[0.45]]}], LineBreakWithin -> Automatic]}, {
       ItemBox[
        RowBox[{"3 levels", 
          AdjustmentBox[" | ", BoxBaselineShift -> -0.3], 
          RowBox[{"8", "rows"}]}], 
        BaseStyle -> {
         FontFamily -> "Helvetica", FontSize -> 10, FontColor -> 
          GrayLevel[0.4], Editable -> False, Selectable -> False}, 
        ItemSize -> {Automatic, Automatic}, Alignment -> {Left, Center}, 
        Background -> RGBColor[0.92, 0.92, 0.9]], "\[SpanFromLeft]"}}, 
     GridBoxFrame -> {"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}}, 
     FrameStyle -> RGBColor[0, 0, 0, 0.4], GridBoxDividers -> {"Columns" -> {
         RGBColor[0, 0, 0, 0.4], 
         RGBColor[0, 0, 0, 0.3], {
          RGBColor[0, 0, 0, 0.09]}, 
         RGBColor[0, 0, 0, 0.4]}, "Rows" -> {
         RGBColor[0, 0, 0, 0.4], {
          RGBColor[0, 0, 0, 0.08]}, 
         RGBColor[0, 0, 0, 0.4]}}, RowSpacings -> 1.2, 
     GridBoxBackground -> {"Columns" -> {
         RGBColor[0.92, 0.92, 0.9]}}, 
     GridBoxAlignment -> {"Columns" -> {{Left}}}, ColumnSpacings -> 2.5, 
     GridFrameMargins -> {{2, 3}, {1, 3}}, 
     GridBoxItemSize -> {"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
      RowMinHeight -> 1.3],
    "Dataset[Association[(_String -> _Association)..]]"},
   "Dataset",
   DisplayFunction->(TagBox[
     StyleBox[#, {
      ShowAutoStyles -> False, LineBreakWithin -> False, FontWeight -> 
       "Light", FontFamily -> "Helvetica Neue", NumberMarks -> False, 
       SpanMaxSize -> 3, SpanMinSize -> 1., Editable -> False, Selectable -> 
       True, Background -> RGBColor[0.985, 0.98, 0.973], 
       LinebreakAdjustments -> {0.4, 5, 100, 0, 0.5}, LineIndent -> 0, 
       LineSpacing -> {1.1, 5}}], Deploy]& ),
   InterpretationFunction->(#2& )],
  False,
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 Editable->False,
 PageWidth->1200,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellTags->"LastCellOfAPage",
 CellLabel->"Out[37]=",ExpressionUUID->"e26d2fa2-d313-4602-b9b0-a28878aa6f80"]
}, Open  ]],

Cell["\<\
Get the list of keys (i.e. moon names) in the resulting association for each \
planet:\
\>", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"55a98c6c-d36e-4712-a3e1-f96d041c6f2d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"planets", "[", 
   RowBox[{"All", ",", "\"\<Moons\>\"", ",", 
    RowBox[{"Select", "[", 
     RowBox[{
      RowBox[{"#Mass", ">", 
       NamespaceBox["LinguisticAssistant",
        DynamicModuleBox[{Typeset`query$$ = "1/100 earth mass", 
         Typeset`boxes$$ = TemplateBox[{"0.01", 
           SubscriptBox[
            StyleBox["\"M\"", Italic, StripOnInput -> False], "\"\[Earth]\""],
            "Earth masses", "\"EarthMass\""}, "Quantity", SyntaxForm -> Mod], 
         Typeset`allassumptions$$ = {}, Typeset`assumptions$$ = {}, 
         Typeset`open$$ = {1, 2}, Typeset`querystate$$ = {
         "Online" -> True, "Allowed" -> True, "mparse.jsp" -> 
          1.23332`6.542620767742447, "Messages" -> {}}}, 
         DynamicBox[ToBoxes[
           AlphaIntegration`LinguisticAssistantBoxes["", 4, Automatic, 
            Dynamic[Typeset`query$$], 
            Dynamic[Typeset`boxes$$], 
            Dynamic[Typeset`allassumptions$$], 
            Dynamic[Typeset`assumptions$$], 
            Dynamic[Typeset`open$$], 
            Dynamic[Typeset`querystate$$]], StandardForm],
          ImageSizeCache->{94., {10., 18.}},
          
          TrackedSymbols:>{
           Typeset`query$$, Typeset`boxes$$, Typeset`allassumptions$$, 
            Typeset`assumptions$$, Typeset`open$$, Typeset`querystate$$}],
         DynamicModuleValues:>{},
         UndoTrackedVariables:>{Typeset`open$$}],
        BaseStyle->{"Deploy"},
        DeleteWithContents->True,
        Editable->False,
        SelectWithContents->True]}], "&"}], "]"}]}], "]"}], "[", 
  RowBox[{"All", ",", "Keys"}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[38]:=",ExpressionUUID->"e81de660-2d5d-4743-bb9e-50078b6a98aa"],

Cell[BoxData[
 TagBox[
  TemplateBox[{GridBox[{{
       StyleBox[
        StyleBox["\"Mercury\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 
       StyleBox[
        RowBox[{"{", "\[ThinSpace]", "\[ThinSpace]", "}"}], LineBreakWithin -> 
        Automatic]}, {
       StyleBox[
        StyleBox["\"Venus\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 
       StyleBox[
        RowBox[{"{", "\[ThinSpace]", "\[ThinSpace]", "}"}], LineBreakWithin -> 
        Automatic]}, {
       StyleBox[
        StyleBox["\"Earth\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 
       StyleBox[
        RowBox[{"{", "\[ThinSpace]", 
          StyleBox["\"Moon\"", FontColor -> GrayLevel[0.4]], "\[ThinSpace]", 
          "}"}], LineBreakWithin -> Automatic]}, {
       StyleBox[
        StyleBox["\"Mars\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 
       StyleBox[
        RowBox[{"{", "\[ThinSpace]", "\[ThinSpace]", "}"}], LineBreakWithin -> 
        Automatic]}, {
       StyleBox[
        StyleBox["\"Jupiter\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 
       StyleBox[
        RowBox[{"{", "\[ThinSpace]", 
          StyleBox["\"Ganymede\"", FontColor -> GrayLevel[0.4]], ",", 
          StyleBox["\"Callisto\"", FontColor -> GrayLevel[0.4]], ",", 
          StyleBox["\"Io\"", FontColor -> GrayLevel[0.4]], "\[ThinSpace]", 
          "}"}], LineBreakWithin -> Automatic]}, {
       StyleBox[
        StyleBox["\"Saturn\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 
       StyleBox[
        RowBox[{"{", "\[ThinSpace]", 
          StyleBox["\"Titan\"", FontColor -> GrayLevel[0.4]], "\[ThinSpace]", 
          "}"}], LineBreakWithin -> Automatic]}, {
       StyleBox[
        StyleBox["\"Uranus\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 
       StyleBox[
        RowBox[{"{", "\[ThinSpace]", "\[ThinSpace]", "}"}], LineBreakWithin -> 
        Automatic]}, {
       StyleBox[
        StyleBox["\"Neptune\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 
       StyleBox[
        RowBox[{"{", "\[ThinSpace]", "\[ThinSpace]", "}"}], LineBreakWithin -> 
        Automatic]}, {
       ItemBox[
        RowBox[{"2 levels", 
          AdjustmentBox[" | ", BoxBaselineShift -> -0.3], 
          RowBox[{"8", "rows"}]}], 
        BaseStyle -> {
         FontFamily -> "Helvetica", FontSize -> 10, FontColor -> 
          GrayLevel[0.4], Editable -> False, Selectable -> False}, 
        ItemSize -> {Automatic, Automatic}, Alignment -> {Left, Center}, 
        Background -> RGBColor[0.92, 0.92, 0.9]], "\[SpanFromLeft]"}}, 
     GridBoxFrame -> {"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}}, 
     FrameStyle -> RGBColor[0, 0, 0, 0.4], GridBoxDividers -> {"Columns" -> {
         RGBColor[0, 0, 0, 0.4], 
         RGBColor[0, 0, 0, 0.3], {
          RGBColor[0, 0, 0, 0.09]}, 
         RGBColor[0, 0, 0, 0.4]}, "Rows" -> {
         RGBColor[0, 0, 0, 0.4], {
          RGBColor[0, 0, 0, 0.08]}, 
         RGBColor[0, 0, 0, 0.4]}}, RowSpacings -> 1.2, 
     GridBoxBackground -> {"Columns" -> {
         RGBColor[0.92, 0.92, 0.9]}}, 
     GridBoxAlignment -> {"Columns" -> {{Left}}}, ColumnSpacings -> 2.5, 
     GridFrameMargins -> {{2, 3}, {1, 3}}, 
     GridBoxItemSize -> {"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
      RowMinHeight -> 1.3],"Dataset[Association[(_String -> _List)..]]"},
   "Dataset",
   DisplayFunction->(TagBox[
     StyleBox[#, {
      ShowAutoStyles -> False, LineBreakWithin -> False, FontWeight -> 
       "Light", FontFamily -> "Helvetica Neue", NumberMarks -> False, 
       SpanMaxSize -> 3, SpanMinSize -> 1., Editable -> False, Selectable -> 
       True, Background -> RGBColor[0.985, 0.98, 0.973], 
       LinebreakAdjustments -> {0.4, 5, 100, 0, 0.5}, LineIndent -> 0, 
       LineSpacing -> {1.1, 5}}], Deploy]& ),
   InterpretationFunction->(#2& )],
  False,
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[38]=",ExpressionUUID->"6b8812e4-10be-4b1d-98de-c67a42283330"]
}, Open  ]],

Cell["Get the underlying association:", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"p:279",ExpressionUUID->"d667f47e-2343-439f-aadd-106948d262f2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Normal", "[", "%", "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[39]:=",ExpressionUUID->"09c76102-2928-4699-8c71-0ac0350fef5e"],

Cell[BoxData[
 RowBox[{"\[LeftAssociation]", 
  RowBox[{
   RowBox[{"\<\"Mercury\"\>", "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{"\<\"Venus\"\>", "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{"\<\"Earth\"\>", "\[Rule]", 
    RowBox[{"{", "\<\"Moon\"\>", "}"}]}], ",", 
   RowBox[{"\<\"Mars\"\>", "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{"\<\"Jupiter\"\>", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\<\"Ganymede\"\>", ",", "\<\"Callisto\"\>", ",", "\<\"Io\"\>"}],
      "}"}]}], ",", 
   RowBox[{"\<\"Saturn\"\>", "\[Rule]", 
    RowBox[{"{", "\<\"Titan\"\>", "}"}]}], ",", 
   RowBox[{"\<\"Uranus\"\>", "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{"\<\"Neptune\"\>", "\[Rule]", 
    RowBox[{"{", "}"}]}]}], "\[RightAssociation]"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[39]=",ExpressionUUID->"0c54008a-59d3-4c05-a380-4c09026a3d01"]
}, Open  ]],

Cell[TextData[{
 ButtonBox["Catenate",
  BaseStyle->"Link"],
 " the lists for all keys:"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:18",ExpressionUUID->"af3b7c15-ac0c-4139-aafc-7dcfe95aac0e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Catenate", "[", "%", "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[40]:=",ExpressionUUID->"9a119d97-05bd-40d3-8a6e-2e1853f9e5b8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"Moon\"\>", ",", "\<\"Ganymede\"\>", ",", "\<\"Callisto\"\>", 
   ",", "\<\"Io\"\>", ",", "\<\"Titan\"\>"}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[40]=",ExpressionUUID->"fb7b5436-f5fd-401d-a6a2-a1e795817dd1"]
}, Open  ]],

Cell["Here\[CloseCurlyQuote]s the whole computation in one line:", \
"CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"3156023d-8266-40c1-a8a6-7b3cf38eefa2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"planets", "[", 
    RowBox[{"All", ",", "\"\<Moons\>\"", ",", 
     RowBox[{"Select", "[", 
      RowBox[{
       RowBox[{"#Mass", ">", 
        NamespaceBox["LinguisticAssistant",
         DynamicModuleBox[{Typeset`query$$ = "1/100 earth mass", 
          Typeset`boxes$$ = TemplateBox[{"0.01", 
            SubscriptBox[
             StyleBox["\"M\"", Italic, StripOnInput -> False], 
             "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, "Quantity", 
           SyntaxForm -> Mod], Typeset`allassumptions$$ = {}, 
          Typeset`assumptions$$ = {}, Typeset`open$$ = {1, 2}, 
          Typeset`querystate$$ = {
          "Online" -> True, "Allowed" -> True, "mparse.jsp" -> 
           1.23332`6.542620767742447, "Messages" -> {}}}, 
          DynamicBox[ToBoxes[
            AlphaIntegration`LinguisticAssistantBoxes["", 4, Automatic, 
             Dynamic[Typeset`query$$], 
             Dynamic[Typeset`boxes$$], 
             Dynamic[Typeset`allassumptions$$], 
             Dynamic[Typeset`assumptions$$], 
             Dynamic[Typeset`open$$], 
             Dynamic[Typeset`querystate$$]], StandardForm],
           ImageSizeCache->{94., {10., 18.}},
           
           TrackedSymbols:>{
            Typeset`query$$, Typeset`boxes$$, Typeset`allassumptions$$, 
             Typeset`assumptions$$, Typeset`open$$, Typeset`querystate$$}],
          DynamicModuleValues:>{},
          UndoTrackedVariables:>{Typeset`open$$}],
         BaseStyle->{"Deploy"},
         DeleteWithContents->True,
         Editable->False,
         SelectWithContents->True]}], "&"}], "]"}]}], "]"}], "[", 
   RowBox[{"Catenate", ",", "Keys"}], "]"}], "//", "Normal"}]], "Input",
 Deletable->False,
 CellLabel->"In[41]:=",ExpressionUUID->"d030d232-b71a-4a10-af20-5ee305193c44"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"Moon\"\>", ",", "\<\"Ganymede\"\>", ",", "\<\"Callisto\"\>", 
   ",", "\<\"Io\"\>", ",", "\<\"Titan\"\>"}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[41]=",ExpressionUUID->"4a8544b5-f763-4874-8e10-4da1563839b0"]
}, Open  ]],

Cell["\<\
Here\[CloseCurlyQuote]s one more example, where we find the logarithm of the \
mass of each moon, then make a number line plot of these values for each \
planet.\
\>", "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:19",ExpressionUUID->"d26353e7-5861-46b6-a125-d5a9784022b7"],

Cell["\<\
Make number line plots of the logarithms of masses for moons of each planet:\
\>", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"14030172-864a-4046-810b-f1b27d8b24f8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"planets", "[", 
  RowBox[{"All", ",", "\"\<Moons\>\"", ",", 
   RowBox[{
    RowBox[{"NumberLinePlot", "[", 
     RowBox[{"Values", "[", "#", "]"}], "]"}], "&"}], ",", 
   RowBox[{
    RowBox[{"Log", "[", 
     RowBox[{"#Mass", "/", 
      NamespaceBox["LinguisticAssistant",
       DynamicModuleBox[{Typeset`query$$ = "1 earth mass", Typeset`boxes$$ = 
        TemplateBox[{"1", 
          SubscriptBox[
           StyleBox["\"M\"", Italic, StripOnInput -> False], "\"\[Earth]\""], 
          "Earth masses", "\"EarthMass\""}, "Quantity", SyntaxForm -> Mod], 
        Typeset`allassumptions$$ = {}, Typeset`assumptions$$ = {}, 
        Typeset`open$$ = {1, 2}, Typeset`querystate$$ = {
        "Online" -> True, "Allowed" -> True, "mparse.jsp" -> 
         1.21194`6.535026113067228, "Messages" -> {}}}, 
        DynamicBox[ToBoxes[
          AlphaIntegration`LinguisticAssistantBoxes["", 4, Automatic, 
           Dynamic[Typeset`query$$], 
           Dynamic[Typeset`boxes$$], 
           Dynamic[Typeset`allassumptions$$], 
           Dynamic[Typeset`assumptions$$], 
           Dynamic[Typeset`open$$], 
           Dynamic[Typeset`querystate$$]], StandardForm],
         ImageSizeCache->{75., {10., 18.}},
         TrackedSymbols:>{
          Typeset`query$$, Typeset`boxes$$, Typeset`allassumptions$$, 
           Typeset`assumptions$$, Typeset`open$$, Typeset`querystate$$}],
        DynamicModuleValues:>{},
        UndoTrackedVariables:>{Typeset`open$$}],
       BaseStyle->{"Deploy"},
       DeleteWithContents->True,
       Editable->False,
       SelectWithContents->True]}], "]"}], "&"}]}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[42]:=",ExpressionUUID->"a4cc2b28-35c2-4928-9400-5876f92a2d34"],

Cell[BoxData[
 TagBox[
  TemplateBox[{GridBox[{{
       StyleBox[
        StyleBox["\"Mercury\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 
       InterpretationBox[
        GraphicsBox[{}, {
         PlotRangeClipping -> True, Frame -> True, FrameStyle -> 
          GrayLevel[0.85], Ticks -> None, FrameTicks -> None, Axes -> None, 
          ImageSize -> 96, AxesLabel -> {None}, 
          Ticks -> {Automatic, Automatic}, 
          FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
          PlotRange -> {{-3., 3.}, {0, 1}}, PlotRangePadding -> {{
             Scaled[0.1], 
             Scaled[0.1]}, {0, 0}}, AspectRatio -> 
          NCache[Rational[1, 10]/GoldenRatio, 0.06180339887498948], 
          AxesOrigin -> {Automatic, Automatic}, Axes -> {True, False}, 
          ImagePadding -> All}], 
        Graphics[{}, AxesLabel -> {None}, Ticks -> {Automatic, Automatic}, 
         FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
         PlotRange -> {{-3., 3.}, {0, 1}}, PlotRangePadding -> {{
            Scaled[0.1], 
            Scaled[0.1]}, {0, 0}}, AspectRatio -> Rational[1, 10]/GoldenRatio,
          AxesOrigin -> {Automatic, Automatic}, Axes -> {True, False}, 
         ImagePadding -> All, {}]]}, {
       StyleBox[
        StyleBox["\"Venus\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 
       InterpretationBox[
        GraphicsBox[{}, {
         PlotRangeClipping -> True, Frame -> True, FrameStyle -> 
          GrayLevel[0.85], Ticks -> None, FrameTicks -> None, Axes -> None, 
          ImageSize -> 96, AxesLabel -> {None}, 
          Ticks -> {Automatic, Automatic}, 
          FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
          PlotRange -> {{-3., 3.}, {0, 1}}, PlotRangePadding -> {{
             Scaled[0.1], 
             Scaled[0.1]}, {0, 0}}, AspectRatio -> 
          NCache[Rational[1, 10]/GoldenRatio, 0.06180339887498948], 
          AxesOrigin -> {Automatic, Automatic}, Axes -> {True, False}, 
          ImagePadding -> All}], 
        Graphics[{}, AxesLabel -> {None}, Ticks -> {Automatic, Automatic}, 
         FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
         PlotRange -> {{-3., 3.}, {0, 1}}, PlotRangePadding -> {{
            Scaled[0.1], 
            Scaled[0.1]}, {0, 0}}, AspectRatio -> Rational[1, 10]/GoldenRatio,
          AxesOrigin -> {Automatic, Automatic}, Axes -> {True, False}, 
         ImagePadding -> All, {}]]}, {
       StyleBox[
        StyleBox["\"Earth\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 
       InterpretationBox[
        GraphicsBox[{{
           RGBColor[0.24720000000000014`, 0.24, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-4.398142899775445, 1}]}}}, {
         PlotRangeClipping -> True, Frame -> True, FrameStyle -> 
          GrayLevel[0.85], Ticks -> None, FrameTicks -> None, Axes -> None, 
          ImageSize -> 96, AxesLabel -> {None}, 
          Ticks -> {Automatic, Automatic}, 
          FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
          PlotRange -> {{-4.398142899775445, 8.79628579955089}, {0, 1}}, 
          PlotRangePadding -> {{
             Scaled[0.1], 
             Scaled[0.1]}, {0, 1}}, AspectRatio -> 
          NCache[Rational[1, 10]/GoldenRatio, 0.06180339887498948], 
          AxesOrigin -> {Automatic, Automatic}, Axes -> {True, False}, 
          ImagePadding -> All}], 
        Graphics[{{
           RGBColor[0.24720000000000014`, 0.24, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-4.3981428997754451606`5.638518180296832, 1}]}}}, 
         AxesLabel -> {None}, Ticks -> {Automatic, Automatic}, 
         FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
         PlotRange -> {{-4.398142899775445, 8.79628579955089}, {0, 1}}, 
         PlotRangePadding -> {{
            Scaled[0.1], 
            Scaled[0.1]}, {0, 1}}, AspectRatio -> Rational[1, 10]/GoldenRatio,
          AxesOrigin -> {Automatic, Automatic}, Axes -> {True, False}, 
         ImagePadding -> All, {}]]}, {
       StyleBox[
        StyleBox["\"Mars\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 
       InterpretationBox[
        GraphicsBox[{{
           RGBColor[0.24720000000000014`, 0.24, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-20.137814612839865`, 1}]}}, {
           RGBColor[0.6, 0.24, 0.4428931686004542], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-22.12624793250122, 1}]}}}, {
         PlotRangeClipping -> True, Frame -> True, FrameStyle -> 
          GrayLevel[0.85], Ticks -> None, FrameTicks -> None, Axes -> None, 
          ImageSize -> 96, AxesLabel -> {None}, 
          Ticks -> {Automatic, Automatic}, 
          FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
          PlotRange -> {{-22.12624793250122, -20.137814612839865`}, {0, 1}}, 
          PlotRangePadding -> {{
             Scaled[0.1], 
             Scaled[0.1]}, {0, 1}}, AspectRatio -> 
          NCache[Rational[1, 10]/GoldenRatio, 0.06180339887498948], 
          AxesOrigin -> {Automatic, Automatic}, Axes -> {True, False}, 
          ImagePadding -> All}], 
        Graphics[{{
           RGBColor[0.24720000000000014`, 0.24, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-20.1378146128398643037`5.26258017377757, 1}]}}, {
           RGBColor[0.6, 0.24, 0.4428931686004542], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-22.1262479325012178133`3.3444732631675422, 1}]}}}, 
         AxesLabel -> {None}, Ticks -> {Automatic, Automatic}, 
         FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
         PlotRange -> {{-22.12624793250122, -20.137814612839865`}, {0, 1}}, 
         PlotRangePadding -> {{
            Scaled[0.1], 
            Scaled[0.1]}, {0, 1}}, AspectRatio -> Rational[1, 10]/GoldenRatio,
          AxesOrigin -> {Automatic, Automatic}, Axes -> {True, False}, 
         ImagePadding -> All, {}]]}, {
       StyleBox[
        StyleBox["\"Jupiter\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 
       InterpretationBox[
        GraphicsBox[{{
           RGBColor[0.24720000000000014`, 0.24, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-3.696644461676854, 1}]}}, {
           RGBColor[0.6, 0.24, 0.4428931686004542], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-4.016749221138189, 1}]}}, {
           RGBColor[0.6, 0.5470136627990908, 0.24], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-4.202893187207173, 1}]}}, {
           RGBColor[0.24, 0.6, 0.33692049419863584`], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-4.823943193025306, 1}]}}, {
           RGBColor[0.24, 0.3531726744018182, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-13.694212549425288`, 1}]}}, {
           RGBColor[0.6, 0.24, 0.5632658430022722], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-14.876206447032448`, 1}]}}, {
           RGBColor[0.6, 0.42664098839727194`, 0.24], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-15.19828994620156, 1}]}}, {
           RGBColor[0.2634521802031821, 0.6, 0.24], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-15.743017121643234`, 1}]}}, {
           RGBColor[0.24, 0.47354534880363613`, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-16.807727858635662`, 1}]}}, {
           RGBColor[0.5163614825959097, 0.24, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-17.628708410705492`, 1}]}}, {
           RGBColor[0.6, 0.3062683139954558, 0.24], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-17.724018590509818`, 1}]}}, {
           RGBColor[0.3838248546049982, 0.6, 0.24], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-18.194022219755553`, 1}]}}, {
           RGBColor[0.24, 0.5939180232054561, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-18.36837560690033, 1}]}}, {
           RGBColor[0.39598880819409377`, 0.24, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-19.11031295162971, 1}]}}, {
           RGBColor[0.6, 0.24, 0.2941043604063603], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-20.118170877029353`, 1}]}}, {
           RGBColor[0.5041975290068142, 0.6, 0.24], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-20.4966073127496, 1}]}}, {
           RGBColor[0.24, 0.6, 0.48570930239273163`], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-22.65077240062537, 1}]}}, {
           RGBColor[0.2756161337922776, 0.24, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-22.873856958478196`, 1}]}}, {
           RGBColor[0.6, 0.24, 0.4144770348081764], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-23.343919581185315`, 1}]}}, {
           RGBColor[0.6, 0.5754297965913696, 0.24], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-24.07215808155653, 1}]}}, {
           RGBColor[0.24, 0.6, 0.36533662799091565`], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-24.146266053710253`, 1}]}}, {
           RGBColor[0.24, 0.32475654060953846`, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-24.146266053710253`, 1}]}}, {
           RGBColor[0.6, 0.24, 0.5348497092099924], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-24.31332013837342, 1}]}}, {
           RGBColor[0.6, 0.45505712218955346`, 0.24], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-24.631773869491955`, 1}]}}, {
           RGBColor[0.24, 0.6, 0.24496395358909184`], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-24.95329850015803, 1}]}}, {
           RGBColor[0.24, 0.4451292150113622, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-24.95329850015803, 1}]}}, {
           RGBColor[0.5447776163881838, 0.24, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-24.95329850015803, 1}]}}, {
           RGBColor[0.6, 0.3346844477877375, 0.24], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-25.10177749873769, 1}]}}, {
           RGBColor[0.35540872081272423`, 0.6, 0.24], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-25.10177749873769, 1}]}}, {
           RGBColor[0.24, 0.5655018894131706, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-25.646445680717978`, 1}]}}, {
           RGBColor[0.42440494198636775`, 0.24, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-25.646445680717978`, 1}]}}, {
           RGBColor[0.6, 0.24, 0.26568822661407865`], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-25.646445680717978`, 1}]}}, {
           RGBColor[0.4757813952145403, 0.6, 0.24], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-25.646445680717978`, 1}]}}, {
           RGBColor[0.24, 0.6, 0.514125436184998], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-26.71121541117179, 1}]}}, {
           RGBColor[0.3040322675845516, 0.24, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-26.71121541117179, 1}]}}, {
           RGBColor[0.6, 0.24, 0.3860609010159101], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-26.71121541117179, 1}]}}, {
           RGBColor[0.5961540696163564, 0.6, 0.24], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-26.71121541117179, 1}]}}, {
           RGBColor[0.24, 0.6, 0.39375276178318186`], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-26.71121541117179, 1}]}}}, {
         PlotRangeClipping -> True, Frame -> True, FrameStyle -> 
          GrayLevel[0.85], Ticks -> None, FrameTicks -> None, Axes -> None, 
          ImageSize -> 96, AxesLabel -> {None}, 
          Ticks -> {Automatic, Automatic}, 
          FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
          PlotRange -> {{-26.71121541117179, -3.696644461676854}, {0, 1}}, 
          PlotRangePadding -> {{
             Scaled[0.1], 
             Scaled[0.1]}, {0, 1}}, AspectRatio -> 
          NCache[Rational[1, 10]/GoldenRatio, 0.06180339887498948], 
          AxesOrigin -> {Automatic, Automatic}, Axes -> {True, False}, 
          ImagePadding -> All}], 
        Graphics[{{
           RGBColor[0.24720000000000014`, 0.24, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-3.696644461676854071`5.563056527127905, 1}]}}, {
           RGBColor[0.6, 0.24, 0.4428931686004542], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-4.0167492211381895566`5.599123562554503, 1}]}}, {
           RGBColor[0.6, 0.5470136627990908, 0.24], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-4.2028931872071725122`5.618797197346639, 1}]}}, {
           RGBColor[0.24, 0.6, 0.33692049419863584`], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-4.8239431930253055486`5.678651029299618, 1}]}}, {
           RGBColor[0.24, 0.3531726744018182, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-13.6942125494252872395`3.136102552977773, 1}]}}, {
           RGBColor[0.6, 0.24, 0.5632658430022722], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-14.8762064470324479892`4.168166523016045, 1}]}}, {
           RGBColor[0.6, 0.42664098839727194`, 0.24], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-15.1982899462015613129`3.181360214190064, 1}]}}, {
           RGBColor[0.2634521802031821, 0.6, 0.24], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-15.7430171216432333443`3.196653456436358, 1}]}}, {
           RGBColor[0.24, 0.47354534880363613`, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-16.8077278586356616875`3.225074496260832, 1}]}}, {
           RGBColor[0.5163614825959097, 0.24, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-17.6287084107054918925`3.245785982998642, 1}]}}, {
           RGBColor[0.6, 0.3062683139954558, 0.24], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-17.724018590509816752`2.248518726184107, 1}]}}, {
           RGBColor[0.3838248546049982, 0.6, 0.24], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-18.1940222197555523062`3.259494209424789, 1}]}}, {
           RGBColor[0.24, 0.5939180232054561, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-18.3683756069003300591`3.263636240167375, 1}]}}, {
           RGBColor[0.39598880819409377`, 0.24, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-19.1103129516297073715`3.280833287805982, 1}]}}, {
           RGBColor[0.6, 0.24, 0.2941043604063603], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-20.1181708770293529198`3.303153981240803, 1}]}}, {
           RGBColor[0.5041975290068142, 0.6, 0.24], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-20.4966073127495979902`2.3116385099982404, 1}]}}, {
           RGBColor[0.24, 0.6, 0.48570930239273163`], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-22.6507724006253703963`3.354648504881535, 1}]}}, {
           RGBColor[0.2756161337922776, 0.24, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-22.8738569584781952108`3.358904889583309, 1}]}}, {
           RGBColor[0.6, 0.24, 0.4144770348081764], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-23.3439195811853157053`3.3677392670861326, 1}]}}, {
           RGBColor[0.6, 0.5754297965913696, 0.24], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-24.0721580815565311183`3.38108051540802, 1}]}}, {
           RGBColor[0.24, 0.6, 0.36533662799091565`], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-24.1462660537102529968`3.382415470222081, 1}]}}, {
           RGBColor[0.24, 0.32475654060953846`, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-24.1462660537102529968`3.382415470222081, 1}]}}, {
           RGBColor[0.6, 0.24, 0.5348497092099924], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-24.3133201383734191886`3.385409757224669, 1}]}}, {
           RGBColor[0.6, 0.45505712218955346`, 0.24], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-24.6317738694919538046`2.391452218197295, 1}]}}, {
           RGBColor[0.24, 0.6, 0.24496395358909184`], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-24.9532985001580311389`2.3823868548245044, 1}]}}, {
           RGBColor[0.24, 0.4451292150113622, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-24.9532985001580311389`2.3823868548245044, 1}]}}, {
           RGBColor[0.5447776163881838, 0.24, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-24.9532985001580311389`2.3823868548245044, 1}]}}, {
           RGBColor[0.6, 0.3346844477877375, 0.24], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-25.1017774987376893583`2.39966100498469, 1}]}}, {
           RGBColor[0.35540872081272423`, 0.6, 0.24], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-25.1017774987376893583`2.39966100498469, 1}]}}, {
           RGBColor[0.24, 0.5655018894131706, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-25.646445680717976449`2.394286078124212, 1}]}}, {
           RGBColor[0.42440494198636775`, 0.24, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-25.646445680717976449`2.394286078124212, 1}]}}, {
           RGBColor[0.6, 0.24, 0.26568822661407865`], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-25.646445680717976449`2.394286078124212, 1}]}}, {
           RGBColor[0.4757813952145403, 0.6, 0.24], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-25.646445680717976449`2.394286078124212, 1}]}}, {
           RGBColor[0.24, 0.6, 0.514125436184998], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-26.7112154111717897329`2.426650178995036, 1}]}}, {
           RGBColor[0.3040322675845516, 0.24, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-26.7112154111717897329`2.426650178995036, 1}]}}, {
           RGBColor[0.6, 0.24, 0.3860609010159101], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-26.7112154111717897329`2.426650178995036, 1}]}}, {
           RGBColor[0.5961540696163564, 0.6, 0.24], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-26.7112154111717897329`2.426650178995036, 1}]}}, {
           RGBColor[0.24, 0.6, 0.39375276178318186`], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-26.7112154111717897329`2.426650178995036, 1}]}}}, 
         AxesLabel -> {None}, Ticks -> {Automatic, Automatic}, 
         FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
         PlotRange -> {{-26.71121541117179, -3.696644461676854}, {0, 1}}, 
         PlotRangePadding -> {{
            Scaled[0.1], 
            Scaled[0.1]}, {0, 1}}, AspectRatio -> Rational[1, 10]/GoldenRatio,
          AxesOrigin -> {Automatic, Automatic}, Axes -> {True, False}, 
         ImagePadding -> All, {}]]}, {
       StyleBox[
        StyleBox["\"Saturn\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 
       InterpretationBox[
        GraphicsBox[{{
           RGBColor[0.24720000000000014`, 0.24, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-3.7931512712470643`, 1}]}}, {
           RGBColor[0.6, 0.24, 0.4428931686004542], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-7.858297808613832, 1}]}}, {
           RGBColor[0.6, 0.5470136627990908, 0.24], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-8.104055100276806, 1}]}}, {
           RGBColor[0.24, 0.6, 0.33692049419863584`], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-8.603698663685897, 1}]}}, {
           RGBColor[0.24, 0.3531726744018182, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-9.177023907856789, 1}]}}, {
           RGBColor[0.6, 0.24, 0.5632658430022722], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-10.920235901910658`, 1}]}}, {
           RGBColor[0.6, 0.42664098839727194`, 0.24], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-11.967485550468087`, 1}]}}, {
           RGBColor[0.2634521802031821, 0.6, 0.24], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-13.48792131518902, 1}]}}, {
           RGBColor[0.24, 0.47354534880363613`, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-13.889957126551382`, 1}]}}, {
           RGBColor[0.5163614825959097, 0.24, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-14.962427622479577`, 1}]}}, {
           RGBColor[0.6, 0.3062683139954558, 0.24], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-16.245259001717834`, 1}]}}, {
           RGBColor[0.3838248546049982, 0.6, 0.24], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-17.280936618830346`, 1}]}}, {
           RGBColor[0.24, 0.5939180232054561, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-17.505887581019152`, 1}]}}, {
           RGBColor[0.39598880819409377`, 0.24, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-18.847948687162216`, 1}]}}, {
           RGBColor[0.6, 0.24, 0.2941043604063603], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-19.272831881127484`, 1}]}}, {
           RGBColor[0.5041975290068142, 0.6, 0.24], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-19.46698789556844, 1}]}}, {
           RGBColor[0.24, 0.6, 0.48570930239273163`], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-20.401297132945274`, 1}]}}, {
           RGBColor[0.2756161337922776, 0.24, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-20.537429307269853`, 1}]}}, {
           RGBColor[0.6, 0.24, 0.4144770348081764], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-20.912122756711263`, 1}]}}, {
           RGBColor[0.6, 0.5754297965913696, 0.24], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-20.912122756711263`, 1}]}}, {
           RGBColor[0.24, 0.6, 0.36533662799091565`], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-21.230576487829797`, 1}]}}, {
           RGBColor[0.24, 0.32475654060953846`, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-21.31758786481943, 1}]}}, {
           RGBColor[0.6, 0.24, 0.5348497092099924], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-21.51825856028158, 1}]}}, {
           RGBColor[0.6, 0.45505712218955346`, 0.24], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-21.769572988562487`, 1}]}}, {
           RGBColor[0.24, 0.6, 0.24496395358909184`], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-22.329188776497908`, 1}]}}, {
           RGBColor[0.24, 0.4451292150113622, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-22.779389778447463`, 1}]}}, {
           RGBColor[0.5447776163881838, 0.24, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-23.56700413903814, 1}]}}, {
           RGBColor[0.6, 0.3346844477877375, 0.24], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-23.666692973448367`, 1}]}}, {
           RGBColor[0.35540872081272423`, 0.6, 0.24], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-24.07215808155653, 1}]}}, {
           RGBColor[0.24, 0.5655018894131706, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-24.07215808155653, 1}]}}, {
           RGBColor[0.42440494198636775`, 0.24, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-24.07215808155653, 1}]}}, {
           RGBColor[0.6, 0.24, 0.26568822661407865`], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-24.407500956147185`, 1}]}}, {
           RGBColor[0.4757813952145403, 0.6, 0.24], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-27.725887222397812`, 1}]}}}, {
         PlotRangeClipping -> True, Frame -> True, FrameStyle -> 
          GrayLevel[0.85], Ticks -> None, FrameTicks -> None, Axes -> None, 
          ImageSize -> 96, AxesLabel -> {None}, 
          Ticks -> {Automatic, Automatic}, 
          FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
          PlotRange -> {{-27.725887222397812`, -3.7931512712470643`}, {0, 1}},
           PlotRangePadding -> {{
             Scaled[0.1], 
             Scaled[0.1]}, {0, 1}}, AspectRatio -> 
          NCache[Rational[1, 10]/GoldenRatio, 0.06180339887498948], 
          AxesOrigin -> {Automatic, Automatic}, Axes -> {True, False}, 
          ImagePadding -> All}], 
        Graphics[{{
           RGBColor[0.24720000000000014`, 0.24, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-3.7931512712470640938`5.537212843783208, 1}]}}, {
           RGBColor[0.6, 0.24, 0.4428931686004542], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-7.8582978086138320245`5.594081394758751, 1}]}}, {
           RGBColor[0.6, 0.5470136627990908, 0.24], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-8.1040551002768059345`5.607455296537437, 1}]}}, {
           RGBColor[0.24, 0.6, 0.33692049419863584`], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-8.6036986636858966565`5.6334381025968625, 1}]}}, {
           RGBColor[0.24, 0.3531726744018182, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-9.1770239078567896465`5.661454774487632, 1}]}}, {
           RGBColor[0.6, 0.24, 0.5632658430022722], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-10.9202359019106579209`4.996799855537492, 1}]}}, {
           RGBColor[0.6, 0.42664098839727194`, 0.24], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-11.9674855504680867621`5.03657074710725, 1}]}}, {
           RGBColor[0.2634521802031821, 0.6, 0.24], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-13.4879213151890203462`5.08851285905363, 1}]}}, {
           RGBColor[0.24, 0.47354534880363613`, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-13.8899571265513825526`3.142266393884516, 1}]}}, {
           RGBColor[0.5163614825959097, 0.24, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-14.9624276224795768684`5.133569897933285, 1}]}}, {
           RGBColor[0.6, 0.3062683139954558, 0.24], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-16.2452590017178325547`4.206400966081399, 1}]}}, {
           RGBColor[0.3838248546049982, 0.6, 0.24], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-17.280936618830345596`5.1961351126620405, 1}]}}, {
           RGBColor[0.24, 0.5939180232054561, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-17.5058875810191512789`4.238858461489541, 1}]}}, {
           RGBColor[0.39598880819409377`, 0.24, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-18.8479486871622163194`3.274829579418357, 1}]}}, {
           RGBColor[0.6, 0.24, 0.2941043604063603], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-19.2728318811274822846`3.2845110216855473, 1}]}}, {
           RGBColor[0.5041975290068142, 0.6, 0.24], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-19.4669878955684397503`3.288864247497632, 1}]}}, {
           RGBColor[0.24, 0.6, 0.48570930239273163`], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-20.4012971329452731301`3.3092232698004556, 1}]}}, {
           RGBColor[0.2756161337922776, 0.24, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-20.5374293072698531198`3.3121115702030752, 1}]}}, {
           RGBColor[0.6, 0.24, 0.4144770348081764], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-20.9121227567112638136`3.3199636082658146, 1}]}}, {
           RGBColor[0.6, 0.5754297965913696, 0.24], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-20.9121227567112638136`3.3199636082658146, 1}]}}, {
           RGBColor[0.24, 0.6, 0.36533662799091565`], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-21.2305764878297984294`3.3265272756705655, 1}]}}, {
           RGBColor[0.24, 0.32475654060953846`, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-21.3175878648194281954`3.328303550353271, 1}]}}, {
           RGBColor[0.6, 0.24, 0.5348497092099924], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-21.5182585602815793629`3.332372610289269, 1}]}}, {
           RGBColor[0.6, 0.45505712218955346`, 0.24], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-21.7695729885624854343`3.337415399073448, 1}]}}, {
           RGBColor[0.24, 0.6, 0.24496395358909184`], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-22.3291887764979081206`3.348438434020561, 1}]}}, {
           RGBColor[0.24, 0.4451292150113622, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-22.7793897784474639614`3.357107574540216, 1}]}}, {
           RGBColor[0.5447776163881838, 0.24, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-23.5670041390381405202`3.371869866747676, 1}]}}, {
           RGBColor[0.6, 0.3346844477877375, 0.24], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-23.6666929734483667365`3.3737030654012545, 1}]}}, {
           RGBColor[0.35540872081272423`, 0.6, 0.24], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-24.0721580815565311183`3.38108051540802, 1}]}}, {
           RGBColor[0.24, 0.5655018894131706, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-24.0721580815565311183`3.38108051540802, 1}]}}, {
           RGBColor[0.42440494198636775`, 0.24, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-24.0721580815565311183`3.38108051540802, 1}]}}, {
           RGBColor[0.6, 0.24, 0.26568822661407865`], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-24.4075009561471856328`3.387522880701968, 1}]}}, {
           RGBColor[0.4757813952145403, 0.6, 0.24], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-27.7258872223978123766`2.442885408943656, 1}]}}}, 
         AxesLabel -> {None}, Ticks -> {Automatic, Automatic}, 
         FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
         PlotRange -> {{-27.725887222397812`, -3.7931512712470643`}, {0, 1}}, 
         PlotRangePadding -> {{
            Scaled[0.1], 
            Scaled[0.1]}, {0, 1}}, AspectRatio -> Rational[1, 10]/GoldenRatio,
          AxesOrigin -> {Automatic, Automatic}, Axes -> {True, False}, 
         ImagePadding -> All, {}]]}, {
       StyleBox[
        StyleBox["\"Uranus\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 
       InterpretationBox[
        GraphicsBox[{{
           RGBColor[0.24720000000000014`, 0.24, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-7.434843557474199, 1}]}}, {
           RGBColor[0.6, 0.24, 0.4428931686004542], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-7.591902556428909, 1}]}}, {
           RGBColor[0.6, 0.5470136627990908, 0.24], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-8.392567392784576, 1}]}}, {
           RGBColor[0.24, 0.6, 0.33692049419863584`], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-8.53643520565625, 1}]}}, {
           RGBColor[0.24, 0.3531726744018182, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-11.414100312283301`, 1}]}}, {
           RGBColor[0.6, 0.24, 0.5632658430022722], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-13.920137743701375`, 1}]}}, {
           RGBColor[0.6, 0.42664098839727194`, 0.24], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-14.540251942755184`, 1}]}}, {
           RGBColor[0.2634521802031821, 0.6, 0.24], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-15.083177139101057`, 1}]}}, {
           RGBColor[0.24, 0.47354534880363613`, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-15.911639834079025`, 1}]}}, {
           RGBColor[0.5163614825959097, 0.24, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-16.187151370910552`, 1}]}}, {
           RGBColor[0.6, 0.3062683139954558, 0.24], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-16.633774551512225`, 1}]}}, {
           RGBColor[0.3838248546049982, 0.6, 0.24], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-16.67232322162946, 1}]}}, {
           RGBColor[0.24, 0.5939180232054561, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-16.970246788133437`, 1}]}}, {
           RGBColor[0.39598880819409377`, 0.24, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-17.32692173207217, 1}]}}, {
           RGBColor[0.6, 0.24, 0.2941043604063603], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-17.978910840138607`, 1}]}}, {
           RGBColor[0.5041975290068142, 0.6, 0.24], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-18.522526286727587`, 1}]}}, {
           RGBColor[0.24, 0.6, 0.48570930239273163`], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-18.70484784352154, 1}]}}, {
           RGBColor[0.2756161337922776, 0.24, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-19.46698789556844, 1}]}}, {
           RGBColor[0.6, 0.24, 0.4144770348081764], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-19.46698789556844, 1}]}}, {
           RGBColor[0.6, 0.5754297965913696, 0.24], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-20.79441541679836, 1}]}}, {
           RGBColor[0.24, 0.6, 0.36533662799091565`], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-22.873856958478196`, 1}]}}}, {
         PlotRangeClipping -> True, Frame -> True, FrameStyle -> 
          GrayLevel[0.85], Ticks -> None, FrameTicks -> None, Axes -> None, 
          ImageSize -> 96, AxesLabel -> {None}, 
          Ticks -> {Automatic, Automatic}, 
          FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
          PlotRange -> {{-22.873856958478196`, -7.434843557474199}, {0, 1}}, 
          PlotRangePadding -> {{
             Scaled[0.1], 
             Scaled[0.1]}, {0, 1}}, AspectRatio -> 
          NCache[Rational[1, 10]/GoldenRatio, 0.06180339887498948], 
          AxesOrigin -> {Automatic, Automatic}, Axes -> {True, False}, 
          ImagePadding -> All}], 
        Graphics[{{
           RGBColor[0.24720000000000014`, 0.24, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-7.4348435574741988299`4.829839669934199, 1}]}}, {
           RGBColor[0.6, 0.24, 0.4428931686004542], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-7.5919025564289092665`4.838918460519162, 1}]}}, {
           RGBColor[0.6, 0.5470136627990908, 0.24], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-8.3925673927845758928`3.91956916363626, 1}]}}, {
           RGBColor[0.24, 0.6, 0.33692049419863584`], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-8.5364352056562502323`3.9269508745322015, 1}]}}, {
           RGBColor[0.24, 0.3531726744018182, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-11.41410031228330015`3.0570071736666056, 1}]}}, {
           RGBColor[0.6, 0.24, 0.5632658430022722], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-13.9201377437013738079`4.139317859055862, 1}]}}, {
           RGBColor[0.6, 0.42664098839727194`, 0.24], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-14.5402519427551839232`5.121139767042232, 1}]}}, {
           RGBColor[0.2634521802031821, 0.6, 0.24], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-15.0831771391010567398`5.137060666816805, 1}]}}, {
           RGBColor[0.24, 0.47354534880363613`, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-15.9116398340790260707`3.2012804284698295, 1}]}}, {
           RGBColor[0.5163614825959097, 0.24, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-16.1871513709105518086`4.204844754247083, 1}]}}, {
           RGBColor[0.6, 0.3062683139954558, 0.24], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-16.6337745515122236702`4.216665137201766, 1}]}}, {
           RGBColor[0.3838248546049982, 0.6, 0.24], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-16.6723232216294587164`4.217670447538994, 1}]}}, {
           RGBColor[0.24, 0.5939180232054561, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-16.9702467881334366006`4.225362484341375, 1}]}}, {
           RGBColor[0.39598880819409377`, 0.24, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-17.3269217320721689795`4.234395739929239, 1}]}}, {
           RGBColor[0.6, 0.24, 0.2941043604063603], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-17.9789108401386068095`3.254328867356432, 1}]}}, {
           RGBColor[0.5041975290068142, 0.6, 0.24], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-18.5225262867275883633`3.2672657084555405, 1}]}}, {
           RGBColor[0.24, 0.6, 0.48570930239273163`], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-18.7048478435215429895`3.271519668396445, 1}]}}, {
           RGBColor[0.2756161337922776, 0.24, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-19.4669878955684397503`3.288864247497632, 1}]}}, {
           RGBColor[0.6, 0.24, 0.4144770348081764], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-19.4669878955684397503`3.288864247497632, 1}]}}, {
           RGBColor[0.6, 0.5754297965913696, 0.24], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-20.7944154167983592825`2.285476841816446, 1}]}}, {
           RGBColor[0.24, 0.6, 0.36533662799091565`], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-22.8738569584781952108`2.326869526974671, 1}]}}}, 
         AxesLabel -> {None}, Ticks -> {Automatic, Automatic}, 
         FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
         PlotRange -> {{-22.873856958478196`, -7.434843557474199}, {0, 1}}, 
         PlotRangePadding -> {{
            Scaled[0.1], 
            Scaled[0.1]}, {0, 1}}, AspectRatio -> Rational[1, 10]/GoldenRatio,
          AxesOrigin -> {Automatic, Automatic}, Axes -> {True, False}, 
         ImagePadding -> All, {}]]}, {
       StyleBox[
        StyleBox["\"Neptune\"", FontColor -> GrayLevel[0.4]], 
        GrayLevel[0.3]], 
       InterpretationBox[
        GraphicsBox[{{
           RGBColor[0.24720000000000014`, 0.24, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-5.631744740771266, 1}]}}, {
           RGBColor[0.6, 0.24, 0.4428931686004542], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-11.683763879232403`, 1}]}}, {
           RGBColor[0.6, 0.5470136627990908, 0.24], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-12.172998870406026`, 1}]}}, {
           RGBColor[0.24, 0.6, 0.33692049419863584`], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-14.004367477729128`, 1}]}}, {
           RGBColor[0.24, 0.3531726744018182, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-14.281999214327406`, 1}]}}, {
           RGBColor[0.6, 0.24, 0.5632658430022722], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-14.861817709580349`, 1}]}}, {
           RGBColor[0.6, 0.42664098839727194`, 0.24], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-16.584584307321453`, 1}]}}, {
           RGBColor[0.2634521802031821, 0.6, 0.24], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            PointBox[{-17.238510774728116`, 1}]}}}, {
         PlotRangeClipping -> True, Frame -> True, FrameStyle -> 
          GrayLevel[0.85], Ticks -> None, FrameTicks -> None, Axes -> None, 
          ImageSize -> 96, AxesLabel -> {None}, 
          Ticks -> {Automatic, Automatic}, 
          FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
          PlotRange -> {{-17.238510774728116`, -5.631744740771266}, {0, 1}}, 
          PlotRangePadding -> {{
             Scaled[0.1], 
             Scaled[0.1]}, {0, 1}}, AspectRatio -> 
          NCache[Rational[1, 10]/GoldenRatio, 0.06180339887498948], 
          AxesOrigin -> {Automatic, Automatic}, Axes -> {True, False}, 
          ImagePadding -> All}], 
        Graphics[{{
           RGBColor[0.24720000000000014`, 0.24, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-5.6317447407712660682`5.4493958735158206, 1}]}}, {
           RGBColor[0.6, 0.24, 0.4428931686004542], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-11.6837638792324027628`4.063257097893104, 1}]}}, {
           RGBColor[0.6, 0.5470136627990908, 0.24], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-12.1729988704060259166`4.081071908009876, 1}]}}, {
           RGBColor[0.24, 0.6, 0.33692049419863584`], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-14.0043674777291267613`3.1458289868869547, 1}]}}, {
           RGBColor[0.24, 0.3531726744018182, 0.6], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-14.2819992143274062476`3.1543544935078915, 1}]}}, {
           RGBColor[0.6, 0.24, 0.5632658430022722], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-14.8618177095803483823`3.171637418741802, 1}]}}, {
           RGBColor[0.6, 0.42664098839727194`, 0.24], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-16.5845843073214519316`3.2192700790591084, 1}]}}, {
           RGBColor[0.2634521802031821, 0.6, 0.24], 
           PointSize[Medium], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], {
            Point[{-17.2385107747281159448`3.236065233312909, 1}]}}}, 
         AxesLabel -> {None}, Ticks -> {Automatic, Automatic}, 
         FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
         PlotRange -> {{-17.238510774728116`, -5.631744740771266}, {0, 1}}, 
         PlotRangePadding -> {{
            Scaled[0.1], 
            Scaled[0.1]}, {0, 1}}, AspectRatio -> Rational[1, 10]/GoldenRatio,
          AxesOrigin -> {Automatic, Automatic}, Axes -> {True, False}, 
         ImagePadding -> All, {}]]}, {
       ItemBox[
        RowBox[{"1 level", 
          AdjustmentBox[" | ", BoxBaselineShift -> -0.3], 
          RowBox[{"8", "elements"}]}], 
        BaseStyle -> {
         FontFamily -> "Helvetica", FontSize -> 10, FontColor -> 
          GrayLevel[0.4], Editable -> False, Selectable -> False}, 
        ItemSize -> {Automatic, Automatic}, Alignment -> {Left, Center}, 
        Background -> RGBColor[0.92, 0.92, 0.9]], "\[SpanFromLeft]"}}, 
     GridBoxFrame -> {"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}}, 
     FrameStyle -> RGBColor[0, 0, 0, 0.4], GridBoxDividers -> {"Columns" -> {
         RGBColor[0, 0, 0, 0.4], 
         RGBColor[0, 0, 0, 0.3], {
          RGBColor[0, 0, 0, 0.09]}, 
         RGBColor[0, 0, 0, 0.4]}, "Rows" -> {
         RGBColor[0, 0, 0, 0.4], {
          RGBColor[0, 0, 0, 0.08]}, 
         RGBColor[0, 0, 0, 0.4]}}, RowSpacings -> 1.2, 
     GridBoxBackground -> {"Columns" -> {
         RGBColor[0.92, 0.92, 0.9]}}, 
     GridBoxAlignment -> {"Columns" -> {{Left}}}, ColumnSpacings -> 2.5, 
     GridFrameMargins -> {{2, 3}, {1, 3}}, 
     GridBoxItemSize -> {"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
      RowMinHeight -> 1.3],"Dataset[Association[(_String -> _Graphics)..]]"},
   "Dataset",
   DisplayFunction->(TagBox[
     StyleBox[#, {
      ShowAutoStyles -> False, LineBreakWithin -> False, FontWeight -> 
       "Light", FontFamily -> "Helvetica Neue", NumberMarks -> False, 
       SpanMaxSize -> 3, SpanMinSize -> 1., Editable -> False, Selectable -> 
       True, Background -> RGBColor[0.985, 0.98, 0.973], 
       LinebreakAdjustments -> {0.4, 5, 100, 0, 0.5}, LineIndent -> 0, 
       LineSpacing -> {1.1, 5}}], Deploy]& ),
   InterpretationFunction->(#2& )],
  False,
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[42]=",ExpressionUUID->"e7103873-8150-484e-904b-49e270e14bd8"]
}, Open  ]],

Cell["\<\
As a final example, let\[CloseCurlyQuote]s make a word cloud of names of \
moons, sized according to the masses of the moons. To do this, we need a \
single association that associates the name of each moon with its mass. \
\>", "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->
  "LastCellOfAPage",ExpressionUUID->"fc0b1401-8adf-459c-97ea-e5f28b4c85ba"],

Cell[TextData[{
 "When given an association, ",
 ButtonBox["WordCloud",
  BaseStyle->"Link"],
 " determines sizes from values in the association:"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:20",ExpressionUUID->"ac918967-8049-4a40-b209-429ff1b5d81c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"WordCloud", "[", 
  RowBox[{"\[LeftAssociation]", 
   RowBox[{
    RowBox[{"\"\<A\>\"", "\[Rule]", "5"}], ",", 
    RowBox[{"\"\<B\>\"", "\[Rule]", "4"}], ",", 
    RowBox[{"\"\<C\>\"", "\[Rule]", "3"}], ",", 
    RowBox[{"\"\<D\>\"", "\[Rule]", "2"}], ",", 
    RowBox[{"\"\<E\>\"", "\[Rule]", "1"}]}], "\[RightAssociation]"}], 
  "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[43]:=",ExpressionUUID->"f2bd4855-efbd-4b95-8d88-b15e1b1aeadc"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     StyleBox["\<\"A\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.6666666666666667],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[0.368417, 0.506779, 0.709798]], {0, 0}], InsetBox[
     StyleBox["\<\"B\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.5238095238095238],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[0.880722, 0.611041, 0.142051]], {-33., 18.5}], 
    InsetBox[
     StyleBox["\<\"C\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.380952380952381],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[0.560181, 0.691569, 0.194885]], {30., 13.5}], 
    InsetBox[
     StyleBox["\<\"D\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.2380952380952381],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[0.922526, 0.385626, 0.209179]], {0., -25.5}], 
    InsetBox[
     StyleBox["\<\"E\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.09523809523809525],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[0.528488, 0.470624, 0.701351]], {-28., -5.5}]}},
  Background->GrayLevel[0, 0],
  ImageSize->{83.67578125, 91.},
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultPlotStyle" -> Automatic},
  PlotRange->{{-52.5, 52.5}, {-57., 57.}}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[43]=",ExpressionUUID->"274dd8f9-5b9a-4c22-9441-0b68670ba722"]
}, Open  ]],

Cell[TextData[{
 "The function ",
 ButtonBox["Association",
  BaseStyle->"Link"],
 " combines associations:"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:21",ExpressionUUID->"077d8b5a-d713-46af-af99-b847bb85496a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Association", "[", 
  RowBox[{
   RowBox[{"\[LeftAssociation]", 
    RowBox[{
     RowBox[{"\"\<a\>\"", "\[Rule]", "1"}], ",", 
     RowBox[{"\"\<b\>\"", "\[Rule]", "2"}]}], "\[RightAssociation]"}], ",", 
   RowBox[{"\[LeftAssociation]", 
    RowBox[{"\"\<c\>\"", "\[Rule]", "3"}], "\[RightAssociation]"}]}], 
  "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[44]:=",ExpressionUUID->"0e2f3e54-9878-482d-8b04-b0d7f0637d2d"],

Cell[BoxData[
 RowBox[{"\[LeftAssociation]", 
  RowBox[{
   RowBox[{"\<\"a\"\>", "\[Rule]", "1"}], ",", 
   RowBox[{"\<\"b\"\>", "\[Rule]", "2"}], ",", 
   RowBox[{"\<\"c\"\>", "\[Rule]", "3"}]}], "\[RightAssociation]"}]], "Output",\

 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[44]=",ExpressionUUID->"78abf2e1-db41-48e1-9bc5-b2df26ef1bcc"]
}, Open  ]],

Cell["Generate the word cloud of moon masses:", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->{
  "i:22", "p:280"},ExpressionUUID->"85a000a9-860a-48dc-af17-61a3fc01aef5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"planets", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"WordCloud", "[", 
     RowBox[{"Association", "[", 
      RowBox[{"Values", "[", "#", "]"}], "]"}], "]"}], "&"}], ",", 
   "\"\<Moons\>\"", ",", "All", ",", "\"\<Mass\>\""}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[45]:=",ExpressionUUID->"324e1662-c35d-436b-b65f-76ed4ccfa40e"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     StyleBox["\<\"Ganymede\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.2046783625730994],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[0.368417, 0.506779, 0.709798]], {0, 0}], InsetBox[
     StyleBox["\<\"Titan\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.2046783625730994],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[0.880722, 0.611041, 0.142051]], {0., 43.}], InsetBox[
     StyleBox["\<\"Callisto\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.15662098889738937`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[0.560181, 0.691569, 0.194885]], {0., -52.}], 
    InsetBox[
     StyleBox["\<\"Moon\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.116229548295786],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[0.528488, 0.470624, 0.701351]], {43., 77.}], 
    InsetBox[
     StyleBox["\<\"Europa\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.086065561799023],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[0.772079, 0.431554, 0.102387]], {0., -85.}], 
    InsetBox[
     StyleBox["\<\"Io\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.13498580694136814`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[0.922526, 0.385626, 0.209179]], {-82., 36.}], 
    InsetBox[
     StyleBox["\<\"Triton\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.05457481638507435],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[0.363898, 0.618501, 0.782349]], {-30., 84.}], 
    InsetBox[
     StyleBox["\<\"Desdemona\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02923997720433354],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.6361597700445392, 0.7170733077827265, 0.]], {98., -29.}], InsetBox[
     StyleBox["\<\"Prometheus\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02923998714034319],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.6536293927965667, 0.37163285420200276`, 
        0.6534265180085832]], {-14., -102.}], InsetBox[
     StyleBox["\<\"Epimetheus\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02924038883901905],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.37977756485605163`, 0.715, 0.3025558265468435]], {0., 103.}], 
    InsetBox[
     StyleBox["\<\"S/2007 S2\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239766241757705`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.8774935098648088, 0.34000129802703827`, 
        0.2750108168919853]], {-73., -76.}], InsetBox[
     StyleBox["\<\"Enceladus\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02936769218837668],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.838355547812947, 0.44746667828057946`, 
        0.0208888695323676]], {73., -76.}], InsetBox[
     StyleBox["\<\"Eurydome\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239766117357093`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.8949268664259606, 0.5032845776173072, 
        0.05843417978336459]], {99., 39.}], InsetBox[
     StyleBox["\<\"Hermippe\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239766170585716`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.7042770479220728, 0.358, 0.5530353108891188]], {51., 97.}], 
    InsetBox[
     StyleBox["\<\"Harpalyke\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239766206071466`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.3383114092015346, 0.5643508726387724, 
        0.8209736910418415]], {98., 51.}], InsetBox[
     StyleBox["\<\"Amalthea\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029242214580792302`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.8613800418100862, 0.48092002787339083`, 
        0.02824203762907758]], {-51., 99.}], InsetBox[
     StyleBox["\<\"Chaldene\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02923976615284284],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.8633598745697435, 0.40996018814538476`, 
        0.08339968642435877]], {44., -103.}], InsetBox[
     StyleBox["\<\"Mundilfari\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239766312528708`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.9840111653093676, 0.677555826546838, 
        0.04316985366470745]], {-71., -88.}], InsetBox[
     StyleBox["\<\"Megaclite\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239766312528708`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.4567336004533182, 0.4884598397280091, 0.85]], {-109., -29.}], 
    InsetBox[
     StyleBox["\<\"Themisto\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02923976688030069],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.922066817647527, 0.5213778784316846, 
        0.08286013588277422]], {71., -88.}], InsetBox[
     StyleBox["\<\"Callirrhoe\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239767093215185`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.9307395679624266, 0.7498043964402695, 0.]], {-78., 82.}], InsetBox[
     StyleBox["\<\"Stephano\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02923977316127822],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.6319174318193065, 0.38429816477207124`, 
        0.7077064204517338]], {0., -114.}], InsetBox[
     StyleBox["\<\"Thalassa\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029240209635987863`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.8564488486273256, 0.42032672705901153`, 
        0.06612212156831418]], {107., -41.}], InsetBox[
     StyleBox["\<\"Adrastea\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239774935565656`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.19193353076984873`, 0.681453175384121, 
        0.6453202369238185]], {0., 115.}], InsetBox[
     StyleBox["\<\"Pasiphae\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029240120921615983`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.8168067340273636, 0.3521386531945273, 
        0.3761554432877274]], {-111., -43.}], InsetBox[
     StyleBox["\<\"Praxidike\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02923976657867183],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.6670481226429111, 0.3638052617916352, 
        0.6198796933927223]], {-65., -100.}], InsetBox[
     StyleBox["\<\"Prospero\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02923979090415259],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.47929071933511125`, 0.715, 0.1759027208462221]], {43., 112.}], 
    InsetBox[
     StyleBox["\<\"Cressida\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02924017237595167],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.9810598048862722, 0.7553955338762525, 0.]], {-101., 64.}], InsetBox[
     StyleBox["\<\"Hyperion\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02924633092764745],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.5407932311309059, 0.715, 0.09762679674248334]], {109., -53.}], 
    InsetBox[
     StyleBox["\<\"Iapetus\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.03137778242639052],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[0.915, 0.3325, 0.2125]], {-43., -113.}], InsetBox[
     StyleBox["\<\"Oberon\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.03280785810106538],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[0.647624, 0.37816, 0.614037]], {-48., 111.}], 
    InsetBox[
     StyleBox["\<\"Autonoe\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239766170585716`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.9603267270590103, 0.5591336352950514, 
        0.10711783694067224`]], {-109., -55.}], InsetBox[
     StyleBox["\<\"Cordelia\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239819292751594`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.8493197142977551, 0.7407577460330839, 0.]], {43., -115.}], InsetBox[
     StyleBox["\<\"Lysithea\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239840584200847`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.8342400905885153, 0.4628267270590103, 
        0.0038160815296638794`]], {2., -126.}], InsetBox[
     StyleBox["\<\"Rosalind\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029240067692992856`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.23716678280579248`, 0.645266573755366, 
        0.699600139366951]], {6., 126.}], InsetBox[
     StyleBox["\<\"Titania\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.03341466440471154],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[1, 0.75, 0]], {-119., 39.}], InsetBox[
     StyleBox["\<\"Orthosie\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239766081871343`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.9107287510704583, 0.33890687339431275`, 
        0.20182187767614543`]], {-40., 123.}], InsetBox[
     StyleBox["\<\"Taygete\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239766259300085`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.7989994773739094, 0.735166608597101, 0.]], {114., 65.}], InsetBox[
     StyleBox["\<\"Suttungr\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239766312528708`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.7658565873730018, 0.358, 0.4582975578876895]], {88., -99.}], InsetBox[
     StyleBox["\<\"Trinculo\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239766951272186`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.26512246998569167`, 0.6229020240114467, 
        0.73314696398283]], {48., 122.}], InsetBox[
     StyleBox["\<\"Calypso\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02923977032241832],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.38354466123747527`, 0.5323732032575149, 0.85]], {95., 95.}], InsetBox[
     StyleBox["\<\"Pandora\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239942605728503`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.9038177251280404, 0.3492734123079395, 
        0.18454431282010084`]], {-42., -126.}], InsetBox[
     StyleBox["\<\"Sycorax\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02924613575602932],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.8857244243136628, 0.3764133635295058, 
        0.1393110607841571]], {-95., 94.}], InsetBox[
     StyleBox["\<\"Miranda\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02931783471138119],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.5833680111493557, 0.4126186601628758, 
        0.8290799721266107]], {-118., -67.}], InsetBox[
     StyleBox["\<\"Euanthe\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239766117357093`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.2198892179497479, 0.6590886256402017, 
        0.6788670615396974]], {118., -67.}], InsetBox[
     StyleBox["\<\"Erinome\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239766117357093`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.8064401951137368, 0.3542119609772526, 
        0.39343300814377197`]], {-120., 51.}], InsetBox[
     StyleBox["\<\"Setebos\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02923979090415259],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.8745421494417032, 0.39318677583744527`, 
        0.11135537360425793`]], {85., 107.}], InsetBox[
     StyleBox["\<\"Despina\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029242250066541055`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.16397784358994957`, 0.7038177251280403, 
        0.6117734123079395]], {113., 77.}], InsetBox[
     StyleBox["\<\"Euporie\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239766081871343`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.6453361616656581, 0.37647057236169945`, 
        0.6741595958358548]], {-81., -112.}], InsetBox[
     StyleBox["\<\"Ananke\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239801549877223`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.3103557220216354, 0.5867154223826917, 
        0.7874268664259625]], {-92., 105.}], InsetBox[
     StyleBox["\<\"Siarnaq\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239812195601848`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.8607200975568693, 0.34335598048862614`, 
        0.30296650407188447`]], {86., -111.}], InsetBox[
     StyleBox["\<\"Ophelia\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239829938476222`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.596786740995709, 0.404791067752503, 
        0.7955331475107271]], {-116., -80.}], InsetBox[
     StyleBox["\<\"Phoebe\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029249579647945622`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.9324333565611593, 0.5282889043741062, 
        0.0921900209050434]], {117., -79.}], InsetBox[
     StyleBox["\<\"Thyone\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239766170585716`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.4177882075393331, 0.715, 0.25417864494993975`]], {-120., 77.}], 
    InsetBox[
     StyleBox["\<\"Telesto\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02923977458070817],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.8781534541180211, 0.4921023027453475, 
        0.04333810870621905]], {-105., -98.}], InsetBox[
     StyleBox["\<\"Paaliaq\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239775822709375`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.7896667828057927, 0.3575666434388414, 
        0.4213886953236787]], {-87., 117.}], InsetBox[
     StyleBox["\<\"Albiorix\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02923979090415259],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.6897400905885174, 0.358, 0.5753998606330502]], {86., 119.}], InsetBox[
     StyleBox["\<\"Belinda\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02924018834453861],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.5472001045252132, 0.43417993728487203`, 0.85]], {141., 38.}], 
    InsetBox[
     StyleBox["\<\"Galatea\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029244201782722377`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.9874666782805795, 0.6948333914028977, 
        0.033839968642435214`]], {145., -29.}], InsetBox[
     StyleBox["\<\"Himalia\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029247750357597496`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.6753413537738198, 0.3589675436319385, 
        0.5991466155654507]], {82., -123.}], InsetBox[
     StyleBox["\<\"Proteus\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029299382122030548`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.8996399512215667, 0.7463488834690629, 0.]], {-82., -124.}], 
    InsetBox[
     StyleBox["\<\"Thrymr\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239766312528708`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.15725938678540247`, 0.715, 0.5857607804549424]], {93., 25.}], 
    InsetBox[
     StyleBox["\<\"Erriapo\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02923976696901506],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.8335801463353031, 0.3487839707329394, 
        0.3481997561078282]], {140., 51.}], InsetBox[
     StyleBox["\<\"Deimos\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02923976780293016],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.845266573755366, 0.437100139366951, 
        0.03816643438841502]], {-150., -29.}], InsetBox[
     StyleBox["\<\"Phobos\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02923977876447795],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.9930578157165594, 0.7227890785827968, 
        0.01874389756528967]], {-140., 63.}], InsetBox[
     StyleBox["\<\"Caliban\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029240635464972874`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.9637822400302223, 0.5764112001511111, 
        0.0977879519184]], {148., -41.}], InsetBox[
     StyleBox["\<\"Larissa\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02924562121267242],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.47401116530937026`, 0.47809330081437784`, 0.85]], {126., -91.}], 
    InsetBox[
     StyleBox["\<\"Umbriel\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.030627258840301846`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.9728288904374106, 0.621644452187053, 
        0.07336199581899142]], {150., -53.}], InsetBox[
     StyleBox["\<\"Tarvos\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239769257845858`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.7277983389807635, 0.358, 0.5168487092603637]], {-147., -52.}], 
    InsetBox[
     StyleBox["\<\"Tethys\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029970949917147712`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.28026441037696703`, 0.715, 0.4292089322474965]], {133., 88.}], 
    InsetBox[
     StyleBox["\<\"Iocaste\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02923976629478584],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.8510135028964549, 0.47400900193096995`, 
        0.018912152606809424`]], {-132., 89.}], InsetBox[
     StyleBox["\<\"Helene\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02923979622701491],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.9492067688690977, 0.5394711792460651, 
        0.10728609198218791`]], {-117., -109.}], InsetBox[
     StyleBox["\<\"Sinope\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239854778500347`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.2187618985811806, 0.715, 0.5074848563512248]], {122., 105.}], 
    InsetBox[
     StyleBox["\<\"Bianca\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239876069949596`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.7513196300394465, 0.358, 0.48066210763162087`]], {125., -103.}], 
    InsetBox[
     StyleBox["\<\"Nereid\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02927631638534224],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.28240003484173815`, 0.6090799721266095, 
        0.7538800418100857]], {149., 62.}], InsetBox[
     StyleBox["\<\"Mimas\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029284655536298783`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.8439466852489265, 0.3467106629502147, 
        0.3309221912517893]], {-132., 100.}], InsetBox[
     StyleBox["\<\"Rhea\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.031973410719180036`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[0.571589, 0.586483, 0.]], {-154., 41.}], InsetBox[
     StyleBox["\<\"Isonoe\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02923976615284284],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.529922539669161, 0.44454647619850335`, 0.85]], {-154., -62.}], 
    InsetBox[
     StyleBox["\<\"Kalyke\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02923976629478584],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.6102054708420535, 0.39696347534213544`, 
        0.7619863228948663]], {-140., -92.}], InsetBox[
     StyleBox["\<\"Carme\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239922201422974`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.428777913273419, 0.5052332520359486, 0.85]], {122., -114.}], InsetBox[
     StyleBox["\<\"Thebe\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029241540351566033`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.8878600487784333, 0.33792799024431336`, 
        0.2577332520359445]], {121., 116.}], InsetBox[
     StyleBox["\<\"Janus\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02924201231202442],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.6184987019729621, 0.39212575718243875`, 
        0.7412532450675947]], {154., -66.}], InsetBox[
     StyleBox["\<\"Skathi\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02923976643672883],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.8926354502560807, 0.366046824615879, 
        0.15658862564020168`]], {-120., 116.}], InsetBox[
     StyleBox["\<\"Portia\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029241756814633414`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.7678998606330495, 0.7317110956258943, 0.]], {-116., -121.}], InsetBox[
     StyleBox["\<\"Kiviuq\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239769967560832`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.969373377466199, 0.6043668873309952, 
        0.08269188084126262]], {-150., -76.}], InsetBox[
     StyleBox["\<\"Naiad\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239996721495354`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.9052934053395919, 0.510195603559728, 
        0.06776406480563275]], {-153., 75.}], InsetBox[
     StyleBox["\<\"Aitne\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239766117357093`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.9986489531525362, 0.7507447657626809, 
        0.0036478264881522893`]], {28., -27.}], InsetBox[
     StyleBox["\<\"Juliet\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029240426099055243`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.7132613816472081, 0.358, 0.5392132590042952]], {150., -78.}], 
    InsetBox[
     StyleBox["\<\"Elara\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029240795150842255`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.35558897405758294`, 0.5505288207539337, 
        0.8417067688690995]], {114., -126.}], InsetBox[
     StyleBox["\<\"Dione\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.030537000838353076`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.736782672705901, 0.358, 0.5030266573755369]], {154., 97.}], 
    InsetBox[
     StyleBox["\<\"Atlas\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239768548130884`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.31827505306025683`, 0.715, 0.3808317506505822]], {154., 74.}], 
    InsetBox[
     StyleBox["\<\"Leda\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239779016426763`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.5019668524892619, 0.46131988850644284`, 0.85]], {157., -90.}], 
    InsetBox[
     StyleBox["\<\"Metis\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239908007123474`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.9784200278733908, 0.649600139366954, 
        0.058265924741844846`]], {-148., -106.}], InsetBox[
     StyleBox["\<\"Puck\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.0292431922131704],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.7748409210981391, 0.358, 0.4444755060028629]], {155., -103.}], 
    InsetBox[
     StyleBox["\<\"Narvi\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02923976647221458],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.5788038738141875, 0.715, 0.049249615145579635`]], {-149., 112.}], 
    InsetBox[
     StyleBox["\<\"Ijiraq\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239767483558415`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.5750747800184488, 0.4174563783225715, 
        0.8498130499538777]], {-143., -118.}], InsetBox[
     StyleBox["\<\"Ariel\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.030841947620246835`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.40082222609352647`, 0.5220066643438841, 0.85]], {152., 107.}], 
    InsetBox[
     StyleBox["\<\"Ymir\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02923977191927701],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.9046334610863751, 0.334573307782725, 
        0.22977756485604156`]], {137., 125.}], InsetBox[
     StyleBox["\<\"Kale\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239766081871343`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.6672593867853922, 0.7205288207539324, 0.]], {140., -126.}], 
    InsetBox[
     StyleBox["\<\"Pan\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02923977191927701],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.7175796237092107, 0.7261199581899123, 0.]], {-160., 87.}]}},
  Background->GrayLevel[0, 0],
  ImageSize->{199.58203125, 155.},
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultPlotStyle" -> Automatic},
  PlotRange->{{-171.5, 170.5}, {-133.5, 133.5}}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[45]=",ExpressionUUID->"d566a20d-7dfa-4f19-9266-d0ced07e8df2"]
}, Open  ]],

Cell[TextData[{
 "For what it does, the code here is surprisingly simple. But we can make it \
slightly more streamlined by using ",
 Cell[BoxData[
  ButtonBox["@*",
   BaseStyle->"Link",
   ButtonData->"Composition"]], "InlineCodeText",ExpressionUUID->
  "bbbfbd67-03b4-4fac-8710-144a626782dc"],
 " or ",
 Cell[BoxData[
  ButtonBox["/*",
   BaseStyle->"Link",
   ButtonData->"RightComposition"]], "InlineCodeText",ExpressionUUID->
  "deeabd2c-e5b4-43b0-b0bb-b0dda89e72fd"],
 ". "
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"c4511143-f1c0-48d5-a62f-eda42f6fcbba"],

Cell[TextData[{
 "We\[CloseCurlyQuote]ve seen before that we can write something like ",
 Cell[BoxData[
  RowBox[{"f", "[", 
   RowBox[{"g", "[", "x", "]"}], "]"}]], "InlineCodeText",ExpressionUUID->
  "6c2d2037-f8ed-4080-b853-ed97842d9467"],
 " as ",
 Cell[BoxData[
  RowBox[{"f", 
   ButtonBox["@",
    BaseStyle->"Link",
    ButtonData->"Prefix"], "g", 
   ButtonBox["@",
    BaseStyle->"Link",
    ButtonData->"Prefix"], "x"}]], "InlineCodeText",ExpressionUUID->
  "f9fbcfe5-4302-44cb-ba1c-30b7ccdb132f"],
 " or ",
 Cell[BoxData[
  RowBox[{"x", 
   ButtonBox["//",
    BaseStyle->"Link",
    ButtonData->"Postfix"], "g", 
   ButtonBox["//",
    BaseStyle->"Link",
    ButtonData->"Postfix"], "f"}]], "InlineCodeText",ExpressionUUID->
  "b93bdf9e-3c84-445c-b46e-52c4ca0dbaf2"],
 ". We can also write it ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", 
    RowBox[{"g", "[", 
     ButtonBox["#",
      BaseStyle->"Link",
      ButtonData->"Slot"], "]"}], "]"}], 
   RowBox[{
    ButtonBox["&",
     BaseStyle->"Link",
     ButtonData->"Function"], "[", "x", "]"}]}]], "InlineCodeText",
  ExpressionUUID->"6e15a0df-703d-4c38-9726-aaf1849e4987"],
 ". But what about ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", 
    RowBox[{"g", "[", 
     ButtonBox["#",
      BaseStyle->"Link",
      ButtonData->"Slot"], "]"}], "]"}], 
   ButtonBox["&",
    BaseStyle->"Link",
    ButtonData->"Function"]}]], "InlineCodeText",ExpressionUUID->
  "53780773-e277-493f-be91-a837965e1717"],
 "? Is there a short way to write this? The answer is that there is, in terms \
of the ",
 StyleBox["function composition operators",
  FontSlant->"Italic"],
 " ",
 Cell[BoxData[
  ButtonBox["@*",
   BaseStyle->"Link",
   ButtonData->"Composition"]], "InlineCodeText",ExpressionUUID->
  "11172749-03c9-4c0a-ab26-632ec6434ba5"],
 " and ",
 Cell[BoxData[
  ButtonBox["/*",
   BaseStyle->"Link",
   ButtonData->"RightComposition"]], "InlineCodeText",ExpressionUUID->
  "00676a67-bb3b-471c-9118-4fa74df6b962"],
 "."
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:23",ExpressionUUID->"7afcd178-5b7f-4b0b-bd9c-f87370d9497b"],

Cell[TextData[{
 Cell[BoxData[
  RowBox[{"f", 
   ButtonBox["@*",
    BaseStyle->"Link",
    ButtonData->"Composition"], "g", 
   ButtonBox["@*",
    BaseStyle->"Link",
    ButtonData->"Composition"], "h"}]], "InlineCode",ExpressionUUID->
  "065facf4-4180-4479-a6a7-49b7c28f14df"],
 " represents a composition of functions to be applied right-to-left:"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:24",ExpressionUUID->"62546393-eef3-4f27-a3eb-22c28ccf7d5d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"f", "@*", "g", "@*", "h"}], ")"}], "[", "x", "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[46]:=",ExpressionUUID->"62e03f26-26f7-40f0-8d10-a174e1d61c4c"],

Cell[BoxData[
 RowBox[{"f", "[", 
  RowBox[{"g", "[", 
   RowBox[{"h", "[", "x", "]"}], "]"}], "]"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[46]=",ExpressionUUID->"c2a08c42-57c2-45da-8dc2-a0239cd19407"]
}, Open  ]],

Cell[TextData[{
 Cell[BoxData[
  RowBox[{"h", 
   ButtonBox["/*",
    BaseStyle->"Link",
    ButtonData->"RightComposition"], "g", 
   ButtonBox["/*",
    BaseStyle->"Link",
    ButtonData->"RightComposition"], "f"}]], "InlineCode",ExpressionUUID->
  "68629363-6f24-43bd-824a-f7fc1e944a6f"],
 " represents a composition of functions to be applied left-to-right:"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:25",ExpressionUUID->"40c49a90-84f1-4263-9982-dcba75e68fa6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"h", "/*", "g", "/*", "f"}], ")"}], "[", "x", "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[47]:=",ExpressionUUID->"d3b3b9d5-700d-48f9-af30-af8317857afd"],

Cell[BoxData[
 RowBox[{"f", "[", 
  RowBox[{"g", "[", 
   RowBox[{"h", "[", "x", "]"}], "]"}], "]"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellTags->"LastCellOfAPage",
 CellLabel->"Out[47]=",ExpressionUUID->"94ad9963-1801-406c-8b76-245fa1fcaf7f"]
}, Open  ]],

Cell[TextData[{
 "Here\[CloseCurlyQuote]s the previous code rewritten using composition ",
 Cell[BoxData[
  ButtonBox["@*",
   BaseStyle->"Link",
   ButtonData->"Composition"]], "InlineCode",ExpressionUUID->
  "5833e846-d6f5-46a2-bf30-bb18a52fce08"],
 ":"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"29c68b46-637d-4548-801f-4b206d47ea8c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"planets", "[", 
  RowBox[{
   RowBox[{"WordCloud", "@*", "Association", "@*", "Values"}], ",", 
   "\"\<Moons\>\"", ",", "All", ",", "\"\<Mass\>\""}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[48]:=",ExpressionUUID->"5b2b5756-210c-458c-a4a3-0dd6341483df"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     StyleBox["\<\"Ganymede\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.2046783625730994],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[0.368417, 0.506779, 0.709798]], {0, 0}], InsetBox[
     StyleBox["\<\"Titan\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.2046783625730994],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[0.880722, 0.611041, 0.142051]], {0., 43.}], InsetBox[
     StyleBox["\<\"Callisto\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.15662098889738937`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[0.560181, 0.691569, 0.194885]], {0., -52.}], 
    InsetBox[
     StyleBox["\<\"Moon\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.116229548295786],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[0.528488, 0.470624, 0.701351]], {43., 77.}], 
    InsetBox[
     StyleBox["\<\"Europa\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.086065561799023],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[0.772079, 0.431554, 0.102387]], {0., -85.}], 
    InsetBox[
     StyleBox["\<\"Io\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.13498580694136814`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[0.922526, 0.385626, 0.209179]], {-82., 36.}], 
    InsetBox[
     StyleBox["\<\"Triton\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.05457481638507435],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[0.363898, 0.618501, 0.782349]], {-30., 84.}], 
    InsetBox[
     StyleBox["\<\"Desdemona\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02923997720433354],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.6361597700445392, 0.7170733077827265, 0.]], {98., -29.}], InsetBox[
     StyleBox["\<\"Prometheus\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02923998714034319],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.6536293927965667, 0.37163285420200276`, 
        0.6534265180085832]], {-14., -102.}], InsetBox[
     StyleBox["\<\"Epimetheus\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02924038883901905],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.37977756485605163`, 0.715, 0.3025558265468435]], {0., 103.}], 
    InsetBox[
     StyleBox["\<\"S/2007 S2\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239766241757705`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.8774935098648088, 0.34000129802703827`, 
        0.2750108168919853]], {-73., -76.}], InsetBox[
     StyleBox["\<\"Enceladus\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02936769218837668],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.838355547812947, 0.44746667828057946`, 
        0.0208888695323676]], {73., -76.}], InsetBox[
     StyleBox["\<\"Eurydome\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239766117357093`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.8949268664259606, 0.5032845776173072, 
        0.05843417978336459]], {99., 39.}], InsetBox[
     StyleBox["\<\"Hermippe\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239766170585716`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.7042770479220728, 0.358, 0.5530353108891188]], {51., 97.}], 
    InsetBox[
     StyleBox["\<\"Harpalyke\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239766206071466`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.3383114092015346, 0.5643508726387724, 
        0.8209736910418415]], {98., 51.}], InsetBox[
     StyleBox["\<\"Amalthea\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029242214580792302`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.8613800418100862, 0.48092002787339083`, 
        0.02824203762907758]], {-51., 99.}], InsetBox[
     StyleBox["\<\"Chaldene\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02923976615284284],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.8633598745697435, 0.40996018814538476`, 
        0.08339968642435877]], {44., -103.}], InsetBox[
     StyleBox["\<\"Mundilfari\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239766312528708`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.9840111653093676, 0.677555826546838, 
        0.04316985366470745]], {-71., -88.}], InsetBox[
     StyleBox["\<\"Megaclite\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239766312528708`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.4567336004533182, 0.4884598397280091, 0.85]], {-109., -29.}], 
    InsetBox[
     StyleBox["\<\"Themisto\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02923976688030069],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.922066817647527, 0.5213778784316846, 
        0.08286013588277422]], {71., -88.}], InsetBox[
     StyleBox["\<\"Callirrhoe\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239767093215185`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.9307395679624266, 0.7498043964402695, 0.]], {-78., 82.}], InsetBox[
     StyleBox["\<\"Stephano\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02923977316127822],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.6319174318193065, 0.38429816477207124`, 
        0.7077064204517338]], {0., -114.}], InsetBox[
     StyleBox["\<\"Thalassa\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029240209635987863`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.8564488486273256, 0.42032672705901153`, 
        0.06612212156831418]], {107., -41.}], InsetBox[
     StyleBox["\<\"Adrastea\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239774935565656`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.19193353076984873`, 0.681453175384121, 
        0.6453202369238185]], {0., 115.}], InsetBox[
     StyleBox["\<\"Pasiphae\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029240120921615983`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.8168067340273636, 0.3521386531945273, 
        0.3761554432877274]], {-111., -43.}], InsetBox[
     StyleBox["\<\"Praxidike\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02923976657867183],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.6670481226429111, 0.3638052617916352, 
        0.6198796933927223]], {-65., -100.}], InsetBox[
     StyleBox["\<\"Prospero\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02923979090415259],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.47929071933511125`, 0.715, 0.1759027208462221]], {43., 112.}], 
    InsetBox[
     StyleBox["\<\"Cressida\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02924017237595167],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.9810598048862722, 0.7553955338762525, 0.]], {-101., 64.}], InsetBox[
     StyleBox["\<\"Hyperion\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02924633092764745],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.5407932311309059, 0.715, 0.09762679674248334]], {109., -53.}], 
    InsetBox[
     StyleBox["\<\"Iapetus\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.03137778242639052],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[0.915, 0.3325, 0.2125]], {-43., -113.}], InsetBox[
     StyleBox["\<\"Oberon\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.03280785810106538],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[0.647624, 0.37816, 0.614037]], {-48., 111.}], 
    InsetBox[
     StyleBox["\<\"Autonoe\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239766170585716`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.9603267270590103, 0.5591336352950514, 
        0.10711783694067224`]], {-109., -55.}], InsetBox[
     StyleBox["\<\"Cordelia\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239819292751594`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.8493197142977551, 0.7407577460330839, 0.]], {43., -115.}], InsetBox[
     StyleBox["\<\"Lysithea\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239840584200847`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.8342400905885153, 0.4628267270590103, 
        0.0038160815296638794`]], {2., -126.}], InsetBox[
     StyleBox["\<\"Rosalind\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029240067692992856`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.23716678280579248`, 0.645266573755366, 
        0.699600139366951]], {6., 126.}], InsetBox[
     StyleBox["\<\"Titania\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.03341466440471154],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[1, 0.75, 0]], {-119., 39.}], InsetBox[
     StyleBox["\<\"Orthosie\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239766081871343`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.9107287510704583, 0.33890687339431275`, 
        0.20182187767614543`]], {-40., 123.}], InsetBox[
     StyleBox["\<\"Taygete\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239766259300085`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.7989994773739094, 0.735166608597101, 0.]], {114., 65.}], InsetBox[
     StyleBox["\<\"Suttungr\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239766312528708`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.7658565873730018, 0.358, 0.4582975578876895]], {88., -99.}], InsetBox[
     StyleBox["\<\"Trinculo\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239766951272186`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.26512246998569167`, 0.6229020240114467, 
        0.73314696398283]], {48., 122.}], InsetBox[
     StyleBox["\<\"Calypso\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02923977032241832],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.38354466123747527`, 0.5323732032575149, 0.85]], {95., 95.}], InsetBox[
     StyleBox["\<\"Pandora\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239942605728503`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.9038177251280404, 0.3492734123079395, 
        0.18454431282010084`]], {-42., -126.}], InsetBox[
     StyleBox["\<\"Sycorax\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02924613575602932],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.8857244243136628, 0.3764133635295058, 
        0.1393110607841571]], {-95., 94.}], InsetBox[
     StyleBox["\<\"Miranda\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02931783471138119],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.5833680111493557, 0.4126186601628758, 
        0.8290799721266107]], {-118., -67.}], InsetBox[
     StyleBox["\<\"Euanthe\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239766117357093`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.2198892179497479, 0.6590886256402017, 
        0.6788670615396974]], {118., -67.}], InsetBox[
     StyleBox["\<\"Erinome\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239766117357093`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.8064401951137368, 0.3542119609772526, 
        0.39343300814377197`]], {-120., 51.}], InsetBox[
     StyleBox["\<\"Setebos\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02923979090415259],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.8745421494417032, 0.39318677583744527`, 
        0.11135537360425793`]], {85., 107.}], InsetBox[
     StyleBox["\<\"Despina\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029242250066541055`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.16397784358994957`, 0.7038177251280403, 
        0.6117734123079395]], {113., 77.}], InsetBox[
     StyleBox["\<\"Euporie\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239766081871343`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.6453361616656581, 0.37647057236169945`, 
        0.6741595958358548]], {-81., -112.}], InsetBox[
     StyleBox["\<\"Ananke\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239801549877223`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.3103557220216354, 0.5867154223826917, 
        0.7874268664259625]], {-92., 105.}], InsetBox[
     StyleBox["\<\"Siarnaq\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239812195601848`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.8607200975568693, 0.34335598048862614`, 
        0.30296650407188447`]], {86., -111.}], InsetBox[
     StyleBox["\<\"Ophelia\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239829938476222`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.596786740995709, 0.404791067752503, 
        0.7955331475107271]], {-116., -80.}], InsetBox[
     StyleBox["\<\"Phoebe\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029249579647945622`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.9324333565611593, 0.5282889043741062, 
        0.0921900209050434]], {117., -79.}], InsetBox[
     StyleBox["\<\"Thyone\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239766170585716`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.4177882075393331, 0.715, 0.25417864494993975`]], {-120., 77.}], 
    InsetBox[
     StyleBox["\<\"Telesto\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02923977458070817],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.8781534541180211, 0.4921023027453475, 
        0.04333810870621905]], {-105., -98.}], InsetBox[
     StyleBox["\<\"Paaliaq\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239775822709375`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.7896667828057927, 0.3575666434388414, 
        0.4213886953236787]], {-87., 117.}], InsetBox[
     StyleBox["\<\"Albiorix\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02923979090415259],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.6897400905885174, 0.358, 0.5753998606330502]], {86., 119.}], InsetBox[
     StyleBox["\<\"Belinda\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02924018834453861],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.5472001045252132, 0.43417993728487203`, 0.85]], {141., 38.}], 
    InsetBox[
     StyleBox["\<\"Galatea\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029244201782722377`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.9874666782805795, 0.6948333914028977, 
        0.033839968642435214`]], {145., -29.}], InsetBox[
     StyleBox["\<\"Himalia\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029247750357597496`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.6753413537738198, 0.3589675436319385, 
        0.5991466155654507]], {82., -123.}], InsetBox[
     StyleBox["\<\"Proteus\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029299382122030548`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.8996399512215667, 0.7463488834690629, 0.]], {-82., -124.}], 
    InsetBox[
     StyleBox["\<\"Thrymr\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239766312528708`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.15725938678540247`, 0.715, 0.5857607804549424]], {93., 25.}], 
    InsetBox[
     StyleBox["\<\"Erriapo\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02923976696901506],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.8335801463353031, 0.3487839707329394, 
        0.3481997561078282]], {140., 51.}], InsetBox[
     StyleBox["\<\"Deimos\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02923976780293016],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.845266573755366, 0.437100139366951, 
        0.03816643438841502]], {-150., -29.}], InsetBox[
     StyleBox["\<\"Phobos\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02923977876447795],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.9930578157165594, 0.7227890785827968, 
        0.01874389756528967]], {-140., 63.}], InsetBox[
     StyleBox["\<\"Caliban\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029240635464972874`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.9637822400302223, 0.5764112001511111, 
        0.0977879519184]], {148., -41.}], InsetBox[
     StyleBox["\<\"Larissa\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02924562121267242],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.47401116530937026`, 0.47809330081437784`, 0.85]], {126., -91.}], 
    InsetBox[
     StyleBox["\<\"Umbriel\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.030627258840301846`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.9728288904374106, 0.621644452187053, 
        0.07336199581899142]], {150., -53.}], InsetBox[
     StyleBox["\<\"Tarvos\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239769257845858`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.7277983389807635, 0.358, 0.5168487092603637]], {-147., -52.}], 
    InsetBox[
     StyleBox["\<\"Tethys\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029970949917147712`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.28026441037696703`, 0.715, 0.4292089322474965]], {133., 88.}], 
    InsetBox[
     StyleBox["\<\"Iocaste\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02923976629478584],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.8510135028964549, 0.47400900193096995`, 
        0.018912152606809424`]], {-132., 89.}], InsetBox[
     StyleBox["\<\"Helene\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02923979622701491],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.9492067688690977, 0.5394711792460651, 
        0.10728609198218791`]], {-117., -109.}], InsetBox[
     StyleBox["\<\"Sinope\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239854778500347`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.2187618985811806, 0.715, 0.5074848563512248]], {122., 105.}], 
    InsetBox[
     StyleBox["\<\"Bianca\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239876069949596`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.7513196300394465, 0.358, 0.48066210763162087`]], {125., -103.}], 
    InsetBox[
     StyleBox["\<\"Nereid\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02927631638534224],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.28240003484173815`, 0.6090799721266095, 
        0.7538800418100857]], {149., 62.}], InsetBox[
     StyleBox["\<\"Mimas\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029284655536298783`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.8439466852489265, 0.3467106629502147, 
        0.3309221912517893]], {-132., 100.}], InsetBox[
     StyleBox["\<\"Rhea\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.031973410719180036`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[0.571589, 0.586483, 0.]], {-154., 41.}], InsetBox[
     StyleBox["\<\"Isonoe\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02923976615284284],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.529922539669161, 0.44454647619850335`, 0.85]], {-154., -62.}], 
    InsetBox[
     StyleBox["\<\"Kalyke\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02923976629478584],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.6102054708420535, 0.39696347534213544`, 
        0.7619863228948663]], {-140., -92.}], InsetBox[
     StyleBox["\<\"Carme\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239922201422974`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.428777913273419, 0.5052332520359486, 0.85]], {122., -114.}], InsetBox[
     StyleBox["\<\"Thebe\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029241540351566033`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.8878600487784333, 0.33792799024431336`, 
        0.2577332520359445]], {121., 116.}], InsetBox[
     StyleBox["\<\"Janus\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02924201231202442],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.6184987019729621, 0.39212575718243875`, 
        0.7412532450675947]], {154., -66.}], InsetBox[
     StyleBox["\<\"Skathi\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02923976643672883],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.8926354502560807, 0.366046824615879, 
        0.15658862564020168`]], {-120., 116.}], InsetBox[
     StyleBox["\<\"Portia\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029241756814633414`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.7678998606330495, 0.7317110956258943, 0.]], {-116., -121.}], InsetBox[
     StyleBox["\<\"Kiviuq\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239769967560832`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.969373377466199, 0.6043668873309952, 
        0.08269188084126262]], {-150., -76.}], InsetBox[
     StyleBox["\<\"Naiad\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239996721495354`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.9052934053395919, 0.510195603559728, 
        0.06776406480563275]], {-153., 75.}], InsetBox[
     StyleBox["\<\"Aitne\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239766117357093`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.9986489531525362, 0.7507447657626809, 
        0.0036478264881522893`]], {28., -27.}], InsetBox[
     StyleBox["\<\"Juliet\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029240426099055243`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.7132613816472081, 0.358, 0.5392132590042952]], {150., -78.}], 
    InsetBox[
     StyleBox["\<\"Elara\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029240795150842255`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.35558897405758294`, 0.5505288207539337, 
        0.8417067688690995]], {114., -126.}], InsetBox[
     StyleBox["\<\"Dione\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.030537000838353076`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.736782672705901, 0.358, 0.5030266573755369]], {154., 97.}], 
    InsetBox[
     StyleBox["\<\"Atlas\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239768548130884`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.31827505306025683`, 0.715, 0.3808317506505822]], {154., 74.}], 
    InsetBox[
     StyleBox["\<\"Leda\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239779016426763`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.5019668524892619, 0.46131988850644284`, 0.85]], {157., -90.}], 
    InsetBox[
     StyleBox["\<\"Metis\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239908007123474`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.9784200278733908, 0.649600139366954, 
        0.058265924741844846`]], {-148., -106.}], InsetBox[
     StyleBox["\<\"Puck\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.0292431922131704],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.7748409210981391, 0.358, 0.4444755060028629]], {155., -103.}], 
    InsetBox[
     StyleBox["\<\"Narvi\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02923976647221458],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.5788038738141875, 0.715, 0.049249615145579635`]], {-149., 112.}], 
    InsetBox[
     StyleBox["\<\"Ijiraq\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239767483558415`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.5750747800184488, 0.4174563783225715, 
        0.8498130499538777]], {-143., -118.}], InsetBox[
     StyleBox["\<\"Ariel\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.030841947620246835`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.40082222609352647`, 0.5220066643438841, 0.85]], {152., 107.}], 
    InsetBox[
     StyleBox["\<\"Ymir\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02923977191927701],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.9046334610863751, 0.334573307782725, 
        0.22977756485604156`]], {137., 125.}], InsetBox[
     StyleBox["\<\"Kale\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239766081871343`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.6672593867853922, 0.7205288207539324, 0.]], {140., -126.}], 
    InsetBox[
     StyleBox["\<\"Pan\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02923977191927701],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.7175796237092107, 0.7261199581899123, 0.]], {-160., 87.}]}},
  Background->GrayLevel[0, 0],
  ImageSize->{199.73828125, 151.},
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultPlotStyle" -> Automatic},
  PlotRange->{{-171.5, 170.5}, {-133.5, 133.5}}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[48]=",ExpressionUUID->"f8da4100-dbe5-42c2-b1d3-0004ca144d13"]
}, Open  ]],

Cell[TextData[{
 "And using right composition ",
 Cell[BoxData[
  ButtonBox["/*",
   BaseStyle->"Link",
   ButtonData->"RightComposition"]], "InlineCode",ExpressionUUID->
  "29acb7e4-b20d-47bc-8ffc-7493d3d8a465"],
 ":"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"p:281",ExpressionUUID->"5eeb8a3a-3cc3-4057-8c6b-67f219d45869"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"planets", "[", 
  RowBox[{
   RowBox[{"Values", "/*", "Association", "/*", "WordCloud"}], ",", 
   "\"\<Moons\>\"", ",", "All", ",", "\"\<Mass\>\""}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[49]:=",ExpressionUUID->"127a5577-1577-4e93-8304-6e2769426623"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     StyleBox["\<\"Ganymede\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.2046783625730994],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[0.368417, 0.506779, 0.709798]], {0, 0}], InsetBox[
     StyleBox["\<\"Titan\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.2046783625730994],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[0.880722, 0.611041, 0.142051]], {0., 43.}], InsetBox[
     StyleBox["\<\"Callisto\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.15662098889738937`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[0.560181, 0.691569, 0.194885]], {0., -52.}], 
    InsetBox[
     StyleBox["\<\"Moon\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.116229548295786],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[0.528488, 0.470624, 0.701351]], {43., 77.}], 
    InsetBox[
     StyleBox["\<\"Europa\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.086065561799023],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[0.772079, 0.431554, 0.102387]], {0., -85.}], 
    InsetBox[
     StyleBox["\<\"Io\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.13498580694136814`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[0.922526, 0.385626, 0.209179]], {-82., 36.}], 
    InsetBox[
     StyleBox["\<\"Triton\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.05457481638507435],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[0.363898, 0.618501, 0.782349]], {-30., 84.}], 
    InsetBox[
     StyleBox["\<\"Desdemona\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02923997720433354],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.6361597700445392, 0.7170733077827265, 0.]], {98., -29.}], InsetBox[
     StyleBox["\<\"Prometheus\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02923998714034319],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.6536293927965667, 0.37163285420200276`, 
        0.6534265180085832]], {-14., -102.}], InsetBox[
     StyleBox["\<\"Epimetheus\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02924038883901905],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.37977756485605163`, 0.715, 0.3025558265468435]], {0., 103.}], 
    InsetBox[
     StyleBox["\<\"S/2007 S2\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239766241757705`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.8774935098648088, 0.34000129802703827`, 
        0.2750108168919853]], {-73., -76.}], InsetBox[
     StyleBox["\<\"Enceladus\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02936769218837668],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.838355547812947, 0.44746667828057946`, 
        0.0208888695323676]], {73., -76.}], InsetBox[
     StyleBox["\<\"Eurydome\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239766117357093`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.8949268664259606, 0.5032845776173072, 
        0.05843417978336459]], {99., 39.}], InsetBox[
     StyleBox["\<\"Hermippe\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239766170585716`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.7042770479220728, 0.358, 0.5530353108891188]], {51., 97.}], 
    InsetBox[
     StyleBox["\<\"Harpalyke\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239766206071466`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.3383114092015346, 0.5643508726387724, 
        0.8209736910418415]], {98., 51.}], InsetBox[
     StyleBox["\<\"Amalthea\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029242214580792302`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.8613800418100862, 0.48092002787339083`, 
        0.02824203762907758]], {-51., 99.}], InsetBox[
     StyleBox["\<\"Chaldene\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02923976615284284],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.8633598745697435, 0.40996018814538476`, 
        0.08339968642435877]], {44., -103.}], InsetBox[
     StyleBox["\<\"Mundilfari\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239766312528708`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.9840111653093676, 0.677555826546838, 
        0.04316985366470745]], {-71., -88.}], InsetBox[
     StyleBox["\<\"Megaclite\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239766312528708`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.4567336004533182, 0.4884598397280091, 0.85]], {-109., -29.}], 
    InsetBox[
     StyleBox["\<\"Themisto\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02923976688030069],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.922066817647527, 0.5213778784316846, 
        0.08286013588277422]], {71., -88.}], InsetBox[
     StyleBox["\<\"Callirrhoe\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239767093215185`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.9307395679624266, 0.7498043964402695, 0.]], {-78., 82.}], InsetBox[
     StyleBox["\<\"Stephano\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02923977316127822],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.6319174318193065, 0.38429816477207124`, 
        0.7077064204517338]], {0., -114.}], InsetBox[
     StyleBox["\<\"Thalassa\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029240209635987863`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.8564488486273256, 0.42032672705901153`, 
        0.06612212156831418]], {107., -41.}], InsetBox[
     StyleBox["\<\"Adrastea\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239774935565656`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.19193353076984873`, 0.681453175384121, 
        0.6453202369238185]], {0., 115.}], InsetBox[
     StyleBox["\<\"Pasiphae\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029240120921615983`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.8168067340273636, 0.3521386531945273, 
        0.3761554432877274]], {-111., -43.}], InsetBox[
     StyleBox["\<\"Praxidike\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02923976657867183],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.6670481226429111, 0.3638052617916352, 
        0.6198796933927223]], {-65., -100.}], InsetBox[
     StyleBox["\<\"Prospero\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02923979090415259],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.47929071933511125`, 0.715, 0.1759027208462221]], {43., 112.}], 
    InsetBox[
     StyleBox["\<\"Cressida\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02924017237595167],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.9810598048862722, 0.7553955338762525, 0.]], {-101., 64.}], InsetBox[
     StyleBox["\<\"Hyperion\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02924633092764745],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.5407932311309059, 0.715, 0.09762679674248334]], {109., -53.}], 
    InsetBox[
     StyleBox["\<\"Iapetus\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.03137778242639052],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[0.915, 0.3325, 0.2125]], {-43., -113.}], InsetBox[
     StyleBox["\<\"Oberon\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.03280785810106538],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[0.647624, 0.37816, 0.614037]], {-48., 111.}], 
    InsetBox[
     StyleBox["\<\"Autonoe\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239766170585716`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.9603267270590103, 0.5591336352950514, 
        0.10711783694067224`]], {-109., -55.}], InsetBox[
     StyleBox["\<\"Cordelia\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239819292751594`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.8493197142977551, 0.7407577460330839, 0.]], {43., -115.}], InsetBox[
     StyleBox["\<\"Lysithea\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239840584200847`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.8342400905885153, 0.4628267270590103, 
        0.0038160815296638794`]], {2., -126.}], InsetBox[
     StyleBox["\<\"Rosalind\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029240067692992856`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.23716678280579248`, 0.645266573755366, 
        0.699600139366951]], {6., 126.}], InsetBox[
     StyleBox["\<\"Titania\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.03341466440471154],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[1, 0.75, 0]], {-119., 39.}], InsetBox[
     StyleBox["\<\"Orthosie\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239766081871343`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.9107287510704583, 0.33890687339431275`, 
        0.20182187767614543`]], {-40., 123.}], InsetBox[
     StyleBox["\<\"Taygete\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239766259300085`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.7989994773739094, 0.735166608597101, 0.]], {114., 65.}], InsetBox[
     StyleBox["\<\"Suttungr\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239766312528708`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.7658565873730018, 0.358, 0.4582975578876895]], {88., -99.}], InsetBox[
     StyleBox["\<\"Trinculo\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239766951272186`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.26512246998569167`, 0.6229020240114467, 
        0.73314696398283]], {48., 122.}], InsetBox[
     StyleBox["\<\"Calypso\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02923977032241832],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.38354466123747527`, 0.5323732032575149, 0.85]], {95., 95.}], InsetBox[
     StyleBox["\<\"Pandora\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239942605728503`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.9038177251280404, 0.3492734123079395, 
        0.18454431282010084`]], {-42., -126.}], InsetBox[
     StyleBox["\<\"Sycorax\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02924613575602932],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.8857244243136628, 0.3764133635295058, 
        0.1393110607841571]], {-95., 94.}], InsetBox[
     StyleBox["\<\"Miranda\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02931783471138119],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.5833680111493557, 0.4126186601628758, 
        0.8290799721266107]], {-118., -67.}], InsetBox[
     StyleBox["\<\"Euanthe\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239766117357093`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.2198892179497479, 0.6590886256402017, 
        0.6788670615396974]], {118., -67.}], InsetBox[
     StyleBox["\<\"Erinome\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239766117357093`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.8064401951137368, 0.3542119609772526, 
        0.39343300814377197`]], {-120., 51.}], InsetBox[
     StyleBox["\<\"Setebos\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02923979090415259],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.8745421494417032, 0.39318677583744527`, 
        0.11135537360425793`]], {85., 107.}], InsetBox[
     StyleBox["\<\"Despina\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029242250066541055`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.16397784358994957`, 0.7038177251280403, 
        0.6117734123079395]], {113., 77.}], InsetBox[
     StyleBox["\<\"Euporie\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239766081871343`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.6453361616656581, 0.37647057236169945`, 
        0.6741595958358548]], {-81., -112.}], InsetBox[
     StyleBox["\<\"Ananke\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239801549877223`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.3103557220216354, 0.5867154223826917, 
        0.7874268664259625]], {-92., 105.}], InsetBox[
     StyleBox["\<\"Siarnaq\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239812195601848`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.8607200975568693, 0.34335598048862614`, 
        0.30296650407188447`]], {86., -111.}], InsetBox[
     StyleBox["\<\"Ophelia\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239829938476222`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.596786740995709, 0.404791067752503, 
        0.7955331475107271]], {-116., -80.}], InsetBox[
     StyleBox["\<\"Phoebe\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029249579647945622`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.9324333565611593, 0.5282889043741062, 
        0.0921900209050434]], {117., -79.}], InsetBox[
     StyleBox["\<\"Thyone\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239766170585716`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.4177882075393331, 0.715, 0.25417864494993975`]], {-120., 77.}], 
    InsetBox[
     StyleBox["\<\"Telesto\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02923977458070817],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.8781534541180211, 0.4921023027453475, 
        0.04333810870621905]], {-105., -98.}], InsetBox[
     StyleBox["\<\"Paaliaq\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239775822709375`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.7896667828057927, 0.3575666434388414, 
        0.4213886953236787]], {-87., 117.}], InsetBox[
     StyleBox["\<\"Albiorix\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02923979090415259],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.6897400905885174, 0.358, 0.5753998606330502]], {86., 119.}], InsetBox[
     StyleBox["\<\"Belinda\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02924018834453861],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.5472001045252132, 0.43417993728487203`, 0.85]], {141., 38.}], 
    InsetBox[
     StyleBox["\<\"Galatea\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029244201782722377`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.9874666782805795, 0.6948333914028977, 
        0.033839968642435214`]], {145., -29.}], InsetBox[
     StyleBox["\<\"Himalia\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029247750357597496`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.6753413537738198, 0.3589675436319385, 
        0.5991466155654507]], {82., -123.}], InsetBox[
     StyleBox["\<\"Proteus\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029299382122030548`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.8996399512215667, 0.7463488834690629, 0.]], {-82., -124.}], 
    InsetBox[
     StyleBox["\<\"Thrymr\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239766312528708`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.15725938678540247`, 0.715, 0.5857607804549424]], {93., 25.}], 
    InsetBox[
     StyleBox["\<\"Erriapo\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02923976696901506],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.8335801463353031, 0.3487839707329394, 
        0.3481997561078282]], {140., 51.}], InsetBox[
     StyleBox["\<\"Deimos\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02923976780293016],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.845266573755366, 0.437100139366951, 
        0.03816643438841502]], {-150., -29.}], InsetBox[
     StyleBox["\<\"Phobos\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02923977876447795],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.9930578157165594, 0.7227890785827968, 
        0.01874389756528967]], {-140., 63.}], InsetBox[
     StyleBox["\<\"Caliban\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029240635464972874`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.9637822400302223, 0.5764112001511111, 
        0.0977879519184]], {148., -41.}], InsetBox[
     StyleBox["\<\"Larissa\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02924562121267242],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.47401116530937026`, 0.47809330081437784`, 0.85]], {126., -91.}], 
    InsetBox[
     StyleBox["\<\"Umbriel\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.030627258840301846`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.9728288904374106, 0.621644452187053, 
        0.07336199581899142]], {150., -53.}], InsetBox[
     StyleBox["\<\"Tarvos\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239769257845858`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.7277983389807635, 0.358, 0.5168487092603637]], {-147., -52.}], 
    InsetBox[
     StyleBox["\<\"Tethys\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029970949917147712`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.28026441037696703`, 0.715, 0.4292089322474965]], {133., 88.}], 
    InsetBox[
     StyleBox["\<\"Iocaste\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02923976629478584],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.8510135028964549, 0.47400900193096995`, 
        0.018912152606809424`]], {-132., 89.}], InsetBox[
     StyleBox["\<\"Helene\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02923979622701491],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.9492067688690977, 0.5394711792460651, 
        0.10728609198218791`]], {-117., -109.}], InsetBox[
     StyleBox["\<\"Sinope\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239854778500347`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.2187618985811806, 0.715, 0.5074848563512248]], {122., 105.}], 
    InsetBox[
     StyleBox["\<\"Bianca\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239876069949596`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.7513196300394465, 0.358, 0.48066210763162087`]], {125., -103.}], 
    InsetBox[
     StyleBox["\<\"Nereid\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02927631638534224],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.28240003484173815`, 0.6090799721266095, 
        0.7538800418100857]], {149., 62.}], InsetBox[
     StyleBox["\<\"Mimas\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029284655536298783`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.8439466852489265, 0.3467106629502147, 
        0.3309221912517893]], {-132., 100.}], InsetBox[
     StyleBox["\<\"Rhea\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.031973410719180036`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[0.571589, 0.586483, 0.]], {-154., 41.}], InsetBox[
     StyleBox["\<\"Isonoe\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02923976615284284],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.529922539669161, 0.44454647619850335`, 0.85]], {-154., -62.}], 
    InsetBox[
     StyleBox["\<\"Kalyke\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02923976629478584],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.6102054708420535, 0.39696347534213544`, 
        0.7619863228948663]], {-140., -92.}], InsetBox[
     StyleBox["\<\"Carme\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239922201422974`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.428777913273419, 0.5052332520359486, 0.85]], {122., -114.}], InsetBox[
     StyleBox["\<\"Thebe\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029241540351566033`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.8878600487784333, 0.33792799024431336`, 
        0.2577332520359445]], {121., 116.}], InsetBox[
     StyleBox["\<\"Janus\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02924201231202442],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.6184987019729621, 0.39212575718243875`, 
        0.7412532450675947]], {154., -66.}], InsetBox[
     StyleBox["\<\"Skathi\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02923976643672883],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.8926354502560807, 0.366046824615879, 
        0.15658862564020168`]], {-120., 116.}], InsetBox[
     StyleBox["\<\"Portia\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029241756814633414`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.7678998606330495, 0.7317110956258943, 0.]], {-116., -121.}], InsetBox[
     StyleBox["\<\"Kiviuq\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239769967560832`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.969373377466199, 0.6043668873309952, 
        0.08269188084126262]], {-150., -76.}], InsetBox[
     StyleBox["\<\"Naiad\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239996721495354`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.9052934053395919, 0.510195603559728, 
        0.06776406480563275]], {-153., 75.}], InsetBox[
     StyleBox["\<\"Aitne\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239766117357093`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.9986489531525362, 0.7507447657626809, 
        0.0036478264881522893`]], {28., -27.}], InsetBox[
     StyleBox["\<\"Juliet\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029240426099055243`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.7132613816472081, 0.358, 0.5392132590042952]], {150., -78.}], 
    InsetBox[
     StyleBox["\<\"Elara\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029240795150842255`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.35558897405758294`, 0.5505288207539337, 
        0.8417067688690995]], {114., -126.}], InsetBox[
     StyleBox["\<\"Dione\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.030537000838353076`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.736782672705901, 0.358, 0.5030266573755369]], {154., 97.}], 
    InsetBox[
     StyleBox["\<\"Atlas\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239768548130884`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.31827505306025683`, 0.715, 0.3808317506505822]], {154., 74.}], 
    InsetBox[
     StyleBox["\<\"Leda\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239779016426763`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.5019668524892619, 0.46131988850644284`, 0.85]], {157., -90.}], 
    InsetBox[
     StyleBox["\<\"Metis\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239908007123474`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.9784200278733908, 0.649600139366954, 
        0.058265924741844846`]], {-148., -106.}], InsetBox[
     StyleBox["\<\"Puck\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.0292431922131704],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.7748409210981391, 0.358, 0.4444755060028629]], {155., -103.}], 
    InsetBox[
     StyleBox["\<\"Narvi\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02923976647221458],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.5788038738141875, 0.715, 0.049249615145579635`]], {-149., 112.}], 
    InsetBox[
     StyleBox["\<\"Ijiraq\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239767483558415`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.5750747800184488, 0.4174563783225715, 
        0.8498130499538777]], {-143., -118.}], InsetBox[
     StyleBox["\<\"Ariel\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.030841947620246835`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.40082222609352647`, 0.5220066643438841, 0.85]], {152., 107.}], 
    InsetBox[
     StyleBox["\<\"Ymir\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02923977191927701],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.9046334610863751, 0.334573307782725, 
        0.22977756485604156`]], {137., 125.}], InsetBox[
     StyleBox["\<\"Kale\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.029239766081871343`],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.6672593867853922, 0.7205288207539324, 0.]], {140., -126.}], 
    InsetBox[
     StyleBox["\<\"Pan\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->Scaled[0.02923977191927701],
      FontWeight->Plain,
      FontSlant->Plain,
      FontTracking->"Plain",
      FontColor->RGBColor[
       0.7175796237092107, 0.7261199581899123, 0.]], {-160., 87.}]}},
  Background->GrayLevel[0, 0],
  ImageSize->{200.1953125, 154.},
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultPlotStyle" -> Automatic},
  PlotRange->{{-171.5, 170.5}, {-133.5, 133.5}}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[49]=",ExpressionUUID->"f6b3da2f-d821-451c-9331-a884a33f324b"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Vocabulary", "VocabularySection",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"6c92142d-db3b-4676-8e56-89bd1faabd76"],

Cell[BoxData[GridBox[{
   {
    RowBox[{
     ButtonBox["Dataset",
      BaseStyle->"CodeLink"], "[", 
     StyleBox["data", "CodeVariableLrg"], "]"}], " ", Cell[
    "a dataset", "VocabularyText",ExpressionUUID->
     "54978097-33f4-4286-b36f-cf816412556e"]},
   {
    RowBox[{
     ButtonBox["Normal",
      BaseStyle->"CodeLink"], "[", 
     StyleBox["dataset", "CodeVariableLrg"], "]"}], " ", Cell[
    "convert a dataset to normal lists and associations", "VocabularyText",
     ExpressionUUID->"2c61a5f0-f5f6-4709-bc46-67331cf01a3f"]},
   {
    RowBox[{
     ButtonBox["Catenate",
      BaseStyle->"CodeLink"], "[", 
     RowBox[{"{", 
      RowBox[{
       SubscriptBox[
        StyleBox["assoc", "CodeVariableLrg"], "1"], ",", 
       StyleBox["...", "GrayPointSix"]}], "}"}], "]"}], " ", Cell[
    "catenate associations, combining their elements", "VocabularyText",
     ExpressionUUID->"5d36075c-3e82-49bc-86f9-161641f2919f"]},
   {
    RowBox[{
     StyleBox["f", "CodeVariableLrg"], 
     ButtonBox["@*",
      BaseStyle->"CodeLink",
      ButtonData->"Composition"], 
     StyleBox["g", "CodeVariableLrg"]}], " ", Cell[TextData[{
     "composition of functions (",
     Cell[BoxData[
      RowBox[{
       StyleBox["f", "CodeVariable"], "[", 
       RowBox[{
        StyleBox["g", "CodeVariable"], "[", 
        StyleBox["x", "CodeVariable"], "]"}], "]"}]], "InlineCode",
      ExpressionUUID->"dc00c24d-c234-4c69-ae64-80407712fb50"],
     " when applied to ",
     Cell[BoxData[
      StyleBox["x", "CodeVariable"]], "InlineCode",ExpressionUUID->
      "d1713bc2-789f-4883-9c54-659a8662407d"],
     ")"
    }], "VocabularyText",ExpressionUUID->
     "b49596c1-bae2-48ef-823e-190a244631fb"]},
   {
    RowBox[{
     StyleBox["f", "CodeVariableLrg"], 
     ButtonBox["/*",
      BaseStyle->"CodeLink",
      ButtonData->"RightComposition"], 
     StyleBox["g", "CodeVariableLrg"]}], " ", Cell[TextData[{
     "right composition (",
     Cell[BoxData[
      RowBox[{
       StyleBox["g", "CodeVariable"], "[", 
       RowBox[{
        StyleBox["f", "CodeVariable"], "[", 
        StyleBox["x", "CodeVariable"], "]"}], "]"}]], "InlineCode",
      ExpressionUUID->"73752441-c1ea-427d-9759-b5d8cf9ba361"],
     " when applied to ",
     Cell[BoxData[
      StyleBox["x", "CodeVariable"]], "InlineCode",ExpressionUUID->
      "723f823d-b23a-44e3-8f9b-01347ec3f00d"],
     ")"
    }], "VocabularyText",ExpressionUUID->
     "9c3b475c-2edd-4712-8f3b-8cab3380cf97"]}
  }]], "VocabularyTable",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 GridBoxOptions->{
 GridBoxDividers->{"Columns" -> {{False}}, "Rows" -> {False, {True, True, 
      Directive[
       Thickness[1.5], "VocabDivColor"], True, True}, 
     False}}},ExpressionUUID->"d82111fd-5835-4931-ae06-425c7f6a721a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 DynamicModuleBox[{$CellContext`open$$ = False}, 
  TagBox[GridBox[{
     {
      StyleBox["\<\"Exercises\"\>",
       StripOnInput->False,
       FontSlant->"Italic"], 
      PaneBox[
       TagBox[
        ButtonBox[
         DynamicBox[ToBoxes[
           If[$CellContext`open$$, 
            Row[{
              Style["-", "ExercisePreviewButtonTextHighlight"], 
              Style[" Preview Exercises", "ExercisePreviewButtonText"]}], 
            Row[{
              Style["+", "ExercisePreviewButtonTextHighlight"], 
              Style[" Preview Exercises", "ExercisePreviewButtonText"]}]], 
           StandardForm],
          ImageSizeCache->{115., {1., 10.}}],
         Appearance->None,
         ButtonFunction:>(
          If[$CellContext`open$$, $CellContext`open$$ = 
            False, $CellContext`open$$ = True]; NotebookFind[
            EvaluationNotebook[], "ExerciseSummaryCell", Next, CellStyle, 
            WrapAround -> True, AutoScroll -> False]; FrontEndTokenExecute[
            EvaluationNotebook[], "ExpandSelection"]; FrontEndExecute[
            FrontEndToken[
             EvaluationNotebook[], "OpenCloseGroup"]]),
         Evaluator->Automatic,
         Method->"Preemptive"],
        MouseAppearanceTag["LinkHand"]],
       Alignment->Right,
       ImageSize->Full]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {Left, Right}, "Rows" -> {{Center}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"],
  DynamicModuleValues:>{}]], "ExerciseSection",
 Editable->False,
 ShowCellBracket->False,
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{3.669991951589675*^9},
 ShowStringCharacters->
  False,ExpressionUUID->"f6437afe-f312-46c7-acb1-d630eca3547f"],

Cell[CellGroupData[{

Cell[BoxData[
 TagBox[GridBox[{
    {
     TagBox[GridBox[{
        {
         PaneBox[
          StyleBox["\<\"8 Exercises Available\"\>", "ExerciseSummaryHeading",
           StripOnInput->False],
          ImageMargins->{{20, 0}, {0, 10}}]}
       },
       DefaultBaseStyle->"Column",
       GridBoxAlignment->{"Columns" -> {{Left}}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
       
       GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{0}}}],
      "Column"], 
     PaneBox[
      ButtonBox[
       StyleBox["\<\"Get Started \[RightGuillemet]\"\>", 
        "ExerciseSummaryHeading",
        StripOnInput->False],
       Appearance->None,
       ButtonFunction:>NotebookLocate[{"EIWL1-45-datasets-exercises.nb", ""}],
       
       Evaluator->Automatic,
       Method->"Preemptive"],
      FrameMargins->{{10, 0}, {10, 10}},
      ImageSize->Full]}
   },
   AutoDelete->False,
   GridBoxAlignment->{"Columns" -> {{Left}}},
   GridBoxItemSize->{"Columns" -> {
       Scaled[0.7], 
       Scaled[0.3]}, "Rows" -> {{Automatic}}}],
  "Grid"]], "ExerciseSummaryCell",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"dae49f73-c8f4-449e-bbac-7adea862a001"],

Cell[TextData[{
 StyleBox["Note:",
  FontWeight->"Bold"],
 " These exercises use the dataset ",
 Cell[BoxData[
  RowBox[{"planets", "=", 
   RowBox[{
    ButtonBox["CloudGet",
     BaseStyle->"CodeLink"], "[", "\"\<http://wolfr.am/7FxLgPm5\>\"", 
    "]"}]}]], "InlineCodeText",ExpressionUUID->
  "6828452c-f237-4a29-af52-8d3f08a748ec"],
 "."
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"1bf7fbe3-4e4e-446f-ac52-c20ba5af8ea4"],

Cell[CellGroupData[{

Cell[TextData[{
 "Make a word cloud of the planets, with weights determined by their number \
of moons.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "45.1", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"51ff3254-0693-4ffb-9810-012e6c0cd5a4"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       GraphicsBox[{{}, {InsetBox[
           StyleBox["\<\"Jupiter\"\>",
            StripOnInput->False,
            FontFamily->"Helvetica",
            FontSize->Scaled[0.32710280373831774`],
            FontWeight->Plain,
            FontSlant->Plain,
            FontTracking->"Plain",
            FontColor->RGBColor[0.368417, 0.506779, 0.709798]], {0, 0}], 
          InsetBox[
           StyleBox["\<\"Saturn\"\>",
            StripOnInput->False,
            FontFamily->"Helvetica",
            FontSize->Scaled[0.28921444809295277`],
            FontWeight->Plain,
            FontSlant->Plain,
            FontTracking->"Plain",
            FontColor->RGBColor[0.880722, 0.611041, 0.142051]], {0., -53.5}], 
          InsetBox[
           StyleBox["\<\"Uranus\"\>",
            StripOnInput->False,
            FontFamily->"Helvetica",
            FontSize->Scaled[0.19828239454407678`],
            FontWeight->Plain,
            FontSlant->Plain,
            FontTracking->"Plain",
            FontColor->RGBColor[0.560181, 0.691569, 0.194885]], {0., 47.5}], 
          InsetBox[
           StyleBox["\<\"Neptune\"\>",
            StripOnInput->False,
            FontFamily->"Helvetica",
            FontSize->Scaled[0.0997726698661278],
            FontWeight->Plain,
            FontSlant->Plain,
            FontTracking->"Plain",
            FontColor->RGBColor[0.922526, 0.385626, 0.209179]], {7., 72.5}], 
          InsetBox[
           StyleBox["\<\"Mars\"\>",
            StripOnInput->False,
            FontFamily->"Helvetica",
            FontSize->Scaled[0.05430664309168982],
            FontWeight->Plain,
            FontSlant->Plain,
            FontTracking->"Plain",
            FontColor->RGBColor[0.528488, 0.470624, 0.701351]], {12., -27.5}],
           InsetBox[
           StyleBox["\<\"Earth\"\>",
            StripOnInput->False,
            FontFamily->"Helvetica",
            FontSize->Scaled[0.04672897196261682],
            FontWeight->Plain,
            FontSlant->Plain,
            FontTracking->"Plain",
            
            FontColor->RGBColor[
             0.772079, 0.431554, 0.102387]], {40., -27.5}]}},
        Background->GrayLevel[0, 0],
        ImageSize->{214., 158.},
        Method->{
         "DefaultBoundaryStyle" -> Automatic, "DefaultPlotStyle" -> Automatic},
        PlotRange->{{-107.5, 106.5}, {-74., 84.}}]], "ExerciseOutput",
       ExpressionUUID->"5ebd7bd5-3013-4fec-817c-1c5ed8c06b31"],
      Apply[TextCell, 
       Cell[
        BoxData[
         GraphicsBox[{{}, {
            InsetBox[
             StyleBox[
             "\"Jupiter\"", StripOnInput -> False, FontFamily -> "Helvetica", 
              FontSize -> Scaled[0.32710280373831774`], FontWeight -> Plain, 
              FontSlant -> Plain, FontTracking -> "Plain", FontColor -> 
              RGBColor[0.368417, 0.506779, 0.709798]], {0, 0}], 
            InsetBox[
             StyleBox[
             "\"Saturn\"", StripOnInput -> False, FontFamily -> "Helvetica", 
              FontSize -> Scaled[0.28921444809295277`], FontWeight -> Plain, 
              FontSlant -> Plain, FontTracking -> "Plain", FontColor -> 
              RGBColor[0.880722, 0.611041, 0.142051]], {0., -53.5}], 
            InsetBox[
             StyleBox[
             "\"Uranus\"", StripOnInput -> False, FontFamily -> "Helvetica", 
              FontSize -> Scaled[0.19828239454407678`], FontWeight -> Plain, 
              FontSlant -> Plain, FontTracking -> "Plain", FontColor -> 
              RGBColor[0.560181, 0.691569, 0.194885]], {0., 47.5}], 
            InsetBox[
             StyleBox[
             "\"Neptune\"", StripOnInput -> False, FontFamily -> "Helvetica", 
              FontSize -> Scaled[0.0997726698661278], FontWeight -> Plain, 
              FontSlant -> Plain, FontTracking -> "Plain", FontColor -> 
              RGBColor[0.922526, 0.385626, 0.209179]], {7., 72.5}], 
            InsetBox[
             StyleBox[
             "\"Mars\"", StripOnInput -> False, FontFamily -> "Helvetica", 
              FontSize -> Scaled[0.05430664309168982], FontWeight -> Plain, 
              FontSlant -> Plain, FontTracking -> "Plain", FontColor -> 
              RGBColor[0.528488, 0.470624, 0.701351]], {12., -27.5}], 
            InsetBox[
             StyleBox[
             "\"Earth\"", StripOnInput -> False, FontFamily -> "Helvetica", 
              FontSize -> Scaled[0.04672897196261682], FontWeight -> Plain, 
              FontSlant -> Plain, FontTracking -> "Plain", FontColor -> 
              RGBColor[0.772079, 0.431554, 0.102387]], {40., -27.5}]}}, 
          Background -> GrayLevel[0, 0], ImageSize -> {214., 158.}, 
          Method -> {
           "DefaultBoundaryStyle" -> Automatic, "DefaultPlotStyle" -> 
            Automatic}, PlotRange -> {{-107.5, 106.5}, {-74., 84.}}]], 
        "ExerciseOutput", Selectable -> False, Copyable -> False, Editable -> 
        False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"8ca14b3d-596d-4961-b6df-72a74b48a774"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Make a bar chart of the number of moons for each planet.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "45.2", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"b2c1894a-f885-4c68-a55e-14bd45af0d92"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       GraphicsBox[{{{{
            {Opacity[0], PointBox[{0.38380952380952377`, 0.}]}}}}, {{}, {{{
             {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
              0.644], Thickness[Small]}], {{{
                 {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
                  0.644], Thickness[Small]}], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{0.5421245421245421, 0.}, {
                    1.4578754578754578`, 0.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{20.28886554621849, 58.61201192647351}, {
                    99.62454973905864, 100.12454973905864`}}],
                    StatusArea[#, 0]& ,
                    TagBoxNote->"0"],
                    StyleBox["0", {}, StripOnInput -> False]],
                   Annotation[#, 
                    Style[0, {}], "Tooltip"]& ]}}}}, {{{
                 {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
                  0.644], Thickness[Small]}], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{1.542124542124542, 0.}, {
                    2.4578754578754576`, 0.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{61.591741393456964`, 
                    99.91488777371198}, {99.62454973905864, 
                    100.12454973905864`}}],
                    StatusArea[#, 0]& ,
                    TagBoxNote->"0"],
                    StyleBox["0", {}, StripOnInput -> False]],
                   Annotation[#, 
                    Style[0, {}], "Tooltip"]& ]}}}}, {{{
                 {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
                  0.644], Thickness[Small]}], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{2.542124542124542, 0.}, {
                    3.4578754578754576`, 1.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{102.89461724069545`, 
                    141.21776362095045`}, {94.26518599558217, 
                    100.12454973905864`}}],
                    StatusArea[#, 1]& ,
                    TagBoxNote->"1"],
                    StyleBox["1", {}, StripOnInput -> False]],
                   Annotation[#, 
                    Style[1, {}], "Tooltip"]& ]}}}}, {{{
                 {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
                  0.644], Thickness[Small]}], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{3.542124542124542, 0.}, {4.457875457875458, 
                    2.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{144.19749308793394`, 
                    182.52063946818896`}, {88.90582225210571, 
                    100.12454973905864`}}],
                    StatusArea[#, 2]& ,
                    TagBoxNote->"2"],
                    StyleBox["2", {}, StripOnInput -> False]],
                   Annotation[#, 
                    Style[2, {}], "Tooltip"]& ]}}}}, {{{
                 {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
                  0.644], Thickness[Small]}], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{4.542124542124542, 0.}, {5.457875457875458, 
                    38.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{185.50036893517242`, 
                    223.82351531542744`}, {-104.03127251304707`, 
                    100.12454973905864`}}],
                    StatusArea[#, 38]& ,
                    TagBoxNote->"38"],
                    StyleBox["38", {}, StripOnInput -> False]],
                   Annotation[#, 
                    Style[38, {}], "Tooltip"]& ]}}}}, {{{
                 {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
                  0.644], Thickness[Small]}], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{5.542124542124542, 0.}, {6.457875457875458, 
                    33.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{226.8032447824109, 
                    265.1263911626659}, {-77.23445379566476, 
                    100.12454973905864`}}],
                    StatusArea[#, 33]& ,
                    TagBoxNote->"33"],
                    StyleBox["33", {}, StripOnInput -> False]],
                   Annotation[#, 
                    Style[33, {}], "Tooltip"]& ]}}}}, {{{
                 {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
                  0.644], Thickness[Small]}], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{6.542124542124542, 0.}, {7.457875457875458, 
                    21.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{268.10612062964935`, 
                    306.42926700990444`}, {-12.92208887394716, 
                    100.12454973905864`}}],
                    StatusArea[#, 21]& ,
                    TagBoxNote->"21"],
                    StyleBox["21", {}, StripOnInput -> False]],
                   Annotation[#, 
                    Style[21, {}], "Tooltip"]& ]}}}}, {{{
                 {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
                  0.644], Thickness[Small]}], 
                  TagBox[
                   TooltipBox[
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{7.542124542124542, 0.}, {8.457875457875458, 
                    8.}, "RoundingRadius" -> 0]},
                    
                    ImageSizeCache->{{309.40899647688786`, 
                    347.7321428571429}, {56.749639791246906`, 
                    100.12454973905864`}}],
                    StatusArea[#, 8]& ,
                    TagBoxNote->"8"],
                    StyleBox["8", {}, StripOnInput -> False]],
                   Annotation[#, 
                    Style[8, {}], "Tooltip"]& ]}}}}}}}}, {}, {}}, {}, {}, 
         StyleBox[{{{{
              {Thickness[Tiny], 
               LineBox[{{0.38380952380952377`, 0.}, {8.619356776556776, 0.}}], 
               StyleBox[{}, "GraphicsLabel",
                StripOnInput->False]}}}}, 
           StyleBox[{{{{
                {Thickness[Tiny], 
                 LineBox[{{0.5421245421245421, 0.}, 
                   Offset[{-1.102182119232618*^-15, -6.}, {0.5421245421245421,
                     0.}]}], 
                 LineBox[{{8.457875457875458, 0.}, 
                   Offset[{-1.102182119232618*^-15, -6.}, {8.457875457875458, 
                    0.}]}], {{}, {}, {}, {}, {}, {}, {}, {}, {
                   LineBox[{{1.4578754578754578`, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    1.4578754578754578`, 0.}]}], 
                   LineBox[{{1.542124542124542, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {1.542124542124542,
                     0.}]}], 
                   LineBox[{{2.4578754578754576`, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    2.4578754578754576`, 0.}]}], 
                   LineBox[{{2.542124542124542, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {2.542124542124542,
                     0.}]}], 
                   LineBox[{{3.457875457875457, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {3.457875457875457,
                     0.}]}], 
                   LineBox[{{3.5421245421245415`, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    3.5421245421245415`, 0.}]}], 
                   LineBox[{{4.457875457875458, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {4.457875457875458,
                     0.}]}], 
                   LineBox[{{4.542124542124542, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {4.542124542124542,
                     0.}]}], 
                   LineBox[{{5.457875457875458, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {5.457875457875458,
                     0.}]}], 
                   LineBox[{{5.542124542124542, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {5.542124542124542,
                     0.}]}], 
                   LineBox[{{6.457875457875458, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {6.457875457875458,
                     0.}]}], 
                   LineBox[{{6.542124542124542, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {6.542124542124542,
                     0.}]}], 
                   LineBox[{{7.457875457875458, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {7.457875457875458,
                     0.}]}], 
                   LineBox[{{7.542124542124542, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {7.542124542124542,
                     0.}]}]}, {}}}}}}, 
             StyleBox[{{{
                 {Thickness[Tiny], 
                  InsetBox["\<\"Mercury\"\>", Offset[{0., -2.}, {1., 0.}], {0, 1},
                    Automatic, {1, 0}], 
                  InsetBox["\<\"Venus\"\>", Offset[{0., -2.}, {2., 0.}], {0, 1},
                    Automatic, {1, 0}], 
                  InsetBox["\<\"Earth\"\>", 
                   Offset[{0., -2.}, {2.9999999999999996, 0.}], {0, 1}, 
                   Automatic, {1, 0}], 
                  InsetBox["\<\"Mars\"\>", 
                   Offset[{0., -2.}, {3.9999999999999996, 0.}], {0, 1}, 
                   Automatic, {1, 0}], 
                  InsetBox["\<\"Jupiter\"\>", Offset[{0., -2.}, {5., 0.}], {0, 1},
                    Automatic, {1, 0}], 
                  InsetBox["\<\"Saturn\"\>", Offset[{0., -2.}, {6., 0.}], {0, 1},
                    Automatic, {1, 0}], 
                  InsetBox["\<\"Uranus\"\>", Offset[{0., -2.}, {7., 0.}], {0, 1},
                    Automatic, {1, 0}], 
                  InsetBox["\<\"Neptune\"\>", Offset[{0., -2.}, {8., 0.}], {0, 1},
                    Automatic, {1, 0}]}}}}, "GraphicsLabel",
              StripOnInput->False]}, "GraphicsTicks",
            StripOnInput->False]}, "GraphicsAxes",
          StripOnInput->False,
          Antialiasing->False]},
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->{False, True},
        AxesLabel->{None, None},
        AxesOrigin->{0.38380952380952377`, 0.},
        CoordinatesToolOptions:>{"DisplayFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& )},
        FrameLabel->{{None, None}, {None, None}},
        FrameTicks->{{Automatic, Automatic}, {{{1., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {1., 
             FormBox["\"Mercury\"", TraditionalForm], 0}, {
            1.9999999999999998`, 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {
            1.9999999999999998`, 
             FormBox["\"Venus\"", TraditionalForm], 0}, {3., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {3., 
             FormBox["\"Earth\"", TraditionalForm], 0}, {4., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {4., 
             FormBox["\"Mars\"", TraditionalForm], 0}, {5., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {5., 
             FormBox["\"Jupiter\"", TraditionalForm], 0}, {6., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {6., 
             FormBox["\"Saturn\"", TraditionalForm], 0}, {7., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {7., 
             FormBox["\"Uranus\"", TraditionalForm], 0}, {8., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {8., 
             FormBox["\"Neptune\"", TraditionalForm], 0}}, {{1., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {
            1.9999999999999998`, 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {3., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {4., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {5., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {6., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {7., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}, {8., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.004, 0}}}}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        ImageSize->{362.23828125, Automatic},
        PlotRange->{{All, All}, {All, All}},
        PlotRangePadding->{{
           Scaled[0.02], 
           Scaled[0.02]}, {
           Scaled[0.02], 
           Scaled[0.05]}},
        Ticks->{None, Automatic}]], "ExerciseOutput",ExpressionUUID->
       "0aa5e6a1-1830-4ad6-b423-1488dfa68fba"],
      Apply[TextCell, 
       Cell[
        BoxData[
         GraphicsBox[{{
            Opacity[0], 
            PointBox[{0.38380952380952377`, 0.}]}, {{}, {
             RGBColor[0.982864, 0.7431472, 0.3262672], 
             EdgeForm[{
               Opacity[0.644], 
               Thickness[Small]}], {
              RGBColor[0.982864, 0.7431472, 0.3262672], 
              EdgeForm[{
                Opacity[0.644], 
                Thickness[Small]}], 
              TagBox[
               TooltipBox[
                TagBox[
                 DynamicBox[{
                   FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                   
                   RectangleBox[{0.5421245421245421, 0.}, {
                    1.4578754578754578`, 0.}, "RoundingRadius" -> 0]}, 
                  ImageSizeCache -> {{21.270034484381984`, 
                   59.48425524087196}, {100.00717958917956`, 
                   100.50717958917956`}}], StatusArea[#, 0]& , TagBoxNote -> 
                 "0"], 
                StyleBox["0", {}, StripOnInput -> False]], Annotation[#, 
                Style[0, {}], "Tooltip"]& ]}, {
              RGBColor[0.982864, 0.7431472, 0.3262672], 
              EdgeForm[{
                Opacity[0.644], 
                Thickness[Small]}], 
              TagBox[
               TooltipBox[
                TagBox[
                 DynamicBox[{
                   FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                   
                   RectangleBox[{1.542124542124542, 0.}, {2.4578754578754576`,
                     0.}, "RoundingRadius" -> 0]}, 
                  ImageSizeCache -> {{62.453963550469034`, 
                   100.668184306959}, {100.00717958917956`, 
                   100.50717958917956`}}], StatusArea[#, 0]& , TagBoxNote -> 
                 "0"], 
                StyleBox["0", {}, StripOnInput -> False]], Annotation[#, 
                Style[0, {}], "Tooltip"]& ]}, {
              RGBColor[0.982864, 0.7431472, 0.3262672], 
              EdgeForm[{
                Opacity[0.644], 
                Thickness[Small]}], 
              TagBox[
               TooltipBox[
                TagBox[
                 DynamicBox[{
                   FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                   
                   RectangleBox[{2.542124542124542, 0.}, {3.4578754578754576`,
                     1.}, "RoundingRadius" -> 0]}, 
                  ImageSizeCache -> {{103.63789261655609`, 
                   141.85211337304608`}, {94.66325009945007, 
                   100.50717958917956`}}], StatusArea[#, 1]& , TagBoxNote -> 
                 "1"], 
                StyleBox["1", {}, StripOnInput -> False]], Annotation[#, 
                Style[1, {}], "Tooltip"]& ]}, {
              RGBColor[0.982864, 0.7431472, 0.3262672], 
              EdgeForm[{
                Opacity[0.644], 
                Thickness[Small]}], 
              TagBox[
               TooltipBox[
                TagBox[
                 DynamicBox[{
                   FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                   
                   RectangleBox[{3.542124542124542, 0.}, {4.457875457875458, 
                    2.}, "RoundingRadius" -> 0]}, 
                  ImageSizeCache -> {{144.82182168264316`, 
                   183.03604243913313`}, {89.31932060972058, 
                   100.50717958917956`}}], StatusArea[#, 2]& , TagBoxNote -> 
                 "2"], 
                StyleBox["2", {}, StripOnInput -> False]], Annotation[#, 
                Style[2, {}], "Tooltip"]& ]}, {
              RGBColor[0.982864, 0.7431472, 0.3262672], 
              EdgeForm[{
                Opacity[0.644], 
                Thickness[Small]}], 
              TagBox[
               TooltipBox[
                TagBox[
                 DynamicBox[{
                   FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                   
                   RectangleBox[{4.542124542124542, 0.}, {5.457875457875458, 
                    38.}, "RoundingRadius" -> 0]}, 
                  ImageSizeCache -> {{186.0057507487302, 
                   224.2199715052202}, {-103.06214102054103`, 
                   100.50717958917956`}}], StatusArea[#, 38]& , TagBoxNote -> 
                 "38"], 
                StyleBox["38", {}, StripOnInput -> False]], Annotation[#, 
                Style[38, {}], "Tooltip"]& ]}, {
              RGBColor[0.982864, 0.7431472, 0.3262672], 
              EdgeForm[{
                Opacity[0.644], 
                Thickness[Small]}], 
              TagBox[
               TooltipBox[
                TagBox[
                 DynamicBox[{
                   FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                   
                   RectangleBox[{5.542124542124542, 0.}, {6.457875457875458, 
                    33.}, "RoundingRadius" -> 0]}, 
                  ImageSizeCache -> {{227.18967981481725`, 
                   265.4039005713072}, {-76.34249357189357, 
                   100.50717958917956`}}], StatusArea[#, 33]& , TagBoxNote -> 
                 "33"], 
                StyleBox["33", {}, StripOnInput -> False]], Annotation[#, 
                Style[33, {}], "Tooltip"]& ]}, {
              RGBColor[0.982864, 0.7431472, 0.3262672], 
              EdgeForm[{
                Opacity[0.644], 
                Thickness[Small]}], 
              TagBox[
               TooltipBox[
                TagBox[
                 DynamicBox[{
                   FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                   
                   RectangleBox[{6.542124542124542, 0.}, {7.457875457875458, 
                    21.}, "RoundingRadius" -> 0]}, 
                  ImageSizeCache -> {{268.37360888090427`, 
                   306.5878296373943}, {-12.215339695139718`, 
                   100.50717958917956`}}], StatusArea[#, 21]& , TagBoxNote -> 
                 "21"], 
                StyleBox["21", {}, StripOnInput -> False]], Annotation[#, 
                Style[21, {}], "Tooltip"]& ]}, {
              RGBColor[0.982864, 0.7431472, 0.3262672], 
              EdgeForm[{
                Opacity[0.644], 
                Thickness[Small]}], 
              TagBox[
               TooltipBox[
                TagBox[
                 DynamicBox[{
                   FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                   
                   RectangleBox[{7.542124542124542, 0.}, {8.457875457875458, 
                    8.}, "RoundingRadius" -> 0]}, 
                  ImageSizeCache -> {{309.5575379469913, 
                   347.77175870348134`}, {57.255743671343645`, 
                   100.50717958917956`}}], StatusArea[#, 8]& , TagBoxNote -> 
                 "8"], 
                StyleBox["8", {}, StripOnInput -> False]], Annotation[#, 
                Style[8, {}], "Tooltip"]& ]}}, {}, {}}, {}, {}, 
           StyleBox[{{
              Thickness[Tiny], 
              LineBox[{{0.38380952380952377`, 0.}, {8.619356776556776, 0.}}], 
              
              StyleBox[{}, "GraphicsLabel", StripOnInput -> False]}, 
             StyleBox[{{
                Thickness[Tiny], 
                LineBox[{{0.5421245421245421, 0.}, 
                  
                  Offset[{-1.102182119232618*^-15, -6.}, {0.5421245421245421, 
                   0.}]}], 
                LineBox[{{8.457875457875458, 0.}, 
                  Offset[{-1.102182119232618*^-15, -6.}, {8.457875457875458, 
                   0.}]}], {{}, {}, {}, {}, {}, {}, {}, {}, {
                  LineBox[{{1.4578754578754578`, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    1.4578754578754578`, 0.}]}], 
                  LineBox[{{1.542124542124542, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {1.542124542124542,
                     0.}]}], 
                  LineBox[{{2.4578754578754576`, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    2.4578754578754576`, 0.}]}], 
                  LineBox[{{2.542124542124542, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {2.542124542124542,
                     0.}]}], 
                  LineBox[{{3.457875457875457, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {3.457875457875457,
                     0.}]}], 
                  LineBox[{{3.5421245421245415`, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {
                    3.5421245421245415`, 0.}]}], 
                  LineBox[{{4.457875457875458, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {4.457875457875458,
                     0.}]}], 
                  LineBox[{{4.542124542124542, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {4.542124542124542,
                     0.}]}], 
                  LineBox[{{5.457875457875458, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {5.457875457875458,
                     0.}]}], 
                  LineBox[{{5.542124542124542, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {5.542124542124542,
                     0.}]}], 
                  LineBox[{{6.457875457875458, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {6.457875457875458,
                     0.}]}], 
                  LineBox[{{6.542124542124542, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {6.542124542124542,
                     0.}]}], 
                  LineBox[{{7.457875457875458, 0.}, 
                    Offset[{-7.347880794884119*^-16, -4.}, {7.457875457875458,
                     0.}]}], 
                  LineBox[{{7.542124542124542, 0.}, 
                    
                    Offset[{-7.347880794884119*^-16, -4.}, {7.542124542124542,
                     0.}]}]}, {}}}, 
               StyleBox[{
                 Thickness[Tiny], 
                 InsetBox["\"Mercury\"", 
                  Offset[{0., -2.}, {1., 0.}], {0, 1}, Automatic, {1, 0}], 
                 InsetBox["\"Venus\"", 
                  Offset[{0., -2.}, {2., 0.}], {0, 1}, Automatic, {1, 0}], 
                 InsetBox["\"Earth\"", 
                  Offset[{0., -2.}, {2.9999999999999996`, 0.}], {0, 1}, 
                  Automatic, {1, 0}], 
                 InsetBox["\"Mars\"", 
                  Offset[{0., -2.}, {3.9999999999999996`, 0.}], {0, 1}, 
                  Automatic, {1, 0}], 
                 InsetBox["\"Jupiter\"", 
                  Offset[{0., -2.}, {5., 0.}], {0, 1}, Automatic, {1, 0}], 
                 InsetBox["\"Saturn\"", 
                  Offset[{0., -2.}, {6., 0.}], {0, 1}, Automatic, {1, 0}], 
                 InsetBox["\"Uranus\"", 
                  Offset[{0., -2.}, {7., 0.}], {0, 1}, Automatic, {1, 0}], 
                 InsetBox["\"Neptune\"", 
                  Offset[{0., -2.}, {8., 0.}], {0, 1}, Automatic, {1, 0}]}, 
                "GraphicsLabel", StripOnInput -> False]}, "GraphicsTicks", 
              StripOnInput -> False]}, "GraphicsAxes", StripOnInput -> False, 
            Antialiasing -> False]}, AspectRatio -> 
          NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {False, True},
           AxesLabel -> {None, None}, 
          AxesOrigin -> {0.38380952380952377`, 0.}, 
          CoordinatesToolOptions :> {"DisplayFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& )}, FrameLabel -> {{None, None}, {None, None}}, 
          FrameTicks -> {{Automatic, Automatic}, {{{1., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {1., 
               FormBox["\"Mercury\"", TraditionalForm], 0}, {
              1.9999999999999998`, 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {
              1.9999999999999998`, 
               FormBox["\"Venus\"", TraditionalForm], 0}, {3., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {3., 
               FormBox["\"Earth\"", TraditionalForm], 0}, {4., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {4., 
               FormBox["\"Mars\"", TraditionalForm], 0}, {5., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {5., 
               FormBox["\"Jupiter\"", TraditionalForm], 0}, {6., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {6., 
               FormBox["\"Saturn\"", TraditionalForm], 0}, {7., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {7., 
               FormBox["\"Uranus\"", TraditionalForm], 0}, {8., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {8., 
               FormBox["\"Neptune\"", TraditionalForm], 0}}, {{1., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {
              1.9999999999999998`, 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {3., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {4., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {5., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {6., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {7., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}, {8., 
               FormBox[
                InterpretationBox[
                 StyleBox[
                  
                  GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                   Baseline], "CacheGraphics" -> False], 
                 Spacer[0]], TraditionalForm], {0.004, 0}}}}}, 
          GridLines -> {None, None}, GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], ImageSize -> {362.23828125, Automatic}, 
          PlotRange -> {{All, All}, {All, All}}, PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, Ticks -> {None, Automatic}]], "ExerciseOutput", 
        Selectable -> False, Copyable -> False, Editable -> False, 
        ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"8373ceee-f9af-4eba-8ade-8cce550277a6"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Make a dataset of the masses of the planets, sorted by their number of \
moons.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "45.3", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"cd99c2da-2315-4762-9f06-e4c2d1708bf1"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       TagBox[
        TemplateBox[{GridBox[{{
             StyleBox[
              StyleBox["\"Mercury\"", FontColor -> GrayLevel[0.4]], 
              GrayLevel[0.3]], 
             
             TemplateBox[{
              "0.05527344653273921600664787001557157621`5.995678626217358", 
               SubscriptBox[
                StyleBox["\"M\"", Italic, StripOnInput -> False], 
                "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, "Quantity",
               SyntaxForm -> Mod]}, {
             StyleBox[
              StyleBox["\"Venus\"", FontColor -> GrayLevel[0.4]], 
              GrayLevel[0.3]], 
             
             TemplateBox[{
              "0.81499633987389501748987382971485302911`5.995678626217358", 
               SubscriptBox[
                StyleBox["\"M\"", Italic, StripOnInput -> False], 
                "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, "Quantity",
               SyntaxForm -> Mod]}, {
             StyleBox[
              StyleBox["\"Earth\"", FontColor -> GrayLevel[0.4]], 
              GrayLevel[0.3]], 
             
             TemplateBox[{
              "0.99999999999999999999999999999993500728`7.698970004336019", 
               SubscriptBox[
                StyleBox["\"M\"", Italic, StripOnInput -> False], 
                "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, "Quantity",
               SyntaxForm -> Mod]}, {
             StyleBox[
              StyleBox["\"Mars\"", FontColor -> GrayLevel[0.4]], 
              GrayLevel[0.3]], 
             
             TemplateBox[{
              "0.10744669475660102796983342114576670217`5.995678626217358", 
               SubscriptBox[
                StyleBox["\"M\"", Italic, StripOnInput -> False], 
                "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, "Quantity",
               SyntaxForm -> Mod]}, {
             StyleBox[
              StyleBox["\"Neptune\"", FontColor -> GrayLevel[0.4]], 
              GrayLevel[0.3]], 
             
             TemplateBox[{
              "17.14778875571887378293146513915216149975`5.995678626217358", 
               SubscriptBox[
                StyleBox["\"M\"", Italic, StripOnInput -> False], 
                "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, "Quantity",
               SyntaxForm -> Mod]}, {
             StyleBox[
              StyleBox["\"Uranus\"", FontColor -> GrayLevel[0.4]], 
              GrayLevel[0.3]], 
             
             TemplateBox[{
              "14.53573563343991942933712887578694351569`5.995678626217358", 
               SubscriptBox[
                StyleBox["\"M\"", Italic, StripOnInput -> False], 
                "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, "Quantity",
               SyntaxForm -> Mod]}, {
             StyleBox[
              StyleBox["\"Saturn\"", FontColor -> GrayLevel[0.4]], 
              GrayLevel[0.3]], 
             
             TemplateBox[{
              "95.160767091703882720845887476006418039`5.995678626217358", 
               SubscriptBox[
                StyleBox["\"M\"", Italic, StripOnInput -> False], 
                "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, "Quantity",
               SyntaxForm -> Mod]}, {
             StyleBox[
              StyleBox["\"Jupiter\"", FontColor -> GrayLevel[0.4]], 
              GrayLevel[0.3]], 
             
             TemplateBox[{
              "317.82767572397877056533250585469087303499`5.995678626217358", 
               
               SubscriptBox[
                StyleBox["\"M\"", Italic, StripOnInput -> False], 
                "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, "Quantity",
               SyntaxForm -> Mod]}, {
             ItemBox[
              RowBox[{"1 level", 
                AdjustmentBox[" | ", BoxBaselineShift -> -0.3], 
                RowBox[{"8", "elements"}]}], 
              BaseStyle -> {
               FontFamily -> "Helvetica", FontSize -> 10, FontColor -> 
                GrayLevel[0.4], Editable -> False, Selectable -> False}, 
              ItemSize -> {Automatic, Automatic}, Alignment -> {Left, Center},
               Background -> RGBColor[0.92, 0.92, 0.9]], "\[SpanFromLeft]"}}, 
           GridBoxFrame -> {"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
            FrameStyle -> RGBColor[0, 0, 0, 0.4], 
           GridBoxDividers -> {"Columns" -> {
               RGBColor[0, 0, 0, 0.4], 
               RGBColor[0, 0, 0, 0.3], {
                RGBColor[0, 0, 0, 0.09]}, 
               RGBColor[0, 0, 0, 0.4]}, "Rows" -> {
               RGBColor[0, 0, 0, 0.4], {
                RGBColor[0, 0, 0, 0.08]}, 
               RGBColor[0, 0, 0, 0.4]}}, RowSpacings -> 1.2, 
           GridBoxBackground -> {"Columns" -> {
               RGBColor[0.92, 0.92, 0.9]}}, 
           GridBoxAlignment -> {"Columns" -> {{Left}}}, ColumnSpacings -> 2.5,
            GridFrameMargins -> {{2, 3}, {1, 3}}, 
           GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
           RowMinHeight -> 1.3],
          "Dataset[Association[(_String -> Quantity[_, \"EarthMass\"])..]]"},
         "Dataset",
         DisplayFunction->(TagBox[
           
           StyleBox[#, {
            ShowAutoStyles -> False, LineBreakWithin -> False, FontWeight -> 
             "Light", FontFamily -> "Helvetica Neue", NumberMarks -> False, 
             SpanMaxSize -> 3, SpanMinSize -> 1., Editable -> False, 
             Selectable -> True, Background -> RGBColor[0.985, 0.98, 0.973], 
             LinebreakAdjustments -> {0.4, 5, 100, 0, 0.5}, LineIndent -> 0, 
             LineSpacing -> {1.1, 5}}], Deploy]& ),
         InterpretationFunction->(#2& )],
        False,
        Editable->False,
        SelectWithContents->True,
        Selectable->False]], "ExerciseOutput",ExpressionUUID->
       "6a798962-8232-45f0-a684-63038aa8fb55"],
      Apply[TextCell, 
       Cell[
        BoxData[
         TagBox[
          TemplateBox[{
            GridBox[{{
               StyleBox[
                StyleBox["\"Mercury\"", FontColor -> GrayLevel[0.4]], 
                GrayLevel[0.3]], 
               TemplateBox[{
                "0.05527344653273921600664787001557157621`5.995678626217358", 
                 
                 SubscriptBox[
                  StyleBox["\"M\"", Italic, StripOnInput -> False], 
                  "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, 
                "Quantity", SyntaxForm -> Mod]}, {
               StyleBox[
                StyleBox["\"Venus\"", FontColor -> GrayLevel[0.4]], 
                GrayLevel[0.3]], 
               
               TemplateBox[{
                "0.81499633987389501748987382971485302911`5.995678626217358", 
                 
                 SubscriptBox[
                  StyleBox["\"M\"", Italic, StripOnInput -> False], 
                  "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, 
                "Quantity", SyntaxForm -> Mod]}, {
               StyleBox[
                StyleBox["\"Earth\"", FontColor -> GrayLevel[0.4]], 
                GrayLevel[0.3]], 
               
               TemplateBox[{
                "0.99999999999999999999999999999993500728`7.698970004336019", 
                 
                 SubscriptBox[
                  StyleBox["\"M\"", Italic, StripOnInput -> False], 
                  "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, 
                "Quantity", SyntaxForm -> Mod]}, {
               StyleBox[
                StyleBox["\"Mars\"", FontColor -> GrayLevel[0.4]], 
                GrayLevel[0.3]], 
               
               TemplateBox[{
                "0.10744669475660102796983342114576670217`5.995678626217358", 
                 
                 SubscriptBox[
                  StyleBox["\"M\"", Italic, StripOnInput -> False], 
                  "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, 
                "Quantity", SyntaxForm -> Mod]}, {
               StyleBox[
                StyleBox["\"Neptune\"", FontColor -> GrayLevel[0.4]], 
                GrayLevel[0.3]], 
               
               TemplateBox[{
                "17.14778875571887378293146513915216149975`5.995678626217358", 
                 SubscriptBox[
                  StyleBox["\"M\"", Italic, StripOnInput -> False], 
                  "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, 
                "Quantity", SyntaxForm -> Mod]}, {
               StyleBox[
                StyleBox["\"Uranus\"", FontColor -> GrayLevel[0.4]], 
                GrayLevel[0.3]], 
               
               TemplateBox[{
                "14.53573563343991942933712887578694351569`5.995678626217358", 
                 SubscriptBox[
                  StyleBox["\"M\"", Italic, StripOnInput -> False], 
                  "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, 
                "Quantity", SyntaxForm -> Mod]}, {
               StyleBox[
                StyleBox["\"Saturn\"", FontColor -> GrayLevel[0.4]], 
                GrayLevel[0.3]], 
               
               TemplateBox[{
                "95.160767091703882720845887476006418039`5.995678626217358", 
                 SubscriptBox[
                  StyleBox["\"M\"", Italic, StripOnInput -> False], 
                  "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, 
                "Quantity", SyntaxForm -> Mod]}, {
               StyleBox[
                StyleBox["\"Jupiter\"", FontColor -> GrayLevel[0.4]], 
                GrayLevel[0.3]], 
               
               TemplateBox[{
                "317.82767572397877056533250585469087303499`5.\
995678626217358", 
                 SubscriptBox[
                  StyleBox["\"M\"", Italic, StripOnInput -> False], 
                  "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, 
                "Quantity", SyntaxForm -> Mod]}, {
               ItemBox[
                RowBox[{"1 level", 
                  AdjustmentBox[" | ", BoxBaselineShift -> -0.3], 
                  RowBox[{"8", "elements"}]}], 
                BaseStyle -> {
                 FontFamily -> "Helvetica", FontSize -> 10, FontColor -> 
                  GrayLevel[0.4], Editable -> False, Selectable -> False}, 
                ItemSize -> {Automatic, Automatic}, 
                Alignment -> {Left, Center}, Background -> 
                RGBColor[0.92, 0.92, 0.9]], "\[SpanFromLeft]"}}, 
             GridBoxFrame -> {
              "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}}, FrameStyle -> 
             RGBColor[0, 0, 0, 0.4], GridBoxDividers -> {"Columns" -> {
                 RGBColor[0, 0, 0, 0.4], 
                 RGBColor[0, 0, 0, 0.3], {
                  RGBColor[0, 0, 0, 0.09]}, 
                 RGBColor[0, 0, 0, 0.4]}, "Rows" -> {
                 RGBColor[0, 0, 0, 0.4], {
                  RGBColor[0, 0, 0, 0.08]}, 
                 RGBColor[0, 0, 0, 0.4]}}, RowSpacings -> 1.2, 
             GridBoxBackground -> {"Columns" -> {
                 RGBColor[0.92, 0.92, 0.9]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}}, ColumnSpacings -> 
             2.5, GridFrameMargins -> {{2, 3}, {1, 3}}, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             RowMinHeight -> 1.3], 
            "Dataset[Association[(_String -> Quantity[_, \
\"EarthMass\"])..]]"}, "Dataset", DisplayFunction -> (TagBox[
             
             StyleBox[#, {
              ShowAutoStyles -> False, LineBreakWithin -> False, FontWeight -> 
               "Light", FontFamily -> "Helvetica Neue", NumberMarks -> False, 
               SpanMaxSize -> 3, SpanMinSize -> 1., Editable -> False, 
               Selectable -> True, Background -> RGBColor[0.985, 0.98, 0.973],
                LinebreakAdjustments -> {0.4, 5, 100, 0, 0.5}, LineIndent -> 
               0, LineSpacing -> {1.1, 5}}], Deploy]& ), 
           InterpretationFunction -> (#2& )], False, Editable -> False, 
          SelectWithContents -> True, Selectable -> False]], "ExerciseOutput",
         Selectable -> False, Copyable -> False, Editable -> False, 
        ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"c5708874-ae11-447a-be7a-f393cb9a26e0"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Make a dataset of planets and the mass of each one\[CloseCurlyQuote]s most \
massive moon.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "45.4", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->False,
 CellTags->
  "LastCellOfAPage",ExpressionUUID->"30fa41be-2d99-43e1-b81a-54316f635ca6"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       TagBox[
        TemplateBox[{GridBox[{{
             StyleBox[
              StyleBox["\"Mercury\"", FontColor -> GrayLevel[0.4]], 
              GrayLevel[0.3]], 
             TooltipBox[
              FrameBox[
               RowBox[{"-", "\[Infinity]"}], FrameMargins -> {{0, 0}, {0, 0}},
                FrameStyle -> RGBColor[1, 0.9, 0.8]], 
              "Element with head DirectedInfinity is not of the form \
Quantity[_, \"EarthMass\"]."]}, {
             StyleBox[
              StyleBox["\"Venus\"", FontColor -> GrayLevel[0.4]], 
              GrayLevel[0.3]], 
             TooltipBox[
              FrameBox[
               RowBox[{"-", "\[Infinity]"}], FrameMargins -> {{0, 0}, {0, 0}},
                FrameStyle -> RGBColor[1, 0.9, 0.8]], 
              "Element with head DirectedInfinity is not of the form \
Quantity[_, \"EarthMass\"]."]}, {
             StyleBox[
              StyleBox["\"Earth\"", FontColor -> GrayLevel[0.4]], 
              GrayLevel[0.3]], 
             
             TemplateBox[{
              "0.01230016133804645640112692149922730729`4.995248844409004", 
               SubscriptBox[
                StyleBox["\"M\"", Italic, StripOnInput -> False], 
                "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, "Quantity",
               SyntaxForm -> Mod]}, {
             StyleBox[
              StyleBox["\"Mars\"", FontColor -> GrayLevel[0.4]], 
              GrayLevel[0.3]], 
             
             TemplateBox[{
              "1.79580111160409192458079582453`3.9585678353197324*^-9", 
               SubscriptBox[
                StyleBox["\"M\"", Italic, StripOnInput -> False], 
                "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, "Quantity",
               SyntaxForm -> Mod]}, {
             StyleBox[
              StyleBox["\"Jupiter\"", FontColor -> GrayLevel[0.4]], 
              GrayLevel[0.3]], 
             
             TemplateBox[{
              "0.02480662655568138400530235916802739469`4.995248844409004", 
               SubscriptBox[
                StyleBox["\"M\"", Italic, StripOnInput -> False], 
                "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, "Quantity",
               SyntaxForm -> Mod]}, {
             StyleBox[
              StyleBox["\"Saturn\"", FontColor -> GrayLevel[0.4]], 
              GrayLevel[0.3]], 
             
             TemplateBox[{
              "0.02252450905587139155679247739684866761`4.958212681028252", 
               SubscriptBox[
                StyleBox["\"M\"", Italic, StripOnInput -> False], 
                "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, "Quantity",
               SyntaxForm -> Mod]}, {
             StyleBox[
              StyleBox["\"Uranus\"", FontColor -> GrayLevel[0.4]], 
              GrayLevel[0.3]], 
             
             TemplateBox[{
              "0.00059032132098413359856644486002186379`3.9585678353197364", 
               SubscriptBox[
                StyleBox["\"M\"", Italic, StripOnInput -> False], 
                "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, "Quantity",
               SyntaxForm -> Mod]}, {
             StyleBox[
              StyleBox["\"Neptune\"", FontColor -> GrayLevel[0.4]], 
              GrayLevel[0.3]], 
             
             TemplateBox[{
              "0.00358231965249997605351902530501892712`4.6987529113637905", 
               SubscriptBox[
                StyleBox["\"M\"", Italic, StripOnInput -> False], 
                "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, "Quantity",
               SyntaxForm -> Mod]}, {
             ItemBox[
              RowBox[{"1 level", 
                AdjustmentBox[" | ", BoxBaselineShift -> -0.3], 
                RowBox[{"8", "elements"}]}], 
              BaseStyle -> {
               FontFamily -> "Helvetica", FontSize -> 10, FontColor -> 
                GrayLevel[0.4], Editable -> False, Selectable -> False}, 
              ItemSize -> {Automatic, Automatic}, Alignment -> {Left, Center},
               Background -> RGBColor[0.92, 0.92, 0.9]], "\[SpanFromLeft]"}}, 
           GridBoxFrame -> {"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
            FrameStyle -> RGBColor[0, 0, 0, 0.4], 
           GridBoxDividers -> {"Columns" -> {
               RGBColor[0, 0, 0, 0.4], 
               RGBColor[0, 0, 0, 0.3], {
                RGBColor[0, 0, 0, 0.09]}, 
               RGBColor[0, 0, 0, 0.4]}, "Rows" -> {
               RGBColor[0, 0, 0, 0.4], {
                RGBColor[0, 0, 0, 0.08]}, 
               RGBColor[0, 0, 0, 0.4]}}, RowSpacings -> 1.2, 
           GridBoxBackground -> {"Columns" -> {
               RGBColor[0.92, 0.92, 0.9]}}, 
           GridBoxAlignment -> {"Columns" -> {{Left}}}, ColumnSpacings -> 2.5,
            GridFrameMargins -> {{2, 3}, {1, 3}}, 
           GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
           RowMinHeight -> 1.3],
          "Dataset[Association[(_String -> Quantity[_, \"EarthMass\"])..]]"},
         "Dataset",
         DisplayFunction->(TagBox[
           
           StyleBox[#, {
            ShowAutoStyles -> False, LineBreakWithin -> False, FontWeight -> 
             "Light", FontFamily -> "Helvetica Neue", NumberMarks -> False, 
             SpanMaxSize -> 3, SpanMinSize -> 1., Editable -> False, 
             Selectable -> True, Background -> RGBColor[0.985, 0.98, 0.973], 
             LinebreakAdjustments -> {0.4, 5, 100, 0, 0.5}, LineIndent -> 0, 
             LineSpacing -> {1.1, 5}}], Deploy]& ),
         InterpretationFunction->(#2& )],
        False,
        Editable->False,
        SelectWithContents->True,
        Selectable->False]], "ExerciseOutput",ExpressionUUID->
       "b7afbeb4-4811-40f5-a319-007c47bf11fd"],
      Apply[TextCell, 
       Cell[
        BoxData[
         TagBox[
          TemplateBox[{
            GridBox[{{
               StyleBox[
                StyleBox["\"Mercury\"", FontColor -> GrayLevel[0.4]], 
                GrayLevel[0.3]], 
               TooltipBox[
                FrameBox[
                 RowBox[{"-", "\[Infinity]"}], 
                 FrameMargins -> {{0, 0}, {0, 0}}, FrameStyle -> 
                 RGBColor[1, 0.9, 0.8]], 
                "Element with head DirectedInfinity is not of the form \
Quantity[_, \"EarthMass\"]."]}, {
               StyleBox[
                StyleBox["\"Venus\"", FontColor -> GrayLevel[0.4]], 
                GrayLevel[0.3]], 
               TooltipBox[
                FrameBox[
                 RowBox[{"-", "\[Infinity]"}], 
                 FrameMargins -> {{0, 0}, {0, 0}}, FrameStyle -> 
                 RGBColor[1, 0.9, 0.8]], 
                "Element with head DirectedInfinity is not of the form \
Quantity[_, \"EarthMass\"]."]}, {
               StyleBox[
                StyleBox["\"Earth\"", FontColor -> GrayLevel[0.4]], 
                GrayLevel[0.3]], 
               
               TemplateBox[{
                "0.01230016133804645640112692149922730729`4.995248844409004", 
                 
                 SubscriptBox[
                  StyleBox["\"M\"", Italic, StripOnInput -> False], 
                  "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, 
                "Quantity", SyntaxForm -> Mod]}, {
               StyleBox[
                StyleBox["\"Mars\"", FontColor -> GrayLevel[0.4]], 
                GrayLevel[0.3]], 
               
               TemplateBox[{
                "1.79580111160409192458079582453`3.9585678353197324*^-9", 
                 SubscriptBox[
                  StyleBox["\"M\"", Italic, StripOnInput -> False], 
                  "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, 
                "Quantity", SyntaxForm -> Mod]}, {
               StyleBox[
                StyleBox["\"Jupiter\"", FontColor -> GrayLevel[0.4]], 
                GrayLevel[0.3]], 
               
               TemplateBox[{
                "0.02480662655568138400530235916802739469`4.995248844409004", 
                 
                 SubscriptBox[
                  StyleBox["\"M\"", Italic, StripOnInput -> False], 
                  "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, 
                "Quantity", SyntaxForm -> Mod]}, {
               StyleBox[
                StyleBox["\"Saturn\"", FontColor -> GrayLevel[0.4]], 
                GrayLevel[0.3]], 
               
               TemplateBox[{
                "0.02252450905587139155679247739684866761`4.958212681028252", 
                 
                 SubscriptBox[
                  StyleBox["\"M\"", Italic, StripOnInput -> False], 
                  "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, 
                "Quantity", SyntaxForm -> Mod]}, {
               StyleBox[
                StyleBox["\"Uranus\"", FontColor -> GrayLevel[0.4]], 
                GrayLevel[0.3]], 
               
               TemplateBox[{
                "0.00059032132098413359856644486002186379`3.9585678353197364", 
                 SubscriptBox[
                  StyleBox["\"M\"", Italic, StripOnInput -> False], 
                  "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, 
                "Quantity", SyntaxForm -> Mod]}, {
               StyleBox[
                StyleBox["\"Neptune\"", FontColor -> GrayLevel[0.4]], 
                GrayLevel[0.3]], 
               
               TemplateBox[{
                "0.00358231965249997605351902530501892712`4.6987529113637905", 
                 SubscriptBox[
                  StyleBox["\"M\"", Italic, StripOnInput -> False], 
                  "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, 
                "Quantity", SyntaxForm -> Mod]}, {
               ItemBox[
                RowBox[{"1 level", 
                  AdjustmentBox[" | ", BoxBaselineShift -> -0.3], 
                  RowBox[{"8", "elements"}]}], 
                BaseStyle -> {
                 FontFamily -> "Helvetica", FontSize -> 10, FontColor -> 
                  GrayLevel[0.4], Editable -> False, Selectable -> False}, 
                ItemSize -> {Automatic, Automatic}, 
                Alignment -> {Left, Center}, Background -> 
                RGBColor[0.92, 0.92, 0.9]], "\[SpanFromLeft]"}}, 
             GridBoxFrame -> {
              "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}}, FrameStyle -> 
             RGBColor[0, 0, 0, 0.4], GridBoxDividers -> {"Columns" -> {
                 RGBColor[0, 0, 0, 0.4], 
                 RGBColor[0, 0, 0, 0.3], {
                  RGBColor[0, 0, 0, 0.09]}, 
                 RGBColor[0, 0, 0, 0.4]}, "Rows" -> {
                 RGBColor[0, 0, 0, 0.4], {
                  RGBColor[0, 0, 0, 0.08]}, 
                 RGBColor[0, 0, 0, 0.4]}}, RowSpacings -> 1.2, 
             GridBoxBackground -> {"Columns" -> {
                 RGBColor[0.92, 0.92, 0.9]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}}, ColumnSpacings -> 
             2.5, GridFrameMargins -> {{2, 3}, {1, 3}}, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             RowMinHeight -> 1.3], 
            "Dataset[Association[(_String -> Quantity[_, \
\"EarthMass\"])..]]"}, "Dataset", DisplayFunction -> (TagBox[
             
             StyleBox[#, {
              ShowAutoStyles -> False, LineBreakWithin -> False, FontWeight -> 
               "Light", FontFamily -> "Helvetica Neue", NumberMarks -> False, 
               SpanMaxSize -> 3, SpanMinSize -> 1., Editable -> False, 
               Selectable -> True, Background -> RGBColor[0.985, 0.98, 0.973],
                LinebreakAdjustments -> {0.4, 5, 100, 0, 0.5}, LineIndent -> 
               0, LineSpacing -> {1.1, 5}}], Deploy]& ), 
           InterpretationFunction -> (#2& )], False, Editable -> False, 
          SelectWithContents -> True, Selectable -> False]], "ExerciseOutput",
         Selectable -> False, Copyable -> False, Editable -> False, 
        ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"835612ff-a666-4282-af2d-052637af60ce"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Make a dataset of masses of planets, where the planets are sorted by the \
largest mass of their moons.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "45.5", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"c56f7e2e-7d46-4fd9-8f51-e184a58fcd10"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       TagBox[
        TemplateBox[{GridBox[{{
             StyleBox[
              StyleBox["\"Mercury\"", FontColor -> GrayLevel[0.4]], 
              GrayLevel[0.3]], 
             TemplateBox[{"0", 
               SubscriptBox[
                StyleBox["\"M\"", Italic, StripOnInput -> False], 
                "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, "Quantity",
               SyntaxForm -> Mod]}, {
             StyleBox[
              StyleBox["\"Venus\"", FontColor -> GrayLevel[0.4]], 
              GrayLevel[0.3]], 
             TemplateBox[{"0", 
               SubscriptBox[
                StyleBox["\"M\"", Italic, StripOnInput -> False], 
                "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, "Quantity",
               SyntaxForm -> Mod]}, {
             StyleBox[
              StyleBox["\"Mars\"", FontColor -> GrayLevel[0.4]], 
              GrayLevel[0.3]], 
             
             TemplateBox[{
              "2.04166379522689299835687572227`2.885324039235817*^-9", 
               SubscriptBox[
                StyleBox["\"M\"", Italic, StripOnInput -> False], 
                "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, "Quantity",
               SyntaxForm -> Mod]}, {
             StyleBox[
              StyleBox["\"Uranus\"", FontColor -> GrayLevel[0.4]], 
              GrayLevel[0.3]], 
             
             TemplateBox[{
              "0.00153072639173862894057189795708694655`3.364747904287189", 
               SubscriptBox[
                StyleBox["\"M\"", Italic, StripOnInput -> False], 
                "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, "Quantity",
               SyntaxForm -> Mod]}, {
             StyleBox[
              StyleBox["\"Neptune\"", FontColor -> GrayLevel[0.4]], 
              GrayLevel[0.3]], 
             
             TemplateBox[{
              "0.00359781903677978896202707241196317041`4.537123375643805", 
               SubscriptBox[
                StyleBox["\"M\"", Italic, StripOnInput -> False], 
                "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, "Quantity",
               SyntaxForm -> Mod]}, {
             StyleBox[
              StyleBox["\"Earth\"", FontColor -> GrayLevel[0.4]], 
              GrayLevel[0.3]], 
             
             TemplateBox[{
              "0.01230016133804645640112692149922730729`4.995248844409004", 
               SubscriptBox[
                StyleBox["\"M\"", Italic, StripOnInput -> False], 
                "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, "Quantity",
               SyntaxForm -> Mod]}, {
             StyleBox[
              StyleBox["\"Saturn\"", FontColor -> GrayLevel[0.4]], 
              GrayLevel[0.3]], 
             
             TemplateBox[{
              "0.02352739951889508060941283216744272444`4.924394335943824", 
               SubscriptBox[
                StyleBox["\"M\"", Italic, StripOnInput -> False], 
                "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, "Quantity",
               SyntaxForm -> Mod]}, {
             StyleBox[
              StyleBox["\"Jupiter\"", FontColor -> GrayLevel[0.4]], 
              GrayLevel[0.3]], 
             
             TemplateBox[{
              "0.06580733862818021716336684549470626106`4.983164919320384", 
               SubscriptBox[
                StyleBox["\"M\"", Italic, StripOnInput -> False], 
                "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, "Quantity",
               SyntaxForm -> Mod]}, {
             ItemBox[
              RowBox[{"1 level", 
                AdjustmentBox[" | ", BoxBaselineShift -> -0.3], 
                RowBox[{"8", "elements"}]}], 
              BaseStyle -> {
               FontFamily -> "Helvetica", FontSize -> 10, FontColor -> 
                GrayLevel[0.4], Editable -> False, Selectable -> False}, 
              ItemSize -> {Automatic, Automatic}, Alignment -> {Left, Center},
               Background -> RGBColor[0.92, 0.92, 0.9]], "\[SpanFromLeft]"}}, 
           GridBoxFrame -> {"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
            FrameStyle -> RGBColor[0, 0, 0, 0.4], 
           GridBoxDividers -> {"Columns" -> {
               RGBColor[0, 0, 0, 0.4], 
               RGBColor[0, 0, 0, 0.3], {
                RGBColor[0, 0, 0, 0.09]}, 
               RGBColor[0, 0, 0, 0.4]}, "Rows" -> {
               RGBColor[0, 0, 0, 0.4], {
                RGBColor[0, 0, 0, 0.08]}, 
               RGBColor[0, 0, 0, 0.4]}}, RowSpacings -> 1.2, 
           GridBoxBackground -> {"Columns" -> {
               RGBColor[0.92, 0.92, 0.9]}}, 
           GridBoxAlignment -> {"Columns" -> {{Left}}}, ColumnSpacings -> 2.5,
            GridFrameMargins -> {{2, 3}, {1, 3}}, 
           GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
           RowMinHeight -> 1.3],
          "Dataset[Association[(_String -> Quantity[_, \"EarthMass\"])..]]"},
         "Dataset",
         DisplayFunction->(TagBox[
           
           StyleBox[#, {
            ShowAutoStyles -> False, LineBreakWithin -> False, FontWeight -> 
             "Light", FontFamily -> "Helvetica Neue", NumberMarks -> False, 
             SpanMaxSize -> 3, SpanMinSize -> 1., Editable -> False, 
             Selectable -> True, Background -> RGBColor[0.985, 0.98, 0.973], 
             LinebreakAdjustments -> {0.4, 5, 100, 0, 0.5}, LineIndent -> 0, 
             LineSpacing -> {1.1, 5}}], Deploy]& ),
         InterpretationFunction->(#2& )],
        False,
        Editable->False,
        SelectWithContents->True,
        Selectable->False]], "ExerciseOutput",ExpressionUUID->
       "ffad8244-4f51-4fc4-998b-a030fbe147a2"],
      Apply[TextCell, 
       Cell[
        BoxData[
         TagBox[
          TemplateBox[{
            GridBox[{{
               StyleBox[
                StyleBox["\"Mercury\"", FontColor -> GrayLevel[0.4]], 
                GrayLevel[0.3]], 
               TemplateBox[{"0", 
                 SubscriptBox[
                  StyleBox["\"M\"", Italic, StripOnInput -> False], 
                  "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, 
                "Quantity", SyntaxForm -> Mod]}, {
               StyleBox[
                StyleBox["\"Venus\"", FontColor -> GrayLevel[0.4]], 
                GrayLevel[0.3]], 
               TemplateBox[{"0", 
                 SubscriptBox[
                  StyleBox["\"M\"", Italic, StripOnInput -> False], 
                  "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, 
                "Quantity", SyntaxForm -> Mod]}, {
               StyleBox[
                StyleBox["\"Mars\"", FontColor -> GrayLevel[0.4]], 
                GrayLevel[0.3]], 
               
               TemplateBox[{
                "2.04166379522689299835687572227`2.885324039235817*^-9", 
                 SubscriptBox[
                  StyleBox["\"M\"", Italic, StripOnInput -> False], 
                  "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, 
                "Quantity", SyntaxForm -> Mod]}, {
               StyleBox[
                StyleBox["\"Uranus\"", FontColor -> GrayLevel[0.4]], 
                GrayLevel[0.3]], 
               
               TemplateBox[{
                "0.00153072639173862894057189795708694655`3.364747904287189", 
                 
                 SubscriptBox[
                  StyleBox["\"M\"", Italic, StripOnInput -> False], 
                  "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, 
                "Quantity", SyntaxForm -> Mod]}, {
               StyleBox[
                StyleBox["\"Neptune\"", FontColor -> GrayLevel[0.4]], 
                GrayLevel[0.3]], 
               
               TemplateBox[{
                "0.00359781903677978896202707241196317041`4.537123375643805", 
                 
                 SubscriptBox[
                  StyleBox["\"M\"", Italic, StripOnInput -> False], 
                  "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, 
                "Quantity", SyntaxForm -> Mod]}, {
               StyleBox[
                StyleBox["\"Earth\"", FontColor -> GrayLevel[0.4]], 
                GrayLevel[0.3]], 
               
               TemplateBox[{
                "0.01230016133804645640112692149922730729`4.995248844409004", 
                 
                 SubscriptBox[
                  StyleBox["\"M\"", Italic, StripOnInput -> False], 
                  "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, 
                "Quantity", SyntaxForm -> Mod]}, {
               StyleBox[
                StyleBox["\"Saturn\"", FontColor -> GrayLevel[0.4]], 
                GrayLevel[0.3]], 
               
               TemplateBox[{
                "0.02352739951889508060941283216744272444`4.924394335943824", 
                 
                 SubscriptBox[
                  StyleBox["\"M\"", Italic, StripOnInput -> False], 
                  "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, 
                "Quantity", SyntaxForm -> Mod]}, {
               StyleBox[
                StyleBox["\"Jupiter\"", FontColor -> GrayLevel[0.4]], 
                GrayLevel[0.3]], 
               
               TemplateBox[{
                "0.06580733862818021716336684549470626106`4.983164919320384", 
                 
                 SubscriptBox[
                  StyleBox["\"M\"", Italic, StripOnInput -> False], 
                  "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, 
                "Quantity", SyntaxForm -> Mod]}, {
               ItemBox[
                RowBox[{"1 level", 
                  AdjustmentBox[" | ", BoxBaselineShift -> -0.3], 
                  RowBox[{"8", "elements"}]}], 
                BaseStyle -> {
                 FontFamily -> "Helvetica", FontSize -> 10, FontColor -> 
                  GrayLevel[0.4], Editable -> False, Selectable -> False}, 
                ItemSize -> {Automatic, Automatic}, 
                Alignment -> {Left, Center}, Background -> 
                RGBColor[0.92, 0.92, 0.9]], "\[SpanFromLeft]"}}, 
             GridBoxFrame -> {
              "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}}, FrameStyle -> 
             RGBColor[0, 0, 0, 0.4], GridBoxDividers -> {"Columns" -> {
                 RGBColor[0, 0, 0, 0.4], 
                 RGBColor[0, 0, 0, 0.3], {
                  RGBColor[0, 0, 0, 0.09]}, 
                 RGBColor[0, 0, 0, 0.4]}, "Rows" -> {
                 RGBColor[0, 0, 0, 0.4], {
                  RGBColor[0, 0, 0, 0.08]}, 
                 RGBColor[0, 0, 0, 0.4]}}, RowSpacings -> 1.2, 
             GridBoxBackground -> {"Columns" -> {
                 RGBColor[0.92, 0.92, 0.9]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}}, ColumnSpacings -> 
             2.5, GridFrameMargins -> {{2, 3}, {1, 3}}, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             RowMinHeight -> 1.3], 
            "Dataset[Association[(_String -> Quantity[_, \
\"EarthMass\"])..]]"}, "Dataset", DisplayFunction -> (TagBox[
             
             StyleBox[#, {
              ShowAutoStyles -> False, LineBreakWithin -> False, FontWeight -> 
               "Light", FontFamily -> "Helvetica Neue", NumberMarks -> False, 
               SpanMaxSize -> 3, SpanMinSize -> 1., Editable -> False, 
               Selectable -> True, Background -> RGBColor[0.985, 0.98, 0.973],
                LinebreakAdjustments -> {0.4, 5, 100, 0, 0.5}, LineIndent -> 
               0, LineSpacing -> {1.1, 5}}], Deploy]& ), 
           InterpretationFunction -> (#2& )], False, Editable -> False, 
          SelectWithContents -> True, Selectable -> False]], "ExerciseOutput",
         Selectable -> False, Copyable -> False, Editable -> False, 
        ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"27e53d26-8dfe-48d0-8228-48ac8ed8971c"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Make a dataset of the median mass of all moons for each planet.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "45.6", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"f0827408-96d0-4b43-b327-0c99aae86c4a"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       TagBox[
        TemplateBox[{GridBox[{{
             StyleBox[
              StyleBox["\"Mercury\"", FontColor -> GrayLevel[0.4]], 
              GrayLevel[0.3]], 
             InterpretationBox[
              StyleBox[
              "Indeterminate", FontFamily -> "Arial", FontSize -> 11, 
               FontWeight -> Bold, 
               GrayLevel[0.7]], 
              Missing["Indeterminate"]]}, {
             StyleBox[
              StyleBox["\"Venus\"", FontColor -> GrayLevel[0.4]], 
              GrayLevel[0.3]], 
             InterpretationBox[
              StyleBox[
              "Indeterminate", FontFamily -> "Arial", FontSize -> 11, 
               FontWeight -> Bold, 
               GrayLevel[0.7]], 
              Missing["Indeterminate"]]}, {
             StyleBox[
              StyleBox["\"Earth\"", FontColor -> GrayLevel[0.4]], 
              GrayLevel[0.3]], 
             
             TemplateBox[{
              "0.01230016133804645640112692149922730729`4.995248844409004", 
               SubscriptBox[
                StyleBox["\"M\"", Italic, StripOnInput -> False], 
                "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, "Quantity",
               SyntaxForm -> Mod]}, {
             StyleBox[
              StyleBox["\"Mars\"", FontColor -> GrayLevel[0.4]], 
              GrayLevel[0.3]], 
             
             TemplateBox[{
              "1.02083189761344649917843786114`1.9995654886602736*^-9", 
               SubscriptBox[
                StyleBox["\"M\"", Italic, StripOnInput -> False], 
                "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, "Quantity",
               SyntaxForm -> Mod]}, {
             StyleBox[
              StyleBox["\"Jupiter\"", FontColor -> GrayLevel[0.4]], 
              GrayLevel[0.3]], 
             
             TemplateBox[{
              "5.268486077631451580915997809`0.9999565292980389*^-11", 
               SubscriptBox[
                StyleBox["\"M\"", Italic, StripOnInput -> False], 
                "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, "Quantity",
               SyntaxForm -> Mod]}, {
             StyleBox[
              StyleBox["\"Saturn\"", FontColor -> GrayLevel[0.4]], 
              GrayLevel[0.3]], 
             
             TemplateBox[{
              "1.37984159176061827119228514039`0.999999956570554*^-9", 
               SubscriptBox[
                StyleBox["\"M\"", Italic, StripOnInput -> False], 
                "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, "Quantity",
               SyntaxForm -> Mod]}, {
             StyleBox[
              StyleBox["\"Uranus\"", FontColor -> GrayLevel[0.4]], 
              GrayLevel[0.3]], 
             
             TemplateBox[{
              "5.745158627512392438236969039065`0.9999565292980337*^-8", 
               SubscriptBox[
                StyleBox["\"M\"", Italic, StripOnInput -> False], 
                "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, "Quantity",
               SyntaxForm -> Mod]}, {
             StyleBox[
              StyleBox["\"Neptune\"", FontColor -> GrayLevel[0.4]], 
              GrayLevel[0.3]], 
             
             TemplateBox[{
              "7.2755283929196236117407415084953`1.999565488660279*^-7", 
               SubscriptBox[
                StyleBox["\"M\"", Italic, StripOnInput -> False], 
                "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, "Quantity",
               SyntaxForm -> Mod]}, {
             ItemBox[
              RowBox[{"1 level", 
                AdjustmentBox[" | ", BoxBaselineShift -> -0.3], 
                RowBox[{"8", "elements"}]}], 
              BaseStyle -> {
               FontFamily -> "Helvetica", FontSize -> 10, FontColor -> 
                GrayLevel[0.4], Editable -> False, Selectable -> False}, 
              ItemSize -> {Automatic, Automatic}, Alignment -> {Left, Center},
               Background -> RGBColor[0.92, 0.92, 0.9]], "\[SpanFromLeft]"}}, 
           GridBoxFrame -> {"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
            FrameStyle -> RGBColor[0, 0, 0, 0.4], 
           GridBoxDividers -> {"Columns" -> {
               RGBColor[0, 0, 0, 0.4], 
               RGBColor[0, 0, 0, 0.3], {
                RGBColor[0, 0, 0, 0.09]}, 
               RGBColor[0, 0, 0, 0.4]}, "Rows" -> {
               RGBColor[0, 0, 0, 0.4], {
                RGBColor[0, 0, 0, 0.08]}, 
               RGBColor[0, 0, 0, 0.4]}}, RowSpacings -> 1.2, 
           GridBoxBackground -> {"Columns" -> {
               RGBColor[0.92, 0.92, 0.9]}}, 
           GridBoxAlignment -> {"Columns" -> {{Left}}}, ColumnSpacings -> 2.5,
            GridFrameMargins -> {{2, 3}, {1, 3}}, 
           GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
           RowMinHeight -> 1.3],
          "Dataset[Association[(_String -> Quantity[_, \"EarthMass\"])..]]"},
         "Dataset",
         DisplayFunction->(TagBox[
           
           StyleBox[#, {
            ShowAutoStyles -> False, LineBreakWithin -> False, FontWeight -> 
             "Light", FontFamily -> "Helvetica Neue", NumberMarks -> False, 
             SpanMaxSize -> 3, SpanMinSize -> 1., Editable -> False, 
             Selectable -> True, Background -> RGBColor[0.985, 0.98, 0.973], 
             LinebreakAdjustments -> {0.4, 5, 100, 0, 0.5}, LineIndent -> 0, 
             LineSpacing -> {1.1, 5}}], Deploy]& ),
         InterpretationFunction->(#2& )],
        False,
        Editable->False,
        SelectWithContents->True,
        Selectable->False]], "ExerciseOutput",ExpressionUUID->
       "e1a9f827-d928-4669-87ec-7ba1d4e0c2a5"],
      Apply[TextCell, 
       Cell[
        BoxData[
         TagBox[
          TemplateBox[{
            GridBox[{{
               StyleBox[
                StyleBox["\"Mercury\"", FontColor -> GrayLevel[0.4]], 
                GrayLevel[0.3]], 
               InterpretationBox[
                StyleBox[
                "Indeterminate", FontFamily -> "Arial", FontSize -> 11, 
                 FontWeight -> Bold, 
                 GrayLevel[0.7]], 
                Missing["Indeterminate"]]}, {
               StyleBox[
                StyleBox["\"Venus\"", FontColor -> GrayLevel[0.4]], 
                GrayLevel[0.3]], 
               InterpretationBox[
                StyleBox[
                "Indeterminate", FontFamily -> "Arial", FontSize -> 11, 
                 FontWeight -> Bold, 
                 GrayLevel[0.7]], 
                Missing["Indeterminate"]]}, {
               StyleBox[
                StyleBox["\"Earth\"", FontColor -> GrayLevel[0.4]], 
                GrayLevel[0.3]], 
               
               TemplateBox[{
                "0.01230016133804645640112692149922730729`4.995248844409004", 
                 
                 SubscriptBox[
                  StyleBox["\"M\"", Italic, StripOnInput -> False], 
                  "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, 
                "Quantity", SyntaxForm -> Mod]}, {
               StyleBox[
                StyleBox["\"Mars\"", FontColor -> GrayLevel[0.4]], 
                GrayLevel[0.3]], 
               
               TemplateBox[{
                "1.02083189761344649917843786114`1.9995654886602736*^-9", 
                 SubscriptBox[
                  StyleBox["\"M\"", Italic, StripOnInput -> False], 
                  "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, 
                "Quantity", SyntaxForm -> Mod]}, {
               StyleBox[
                StyleBox["\"Jupiter\"", FontColor -> GrayLevel[0.4]], 
                GrayLevel[0.3]], 
               
               TemplateBox[{
                "5.268486077631451580915997809`0.9999565292980389*^-11", 
                 SubscriptBox[
                  StyleBox["\"M\"", Italic, StripOnInput -> False], 
                  "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, 
                "Quantity", SyntaxForm -> Mod]}, {
               StyleBox[
                StyleBox["\"Saturn\"", FontColor -> GrayLevel[0.4]], 
                GrayLevel[0.3]], 
               
               TemplateBox[{
                "1.37984159176061827119228514039`0.999999956570554*^-9", 
                 SubscriptBox[
                  StyleBox["\"M\"", Italic, StripOnInput -> False], 
                  "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, 
                "Quantity", SyntaxForm -> Mod]}, {
               StyleBox[
                StyleBox["\"Uranus\"", FontColor -> GrayLevel[0.4]], 
                GrayLevel[0.3]], 
               
               TemplateBox[{
                "5.745158627512392438236969039065`0.9999565292980337*^-8", 
                 SubscriptBox[
                  StyleBox["\"M\"", Italic, StripOnInput -> False], 
                  "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, 
                "Quantity", SyntaxForm -> Mod]}, {
               StyleBox[
                StyleBox["\"Neptune\"", FontColor -> GrayLevel[0.4]], 
                GrayLevel[0.3]], 
               
               TemplateBox[{
                "7.2755283929196236117407415084953`1.999565488660279*^-7", 
                 SubscriptBox[
                  StyleBox["\"M\"", Italic, StripOnInput -> False], 
                  "\"\[Earth]\""], "Earth masses", "\"EarthMass\""}, 
                "Quantity", SyntaxForm -> Mod]}, {
               ItemBox[
                RowBox[{"1 level", 
                  AdjustmentBox[" | ", BoxBaselineShift -> -0.3], 
                  RowBox[{"8", "elements"}]}], 
                BaseStyle -> {
                 FontFamily -> "Helvetica", FontSize -> 10, FontColor -> 
                  GrayLevel[0.4], Editable -> False, Selectable -> False}, 
                ItemSize -> {Automatic, Automatic}, 
                Alignment -> {Left, Center}, Background -> 
                RGBColor[0.92, 0.92, 0.9]], "\[SpanFromLeft]"}}, 
             GridBoxFrame -> {
              "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}}, FrameStyle -> 
             RGBColor[0, 0, 0, 0.4], GridBoxDividers -> {"Columns" -> {
                 RGBColor[0, 0, 0, 0.4], 
                 RGBColor[0, 0, 0, 0.3], {
                  RGBColor[0, 0, 0, 0.09]}, 
                 RGBColor[0, 0, 0, 0.4]}, "Rows" -> {
                 RGBColor[0, 0, 0, 0.4], {
                  RGBColor[0, 0, 0, 0.08]}, 
                 RGBColor[0, 0, 0, 0.4]}}, RowSpacings -> 1.2, 
             GridBoxBackground -> {"Columns" -> {
                 RGBColor[0.92, 0.92, 0.9]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}}, ColumnSpacings -> 
             2.5, GridFrameMargins -> {{2, 3}, {1, 3}}, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             RowMinHeight -> 1.3], 
            "Dataset[Association[(_String -> Quantity[_, \
\"EarthMass\"])..]]"}, "Dataset", DisplayFunction -> (TagBox[
             
             StyleBox[#, {
              ShowAutoStyles -> False, LineBreakWithin -> False, FontWeight -> 
               "Light", FontFamily -> "Helvetica Neue", NumberMarks -> False, 
               SpanMaxSize -> 3, SpanMinSize -> 1., Editable -> False, 
               Selectable -> True, Background -> RGBColor[0.985, 0.98, 0.973],
                LinebreakAdjustments -> {0.4, 5, 100, 0, 0.5}, LineIndent -> 
               0, LineSpacing -> {1.1, 5}}], Deploy]& ), 
           InterpretationFunction -> (#2& )], False, Editable -> False, 
          SelectWithContents -> True, Selectable -> False]], "ExerciseOutput",
         Selectable -> False, Copyable -> False, Editable -> False, 
        ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"d7fd717f-f783-4043-9bf4-1a1214ab473a"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "For each planet, make a list of moons larger in mass than 0.0001 Earth \
masses.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "45.7", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"aa58695b-4438-4abf-b1ec-22f971033261"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       TagBox[
        TemplateBox[{GridBox[{{
             StyleBox[
              StyleBox["\"Mercury\"", FontColor -> GrayLevel[0.4]], 
              GrayLevel[0.3]], 
             StyleBox[
              RowBox[{"{", "\[ThinSpace]", "\[ThinSpace]", "}"}], 
              LineBreakWithin -> Automatic]}, {
             StyleBox[
              StyleBox["\"Venus\"", FontColor -> GrayLevel[0.4]], 
              GrayLevel[0.3]], 
             StyleBox[
              RowBox[{"{", "\[ThinSpace]", "\[ThinSpace]", "}"}], 
              LineBreakWithin -> Automatic]}, {
             StyleBox[
              StyleBox["\"Earth\"", FontColor -> GrayLevel[0.4]], 
              GrayLevel[0.3]], 
             StyleBox[
              RowBox[{"{", "\[ThinSpace]", 
                StyleBox["\"Moon\"", FontColor -> GrayLevel[0.4]], 
                "\[ThinSpace]", "}"}], LineBreakWithin -> Automatic]}, {
             StyleBox[
              StyleBox["\"Mars\"", FontColor -> GrayLevel[0.4]], 
              GrayLevel[0.3]], 
             StyleBox[
              RowBox[{"{", "\[ThinSpace]", "\[ThinSpace]", "}"}], 
              LineBreakWithin -> Automatic]}, {
             StyleBox[
              StyleBox["\"Jupiter\"", FontColor -> GrayLevel[0.4]], 
              GrayLevel[0.3]], 
             StyleBox[
              RowBox[{"{", "\[ThinSpace]", 
                StyleBox["\"Ganymede\"", FontColor -> GrayLevel[0.4]], ",", 
                StyleBox["\"Callisto\"", FontColor -> GrayLevel[0.4]], ",", 
                StyleBox["\"Io\"", FontColor -> GrayLevel[0.4]], ",", 
                StyleBox["\"Europa\"", FontColor -> GrayLevel[0.4]], 
                "\[ThinSpace]", "}"}], LineBreakWithin -> Automatic]}, {
             StyleBox[
              StyleBox["\"Saturn\"", FontColor -> GrayLevel[0.4]], 
              GrayLevel[0.3]], 
             StyleBox[
              RowBox[{"{", "\[ThinSpace]", 
                StyleBox["\"Titan\"", FontColor -> GrayLevel[0.4]], ",", 
                StyleBox["\"Rhea\"", FontColor -> GrayLevel[0.4]], ",", 
                StyleBox["\"Iapetus\"", FontColor -> GrayLevel[0.4]], ",", 
                StyleBox["\"Dione\"", FontColor -> GrayLevel[0.4]], ",", 
                StyleBox["\"Tethys\"", FontColor -> GrayLevel[0.4]], 
                "\[ThinSpace]", "}"}], LineBreakWithin -> Automatic]}, {
             StyleBox[
              StyleBox["\"Uranus\"", FontColor -> GrayLevel[0.4]], 
              GrayLevel[0.3]], 
             StyleBox[
              RowBox[{"{", "\[ThinSpace]", 
                StyleBox["\"Titania\"", FontColor -> GrayLevel[0.4]], ",", 
                StyleBox["\"Oberon\"", FontColor -> GrayLevel[0.4]], ",", 
                StyleBox["\"Ariel\"", FontColor -> GrayLevel[0.4]], ",", 
                StyleBox["\"Umbriel\"", FontColor -> GrayLevel[0.4]], 
                "\[ThinSpace]", "}"}], LineBreakWithin -> Automatic]}, {
             StyleBox[
              StyleBox["\"Neptune\"", FontColor -> GrayLevel[0.4]], 
              GrayLevel[0.3]], 
             StyleBox[
              RowBox[{"{", "\[ThinSpace]", 
                StyleBox["\"Triton\"", FontColor -> GrayLevel[0.4]], 
                "\[ThinSpace]", "}"}], LineBreakWithin -> Automatic]}, {
             ItemBox[
              RowBox[{"2 levels", 
                AdjustmentBox[" | ", BoxBaselineShift -> -0.3], 
                RowBox[{"8", "rows"}]}], 
              BaseStyle -> {
               FontFamily -> "Helvetica", FontSize -> 10, FontColor -> 
                GrayLevel[0.4], Editable -> False, Selectable -> False}, 
              ItemSize -> {Automatic, Automatic}, Alignment -> {Left, Center},
               Background -> RGBColor[0.92, 0.92, 0.9]], "\[SpanFromLeft]"}}, 
           GridBoxFrame -> {"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
            FrameStyle -> RGBColor[0, 0, 0, 0.4], 
           GridBoxDividers -> {"Columns" -> {
               RGBColor[0, 0, 0, 0.4], 
               RGBColor[0, 0, 0, 0.3], {
                RGBColor[0, 0, 0, 0.09]}, 
               RGBColor[0, 0, 0, 0.4]}, "Rows" -> {
               RGBColor[0, 0, 0, 0.4], {
                RGBColor[0, 0, 0, 0.08]}, 
               RGBColor[0, 0, 0, 0.4]}}, RowSpacings -> 1.2, 
           GridBoxBackground -> {"Columns" -> {
               RGBColor[0.92, 0.92, 0.9]}}, 
           GridBoxAlignment -> {"Columns" -> {{Left}}}, ColumnSpacings -> 2.5,
            GridFrameMargins -> {{2, 3}, {1, 3}}, 
           GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
           RowMinHeight -> 1.3],"Dataset[Association[(_String -> _List)..]]"},
         
         "Dataset",
         DisplayFunction->(TagBox[
           
           StyleBox[#, {
            ShowAutoStyles -> False, LineBreakWithin -> False, FontWeight -> 
             "Light", FontFamily -> "Helvetica Neue", NumberMarks -> False, 
             SpanMaxSize -> 3, SpanMinSize -> 1., Editable -> False, 
             Selectable -> True, Background -> RGBColor[0.985, 0.98, 0.973], 
             LinebreakAdjustments -> {0.4, 5, 100, 0, 0.5}, LineIndent -> 0, 
             LineSpacing -> {1.1, 5}}], Deploy]& ),
         InterpretationFunction->(#2& )],
        False,
        Editable->False,
        SelectWithContents->True,
        Selectable->False]], "ExerciseOutput",ExpressionUUID->
       "09486c66-826f-4305-85c1-246b60565fe6"],
      Apply[TextCell, 
       Cell[
        BoxData[
         TagBox[
          TemplateBox[{
            GridBox[{{
               StyleBox[
                StyleBox["\"Mercury\"", FontColor -> GrayLevel[0.4]], 
                GrayLevel[0.3]], 
               StyleBox[
                RowBox[{"{", "\[ThinSpace]", "\[ThinSpace]", "}"}], 
                LineBreakWithin -> Automatic]}, {
               StyleBox[
                StyleBox["\"Venus\"", FontColor -> GrayLevel[0.4]], 
                GrayLevel[0.3]], 
               StyleBox[
                RowBox[{"{", "\[ThinSpace]", "\[ThinSpace]", "}"}], 
                LineBreakWithin -> Automatic]}, {
               StyleBox[
                StyleBox["\"Earth\"", FontColor -> GrayLevel[0.4]], 
                GrayLevel[0.3]], 
               StyleBox[
                RowBox[{"{", "\[ThinSpace]", 
                  StyleBox["\"Moon\"", FontColor -> GrayLevel[0.4]], 
                  "\[ThinSpace]", "}"}], LineBreakWithin -> Automatic]}, {
               StyleBox[
                StyleBox["\"Mars\"", FontColor -> GrayLevel[0.4]], 
                GrayLevel[0.3]], 
               StyleBox[
                RowBox[{"{", "\[ThinSpace]", "\[ThinSpace]", "}"}], 
                LineBreakWithin -> Automatic]}, {
               StyleBox[
                StyleBox["\"Jupiter\"", FontColor -> GrayLevel[0.4]], 
                GrayLevel[0.3]], 
               StyleBox[
                RowBox[{"{", "\[ThinSpace]", 
                  StyleBox["\"Ganymede\"", FontColor -> GrayLevel[0.4]], ",", 
                  
                  StyleBox["\"Callisto\"", FontColor -> GrayLevel[0.4]], ",", 
                  
                  StyleBox["\"Io\"", FontColor -> GrayLevel[0.4]], ",", 
                  StyleBox["\"Europa\"", FontColor -> GrayLevel[0.4]], 
                  "\[ThinSpace]", "}"}], LineBreakWithin -> Automatic]}, {
               StyleBox[
                StyleBox["\"Saturn\"", FontColor -> GrayLevel[0.4]], 
                GrayLevel[0.3]], 
               StyleBox[
                RowBox[{"{", "\[ThinSpace]", 
                  StyleBox["\"Titan\"", FontColor -> GrayLevel[0.4]], ",", 
                  StyleBox["\"Rhea\"", FontColor -> GrayLevel[0.4]], ",", 
                  StyleBox["\"Iapetus\"", FontColor -> GrayLevel[0.4]], ",", 
                  StyleBox["\"Dione\"", FontColor -> GrayLevel[0.4]], ",", 
                  StyleBox["\"Tethys\"", FontColor -> GrayLevel[0.4]], 
                  "\[ThinSpace]", "}"}], LineBreakWithin -> Automatic]}, {
               StyleBox[
                StyleBox["\"Uranus\"", FontColor -> GrayLevel[0.4]], 
                GrayLevel[0.3]], 
               StyleBox[
                RowBox[{"{", "\[ThinSpace]", 
                  StyleBox["\"Titania\"", FontColor -> GrayLevel[0.4]], ",", 
                  StyleBox["\"Oberon\"", FontColor -> GrayLevel[0.4]], ",", 
                  StyleBox["\"Ariel\"", FontColor -> GrayLevel[0.4]], ",", 
                  StyleBox["\"Umbriel\"", FontColor -> GrayLevel[0.4]], 
                  "\[ThinSpace]", "}"}], LineBreakWithin -> Automatic]}, {
               StyleBox[
                StyleBox["\"Neptune\"", FontColor -> GrayLevel[0.4]], 
                GrayLevel[0.3]], 
               StyleBox[
                RowBox[{"{", "\[ThinSpace]", 
                  StyleBox["\"Triton\"", FontColor -> GrayLevel[0.4]], 
                  "\[ThinSpace]", "}"}], LineBreakWithin -> Automatic]}, {
               ItemBox[
                RowBox[{"2 levels", 
                  AdjustmentBox[" | ", BoxBaselineShift -> -0.3], 
                  RowBox[{"8", "rows"}]}], 
                BaseStyle -> {
                 FontFamily -> "Helvetica", FontSize -> 10, FontColor -> 
                  GrayLevel[0.4], Editable -> False, Selectable -> False}, 
                ItemSize -> {Automatic, Automatic}, 
                Alignment -> {Left, Center}, Background -> 
                RGBColor[0.92, 0.92, 0.9]], "\[SpanFromLeft]"}}, 
             GridBoxFrame -> {
              "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}}, FrameStyle -> 
             RGBColor[0, 0, 0, 0.4], GridBoxDividers -> {"Columns" -> {
                 RGBColor[0, 0, 0, 0.4], 
                 RGBColor[0, 0, 0, 0.3], {
                  RGBColor[0, 0, 0, 0.09]}, 
                 RGBColor[0, 0, 0, 0.4]}, "Rows" -> {
                 RGBColor[0, 0, 0, 0.4], {
                  RGBColor[0, 0, 0, 0.08]}, 
                 RGBColor[0, 0, 0, 0.4]}}, RowSpacings -> 1.2, 
             GridBoxBackground -> {"Columns" -> {
                 RGBColor[0.92, 0.92, 0.9]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}}, ColumnSpacings -> 
             2.5, GridFrameMargins -> {{2, 3}, {1, 3}}, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             RowMinHeight -> 1.3], 
            "Dataset[Association[(_String -> _List)..]]"}, "Dataset", 
           DisplayFunction -> (TagBox[
             
             StyleBox[#, {
              ShowAutoStyles -> False, LineBreakWithin -> False, FontWeight -> 
               "Light", FontFamily -> "Helvetica Neue", NumberMarks -> False, 
               SpanMaxSize -> 3, SpanMinSize -> 1., Editable -> False, 
               Selectable -> True, Background -> RGBColor[0.985, 0.98, 0.973],
                LinebreakAdjustments -> {0.4, 5, 100, 0, 0.5}, LineIndent -> 
               0, LineSpacing -> {1.1, 5}}], Deploy]& ), 
           InterpretationFunction -> (#2& )], False, Editable -> False, 
          SelectWithContents -> True, Selectable -> False]], "ExerciseOutput",
         Selectable -> False, Copyable -> False, Editable -> False, 
        ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"41a65d5c-5d6c-42ab-bcf8-db7a1d8e9ef0"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Make a word cloud of countries in Central America, with the names of \
countries proportional to the lengths of the Wikipedia article about them.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "45.8", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"60c74ee8-90b0-4e8e-b5d0-4d35393a1bb7"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Sample", " ", "expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       GraphicsBox[{{}, {InsetBox[
           StyleBox["\<\"Guatemala\"\>",
            StripOnInput->False,
            FontFamily->"Helvetica",
            FontSize->Scaled[0.19886363636363638`],
            FontWeight->Plain,
            FontSlant->Plain,
            FontTracking->"Plain",
            FontColor->RGBColor[0.368417, 0.506779, 0.709798]], {0, 0}], 
          InsetBox[
           StyleBox["\<\"El Salvador\"\>",
            StripOnInput->False,
            FontFamily->"Helvetica",
            FontSize->Scaled[0.18423365121141416`],
            FontWeight->Plain,
            FontSlant->Plain,
            FontTracking->"Plain",
            FontColor->RGBColor[0.880722, 0.611041, 0.142051]], {0., -54.5}], 
          InsetBox[
           StyleBox["\<\"Nicaragua\"\>",
            StripOnInput->False,
            FontFamily->"Helvetica",
            FontSize->Scaled[0.13436183774798602`],
            FontWeight->Plain,
            FontSlant->Plain,
            FontTracking->"Plain",
            FontColor->RGBColor[0.560181, 0.691569, 0.194885]], {0., 46.5}], 
          InsetBox[
           StyleBox["\<\"Panama\"\>",
            StripOnInput->False,
            FontFamily->"Helvetica",
            FontSize->Scaled[0.11573041976356105`],
            FontWeight->Plain,
            FontSlant->Plain,
            FontTracking->"Plain",
            FontColor->RGBColor[0.528488, 0.470624, 0.701351]], {11., 73.5}], 
          InsetBox[
           StyleBox["\<\"Belize\"\>",
            StripOnInput->False,
            FontFamily->"Helvetica",
            FontSize->Scaled[0.12020666764786093`],
            FontWeight->Plain,
            FontSlant->Plain,
            FontTracking->"Plain",
            
            FontColor->RGBColor[
             0.922526, 0.385626, 0.209179]], {-123., 83.5}], InsetBox[
           StyleBox["\<\"Costa Rica\"\>",
            StripOnInput->False,
            FontFamily->"Helvetica",
            FontSize->Scaled[0.0399548073468363],
            FontWeight->Plain,
            FontSlant->Plain,
            FontTracking->"Plain",
            FontColor->RGBColor[0.772079, 0.431554, 0.102387]], {4., -83.5}], 
          InsetBox[
           StyleBox["\<\"Honduras\"\>",
            StripOnInput->False,
            FontFamily->"Helvetica",
            FontSize->Scaled[0.02840909090909091],
            FontWeight->Plain,
            FontSlant->Plain,
            FontTracking->"Plain",
            
            FontColor->RGBColor[
             0.363898, 0.618501, 0.782349]], {27., -27.5}]}},
        Method->{
         "DefaultBoundaryStyle" -> Automatic, "DefaultPlotStyle" -> Automatic},
        PlotRange->{{-180.5, 171.5}, {-90., 105.}}]], "ExerciseOutput",
       ExpressionUUID->"f3a01881-8704-4c0b-8b9a-ce0102bd0ceb"],
      Apply[TextCell, 
       Cell[
        BoxData[
         GraphicsBox[{{}, {
            InsetBox[
             StyleBox[
             "\"Guatemala\"", StripOnInput -> False, FontFamily -> 
              "Helvetica", FontSize -> Scaled[0.19886363636363638`], 
              FontWeight -> Plain, FontSlant -> Plain, FontTracking -> 
              "Plain", FontColor -> RGBColor[0.368417, 0.506779, 0.709798]], {
             0, 0}], 
            InsetBox[
             StyleBox[
             "\"El Salvador\"", StripOnInput -> False, FontFamily -> 
              "Helvetica", FontSize -> Scaled[0.18423365121141416`], 
              FontWeight -> Plain, FontSlant -> Plain, FontTracking -> 
              "Plain", FontColor -> RGBColor[0.880722, 0.611041, 0.142051]], {
             0., -54.5}], 
            InsetBox[
             StyleBox[
             "\"Nicaragua\"", StripOnInput -> False, FontFamily -> 
              "Helvetica", FontSize -> Scaled[0.13436183774798602`], 
              FontWeight -> Plain, FontSlant -> Plain, FontTracking -> 
              "Plain", FontColor -> RGBColor[0.560181, 0.691569, 0.194885]], {
             0., 46.5}], 
            InsetBox[
             StyleBox[
             "\"Panama\"", StripOnInput -> False, FontFamily -> "Helvetica", 
              FontSize -> Scaled[0.11573041976356105`], FontWeight -> Plain, 
              FontSlant -> Plain, FontTracking -> "Plain", FontColor -> 
              RGBColor[0.528488, 0.470624, 0.701351]], {11., 73.5}], 
            InsetBox[
             StyleBox[
             "\"Belize\"", StripOnInput -> False, FontFamily -> "Helvetica", 
              FontSize -> Scaled[0.12020666764786093`], FontWeight -> Plain, 
              FontSlant -> Plain, FontTracking -> "Plain", FontColor -> 
              RGBColor[0.922526, 0.385626, 0.209179]], {-123., 83.5}], 
            InsetBox[
             StyleBox[
             "\"Costa Rica\"", StripOnInput -> False, FontFamily -> 
              "Helvetica", FontSize -> Scaled[0.0399548073468363], FontWeight -> 
              Plain, FontSlant -> Plain, FontTracking -> "Plain", FontColor -> 
              RGBColor[0.772079, 0.431554, 0.102387]], {4., -83.5}], 
            InsetBox[
             StyleBox[
             "\"Honduras\"", StripOnInput -> False, FontFamily -> "Helvetica",
               FontSize -> Scaled[0.02840909090909091], FontWeight -> Plain, 
              FontSlant -> Plain, FontTracking -> "Plain", FontColor -> 
              RGBColor[0.363898, 0.618501, 0.782349]], {27., -27.5}]}}, 
          Method -> {
           "DefaultBoundaryStyle" -> Automatic, "DefaultPlotStyle" -> 
            Automatic}, PlotRange -> {{-180.5, 171.5}, {-90., 105.}}]], 
        "ExerciseOutput", Selectable -> False, Copyable -> False, Editable -> 
        False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"50030b03-d45d-4ae3-88d5-6a4d56123b8c"]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Q&A", "QASection",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"p:282",ExpressionUUID->"183acc82-52bc-4d90-8beb-601a886c3e6d"],

Cell["What kinds of data can datasets contain?", "Question",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"27ae4f7c-cae0-413d-929b-45326b3bcaf8"],

Cell["\<\
Any kinds. Not just numbers and text but also images, graphs and lots more. \
There\[CloseCurlyQuote]s no need for all elements of a particular row or \
column to be the same type.\
\>", "Answer",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"9e04f265-542a-4f25-a3d7-41efaebef88a"],

Cell["Can I turn spreadsheets into datasets?", "Question",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:26",ExpressionUUID->"2a8af4f9-901e-4494-b14e-b68c718b4fdd"],

Cell[TextData[{
 "Yes. ",
 ButtonBox["SemanticImport",
  BaseStyle->"Link"],
 " is often a good way to do it. "
}], "Answer",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"5555afc6-afab-45d2-9be3-5f88789cd0e5"],

Cell[TextData[{
 "What are databases and how do they relate to ",
 ButtonBox["Dataset",
  BaseStyle->"Link"],
 "?"
}], "Question",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"201359bd-2a59-4eb3-aa90-9300b427cabd"],

Cell[TextData[{
 "Databases are a traditional way to store structured data in a computer \
system. Databases are often set up to allow both reading and writing of data. \
",
 ButtonBox["Dataset",
  BaseStyle->"Link"],
 " is a way to represent data that might be stored in a database so that it\
\[CloseCurlyQuote]s easy to manipulate with the Wolfram Language. "
}], "Answer",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:27",ExpressionUUID->"eaaa3260-ec22-43a3-877a-1a32ce1aa32f"],

Cell[TextData[{
 "How does data in ",
 ButtonBox["Dataset",
  BaseStyle->"Link"],
 " compare to data in an SQL (relational) database?"
}], "Question",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:28",ExpressionUUID->"cb2a1140-5cd9-4c9d-a6f3-3903672ef4df"],

Cell[TextData[{
 "SQL databases are strictly based on tables of data arranged in rows and \
columns of particular types, with additional data linked in through \
\[OpenCurlyDoubleQuote]foreign keys\[CloseCurlyDoubleQuote]. ",
 ButtonBox["Dataset",
  BaseStyle->"Link"],
 " can have any mixture of types of data, with any number of levels of \
nesting, and any hierarchical structure, somewhat more analogous to a NoSQL \
database, but with additional operations made possible by the symbolic nature \
of the language. "
}], "Answer",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"108a05db-27c1-478b-9c18-6628f3c6e159"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Tech Notes", "TechNoteSection",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"6e7e3fac-ae11-46a8-b005-4fbd062ef113"],

Cell[TextData[{
 ButtonBox["Dataset",
  BaseStyle->"Link"],
 " supports a new kind of ",
 StyleBox["symbolic database structure",
  FontSlant->"Italic"],
 " which generalizes both ",
 StyleBox["relational",
  FontSlant->"Italic"],
 " and ",
 StyleBox["hierarchical databases",
  FontSlant->"Italic"],
 "."
}], "TechNote",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:29",ExpressionUUID->"1b905e65-6889-46a4-ac00-dfddb9c1551c"],

Cell[TextData[{
 ButtonBox["Dataset",
  BaseStyle->"Link"],
 " has many additional mechanisms and capabilities that we haven\
\[CloseCurlyQuote]t discussed."
}], "TechNote",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"60cc95cf-817f-47ef-b0c4-f909cf2556ec"],

Cell[TextData[{
 "Everything that can be done with queries on datasets can also be done by \
using functions like ",
 ButtonBox["Map",
  BaseStyle->"Link"],
 " and ",
 ButtonBox["Apply",
  BaseStyle->"Link"],
 " on underlying lists and association\[LongDash]but it\[CloseCurlyQuote]s \
typically much simpler with dataset queries."
}], "TechNote",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"b424403d-09bd-48fb-bb2d-47ca21475e0c"],

Cell[TextData[{
 "You can connect the Wolfram Language directly to SQL \
databases\[LongDash]and do queries with SQL syntax\[LongDash]using ",
 ButtonBox["DatabaseLink",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/DatabaseLink/guide/\
SQLDatabaseOperations.html"], None},
  ButtonNote->
   "http://reference.wolfram.com/language/DatabaseLink/guide/\
SQLDatabaseOperations.html"],
 ". "
}], "TechNote",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:30",ExpressionUUID->"98061f78-570f-4941-9192-a5cef97a7d4d"]
}, Open  ]],

Cell[CellGroupData[{

Cell["More to Explore", "MoreExploreSection",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"e3edf3c2-2901-4e41-b59f-b920c0561aeb"],

Cell[TextData[ButtonBox["Guide to Computation with Structured Datasets in the \
Wolfram Language\[NonBreakingSpace]\[RightGuillemet]",
 BaseStyle->"Link",
 ButtonData->{
  "paclet:guide/ComputationWithStructuredDatasets", None}]], "MoreExplore",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->
  "LastCellOfAPage",ExpressionUUID->"157cf999-448f-4342-b8ae-ad3f08534f89"]
}, Open  ]]
},
Saveable->False,
WindowToolbars->{},
BlinkingCellInsertionPoint->False,
CellInsertionPointCell->None,
WindowSize->{830, 800},
WindowMargins->Automatic,
WindowPersistentStyles->{
 WindowFrame, WindowMargins, WindowSize, Magnification},
WindowTitle->"Datasets: Elementary Introduction to the Wolfram Language",
DockedCells->{
  Cell[
   BoxData[
    TagBox[
     GridBox[{{
        TemplateBox[{
         "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]", 
          "\"\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\"", 
          GraphicsBox[
           TagBox[
            RasterBox[CompressedData["
1:eJztl01IVFEUxyctMFzUysjIyUDCTauiIJFM6ENpM4NEtJrBUaSYZMYPhCRm
rYuoICgiW0VEBVIUEbTNEMTAIqRsk6JGCVFBHx7//+4JLo/36DqvB4Ie+Mk7
7+t3733nHpzq9NlEW0ksFsuX4U8i1duQy6X6kpuRtGTzHe3ZTOuxbFemPZPb
ny7FyZ2gEqwHInICfJToguOIReywPVHHlYDzcY4hJHZ486giyBOXtfms5Pms
Bs9zUBDTow6DJOgBT8DP/+B5CepAPbgqZm+zT70Bt9VXCx6H8DwE28Gw5ufB
IT2eA1N6PKquC0V4xtUxqfkE6ARD4BHYAx5Y938Gu8GdZXq4VsNWngIfwDzY
Aa6Bm55nOKYq8NXRw29eb+Uz4JSVd4Nn4IbPs2fARUdPQcfLWAQJ8Mq6Tkdd
gGcEHHT0sHYn9Jg1dcnnnhf6vnee8xzXVkcP9wdr97eY7z0NnlrX74qpxffg
iOZ2VDp6kvqOe6AVXAb7xNQB462YNfsCfoBzoE1MzTEqHD096mgE98WsEec4
Jqamvvk8cx2kwWuw19HDXnIAbNAx03ka9IO8mO+3ScyebRZTi01i1rqguHjY
r3aJWaugOA5O6vEC+K6ebWDW0cNgv6oBnwKus87KwKDmv8BRMOBz77/6G/sV
e8lkwHWuTwm4pQ7WzGIRHgb7FXsJ9/mI5z2si42gXMw8/ByuHgb7FXsJ9yX3
IPfHFjF1xTl5v0exnrCx5gnn+fu7JC7h/z/0Y52+P+rfWX9iCXVYErg=
             "], {{0,
              34}, {26, 0}}, {0, 255}, ColorFunction -> RGBColor], 
            BoxForm`ImageTag[
            "Byte", ColorSpace -> "RGB", Interleaving -> True, Magnification -> 
             1], Selectable -> False], DefaultBaseStyle -> "ImageGraphics", 
           ImageSize -> Magnification[1], ImageSizeRaw -> {26, 34}, 
           PlotRange -> {{0, 26}, {0, 34}}], 
          GraphicsBox[
           TagBox[
            RasterBox[CompressedData["
1:eJztXUuS47gRLX8WXtYRaJ+gl17SS+8U4/CeM+H2hDdtRY8jHF6ZR9AReATt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             "], {{0, 34}, {383, 0}}, {0, 255}, 
             ColorFunction -> RGBColor], 
            BoxForm`ImageTag[
            "Byte", ColorSpace -> "RGB", Interleaving -> True, Magnification -> 
             1], Selectable -> False], DefaultBaseStyle -> "ImageGraphics", 
           ImageSize -> Magnification[1], ImageSizeRaw -> {383, 34}, 
           PlotRange -> {{0, 383}, {0, 34}}]}, "RowWithSeparators"], 
        PaneBox[
         StyleBox["\[VeryThinSpace]", ShowStringCharacters -> False], 
         Alignment -> Right, ImageSize -> {174, 47}], 
        PaneBox[
         PaneBox[
          TemplateBox[{"\[ThinSpace]", "\" \"", 
            TagBox[
             TooltipBox[
              PaneSelectorBox[{False -> ButtonBox[
                  PaneBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAPiDmBmIUBO/j//z8jEDcA8W8g3oBFnhmIZ/9HgE9o8mxAvBZJ/hsQuyPJ
8wPxfiT5N0BsjiQvCsTnkOSfALEWkrwSEN9Bkr8OxDJobniAJP8ZZCYWfxCj
RpGQXcS4mVi/ExuGxMYFmlp4nAIAG14fWQ==
                    "], {{0, 14}, {9, 
                    0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                     ImageSizeRaw -> {9, 14}, PlotRange -> {{0, 9}, {0, 14}}, 
                    ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                   Alignment -> Center], 
                  ButtonFunction :> (
                   NotebookLocate[{"EIWL1-44-importing-and-exporting.nb", ""},
                     FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Enabled -> True, Appearance -> 
                  None, Evaluator -> Automatic, Method -> "Preemptive"], True -> 
                ButtonBox[
                  PaneBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAPiDmBmIUBO/j//z8jEDcA8W8g3oBFnhmIZ/9HgE9o8mxAvBZJ/hsQuyPJ
8wPxfiT5N0BsjiQvCsTnkOSfALEWkrwSEN9Bkr8OxDJobniAJP8ZZCYWfxCj
RpGQXcS4mVi/ExuGxMYFmlp4nAIAG14fWQ==
                    "], {{0, 14}, {9, 
                    0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                     ImageSizeRaw -> {9, 14}, PlotRange -> {{0, 9}, {0, 14}}, 
                    ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                   Alignment -> Center], 
                  ButtonFunction :> (
                   NotebookLocate[{"EIWL1-44-importing-and-exporting.nb", ""},
                     FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Enabled -> True, Appearance -> 
                  None, Background -> RGBColor[0.835294, 0.364706, 0.0196078],
                   Evaluator -> Automatic, Method -> "Preemptive"]}, 
               Dynamic[
                CurrentValue["MouseOver"]], ImageSize -> Automatic, 
               FrameMargins -> 0], "\"Importing and Exporting\"", 
              TooltipDelay -> 0.15, LabelStyle -> "TextStyling"], 
             Annotation[#, "Importing and Exporting", "Tooltip"]& ], 
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {5, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[5], Selectable -> False], 
            TagBox[
             TooltipBox[
              PaneSelectorBox[{False -> ButtonBox[
                  PaneBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAfiDmBmAWI////vwKIfwFxMQMOAJT7+R8B6nGoSf+PCjpwqMskUl0SEP9F
UtcHxIxY1EWjqZuOQ10Mmr2TcNj7BEnNP1LNIeQeIDsZn78IhQ8x4fwfNb4a
cPgTFu8l2ORBAAC+1hnm
                    "], {{0, 15}, {9, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                     ImageSizeRaw -> {9, 15}, PlotRange -> {{0, 9}, {0, 15}}, 
                    ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                   Alignment -> Center], 
                  ButtonFunction :> (
                   NotebookLocate[{"EIWL1-46-writing-good-code.nb", ""}, 
                    FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Appearance -> None, Evaluator -> 
                  Automatic, Method -> "Preemptive"], True -> ButtonBox[
                  PaneBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAfiDmBmAWI////vwKIfwFxMQMOAJT7+R8B6nGoSf+PCjpwqMskUl0SEP9F
UtcHxIxY1EWjqZuOQ10Mmr2TcNj7BEnNP1LNIeQeIDsZn78IhQ8x4fwfNb4a
cPgTFu8l2ORBAAC+1hnm
                    "], {{0, 15}, {9, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                     ImageSizeRaw -> {9, 15}, PlotRange -> {{0, 9}, {0, 15}}, 
                    ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                   Alignment -> Center], 
                  ButtonFunction :> (
                   NotebookLocate[{"EIWL1-46-writing-good-code.nb", ""}, 
                    FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Appearance -> None, Background -> 
                  RGBColor[0.835294, 0.364706, 0.0196078], Evaluator -> 
                  Automatic, Method -> "Preemptive"]}, 
               Dynamic[
                CurrentValue["MouseOver"]], ImageSize -> Automatic, 
               FrameMargins -> 0], "\"Writing Good Code\"", TooltipDelay -> 
              0.15, LabelStyle -> "TextStyling"], 
             Annotation[#, "Writing Good Code", "Tooltip"]& ]}, 
           "RowWithSeparators"], Alignment -> Right], ImageSize -> {100, 30}, 
         FrameMargins -> {{0, 6}, {0, 0}}, Alignment -> Right], 
        ActionMenuBox[
         PaneSelectorBox[{True -> PanelBox[
             GraphicsBox[
              TagBox[
               RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UBAkIQ3ELED8////Jf/pA0D2/KWTXSB7ZtPBPrA9DKOAYgAMR1Eg9gPiABpi
P6g912mcLmAAZM9XOtkFsicKiNcD8QYaYpD5UQOdXoYD+E/HMooO9iDbR7c6
BQDxtyEt
                "], {{0, 16}, {27, 0}}, {0, 255}, ColorFunction -> 
                RGBColor], 
               BoxForm`ImageTag[
               "Byte", ColorSpace -> "RGB", Interleaving -> True, 
                Magnification -> 1], Selectable -> False], DefaultBaseStyle -> 
              "ImageGraphics", ImageSize -> Magnification[1], 
              ImageSizeRaw -> {27, 16}, PlotRange -> {{0, 27}, {0, 16}}], 
             Appearance -> None, Background -> 
             RGBColor[0.835294, 0.364706, 0.0196078], ImageSize -> {35, 30}, 
             Alignment -> Center], False -> PanelBox[
             GraphicsBox[
              TagBox[
               RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UBAkIQ3ELED8////Jf/pA0D2/KWTXSB7ZtPBPrA9DKOAYgAMR1Eg9gPiABpi
P6g912mcLmAAZM9XOtkFsicKiNcD8QYaYpD5UQOdXoYD+E/HMooO9iDbR7c6
BQDxtyEt
                "], {{0, 16}, {27, 0}}, {0, 255}, ColorFunction -> 
                RGBColor], 
               BoxForm`ImageTag[
               "Byte", ColorSpace -> "RGB", Interleaving -> True, 
                Magnification -> 1], Selectable -> False], DefaultBaseStyle -> 
              "ImageGraphics", ImageSize -> Magnification[1], 
              ImageSizeRaw -> {27, 16}, PlotRange -> {{0, 27}, {0, 16}}], 
             Appearance -> None, Background -> 
             RGBColor[0.952941, 0.509804, 0], ImageSize -> {35, 30}, 
             Alignment -> Center]}, 
          Dynamic[
           CurrentValue["MouseOver"]]], {
         "Preface" :> 
          NotebookLocate[{"EIWL1-0a-preface.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "What Is the Wolfram Language?" :> 
          NotebookLocate[{"EIWL1-0b-what-is-the-wolfram-language.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "Practicalities of Using the Wolfram Language" :> 
          NotebookLocate[{
            "EIWL1-0c-practicalities-of-using-the-wolfram-language.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "Other Resources" :> 
          NotebookLocate[{"EIWL1-0d-other-resources.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]1\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Starting Out: Elementary Arithmetic" :> 
          NotebookLocate[{
            "EIWL1-01-starting-out-elementary-arithmetic.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]2\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Introducing Functions" :> 
          NotebookLocate[{"EIWL1-02-introducing-functions.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]3\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]First Look at Lists" :> 
          NotebookLocate[{"EIWL1-03-first-look-at-lists.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]4\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Displaying Lists" :> 
          NotebookLocate[{"EIWL1-04-displaying-lists.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]5\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Operations on Lists" :> 
          NotebookLocate[{"EIWL1-05-operations-on-lists.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]6\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Making Tables" :> 
          NotebookLocate[{"EIWL1-06-making-tables.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]7\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Colors and Styles" :> 
          NotebookLocate[{"EIWL1-07-colors-and-styles.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]8\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Basic Graphics Objects" :> 
          NotebookLocate[{"EIWL1-08-basic-graphics-objects.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]9\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Interactive Manipulation" :> 
          NotebookLocate[{"EIWL1-09-interactive-manipulation.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "10\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Images" :> 
          NotebookLocate[{"EIWL1-10-images.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "11\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Strings and \
Text" :> NotebookLocate[{"EIWL1-11-strings-and-text.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "12\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Sound" :> 
          NotebookLocate[{"EIWL1-12-sound.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "13\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Arrays, or \
Lists of Lists" :> 
          NotebookLocate[{"EIWL1-13-arrays-or-lists-of-lists.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "14\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Coordinates \
and Graphics" :> 
          NotebookLocate[{"EIWL1-14-coordinates-and-graphics.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "15\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]The Scope \
of the Wolfram Language" :> 
          NotebookLocate[{
            "EIWL1-15-the-scope-of-the-wolfram-language.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "16\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Real\
\[VeryThinSpace]\[Hyphen]\[VeryThinSpace]\[NegativeVeryThinSpace]World Data" :> 
          NotebookLocate[{"EIWL1-16-real-world-data.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "17\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Units" :> 
          NotebookLocate[{"EIWL1-17-units.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "18\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]\
Geocomputation" :> 
          NotebookLocate[{"EIWL1-18-geocomputation.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "19\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Dates and \
Times" :> NotebookLocate[{"EIWL1-19-dates-and-times.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "20\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Options" :> 
          NotebookLocate[{"EIWL1-20-options.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "21\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Graphs and \
Networks" :> NotebookLocate[{"EIWL1-21-graphs-and-networks.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "22\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Machine \
Learning" :> 
          NotebookLocate[{"EIWL1-22-machine-learning.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "23\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]More about \
Numbers" :> NotebookLocate[{"EIWL1-23-more-about-numbers.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "24\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]More Forms \
of Visualization" :> 
          NotebookLocate[{"EIWL1-24-more-forms-of-visualization.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "25\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Ways to \
Apply Functions" :> 
          NotebookLocate[{"EIWL1-25-ways-to-apply-functions.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "26\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Pure \
Anonymous Functions" :> 
          NotebookLocate[{"EIWL1-26-pure-anonymous-functions.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "27\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Applying \
Functions Repeatedly" :> 
          NotebookLocate[{"EIWL1-27-applying-functions-repeatedly.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "28\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Tests and \
Conditionals" :> 
          NotebookLocate[{"EIWL1-28-tests-and-conditionals.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "29\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]More about \
Pure Functions" :> 
          NotebookLocate[{"EIWL1-29-more-about-pure-functions.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "30\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Rearranging \
Lists" :> NotebookLocate[{"EIWL1-30-rearranging-lists.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "31\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Parts of \
Lists" :> NotebookLocate[{"EIWL1-31-parts-of-lists.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "32\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Patterns" :> 
          NotebookLocate[{"EIWL1-32-patterns.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "33\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Expressions \
and Their Structure" :> 
          NotebookLocate[{"EIWL1-33-expressions-and-their-structure.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "34\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]\
Associations" :> 
          NotebookLocate[{"EIWL1-34-associations.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "35\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Natural \
Language Understanding" :> 
          NotebookLocate[{"EIWL1-35-natural-language-understanding.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "36\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Creating \
Websites and Apps" :> 
          NotebookLocate[{"EIWL1-36-creating-websites-and-apps.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "37\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Layout and \
Display" :> NotebookLocate[{"EIWL1-37-layout-and-display.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "38\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Assigning \
Names to Things" :> 
          NotebookLocate[{"EIWL1-38-assigning-names-to-things.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "39\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Immediate \
and Delayed Values" :> 
          NotebookLocate[{"EIWL1-39-immediate-and-delayed-values.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "40\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Defining \
Your Own Functions" :> 
          NotebookLocate[{"EIWL1-40-defining-your-own-functions.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "41\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]More about \
Patterns" :> 
          NotebookLocate[{"EIWL1-41-more-about-patterns.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "42\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]String \
Patterns and Templates " :> 
          NotebookLocate[{"EIWL1-42-string-patterns-and-templates.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "43\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Storing \
Things" :> NotebookLocate[{"EIWL1-43-storing-things.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "44\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Importing \
and Exporting" :> 
          NotebookLocate[{"EIWL1-44-importing-and-exporting.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "45\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Datasets" :> 
          NotebookLocate[{"EIWL1-45-datasets.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "46\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Writing \
Good Code" :> 
          NotebookLocate[{"EIWL1-46-writing-good-code.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "47\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Debugging \
Your Code" :> 
          NotebookLocate[{"EIWL1-47-debugging-your-code.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "What We Haven\[CloseCurlyQuote]t Discussed" :> 
          NotebookLocate[{"EIWL1-what-we-havent-discussed.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "Afterword: Being a Programmer" :> 
          NotebookLocate[{"EIWL1-being-a-programmer.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "Answers to Exercises" :> 
          NotebookLocate[{"EIWL1-answers-to-exercises.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "Index" :> 
          NotebookLocate[{"EIWL1-book-index.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}]}, Appearance -> None]}}, 
      GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Center}}}, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"]], 
   "Text", ShowCellBracket -> False, CellFrame -> {{0, 0}, {3, 0}}, 
   Selectable -> False, CellFrameColor -> 
   RGBColor[0.835294, 0.364706, 0.0196078], CellMargins -> {{0, 0}, {0, -1}}, 
   CellFrameMargins -> {{27, 0}, {1, 7}}, Background -> 
   RGBColor[0.952941, 0.509804, 0], CellTags -> "DockedCellLogoCell"], 
  Cell["FIRST EDITION (2015)", "Text", FontFamily -> "Source Sans Pro", 
   CellFrame -> {{0, 0}, {3, 0}}, ShowCellBracket -> False, 
   CellMargins -> {{0, 0}, {-1, -1}}, CellFrameMargins -> {{66, 0}, {2, 4}}, 
   CellFrameColor -> RGBColor[0.952941, 0.509804, 0], FontSize -> 10, 
   FontTracking -> "Extended", FontColor -> RGBColor[1, 0.929412, 0.721569], 
   Background -> RGBColor[0.862745, 0.309804, 0], CellTags -> 
   "DockedCellLogoCell"]},
PrintingStartingPageNumber->359,
PageHeaders->{{
   Cell[
    TextData[{
      StyleBox[
       CounterBox["Page"], "PageNumber"], 
      StyleBox[
      "    An Elementary Introduction to the Wolfram Language", "Header"]}], 
    "Header", CellMargins -> {{37, Inherited}, {Inherited, Inherited}}], None,
    None}, {None, None, 
   Cell[
    TextData[{
      StyleBox[
       CounterBox["Section"], "Header"], 
      StyleBox[" | Datasets \[LongDash] wolfr.am/eiwl-", "Header"], 
      StyleBox[
       CounterBox["Section"], "Header"], 
      StyleBox["    ", "Header"], 
      StyleBox[
       CounterBox["Page"], "PageNumber"]}], "Header", 
    CellMargins -> {{Inherited, 17}, {Inherited, Inherited}}]}},
PrintingOptions->{"FirstPageHeader"->True},
ShowCellBracket->Automatic,
ShowSyntaxStyles->False,
Magnification->1.,
FrontEndVersion->"11.1 for Mac OS X x86 (32-bit, 64-bit Kernel) (March 16, \
2017)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "Default.nb"]], 
   Cell[
    CellGroupData[{
      Cell[
      "Style Environments", "Section", 
       CellChangeTimes -> {{3.64661165091824*^9, 3.646611654013329*^9}, 
         3.6485723794335403`*^9, 3.651347081728628*^9, 3.651347179462186*^9, 
         3.651347384135805*^9, 3.651348171662589*^9}], 
      Cell[
       StyleData[All, "Working"], CellInsertionPointCell -> 
       FEPrivate`FrontEndResource["FEExpressions", "CellInsertionMenu"], 
       CreateCellID -> True, $CellContext`GhostCellInEmptyNotebook -> False], 
      
      Cell[
       StyleData[All, "Printout"], 
       PrintingOptions -> {
        "PageSize" -> {504, 720}, "PrintRegistrationMarks" -> True}, 
       Magnification -> 0.6]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell["Styles for Headers and Footers", "Section"], 
      Cell[
       StyleData["Header"], StyleMenuListing -> None, FontFamily -> "Verdana",
        FontSize -> 7, FontSlant -> "Plain", FontColor -> GrayLevel[0.6]], 
      Cell[
       StyleData["PageNumber"], CellMargins -> {{0, 0}, {4, 1}}, 
       StyleMenuListing -> None, FontFamily -> "Verdana", FontSize -> 7, 
       FontWeight -> "Bold", FontSlant -> "Plain", FontColor -> 
       GrayLevel[0]]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell[
      "WPL Specific", "Section", 
       CellChangeTimes -> {{3.6556608433734913`*^9, 3.6556608489412746`*^9}}], 
      Cell[
       StyleData["Link"], FontFamily -> "Source Sans Pro", FontSize :> 
       If[CurrentValue[
           EvaluationCell[], "FontFamily"] === "Source Sans Pro", Inherited, 
         If[CurrentValue[
            EvaluationCell[], "FontFamily"] === "WolframCodeSans", Inherited, 
          Inherited 0.9]], FontColor -> GrayLevel[0]], 
      Cell[
       StyleData["CodeLink"], 
       ButtonBoxOptions -> {
        Appearance -> None, ButtonFunction :> (FEPrivate`FrontEndExecute[
           FrontEndToken["OpenHelpLink", {
             Part[#, 1], Null}]]& ), ButtonSource -> ButtonContents, 
         Evaluator -> None, Method -> "Preemptive"}]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell[
      "Custom Styles", "Section", 
       CellChangeTimes -> {{3.646611660445352*^9, 3.646611669493331*^9}}], 
      Cell[
       StyleData["Notebook"], PageWidth -> 700, 
       PrintingOptions -> {
        "InnerOuterMargins" -> {35, 16}, "PaperOrientation" -> "Portrait", 
         "PaperSize" -> {504, 720}, 
         "PrintingMargins" -> {{20, 20}, {54, 54}}}, CellLabelAutoDelete -> 
       False, ShowSyntaxStyles -> False, MenuSortingValue -> None, 
       GraphicsBoxOptions -> {ImageSize -> 240}, 
       Graphics3DBoxOptions -> {ImageSize -> 240}], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Title"], CellMargins -> {{64, Inherited}, {50, 72}}, 
          MenuCommandKey -> None, FontFamily -> "Verdana", FontSize -> 42, 
          FontWeight -> "Bold", FontColor -> GrayLevel[0.4]], 
         Cell[
          StyleData["Title", "Printout"], 
          CellMargins -> {{64, Inherited}, {50, 72}}]}, Closed]], 
      Cell[
       StyleData["Chapter"], MenuCommandKey -> None], 
      Cell[
       StyleData["Subchapter"], MenuCommandKey -> None], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Section"], CellFrame -> {{0, 0}, {0, 0}}, CellDingbat -> 
          Cell[
            TextData[
             CounterBox["Section"], 
             StyleBox[
             "|\[NegativeThinSpace]", FontColor -> 
              RGBColor[
               0.9019607843137255, 0.4117647058823529, 0.027450980392156862`],
               FontFamily -> "Courier", FontSize -> 36, FontWeight -> Plain]],
             "SectionNumber"], CellMargins -> {{96, Inherited}, {12, 44}}, 
          Evaluatable -> True, CellGroupingRules -> {"SectionGrouping", 60}, 
          PageBreakAbove -> True, ShowCellLabel -> False, 
          CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
          CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
          CounterIncrements -> "Section", 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", 
          FontSize -> 26, FontSlant -> "Plain", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          InterpretationBoxOptions -> {Editable -> True}], 
         Cell[
          StyleData["Section", "Printout"], 
          CellMargins -> {{96, Inherited}, {12, 2}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionDoubleDigit"], CellFrame -> {{0, 0}, {0, 0}}, 
          CellDingbat -> Cell[
            TextData[
             CounterBox["Section"], 
             StyleBox[
             "|\[NegativeThinSpace]", FontColor -> 
              RGBColor[
               0.9019607843137255, 0.4117647058823529, 0.027450980392156862`],
               FontFamily -> "Courier", FontSize -> 36, FontWeight -> Plain]],
             "SectionNumber"], CellMargins -> {{112, Inherited}, {12, 44}}, 
          Evaluatable -> True, CellGroupingRules -> {"SectionGrouping", 60}, 
          PageBreakAbove -> True, ShowCellLabel -> False, 
          CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
          CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
          CounterIncrements -> "Section", 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", 
          FontSize -> 26, FontSlant -> "Plain", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          InterpretationBoxOptions -> {Editable -> True}], 
         Cell[
          StyleData["SectionDoubleDigit", "Printout"], 
          CellMargins -> {{112, Inherited}, {12, 2}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionNumber"], CellBaseline -> Baseline, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 26, FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["SectionNumber", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionInline"], FontFamily -> 
          "Source Sans Pro Semibold", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["SectionInline", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionNoDingbat"], 
          CellMargins -> {{64, Inherited}, {12, 44}}, Evaluatable -> True, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakAbove -> 
          True, ShowCellLabel -> False, 
          CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
          CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
          CounterIncrements -> "Section", 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", 
          FontSize -> 26, FontSlant -> "Plain", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          InterpretationBoxOptions -> {Editable -> True}], 
         Cell[
          StyleData["SectionNoDingbat", "Printout"], 
          CellMargins -> {{64, Inherited}, {12, 2}}]}, Closed]], 
      Cell[
       StyleData["AnswerKeyNumberedSection"], 
       CellMargins -> {{64, Inherited}, {8, 28}}, Evaluatable -> True, 
       CellGroupingRules -> {"SectionGrouping", 60}, PageBreakAbove -> True, 
       ShowCellLabel -> False, 
       CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
       CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
       CounterIncrements -> "Section", 
       CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
         "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", FontSize -> 
       18, FontSlant -> "Plain", FontColor -> 
       RGBColor[
        0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
       InterpretationBoxOptions -> {Editable -> True}], 
      Cell[
       StyleData["AnswerKeySectionNumber"], CellBaseline -> Baseline, 
       FontFamily -> "Source Sans Pro Semibold", FontSize -> 18, FontColor -> 
       RGBColor[
        0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
      Cell[
       StyleData["IndexLinkGuide"], 
       CellMargins -> {{64, Inherited}, {48, 28}}, Evaluatable -> True, 
       CellGroupingRules -> {"SectionGrouping", 60}, PageBreakAbove -> True, 
       ShowCellLabel -> False, 
       CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
       CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
       CounterIncrements -> "Section", 
       CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
         "Exercise", 0}}, FontFamily -> "Source Sans Pro", FontSize -> 14, 
       FontSlant -> "Plain", FontColor -> 
       RGBColor[
        0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
       InterpretationBoxOptions -> {Editable -> True}], 
      Cell[
       StyleData["Index"], MenuSortingValue -> 10000, FontFamily -> 
       "Source Sans Pro", FontSize -> 11], 
      Cell[
       StyleData["IndexSubentry"], MenuSortingValue -> 10000, FontFamily -> 
       "Source Sans Pro", FontSize -> 11], 
      Cell[
       StyleData["FunctionName"], MenuSortingValue -> 10000, FontFamily -> 
       "Source Sans Pro Semibold", FontWeight -> "Bold"], 
      Cell[
       StyleData["IndexColumn"], 
       CellMargins -> {{66, 0}, {Inherited, Inherited}}, TabSpacings -> {2.}, 
       MenuSortingValue -> 10000, FontFamily -> "Source Sans Pro", 
       GridBoxOptions -> {
        GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
         GridBoxItemSize -> {"Columns" -> {{25}}}, 
         GridBoxSpacings -> {"Columns" -> {{2}}}}], 
      Cell[
       StyleData["IndexSubsection"], 
       CellMargins -> {{64, Inherited}, {9, 28}}, 
       CellGroupingRules -> {"SectionGrouping", 40}, MenuSortingValue -> 
       10000, FontFamily -> "Source Sans Pro", FontSize -> 24], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Subsection"], CellMargins -> {{64, Inherited}, {12, 32}},
           FontFamily -> "Source Sans Pro Semibold", FontSize -> 18, 
          FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["Subsection", "Printout"], 
          CellMargins -> {{64, Inherited}, {12, 32}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ResourcesSubsection"], 
          CellMargins -> {{64, Inherited}, {4, 16}}, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 15, FontSlant -> "Plain", 
          FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["ResourcesSubsection", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 16}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Subsubsection"], 
          CellMargins -> {{64, Inherited}, {6, 12}}, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 16, FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["Subsubsection", "Printout"], 
          CellMargins -> {{64, Inherited}, {6, 12}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularySection"], PageWidth -> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 24}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["VocabularySection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 24}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularyTable", StyleDefinitions -> StyleData["Text"]],
           SpanMaxSize -> 1, FontFamily -> "Source Sans Pro Light", FontColor -> 
          GrayLevel[0.8], 
          GridBoxOptions -> {
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
            GridBoxDividers -> {"Columns" -> {{False}}, "Rows" -> {False, {
                 Directive[
                  Thickness[0.5], "VocabDivColor"]}, False}}, 
            GridBoxItemStyle -> {
             "Columns" -> {"VocabularyCode", Inherited, Inherited}, 
              "Rows" -> {{Automatic}}}, 
            GridBoxSpacings -> {
             "Columns" -> {{0, 1, 2, 1, 2}}, "Rows" -> {{1}}}}], 
         Cell[
          StyleData["VocabularyTable", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "VocabularyTable3Column", StyleDefinitions -> StyleData["Text"]], 
          SpanMaxSize -> 1, FontFamily -> "Source Sans Pro Light", FontColor -> 
          GrayLevel[0.8], 
          GridBoxOptions -> {
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
            GridBoxDividers -> {"Columns" -> {{False}}, "Rows" -> {False, {
                 Directive[
                  Thickness[0.5], "VocabDivColor"]}, False}}, 
            GridBoxItemStyle -> {
             "Columns" -> {
               "VocabularyCode", Inherited, "VocabularyCode", Inherited, 
                Inherited}, "Rows" -> {{Automatic}}}, 
            GridBoxSpacings -> {
             "Columns" -> {{0, 1, 2, 1, 2}}, "Rows" -> {{1}}}}], 
         Cell[
          StyleData["VocabularyTable3Column", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularyText"], FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["VocabularyText", "Printout"], 
          CellMargins -> {{66, 10}, {7, 7}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularyCode", StyleDefinitions -> StyleData["Text"]], 
          Deletable -> False, FontFamily -> "Source Sans Pro", FontSize -> 14,
           FontWeight -> "Bold", FontColor -> GrayLevel[0.25], 
          GridBoxOptions -> {
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
            GridBoxDividers -> {
             "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {True, {True}, True}, "RowsIndexed" -> {}}}], 
         Cell[
          StyleData["VocabularyCode", "Printout"], FontColor -> 
          GrayLevel[0.25]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabDivColor"], FontColor -> GrayLevel[0.8]], 
         Cell[
          StyleData["VocabDivColor", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseSection"], PageWidth -> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 30}}, Evaluatable -> True, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, ShowCellLabel -> False, CellFrameMargins -> {{8, 8}, {4, 6}},
           CellFrameColor -> RGBColor[0.901961, 0.411765, 0.027451], 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro", FontSize -> 18, 
          FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["ExerciseSection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Exercise"], PageWidth -> 700, CellDingbat -> Cell[
            TextData[{"  ", 
              CounterBox["Section"], ".", 
              CounterBox["Exercise"]}], "ExerciseNumber", FontColor -> 
            RGBColor[
             0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
          ShowGroupOpener -> True, CellMargins -> {{108, Inherited}, {4, 8}}, 
          CellGroupingRules -> {"SectionGrouping", 67}, CounterIncrements -> 
          "Exercise", MenuSortingValue -> 10020, MenuCommandKey -> "2", 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Plain", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["Exercise", "Printout"], ShowGroupOpener -> False, 
          CellMargins -> {{110, Inherited}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseNumber"], FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Bold", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["ExerciseNumber", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseSubsection"], PageWidth -> 500, 
          CellFrame -> {{False, False}, {1, False}}, 
          CellMargins -> {{64, Inherited}, {8, 18}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, CellFrameColor -> 
          RGBColor[0.65, 0.6, 0.6], FontFamily -> "Source Sans Pro", FontSize -> 
          18, FontSlant -> "Italic", FontColor -> RGBColor[0.65, 0.6, 0.6]], 
         Cell[
          StyleData["ExerciseSubsection", "Printout"], 
          CellFrame -> {{False, False}, {1, False}}, CellFrameColor -> 
          RGBColor[0.65, 0.6, 0.6]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseNote"], PageWidth -> 700, 
          CellMargins -> {{64, Inherited}, {4, 8}}, PageBreakBelow -> False, 
          MenuSortingValue -> 10050, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25], $CellContext`ReturnCreatesNewCell -> 
          True], 
         Cell[
          StyleData["ExerciseNote", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["QASection"], PageWidth -> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 30}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Question", 0}}, FontFamily -> "Source Sans Pro", FontSize -> 18, 
          FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["QASection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Question"], PageWidth -> 700, 
          CellMargins -> {{64, Inherited}, {2, 12}}, PageBreakBelow -> False, 
          CounterIncrements -> "Question", MenuSortingValue -> 10030, 
          MenuCommandKey -> "3", FontFamily -> "Source Sans Pro", FontSize -> 
          14, FontWeight -> "Bold", FontSlant -> 
          "Plain", $CellContext`ReturnCreatesNewCell -> 
          True, $CellContext`DefaultReturnCreatedCellStyle -> "Answer"], 
         Cell[
          StyleData["Question", "Printout"], 
          CellMargins -> {{65, Inherited}, {2, 12}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Answer"], PageWidth -> 700, 
          CellMargins -> {{66, 10}, {4, 1}}, LineSpacing -> {1.125, 1., 2.}, 
          MenuSortingValue -> 10032, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25], $CellContext`ReturnCreatesNewCell -> 
          True, $CellContext`DefaultReturnCreatedCellStyle -> "Question"], 
         Cell[
          StyleData["Answer", "Printout"], 
          CellMargins -> {{66, 10}, {4, 1}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["QuestionNumber"], FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Bold", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["QuestionNumber", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TechNoteSection"], PageWidth -> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 30}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["TechNoteSection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TechNote"], PageWidth -> 700, CellDingbat -> Cell[
            TextData[{"\[FilledSmallSquare]"}], FontSize -> 12, FontColor -> 
            GrayLevel[0.5]], CellMargins -> {{78, Inherited}, {4, 8}}, 
          CellChangeTimes -> {{3.651515120816633*^9, 3.651515125814807*^9}, 
            3.6515155174947033`*^9}, LineSpacing -> {1.25, 1., 2.}, 
          MenuSortingValue -> 10040, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25], $CellContext`ReturnCreatesNewCell -> 
          True], 
         Cell[
          StyleData["TechNote", "Printout"], 
          CellMargins -> {{82, Inherited}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["MoreExploreSection"], PageWidth -> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 30}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["MoreExploreSection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["MoreExplore"], PageWidth -> 700, 
          CellMargins -> {{64, Inherited}, {4, 8}}, PageBreakBelow -> False, 
          MenuSortingValue -> 10050, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0], $CellContext`ReturnCreatesNewCell -> 
          True], 
         Cell[
          StyleData["MoreExplore", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["MoreExploreShortURL"], 
          CellMargins -> {{64, Inherited}, {4, 8}}, PageBreakBelow -> False, 
          FontFamily -> "Source Sans Pro Light", FontSize -> 14, FontSlant -> 
          "Plain", FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["MoreExploreShortURL", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Text"], CellMargins -> {{66, 10}, {4, 14}}, FontFamily -> 
          "Baskerville", FontSize -> 18, FontColor -> 
          GrayLevel[0], $CellContext`ReturnCreatesNewCell -> True], 
         Cell[
          StyleData["Text", "Printout"], CellMargins -> {{66, 10}, {7, 7}}]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ResourcesText"], CellMargins -> {{66, 10}, {2, 0}}, 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Plain", FontColor -> 
          GrayLevel[0], $CellContext`ReturnCreatesNewCell -> True], 
         Cell[
          StyleData["ResourcesText", "Printout"], 
          CellMargins -> {{66, 10}, {2, 0}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ResourcesLink"], CellMargins -> {{66, 10}, {2, 0}}, 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Italic", FontColor -> 
          GrayLevel[0], $CellContext`ReturnCreatesNewCell -> True], 
         Cell[
          StyleData["ResourcesLink", "Printout"], 
          CellMargins -> {{66, 10}, {2, 0}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CodeCaption"], CellFrame -> {{0, 0}, {0, 0}}, 
          CellMargins -> {{66, 10}, {4, 12}}, PageBreakBelow -> False, 
          CellFrameColor -> GrayLevel[0.4], MenuSortingValue -> 10010, 
          MenuCommandKey -> "1", FontFamily -> "Source Sans Pro", FontSize -> 
          16, FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["CodeCaption", "Printout"], 
          CellMargins -> {{66, 10}, {4, 12}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Input"], CellMargins -> {{99, 10}, {3, 7}}, SpanMaxSize -> 
          1, FontSize -> 15], 
         Cell[
          StyleData["Input", "Printout"], CellMargins -> {{99, 10}, {3, 7}}]},
         Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Output"], CellMargins -> {{99, 10}, {14, 7}}, FontSize -> 
          15], 
         Cell[
          StyleData["Output", "Printout"], 
          CellMargins -> {{99, 10}, {14, 7}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["InputOnly"], CellMargins -> {{99, 10}, {25, 10}}, 
          SpanMaxSize -> 1, MenuSortingValue -> 1500, FontSize -> 15], 
         Cell[
          StyleData["InputOnly", "Printout"], 
          CellMargins -> {{99, 10}, {15, 10}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CellLabel"], 
          CellLabelMargins -> {{12, Inherited}, {Inherited, Inherited}}, 
          LanguageCategory -> None, StyleMenuListing -> None, FontFamily -> 
          "Helvetica Neue", FontSize -> 9, FontWeight -> "Plain", FontSlant -> 
          "Plain", FontColor -> GrayLevel[0.5]], 
         Cell[
          StyleData["CellLabel", "Printout"], FontSize -> 8, FontColor -> 
          GrayLevel[0.5]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Message"], Editable -> False, 
          CellMargins -> {{66, Inherited}, {Inherited, Inherited}}, 
          CellGroupingRules -> "OutputGrouping", TextClipboardType -> 
          "PlainText", PageBreakWithin -> False, GroupPageBreakWithin -> 
          False, GeneratedCell -> True, CellAutoOverwrite -> True, 
          ShowCellLabel -> False, DefaultFormatType -> 
          DefaultOutputFormatType, ContextMenu -> 
          FEPrivate`FrontEndResource["ContextMenus", "Output"], 
          ShowAutoStyles -> False, ShowSyntaxStyles -> False, 
          AutoStyleOptions -> {
           "StringStyle" -> None, "SyntaxErrorStyle" -> None}, 
          HyphenationOptions -> {"HyphenationCharacter" -> "\[Continuation]"},
           AutoItalicWords -> {}, AutoQuoteCharacters -> {}, 
          PasteAutoQuoteCharacters -> {}, LanguageCategory -> None, 
          FormatType -> InputForm, ShowStringCharacters -> False, 
          CounterIncrements -> "Message", MenuSortingValue -> 1600, 
          StyleMenuListing -> None, FontFamily :> 
          CurrentValue["PanelFontFamily"], FontSize -> 11, FontColor -> 
          RGBColor[0.5072, 0.16933, 0.15221], $CellContext`StripStyleOnPaste -> 
          True], 
         Cell[
          StyleData["Message", "Printout"], 
          CellMargins -> {{100, Inherited}, {Inherited, Inherited}}, 
          CellFrameLabels -> {{None, None}, {None, None}}, FontColor -> 
          GrayLevel[0]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseInput", StyleDefinitions -> StyleData["Input"]], 
          CellMargins -> {{88, 10}, {4, 7}}, ShowCellLabel -> False, 
          SpanMaxSize -> 1, FontSize -> 
          14, $CellContext`GeneratedCellStyles -> {
           "Output" -> "ExerciseOutput"}], 
         Cell[
          StyleData["ExerciseInput", "Printout"], 
          CellMargins -> {{88, 10}, {4, 7}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "ExerciseOutput", StyleDefinitions -> StyleData["Output"]], 
          CellMargins -> {{88, 10}, {10, 4}}, ShowCellLabel -> False, 
          FontSize -> 14], 
         Cell[
          StyleData["ExerciseOutput", "Printout"], 
          CellMargins -> {{88, 10}, {10, 4}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Picture"], CellMargins -> {{66, 10}, {10, 10}}, 
          CellGroupingRules -> "GraphicsGrouping", StyleMenuListing -> None], 
         
         Cell[
          StyleData["Picture", "Printout"], 
          CellMargins -> {{66, 10}, {8, 8}}]}, Closed]], 
      Cell[
       StyleData["ExerciseSummaryCell"], PageWidth -> 700, CellFrame -> 0, 
       CellMargins -> {{64, Inherited}, {8, 10}}, 
       CellGroupingRules -> {"SectionGrouping", 64}, PageBreakBelow -> False, 
       ShowCellLabel -> False, CellFrameMargins -> 0, ShowStringCharacters -> 
       False, FontFamily -> "Source Sans Pro", FontSize -> 18, FontColor -> 
       RGBColor[1, 1, 1], 
       GridBoxOptions -> {GridBoxBackground -> {"Columns" -> {{
              RGBColor[0.990997, 0.539528, 0.155779], 
              RGBColor[0.989487, 0.434699, 0.0320439]}}, "Rows" -> {{None}}}, 
         GridBoxItemSize -> {"Columns" -> {
             Scaled[0.7], 
             Scaled[0.3]}, "Rows" -> {{Automatic}}}}], 
      Cell[
       StyleData["ExerciseSummaryHeading"], ShowStringCharacters -> False, 
       FontFamily -> "Source Sans Pro", FontSize -> 18, FontColor -> 
       RGBColor[1, 1, 1]], 
      Cell[
       StyleData["ExerciseSummarySubheading"], ShowStringCharacters -> False, 
       FontFamily -> "Source Sans Pro", FontSize -> 15, FontColor -> 
       RGBColor[1., 0.9294117647058824, 0.7215686274509804]], 
      Cell[
       StyleData["ExercisePreviewButtonText"], ShowStringCharacters -> False, 
       FontFamily -> "Source Sans Pro", FontSize -> 14, FontSlant -> "Plain", 
       FontColor -> RGBColor[0.6, 0.6, 0.6]], 
      Cell[
       StyleData["ExercisePreviewButtonTextHighlight"], ShowStringCharacters -> 
       False, FontFamily -> "Source Sans Pro", FontSize -> 14, FontSlant -> 
       "Plain", FontColor -> 
       RGBColor[
        0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]]}, 
     Closed]], 
   Cell[
    CellGroupData[{
      Cell[
      "Inline and special formatting", "Section", 
       CellChangeTimes -> {{3.646681732592888*^9, 3.646681749414035*^9}}], 
      Cell[
       StyleData["Graphics"], MenuSortingValue -> None], 
      Cell[
       StyleData["Graphics3D"], MenuSortingValue -> None], 
      Cell[
       StyleData["StandardForm"], 
       InputAutoReplacements -> {
        "->" -> "\[Rule]", ":>" -> "\[RuleDelayed]", "<=" -> "\[LessEqual]", 
         ">=" -> "\[GreaterEqual]", "!=" -> "\[NotEqual]", "==" -> "\[Equal]",
          "@>" -> "\\[InlinePart]", "<->" -> "\[UndirectedEdge]", ParentList},
        LineSpacing -> {1.25, 0, 2}, SingleLetterItalics -> False, 
       StyleMenuListing -> None, FontFamily -> "Source Sans Pro", 
       PrivateFontOptions -> {"OperatorSubstitution" -> True}], 
      Cell[
       StyleData["OutputForm"], PageWidth -> DirectedInfinity[1], 
       TextAlignment -> Left, LineSpacing -> {0.6, 1}, 
       AutoQuoteCharacters -> {}, PasteAutoQuoteCharacters -> {}, 
       StyleMenuListing -> None, FontFamily -> "Source Sans Pro", 
       PrivateFontOptions -> {"OperatorSubstitution" -> True}], 
      Cell[
       StyleData["InputForm"], PageWidth -> DirectedInfinity[1], 
       InputAutoReplacements -> {}, AllowInlineCells -> False, Hyphenation -> 
       False, AutoQuoteCharacters -> {}, PasteAutoQuoteCharacters -> {}, 
       AutoSpacing -> False, NumberMarks -> True, AutoNumberFormatting -> 
       False, StyleMenuListing -> None, FontFamily -> "Source Sans Pro", 
       PrivateFontOptions -> {"OperatorSubstitution" -> True}], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["DetailsLink"], FontFamily -> "Source Sans Pro", FontSize :> 
          If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.9]], FontColor -> GrayLevel[0], 
          ButtonBoxOptions -> {
           ButtonFunction :> (
             Function[$CellContext`t, 
              NotebookFind[$CellContext`t, "Notes", All, CellStyle]; 
              NotebookFind[$CellContext`t, "NotesSection", All, CellStyle, 
                AutoScroll -> Top]][
              Documentation`HelpLookup[
               StringJoin["ref/", #]]]& ), ButtonSource -> ButtonContents, 
            Evaluator -> Automatic}], 
         Cell[
          StyleData["DetailsLink", "Printout"], FontFamily -> 
          "Source Sans Pro", FontSize :> If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.88]], FontColor -> GrayLevel[0]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["LinkAlt"], FontFamily -> "Source Sans Pro", FontSize :> 
          If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.9]], FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["LinkAlt", "Printout"], FontFamily -> "Source Sans Pro", 
          FontSize :> If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.88]], FontColor -> GrayLevel[0]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Hyperlink"], MenuSortingValue -> None, FontColor -> 
          RGBColor[0.3, 0.35, 0.5]], 
         Cell[
          StyleData["Hyperlink", "Printout"]]}, Closed]], 
      Cell[
       StyleData[
       "IndexNavigationLink", StyleDefinitions -> StyleData["Hyperlink"]], 
       MenuSortingValue -> None, FontColor -> 
       RGBColor[
        0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
      Cell[
       StyleData["Crosslink"], 
       ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
            
            NotebookLocate[#2, "OpenInNewWindow" -> 
             CurrentValue["HyperlinkModifierKey"]]}]& ), Evaluator -> None, 
         Method -> "Queued"}], 
      Cell[
       StyleData["VocabularyLink"], FontColor -> GrayLevel[0], 
       ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
            
            NotebookLocate[#2, "OpenInNewWindow" -> 
             CurrentValue["HyperlinkModifierKey"]]}]& ), Evaluator -> None, 
         Method -> "Queued"}], 
      Cell[
       StyleData["InlineCode"], SpanMaxSize -> 1, FontColor -> GrayLevel[0]], 
      
      Cell[
       StyleData["InlineCodeText"], SpanMaxSize -> 1, FontFamily -> 
       "Source Sans Pro", FontSize -> 0.95 Inherited], 
      Cell[
       StyleData["NoLabel"], ShowCellLabel -> 
       False, $CellContext`GeneratedCellStyles -> {
        "Output" -> "ExerciseOutput"}], 
      Cell[
       StyleData["MenuName"], FontFamily -> "Verdana", FontWeight -> "Bold", 
       FontColor -> GrayLevel[0.286275]], 
      Cell[
       StyleData["KeyEvent"], CellFrame -> {{0.5, 0.5}, {0.5, 0.5}}, 
       CellFrameMargins -> {{2, 2}, {2, 2}}, CellFrameColor -> GrayLevel[0.7],
        FontFamily -> "Verdana", FontColor -> GrayLevel[0.4]], 
      Cell[
       StyleData["KeyEventDelimiter"], FontColor -> GrayLevel[0.5]], 
      Cell[
       CellGroupData[{
         Cell["Key Styles", "Subsubsection"], 
         Cell[
          StyleData["Key0"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {"Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-2, -2}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}], 
         Cell[
          StyleData["Key1"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #2, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {
                 "ColumnsIndexed" -> {2 -> GrayLevel[0.8352941176470589]}, 
                  "Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-2, -2}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}], 
         Cell[
          StyleData["Key2"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #2, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #3, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {
                 "ColumnsIndexed" -> {
                   2 -> GrayLevel[0.8352941176470589], 3 -> 
                    GrayLevel[0.8352941176470589]}, "Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-2, -2}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}], 
         Cell[
          StyleData["Key3"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #2, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   TemplateBox[{"\[ThickSpace]", #3, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #4, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {
                 "ColumnsIndexed" -> {
                   2 -> GrayLevel[0.8352941176470589], 3 -> 
                    GrayLevel[0.8352941176470589], 4 -> 
                    GrayLevel[0.8352941176470589]}, "Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-2, -2}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Entity styles", "Subsubsection"], 
         Cell[
          StyleData["Entity"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               PaneSelectorBox[{True -> GridBox[{{
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontFamily -> "Source Sans Pro", 
                    FontWeight -> "Plain", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}},
                    BaselinePosition -> {1, 1}], False -> 
                 PaneBox[#, 
                   BaseStyle -> {
                    FontColor -> RGBColor[0.395437, 0.20595, 0.061158]}, 
                   BaselinePosition -> Baseline]}, 
                Dynamic[
                 CurrentValue[Evaluatable]], ImageSize -> Automatic, 
                BaselinePosition -> Baseline, 
                BaseStyle -> {FontFamily -> "Helvetica"}], FrameStyle -> 
               RGBColor[1., 0.504768, 0.], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityFrameless"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              PaneSelectorBox[{True -> GridBox[{{
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontFamily -> "Source Sans Pro", 
                    FontWeight -> "Plain", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                  BaselinePosition -> {1, 1}], False -> 
                PaneBox[#, 
                  BaseStyle -> {
                   FontColor -> RGBColor[0.395437, 0.20595, 0.061158]}, 
                  BaselinePosition -> Baseline]}, 
               Dynamic[
                CurrentValue[Evaluatable]], ImageSize -> Automatic, 
               BaselinePosition -> Baseline, 
               BaseStyle -> {FontFamily -> "Helvetica"}], #3, 
              BaseStyle -> {
               ShowStringCharacters -> False, LineIndent -> 0, 
                PrivateFontOptions -> {
                 FontWeight -> "Plain", "OperatorSubstitution" -> False}}]& ),
             Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityFramelessHot"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {
           DisplayFunction -> (PaneSelectorBox[{True -> GridBox[{{
                   
                   StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0]], 
                   StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0], Selectable -> 
                    False]}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 1}], False -> 
               PaneBox[#, BaseStyle -> {FontColor -> GrayLevel[0]}, 
                 BaselinePosition -> Baseline]}, 
              Dynamic[
               CurrentValue[Evaluatable]], ImageSize -> Automatic, 
              BaselinePosition -> Baseline, 
              BaseStyle -> {
               FontWeight -> "Plain", FontFamily -> "Helvetica", 
                ShowStringCharacters -> False, LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityClass"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               PaneSelectorBox[{True -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}},
                    BaselinePosition -> {1, 2}], False -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]]}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}},
                    BaselinePosition -> {1, 2}]}, 
                Dynamic[
                 CurrentValue[Evaluatable]], ImageSize -> Automatic, 
                BaselinePosition -> Baseline, 
                BaseStyle -> {FontFamily -> "Helvetica"}], FrameStyle -> 
               RGBColor[1., 0.504768, 0.], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityClassFrameless"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              PaneSelectorBox[{True -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                  BaselinePosition -> {1, 2}], False -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]]}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                  BaselinePosition -> {1, 2}]}, 
               Dynamic[
                CurrentValue[Evaluatable]], ImageSize -> Automatic, 
               BaselinePosition -> Baseline, 
               BaseStyle -> {FontFamily -> "Helvetica"}], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityClassFramelessHot"], ShowStringCharacters -> False,
           TemplateBoxOptions -> {
           DisplayFunction -> (PaneSelectorBox[{True -> GridBox[{{
                   PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                   
                   StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0]], 
                   StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0], Selectable -> 
                    False]}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 2}], False -> GridBox[{{
                   PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                   StyleBox[#, FontColor -> GrayLevel[0]]}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 2}]}, 
              Dynamic[
               CurrentValue[Evaluatable]], ImageSize -> Automatic, 
              BaselinePosition -> Baseline, 
              BaseStyle -> {
               FontWeight -> "Plain", FontFamily -> "Helvetica", 
                ShowStringCharacters -> False, LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityProperty"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               
               PaneBox[#, 
                BaseStyle -> {
                 FontSlant -> Italic, FontWeight -> Plain, FontFamily -> 
                  "Source Sans Pro", FontColor -> 
                  RGBColor[0.395437, 0.20595, 0.061158]}, BaselinePosition -> 
                Baseline], FrameStyle -> 
               RGBColor[0.94227, 0.703639, 0.033387], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityPropertyClass"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               PaneBox[
                GridBox[{{
                   PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], #}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 2}], 
                BaseStyle -> {
                 FontSlant -> Italic, FontWeight -> Plain, FontFamily -> 
                  "Source Sans Pro", FontColor -> 
                  RGBColor[0.395437, 0.20595, 0.061158]}, BaselinePosition -> 
                Baseline], FrameStyle -> 
               RGBColor[0.94227, 0.703639, 0.033387], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityValue"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              
              GridBox[{{#, #2}}, GridBoxAlignment -> {"Rows" -> {{Baseline}}},
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
               GridBoxSpacings -> {"Columns" -> {{0}}}, 
               BaselinePosition -> {1, 1}], Background -> 
              RGBColor[{0.9921568627450981, 0.9529411764705882, 
                0.8509803921568627}], BaselinePosition -> Baseline, 
              FrameMargins -> {{1, 1}, {1, 1}}, ImageMargins -> 2, FrameStyle -> 
              RGBColor[{0.9333333333333333, 0.8470588235294118, 
                0.5529411764705883}], RoundingRadius -> 5]& )}]}, Closed]]}, 
     Closed]]}, Visible -> False, FrontEndVersion -> 
  "11.1 for Mac OS X x86 (32-bit, 64-bit Kernel) (March 16, 2017)", 
  StyleDefinitions -> "StylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "p:271"->{
  Cell[651, 23, 434, 11, 
  70, "SectionDoubleDigit", "ExpressionUUID" -> "cc19c375-305f-43a2-80f2-
   fda7d353deee",
   CounterAssignments->{{"Section", 44}, {"Subsection", 0}, {
     "Subsubsection", 0}, {"Exercise", 0}},
   CellTags->"p:271"]},
 "i:1"->{
  Cell[1088, 36, 432, 11, 
  70, "Text", "ExpressionUUID" -> "2796ab3a-2022-4335-b56e-a22c0a7a08ef",
   CellTags->"i:1"]},
 "i:2"->{
  Cell[1523, 49, 235, 6, 
  70, "Text", "ExpressionUUID" -> "b416472a-5cd4-4ca1-bd84-8fc2c03f472d",
   CellTags->"i:2"]},
 "i:3"->{
  Cell[5436, 153, 296, 7, 
  70, "Text", "ExpressionUUID" -> "2e0f0e04-9c10-4516-896d-9d34ba4ae91a",
   CellTags->"i:3"]},
 "i:4"->{
  Cell[5735, 162, 499, 12, 
  70, "CodeCaption", "ExpressionUUID" -> "847886a6-e4eb-4ae8-beb1-89ff98caed6d
   ",
   CellTags->"i:4"]},
 "LastCellOfAPage"->{
  Cell[14025, 390, 340, 9, 
  70, "Text", "ExpressionUUID" -> "6973e92e-363d-48a2-839a-86b186bd1db4",
   CellTags->"LastCellOfAPage"],
  Cell[61994, 1527, 394, 11, 
  70, "Output", "ExpressionUUID" -> "46275763-ac98-4a54-860d-488d44cadfd0",
   Evaluatable->False,
   CellTags->"LastCellOfAPage"],
  Cell[71092, 1820, 3150, 76, 
  70, "Output", "ExpressionUUID" -> "8c5f0ad6-5aab-4240-8cc0-ef6ff56c3b30",
   Evaluatable->False,
   CellTags->"LastCellOfAPage"],
  Cell[81291, 2120, 2251, 51, 
  70, "Output", "ExpressionUUID" -> "0ca64217-b931-4a26-a002-b74e8c8d7b37",
   Evaluatable->False,
   CellTags->"LastCellOfAPage"],
  Cell[97384, 2545, 702, 14, 
  70, "Text", "ExpressionUUID" -> "e766c2f4-bb10-4674-86ea-79092efbc8b4",
   CellTags->{"i:15", "LastCellOfAPage"}],
  Cell[128282, 3295, 17454, 407, 
  70, "Output", "ExpressionUUID" -> "820322f8-c9ef-473b-9503-bb8da54e8a48",
   Evaluatable->False,
   CellTags->"LastCellOfAPage"],
  Cell[156828, 3991, 4924, 107, 
  70, "Output", "ExpressionUUID" -> "25d5d210-10ca-469e-9f56-63f16620f998",
   Evaluatable->False,
   CellTags->"LastCellOfAPage"],
  Cell[198675, 4901, 10791, 266, 
  70, "Output", "ExpressionUUID" -> "e26d2fa2-d313-4602-b9b0-a28878aa6f80",
   Evaluatable->False,
   CellTags->"LastCellOfAPage"],
  Cell[288383, 6994, 396, 9, 
  70, "Text", "ExpressionUUID" -> "fc0b1401-8adf-459c-97ea-e5f28b4c85ba",
   CellTags->"LastCellOfAPage"],
  Cell[331480, 8289, 287, 8, 
  70, "Output", "ExpressionUUID" -> "94ad9963-1801-406c-8b76-245fa1fcaf7f",
   Evaluatable->False,
   CellTags->"LastCellOfAPage"],
  Cell[467640, 11900, 785, 22, 
  70, "Exercise", "ExpressionUUID" -> "30fa41be-2d99-43e1-b81a-54316f635ca6",
   CellTags->"LastCellOfAPage"],
  Cell[532937, 13435, 395, 9, 
  70, "MoreExplore", "ExpressionUUID" -> "157cf999-448f-4342-b8ae-ad3f08534f89
   ",
   CellTags->"LastCellOfAPage"]},
 "i:5"->{
  Cell[14368, 401, 303, 10, 
  70, "CodeCaption", "ExpressionUUID" -> "3bad4a51-60e4-4d45-9308-b6509362a956
   ",
   CellTags->{"i:5", "p:272"}]},
 "p:272"->{
  Cell[14368, 401, 303, 10, 
  70, "CodeCaption", "ExpressionUUID" -> "3bad4a51-60e4-4d45-9308-b6509362a956
   ",
   CellTags->{"i:5", "p:272"}]},
 "i:6"->{
  Cell[24087, 662, 274, 9, 
  70, "CodeCaption", "ExpressionUUID" -> "4140d15c-cd8d-472f-ba50-a01ef9ec4d23
   ",
   CellTags->"i:6"]},
 "i:7"->{
  Cell[62403, 1541, 205, 5, 
  70, "CodeCaption", "ExpressionUUID" -> "d82b1ffa-93e4-4633-a488-dfbf8a910fd6
   ",
   CellTags->{"i:7", "p:273"}]},
 "p:273"->{
  Cell[62403, 1541, 205, 5, 
  70, "CodeCaption", "ExpressionUUID" -> "d82b1ffa-93e4-4633-a488-dfbf8a910fd6
   ",
   CellTags->{"i:7", "p:273"}]},
 "i:8"->{
  Cell[63009, 1563, 490, 12, 
  70, "Text", "ExpressionUUID" -> "ff98b7e0-138a-45af-989d-ed8d050058f1",
   CellTags->"i:8"]},
 "i:9"->{
  Cell[64898, 1626, 469, 13, 
  70, "Text", "ExpressionUUID" -> "b9eadf98-12c8-4cee-ba34-02522b3964a9",
   CellTags->"i:9"]},
 "i:10"->{
  Cell[65370, 1641, 201, 4, 
  70, "CodeCaption", "ExpressionUUID" -> "d7cbc34c-71c2-4865-a6f1-367a4f38ae80
   ",
   CellTags->"i:10"]},
 "i:11"->{
  Cell[74257, 1899, 296, 9, 
  70, "CodeCaption", "ExpressionUUID" -> "572c48e2-ce18-492b-847e-243f6b22a7eb
   ",
   CellTags->{"i:11", "p:274"}]},
 "p:274"->{
  Cell[74257, 1899, 296, 9, 
  70, "CodeCaption", "ExpressionUUID" -> "572c48e2-ce18-492b-847e-243f6b22a7eb
   ",
   CellTags->{"i:11", "p:274"}]},
 "i:12"->{
  Cell[75501, 1940, 234, 6, 
  70, "CodeCaption", "ExpressionUUID" -> "4bebf4d1-6780-4e6f-a019-008665b748b4
   ",
   CellTags->"i:12"]},
 "i:13"->{
  Cell[90594, 2364, 432, 14, 
  70, "Text", "ExpressionUUID" -> "aaafc508-8ccd-429f-bbc7-0d7775b5a9a2",
   CellTags->{"i:13", "p:275"}]},
 "p:275"->{
  Cell[90594, 2364, 432, 14, 
  70, "Text", "ExpressionUUID" -> "aaafc508-8ccd-429f-bbc7-0d7775b5a9a2",
   CellTags->{"i:13", "p:275"}]},
 "i:14"->{
  Cell[94123, 2460, 210, 4, 
  70, "CodeCaption", "ExpressionUUID" -> "8b3ce44b-c5b9-45c8-8ca3-9b3efd7ad228
   ",
   CellTags->"i:14"]},
 "i:15"->{
  Cell[97384, 2545, 702, 14, 
  70, "Text", "ExpressionUUID" -> "e766c2f4-bb10-4674-86ea-79092efbc8b4",
   CellTags->{"i:15", "LastCellOfAPage"}]},
 "i:16"->{
  Cell[98089, 2561, 230, 6, 
  70, "CodeCaption", "ExpressionUUID" -> "ea197806-bbae-4297-bf04-646ef8c24b10
   ",
   CellTags->"i:16"]},
 "p:276"->{
  Cell[123391, 3173, 194, 4, 
  70, "CodeCaption", "ExpressionUUID" -> "514fe8d7-dcf9-40ab-9724-a4eefe282359
   ",
   CellTags->"p:276"]},
 "i:17"->{
  Cell[127757, 3278, 192, 4, 
  70, "CodeCaption", "ExpressionUUID" -> "79c5c140-961a-4c40-a886-45ac913443e7
   ",
   CellTags->"i:17"]},
 "p:277"->{
  Cell[152711, 3880, 304, 7, 
  70, "Text", "ExpressionUUID" -> "c4336ec3-aad7-4288-8558-6675ae6db986",
   CellTags->"p:277"]},
 "p:278"->{
  Cell[165544, 4194, 191, 4, 
  70, "CodeCaption", "ExpressionUUID" -> "a0ecd7af-cb0a-4a5e-9e46-c9281e9d6268
   ",
   CellTags->"p:278"]},
 "p:279"->{
  Cell[215640, 5321, 191, 4, 
  70, "CodeCaption", "ExpressionUUID" -> "d667f47e-2343-439f-aadd-106948d262f2
   ",
   CellTags->"p:279"]},
 "i:18"->{
  Cell[216966, 5361, 243, 8, 
  70, "CodeCaption", "ExpressionUUID" -> "af3b7c15-ac0c-4139-aafc-7dcfe95aac0e
   ",
   CellTags->"i:18"]},
 "i:19"->{
  Cell[220110, 5449, 321, 8, 
  70, "Text", "ExpressionUUID" -> "d26353e7-5861-46b6-a125-d5a9784022b7",
   CellTags->"i:19"]},
 "i:20"->{
  Cell[288782, 7005, 301, 9, 
  70, "CodeCaption", "ExpressionUUID" -> "ac918967-8049-4a40-b209-429ff1b5d81c
   ",
   CellTags->"i:20"]},
 "i:21"->{
  Cell[291437, 7087, 263, 9, 
  70, "CodeCaption", "ExpressionUUID" -> "077d8b5a-d713-46af-af99-b847bb85496a
   ",
   CellTags->"i:21"]},
 "i:22"->{
  Cell[292572, 7126, 212, 5, 
  70, "CodeCaption", "ExpressionUUID" -> "85a000a9-860a-48dc-af17-61a3fc01aef5
   ",
   CellTags->{"i:22", "p:280"}]},
 "p:280"->{
  Cell[292572, 7126, 212, 5, 
  70, "CodeCaption", "ExpressionUUID" -> "85a000a9-860a-48dc-af17-61a3fc01aef5
   ",
   CellTags->{"i:22", "p:280"}]},
 "i:23"->{
  Cell[327565, 8153, 2138, 72, 
  70, "Text", "ExpressionUUID" -> "7afcd178-5b7f-4b0b-bd9c-f87370d9497b",
   CellTags->"i:23"]},
 "i:24"->{
  Cell[329706, 8227, 507, 15, 
  70, "CodeCaption", "ExpressionUUID" -> "62546393-eef3-4f27-a3eb-22c28ccf7d5d
   ",
   CellTags->"i:24"]},
 "i:25"->{
  Cell[330724, 8263, 517, 15, 
  70, "CodeCaption", "ExpressionUUID" -> "40c49a90-84f1-4263-9982-dcba75e68fa6
   ",
   CellTags->"i:25"]},
 "p:281"->{
  Cell[366266, 9310, 374, 12, 
  70, "CodeCaption", "ExpressionUUID" -> "5eeb8a3a-3cc3-4057-8c6b-67f219d45869
   ",
   CellTags->"p:281"]},
 "p:282"->{
  Cell[527896, 13262, 161, 4, 
  70, "QASection", "ExpressionUUID" -> "183acc82-52bc-4d90-8beb-601a886c3e6d",
   
   CellTags->"p:282"]},
 "i:26"->{
  Cell[528572, 13284, 194, 4, 
  70, "Question", "ExpressionUUID" -> "2a8af4f9-901e-4494-b14e-b68c718b4fdd",
   CellTags->"i:26"]},
 "i:27"->{
  Cell[529270, 13312, 512, 12, 
  70, "Answer", "ExpressionUUID" -> "eaaa3260-ec22-43a3-877a-1a32ce1aa32f",
   CellTags->"i:27"]},
 "i:28"->{
  Cell[529785, 13326, 286, 9, 
  70, "Question", "ExpressionUUID" -> "cb2a1140-5cd9-4c9d-a6f3-3903672ef4df",
   CellTags->"i:28"]},
 "i:29"->{
  Cell[530924, 13362, 457, 17, 
  70, "TechNote", "ExpressionUUID" -> "1b905e65-6889-46a4-ac00-dfddb9c1551c",
   CellTags->"i:29"]},
 "i:30"->{
  Cell[532150, 13408, 582, 16, 
  70, "TechNote", "ExpressionUUID" -> "98061f78-570f-4941-9192-a5cef97a7d4d",
   CellTags->"i:30"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"p:271", 623034, 15262},
 {"i:1", 623292, 15269},
 {"i:2", 623425, 15273},
 {"i:3", 623557, 15277},
 {"i:4", 623690, 15281},
 {"LastCellOfAPage", 623847, 15286},
 {"i:5", 625716, 15331},
 {"p:272", 625875, 15336},
 {"i:6", 626032, 15341},
 {"i:7", 626177, 15346},
 {"p:273", 626336, 15351},
 {"i:8", 626493, 15356},
 {"i:9", 626629, 15360},
 {"i:10", 626766, 15364},
 {"i:11", 626914, 15369},
 {"p:274", 627074, 15374},
 {"i:12", 627233, 15379},
 {"i:13", 627381, 15384},
 {"p:275", 627531, 15388},
 {"i:14", 627680, 15392},
 {"i:15", 627828, 15397},
 {"i:16", 627987, 15401},
 {"p:276", 628136, 15406},
 {"i:17", 628286, 15411},
 {"p:277", 628436, 15416},
 {"p:278", 628576, 15420},
 {"p:279", 628727, 15425},
 {"i:18", 628877, 15430},
 {"i:19", 629026, 15435},
 {"i:20", 629164, 15439},
 {"i:21", 629313, 15444},
 {"i:22", 629462, 15449},
 {"p:280", 629623, 15454},
 {"i:23", 629783, 15459},
 {"i:24", 629923, 15463},
 {"i:25", 630073, 15468},
 {"p:281", 630224, 15473},
 {"p:282", 630376, 15478},
 {"i:26", 630525, 15483},
 {"i:27", 630668, 15487},
 {"i:28", 630810, 15491},
 {"i:29", 630953, 15495},
 {"i:30", 631097, 15499}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[651, 23, 434, 11, 70, "SectionDoubleDigit", "ExpressionUUID" -> \
"cc19c375-305f-43a2-80f2-fda7d353deee",
 CounterAssignments->{{"Section", 44}, {"Subsection", 0}, {
   "Subsubsection", 0}, {"Exercise", 0}},
 CellTags->"p:271"],
Cell[1088, 36, 432, 11, 70, "Text", "ExpressionUUID" -> \
"2796ab3a-2022-4335-b56e-a22c0a7a08ef",
 CellTags->"i:1"],
Cell[1523, 49, 235, 6, 70, "Text", "ExpressionUUID" -> \
"b416472a-5cd4-4ca1-bd84-8fc2c03f472d",
 CellTags->"i:2"],
Cell[1761, 57, 225, 6, 70, "CodeCaption", "ExpressionUUID" -> \
"6b956a11-633c-4729-8a55-778fc94b6fbb"],
Cell[CellGroupData[{
Cell[2011, 67, 817, 20, 70, "Input", "ExpressionUUID" -> \
"62c29e5d-02e8-4e38-900c-e78f30e2951e"],
Cell[2831, 89, 2590, 61, 70, "Output", "ExpressionUUID" -> \
"a4532548-e265-4d4c-8ddb-d30133dbf1f0",
 Evaluatable->False]
}, Open  ]],
Cell[5436, 153, 296, 7, 70, "Text", "ExpressionUUID" -> \
"2e0f0e04-9c10-4516-896d-9d34ba4ae91a",
 CellTags->"i:3"],
Cell[5735, 162, 499, 12, 70, "CodeCaption", "ExpressionUUID" -> \
"847886a6-e4eb-4ae8-beb1-89ff98caed6d",
 CellTags->"i:4"],
Cell[CellGroupData[{
Cell[6259, 178, 193, 4, 70, "Input", "ExpressionUUID" -> \
"2500d645-bfe1-4021-9463-d6926270dd6a"],
Cell[6455, 184, 172, 4, 70, "Output", "ExpressionUUID" -> \
"5d4957a6-0181-4420-a19e-a4df0fc150da",
 Evaluatable->False]
}, Open  ]],
Cell[6642, 191, 521, 12, 70, "CodeCaption", "ExpressionUUID" -> \
"40a3c7dc-1f32-497f-880e-7dfb7a865819"],
Cell[CellGroupData[{
Cell[7188, 207, 198, 4, 70, "Input", "ExpressionUUID" -> \
"e7f1a697-f063-46a8-a997-71b26aca7b80"],
Cell[7389, 213, 172, 4, 70, "Output", "ExpressionUUID" -> \
"1bf536c7-3fb7-4246-bd44-725d2ca5af45",
 Evaluatable->False]
}, Open  ]],
Cell[7576, 220, 461, 11, 70, "Text", "ExpressionUUID" -> \
"67a20283-5757-463d-82c5-fe97bb5ef5f6"],
Cell[8040, 233, 364, 9, 70, "CodeCaption", "ExpressionUUID" -> \
"cca0a430-542f-4740-a8f8-c49411e682ff"],
Cell[CellGroupData[{
Cell[8429, 246, 162, 3, 70, "Input", "ExpressionUUID" -> \
"a7fdab4c-c5a8-4522-b950-898ef10595a3"],
Cell[8594, 251, 2187, 51, 70, "Output", "ExpressionUUID" -> \
"47783376-343d-4782-a934-510133f75565",
 Evaluatable->False]
}, Open  ]],
Cell[10796, 305, 416, 11, 70, "Text", "ExpressionUUID" -> \
"c2f619ed-c165-43da-b518-4c384c92137c"],
Cell[11215, 318, 361, 9, 70, "CodeCaption", "ExpressionUUID" -> \
"a9b1f89a-9a6c-412d-a2be-0d8b45cd1626"],
Cell[CellGroupData[{
Cell[11601, 331, 187, 4, 70, "Input", "ExpressionUUID" -> \
"3e3df6ec-8b54-45b0-aa1f-7e846091a9e3"],
Cell[11791, 337, 2219, 50, 70, "Output", "ExpressionUUID" -> \
"ddcc842e-7afd-4d97-a479-e0759dc9a0f2",
 Evaluatable->False]
}, Open  ]],
Cell[14025, 390, 340, 9, 70, "Text", "ExpressionUUID" -> \
"6973e92e-363d-48a2-839a-86b186bd1db4",
 CellTags->"LastCellOfAPage"],
Cell[14368, 401, 303, 10, 70, "CodeCaption", "ExpressionUUID" -> \
"3bad4a51-60e4-4d45-9308-b6509362a956",
 CellTags->{"i:5", "p:272"}],
Cell[CellGroupData[{
Cell[14696, 415, 183, 4, 70, "Input", "ExpressionUUID" -> \
"741bda11-46ff-4b93-a375-fc10d45362eb"],
Cell[14882, 421, 2220, 50, 70, "Output", "ExpressionUUID" -> \
"489e1845-524f-479c-9c12-6e8f2ef7872e",
 Evaluatable->False]
}, Open  ]],
Cell[17117, 474, 485, 15, 70, "Text", "ExpressionUUID" -> \
"f3b35c82-ab2e-44bb-8c69-4e3a584ede26"],
Cell[17605, 491, 287, 9, 70, "CodeCaption", "ExpressionUUID" -> \
"e39c6ec6-24ab-41b4-886c-4374e7e04e57"],
Cell[CellGroupData[{
Cell[17917, 504, 179, 4, 70, "Input", "ExpressionUUID" -> \
"c1a76092-f540-4e08-abe1-6e0159116fe0"],
Cell[18099, 510, 3067, 72, 70, "Output", "ExpressionUUID" -> \
"b22143c7-dd6f-40af-9a87-775af8f3c01f",
 Evaluatable->False]
}, Open  ]],
Cell[21181, 585, 418, 12, 70, "CodeCaption", "ExpressionUUID" -> \
"c5f3527f-fd4f-40a8-92e1-4f0b6e8375e7"],
Cell[CellGroupData[{
Cell[21624, 601, 225, 6, 70, "Input", "ExpressionUUID" -> \
"42dcdd97-b419-495d-bfe5-d12bdb032861"],
Cell[21852, 609, 2220, 50, 70, "Output", "ExpressionUUID" -> \
"1af4fd3d-5128-497d-b447-6eee5ea53ebf",
 Evaluatable->False]
}, Open  ]],
Cell[24087, 662, 274, 9, 70, "CodeCaption", "ExpressionUUID" -> \
"4140d15c-cd8d-472f-ba50-a01ef9ec4d23",
 CellTags->"i:6"],
Cell[CellGroupData[{
Cell[24386, 675, 186, 4, 70, "Input", "ExpressionUUID" -> \
"923e34d9-04d7-40ff-963c-a80e2298c50e"],
Cell[24575, 681, 35639, 783, 70, "Output", "ExpressionUUID" -> \
"9349c531-df93-49b9-adcd-38830722cb67",
 Evaluatable->False]
}, Open  ]],
Cell[60229, 1467, 185, 4, 70, "Text", "ExpressionUUID" -> \
"79b5422a-6451-438c-912f-c2858349b26b"],
Cell[60417, 1473, 484, 12, 70, "CodeCaption", "ExpressionUUID" -> \
"027ac5c2-f05c-40b5-a2c8-3e802b9c9989"],
Cell[CellGroupData[{
Cell[60926, 1489, 186, 4, 70, "Input", "ExpressionUUID" -> \
"900774a1-1566-4273-a6cd-2c7b45f72e62"],
Cell[61115, 1495, 363, 10, 70, "Output", "ExpressionUUID" -> \
"93a10bda-3c38-43dc-bf92-1f23031cf17a",
 Evaluatable->False]
}, Open  ]],
Cell[61493, 1508, 291, 9, 70, "CodeCaption", "ExpressionUUID" -> \
"a3a22487-c08e-4d54-bc5b-0522ef264a2b"],
Cell[CellGroupData[{
Cell[61809, 1521, 182, 4, 70, "Input", "ExpressionUUID" -> \
"2afd332c-154e-4e33-8cdd-c5f56a45478d"],
Cell[61994, 1527, 394, 11, 70, "Output", "ExpressionUUID" -> \
"46275763-ac98-4a54-860d-488d44cadfd0",
 Evaluatable->False,
 CellTags->"LastCellOfAPage"]
}, Open  ]],
Cell[62403, 1541, 205, 5, 70, "CodeCaption", "ExpressionUUID" -> \
"d82b1ffa-93e4-4633-a488-dfbf8a910fd6",
 CellTags->{"i:7", "p:273"}],
Cell[CellGroupData[{
Cell[62633, 1550, 184, 4, 70, "Input", "ExpressionUUID" -> \
"b3b54bc9-a83f-4803-aa0b-17e76799019e"],
Cell[62820, 1556, 174, 4, 70, "Output", "ExpressionUUID" -> \
"4aa40155-9de0-44d6-a471-f29c72d60242",
 Evaluatable->False]
}, Open  ]],
Cell[63009, 1563, 490, 12, 70, "Text", "ExpressionUUID" -> \
"ff98b7e0-138a-45af-989d-ed8d050058f1",
 CellTags->"i:8"],
Cell[63502, 1577, 367, 10, 70, "CodeCaption", "ExpressionUUID" -> \
"a6635119-7749-4ac7-95d3-598391ed7cdd"],
Cell[CellGroupData[{
Cell[63894, 1591, 221, 5, 70, "Input", "ExpressionUUID" -> \
"f20154f4-6a41-49af-adfe-c14887a8f821"],
Cell[64118, 1598, 174, 4, 70, "Output", "ExpressionUUID" -> \
"11b49846-53ad-45fe-a741-ba9ab6963177",
 Evaluatable->False]
}, Open  ]],
Cell[64307, 1605, 184, 4, 70, "CodeCaption", "ExpressionUUID" -> \
"a169fc75-0a38-4045-a3a4-aeda08a0fce7"],
Cell[CellGroupData[{
Cell[64516, 1613, 190, 4, 70, "Input", "ExpressionUUID" -> \
"104e98a3-3122-4786-840d-4b2da3dfc687"],
Cell[64709, 1619, 174, 4, 70, "Output", "ExpressionUUID" -> \
"cb82f2cc-1c41-4c84-9d07-1fce75c3d8d7",
 Evaluatable->False]
}, Open  ]],
Cell[64898, 1626, 469, 13, 70, "Text", "ExpressionUUID" -> \
"b9eadf98-12c8-4cee-ba34-02522b3964a9",
 CellTags->"i:9"],
Cell[65370, 1641, 201, 4, 70, "CodeCaption", "ExpressionUUID" -> \
"d7cbc34c-71c2-4865-a6f1-367a4f38ae80",
 CellTags->"i:10"],
Cell[CellGroupData[{
Cell[65596, 1649, 344, 10, 70, "Input", "ExpressionUUID" -> \
"36514890-116a-4f18-9729-92e8d3c5ace1"],
Cell[65943, 1661, 238, 6, 70, "Output", "ExpressionUUID" -> \
"a4d7233f-0698-4e01-87ca-f05647a1b76a",
 Evaluatable->False]
}, Open  ]],
Cell[66196, 1670, 270, 9, 70, "CodeCaption", "ExpressionUUID" -> \
"3e584423-7ae2-45f5-ab32-44545e37b1df"],
Cell[CellGroupData[{
Cell[66491, 1683, 345, 10, 70, "Input", "ExpressionUUID" -> \
"beab4963-4ecf-4497-943a-fa5a1969dac0"],
Cell[66839, 1695, 238, 6, 70, "Output", "ExpressionUUID" -> \
"419fafec-bb14-4557-9600-928ae03d6931",
 Evaluatable->False]
}, Open  ]],
Cell[67092, 1704, 339, 12, 70, "Text", "ExpressionUUID" -> \
"827a4b06-e6e1-4411-a2bd-9a4641c44481"],
Cell[67434, 1718, 372, 9, 70, "CodeCaption", "ExpressionUUID" -> \
"cefa1cbd-d66d-4a62-9103-8a3767c42b31"],
Cell[CellGroupData[{
Cell[67831, 1731, 233, 6, 70, "Input", "ExpressionUUID" -> \
"186f24eb-b211-4ca1-98bd-e1c5ac4b81a2"],
Cell[68067, 1739, 2480, 58, 70, "Output", "ExpressionUUID" -> \
"32734c09-762f-4de3-bcfc-c785750d4f27",
 Evaluatable->False]
}, Open  ]],
Cell[70562, 1800, 242, 7, 70, "CodeCaption", "ExpressionUUID" -> \
"5f8be866-29d8-45a2-a54d-c93d4fbae989"],
Cell[CellGroupData[{
Cell[70829, 1811, 260, 7, 70, "Input", "ExpressionUUID" -> \
"223fea74-c7fd-415f-8bfe-ad381260634e"],
Cell[71092, 1820, 3150, 76, 70, "Output", "ExpressionUUID" -> \
"8c5f0ad6-5aab-4240-8cc0-ef6ff56c3b30",
 Evaluatable->False,
 CellTags->"LastCellOfAPage"]
}, Open  ]],
Cell[74257, 1899, 296, 9, 70, "CodeCaption", "ExpressionUUID" -> \
"572c48e2-ce18-492b-847e-243f6b22a7eb",
 CellTags->{"i:11", "p:274"}],
Cell[CellGroupData[{
Cell[74578, 1912, 157, 3, 70, "Input", "ExpressionUUID" -> \
"c56c6565-0c05-4690-b4dc-b8a3189dceb5"],
Cell[74738, 1917, 556, 14, 70, "Output", "ExpressionUUID" -> \
"e5ead18f-a0f6-446a-9da1-40e89907c1de",
 Evaluatable->False]
}, Open  ]],
Cell[75309, 1934, 189, 4, 70, "Text", "ExpressionUUID" -> \
"737e6bd6-6b78-4101-91a9-a45bf66502fe"],
Cell[75501, 1940, 234, 6, 70, "CodeCaption", "ExpressionUUID" -> \
"4bebf4d1-6780-4e6f-a019-008665b748b4",
 CellTags->"i:12"],
Cell[CellGroupData[{
Cell[75760, 1950, 450, 13, 70, "Input", "ExpressionUUID" -> \
"28d90355-8492-4ca5-bfd4-a8290c872d69"],
Cell[76213, 1965, 284, 8, 70, "Output", "ExpressionUUID" -> \
"52d3be4f-5eb3-46db-91f8-30814e3c81c8",
 Evaluatable->False]
}, Open  ]],
Cell[76512, 1976, 223, 8, 70, "CodeCaption", "ExpressionUUID" -> \
"4380fe6a-134f-415d-a3d9-15fea9f58fc1"],
Cell[CellGroupData[{
Cell[76760, 1988, 451, 13, 70, "Input", "ExpressionUUID" -> \
"93ffa31e-eaa3-4ab9-a226-5d6c0ca9ad6f"],
Cell[77214, 2003, 284, 8, 70, "Output", "ExpressionUUID" -> \
"4279b39a-1f88-479a-8647-bf6b61d9c1f6",
 Evaluatable->False]
}, Open  ]],
Cell[77513, 2014, 424, 12, 70, "CodeCaption", "ExpressionUUID" -> \
"4fbd0656-4f09-4ec4-ae12-1ffe0d6210f0"],
Cell[CellGroupData[{
Cell[77962, 2030, 234, 6, 70, "Input", "ExpressionUUID" -> \
"697b1e75-efde-4bc6-8dbd-8abe08482176"],
Cell[78199, 2038, 2591, 61, 70, "Output", "ExpressionUUID" -> \
"748f56e2-54aa-407b-bf39-84b71868675d",
 Evaluatable->False]
}, Open  ]],
Cell[80805, 2102, 192, 4, 70, "CodeCaption", "ExpressionUUID" -> \
"50003b98-ff85-46ec-bf4e-04325771d12c"],
Cell[CellGroupData[{
Cell[81022, 2110, 266, 8, 70, "Input", "ExpressionUUID" -> \
"f2d0b126-8801-4e40-a711-9376f916e64e"],
Cell[81291, 2120, 2251, 51, 70, "Output", "ExpressionUUID" -> \
"0ca64217-b931-4a26-a002-b74e8c8d7b37",
 Evaluatable->False,
 CellTags->"LastCellOfAPage"]
}, Open  ]],
Cell[83557, 2174, 214, 6, 70, "Text", "ExpressionUUID" -> \
"faeb792f-2496-43f0-bbfa-7aaa2d65bfdb"],
Cell[83774, 2182, 293, 9, 70, "CodeCaption", "ExpressionUUID" -> \
"b3c72b2f-a416-415d-a967-2d2d9874735a"],
Cell[CellGroupData[{
Cell[84092, 2195, 192, 4, 70, "Input", "ExpressionUUID" -> \
"7ce7353c-90ea-4ebf-84db-8153365218be"],
Cell[84287, 2201, 3336, 85, 70, "Output", "ExpressionUUID" -> \
"24e16fb4-dbdd-46fb-b57e-3de2e24013fb",
 Evaluatable->False]
}, Open  ]],
Cell[87638, 2289, 371, 7, 70, "CodeCaption", "ExpressionUUID" -> \
"d1ae8501-e20d-48d5-80e7-e44bb2950a56"],
Cell[CellGroupData[{
Cell[88034, 2300, 318, 9, 70, "Input", "ExpressionUUID" -> \
"276d30ed-bf4e-42d4-85c9-8a8ac964ee47"],
Cell[88355, 2311, 2224, 50, 70, "Output", "ExpressionUUID" -> \
"2727301d-ee49-45a0-973e-3b5a0baf4fea",
 Evaluatable->False]
}, Open  ]],
Cell[90594, 2364, 432, 14, 70, "Text", "ExpressionUUID" -> \
"aaafc508-8ccd-429f-bbc7-0d7775b5a9a2",
 CellTags->{"i:13", "p:275"}],
Cell[91029, 2380, 188, 4, 70, "CodeCaption", "ExpressionUUID" -> \
"b1de8000-15d6-476e-894b-d77998484518"],
Cell[CellGroupData[{
Cell[91242, 2388, 648, 16, 70, "Input", "ExpressionUUID" -> \
"b681b44b-981a-4667-9e70-3b6f5b169df4"],
Cell[91893, 2406, 2215, 51, 70, "Output", "ExpressionUUID" -> \
"8b3174f6-6c26-4896-b23d-44cdbb80a9ff",
 Evaluatable->False]
}, Open  ]],
Cell[94123, 2460, 210, 4, 70, "CodeCaption", "ExpressionUUID" -> \
"8b3ce44b-c5b9-45c8-8ca3-9b3efd7ad228",
 CellTags->"i:14"],
Cell[CellGroupData[{
Cell[94358, 2468, 597, 15, 70, "Input", "ExpressionUUID" -> \
"ca0ad249-b62a-43fb-a3dc-68eb2ff7d1c3"],
Cell[94958, 2485, 2411, 57, 70, "Output", "ExpressionUUID" -> \
"42f5d16e-1d12-41e9-91dc-b6c59ad56152",
 Evaluatable->False]
}, Open  ]],
Cell[97384, 2545, 702, 14, 70, "Text", "ExpressionUUID" -> \
"e766c2f4-bb10-4674-86ea-79092efbc8b4",
 CellTags->{"i:15", "LastCellOfAPage"}],
Cell[98089, 2561, 230, 6, 70, "CodeCaption", "ExpressionUUID" -> \
"ea197806-bbae-4297-bf04-646ef8c24b10",
 CellTags->"i:16"],
Cell[CellGroupData[{
Cell[98344, 2571, 222, 5, 70, "Input", "ExpressionUUID" -> \
"503c7240-2d18-4663-9c2e-fe56325e3a30"],
Cell[98569, 2578, 24807, 592, 70, "Output", "ExpressionUUID" -> \
"f16fbb9a-bace-4a6d-95db-ceb220b228b5",
 Evaluatable->False]
}, Open  ]],
Cell[123391, 3173, 194, 4, 70, "CodeCaption", "ExpressionUUID" -> \
"514fe8d7-dcf9-40ab-9724-a4eefe282359",
 CellTags->"p:276"],
Cell[CellGroupData[{
Cell[123610, 3181, 196, 4, 70, "Input", "ExpressionUUID" -> \
"54ad1f83-90bd-47ca-8eb9-cf81f4e1ae02"],
Cell[123809, 3187, 3933, 88, 70, "Output", "ExpressionUUID" -> \
"cbdd1fa5-d129-4df1-a12a-6c382b4f6652",
 Evaluatable->False]
}, Open  ]],
Cell[127757, 3278, 192, 4, 70, "CodeCaption", "ExpressionUUID" -> \
"79c5c140-961a-4c40-a886-45ac913443e7",
 CellTags->"i:17"],
Cell[CellGroupData[{
Cell[127974, 3286, 305, 7, 70, "Input", "ExpressionUUID" -> \
"40dd9746-da3b-4976-b373-c21831f2f3de"],
Cell[128282, 3295, 17454, 407, 70, "Output", "ExpressionUUID" -> \
"820322f8-c9ef-473b-9503-bb8da54e8a48",
 Evaluatable->False,
 CellTags->"LastCellOfAPage"]
}, Open  ]],
Cell[145751, 3705, 231, 7, 70, "Text", "ExpressionUUID" -> \
"ce38b2e0-5f0b-46c6-b05a-e97bd879b605"],
Cell[145985, 3714, 181, 4, 70, "CodeCaption", "ExpressionUUID" -> \
"ac6257a2-2510-455f-b971-b9eaa8896a52"],
Cell[CellGroupData[{
Cell[146191, 3722, 204, 4, 70, "Input", "ExpressionUUID" -> \
"3c440acd-fd4c-4795-8876-21c68997dfa8"],
Cell[146398, 3728, 3270, 72, 70, "Output", "ExpressionUUID" -> \
"54adfa5d-7aab-4859-82bb-029d5a07d7a5",
 Evaluatable->False]
}, Open  ]],
Cell[149683, 3803, 261, 7, 70, "CodeCaption", "ExpressionUUID" -> \
"2af3a5df-37cf-4211-b426-61d58ec6477c"],
Cell[CellGroupData[{
Cell[149969, 3814, 245, 6, 70, "Input", "ExpressionUUID" -> \
"bfef0abd-9aa7-46a4-bfdd-4ad9224cd20e"],
Cell[150217, 3822, 2479, 55, 70, "Output", "ExpressionUUID" -> \
"0136d980-ce1f-49f2-a9fb-8d8b969a4786",
 Evaluatable->False]
}, Open  ]],
Cell[152711, 3880, 304, 7, 70, "Text", "ExpressionUUID" -> \
"c4336ec3-aad7-4288-8558-6675ae6db986",
 CellTags->"p:277"],
Cell[153018, 3889, 212, 6, 70, "CodeCaption", "ExpressionUUID" -> \
"01ab01d9-db46-4817-97d7-162bd6a5533f"],
Cell[CellGroupData[{
Cell[153255, 3899, 210, 4, 70, "Input", "ExpressionUUID" -> \
"c2a768d2-06b1-4cf6-9b93-e25ce7217556"],
Cell[153468, 3905, 2892, 68, 70, "Output", "ExpressionUUID" -> \
"3b80f848-4e88-48c9-ade1-afc0a7135197",
 Evaluatable->False]
}, Open  ]],
Cell[156375, 3976, 192, 4, 70, "CodeCaption", "ExpressionUUID" -> \
"0d881082-bb3f-42a0-823a-b366d1013fe9"],
Cell[CellGroupData[{
Cell[156592, 3984, 233, 5, 70, "Input", "ExpressionUUID" -> \
"14a91c81-27b7-46da-b4f1-e59a9994e955"],
Cell[156828, 3991, 4924, 107, 70, "Output", "ExpressionUUID" -> \
"25d5d210-10ca-469e-9f56-63f16620f998",
 Evaluatable->False,
 CellTags->"LastCellOfAPage"]
}, Open  ]],
Cell[161767, 4101, 217, 6, 70, "CodeCaption", "ExpressionUUID" -> \
"8c968d56-b267-4e6b-8701-42c1d24a8bf5"],
Cell[CellGroupData[{
Cell[162009, 4111, 355, 9, 70, "Input", "ExpressionUUID" -> \
"4918fbe2-4c3c-43ab-a559-7218b4eec33a"],
Cell[162367, 4122, 3162, 69, 70, "Output", "ExpressionUUID" -> \
"dc351da0-8d09-4871-865d-ec7c73b4b5d2",
 Evaluatable->False]
}, Open  ]],
Cell[165544, 4194, 191, 4, 70, "CodeCaption", "ExpressionUUID" -> \
"a0ecd7af-cb0a-4a5e-9e46-c9281e9d6268",
 CellTags->"p:278"],
Cell[CellGroupData[{
Cell[165760, 4202, 231, 5, 70, "Input", "ExpressionUUID" -> \
"b442e1a3-80e5-447c-8344-3d7b0167c4ed"],
Cell[165994, 4209, 30535, 633, 70, "Output", "ExpressionUUID" -> \
"135f560c-2ca6-48f8-a737-631daf1c50db",
 Evaluatable->False]
}, Open  ]],
Cell[196544, 4845, 216, 6, 70, "Text", "ExpressionUUID" -> \
"8c254ac4-13e6-4d84-8052-451351432a31"],
Cell[196763, 4853, 240, 7, 70, "CodeCaption", "ExpressionUUID" -> \
"0f394454-1845-4666-b565-07bfdd86130c"],
Cell[CellGroupData[{
Cell[197028, 4864, 1644, 35, 70, "Input", "ExpressionUUID" -> \
"ecab95d0-a2e4-4e27-b804-f504cd12c522"],
Cell[198675, 4901, 10791, 266, 70, "Output", "ExpressionUUID" -> \
"e26d2fa2-d313-4602-b9b0-a28878aa6f80",
 Evaluatable->False,
 CellTags->"LastCellOfAPage"]
}, Open  ]],
Cell[209481, 5170, 237, 7, 70, "CodeCaption", "ExpressionUUID" -> \
"55a98c6c-d36e-4712-a3e1-f96d041c6f2d"],
Cell[CellGroupData[{
Cell[209743, 5181, 1743, 38, 70, "Input", "ExpressionUUID" -> \
"e81de660-2d5d-4743-bb9e-50078b6a98aa"],
Cell[211489, 5221, 4136, 97, 70, "Output", "ExpressionUUID" -> \
"6b8812e4-10be-4b1d-98de-c67a42283330",
 Evaluatable->False]
}, Open  ]],
Cell[215640, 5321, 191, 4, 70, "CodeCaption", "ExpressionUUID" -> \
"d667f47e-2343-439f-aadd-106948d262f2",
 CellTags->"p:279"],
Cell[CellGroupData[{
Cell[215856, 5329, 157, 3, 70, "Input", "ExpressionUUID" -> \
"09c76102-2928-4699-8c71-0ac0350fef5e"],
Cell[216016, 5334, 935, 24, 70, "Output", "ExpressionUUID" -> \
"0c54008a-59d3-4c05-a380-4c09026a3d01",
 Evaluatable->False]
}, Open  ]],
Cell[216966, 5361, 243, 8, 70, "CodeCaption", "ExpressionUUID" -> \
"af3b7c15-ac0c-4139-aafc-7dcfe95aac0e",
 CellTags->"i:18"],
Cell[CellGroupData[{
Cell[217234, 5373, 159, 3, 70, "Input", "ExpressionUUID" -> \
"9a119d97-05bd-40d3-8a6e-2e1853f9e5b8"],
Cell[217396, 5378, 314, 7, 70, "Output", "ExpressionUUID" -> \
"fb7b5436-f5fd-401d-a6a2-a1e795817dd1",
 Evaluatable->False]
}, Open  ]],
Cell[217725, 5388, 203, 5, 70, "CodeCaption", "ExpressionUUID" -> \
"3156023d-8266-40c1-a8a6-7b3cf38eefa2"],
Cell[CellGroupData[{
Cell[217953, 5397, 1825, 40, 70, "Input", "ExpressionUUID" -> \
"d030d232-b71a-4a10-af20-5ee305193c44"],
Cell[219781, 5439, 314, 7, 70, "Output", "ExpressionUUID" -> \
"4a8544b5-f763-4874-8e10-4da1563839b0",
 Evaluatable->False]
}, Open  ]],
Cell[220110, 5449, 321, 8, 70, "Text", "ExpressionUUID" -> \
"d26353e7-5861-46b6-a125-d5a9784022b7",
 CellTags->"i:19"],
Cell[220434, 5459, 227, 6, 70, "CodeCaption", "ExpressionUUID" -> \
"14030172-864a-4046-810b-f1b27d8b24f8"],
Cell[CellGroupData[{
Cell[220686, 5469, 1742, 38, 70, "Input", "ExpressionUUID" -> \
"a4cc2b28-35c2-4928-9400-5876f92a2d34"],
Cell[222431, 5509, 65937, 1482, 70, "Output", "ExpressionUUID" -> \
"e7103873-8150-484e-904b-49e270e14bd8",
 Evaluatable->False]
}, Open  ]],
Cell[288383, 6994, 396, 9, 70, "Text", "ExpressionUUID" -> \
"fc0b1401-8adf-459c-97ea-e5f28b4c85ba",
 CellTags->"LastCellOfAPage"],
Cell[288782, 7005, 301, 9, 70, "CodeCaption", "ExpressionUUID" -> \
"ac918967-8049-4a40-b209-429ff1b5d81c",
 CellTags->"i:20"],
Cell[CellGroupData[{
Cell[289108, 7018, 470, 11, 70, "Input", "ExpressionUUID" -> \
"f2bd4855-efbd-4b95-8d88-b15e1b1aeadc"],
Cell[289581, 7031, 1841, 53, 70, "Output", "ExpressionUUID" -> \
"274dd8f9-5b9a-4c22-9441-0b68670ba722",
 Evaluatable->False]
}, Open  ]],
Cell[291437, 7087, 263, 9, 70, "CodeCaption", "ExpressionUUID" -> \
"077d8b5a-d713-46af-af99-b847bb85496a",
 CellTags->"i:21"],
Cell[CellGroupData[{
Cell[291725, 7100, 450, 11, 70, "Input", "ExpressionUUID" -> \
"0e2f3e54-9878-482d-8b04-b0d7f0637d2d"],
Cell[292178, 7113, 379, 10, 70, "Output", "ExpressionUUID" -> \
"78abf2e1-db41-48e1-9bc5-b2df26ef1bcc",
 Evaluatable->False]
}, Open  ]],
Cell[292572, 7126, 212, 5, 70, "CodeCaption", "ExpressionUUID" -> \
"85a000a9-860a-48dc-af17-61a3fc01aef5",
 CellTags->{"i:22", "p:280"}],
Cell[CellGroupData[{
Cell[292809, 7135, 365, 9, 70, "Input", "ExpressionUUID" -> \
"324e1662-c35d-436b-b65f-76ed4ccfa40e"],
Cell[293177, 7146, 33758, 983, 70, "Output", "ExpressionUUID" -> \
"d566a20d-7dfa-4f19-9266-d0ced07e8df2",
 Evaluatable->False]
}, Open  ]],
Cell[326950, 8132, 612, 19, 70, "Text", "ExpressionUUID" -> \
"c4511143-f1c0-48d5-a62f-eda42f6fcbba"],
Cell[327565, 8153, 2138, 72, 70, "Text", "ExpressionUUID" -> \
"7afcd178-5b7f-4b0b-bd9c-f87370d9497b",
 CellTags->"i:23"],
Cell[329706, 8227, 507, 15, 70, "CodeCaption", "ExpressionUUID" -> \
"62546393-eef3-4f27-a3eb-22c28ccf7d5d",
 CellTags->"i:24"],
Cell[CellGroupData[{
Cell[330238, 8246, 211, 5, 70, "Input", "ExpressionUUID" -> \
"62e03f26-26f7-40f0-8d10-a174e1d61c4c"],
Cell[330452, 8253, 257, 7, 70, "Output", "ExpressionUUID" -> \
"c2a08c42-57c2-45da-8dc2-a0239cd19407",
 Evaluatable->False]
}, Open  ]],
Cell[330724, 8263, 517, 15, 70, "CodeCaption", "ExpressionUUID" -> \
"40c49a90-84f1-4263-9982-dcba75e68fa6",
 CellTags->"i:25"],
Cell[CellGroupData[{
Cell[331266, 8282, 211, 5, 70, "Input", "ExpressionUUID" -> \
"d3b3b9d5-700d-48f9-af30-af8317857afd"],
Cell[331480, 8289, 287, 8, 70, "Output", "ExpressionUUID" -> \
"94ad9963-1801-406c-8b76-245fa1fcaf7f",
 Evaluatable->False,
 CellTags->"LastCellOfAPage"]
}, Open  ]],
Cell[331782, 8300, 394, 12, 70, "CodeCaption", "ExpressionUUID" -> \
"29c68b46-637d-4548-801f-4b206d47ea8c"],
Cell[CellGroupData[{
Cell[332201, 8316, 289, 6, 70, "Input", "ExpressionUUID" -> \
"5b2b5756-210c-458c-a4a3-0dd6341483df"],
Cell[332493, 8324, 33758, 983, 70, "Output", "ExpressionUUID" -> \
"f8da4100-dbe5-42c2-b1d3-0004ca144d13",
 Evaluatable->False]
}, Open  ]],
Cell[366266, 9310, 374, 12, 70, "CodeCaption", "ExpressionUUID" -> \
"5eeb8a3a-3cc3-4057-8c6b-67f219d45869",
 CellTags->"p:281"],
Cell[CellGroupData[{
Cell[366665, 9326, 289, 6, 70, "Input", "ExpressionUUID" -> \
"127a5577-1577-4e93-8304-6e2769426623"],
Cell[366957, 9334, 33757, 983, 70, "Output", "ExpressionUUID" -> \
"f6b3da2f-d821-451c-9331-a884a33f324b",
 Evaluatable->False]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[400763, 10323, 159, 4, 70, "VocabularySection", "ExpressionUUID" -> \
"6c92142d-db3b-4676-8e56-89bd1faabd76"],
Cell[400925, 10329, 2795, 78, 70, "VocabularyTable", "ExpressionUUID" -> \
"d82111fd-5835-4931-ae06-425c7f6a721a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[403757, 10412, 1780, 46, 70, "ExerciseSection", "ExpressionUUID" -> \
"f6437afe-f312-46c7-acb1-d630eca3547f"],
Cell[CellGroupData[{
Cell[405562, 10462, 1238, 38, 70, "ExerciseSummaryCell", "ExpressionUUID" -> \
"dae49f73-c8f4-449e-bbac-7adea862a001"],
Cell[406803, 10502, 474, 16, 70, "Text", "ExpressionUUID" -> \
"1bf7fbe3-4e4e-446f-ac52-c20ba5af8ea4"],
Cell[CellGroupData[{
Cell[407302, 10522, 750, 21, 70, "Exercise", "ExpressionUUID" -> \
"51ff3254-0693-4ffb-9810-012e6c0cd5a4"],
Cell[408055, 10545, 5758, 133, 70, "ExerciseOutput", "ExpressionUUID" -> \
"8ca14b3d-596d-4961-b6df-72a74b48a774"]
}, Closed]],
Cell[CellGroupData[{
Cell[413850, 10683, 721, 20, 70, "Exercise", "ExpressionUUID" -> \
"b2c1894a-f885-4c68-a55e-14bd45af0d92"],
Cell[414574, 10705, 39308, 880, 70, "ExerciseOutput", "ExpressionUUID" -> \
"8373ceee-f9af-4eba-8ade-8cce550277a6"]
}, Closed]],
Cell[CellGroupData[{
Cell[453919, 11590, 744, 21, 70, "Exercise", "ExpressionUUID" -> \
"cd99c2da-2315-4762-9f06-e4c2d1708bf1"],
Cell[454666, 11613, 12937, 282, 70, "ExerciseOutput", "ExpressionUUID" -> \
"c5708874-ae11-447a-be7a-f393cb9a26e0"]
}, Closed]],
Cell[CellGroupData[{
Cell[467640, 11900, 785, 22, 70, "Exercise", "ExpressionUUID" -> \
"30fa41be-2d99-43e1-b81a-54316f635ca6",
 CellTags->"LastCellOfAPage"],
Cell[468428, 11924, 12763, 278, 70, "ExerciseOutput", "ExpressionUUID" -> \
"835612ff-a666-4282-af2d-052637af60ce"]
}, Closed]],
Cell[CellGroupData[{
Cell[481228, 12207, 768, 21, 70, "Exercise", "ExpressionUUID" -> \
"c56f7e2e-7d46-4fd9-8f51-e184a58fcd10"],
Cell[481999, 12230, 12585, 274, 70, "ExerciseOutput", "ExpressionUUID" -> \
"27e53d26-8dfe-48d0-8228-48ac8ed8971c"]
}, Closed]],
Cell[CellGroupData[{
Cell[494621, 12509, 728, 20, 70, "Exercise", "ExpressionUUID" -> \
"f0827408-96d0-4b43-b327-0c99aae86c4a"],
Cell[495352, 12531, 12467, 274, 70, "ExerciseOutput", "ExpressionUUID" -> \
"d7fd717f-f783-4043-9bf4-1a1214ab473a"]
}, Closed]],
Cell[CellGroupData[{
Cell[507856, 12810, 745, 21, 70, "Exercise", "ExpressionUUID" -> \
"aa58695b-4438-4abf-b1ec-22f971033261"],
Cell[508604, 12833, 11946, 245, 70, "ExerciseOutput", "ExpressionUUID" -> \
"41a65d5c-5d6c-42ab-bcf8-db7a1d8e9ef0"]
}, Closed]],
Cell[CellGroupData[{
Cell[520587, 13083, 810, 21, 70, "Exercise", "ExpressionUUID" -> \
"60c74ee8-90b0-4e8e-b5d0-4d35393a1bb7"],
Cell[521400, 13106, 6435, 149, 70, "ExerciseOutput", "ExpressionUUID" -> \
"50030b03-d45d-4ae3-88d5-6a4d56123b8c"]
}, Closed]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[527896, 13262, 161, 4, 70, "QASection", "ExpressionUUID" -> \
"183acc82-52bc-4d90-8beb-601a886c3e6d",
 CellTags->"p:282"],
Cell[528060, 13268, 180, 4, 70, "Question", "ExpressionUUID" -> \
"27ae4f7c-cae0-413d-929b-45326b3bcaf8"],
Cell[528243, 13274, 326, 8, 70, "Answer", "ExpressionUUID" -> \
"9e04f265-542a-4f25-a3d7-41efaebef88a"],
Cell[528572, 13284, 194, 4, 70, "Question", "ExpressionUUID" -> \
"2a8af4f9-901e-4494-b14e-b68c718b4fdd",
 CellTags->"i:26"],
Cell[528769, 13290, 245, 9, 70, "Answer", "ExpressionUUID" -> \
"5555afc6-afab-45d2-9be3-5f88789cd0e5"],
Cell[529017, 13301, 250, 9, 70, "Question", "ExpressionUUID" -> \
"201359bd-2a59-4eb3-aa90-9300b427cabd"],
Cell[529270, 13312, 512, 12, 70, "Answer", "ExpressionUUID" -> \
"eaaa3260-ec22-43a3-877a-1a32ce1aa32f",
 CellTags->"i:27"],
Cell[529785, 13326, 286, 9, 70, "Question", "ExpressionUUID" -> \
"cb2a1140-5cd9-4c9d-a6f3-3903672ef4df",
 CellTags->"i:28"],
Cell[530074, 13337, 653, 14, 70, "Answer", "ExpressionUUID" -> \
"108a05db-27c1-478b-9c18-6628f3c6e159"]
}, Open  ]],
Cell[CellGroupData[{
Cell[530764, 13356, 157, 4, 70, "TechNoteSection", "ExpressionUUID" -> \
"6e7e3fac-ae11-46a8-b005-4fbd062ef113"],
Cell[530924, 13362, 457, 17, 70, "TechNote", "ExpressionUUID" -> \
"1b905e65-6889-46a4-ac00-dfddb9c1551c",
 CellTags->"i:29"],
Cell[531384, 13381, 293, 9, 70, "TechNote", "ExpressionUUID" -> \
"60cc95cf-817f-47ef-b0c4-f909cf2556ec"],
Cell[531680, 13392, 467, 14, 70, "TechNote", "ExpressionUUID" -> \
"b424403d-09bd-48fb-bb2d-47ca21475e0c"],
Cell[532150, 13408, 582, 16, 70, "TechNote", "ExpressionUUID" -> \
"98061f78-570f-4941-9192-a5cef97a7d4d",
 CellTags->"i:30"]
}, Open  ]],
Cell[CellGroupData[{
Cell[532769, 13429, 165, 4, 70, "MoreExploreSection", "ExpressionUUID" -> \
"e3edf3c2-2901-4e41-b59f-b920c0561aeb"],
Cell[532937, 13435, 395, 9, 70, "MoreExplore", "ExpressionUUID" -> \
"157cf999-448f-4342-b8ae-ad3f08534f89",
 CellTags->"LastCellOfAPage"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
(* NotebookSignature tRscpOXaKnK@CjuIpLsLooNF *)
