(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    187418,       4350]
NotebookOptionsPosition[     82897,       2136]
NotebookOutlinePosition[    177672,       4112]
CellTagsIndexPosition[    176972,       4082]
WindowTitle->How to Debug: Elementary Introduction to the Wolfram Language
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[BoxData[
 InterpretationBox[Cell[
  "Debugging Your Code", "SectionInline",ExpressionUUID->
   "95024ff6-8d58-42ec-983b-42e66ad31762"],
  $Line = 0; Null]], "SectionDoubleDigit",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CounterAssignments->{{"Section", 46}, {"Subsection", 0}, {
   "Subsubsection", 0}, {"Exercise", 0}},
 CellTags->"p:291",ExpressionUUID->"071a46e0-faad-409c-890a-0e6295b00e15"],

Cell["\<\
Even the most experienced programmers have to spend time debugging their \
code. It\[CloseCurlyQuote]s an inevitable part of programming. But in the \
Wolfram Language it\[CloseCurlyQuote]s particularly easy, especially if you \
follow a few principles.\
\>", "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:1",ExpressionUUID->"1a455f21-94cd-4c5a-be62-2dd01ecaed44"],

Cell["\<\
The first and most important principle is to try out any piece of code you \
write. Because the Wolfram Language is interactive\[LongDash]and symbolic\
\[LongDash]you can always instantly do this. So even if you just make a tiny \
change, run your code again, and see if your test examples still work. If \
they don\[CloseCurlyQuote]t, fix the code before you go on.\
\>", "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:2",ExpressionUUID->"652d8c2f-8976-41c5-abe4-d30059dd3274"],

Cell["\<\
The Wolfram Language can sometimes tell as soon as you type something in that \
it\[CloseCurlyQuote]s likely to be wrong\[LongDash]and then it\
\[CloseCurlyQuote]ll color it red. \
\>", "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"ef388a17-43c4-426e-8ff7-c213db3ca3a0"],

Cell["A piece of code with various problems, indicated with red:", \
"CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:3",ExpressionUUID->"e1cac363-6a06-42d6-971a-01a0ad6b2d28"],

Cell[BoxData[
 RowBox[{"WordCloud", "[", 
  RowBox[{
   RowBox[{"Nest", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Join", "[", 
       RowBox[{"#", ",", 
        RowBox[{
         RowBox[{"Length", "[", "\[ThinSpace]", "]"}], "+", 
         RowBox[{"Reverse", "[", 
          RowBox[{"#", ",", "1", ",", "2"}], "]"}]}]}], "]"}], "&"}], ",", 
     RowBox[{"{", "0", "}"}], ",", "m"}], "]"}], ",", 
   RowBox[{"Spacings", "\[Rule]", "0"}]}], "]"}]], "Input",
 Deletable->False,
 ShowSyntaxStyles->
  True,ExpressionUUID->"18d94e65-c769-4866-95d1-06d1ff557c26"],

Cell["\<\
Once you run a piece of code, the Wolfram Language can also often tell if \
things have gone obviously wrong\[LongDash]in which case \
it\[CloseCurlyQuote]ll display a message. The code here ends up, for example, \
asking for the first element of a length-0 list.\
\>", "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:4",ExpressionUUID->"20e25a54-c006-46cb-90d2-e85e78421d67"],

Cell[TextData[{
 "Something is obviously wrong when ",
 ButtonBox["First",
  BaseStyle->"Link"],
 " is applied to the ",
 Cell[BoxData[
  RowBox[{"{", "}"}]], "InlineCode",ExpressionUUID->
  "348aded0-0c0e-4062-a0d5-59ea0c92ee49"],
 " that\[CloseCurlyQuote]s produced by ",
 ButtonBox["Cases",
  BaseStyle->"Link"],
 ": "
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:5",ExpressionUUID->"0a554842-3837-4c53-b8d8-689232273f3a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"First", "[", 
  RowBox[{"Cases", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "2", ",", "3", ",", "4"}], "}"}], ",", "777"}], "]"}], 
  "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[1]:=",ExpressionUUID->"58f83671-e93b-455d-b7d3-fd30081b5d93"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"First", "::", "nofirst"}], "MessageName"], ":", 
  " ", "\<\"\[NoBreak]\\!\\({}\\)\[NoBreak] has zero length and no first \
element. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\
\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/First\\\", ButtonNote -> \\\
\"First::nofirst\\\"]\\)\"\>"}]], "Message", "MSG",
 CellLabel->
  "During evaluation of \
In[183]:=",ExpressionUUID->"fc7b19fe-cded-4edd-ac6e-357a9d20ee66"],

Cell[BoxData[
 RowBox[{"First", "[", 
  RowBox[{"{", "}"}], "]"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[1]=",ExpressionUUID->"c2ab5e02-4faa-40ac-94cb-e394eba2a1c7"]
}, Open  ]],

Cell["\<\
Sometimes the Wolfram Language may not know what to do with something, but it \
may not be sure there\[CloseCurlyQuote]s a problem. In such cases, it\
\[CloseCurlyQuote]ll just leave the input unchanged and return it in a \
symbolic form that can later get a definite value.\
\>", "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:6",ExpressionUUID->"62c6b4e7-9e6a-4c98-8c01-e445b5c06825"],

Cell[TextData[{
 "Without values for ",
 Cell[BoxData[
 "a"], "InlineCode",ExpressionUUID->"41ccc272-141f-4fed-bc3e-e851af27e473"],
 ", ",
 Cell[BoxData[
 "b"], "InlineCode",ExpressionUUID->"8039005c-168d-40c9-9550-5f7fe5719d83"],
 " and ",
 Cell[BoxData[
 "c"], "InlineCode",ExpressionUUID->"c06caa53-e3f7-4cd4-9847-c643a17d6923"],
 ", the Wolfram Language just returns this unchanged:"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"e4ee2f1a-754f-4141-a2af-5d778c2a01c7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Graph", "[", 
  RowBox[{"{", 
   RowBox[{"a", ",", "b", ",", "c"}], "}"}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[2]:=",ExpressionUUID->"9e636a0b-e857-42ea-bd02-ea522a9480ed"],

Cell[BoxData[
 RowBox[{"Graph", "[", 
  RowBox[{"{", 
   RowBox[{"a", ",", "b", ",", "c"}], "}"}], "]"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[2]=",ExpressionUUID->"75667a5c-59ff-46e8-830e-ab88c52fe5e6"]
}, Open  ]],

Cell["\<\
If you generate graphics with symbolic pieces that can\[CloseCurlyQuote]t be \
rendered, you\[CloseCurlyQuote]ll get a pink box:\
\>", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:7",ExpressionUUID->"62afbb58-67a2-471d-8912-18e6dc58c561"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Graphics", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Circle", "[", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], "]"}], ",", 
    RowBox[{"Disk", "[", 
     RowBox[{"{", 
      RowBox[{"a", ",", "b"}], "}"}], "]"}]}], "}"}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[3]:=",ExpressionUUID->"cf01afb9-684d-42c5-b477-d6f5d6de8a4f"],

Cell[BoxData[
 GraphicsBox[{CircleBox[{0, 0}], DiskBox[{$CellContext`a, $CellContext`b}]},
  ImageSize->{38.72265625, Automatic}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[3]=",ExpressionUUID->"3f31e4d7-cd0d-46e3-9c35-34d839c261c4"]
}, Open  ]],

Cell[TextData[{
 "As you build up functions, it\[CloseCurlyQuote]s quite common to have \
fragments of code that you want to test without finishing the function. You \
can do this by setting values of variables using ",
 ButtonBox["With",
  BaseStyle->"Link"],
 "\[LongDash]which works like ",
 ButtonBox["Module",
  BaseStyle->"Link"],
 ", except it doesn\[CloseCurlyQuote]t allow values to be reset."
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->{
  "i:8", "LastCellOfAPage"},ExpressionUUID->"e6798835-d02a-4ccd-b026-\
fb061dbee5ee"],

Cell[TextData[{
 "Use ",
 ButtonBox["With",
  BaseStyle->"Link"],
 " to temporarily set ",
 Cell[BoxData[
  RowBox[{"m", 
   ButtonBox["=",
    BaseStyle->"Link",
    ButtonData->"Set"], "4"}]], "InlineCode",ExpressionUUID->
  "fcc77e54-0a96-49ee-8c66-3ccd09330e78"],
 " to test a fragment of code:"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->{
  "i:9", "p:292"},ExpressionUUID->"e5809107-7ed7-40fa-8497-5141b9a3b4b1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"With", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"m", "=", "4"}], "}"}], ",", 
   RowBox[{"Nest", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Join", "[", 
       RowBox[{"#", ",", 
        RowBox[{
         RowBox[{"Length", "[", "#", "]"}], "+", 
         RowBox[{"Reverse", "[", "#", "]"}]}]}], "]"}], "&"}], ",", 
     RowBox[{"{", "0", "}"}], ",", "m"}], "]"}]}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[4]:=",ExpressionUUID->"ee41a2c9-8a1c-48e3-b5f0-8cb71010e946"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0", ",", "1", ",", "3", ",", "2", ",", "6", ",", "7", ",", "5", ",", "4", 
   ",", "12", ",", "13", ",", "15", ",", "14", ",", "10", ",", "11", ",", "9",
    ",", "8"}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[4]=",ExpressionUUID->"ba16175f-0b7e-4861-bd61-95701d475da1"]
}, Open  ]],

Cell["\<\
When debugging takes a long time it\[CloseCurlyQuote]s usually because one\
\[CloseCurlyQuote]s made the wrong assumption about what \
one\[CloseCurlyQuote]s code is doing. And in my experience, the best way to \
overcome this is just to systematically analyze how the code behaves, making \
tables of results, generating visualizations, testing out assertions, and so \
on. \
\>", "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:10",ExpressionUUID->"205b4a36-21f1-441b-8b45-1c2e5bb8cfb7"],

Cell["Make plots to see what the code is doing:", "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"8a138d6a-acd0-431c-926b-e5c4ed4ef175"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListLinePlot", "/@", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"Nest", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Join", "[", 
        RowBox[{"#", ",", 
         RowBox[{
          RowBox[{"Length", "[", "#", "]"}], "+", 
          RowBox[{"Reverse", "[", "#", "]"}]}]}], "]"}], "&"}], ",", 
      RowBox[{"{", "0", "}"}], ",", "m"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"m", ",", "6"}], "}"}]}], "]"}]}]], "Input",
 Deletable->False,
 CellLabel->"In[5]:=",ExpressionUUID->"05536735-e73c-444f-8d41-36924ea20583"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   GraphicsBox[{{}, {{}, {}, {{{
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
          0.019444444444444445`], AbsoluteThickness[1.6], 
          LineBox[{{1., 0.}, {2., 1.}}]}}}}}, {}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->{True, True},
    AxesLabel->{None, None},
    AxesOrigin->{0, 0},
    DisplayFunction->Identity,
    Frame->{{False, False}, {False, False}},
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLines->{None, None},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    ImageSize->120,
    Method->{},
    PlotRange->{{0., 2.}, {0, 1.}},
    PlotRangeClipping->True,
    PlotRangePadding->{{
       Scaled[0.02], 
       Scaled[0.02]}, {
       Scaled[0.02], 
       Scaled[0.05]}},
    Ticks->{Automatic, Automatic}], ",", 
   GraphicsBox[{{}, {{}, {}, {{{
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
          0.019444444444444445`], AbsoluteThickness[1.6], 
          LineBox[{{1., 0.}, {2., 1.}, {3., 3.}, {4., 2.}}]}}}}}, {}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->{True, True},
    AxesLabel->{None, None},
    AxesOrigin->{0, 0},
    DisplayFunction->Identity,
    Frame->{{False, False}, {False, False}},
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLines->{None, None},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    ImageSize->120,
    Method->{},
    PlotRange->{{0., 4.}, {0, 3.}},
    PlotRangeClipping->True,
    PlotRangePadding->{{
       Scaled[0.02], 
       Scaled[0.02]}, {
       Scaled[0.02], 
       Scaled[0.05]}},
    Ticks->{Automatic, Automatic}], ",", 
   GraphicsBox[{{}, {{}, {}, {{{
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
          0.019444444444444445`], AbsoluteThickness[1.6], 
          LineBox[{{1., 0.}, {2., 1.}, {3., 3.}, {4., 2.}, {5., 6.}, {6., 
           7.}, {7., 5.}, {8., 4.}}]}}}}}, {}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->{True, True},
    AxesLabel->{None, None},
    AxesOrigin->{0, 0},
    DisplayFunction->Identity,
    Frame->{{False, False}, {False, False}},
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLines->{None, None},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    ImageSize->120,
    Method->{},
    PlotRange->{{0., 8.}, {0, 7.}},
    PlotRangeClipping->True,
    PlotRangePadding->{{
       Scaled[0.02], 
       Scaled[0.02]}, {
       Scaled[0.02], 
       Scaled[0.05]}},
    Ticks->{Automatic, Automatic}], ",", 
   GraphicsBox[{{}, {{}, {}, {{{
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
          0.019444444444444445`], AbsoluteThickness[1.6], 
          LineBox[{{1., 0.}, {2., 1.}, {3., 3.}, {4., 2.}, {5., 6.}, {6., 
           7.}, {7., 5.}, {8., 4.}, {9., 12.}, {10., 13.}, {11., 15.}, {12., 
           14.}, {13., 10.}, {14., 11.}, {15., 9.}, {16., 8.}}]}}}}}, {}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->{True, True},
    AxesLabel->{None, None},
    AxesOrigin->{0, 0},
    DisplayFunction->Identity,
    Frame->{{False, False}, {False, False}},
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLines->{None, None},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    ImageSize->120,
    Method->{},
    PlotRange->{{0., 16.}, {0, 15.}},
    PlotRangeClipping->True,
    PlotRangePadding->{{
       Scaled[0.02], 
       Scaled[0.02]}, {
       Scaled[0.02], 
       Scaled[0.05]}},
    Ticks->{Automatic, Automatic}], ",", 
   GraphicsBox[{{}, {{}, {}, {{{
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
          0.019444444444444445`], AbsoluteThickness[1.6], 
          LineBox[CompressedData["
1:eJx1z7sKwkAUhOHFyjKFhYVFIkFEJMT73Zxn8BEEa1/dR1Dxn2IHXAgfLGfP
TKr78/bopZTKz/f1d15dyk/k9/3ILSKfG+DQHJmaK23PGKdY4wwn2Njc3OZq
u/d3ymmtxwL3uMQDrvCEazziBq+4xQ53eLGcs+X826tc7dE75WivequHequH
/jOwjTedCB3M
           "]]}}}}}, {}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->{True, True},
    AxesLabel->{None, None},
    AxesOrigin->{0, 0},
    DisplayFunction->Identity,
    Frame->{{False, False}, {False, False}},
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLines->{None, None},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    ImageSize->120,
    Method->{},
    PlotRange->{{0., 32.}, {0, 31.}},
    PlotRangeClipping->True,
    PlotRangePadding->{{
       Scaled[0.02], 
       Scaled[0.02]}, {
       Scaled[0.02], 
       Scaled[0.05]}},
    Ticks->{Automatic, Automatic}], ",", 
   GraphicsBox[{{}, {{}, {}, {{{
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
          0.016666666666666666`], AbsoluteThickness[1.6], 
          LineBox[CompressedData["
1:eJx1kclKA0EURRtXLl24cOFCQxCREBziHJPKYBwSTfATBNf+Qn2yn6CScwrq
QRqaw6mqrnff68PP74+vraZp0t/7z/XzM2zqJ9Xr26nmTqrP7cK9wP1Azx2E
e1rwGLbhCTyC3XCuE861w3r8zjqnIccZvIHn8BZewHvYg3fwEg7gFRzCa/gQ
6vRDnU33Wtd7/M463mtuc5jbHPaZIHPI+jMcsY5n/YX9McSzPocT1vGsv7I/
hXjW3+Ej63jWl+zPIJ71N/jEOp71Bfv2idtnyWVfuH2bw9wlp04d51Dq6uY0
xyzkGtd9ONfSB3Msc3KuOv+pzMX/pvufVzClX3NaT9w=
           "]]}}}}}, {}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->{True, True},
    AxesLabel->{None, None},
    AxesOrigin->{0, 0},
    DisplayFunction->Identity,
    Frame->{{False, False}, {False, False}},
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLines->{None, None},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    ImageSize->120,
    Method->{},
    PlotRange->{{0., 64.}, {0, 63.}},
    PlotRangeClipping->True,
    PlotRangePadding->{{
       Scaled[0.02], 
       Scaled[0.02]}, {
       Scaled[0.02], 
       Scaled[0.05]}},
    Ticks->{Automatic, Automatic}]}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[5]=",ExpressionUUID->"59294a32-3b6d-4e45-9a13-938a8f3b2426"]
}, Open  ]],

Cell[TextData[{
 "If this code is working correctly, the result should contain every number \
from ",
 Cell[BoxData[
 "0"], "InlineCode",ExpressionUUID->"fc32c9e1-a90b-4616-b2ff-90e43ff56cec"],
 " to ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"2", "^", "m"}], "-", "1"}]], "InlineCode",ExpressionUUID->
  "3f3750c7-a629-4858-812f-d386ce8088f0"],
 ":"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"423b3785-f0c0-414e-8be6-f2cb77c8485f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Sort", "[", 
  RowBox[{"With", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"m", "=", "4"}], "}"}], ",", 
    RowBox[{"Nest", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Join", "[", 
        RowBox[{"#", ",", 
         RowBox[{
          RowBox[{"Length", "[", "#", "]"}], "+", 
          RowBox[{"Reverse", "[", "#", "]"}]}]}], "]"}], "&"}], ",", 
      RowBox[{"{", "0", "}"}], ",", "m"}], "]"}]}], "]"}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[6]:=",ExpressionUUID->"30c39af9-91b3-48c5-aac6-bef22a2a2403"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0", ",", "1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "7", 
   ",", "8", ",", "9", ",", "10", ",", "11", ",", "12", ",", "13", ",", "14", 
   ",", "15"}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[6]=",ExpressionUUID->"3f424f35-fae2-4a82-900c-1a8143fb0f20"]
}, Open  ]],

Cell[TextData[{
 "Systematically check this up to ",
 Cell[BoxData[
  RowBox[{"m", "=", "10"}]], "InlineCode",ExpressionUUID->
  "1e62b8e1-b3fd-4dfc-ad11-d0896c64a214"],
 ":"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"11910ffb-d9dd-4eea-b7c3-b163e6f549f0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Sort", "[", 
     RowBox[{"Nest", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Join", "[", 
         RowBox[{"#", ",", 
          RowBox[{
           RowBox[{"Length", "[", "#", "]"}], "+", 
           RowBox[{"Reverse", "[", "#", "]"}]}]}], "]"}], "&"}], ",", 
       RowBox[{"{", "0", "}"}], ",", "m"}], "]"}], "]"}], "\[Equal]", 
    RowBox[{"Range", "[", 
     RowBox[{"0", ",", 
      RowBox[{
       RowBox[{"2", "^", "m"}], "-", "1"}]}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"m", ",", "10"}], "}"}]}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[7]:=",ExpressionUUID->"df9b2a30-d3f9-48e3-b468-47ca482a7574"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "True", ",", "True", ",", "True", ",", "True", ",", "True", ",", "True", 
   ",", "True", ",", "True", ",", "True", ",", "True"}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[7]=",ExpressionUUID->"0a398fc4-caf9-4a32-86ce-2162ac4e175a"]
}, Open  ]],

Cell[TextData[{
 "Sometimes it\[CloseCurlyQuote]s not sufficient just to see the final result \
of a piece of code; you need to see what\[CloseCurlyQuote]s going on inside \
as well. You can insert the function ",
 ButtonBox["Echo",
  BaseStyle->"Link"],
 " anywhere to print intermediate results or values from your code."
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"9505a3b7-28a5-48e8-a958-091a50d612b7"],

Cell[TextData[{
 ButtonBox["Echo",
  BaseStyle->"Link"],
 " prints values, but does not interfere with the result:"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:11",ExpressionUUID->"042fa617-36e0-4c46-9f2e-613019fd2dad"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Echo", "[", "n", "]"}], "^", "2"}], ",", 
   RowBox[{"{", 
    RowBox[{"n", ",", "3"}], "}"}]}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[8]:=",ExpressionUUID->"e260fd49-5a7f-4282-bdce-bc94016edb51"],

Cell[CellGroupData[{

Cell[BoxData["1"], "Echo",ExpressionUUID->"20a57b77-bbbe-48f6-ae82-3563e4cdf660"],

Cell[BoxData["2"], "Echo",ExpressionUUID->"0f143ab6-4264-4b1c-96e3-c28c277eab91"],

Cell[BoxData["3"], "Echo",ExpressionUUID->"6b3c3cbe-2ac4-43ad-952f-3a261c2c83ac"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "4", ",", "9"}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellTags->"LastCellOfAPage",
 CellLabel->"Out[8]=",ExpressionUUID->"bbefdc4b-a6b9-4fe5-a2f7-069a1ebcf56d"]
}, Open  ]],

Cell[TextData[{
 "If you\[CloseCurlyQuote]re running a long computation, you can monitor its \
progress using ",
 ButtonBox["Monitor",
  BaseStyle->"Link"],
 ". "
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->{
  "i:12", "p:293"},ExpressionUUID->"d3d9b7a4-890f-4c23-ba02-0e6062556474"],

Cell[TextData[{
 "Continuously show (with a frame) the value of ",
 Cell[BoxData[
 "n"], "InlineCode",ExpressionUUID->"f588141a-6bcd-4218-8030-f47c3b2d9e1e"],
 " reached so far:"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:13",ExpressionUUID->"0beb9f3c-c126-4d2e-809f-9042d78753e7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Monitor", "[", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"PrimeQ", "[", 
      RowBox[{
       RowBox[{"2", "^", 
        RowBox[{"2", "^", "n"}]}], "+", "1"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "15"}], "}"}]}], "]"}], ",", 
   RowBox[{"Framed", "[", "n", "]"}]}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[9]:=",ExpressionUUID->"565766ff-e52f-408a-b7d3-1971ad865389"],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJztndtzG1cZwEOZAV6ghZCL88Y/wfDU0pYX3po0faMXp01DSwhDmmkHZpph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    "], {{0, 54}, {362, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->{109.16796875000011`, Automatic},
  ImageSizeRaw->{362, 54},
  PlotRange->{{0, 362}, {0, 54}}]], "PrintTemporary",
 CellMargins->{{98, Inherited}, {
   Inherited, 
    Inherited}},ExpressionUUID->"1d03f704-e161-4870-9f2c-6d847b571184"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "True", ",", "True", ",", "True", ",", "True", ",", "False", ",", "False", 
   ",", "False", ",", "False", ",", "False", ",", "False", ",", "False", ",", 
   "False", ",", "False", ",", "False", ",", "False"}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[9]=",ExpressionUUID->"997572e6-7710-47db-9699-473ec9462c45"]
}, Open  ]],

Cell[TextData[{
 ButtonBox["Echo",
  BaseStyle->"Link"],
 " and ",
 ButtonBox["Monitor",
  BaseStyle->"Link"],
 " just display things. If you want to actually capture intermediate results, \
you can do it using ",
 ButtonBox["Sow",
  BaseStyle->"Link"],
 " and ",
 ButtonBox["Reap",
  BaseStyle->"Link"],
 ". "
}], "Text",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:14",ExpressionUUID->"2e7e45a4-2217-45ce-8b7a-37a877293d43"],

Cell[TextData[{
 ButtonBox["Reap",
  BaseStyle->"Link"],
 " gives the final result together with a list of everything that was sown by \
",
 ButtonBox["Sow",
  BaseStyle->"Link"],
 ":"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"0791537a-e057-464e-b71c-f96cf1597331"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Reap", "[", 
  RowBox[{"Total", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Sow", "[", "n", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "5"}], "}"}]}], "]"}], "]"}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[10]:=",ExpressionUUID->"11359746-4a75-4d16-bdae-f3c68f5bb477"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"15", ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"1", ",", "2", ",", "3", ",", "4", ",", "5"}], "}"}], "}"}]}], 
  "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[10]=",ExpressionUUID->"000c3c1d-a950-4f64-9466-fc6e0714cad0"]
}, Open  ]],

Cell[TextData[{
 "This sows successive values of ",
 Cell[BoxData[
  RowBox[{
   ButtonBox["Length",
    BaseStyle->"CodeLink"], "[", 
   ButtonBox["#",
    BaseStyle->"Link",
    ButtonData->"Slot"], "]"}]], "InlineCode",ExpressionUUID->
  "c58d2253-28e8-488d-8bad-55223c6392a9"],
 ", and reaps the results:"
}], "CodeCaption",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"32068377-7b68-4f33-982f-f5fb3d0bb509"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Last", "[", 
  RowBox[{"Reap", "[", 
   RowBox[{"Nest", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Join", "[", 
       RowBox[{"#", ",", 
        RowBox[{
         RowBox[{"Sow", "[", 
          RowBox[{"Length", "[", "#", "]"}], "]"}], "+", 
         RowBox[{"Reverse", "[", "#", "]"}]}]}], "]"}], "&"}], ",", 
     RowBox[{"{", "0", "}"}], ",", "10"}], "]"}], "]"}], "]"}]], "Input",
 Deletable->False,
 CellLabel->"In[11]:=",ExpressionUUID->"6d50571f-fadf-4b18-8df4-deee2ca28f5f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
   "1", ",", "2", ",", "4", ",", "8", ",", "16", ",", "32", ",", "64", ",", 
    "128", ",", "256", ",", "512"}], "}"}], "}"}]], "Output",
 Editable->False,
 CellEditDuplicate->False,
 Evaluatable->False,
 CellLabel->"Out[11]=",ExpressionUUID->"71d287d6-04e7-4531-8bd5-08bbdf211b63"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Vocabulary", "VocabularySection",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"5bab5e00-f131-4048-82aa-70c94292f39e"],

Cell[BoxData[GridBox[{
   {
    RowBox[{
     ButtonBox["With",
      BaseStyle->"CodeLink"], "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        StyleBox["x", "CodeVariableLrg"], "=", 
        StyleBox["value", "CodeVariableLrg"]}], "}"}], ",", 
      StyleBox["expr", "CodeVariableLrg"]}], "]"}], " ", Cell[TextData[{
     "compute ",
     Cell[BoxData[
      StyleBox["expr", "CodeVariable"]], "InlineCode",ExpressionUUID->
      "d1807631-b56a-47a9-b562-a7642a968333"],
     " with ",
     Cell[BoxData[
      StyleBox["x", "CodeVariable"]], "InlineCode",ExpressionUUID->
      "bd1f2f52-57b1-41b0-a271-18d998eeb378"],
     " replaced by ",
     Cell[BoxData[
      StyleBox["value", "CodeVariable"]], "InlineCode",ExpressionUUID->
      "4af1938b-9816-4f64-ad2a-26320e0abea7"],
     " "
    }], "VocabularyText",ExpressionUUID->
     "5b6b7617-a969-40dd-992d-cb4ab1832645"]},
   {
    RowBox[{
     ButtonBox["Echo",
      BaseStyle->"CodeLink"], "[", 
     StyleBox["expr", "CodeVariableLrg"], "]"}], " ", Cell[TextData[{
     "display and return the value of ",
     Cell[BoxData[
      StyleBox["expr", "CodeVariable"]], "InlineCode",ExpressionUUID->
      "7d2b0d97-88f4-4ffb-a125-3dc199c15a07"],
     " "
    }], "VocabularyText",ExpressionUUID->
     "d23fedee-545e-4c14-a5a1-f4a0634f0c5e"]},
   {
    RowBox[{
     ButtonBox["Monitor",
      BaseStyle->"CodeLink"], "[", 
     RowBox[{
      StyleBox["expr", "CodeVariableLrg"], ",", 
      StyleBox["obj", "CodeVariableLrg"]}], "]"}], " ", Cell[TextData[{
     "continually display ",
     Cell[BoxData[
      StyleBox["obj", "CodeVariable"]], "InlineCode",ExpressionUUID->
      "ce135c14-79b7-4181-a956-304395f0b551"],
     " during a computation "
    }], "VocabularyText",ExpressionUUID->
     "e61f6cea-3348-426a-9827-50a8269a653d"]},
   {
    RowBox[{
     ButtonBox["Sow",
      BaseStyle->"CodeLink"], "[", 
     StyleBox["expr", "CodeVariableLrg"], "]"}], " ", Cell[TextData[{
     "sow the value of ",
     Cell[BoxData[
      StyleBox["expr", "CodeVariable"]], "InlineCode",ExpressionUUID->
      "a515f6af-fa7e-47b2-bb4a-25c39dfcb738"],
     " for subsequent reaping "
    }], "VocabularyText",ExpressionUUID->
     "fdbae0d5-f758-4ea6-92f3-c8d98e1b8ad3"]},
   {
    RowBox[{
     ButtonBox["Reap",
      BaseStyle->"CodeLink"], "[", 
     StyleBox["expr", "CodeVariableLrg"], "]"}], " ", Cell[TextData[{
     "collect values sowed while ",
     Cell[BoxData[
      StyleBox["expr", "CodeVariable"]], "InlineCode",ExpressionUUID->
      "dce2b80e-ad83-4b03-abf3-a52b20b05300"],
     " is being computed "
    }], "VocabularyText",ExpressionUUID->
     "63bd4cb8-daef-43ce-8dc0-cd2ef780dc3a"]}
  }]], "VocabularyTable",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"ad10a41e-ee2c-4e52-9bdd-4ea969c58a21"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 DynamicModuleBox[{$CellContext`open$$ = False}, 
  TagBox[GridBox[{
     {
      StyleBox["\<\"Exercises\"\>",
       StripOnInput->False,
       FontSlant->"Italic"], 
      PaneBox[
       TagBox[
        ButtonBox[
         DynamicBox[ToBoxes[
           If[$CellContext`open$$, 
            Row[{
              Style["-", "ExercisePreviewButtonTextHighlight"], 
              Style[" Preview Exercises", "ExercisePreviewButtonText"]}], 
            Row[{
              Style["+", "ExercisePreviewButtonTextHighlight"], 
              Style[" Preview Exercises", "ExercisePreviewButtonText"]}]], 
           StandardForm],
          ImageSizeCache->{115., {1., 10.}}],
         Appearance->None,
         ButtonFunction:>(
          If[$CellContext`open$$, $CellContext`open$$ = 
            False, $CellContext`open$$ = True]; NotebookFind[
            EvaluationNotebook[], "ExerciseSummaryCell", Next, CellStyle, 
            WrapAround -> True, AutoScroll -> False]; FrontEndTokenExecute[
            EvaluationNotebook[], "ExpandSelection"]; FrontEndExecute[
            FrontEndToken[
             EvaluationNotebook[], "OpenCloseGroup"]]),
         Evaluator->Automatic,
         Method->"Preemptive"],
        MouseAppearanceTag["LinkHand"]],
       Alignment->Right,
       ImageSize->Full]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {Left, Right}, "Rows" -> {{Center}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"],
  DynamicModuleValues:>{}]], "ExerciseSection",
 Editable->False,
 ShowCellBracket->False,
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{3.669991951589675*^9},
 ShowStringCharacters->
  False,ExpressionUUID->"49fd136b-f4e2-499b-9da2-39a787d45349"],

Cell[CellGroupData[{

Cell[BoxData[
 TagBox[GridBox[{
    {
     TagBox[GridBox[{
        {
         PaneBox[
          StyleBox["\<\"3 Exercises Available\"\>", "ExerciseSummaryHeading",
           StripOnInput->False],
          ImageMargins->{{20, 0}, {0, 10}}]}
       },
       DefaultBaseStyle->"Column",
       GridBoxAlignment->{"Columns" -> {{Left}}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
       
       GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{0}}}],
      "Column"], 
     PaneBox[
      ButtonBox[
       StyleBox["\<\"Get Started \[RightGuillemet]\"\>", 
        "ExerciseSummaryHeading",
        StripOnInput->False],
       Appearance->None,
       ButtonFunction:>
        NotebookLocate[{"EIWL1-47-debugging-your-code-exercises.nb", ""}],
       Evaluator->Automatic,
       Method->"Preemptive"],
      FrameMargins->{{10, 0}, {10, 10}},
      ImageSize->Full]}
   },
   AutoDelete->False,
   GridBoxAlignment->{"Columns" -> {{Left}}},
   GridBoxItemSize->{"Columns" -> {
       Scaled[0.7], 
       Scaled[0.3]}, "Rows" -> {{Automatic}}}],
  "Grid"]], "ExerciseSummaryCell",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"542791b8-1bc4-45b2-8842-e174dac42999"],

Cell[CellGroupData[{

Cell[TextData[{
 "Correct the program ",
 Cell[BoxData[
  RowBox[{
   ButtonBox["Counts",
    BaseStyle->"CodeLink"], "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      ButtonBox["StringTake",
       BaseStyle->"CodeLink"], "[", 
      RowBox[{
       ButtonBox["#",
        BaseStyle->"Link",
        ButtonData->"Slot"], ",", "2"}], "]"}], "&"}], 
    ButtonBox["/@",
     BaseStyle->"Link",
     ButtonData->"Map"], 
    RowBox[{
     ButtonBox["WordList",
      BaseStyle->"CodeLink"], "[", "]"}]}], "]"}]], "InlineCode",
  ExpressionUUID->"c62c4e26-f128-47e2-bfe4-01d87cc75664"],
 " for counting possible first two letters in words.",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "47.1", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"49e77757-27b5-487d-b3f9-2bc6ba340975"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       RowBox[{"\[LeftAssociation]", 
        RowBox[{
         RowBox[{"\<\"aa\"\>", "\[Rule]", "2"}], ",", 
         RowBox[{"\<\"ab\"\>", "\[Rule]", "174"}], ",", 
         RowBox[{"\<\"ac\"\>", "\[Rule]", "223"}], ",", 
         RowBox[{"\<\"ad\"\>", "\[Rule]", "197"}], ",", 
         RowBox[{"\<\"ae\"\>", "\[Rule]", "28"}], ",", 
         RowBox[{"\<\"af\"\>", "\[Rule]", "73"}], ",", 
         RowBox[{"\<\"ag\"\>", "\[Rule]", "81"}], ",", 
         RowBox[{"\<\"ah\"\>", "\[Rule]", "6"}], ",", 
         RowBox[{"\<\"ai\"\>", "\[Rule]", "57"}], ",", 
         RowBox[{"\<\"aj\"\>", "\[Rule]", "1"}], ",", 
         RowBox[{"\<\"ak\"\>", "\[Rule]", "2"}], ",", 
         RowBox[{"\<\"al\"\>", "\[Rule]", "208"}], ",", 
         RowBox[{"\<\"am\"\>", "\[Rule]", "140"}], ",", 
         RowBox[{"\<\"an\"\>", "\[Rule]", "333"}], ",", 
         RowBox[{"\<\"ao\"\>", "\[Rule]", "3"}], ",", 
         RowBox[{"\<\"ap\"\>", "\[Rule]", "168"}], ",", 
         RowBox[{"\<\"aq\"\>", "\[Rule]", "15"}], ",", 
         RowBox[{"\<\"ar\"\>", "\[Rule]", "213"}], ",", 
         RowBox[{"\<\"as\"\>", "\[Rule]", "201"}], ",", 
         RowBox[{"\<\"at\"\>", "\[Rule]", "103"}], ",", 
         RowBox[{"\<\"au\"\>", "\[Rule]", "117"}], ",", 
         RowBox[{"\<\"av\"\>", "\[Rule]", "47"}], ",", 
         RowBox[{"\<\"aw\"\>", "\[Rule]", "31"}], ",", 
         RowBox[{"\<\"ax\"\>", "\[Rule]", "13"}], ",", 
         RowBox[{"\<\"ay\"\>", "\[Rule]", "2"}], ",", 
         RowBox[{"\<\"az\"\>", "\[Rule]", "4"}], ",", 
         RowBox[{"\<\"ba\"\>", "\[Rule]", "461"}], ",", 
         RowBox[{"\<\"be\"\>", "\[Rule]", "372"}], ",", 
         RowBox[{"\<\"bi\"\>", "\[Rule]", "214"}], ",", 
         RowBox[{"\<\"bl\"\>", "\[Rule]", "263"}], ",", 
         RowBox[{"\<\"bo\"\>", "\[Rule]", "318"}], ",", 
         RowBox[{"\<\"br\"\>", "\[Rule]", "314"}], ",", 
         RowBox[{"\<\"bu\"\>", "\[Rule]", "267"}], ",", 
         RowBox[{"\<\"by\"\>", "\[Rule]", "14"}], ",", 
         RowBox[{"\<\"ca\"\>", "\[Rule]", "629"}], ",", 
         RowBox[{"\<\"ce\"\>", "\[Rule]", "130"}], ",", 
         RowBox[{"\<\"ch\"\>", "\[Rule]", "453"}], ",", 
         RowBox[{"\<\"ci\"\>", "\[Rule]", "89"}], ",", 
         RowBox[{"\<\"cl\"\>", "\[Rule]", "273"}], ",", 
         RowBox[{"\<\"cn\"\>", "\[Rule]", "1"}], ",", 
         RowBox[{"\<\"co\"\>", "\[Rule]", "1615"}], ",", 
         RowBox[{"\<\"cr\"\>", "\[Rule]", "350"}], ",", 
         RowBox[{"\<\"cu\"\>", "\[Rule]", "187"}], ",", 
         RowBox[{"\<\"cy\"\>", "\[Rule]", "46"}], ",", 
         RowBox[{"\<\"cz\"\>", "\[Rule]", "3"}], ",", 
         RowBox[{"\<\"da\"\>", "\[Rule]", "169"}], ",", 
         RowBox[{"\<\"dB\"\>", "\[Rule]", "1"}], ",", 
         RowBox[{"\<\"de\"\>", "\[Rule]", "905"}], ",", 
         RowBox[{"\<\"dh\"\>", "\[Rule]", "2"}], ",", 
         RowBox[{"\<\"di\"\>", "\[Rule]", "841"}], ",", 
         RowBox[{"\<\"do\"\>", "\[Rule]", "253"}], ",", 
         RowBox[{"\<\"dr\"\>", "\[Rule]", "174"}], ",", 
         RowBox[{"\<\"du\"\>", "\[Rule]", "120"}], ",", 
         RowBox[{"\<\"dw\"\>", "\[Rule]", "9"}], ",", 
         RowBox[{"\<\"dy\"\>", "\[Rule]", "30"}], ",", 
         RowBox[{"\<\"ea\"\>", "\[Rule]", "73"}], ",", 
         RowBox[{"\<\"eb\"\>", "\[Rule]", "7"}], ",", 
         RowBox[{"\<\"ec\"\>", "\[Rule]", "45"}], ",", 
         RowBox[{"\<\"ed\"\>", "\[Rule]", "40"}], ",", 
         RowBox[{"\<\"ee\"\>", "\[Rule]", "4"}], ",", 
         RowBox[{"\<\"e'\"\>", "\[Rule]", "2"}], ",", 
         RowBox[{"\<\"ef\"\>", "\[Rule]", "46"}], ",", 
         RowBox[{"\<\"eg\"\>", "\[Rule]", "28"}], ",", 
         RowBox[{"\<\"eh\"\>", "\[Rule]", "1"}], ",", 
         RowBox[{"\<\"ei\"\>", "\[Rule]", "16"}], ",", 
         RowBox[{"\<\"ej\"\>", "\[Rule]", "5"}], ",", 
         RowBox[{"\<\"el\"\>", "\[Rule]", "137"}], ",", 
         RowBox[{"\<\"em\"\>", "\[Rule]", "144"}], ",", 
         RowBox[{"\<\"en\"\>", "\[Rule]", "319"}], ",", 
         RowBox[{"\<\"eo\"\>", "\[Rule]", "1"}], ",", 
         RowBox[{"\<\"ep\"\>", "\[Rule]", "53"}], ",", 
         RowBox[{"\<\"eq\"\>", "\[Rule]", "42"}], ",", 
         RowBox[{"\<\"er\"\>", "\[Rule]", "60"}], ",", 
         RowBox[{"\<\"es\"\>", "\[Rule]", "66"}], ",", 
         RowBox[{"\<\"et\"\>", "\[Rule]", "42"}], ",", 
         RowBox[{"\<\"eu\"\>", "\[Rule]", "25"}], ",", 
         RowBox[{"\<\"ev\"\>", "\[Rule]", "76"}], ",", 
         RowBox[{"\<\"ew\"\>", "\[Rule]", "2"}], ",", 
         RowBox[{"\<\"ex\"\>", "\[Rule]", "419"}], ",", 
         RowBox[{"\<\"ey\"\>", "\[Rule]", "21"}], ",", 
         RowBox[{"\<\"fa\"\>", "\[Rule]", "286"}], ",", 
         RowBox[{"\<\"fe\"\>", "\[Rule]", "176"}], ",", 
         RowBox[{"\<\"fi\"\>", "\[Rule]", "258"}], ",", 
         RowBox[{"\<\"fj\"\>", "\[Rule]", "1"}], ",", 
         RowBox[{"\<\"fl\"\>", "\[Rule]", "273"}], ",", 
         RowBox[{"\<\"fo\"\>", "\[Rule]", "344"}], ",", 
         RowBox[{"\<\"fr\"\>", "\[Rule]", "238"}], ",", 
         RowBox[{"\<\"fu\"\>", "\[Rule]", "140"}], ",", 
         RowBox[{"\<\"ga\"\>", "\[Rule]", "206"}], ",", 
         RowBox[{"\<\"ge\"\>", "\[Rule]", "158"}], ",", 
         RowBox[{"\<\"gh\"\>", "\[Rule]", "15"}], ",", 
         RowBox[{"\<\"gi\"\>", "\[Rule]", "66"}], ",", 
         RowBox[{"\<\"gl\"\>", "\[Rule]", "138"}], ",", 
         RowBox[{"\<\"gn\"\>", "\[Rule]", "13"}], ",", 
         RowBox[{"\<\"go\"\>", "\[Rule]", "128"}], ",", 
         RowBox[{"\<\"gr\"\>", "\[Rule]", "355"}], ",", 
         RowBox[{"\<\"gu\"\>", "\[Rule]", "123"}], ",", 
         RowBox[{"\<\"gy\"\>", "\[Rule]", "21"}], ",", 
         RowBox[{"\<\"ha\"\>", "\[Rule]", "373"}], ",", 
         RowBox[{"\<\"he\"\>", "\[Rule]", "333"}], ",", 
         RowBox[{"\<\"hi\"\>", "\[Rule]", "130"}], ",", 
         RowBox[{"\<\"h'\"\>", "\[Rule]", "1"}], ",", 
         RowBox[{"\<\"hm\"\>", "\[Rule]", "1"}], ",", 
         RowBox[{"\<\"ho\"\>", "\[Rule]", "349"}], ",", 
         RowBox[{"\<\"hu\"\>", "\[Rule]", "141"}], ",", 
         RowBox[{"\<\"hy\"\>", "\[Rule]", "118"}], ",", 
         RowBox[{"\<\"ia\"\>", "\[Rule]", "4"}], ",", 
         RowBox[{"\<\"ib\"\>", "\[Rule]", "4"}], ",", 
         RowBox[{"\<\"ic\"\>", "\[Rule]", "27"}], ",", 
         RowBox[{"\<\"id\"\>", "\[Rule]", "56"}], ",", 
         RowBox[{"\<\"if\"\>", "\[Rule]", "2"}], ",", 
         RowBox[{"\<\"ig\"\>", "\[Rule]", "18"}], ",", 
         RowBox[{"\<\"il\"\>", "\[Rule]", "55"}], ",", 
         RowBox[{"\<\"im\"\>", "\[Rule]", "329"}], ",", 
         RowBox[{"\<\"in\"\>", "\[Rule]", "1261"}], ",", 
         RowBox[{"\<\"io\"\>", "\[Rule]", "11"}], ",", 
         RowBox[{"\<\"ip\"\>", "\[Rule]", "1"}], ",", 
         RowBox[{"\<\"ir\"\>", "\[Rule]", "90"}], ",", 
         RowBox[{"\<\"is\"\>", "\[Rule]", "35"}], ",", 
         RowBox[{"\<\"it\"\>", "\[Rule]", "17"}], ",", 
         RowBox[{"\<\"iv\"\>", "\[Rule]", "3"}], ",", 
         RowBox[{"\<\"ja\"\>", "\[Rule]", "75"}], ",", 
         RowBox[{"\<\"je\"\>", "\[Rule]", "47"}], ",", 
         RowBox[{"\<\"ji\"\>", "\[Rule]", "32"}], ",", 
         RowBox[{"\<\"jo\"\>", "\[Rule]", "78"}], ",", 
         RowBox[{"\<\"ju\"\>", "\[Rule]", "87"}], ",", 
         RowBox[{"\<\"ka\"\>", "\[Rule]", "20"}], ",", 
         RowBox[{"\<\"kc\"\>", "\[Rule]", "1"}], ",", 
         RowBox[{"\<\"ke\"\>", "\[Rule]", "40"}], ",", 
         RowBox[{"\<\"kh\"\>", "\[Rule]", "3"}], ",", 
         RowBox[{"\<\"kH\"\>", "\[Rule]", "1"}], ",", 
         RowBox[{"\<\"ki\"\>", "\[Rule]", "89"}], ",", 
         RowBox[{"\<\"kl\"\>", "\[Rule]", "4"}], ",", 
         RowBox[{"\<\"kn\"\>", "\[Rule]", "54"}], ",", 
         RowBox[{"\<\"ko\"\>", "\[Rule]", "10"}], ",", 
         RowBox[{"\<\"kp\"\>", "\[Rule]", "1"}], ",", 
         RowBox[{"\<\"kr\"\>", "\[Rule]", "5"}], ",", 
         RowBox[{"\<\"ku\"\>", "\[Rule]", "3"}], ",", 
         RowBox[{"\<\"kv\"\>", "\[Rule]", "1"}], ",", 
         RowBox[{"\<\"kW\"\>", "\[Rule]", "1"}], ",", 
         RowBox[{"\<\"la\"\>", "\[Rule]", "310"}], ",", 
         RowBox[{"\<\"le\"\>", "\[Rule]", "229"}], ",", 
         RowBox[{"\<\"li\"\>", "\[Rule]", "303"}], ",", 
         RowBox[{"\<\"ll\"\>", "\[Rule]", "2"}], ",", 
         RowBox[{"\<\"lo\"\>", "\[Rule]", "232"}], ",", 
         RowBox[{"\<\"lu\"\>", "\[Rule]", "111"}], ",", 
         RowBox[{"\<\"ly\"\>", "\[Rule]", "20"}], ",", 
         RowBox[{"\<\"ma\"\>", "\[Rule]", "606"}], ",", 
         RowBox[{"\<\"me\"\>", "\[Rule]", "373"}], ",", 
         RowBox[{"\<\"mi\"\>", "\[Rule]", "421"}], ",", 
         RowBox[{"\<\"mn\"\>", "\[Rule]", "2"}], ",", 
         RowBox[{"\<\"mo\"\>", "\[Rule]", "402"}], ",", 
         RowBox[{"\<\"ms\"\>", "\[Rule]", "1"}], ",", 
         RowBox[{"\<\"mu\"\>", "\[Rule]", "211"}], ",", 
         RowBox[{"\<\"my\"\>", "\[Rule]", "33"}], ",", 
         RowBox[{"\<\"na\"\>", "\[Rule]", "132"}], ",", 
         RowBox[{"\<\"ne\"\>", "\[Rule]", "216"}], ",", 
         RowBox[{"\<\"ni\"\>", "\[Rule]", "94"}], ",", 
         RowBox[{"\<\"no\"\>", "\[Rule]", "312"}], ",", 
         RowBox[{"\<\"nt\"\>", "\[Rule]", "1"}], ",", 
         RowBox[{"\<\"nu\"\>", "\[Rule]", "90"}], ",", 
         RowBox[{"\<\"ny\"\>", "\[Rule]", "8"}], ",", 
         RowBox[{"\<\"oa\"\>", "\[Rule]", "16"}], ",", 
         RowBox[{"\<\"ob\"\>", "\[Rule]", "131"}], ",", 
         RowBox[{"\<\"oc\"\>", "\[Rule]", "46"}], ",", 
         RowBox[{"\<\"o'\"\>", "\[Rule]", "2"}], ",", 
         RowBox[{"\<\"od\"\>", "\[Rule]", "20"}], ",", 
         RowBox[{"\<\"oe\"\>", "\[Rule]", "3"}], ",", 
         RowBox[{"\<\"of\"\>", "\[Rule]", "48"}], ",", 
         RowBox[{"\<\"og\"\>", "\[Rule]", "4"}], ",", 
         RowBox[{"\<\"oh\"\>", "\[Rule]", "5"}], ",", 
         RowBox[{"\<\"oi\"\>", "\[Rule]", "12"}], ",", 
         RowBox[{"\<\"ok\"\>", "\[Rule]", "3"}], ",", 
         RowBox[{"\<\"ol\"\>", "\[Rule]", "20"}], ",", 
         RowBox[{"\<\"om\"\>", "\[Rule]", "20"}], ",", 
         RowBox[{"\<\"on\"\>", "\[Rule]", "35"}], ",", 
         RowBox[{"\<\"oo\"\>", "\[Rule]", "7"}], ",", 
         RowBox[{"\<\"op\"\>", "\[Rule]", "86"}], ",", 
         RowBox[{"\<\"or\"\>", "\[Rule]", "118"}], ",", 
         RowBox[{"\<\"os\"\>", "\[Rule]", "29"}], ",", 
         RowBox[{"\<\"ot\"\>", "\[Rule]", "7"}], ",", 
         RowBox[{"\<\"ou\"\>", "\[Rule]", "127"}], ",", 
         RowBox[{"\<\"ov\"\>", "\[Rule]", "224"}], ",", 
         RowBox[{"\<\"ow\"\>", "\[Rule]", "11"}], ",", 
         RowBox[{"\<\"ox\"\>", "\[Rule]", "19"}], ",", 
         RowBox[{"\<\"oy\"\>", "\[Rule]", "1"}], ",", 
         RowBox[{"\<\"oz\"\>", "\[Rule]", "1"}], ",", 
         RowBox[{"\<\"pa\"\>", "\[Rule]", "570"}], ",", 
         RowBox[{"\<\"pe\"\>", "\[Rule]", "503"}], ",", 
         RowBox[{"\<\"pf\"\>", "\[Rule]", "1"}], ",", 
         RowBox[{"\<\"pH\"\>", "\[Rule]", "1"}], ",", 
         RowBox[{"\<\"ph\"\>", "\[Rule]", "163"}], ",", 
         RowBox[{"\<\"pi\"\>", "\[Rule]", "223"}], ",", 
         RowBox[{"\<\"pl\"\>", "\[Rule]", "232"}], ",", 
         RowBox[{"\<\"pn\"\>", "\[Rule]", "4"}], ",", 
         RowBox[{"\<\"po\"\>", "\[Rule]", "419"}], ",", 
         RowBox[{"\<\"pr\"\>", "\[Rule]", "839"}], ",", 
         RowBox[{"\<\"ps\"\>", "\[Rule]", "53"}], ",", 
         RowBox[{"\<\"pt\"\>", "\[Rule]", "3"}], ",", 
         RowBox[{"\<\"pu\"\>", "\[Rule]", "234"}], ",", 
         RowBox[{"\<\"py\"\>", "\[Rule]", "22"}], ",", 
         RowBox[{"\<\"qu\"\>", "\[Rule]", "197"}], ",", 
         RowBox[{"\<\"ra\"\>", "\[Rule]", "319"}], ",", 
         RowBox[{"\<\"re\"\>", "\[Rule]", "1242"}], ",", 
         RowBox[{"\<\"rh\"\>", "\[Rule]", "39"}], ",", 
         RowBox[{"\<\"ri\"\>", "\[Rule]", "151"}], ",", 
         RowBox[{"\<\"ro\"\>", "\[Rule]", "212"}], ",", 
         RowBox[{"\<\"ru\"\>", "\[Rule]", "128"}], ",", 
         RowBox[{"\<\"ry\"\>", "\[Rule]", "1"}], ",", 
         RowBox[{"\<\"sa\"\>", "\[Rule]", "330"}], ",", 
         RowBox[{"\<\"sc\"\>", "\[Rule]", "347"}], ",", 
         RowBox[{"\<\"se\"\>", "\[Rule]", "569"}], ",", 
         RowBox[{"\<\"sh\"\>", "\[Rule]", "386"}], ",", 
         RowBox[{"\<\"si\"\>", "\[Rule]", "250"}], ",", 
         RowBox[{"\<\"sk\"\>", "\[Rule]", "98"}], ",", 
         RowBox[{"\<\"sl\"\>", "\[Rule]", "205"}], ",", 
         RowBox[{"\<\"sm\"\>", "\[Rule]", "81"}], ",", 
         RowBox[{"\<\"sn\"\>", "\[Rule]", "120"}], ",", 
         RowBox[{"\<\"so\"\>", "\[Rule]", "311"}], ",", 
         RowBox[{"\<\"sp\"\>", "\[Rule]", "418"}], ",", 
         RowBox[{"\<\"sq\"\>", "\[Rule]", "62"}], ",", 
         RowBox[{"\<\"st\"\>", "\[Rule]", "709"}], ",", 
         RowBox[{"\<\"su\"\>", "\[Rule]", "530"}], ",", 
         RowBox[{"\<\"sv\"\>", "\[Rule]", "1"}], ",", 
         RowBox[{"\<\"sw\"\>", "\[Rule]", "121"}], ",", 
         RowBox[{"\<\"sy\"\>", "\[Rule]", "104"}], ",", 
         RowBox[{"\<\"ta\"\>", "\[Rule]", "280"}], ",", 
         RowBox[{"\<\"te\"\>", "\[Rule]", "326"}], ",", 
         RowBox[{"\<\"th\"\>", "\[Rule]", "290"}], ",", 
         RowBox[{"\<\"ti\"\>", "\[Rule]", "173"}], ",", 
         RowBox[{"\<\"to\"\>", "\[Rule]", "263"}], ",", 
         RowBox[{"\<\"tr\"\>", "\[Rule]", "485"}], ",", 
         RowBox[{"\<\"ts\"\>", "\[Rule]", "3"}], ",", 
         RowBox[{"\<\"tu\"\>", "\[Rule]", "122"}], ",", 
         RowBox[{"\<\"tw\"\>", "\[Rule]", "53"}], ",", 
         RowBox[{"\<\"ty\"\>", "\[Rule]", "43"}], ",", 
         RowBox[{"\<\"ub\"\>", "\[Rule]", "2"}], ",", 
         RowBox[{"\<\"ud\"\>", "\[Rule]", "1"}], ",", 
         RowBox[{"\<\"ug\"\>", "\[Rule]", "3"}], ",", 
         RowBox[{"\<\"uk\"\>", "\[Rule]", "2"}], ",", 
         RowBox[{"\<\"ul\"\>", "\[Rule]", "24"}], ",", 
         RowBox[{"\<\"um\"\>", "\[Rule]", "14"}], ",", 
         RowBox[{"\<\"un\"\>", "\[Rule]", "1353"}], ",", 
         RowBox[{"\<\"up\"\>", "\[Rule]", "75"}], ",", 
         RowBox[{"\<\"ur\"\>", "\[Rule]", "36"}], ",", 
         RowBox[{"\<\"us\"\>", "\[Rule]", "25"}], ",", 
         RowBox[{"\<\"ut\"\>", "\[Rule]", "18"}], ",", 
         RowBox[{"\<\"uv\"\>", "\[Rule]", "2"}], ",", 
         RowBox[{"\<\"ux\"\>", "\[Rule]", "1"}], ",", 
         RowBox[{"\<\"va\"\>", "\[Rule]", "149"}], ",", 
         RowBox[{"\<\"ve\"\>", "\[Rule]", "173"}], ",", 
         RowBox[{"\<\"vi\"\>", "\[Rule]", "219"}], ",", 
         RowBox[{"\<\"vo\"\>", "\[Rule]", "87"}], ",", 
         RowBox[{"\<\"vu\"\>", "\[Rule]", "18"}], ",", 
         RowBox[{"\<\"wa\"\>", "\[Rule]", "262"}], ",", 
         RowBox[{"\<\"we\"\>", "\[Rule]", "132"}], ",", 
         RowBox[{"\<\"wh\"\>", "\[Rule]", "173"}], ",", 
         RowBox[{"\<\"wi\"\>", "\[Rule]", "196"}], ",", 
         RowBox[{"\<\"wo\"\>", "\[Rule]", "174"}], ",", 
         RowBox[{"\<\"wr\"\>", "\[Rule]", "69"}], ",", 
         RowBox[{"\<\"wu\"\>", "\[Rule]", "1"}], ",", 
         RowBox[{"\<\"xe\"\>", "\[Rule]", "6"}], ",", 
         RowBox[{"\<\"xi\"\>", "\[Rule]", "1"}], ",", 
         RowBox[{"\<\"xy\"\>", "\[Rule]", "4"}], ",", 
         RowBox[{"\<\"ya\"\>", "\[Rule]", "28"}], ",", 
         RowBox[{"\<\"ye\"\>", "\[Rule]", "36"}], ",", 
         RowBox[{"\<\"yi\"\>", "\[Rule]", "8"}], ",", 
         RowBox[{"\<\"yo\"\>", "\[Rule]", "28"}], ",", 
         RowBox[{"\<\"yt\"\>", "\[Rule]", "2"}], ",", 
         RowBox[{"\<\"yu\"\>", "\[Rule]", "7"}], ",", 
         RowBox[{"\<\"za\"\>", "\[Rule]", "3"}], ",", 
         RowBox[{"\<\"ze\"\>", "\[Rule]", "20"}], ",", 
         RowBox[{"\<\"zi\"\>", "\[Rule]", "15"}], ",", 
         RowBox[{"\<\"zl\"\>", "\[Rule]", "1"}], ",", 
         RowBox[{"\<\"zo\"\>", "\[Rule]", "13"}], ",", 
         RowBox[{"\<\"zu\"\>", "\[Rule]", "1"}], ",", 
         RowBox[{"\<\"zw\"\>", "\[Rule]", "1"}], ",", 
         RowBox[{"\<\"zy\"\>", "\[Rule]", "4"}]}], "\[RightAssociation]"}]], 
       "ExerciseOutput",ExpressionUUID->
       "92689552-3fd6-4224-a332-689ed2878715"],
      Apply[TextCell, 
       Cell[
        BoxData[
         RowBox[{"\[LeftAssociation]", 
           RowBox[{
             RowBox[{"\"aa\"", "\[Rule]", "2"}], ",", 
             RowBox[{"\"ab\"", "\[Rule]", "174"}], ",", 
             RowBox[{"\"ac\"", "\[Rule]", "223"}], ",", 
             RowBox[{"\"ad\"", "\[Rule]", "197"}], ",", 
             RowBox[{"\"ae\"", "\[Rule]", "28"}], ",", 
             RowBox[{"\"af\"", "\[Rule]", "73"}], ",", 
             RowBox[{"\"ag\"", "\[Rule]", "81"}], ",", 
             RowBox[{"\"ah\"", "\[Rule]", "6"}], ",", 
             RowBox[{"\"ai\"", "\[Rule]", "57"}], ",", 
             RowBox[{"\"aj\"", "\[Rule]", "1"}], ",", 
             RowBox[{"\"ak\"", "\[Rule]", "2"}], ",", 
             RowBox[{"\"al\"", "\[Rule]", "208"}], ",", 
             RowBox[{"\"am\"", "\[Rule]", "140"}], ",", 
             RowBox[{"\"an\"", "\[Rule]", "333"}], ",", 
             RowBox[{"\"ao\"", "\[Rule]", "3"}], ",", 
             RowBox[{"\"ap\"", "\[Rule]", "168"}], ",", 
             RowBox[{"\"aq\"", "\[Rule]", "15"}], ",", 
             RowBox[{"\"ar\"", "\[Rule]", "213"}], ",", 
             RowBox[{"\"as\"", "\[Rule]", "201"}], ",", 
             RowBox[{"\"at\"", "\[Rule]", "103"}], ",", 
             RowBox[{"\"au\"", "\[Rule]", "117"}], ",", 
             RowBox[{"\"av\"", "\[Rule]", "47"}], ",", 
             RowBox[{"\"aw\"", "\[Rule]", "31"}], ",", 
             RowBox[{"\"ax\"", "\[Rule]", "13"}], ",", 
             RowBox[{"\"ay\"", "\[Rule]", "2"}], ",", 
             RowBox[{"\"az\"", "\[Rule]", "4"}], ",", 
             RowBox[{"\"ba\"", "\[Rule]", "461"}], ",", 
             RowBox[{"\"be\"", "\[Rule]", "372"}], ",", 
             RowBox[{"\"bi\"", "\[Rule]", "214"}], ",", 
             RowBox[{"\"bl\"", "\[Rule]", "263"}], ",", 
             RowBox[{"\"bo\"", "\[Rule]", "318"}], ",", 
             RowBox[{"\"br\"", "\[Rule]", "314"}], ",", 
             RowBox[{"\"bu\"", "\[Rule]", "267"}], ",", 
             RowBox[{"\"by\"", "\[Rule]", "14"}], ",", 
             RowBox[{"\"ca\"", "\[Rule]", "629"}], ",", 
             RowBox[{"\"ce\"", "\[Rule]", "130"}], ",", 
             RowBox[{"\"ch\"", "\[Rule]", "453"}], ",", 
             RowBox[{"\"ci\"", "\[Rule]", "89"}], ",", 
             RowBox[{"\"cl\"", "\[Rule]", "273"}], ",", 
             RowBox[{"\"cn\"", "\[Rule]", "1"}], ",", 
             RowBox[{"\"co\"", "\[Rule]", "1615"}], ",", 
             RowBox[{"\"cr\"", "\[Rule]", "350"}], ",", 
             RowBox[{"\"cu\"", "\[Rule]", "187"}], ",", 
             RowBox[{"\"cy\"", "\[Rule]", "46"}], ",", 
             RowBox[{"\"cz\"", "\[Rule]", "3"}], ",", 
             RowBox[{"\"da\"", "\[Rule]", "169"}], ",", 
             RowBox[{"\"dB\"", "\[Rule]", "1"}], ",", 
             RowBox[{"\"de\"", "\[Rule]", "905"}], ",", 
             RowBox[{"\"dh\"", "\[Rule]", "2"}], ",", 
             RowBox[{"\"di\"", "\[Rule]", "841"}], ",", 
             RowBox[{"\"do\"", "\[Rule]", "253"}], ",", 
             RowBox[{"\"dr\"", "\[Rule]", "174"}], ",", 
             RowBox[{"\"du\"", "\[Rule]", "120"}], ",", 
             RowBox[{"\"dw\"", "\[Rule]", "9"}], ",", 
             RowBox[{"\"dy\"", "\[Rule]", "30"}], ",", 
             RowBox[{"\"ea\"", "\[Rule]", "73"}], ",", 
             RowBox[{"\"eb\"", "\[Rule]", "7"}], ",", 
             RowBox[{"\"ec\"", "\[Rule]", "45"}], ",", 
             RowBox[{"\"ed\"", "\[Rule]", "40"}], ",", 
             RowBox[{"\"ee\"", "\[Rule]", "4"}], ",", 
             RowBox[{"\"e'\"", "\[Rule]", "2"}], ",", 
             RowBox[{"\"ef\"", "\[Rule]", "46"}], ",", 
             RowBox[{"\"eg\"", "\[Rule]", "28"}], ",", 
             RowBox[{"\"eh\"", "\[Rule]", "1"}], ",", 
             RowBox[{"\"ei\"", "\[Rule]", "16"}], ",", 
             RowBox[{"\"ej\"", "\[Rule]", "5"}], ",", 
             RowBox[{"\"el\"", "\[Rule]", "137"}], ",", 
             RowBox[{"\"em\"", "\[Rule]", "144"}], ",", 
             RowBox[{"\"en\"", "\[Rule]", "319"}], ",", 
             RowBox[{"\"eo\"", "\[Rule]", "1"}], ",", 
             RowBox[{"\"ep\"", "\[Rule]", "53"}], ",", 
             RowBox[{"\"eq\"", "\[Rule]", "42"}], ",", 
             RowBox[{"\"er\"", "\[Rule]", "60"}], ",", 
             RowBox[{"\"es\"", "\[Rule]", "66"}], ",", 
             RowBox[{"\"et\"", "\[Rule]", "42"}], ",", 
             RowBox[{"\"eu\"", "\[Rule]", "25"}], ",", 
             RowBox[{"\"ev\"", "\[Rule]", "76"}], ",", 
             RowBox[{"\"ew\"", "\[Rule]", "2"}], ",", 
             RowBox[{"\"ex\"", "\[Rule]", "419"}], ",", 
             RowBox[{"\"ey\"", "\[Rule]", "21"}], ",", 
             RowBox[{"\"fa\"", "\[Rule]", "286"}], ",", 
             RowBox[{"\"fe\"", "\[Rule]", "176"}], ",", 
             RowBox[{"\"fi\"", "\[Rule]", "258"}], ",", 
             RowBox[{"\"fj\"", "\[Rule]", "1"}], ",", 
             RowBox[{"\"fl\"", "\[Rule]", "273"}], ",", 
             RowBox[{"\"fo\"", "\[Rule]", "344"}], ",", 
             RowBox[{"\"fr\"", "\[Rule]", "238"}], ",", 
             RowBox[{"\"fu\"", "\[Rule]", "140"}], ",", 
             RowBox[{"\"ga\"", "\[Rule]", "206"}], ",", 
             RowBox[{"\"ge\"", "\[Rule]", "158"}], ",", 
             RowBox[{"\"gh\"", "\[Rule]", "15"}], ",", 
             RowBox[{"\"gi\"", "\[Rule]", "66"}], ",", 
             RowBox[{"\"gl\"", "\[Rule]", "138"}], ",", 
             RowBox[{"\"gn\"", "\[Rule]", "13"}], ",", 
             RowBox[{"\"go\"", "\[Rule]", "128"}], ",", 
             RowBox[{"\"gr\"", "\[Rule]", "355"}], ",", 
             RowBox[{"\"gu\"", "\[Rule]", "123"}], ",", 
             RowBox[{"\"gy\"", "\[Rule]", "21"}], ",", 
             RowBox[{"\"ha\"", "\[Rule]", "373"}], ",", 
             RowBox[{"\"he\"", "\[Rule]", "333"}], ",", 
             RowBox[{"\"hi\"", "\[Rule]", "130"}], ",", 
             RowBox[{"\"h'\"", "\[Rule]", "1"}], ",", 
             RowBox[{"\"hm\"", "\[Rule]", "1"}], ",", 
             RowBox[{"\"ho\"", "\[Rule]", "349"}], ",", 
             RowBox[{"\"hu\"", "\[Rule]", "141"}], ",", 
             RowBox[{"\"hy\"", "\[Rule]", "118"}], ",", 
             RowBox[{"\"ia\"", "\[Rule]", "4"}], ",", 
             RowBox[{"\"ib\"", "\[Rule]", "4"}], ",", 
             RowBox[{"\"ic\"", "\[Rule]", "27"}], ",", 
             RowBox[{"\"id\"", "\[Rule]", "56"}], ",", 
             RowBox[{"\"if\"", "\[Rule]", "2"}], ",", 
             RowBox[{"\"ig\"", "\[Rule]", "18"}], ",", 
             RowBox[{"\"il\"", "\[Rule]", "55"}], ",", 
             RowBox[{"\"im\"", "\[Rule]", "329"}], ",", 
             RowBox[{"\"in\"", "\[Rule]", "1261"}], ",", 
             RowBox[{"\"io\"", "\[Rule]", "11"}], ",", 
             RowBox[{"\"ip\"", "\[Rule]", "1"}], ",", 
             RowBox[{"\"ir\"", "\[Rule]", "90"}], ",", 
             RowBox[{"\"is\"", "\[Rule]", "35"}], ",", 
             RowBox[{"\"it\"", "\[Rule]", "17"}], ",", 
             RowBox[{"\"iv\"", "\[Rule]", "3"}], ",", 
             RowBox[{"\"ja\"", "\[Rule]", "75"}], ",", 
             RowBox[{"\"je\"", "\[Rule]", "47"}], ",", 
             RowBox[{"\"ji\"", "\[Rule]", "32"}], ",", 
             RowBox[{"\"jo\"", "\[Rule]", "78"}], ",", 
             RowBox[{"\"ju\"", "\[Rule]", "87"}], ",", 
             RowBox[{"\"ka\"", "\[Rule]", "20"}], ",", 
             RowBox[{"\"kc\"", "\[Rule]", "1"}], ",", 
             RowBox[{"\"ke\"", "\[Rule]", "40"}], ",", 
             RowBox[{"\"kh\"", "\[Rule]", "3"}], ",", 
             RowBox[{"\"kH\"", "\[Rule]", "1"}], ",", 
             RowBox[{"\"ki\"", "\[Rule]", "89"}], ",", 
             RowBox[{"\"kl\"", "\[Rule]", "4"}], ",", 
             RowBox[{"\"kn\"", "\[Rule]", "54"}], ",", 
             RowBox[{"\"ko\"", "\[Rule]", "10"}], ",", 
             RowBox[{"\"kp\"", "\[Rule]", "1"}], ",", 
             RowBox[{"\"kr\"", "\[Rule]", "5"}], ",", 
             RowBox[{"\"ku\"", "\[Rule]", "3"}], ",", 
             RowBox[{"\"kv\"", "\[Rule]", "1"}], ",", 
             RowBox[{"\"kW\"", "\[Rule]", "1"}], ",", 
             RowBox[{"\"la\"", "\[Rule]", "310"}], ",", 
             RowBox[{"\"le\"", "\[Rule]", "229"}], ",", 
             RowBox[{"\"li\"", "\[Rule]", "303"}], ",", 
             RowBox[{"\"ll\"", "\[Rule]", "2"}], ",", 
             RowBox[{"\"lo\"", "\[Rule]", "232"}], ",", 
             RowBox[{"\"lu\"", "\[Rule]", "111"}], ",", 
             RowBox[{"\"ly\"", "\[Rule]", "20"}], ",", 
             RowBox[{"\"ma\"", "\[Rule]", "606"}], ",", 
             RowBox[{"\"me\"", "\[Rule]", "373"}], ",", 
             RowBox[{"\"mi\"", "\[Rule]", "421"}], ",", 
             RowBox[{"\"mn\"", "\[Rule]", "2"}], ",", 
             RowBox[{"\"mo\"", "\[Rule]", "402"}], ",", 
             RowBox[{"\"ms\"", "\[Rule]", "1"}], ",", 
             RowBox[{"\"mu\"", "\[Rule]", "211"}], ",", 
             RowBox[{"\"my\"", "\[Rule]", "33"}], ",", 
             RowBox[{"\"na\"", "\[Rule]", "132"}], ",", 
             RowBox[{"\"ne\"", "\[Rule]", "216"}], ",", 
             RowBox[{"\"ni\"", "\[Rule]", "94"}], ",", 
             RowBox[{"\"no\"", "\[Rule]", "312"}], ",", 
             RowBox[{"\"nt\"", "\[Rule]", "1"}], ",", 
             RowBox[{"\"nu\"", "\[Rule]", "90"}], ",", 
             RowBox[{"\"ny\"", "\[Rule]", "8"}], ",", 
             RowBox[{"\"oa\"", "\[Rule]", "16"}], ",", 
             RowBox[{"\"ob\"", "\[Rule]", "131"}], ",", 
             RowBox[{"\"oc\"", "\[Rule]", "46"}], ",", 
             RowBox[{"\"o'\"", "\[Rule]", "2"}], ",", 
             RowBox[{"\"od\"", "\[Rule]", "20"}], ",", 
             RowBox[{"\"oe\"", "\[Rule]", "3"}], ",", 
             RowBox[{"\"of\"", "\[Rule]", "48"}], ",", 
             RowBox[{"\"og\"", "\[Rule]", "4"}], ",", 
             RowBox[{"\"oh\"", "\[Rule]", "5"}], ",", 
             RowBox[{"\"oi\"", "\[Rule]", "12"}], ",", 
             RowBox[{"\"ok\"", "\[Rule]", "3"}], ",", 
             RowBox[{"\"ol\"", "\[Rule]", "20"}], ",", 
             RowBox[{"\"om\"", "\[Rule]", "20"}], ",", 
             RowBox[{"\"on\"", "\[Rule]", "35"}], ",", 
             RowBox[{"\"oo\"", "\[Rule]", "7"}], ",", 
             RowBox[{"\"op\"", "\[Rule]", "86"}], ",", 
             RowBox[{"\"or\"", "\[Rule]", "118"}], ",", 
             RowBox[{"\"os\"", "\[Rule]", "29"}], ",", 
             RowBox[{"\"ot\"", "\[Rule]", "7"}], ",", 
             RowBox[{"\"ou\"", "\[Rule]", "127"}], ",", 
             RowBox[{"\"ov\"", "\[Rule]", "224"}], ",", 
             RowBox[{"\"ow\"", "\[Rule]", "11"}], ",", 
             RowBox[{"\"ox\"", "\[Rule]", "19"}], ",", 
             RowBox[{"\"oy\"", "\[Rule]", "1"}], ",", 
             RowBox[{"\"oz\"", "\[Rule]", "1"}], ",", 
             RowBox[{"\"pa\"", "\[Rule]", "570"}], ",", 
             RowBox[{"\"pe\"", "\[Rule]", "503"}], ",", 
             RowBox[{"\"pf\"", "\[Rule]", "1"}], ",", 
             RowBox[{"\"pH\"", "\[Rule]", "1"}], ",", 
             RowBox[{"\"ph\"", "\[Rule]", "163"}], ",", 
             RowBox[{"\"pi\"", "\[Rule]", "223"}], ",", 
             RowBox[{"\"pl\"", "\[Rule]", "232"}], ",", 
             RowBox[{"\"pn\"", "\[Rule]", "4"}], ",", 
             RowBox[{"\"po\"", "\[Rule]", "419"}], ",", 
             RowBox[{"\"pr\"", "\[Rule]", "839"}], ",", 
             RowBox[{"\"ps\"", "\[Rule]", "53"}], ",", 
             RowBox[{"\"pt\"", "\[Rule]", "3"}], ",", 
             RowBox[{"\"pu\"", "\[Rule]", "234"}], ",", 
             RowBox[{"\"py\"", "\[Rule]", "22"}], ",", 
             RowBox[{"\"qu\"", "\[Rule]", "197"}], ",", 
             RowBox[{"\"ra\"", "\[Rule]", "319"}], ",", 
             RowBox[{"\"re\"", "\[Rule]", "1242"}], ",", 
             RowBox[{"\"rh\"", "\[Rule]", "39"}], ",", 
             RowBox[{"\"ri\"", "\[Rule]", "151"}], ",", 
             RowBox[{"\"ro\"", "\[Rule]", "212"}], ",", 
             RowBox[{"\"ru\"", "\[Rule]", "128"}], ",", 
             RowBox[{"\"ry\"", "\[Rule]", "1"}], ",", 
             RowBox[{"\"sa\"", "\[Rule]", "330"}], ",", 
             RowBox[{"\"sc\"", "\[Rule]", "347"}], ",", 
             RowBox[{"\"se\"", "\[Rule]", "569"}], ",", 
             RowBox[{"\"sh\"", "\[Rule]", "386"}], ",", 
             RowBox[{"\"si\"", "\[Rule]", "250"}], ",", 
             RowBox[{"\"sk\"", "\[Rule]", "98"}], ",", 
             RowBox[{"\"sl\"", "\[Rule]", "205"}], ",", 
             RowBox[{"\"sm\"", "\[Rule]", "81"}], ",", 
             RowBox[{"\"sn\"", "\[Rule]", "120"}], ",", 
             RowBox[{"\"so\"", "\[Rule]", "311"}], ",", 
             RowBox[{"\"sp\"", "\[Rule]", "418"}], ",", 
             RowBox[{"\"sq\"", "\[Rule]", "62"}], ",", 
             RowBox[{"\"st\"", "\[Rule]", "709"}], ",", 
             RowBox[{"\"su\"", "\[Rule]", "530"}], ",", 
             RowBox[{"\"sv\"", "\[Rule]", "1"}], ",", 
             RowBox[{"\"sw\"", "\[Rule]", "121"}], ",", 
             RowBox[{"\"sy\"", "\[Rule]", "104"}], ",", 
             RowBox[{"\"ta\"", "\[Rule]", "280"}], ",", 
             RowBox[{"\"te\"", "\[Rule]", "326"}], ",", 
             RowBox[{"\"th\"", "\[Rule]", "290"}], ",", 
             RowBox[{"\"ti\"", "\[Rule]", "173"}], ",", 
             RowBox[{"\"to\"", "\[Rule]", "263"}], ",", 
             RowBox[{"\"tr\"", "\[Rule]", "485"}], ",", 
             RowBox[{"\"ts\"", "\[Rule]", "3"}], ",", 
             RowBox[{"\"tu\"", "\[Rule]", "122"}], ",", 
             RowBox[{"\"tw\"", "\[Rule]", "53"}], ",", 
             RowBox[{"\"ty\"", "\[Rule]", "43"}], ",", 
             RowBox[{"\"ub\"", "\[Rule]", "2"}], ",", 
             RowBox[{"\"ud\"", "\[Rule]", "1"}], ",", 
             RowBox[{"\"ug\"", "\[Rule]", "3"}], ",", 
             RowBox[{"\"uk\"", "\[Rule]", "2"}], ",", 
             RowBox[{"\"ul\"", "\[Rule]", "24"}], ",", 
             RowBox[{"\"um\"", "\[Rule]", "14"}], ",", 
             RowBox[{"\"un\"", "\[Rule]", "1353"}], ",", 
             RowBox[{"\"up\"", "\[Rule]", "75"}], ",", 
             RowBox[{"\"ur\"", "\[Rule]", "36"}], ",", 
             RowBox[{"\"us\"", "\[Rule]", "25"}], ",", 
             RowBox[{"\"ut\"", "\[Rule]", "18"}], ",", 
             RowBox[{"\"uv\"", "\[Rule]", "2"}], ",", 
             RowBox[{"\"ux\"", "\[Rule]", "1"}], ",", 
             RowBox[{"\"va\"", "\[Rule]", "149"}], ",", 
             RowBox[{"\"ve\"", "\[Rule]", "173"}], ",", 
             RowBox[{"\"vi\"", "\[Rule]", "219"}], ",", 
             RowBox[{"\"vo\"", "\[Rule]", "87"}], ",", 
             RowBox[{"\"vu\"", "\[Rule]", "18"}], ",", 
             RowBox[{"\"wa\"", "\[Rule]", "262"}], ",", 
             RowBox[{"\"we\"", "\[Rule]", "132"}], ",", 
             RowBox[{"\"wh\"", "\[Rule]", "173"}], ",", 
             RowBox[{"\"wi\"", "\[Rule]", "196"}], ",", 
             RowBox[{"\"wo\"", "\[Rule]", "174"}], ",", 
             RowBox[{"\"wr\"", "\[Rule]", "69"}], ",", 
             RowBox[{"\"wu\"", "\[Rule]", "1"}], ",", 
             RowBox[{"\"xe\"", "\[Rule]", "6"}], ",", 
             RowBox[{"\"xi\"", "\[Rule]", "1"}], ",", 
             RowBox[{"\"xy\"", "\[Rule]", "4"}], ",", 
             RowBox[{"\"ya\"", "\[Rule]", "28"}], ",", 
             RowBox[{"\"ye\"", "\[Rule]", "36"}], ",", 
             RowBox[{"\"yi\"", "\[Rule]", "8"}], ",", 
             RowBox[{"\"yo\"", "\[Rule]", "28"}], ",", 
             RowBox[{"\"yt\"", "\[Rule]", "2"}], ",", 
             RowBox[{"\"yu\"", "\[Rule]", "7"}], ",", 
             RowBox[{"\"za\"", "\[Rule]", "3"}], ",", 
             RowBox[{"\"ze\"", "\[Rule]", "20"}], ",", 
             RowBox[{"\"zi\"", "\[Rule]", "15"}], ",", 
             RowBox[{"\"zl\"", "\[Rule]", "1"}], ",", 
             RowBox[{"\"zo\"", "\[Rule]", "13"}], ",", 
             RowBox[{"\"zu\"", "\[Rule]", "1"}], ",", 
             RowBox[{"\"zw\"", "\[Rule]", "1"}], ",", 
             RowBox[{"\"zy\"", "\[Rule]", "4"}]}], "\[RightAssociation]"}]], 
        "ExerciseOutput", Selectable -> False, Copyable -> False, Editable -> 
        False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"6c53e156-1084-4e51-bb63-be0e09af6ff7"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Use ",
 ButtonBox["Sow",
  BaseStyle->"Link"],
 " and ",
 ButtonBox["Reap",
  BaseStyle->"Link"],
 " to find intermediate values of ",
 Cell[BoxData[
  RowBox[{
   ButtonBox["#",
    BaseStyle->"Link",
    ButtonData->"Slot"], "1"}]], "InlineCode",ExpressionUUID->
  "0ee5f475-5afd-4279-8a86-cb62df45cc94"],
 " in ",
 Cell[BoxData[
  RowBox[{
   ButtonBox["Fold",
    BaseStyle->"CodeLink"], "[", 
   RowBox[{
    RowBox[{
     RowBox[{"10", 
      ButtonBox["#",
       BaseStyle->"Link",
       ButtonData->"Slot"], "1"}], "+", 
     RowBox[{"#2", 
      ButtonBox["&",
       BaseStyle->"Link",
       ButtonData->"Function"]}]}], ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "2", ",", "3", ",", "4", ",", "5"}], "}"}]}], "]"}]], 
  "InlineCode",ExpressionUUID->"dd9c0f17-9125-4010-a7c4-335e601bc321"],
 ".",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "47.2", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->
  False,ExpressionUUID->"dcfec621-46b5-4fc7-8e1a-f44b72599384"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       RowBox[{"{", 
        RowBox[{"1", ",", "12", ",", "123", ",", "1234"}], "}"}]], 
       "ExerciseOutput",ExpressionUUID->
       "80151f18-b569-4077-8920-d4907fec57a5"],
      Apply[TextCell, 
       Cell[
        BoxData[
         RowBox[{"{", 
           RowBox[{"1", ",", "12", ",", "123", ",", "1234"}], "}"}]], 
        "ExerciseOutput", Selectable -> False, Copyable -> False, Editable -> 
        False, ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"780de206-587b-41ff-8068-ed82d1033b7b"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Use ",
 ButtonBox["Sow",
  BaseStyle->"Link"],
 " and ",
 ButtonBox["Reap",
  BaseStyle->"Link"],
 " to get a list of all cases where ",
 Cell[BoxData[
  RowBox[{"#", "/", "2"}]], "InlineCode",ExpressionUUID->
  "ac16864b-9391-4fe1-b216-38aa481ea2f5"],
 " is used in ",
 Cell[BoxData[
  RowBox[{
   ButtonBox["Nest",
    BaseStyle->"CodeLink"], "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      ButtonBox["If",
       BaseStyle->"CodeLink"], "[", 
      RowBox[{
       RowBox[{
        ButtonBox["EvenQ",
         BaseStyle->"CodeLink"], "[", 
        ButtonBox["#",
         BaseStyle->"Link",
         ButtonData->"Slot"], "]"}], ",", 
       RowBox[{
        ButtonBox["#",
         BaseStyle->"Link",
         ButtonData->"Slot"], "/", "2"}], ",", 
       RowBox[{
        RowBox[{"3", 
         ButtonBox["#",
          BaseStyle->"Link",
          ButtonData->"Slot"]}], "+", "1"}]}], "]"}], 
     ButtonBox["&",
      BaseStyle->"Link",
      ButtonData->"Function"]}], ",", "1000", ",", "20"}], "]"}]], 
  "InlineCode",ExpressionUUID->"706b17b7-f2ff-4c75-ab7f-179ffcc68419"],
 ".",
 StyleBox[ButtonBox["\[NonBreakingSpace]\[RightGuillemet]",
  Appearance->None,
  Evaluator->Automatic,
  Method->"Preemptive",
  ButtonFunction:>(SelectionMove[
     ButtonNotebook[], All, ButtonCell, AutoScroll -> False]; 
   FrontEndExecute[
     FrontEndToken[
      ButtonNotebook[], "OpenCloseGroup"]])],
  FontColor->RGBColor[1, 0.501961, 0]]
}], "Exercise",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellDingbat->Cell[
  "47.3", "ExerciseNumber", FontColor -> 
   RGBColor[0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 ShowCellBracket->False,
 CellTags->
  "LastCellOfAPage",ExpressionUUID->"6d8eb33c-f9b9-47ed-9e9f-165db8be5321"],

Cell[BoxData[
 PaneBox[GridBox[{
    {" ", 
     StyleBox[
      RowBox[{"Expected", " ", 
       RowBox[{"output", ":"}]}],
      Editable->False,
      Selectable->False,
      StripOnInput->False,
      FontColor->RGBColor[0.45, 0.45, 0.45]], " "},
    {" ", 
     InterpretationBox[Cell[BoxData[
       RowBox[{"{", 
        RowBox[{
        "1000", ",", "500", ",", "250", ",", "376", ",", "188", ",", "94", 
         ",", "142", ",", "214", ",", "322", ",", "484", ",", "242", ",", 
         "364", ",", "182"}], "}"}]], "ExerciseOutput",ExpressionUUID->
       "471f24cd-d027-406d-b0e0-0946ec86f20e"],
      Apply[TextCell, 
       Cell[
        BoxData[
         RowBox[{"{", 
           
           RowBox[{"1000", ",", "500", ",", "250", ",", "376", ",", "188", 
             ",", "94", ",", "142", ",", "214", ",", "322", ",", "484", ",", 
             "242", ",", "364", ",", "182"}], "}"}]], "ExerciseOutput", 
        Selectable -> False, Copyable -> False, Editable -> False, 
        ShowCellBracket -> False]]], " "}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
   GridBoxBackground->{"Columns" -> {{
        RGBColor[1, 1, 1]}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
  FrameMargins->0]], "ExerciseOutput",
 Editable->False,
 Selectable->False,
 Deletable->False,
 CellFrame->{{1, 1}, {1, 1}},
 ShowCellBracket->False,
 CellFrameColor->RGBColor[0.85, 0.85, 0.85],
 LineBreakWithin->
  Automatic,ExpressionUUID->"68e50600-227f-4077-934d-ff38dda89e44"]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Q&A", "QASection",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"p:294",ExpressionUUID->"51f3cfb6-5e19-4f45-b067-6d1d5224b0e9"],

Cell["Can I cause a problem by just trying to run a piece of code?", \
"Question",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"a6003fcd-6121-431e-b6f9-217633d8cdcb"],

Cell[TextData[{
 "Not unless your code is for example set up to delete something. The Wolfram \
Language has protections against \[OpenCurlyDoubleQuote]obviously wrong\
\[CloseCurlyDoubleQuote] infinite loops and so on. If something is taking too \
long, you can always abort it. If you\[CloseCurlyQuote]re really concerned \
about resources, use ",
 ButtonBox["TimeConstrained",
  BaseStyle->"Link"],
 " and ",
 ButtonBox["MemoryConstrained",
  BaseStyle->"Link"],
 "."
}], "Answer",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:15",ExpressionUUID->"074c6db3-427a-4c7c-a7d0-b1c6d7c96fe2"],

Cell["Is there a most common type of bug in Wolfram Language code?", \
"Question",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"eabd5647-24ae-4820-b0d7-5b3f58f8eff2"],

Cell[TextData[{
 "Not really. The design of the language makes all sorts of bugs that are \
common in other programming languages rare. For example, \
\[OpenCurlyDoubleQuote]off by one\[CloseCurlyDoubleQuote] errors are common \
in languages where you\[CloseCurlyQuote]re always explicitly manipulating \
loop variables, but are rare when you\[CloseCurlyQuote]re using Wolfram \
Language \[OpenCurlyDoubleQuote]whole-list\[CloseCurlyDoubleQuote] functions \
like ",
 ButtonBox["Table",
  BaseStyle->"Link"],
 "."
}], "Answer",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:16",ExpressionUUID->"1216c195-6743-4d7d-8ad5-e55d49f972f6"],

Cell["\<\
If I can\[CloseCurlyQuote]t figure out what\[CloseCurlyQuote]s going on, is \
it worth just trying random things?\
\>", "Question",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"790e05b4-83eb-49be-bd11-7ebd4da741e4"],

Cell["\<\
If you think you\[CloseCurlyQuote]re close, it\[CloseCurlyQuote]s often not \
crazy to try making small random changes to code to see what happens. Since \
in the Wolfram Language simpler code is usually more likely to be correct, it\
\[CloseCurlyQuote]s not uncommon to hit the code you want by a small amount \
of random searching.\
\>", "Answer",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:17",ExpressionUUID->"b1f12715-1608-495c-a325-4c17c8ca5c80"],

Cell["\<\
Is there a way to do interactive step-by-step debugging in the Wolfram \
Language?\
\>", "Question",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"9a955e17-5ee1-4c87-9a76-d5dc6d6e50f4"],

Cell["\<\
Yes (at least with a native desktop interface)\[LongDash]though it\
\[CloseCurlyQuote]s rarely used. Given the structure of the Wolfram Language, \
systematically capturing and analyzing intermediate results is almost always \
a better approach.\
\>", "Answer",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:18",ExpressionUUID->"83839ea8-a8b0-4904-a73b-2a9e3d330cd4"],

Cell["\<\
How can I tell what\[CloseCurlyQuote]s wrong when a piece of graphics is \
\[OpenCurlyDoubleQuote]pinked\[CloseCurlyDoubleQuote]?\
\>", "Question",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"a2df5a96-5bdc-4dec-93fe-b6a8d7a8291b"],

Cell[TextData[{
 "Hover over it and you\[CloseCurlyQuote]ll see the underlying symbolic \
expression. Or press the ",
 Cell[BoxData[
 "+"], "InlineCode",ExpressionUUID->"04152f0e-0034-4e2b-a6d6-d9b7c29e318e"],
 " to print messages."
}], "Answer",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:19",ExpressionUUID->"5f60a9dd-f74b-48fa-97ea-59a1acf89bab"],

Cell["What is the code that makes the fractal-like graphics doing?", \
"Question",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:20",ExpressionUUID->"471cf27b-e311-4edd-9699-8192a0172aad"],

Cell[TextData[{
 "It\[CloseCurlyQuote]s making a ",
 StyleBox["Gray code",
  FontSlant->"Italic"],
 "\[LongDash]",
 "an ordering of integers so that only one binary digit changes at each \
step."
}], "Answer",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"bdf9090e-eff2-48c3-8c18-3e9a5aca6a05"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Tech Notes", "TechNoteSection",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"8685e968-e529-4c3f-b8d0-15f9b98a16ac"],

Cell[TextData[{
 "For large-scale software development, the Wolfram Language has a built-in \
framework for creating and running systematic tests, with functions like ",
 ButtonBox["VerificationTest",
  BaseStyle->"Link"],
 " and ",
 ButtonBox["TestReport",
  BaseStyle->"Link"],
 "."
}], "TechNote",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->"i:21",ExpressionUUID->"28a081a6-c745-43c1-b2a7-11f2cdc6cd57"],

Cell["\<\
A major goal of good language design is to encourage people to write correct \
code. \
\>", "TechNote",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"f21e71c9-f172-4109-947b-e3225c734647"]
}, Open  ]],

Cell[CellGroupData[{

Cell["More to Explore", "MoreExploreSection",
 Editable->False,
 Deletable->False,
 ShowCellBracket->
  False,ExpressionUUID->"e6e6ec09-225e-4dd3-b67c-551754826e72"],

Cell[TextData[ButtonBox["Guide to Debugging in the Wolfram Language\
\[NonBreakingSpace]\[RightGuillemet]",
 BaseStyle->"Link",
 ButtonData->{"paclet:guide/TuningAndDebugging", None}]], "MoreExplore",
 Editable->False,
 Deletable->False,
 ShowCellBracket->False,
 CellTags->
  "LastCellOfAPage",ExpressionUUID->"c1c8284d-9d9f-4615-b5ea-21e12544f9bb"]
}, Open  ]]
},
Saveable->False,
WindowToolbars->{},
BlinkingCellInsertionPoint->False,
CellInsertionPointCell->None,
WindowSize->{830, 800},
WindowMargins->Automatic,
WindowPersistentStyles->{
 WindowFrame, WindowMargins, WindowSize, Magnification},
WindowTitle->"How to Debug: Elementary Introduction to the Wolfram Language",
DockedCells->{
  Cell[
   BoxData[
    TagBox[
     GridBox[{{
        TemplateBox[{
         "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]", 
          "\"\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\"", 
          GraphicsBox[
           TagBox[
            RasterBox[CompressedData["
1:eJztl01IVFEUxyctMFzUysjIyUDCTauiIJFM6ENpM4NEtJrBUaSYZMYPhCRm
rYuoICgiW0VEBVIUEbTNEMTAIqRsk6JGCVFBHx7//+4JLo/36DqvB4Ie+Mk7
7+t3733nHpzq9NlEW0ksFsuX4U8i1duQy6X6kpuRtGTzHe3ZTOuxbFemPZPb
ny7FyZ2gEqwHInICfJToguOIReywPVHHlYDzcY4hJHZ486giyBOXtfms5Pms
Bs9zUBDTow6DJOgBT8DP/+B5CepAPbgqZm+zT70Bt9VXCx6H8DwE28Gw5ufB
IT2eA1N6PKquC0V4xtUxqfkE6ARD4BHYAx5Y938Gu8GdZXq4VsNWngIfwDzY
Aa6Bm55nOKYq8NXRw29eb+Uz4JSVd4Nn4IbPs2fARUdPQcfLWAQJ8Mq6Tkdd
gGcEHHT0sHYn9Jg1dcnnnhf6vnee8xzXVkcP9wdr97eY7z0NnlrX74qpxffg
iOZ2VDp6kvqOe6AVXAb7xNQB462YNfsCfoBzoE1MzTEqHD096mgE98WsEec4
Jqamvvk8cx2kwWuw19HDXnIAbNAx03ka9IO8mO+3ScyebRZTi01i1rqguHjY
r3aJWaugOA5O6vEC+K6ebWDW0cNgv6oBnwKus87KwKDmv8BRMOBz77/6G/sV
e8lkwHWuTwm4pQ7WzGIRHgb7FXsJ9/mI5z2si42gXMw8/ByuHgb7FXsJ9yX3
IPfHFjF1xTl5v0exnrCx5gnn+fu7JC7h/z/0Y52+P+rfWX9iCXVYErg=
             "], {{0,
              34}, {26, 0}}, {0, 255}, ColorFunction -> RGBColor], 
            BoxForm`ImageTag[
            "Byte", ColorSpace -> "RGB", Interleaving -> True, Magnification -> 
             1], Selectable -> False], DefaultBaseStyle -> "ImageGraphics", 
           ImageSize -> Magnification[1], ImageSizeRaw -> {26, 34}, 
           PlotRange -> {{0, 26}, {0, 34}}], 
          GraphicsBox[
           TagBox[
            RasterBox[CompressedData["
1:eJztXUuS47gRLX8WXtYRaJ+gl17SS+8U4/CeM+H2hDdtRY8jHF6ZR9AReATt
qrwyj6AjcO+ZaN0gLZCZwEMiQVJqSd2qwYvgdBGf/AF4+LFqfvvd37/56y+f
np5++M3pP998+88/fPz47b/+9Hx6+fOHH/72/Yf3f/njh3+8//79x99/96tT
4u9Oz79/8fT066cY9NNLSz++9uPz0+uOPv3n3Zj+40vj083npZktd5IVdJzk
hvT9pHOq78uc9I75rD/KA31n6/z03+dY1lRX64jkQh3LLpevbWI7t6N/Esv/
vdSJDpcOdpr5M74lvk/tt6VPL1VG3j7v79Qedr2XLlevoKDgsTHx8Cud+OTA
XDKM7yfOijnmlB+XC9zvuGfMm+HhqfwR8sjLY54ddbJuw05yesL7Sp2qHtY1
4+F8VjZ4Xajf2/q6Gd/HuUDH6OTvZOM21jHZmm0TsTvH/d531WZOn5o3x3lL
Ys22pnFN87Bezs6CgoLHhFsnMqd1IW1cz26TsrO8nOdSX8bgO+CwZlmHzf2L
OoXbYE08y/2e80AXcDGkbVEuzEXbIAvmA9S/kvuz+aIL5yeJHbTlVHbcQwzT
/BDncT5l6xXuLyh4k4C1Xfb8wZe9Bfcrnr0J949r43H9vV9bl2Oyn2w88Te/
Yx0+DxmiOiddiSyDk2/B/cEGFWPm/GkOeDmavo5zQ5wnaYX7CwreJvy61HGb
cc7uy63g/rEMPLEeg/tl7cxrZa/DpStZ2TOfFTo1Vy5yP88Zk02vGzkTic54
prjx/JDuFWJ501nXXCwS/Wev+9m+aN/Bdrk8dUYVZE1zv7n/4vScHQUFBY8L
f2fpz99PP1v8vob71ROV8efSruxYfj9xojujVuf92cfg/mWdPf88yDp9ed0f
8uXMZJIxroP5zN3ar6Tn6cGOsK5efd6f8S1/3n/6Nzrbirl7sj852yFuk87P
Zfzzmr1VQUHBY2M6+x/HPJnnCddY9yOXjevmkz7kqhut+xPZS9zv1/juvnvc
N3STTv5+R8XCsi+2Y+Joyy67fLijxifxXbhf5uzkeyZ/zt/yt0ADzrXs06RH
fJ7uKI7TnXfh/oKCnwvgDiD67u8W5/1JmZuc92vOndbus9wvd+D+TEq+ZQ3v
wpNTebkTMO5S4b4gZ5dp9xlnPp7/cR7F73v0g9/K4v7Ff4c17VEK9xcUvE2M
vJR828dcpc/m3wL3e05fvsPktW/0jY7n02m9PSS6FP+infHvJlyZ+4352p/h
671AWi5wv/+2R/Y5hfsLCt4icKzD2cpe3xmOZS8484nuIm/E/efqpJXfLkIc
hihdvtnP7YvcuYq/Ww1nM7EM/v5I2y5zzCV3vXJeF/YCg7Yx8kv2LMj9MofI
7/YV7i8oeJOY1vhwxh+e5JvPS+5643vGG3H/mTr9efYi9/vf5+qUHebc6O0P
c4M8e+Mc3rzLDWcvF3C/P6fnuSdno5xX+d/Lm7mnKNxfUPDmodeeBZdjXD+P
sYw5v6CgoKCgoKCgoKCgoKCgoKCgoKCgoKCgoKCgoKCgoKCgoKCgoKCgoOBr
BxE9n57aPV/aloLr4dSeFbdr9m/CXlmf60fVPXTdGi5mHLvqS9uyhNz45fTm
9LTu3y9jXcFacHu1/NRXktlmnprzXb8ZcQ19Pxdw3K7WTtcG2+bQ30nf4fQc
7zXX3BIuZhy79kryKhl3Kt1K23J6tVK2OX7Bh69mbFv+FkzgeVpg/r9bL5CZ
Q8v5D8n99+S1jP4W43hm3Zvbfivuz/nN6Y7/b/57dCcdwzX6K/T9VqXfgvuj
MYZpBPPluWPRGr9KdkdfyXz8iDxzLzi+5/Ac+d/PHkfQB7bcT+SpOP/huJ+m
PflDcj/Eu7+NZV7PXbn/nrhWf70X97NMGdM1v+M6b8tp0q+T/+/cCh/ISrsG
h1wLj8Yz9wJN5z3C+x3/3KgyY7/g8XeE8vn/z1dAncnP7Rk3xOsrRof9SHiF
6x/gXc4Zxb6dkvuO4v1oT/G6R/JQhvt3w/mNsmuUAbL3Kk/rF50tlNnyv3tV
VvQk8SWDA0HeJba3UFfi2UIbYb2Dtol9HyBf4thr+1a0/Vbpk3bdUYoWZRP0
M8Nu3dai38ntVLmEs9jHAylAvu6zkT4lC9tI+yKx2yt5jZJh6TO5FmQKz6O/
e7DJv4PPOF6cPh1jHweK+4H2S2yUdnT+yzkz1hkobifpmxsK3HNkeysKYy6q
Z8TA25nJrykdv63hK/ogequZmCFqMtZfZI9nHIsSr0bZvKW0H3nZNMW3W5Cx
4bwOftZcRErG0SqXqROt+4146jEkcPZIv+gytmC/ORpp77hOBfk9hfY5gFxs
syPIGYz2OHL5HeftVLqgUXajjcJrggr6j9drxHWO+0XHEWUs2N5COnG5DduB
aVhfbMW4DqT4SNu30PYt1JUz/IEC9+vYNcr3WsVvzu6aYuA4S//+Xcr9PYUx
Vis5EoOR3wxZDZTRvmjewHg+G/51YFevdam4SnsPYOfR6lOUtiv6LmPK4n4d
I91G6HMFaRi33rBdxwPXN6u5aCa/A3nYBtKndH/BdulADtoXjQUK9/g5H1tD
jo59ZdiD+a68tDPOix3EqTb8dn0SuUivtYntdGU8Ry/FWwPyrfEvfjT8/sw2
Hw25so4R3h0otNWg5EgZbCdp43fqfc96fd80bPZtB3Zu4F307SBN0Km6En/x
p9V1Vfk57u8usB25H9dcYheuBSVGnRH7Z1Wvh3o5WzBN+qbEYfTD0O39Vr7X
/C593rJbxoXo92sh8MXkEMtmpa+DNOl/yTyiYq59ETt7CuM8GrOgbwv1RJ81
12xQptgKunCtKjokFr3hp+wVrDbMxUig98IbitcRWp7E6cD5yE/S18W/41MG
lk0q38nG8St9uNV+UeifjREjgV47VUoO1rHGs6uLY1F4sTbigvviDuo74LgU
e5GTxL4NxecoTS52ZLRTLt4cx1YeyLf6jqCH52iVMWKH8Yx4At4PIFfGS63K
1DO6TP6E2O4hntomwbOqJzIP/C7xrzJxneP+s22nzFwDduCYiPq7jrOSl/hu
2ELWe8bvtdwv7Tpn99wYjOKTszmnf6WsJe5vjTTxD/di0RhBG6C+jFVXRniy
ARsaUnMH6MT5Rfw/qvfV3J+xbUfqPG0uTpSO2zV9Zzafy1jjt13ha2/YJnEU
v/ReCetYPjo+30I7aHsiHieY3/l9y++yj+lJ7Q8pPmPRwHVTEjsrzcqnM877
oU6vn5xeupz75dHr/npGV44/8cynA1lZu1V935/Fzpm43or7W5U+GDJ1H/sa
ud/a22q7H5n7BVZfrjL6JCbST/H8we/dDJ1Nzn8rHksxUmm4Lu4hJkvcr+Px
2dxP8ZnPTrfDgq89pAknu7EjXHtYqBP5SBPvH0BOS2EsYhwkrYc4bpRM5H55
RE8H9Vt+pC9k19or4ymoM/lWPMWfjVXH0kvruL/D94zcc7jf2WmdidUzNmXj
BeWlzc2zAlW2hbQk1mfYvsRDuEeMzkUgrp1RJvGdwt5X1iXCI7iX9z5k7OlU
uo69xZ9ipz6vQBuX+BrP2a39eGPo6zKyTF0Z2zXXJby8BKjjoM9PPf/O2a9t
ps/n/tbQoeXdnPspvneQ9brm47Xc731iO7cUjzWpg/OBnKVpXdhOms/ceHHj
WOb/PcVj34/1mZhIu+tvNyIOtmK3Nt6kznwonK/WUEbSJHbjOSyFfdhGyzXi
jW2gY4W6XPmN2GXUqWd04fjvKb3LOpD6bmRNvCjufw7VTFw/l/u17Tnuxz1h
C+W8Hoq/F9zN+C79aU9qH2vE/8i6OoL7UiXb6ZL92pxNObvP5n6ly/nTqnrO
1i3F34HUGTlbKOPHLa3jfvFP4iRjpJmxG2Ng3YNondhXdhS+sSEK/QbHQqPr
WXGbsWlHcDdqlJmLx2rup5iHWq6LY8/Jxn7W5nSQ3YfEhx2F71twnYAxi3y2
dFE6XqSM9IGBfxZdlWGLq79hfXKXKWN7MGIl/nczbZekZeKtgbGaW3MIjmTw
HLwvcr+KF8IaB/Wcj6S+veI0HO/OXpnL+zlZSq7Umf3Gmi7k/hnbTe43/CKr
HKXfkUkc0fdWyfD9GcrgXhfL1Zxfq7x2xnfLbuvs2rLRp62IR2XEQNDMyHG+
JvdCtIL7M3aMZxUz+qJ5PCNno+pY40XfCUXjl87jfjzzIYI7OChzbe7XaJVM
iWVuLb523a8x3skauhyk76CPOA4GsvsFzhsI/J0NXebA6RWpeQnkRnn8c63K
JGlWvvHgPOj0bLUNbJ9LT85+tF7LD8r8XRQu2/Cj71yljt6jJT7SNJYaZccG
5Ro2ZeNFExdI+2bPe5S/FaTVa2ynMOd72y15hj6JWa6MtJfpO5RpQW8utjWX
S3RBf9lQ/O1E5PuS3RT+Fo3ui+Z4UHU3FL5bxnhLDLJxMmwQ+2ScJf3W6pfK
v+z5qOGvtrmy0g0dpk96/KIeVS7X1lK/Ql8N+7LxyOm09BsPyh3HhZJZqXe0
zepDbgwPFP4+hoxpUnWlD1VaF8j2bavjQGHe6Sic0yfraCi7pRV9suC+4H4g
87w/4ygoKHgcUNhb4f2YnMsTLawpztTVa5kUzhH7a+kpuC0o3vc2X9qegoKC
80Hp78Phmr+7si48q5O9hqwdrzbHFNwWFL61rr60LQUFBZeDwt9N7Sl8O1nf
SFdD4XuijtQ3RXP4P6lulfg=
             "], {{0, 34}, {383, 0}}, {0, 255}, 
             ColorFunction -> RGBColor], 
            BoxForm`ImageTag[
            "Byte", ColorSpace -> "RGB", Interleaving -> True, Magnification -> 
             1], Selectable -> False], DefaultBaseStyle -> "ImageGraphics", 
           ImageSize -> Magnification[1], ImageSizeRaw -> {383, 34}, 
           PlotRange -> {{0, 383}, {0, 34}}]}, "RowWithSeparators"], 
        PaneBox[
         StyleBox["\[VeryThinSpace]", ShowStringCharacters -> False], 
         Alignment -> Right, ImageSize -> {174, 47}], 
        PaneBox[
         PaneBox[
          TemplateBox[{"\[ThinSpace]", "\" \"", 
            TagBox[
             TooltipBox[
              PaneSelectorBox[{False -> ButtonBox[
                  PaneBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAPiDmBmIUBO/j//z8jEDcA8W8g3oBFnhmIZ/9HgE9o8mxAvBZJ/hsQuyPJ
8wPxfiT5N0BsjiQvCsTnkOSfALEWkrwSEN9Bkr8OxDJobniAJP8ZZCYWfxCj
RpGQXcS4mVi/ExuGxMYFmlp4nAIAG14fWQ==
                    "], {{0, 14}, {9, 
                    0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                     ImageSizeRaw -> {9, 14}, PlotRange -> {{0, 9}, {0, 14}}, 
                    ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                   Alignment -> Center], 
                  ButtonFunction :> (
                   NotebookLocate[{"EIWL1-46-writing-good-code.nb", ""}, 
                    FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Enabled -> True, Appearance -> 
                  None, Evaluator -> Automatic, Method -> "Preemptive"], True -> 
                ButtonBox[
                  PaneBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAPiDmBmIUBO/j//z8jEDcA8W8g3oBFnhmIZ/9HgE9o8mxAvBZJ/hsQuyPJ
8wPxfiT5N0BsjiQvCsTnkOSfALEWkrwSEN9Bkr8OxDJobniAJP8ZZCYWfxCj
RpGQXcS4mVi/ExuGxMYFmlp4nAIAG14fWQ==
                    "], {{0, 14}, {9, 
                    0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                     ImageSizeRaw -> {9, 14}, PlotRange -> {{0, 9}, {0, 14}}, 
                    ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                   Alignment -> Center], 
                  ButtonFunction :> (
                   NotebookLocate[{"EIWL1-46-writing-good-code.nb", ""}, 
                    FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Enabled -> True, Appearance -> 
                  None, Background -> RGBColor[0.835294, 0.364706, 0.0196078],
                   Evaluator -> Automatic, Method -> "Preemptive"]}, 
               Dynamic[
                CurrentValue["MouseOver"]], ImageSize -> Automatic, 
               FrameMargins -> 0], "\"Writing Good Code\"", TooltipDelay -> 
              0.15, LabelStyle -> "TextStyling"], 
             Annotation[#, "Writing Good Code", "Tooltip"]& ], 
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {5, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[5], Selectable -> False], 
            TagBox[
             TooltipBox[
              PaneSelectorBox[{False -> ButtonBox[
                  PaneBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAfiDmBmAWI////vwKIfwFxMQMOAJT7+R8B6nGoSf+PCjpwqMskUl0SEP9F
UtcHxIxY1EWjqZuOQ10Mmr2TcNj7BEnNP1LNIeQeIDsZn78IhQ8x4fwfNb4a
cPgTFu8l2ORBAAC+1hnm
                    "], {{0, 15}, {9, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                     ImageSizeRaw -> {9, 15}, PlotRange -> {{0, 9}, {0, 15}}, 
                    ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                   Alignment -> Center], 
                  ButtonFunction :> (
                   NotebookLocate[{"EIWL1-what-we-havent-discussed.nb", ""}, 
                    FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Appearance -> None, Evaluator -> 
                  Automatic, Method -> "Preemptive"], True -> ButtonBox[
                  PaneBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAfiDmBmAWI////vwKIfwFxMQMOAJT7+R8B6nGoSf+PCjpwqMskUl0SEP9F
UtcHxIxY1EWjqZuOQ10Mmr2TcNj7BEnNP1LNIeQeIDsZn78IhQ8x4fwfNb4a
cPgTFu8l2ORBAAC+1hnm
                    "], {{0, 15}, {9, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                     ImageSizeRaw -> {9, 15}, PlotRange -> {{0, 9}, {0, 15}}, 
                    ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                   Alignment -> Center], 
                  ButtonFunction :> (
                   NotebookLocate[{"EIWL1-what-we-havent-discussed.nb", ""}, 
                    FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Appearance -> None, Background -> 
                  RGBColor[0.835294, 0.364706, 0.0196078], Evaluator -> 
                  Automatic, Method -> "Preemptive"]}, 
               Dynamic[
                CurrentValue["MouseOver"]], ImageSize -> Automatic, 
               FrameMargins -> 0], 
              "\"What We Haven\[CloseCurlyQuote]t Discussed\"", TooltipDelay -> 
              0.15, LabelStyle -> "TextStyling"], 
             Annotation[#, "What We Haven\[CloseCurlyQuote]t Discussed", 
              "Tooltip"]& ]}, "RowWithSeparators"], Alignment -> Right], 
         ImageSize -> {100, 30}, FrameMargins -> {{0, 6}, {0, 0}}, Alignment -> 
         Right], 
        ActionMenuBox[
         PaneSelectorBox[{True -> PanelBox[
             GraphicsBox[
              TagBox[
               RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UBAkIQ3ELED8////Jf/pA0D2/KWTXSB7ZtPBPrA9DKOAYgAMR1Eg9gPiABpi
P6g912mcLmAAZM9XOtkFsicKiNcD8QYaYpD5UQOdXoYD+E/HMooO9iDbR7c6
BQDxtyEt
                "], {{0, 16}, {27, 0}}, {0, 255}, ColorFunction -> 
                RGBColor], 
               BoxForm`ImageTag[
               "Byte", ColorSpace -> "RGB", Interleaving -> True, 
                Magnification -> 1], Selectable -> False], DefaultBaseStyle -> 
              "ImageGraphics", ImageSize -> Magnification[1], 
              ImageSizeRaw -> {27, 16}, PlotRange -> {{0, 27}, {0, 16}}], 
             Appearance -> None, Background -> 
             RGBColor[0.835294, 0.364706, 0.0196078], ImageSize -> {35, 30}, 
             Alignment -> Center], False -> PanelBox[
             GraphicsBox[
              TagBox[
               RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UBAkIQ3ELED8////Jf/pA0D2/KWTXSB7ZtPBPrA9DKOAYgAMR1Eg9gPiABpi
P6g912mcLmAAZM9XOtkFsicKiNcD8QYaYpD5UQOdXoYD+E/HMooO9iDbR7c6
BQDxtyEt
                "], {{0, 16}, {27, 0}}, {0, 255}, ColorFunction -> 
                RGBColor], 
               BoxForm`ImageTag[
               "Byte", ColorSpace -> "RGB", Interleaving -> True, 
                Magnification -> 1], Selectable -> False], DefaultBaseStyle -> 
              "ImageGraphics", ImageSize -> Magnification[1], 
              ImageSizeRaw -> {27, 16}, PlotRange -> {{0, 27}, {0, 16}}], 
             Appearance -> None, Background -> 
             RGBColor[0.952941, 0.509804, 0], ImageSize -> {35, 30}, 
             Alignment -> Center]}, 
          Dynamic[
           CurrentValue["MouseOver"]]], {
         "Preface" :> 
          NotebookLocate[{"EIWL1-0a-preface.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "What Is the Wolfram Language?" :> 
          NotebookLocate[{"EIWL1-0b-what-is-the-wolfram-language.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "Practicalities of Using the Wolfram Language" :> 
          NotebookLocate[{
            "EIWL1-0c-practicalities-of-using-the-wolfram-language.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "Other Resources" :> 
          NotebookLocate[{"EIWL1-0d-other-resources.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]1\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Starting Out: Elementary Arithmetic" :> 
          NotebookLocate[{
            "EIWL1-01-starting-out-elementary-arithmetic.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]2\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Introducing Functions" :> 
          NotebookLocate[{"EIWL1-02-introducing-functions.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]3\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]First Look at Lists" :> 
          NotebookLocate[{"EIWL1-03-first-look-at-lists.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]4\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Displaying Lists" :> 
          NotebookLocate[{"EIWL1-04-displaying-lists.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]5\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Operations on Lists" :> 
          NotebookLocate[{"EIWL1-05-operations-on-lists.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]6\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Making Tables" :> 
          NotebookLocate[{"EIWL1-06-making-tables.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]7\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Colors and Styles" :> 
          NotebookLocate[{"EIWL1-07-colors-and-styles.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]8\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Basic Graphics Objects" :> 
          NotebookLocate[{"EIWL1-08-basic-graphics-objects.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "\[ThickSpace]\[ThickSpace]\[ThinSpace]9\[ThickSpace]\[ThickSpace]|\
\[ThickSpace]\[ThickSpace]Interactive Manipulation" :> 
          NotebookLocate[{"EIWL1-09-interactive-manipulation.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "10\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Images" :> 
          NotebookLocate[{"EIWL1-10-images.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "11\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Strings and \
Text" :> NotebookLocate[{"EIWL1-11-strings-and-text.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "12\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Sound" :> 
          NotebookLocate[{"EIWL1-12-sound.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "13\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Arrays, or \
Lists of Lists" :> 
          NotebookLocate[{"EIWL1-13-arrays-or-lists-of-lists.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "14\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Coordinates \
and Graphics" :> 
          NotebookLocate[{"EIWL1-14-coordinates-and-graphics.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "15\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]The Scope \
of the Wolfram Language" :> 
          NotebookLocate[{
            "EIWL1-15-the-scope-of-the-wolfram-language.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "16\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Real\
\[VeryThinSpace]\[Hyphen]\[VeryThinSpace]\[NegativeVeryThinSpace]World Data" :> 
          NotebookLocate[{"EIWL1-16-real-world-data.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "17\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Units" :> 
          NotebookLocate[{"EIWL1-17-units.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "18\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]\
Geocomputation" :> 
          NotebookLocate[{"EIWL1-18-geocomputation.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "19\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Dates and \
Times" :> NotebookLocate[{"EIWL1-19-dates-and-times.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "20\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Options" :> 
          NotebookLocate[{"EIWL1-20-options.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "21\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Graphs and \
Networks" :> NotebookLocate[{"EIWL1-21-graphs-and-networks.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "22\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Machine \
Learning" :> 
          NotebookLocate[{"EIWL1-22-machine-learning.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "23\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]More about \
Numbers" :> NotebookLocate[{"EIWL1-23-more-about-numbers.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "24\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]More Forms \
of Visualization" :> 
          NotebookLocate[{"EIWL1-24-more-forms-of-visualization.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "25\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Ways to \
Apply Functions" :> 
          NotebookLocate[{"EIWL1-25-ways-to-apply-functions.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "26\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Pure \
Anonymous Functions" :> 
          NotebookLocate[{"EIWL1-26-pure-anonymous-functions.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "27\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Applying \
Functions Repeatedly" :> 
          NotebookLocate[{"EIWL1-27-applying-functions-repeatedly.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "28\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Tests and \
Conditionals" :> 
          NotebookLocate[{"EIWL1-28-tests-and-conditionals.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "29\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]More about \
Pure Functions" :> 
          NotebookLocate[{"EIWL1-29-more-about-pure-functions.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "30\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Rearranging \
Lists" :> NotebookLocate[{"EIWL1-30-rearranging-lists.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "31\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Parts of \
Lists" :> NotebookLocate[{"EIWL1-31-parts-of-lists.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "32\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Patterns" :> 
          NotebookLocate[{"EIWL1-32-patterns.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "33\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Expressions \
and Their Structure" :> 
          NotebookLocate[{"EIWL1-33-expressions-and-their-structure.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "34\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]\
Associations" :> 
          NotebookLocate[{"EIWL1-34-associations.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "35\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Natural \
Language Understanding" :> 
          NotebookLocate[{"EIWL1-35-natural-language-understanding.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "36\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Creating \
Websites and Apps" :> 
          NotebookLocate[{"EIWL1-36-creating-websites-and-apps.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "37\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Layout and \
Display" :> NotebookLocate[{"EIWL1-37-layout-and-display.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "38\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Assigning \
Names to Things" :> 
          NotebookLocate[{"EIWL1-38-assigning-names-to-things.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "39\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Immediate \
and Delayed Values" :> 
          NotebookLocate[{"EIWL1-39-immediate-and-delayed-values.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "40\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Defining \
Your Own Functions" :> 
          NotebookLocate[{"EIWL1-40-defining-your-own-functions.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "41\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]More about \
Patterns" :> 
          NotebookLocate[{"EIWL1-41-more-about-patterns.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "42\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]String \
Patterns and Templates " :> 
          NotebookLocate[{"EIWL1-42-string-patterns-and-templates.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "43\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Storing \
Things" :> NotebookLocate[{"EIWL1-43-storing-things.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "44\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Importing \
and Exporting" :> 
          NotebookLocate[{"EIWL1-44-importing-and-exporting.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "45\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Datasets" :> 
          NotebookLocate[{"EIWL1-45-datasets.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "46\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Writing \
Good Code" :> 
          NotebookLocate[{"EIWL1-46-writing-good-code.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "47\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]Debugging \
Your Code" :> 
          NotebookLocate[{"EIWL1-47-debugging-your-code.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "What We Haven\[CloseCurlyQuote]t Discussed" :> 
          NotebookLocate[{"EIWL1-what-we-havent-discussed.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "Afterword: Being a Programmer" :> 
          NotebookLocate[{"EIWL1-being-a-programmer.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "Answers to Exercises" :> 
          NotebookLocate[{"EIWL1-answers-to-exercises.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "Index" :> 
          NotebookLocate[{"EIWL1-book-index.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}]}, Appearance -> None]}}, 
      GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Center}}}, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"]], 
   "Text", ShowCellBracket -> False, CellFrame -> {{0, 0}, {3, 0}}, 
   Selectable -> False, CellFrameColor -> 
   RGBColor[0.835294, 0.364706, 0.0196078], CellMargins -> {{0, 0}, {0, -1}}, 
   CellFrameMargins -> {{27, 0}, {1, 7}}, Background -> 
   RGBColor[0.952941, 0.509804, 0], CellTags -> "DockedCellLogoCell"], 
  Cell["FIRST EDITION (2015)", "Text", FontFamily -> "Source Sans Pro", 
   CellFrame -> {{0, 0}, {3, 0}}, ShowCellBracket -> False, 
   CellMargins -> {{0, 0}, {-1, -1}}, CellFrameMargins -> {{66, 0}, {2, 4}}, 
   CellFrameColor -> RGBColor[0.952941, 0.509804, 0], FontSize -> 10, 
   FontTracking -> "Extended", FontColor -> RGBColor[1, 0.929412, 0.721569], 
   Background -> RGBColor[0.862745, 0.309804, 0], CellTags -> 
   "DockedCellLogoCell"]},
PrintingStartingPageNumber->381,
PageHeaders->{{
   Cell[
    TextData[{
      StyleBox[
       CounterBox["Page"], "PageNumber"], 
      StyleBox[
      "    An Elementary Introduction to the Wolfram Language", "Header"]}], 
    "Header", CellMargins -> {{37, Inherited}, {Inherited, Inherited}}], None,
    None}, {None, None, 
   Cell[
    TextData[{
      StyleBox[
       CounterBox["Section"], "Header"], 
      StyleBox[" | Debugging Your Code \[LongDash] wolfr.am/eiwl-", "Header"], 
      StyleBox[
       CounterBox["Section"], "Header"], 
      StyleBox["    ", "Header"], 
      StyleBox[
       CounterBox["Page"], "PageNumber"]}], "Header", 
    CellMargins -> {{Inherited, 17}, {Inherited, Inherited}}]}},
PrintingOptions->{"FirstPageHeader"->True},
ShowCellBracket->Automatic,
ShowSyntaxStyles->False,
Magnification->1.,
FrontEndVersion->"11.1 for Mac OS X x86 (32-bit, 64-bit Kernel) (March 16, \
2017)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "Default.nb"]], 
   Cell[
    CellGroupData[{
      Cell[
      "Style Environments", "Section", 
       CellChangeTimes -> {{3.64661165091824*^9, 3.646611654013329*^9}, 
         3.6485723794335403`*^9, 3.651347081728628*^9, 3.651347179462186*^9, 
         3.651347384135805*^9, 3.651348171662589*^9}], 
      Cell[
       StyleData[All, "Working"], CellInsertionPointCell -> 
       FEPrivate`FrontEndResource["FEExpressions", "CellInsertionMenu"], 
       CreateCellID -> True, $CellContext`GhostCellInEmptyNotebook -> False], 
      
      Cell[
       StyleData[All, "Printout"], 
       PrintingOptions -> {
        "PageSize" -> {504, 720}, "PrintRegistrationMarks" -> True}, 
       Magnification -> 0.6]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell["Styles for Headers and Footers", "Section"], 
      Cell[
       StyleData["Header"], StyleMenuListing -> None, FontFamily -> "Verdana",
        FontSize -> 7, FontSlant -> "Plain", FontColor -> GrayLevel[0.6]], 
      Cell[
       StyleData["PageNumber"], CellMargins -> {{0, 0}, {4, 1}}, 
       StyleMenuListing -> None, FontFamily -> "Verdana", FontSize -> 7, 
       FontWeight -> "Bold", FontSlant -> "Plain", FontColor -> 
       GrayLevel[0]]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell[
      "WPL Specific", "Section", 
       CellChangeTimes -> {{3.6556608433734913`*^9, 3.6556608489412746`*^9}}], 
      Cell[
       StyleData["Link"], FontFamily -> "Source Sans Pro", FontSize :> 
       If[CurrentValue[
           EvaluationCell[], "FontFamily"] === "Source Sans Pro", Inherited, 
         If[CurrentValue[
            EvaluationCell[], "FontFamily"] === "WolframCodeSans", Inherited, 
          Inherited 0.9]], FontColor -> GrayLevel[0]], 
      Cell[
       StyleData["CodeLink"], 
       ButtonBoxOptions -> {
        Appearance -> None, ButtonFunction :> (FEPrivate`FrontEndExecute[
           FrontEndToken["OpenHelpLink", {
             Part[#, 1], Null}]]& ), ButtonSource -> ButtonContents, 
         Evaluator -> None, Method -> "Preemptive"}]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell[
      "Custom Styles", "Section", 
       CellChangeTimes -> {{3.646611660445352*^9, 3.646611669493331*^9}}], 
      Cell[
       StyleData["Notebook"], PageWidth -> 700, 
       PrintingOptions -> {
        "InnerOuterMargins" -> {35, 16}, "PaperOrientation" -> "Portrait", 
         "PaperSize" -> {504, 720}, 
         "PrintingMargins" -> {{20, 20}, {54, 54}}}, CellLabelAutoDelete -> 
       False, ShowSyntaxStyles -> False, MenuSortingValue -> None, 
       GraphicsBoxOptions -> {ImageSize -> 240}, 
       Graphics3DBoxOptions -> {ImageSize -> 240}], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Title"], CellMargins -> {{64, Inherited}, {50, 72}}, 
          MenuCommandKey -> None, FontFamily -> "Verdana", FontSize -> 42, 
          FontWeight -> "Bold", FontColor -> GrayLevel[0.4]], 
         Cell[
          StyleData["Title", "Printout"], 
          CellMargins -> {{64, Inherited}, {50, 72}}]}, Closed]], 
      Cell[
       StyleData["Chapter"], MenuCommandKey -> None], 
      Cell[
       StyleData["Subchapter"], MenuCommandKey -> None], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Section"], CellFrame -> {{0, 0}, {0, 0}}, CellDingbat -> 
          Cell[
            TextData[
             CounterBox["Section"], 
             StyleBox[
             "|\[NegativeThinSpace]", FontColor -> 
              RGBColor[
               0.9019607843137255, 0.4117647058823529, 0.027450980392156862`],
               FontFamily -> "Courier", FontSize -> 36, FontWeight -> Plain]],
             "SectionNumber"], CellMargins -> {{96, Inherited}, {12, 44}}, 
          Evaluatable -> True, CellGroupingRules -> {"SectionGrouping", 60}, 
          PageBreakAbove -> True, ShowCellLabel -> False, 
          CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
          CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
          CounterIncrements -> "Section", 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", 
          FontSize -> 26, FontSlant -> "Plain", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          InterpretationBoxOptions -> {Editable -> True}], 
         Cell[
          StyleData["Section", "Printout"], 
          CellMargins -> {{96, Inherited}, {12, 2}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionDoubleDigit"], CellFrame -> {{0, 0}, {0, 0}}, 
          CellDingbat -> Cell[
            TextData[
             CounterBox["Section"], 
             StyleBox[
             "|\[NegativeThinSpace]", FontColor -> 
              RGBColor[
               0.9019607843137255, 0.4117647058823529, 0.027450980392156862`],
               FontFamily -> "Courier", FontSize -> 36, FontWeight -> Plain]],
             "SectionNumber"], CellMargins -> {{112, Inherited}, {12, 44}}, 
          Evaluatable -> True, CellGroupingRules -> {"SectionGrouping", 60}, 
          PageBreakAbove -> True, ShowCellLabel -> False, 
          CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
          CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
          CounterIncrements -> "Section", 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", 
          FontSize -> 26, FontSlant -> "Plain", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          InterpretationBoxOptions -> {Editable -> True}], 
         Cell[
          StyleData["SectionDoubleDigit", "Printout"], 
          CellMargins -> {{112, Inherited}, {12, 2}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionNumber"], CellBaseline -> Baseline, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 26, FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["SectionNumber", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionInline"], FontFamily -> 
          "Source Sans Pro Semibold", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["SectionInline", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionNoDingbat"], 
          CellMargins -> {{64, Inherited}, {12, 44}}, Evaluatable -> True, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakAbove -> 
          True, ShowCellLabel -> False, 
          CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
          CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
          CounterIncrements -> "Section", 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", 
          FontSize -> 26, FontSlant -> "Plain", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          InterpretationBoxOptions -> {Editable -> True}], 
         Cell[
          StyleData["SectionNoDingbat", "Printout"], 
          CellMargins -> {{64, Inherited}, {12, 2}}]}, Closed]], 
      Cell[
       StyleData["AnswerKeyNumberedSection"], 
       CellMargins -> {{64, Inherited}, {8, 28}}, Evaluatable -> True, 
       CellGroupingRules -> {"SectionGrouping", 60}, PageBreakAbove -> True, 
       ShowCellLabel -> False, 
       CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
       CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
       CounterIncrements -> "Section", 
       CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
         "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", FontSize -> 
       18, FontSlant -> "Plain", FontColor -> 
       RGBColor[
        0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
       InterpretationBoxOptions -> {Editable -> True}], 
      Cell[
       StyleData["AnswerKeySectionNumber"], CellBaseline -> Baseline, 
       FontFamily -> "Source Sans Pro Semibold", FontSize -> 18, FontColor -> 
       RGBColor[
        0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
      Cell[
       StyleData["IndexLinkGuide"], 
       CellMargins -> {{64, Inherited}, {48, 28}}, Evaluatable -> True, 
       CellGroupingRules -> {"SectionGrouping", 60}, PageBreakAbove -> True, 
       ShowCellLabel -> False, 
       CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
       CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
       CounterIncrements -> "Section", 
       CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
         "Exercise", 0}}, FontFamily -> "Source Sans Pro", FontSize -> 14, 
       FontSlant -> "Plain", FontColor -> 
       RGBColor[
        0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
       InterpretationBoxOptions -> {Editable -> True}], 
      Cell[
       StyleData["Index"], MenuSortingValue -> 10000, FontFamily -> 
       "Source Sans Pro", FontSize -> 11], 
      Cell[
       StyleData["IndexSubentry"], MenuSortingValue -> 10000, FontFamily -> 
       "Source Sans Pro", FontSize -> 11], 
      Cell[
       StyleData["FunctionName"], MenuSortingValue -> 10000, FontFamily -> 
       "Source Sans Pro Semibold", FontWeight -> "Bold"], 
      Cell[
       StyleData["IndexColumn"], 
       CellMargins -> {{66, 0}, {Inherited, Inherited}}, TabSpacings -> {2.}, 
       MenuSortingValue -> 10000, FontFamily -> "Source Sans Pro", 
       GridBoxOptions -> {
        GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
         GridBoxItemSize -> {"Columns" -> {{25}}}, 
         GridBoxSpacings -> {"Columns" -> {{2}}}}], 
      Cell[
       StyleData["IndexSubsection"], 
       CellMargins -> {{64, Inherited}, {9, 28}}, 
       CellGroupingRules -> {"SectionGrouping", 40}, MenuSortingValue -> 
       10000, FontFamily -> "Source Sans Pro", FontSize -> 24], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Subsection"], CellMargins -> {{64, Inherited}, {12, 32}},
           FontFamily -> "Source Sans Pro Semibold", FontSize -> 18, 
          FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["Subsection", "Printout"], 
          CellMargins -> {{64, Inherited}, {12, 32}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ResourcesSubsection"], 
          CellMargins -> {{64, Inherited}, {4, 16}}, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 15, FontSlant -> "Plain", 
          FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["ResourcesSubsection", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 16}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Subsubsection"], 
          CellMargins -> {{64, Inherited}, {6, 12}}, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 16, FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["Subsubsection", "Printout"], 
          CellMargins -> {{64, Inherited}, {6, 12}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularySection"], PageWidth -> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 24}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["VocabularySection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 24}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularyTable", StyleDefinitions -> StyleData["Text"]],
           SpanMaxSize -> 1, FontFamily -> "Source Sans Pro Light", FontColor -> 
          GrayLevel[0.8], 
          GridBoxOptions -> {
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
            GridBoxDividers -> {"Columns" -> {{False}}, "Rows" -> {False, {
                 Directive[
                  Thickness[0.5], "VocabDivColor"]}, False}}, 
            GridBoxItemStyle -> {
             "Columns" -> {"VocabularyCode", Inherited, Inherited}, 
              "Rows" -> {{Automatic}}}, 
            GridBoxSpacings -> {
             "Columns" -> {{0, 1, 2, 1, 2}}, "Rows" -> {{1}}}}], 
         Cell[
          StyleData["VocabularyTable", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "VocabularyTable3Column", StyleDefinitions -> StyleData["Text"]], 
          SpanMaxSize -> 1, FontFamily -> "Source Sans Pro Light", FontColor -> 
          GrayLevel[0.8], 
          GridBoxOptions -> {
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
            GridBoxDividers -> {"Columns" -> {{False}}, "Rows" -> {False, {
                 Directive[
                  Thickness[0.5], "VocabDivColor"]}, False}}, 
            GridBoxItemStyle -> {
             "Columns" -> {
               "VocabularyCode", Inherited, "VocabularyCode", Inherited, 
                Inherited}, "Rows" -> {{Automatic}}}, 
            GridBoxSpacings -> {
             "Columns" -> {{0, 1, 2, 1, 2}}, "Rows" -> {{1}}}}], 
         Cell[
          StyleData["VocabularyTable3Column", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularyText"], FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["VocabularyText", "Printout"], 
          CellMargins -> {{66, 10}, {7, 7}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularyCode", StyleDefinitions -> StyleData["Text"]], 
          Deletable -> False, FontFamily -> "Source Sans Pro", FontSize -> 14,
           FontWeight -> "Bold", FontColor -> GrayLevel[0.25], 
          GridBoxOptions -> {
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
            GridBoxDividers -> {
             "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {True, {True}, True}, "RowsIndexed" -> {}}}], 
         Cell[
          StyleData["VocabularyCode", "Printout"], FontColor -> 
          GrayLevel[0.25]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabDivColor"], FontColor -> GrayLevel[0.8]], 
         Cell[
          StyleData["VocabDivColor", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseSection"], PageWidth -> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 30}}, Evaluatable -> True, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, ShowCellLabel -> False, CellFrameMargins -> {{8, 8}, {4, 6}},
           CellFrameColor -> RGBColor[0.901961, 0.411765, 0.027451], 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro", FontSize -> 18, 
          FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["ExerciseSection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Exercise"], PageWidth -> 700, CellDingbat -> Cell[
            TextData[{"  ", 
              CounterBox["Section"], ".", 
              CounterBox["Exercise"]}], "ExerciseNumber", FontColor -> 
            RGBColor[
             0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
          ShowGroupOpener -> True, CellMargins -> {{108, Inherited}, {4, 8}}, 
          CellGroupingRules -> {"SectionGrouping", 67}, CounterIncrements -> 
          "Exercise", MenuSortingValue -> 10020, MenuCommandKey -> "2", 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Plain", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["Exercise", "Printout"], ShowGroupOpener -> False, 
          CellMargins -> {{110, Inherited}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseNumber"], FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Bold", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["ExerciseNumber", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseSubsection"], PageWidth -> 500, 
          CellFrame -> {{False, False}, {1, False}}, 
          CellMargins -> {{64, Inherited}, {8, 18}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, CellFrameColor -> 
          RGBColor[0.65, 0.6, 0.6], FontFamily -> "Source Sans Pro", FontSize -> 
          18, FontSlant -> "Italic", FontColor -> RGBColor[0.65, 0.6, 0.6]], 
         Cell[
          StyleData["ExerciseSubsection", "Printout"], 
          CellFrame -> {{False, False}, {1, False}}, CellFrameColor -> 
          RGBColor[0.65, 0.6, 0.6]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseNote"], PageWidth -> 700, 
          CellMargins -> {{64, Inherited}, {4, 8}}, PageBreakBelow -> False, 
          MenuSortingValue -> 10050, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25], $CellContext`ReturnCreatesNewCell -> 
          True], 
         Cell[
          StyleData["ExerciseNote", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["QASection"], PageWidth -> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 30}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Question", 0}}, FontFamily -> "Source Sans Pro", FontSize -> 18, 
          FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["QASection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Question"], PageWidth -> 700, 
          CellMargins -> {{64, Inherited}, {2, 12}}, PageBreakBelow -> False, 
          CounterIncrements -> "Question", MenuSortingValue -> 10030, 
          MenuCommandKey -> "3", FontFamily -> "Source Sans Pro", FontSize -> 
          14, FontWeight -> "Bold", FontSlant -> 
          "Plain", $CellContext`ReturnCreatesNewCell -> 
          True, $CellContext`DefaultReturnCreatedCellStyle -> "Answer"], 
         Cell[
          StyleData["Question", "Printout"], 
          CellMargins -> {{65, Inherited}, {2, 12}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Answer"], PageWidth -> 700, 
          CellMargins -> {{66, 10}, {4, 1}}, LineSpacing -> {1.125, 1., 2.}, 
          MenuSortingValue -> 10032, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25], $CellContext`ReturnCreatesNewCell -> 
          True, $CellContext`DefaultReturnCreatedCellStyle -> "Question"], 
         Cell[
          StyleData["Answer", "Printout"], 
          CellMargins -> {{66, 10}, {4, 1}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["QuestionNumber"], FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Bold", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["QuestionNumber", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TechNoteSection"], PageWidth -> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 30}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["TechNoteSection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TechNote"], PageWidth -> 700, CellDingbat -> Cell[
            TextData[{"\[FilledSmallSquare]"}], FontSize -> 12, FontColor -> 
            GrayLevel[0.5]], CellMargins -> {{78, Inherited}, {4, 8}}, 
          CellChangeTimes -> {{3.651515120816633*^9, 3.651515125814807*^9}, 
            3.6515155174947033`*^9}, LineSpacing -> {1.25, 1., 2.}, 
          MenuSortingValue -> 10040, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25], $CellContext`ReturnCreatesNewCell -> 
          True], 
         Cell[
          StyleData["TechNote", "Printout"], 
          CellMargins -> {{82, Inherited}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["MoreExploreSection"], PageWidth -> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 30}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["MoreExploreSection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["MoreExplore"], PageWidth -> 700, 
          CellMargins -> {{64, Inherited}, {4, 8}}, PageBreakBelow -> False, 
          MenuSortingValue -> 10050, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0], $CellContext`ReturnCreatesNewCell -> 
          True], 
         Cell[
          StyleData["MoreExplore", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["MoreExploreShortURL"], 
          CellMargins -> {{64, Inherited}, {4, 8}}, PageBreakBelow -> False, 
          FontFamily -> "Source Sans Pro Light", FontSize -> 14, FontSlant -> 
          "Plain", FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["MoreExploreShortURL", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Text"], CellMargins -> {{66, 10}, {4, 14}}, FontFamily -> 
          "Baskerville", FontSize -> 18, FontColor -> 
          GrayLevel[0], $CellContext`ReturnCreatesNewCell -> True], 
         Cell[
          StyleData["Text", "Printout"], CellMargins -> {{66, 10}, {7, 7}}]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ResourcesText"], CellMargins -> {{66, 10}, {2, 0}}, 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Plain", FontColor -> 
          GrayLevel[0], $CellContext`ReturnCreatesNewCell -> True], 
         Cell[
          StyleData["ResourcesText", "Printout"], 
          CellMargins -> {{66, 10}, {2, 0}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ResourcesLink"], CellMargins -> {{66, 10}, {2, 0}}, 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Italic", FontColor -> 
          GrayLevel[0], $CellContext`ReturnCreatesNewCell -> True], 
         Cell[
          StyleData["ResourcesLink", "Printout"], 
          CellMargins -> {{66, 10}, {2, 0}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CodeCaption"], CellFrame -> {{0, 0}, {0, 0}}, 
          CellMargins -> {{66, 10}, {4, 12}}, PageBreakBelow -> False, 
          CellFrameColor -> GrayLevel[0.4], MenuSortingValue -> 10010, 
          MenuCommandKey -> "1", FontFamily -> "Source Sans Pro", FontSize -> 
          16, FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["CodeCaption", "Printout"], 
          CellMargins -> {{66, 10}, {4, 12}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Input"], CellMargins -> {{99, 10}, {3, 7}}, SpanMaxSize -> 
          1, FontSize -> 15], 
         Cell[
          StyleData["Input", "Printout"], CellMargins -> {{99, 10}, {3, 7}}]},
         Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Output"], CellMargins -> {{99, 10}, {14, 7}}, FontSize -> 
          15], 
         Cell[
          StyleData["Output", "Printout"], 
          CellMargins -> {{99, 10}, {14, 7}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["InputOnly"], CellMargins -> {{99, 10}, {25, 10}}, 
          SpanMaxSize -> 1, MenuSortingValue -> 1500, FontSize -> 15], 
         Cell[
          StyleData["InputOnly", "Printout"], 
          CellMargins -> {{99, 10}, {15, 10}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CellLabel"], 
          CellLabelMargins -> {{12, Inherited}, {Inherited, Inherited}}, 
          LanguageCategory -> None, StyleMenuListing -> None, FontFamily -> 
          "Helvetica Neue", FontSize -> 9, FontWeight -> "Plain", FontSlant -> 
          "Plain", FontColor -> GrayLevel[0.5]], 
         Cell[
          StyleData["CellLabel", "Printout"], FontSize -> 8, FontColor -> 
          GrayLevel[0.5]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Message"], Editable -> False, 
          CellMargins -> {{66, Inherited}, {Inherited, Inherited}}, 
          CellGroupingRules -> "OutputGrouping", TextClipboardType -> 
          "PlainText", PageBreakWithin -> False, GroupPageBreakWithin -> 
          False, GeneratedCell -> True, CellAutoOverwrite -> True, 
          ShowCellLabel -> False, DefaultFormatType -> 
          DefaultOutputFormatType, ContextMenu -> 
          FEPrivate`FrontEndResource["ContextMenus", "Output"], 
          ShowAutoStyles -> False, ShowSyntaxStyles -> False, 
          AutoStyleOptions -> {
           "StringStyle" -> None, "SyntaxErrorStyle" -> None}, 
          HyphenationOptions -> {"HyphenationCharacter" -> "\[Continuation]"},
           AutoItalicWords -> {}, AutoQuoteCharacters -> {}, 
          PasteAutoQuoteCharacters -> {}, LanguageCategory -> None, 
          FormatType -> InputForm, ShowStringCharacters -> False, 
          CounterIncrements -> "Message", MenuSortingValue -> 1600, 
          StyleMenuListing -> None, FontFamily :> 
          CurrentValue["PanelFontFamily"], FontSize -> 11, FontColor -> 
          RGBColor[0.5072, 0.16933, 0.15221], $CellContext`StripStyleOnPaste -> 
          True], 
         Cell[
          StyleData["Message", "Printout"], 
          CellMargins -> {{100, Inherited}, {Inherited, Inherited}}, 
          CellFrameLabels -> {{None, None}, {None, None}}, FontColor -> 
          GrayLevel[0]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseInput", StyleDefinitions -> StyleData["Input"]], 
          CellMargins -> {{88, 10}, {4, 7}}, ShowCellLabel -> False, 
          SpanMaxSize -> 1, FontSize -> 
          14, $CellContext`GeneratedCellStyles -> {
           "Output" -> "ExerciseOutput"}], 
         Cell[
          StyleData["ExerciseInput", "Printout"], 
          CellMargins -> {{88, 10}, {4, 7}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "ExerciseOutput", StyleDefinitions -> StyleData["Output"]], 
          CellMargins -> {{88, 10}, {10, 4}}, ShowCellLabel -> False, 
          FontSize -> 14], 
         Cell[
          StyleData["ExerciseOutput", "Printout"], 
          CellMargins -> {{88, 10}, {10, 4}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Picture"], CellMargins -> {{66, 10}, {10, 10}}, 
          CellGroupingRules -> "GraphicsGrouping", StyleMenuListing -> None], 
         
         Cell[
          StyleData["Picture", "Printout"], 
          CellMargins -> {{66, 10}, {8, 8}}]}, Closed]], 
      Cell[
       StyleData["ExerciseSummaryCell"], PageWidth -> 700, CellFrame -> 0, 
       CellMargins -> {{64, Inherited}, {8, 10}}, 
       CellGroupingRules -> {"SectionGrouping", 64}, PageBreakBelow -> False, 
       ShowCellLabel -> False, CellFrameMargins -> 0, ShowStringCharacters -> 
       False, FontFamily -> "Source Sans Pro", FontSize -> 18, FontColor -> 
       RGBColor[1, 1, 1], 
       GridBoxOptions -> {GridBoxBackground -> {"Columns" -> {{
              RGBColor[0.990997, 0.539528, 0.155779], 
              RGBColor[0.989487, 0.434699, 0.0320439]}}, "Rows" -> {{None}}}, 
         GridBoxItemSize -> {"Columns" -> {
             Scaled[0.7], 
             Scaled[0.3]}, "Rows" -> {{Automatic}}}}], 
      Cell[
       StyleData["ExerciseSummaryHeading"], ShowStringCharacters -> False, 
       FontFamily -> "Source Sans Pro", FontSize -> 18, FontColor -> 
       RGBColor[1, 1, 1]], 
      Cell[
       StyleData["ExerciseSummarySubheading"], ShowStringCharacters -> False, 
       FontFamily -> "Source Sans Pro", FontSize -> 15, FontColor -> 
       RGBColor[1., 0.9294117647058824, 0.7215686274509804]], 
      Cell[
       StyleData["ExercisePreviewButtonText"], ShowStringCharacters -> False, 
       FontFamily -> "Source Sans Pro", FontSize -> 14, FontSlant -> "Plain", 
       FontColor -> RGBColor[0.6, 0.6, 0.6]], 
      Cell[
       StyleData["ExercisePreviewButtonTextHighlight"], ShowStringCharacters -> 
       False, FontFamily -> "Source Sans Pro", FontSize -> 14, FontSlant -> 
       "Plain", FontColor -> 
       RGBColor[
        0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]]}, 
     Closed]], 
   Cell[
    CellGroupData[{
      Cell[
      "Inline and special formatting", "Section", 
       CellChangeTimes -> {{3.646681732592888*^9, 3.646681749414035*^9}}], 
      Cell[
       StyleData["Graphics"], MenuSortingValue -> None], 
      Cell[
       StyleData["Graphics3D"], MenuSortingValue -> None], 
      Cell[
       StyleData["StandardForm"], 
       InputAutoReplacements -> {
        "->" -> "\[Rule]", ":>" -> "\[RuleDelayed]", "<=" -> "\[LessEqual]", 
         ">=" -> "\[GreaterEqual]", "!=" -> "\[NotEqual]", "==" -> "\[Equal]",
          "@>" -> "\\[InlinePart]", "<->" -> "\[UndirectedEdge]", ParentList},
        LineSpacing -> {1.25, 0, 2}, SingleLetterItalics -> False, 
       StyleMenuListing -> None, FontFamily -> "Source Sans Pro", 
       PrivateFontOptions -> {"OperatorSubstitution" -> True}], 
      Cell[
       StyleData["OutputForm"], PageWidth -> DirectedInfinity[1], 
       TextAlignment -> Left, LineSpacing -> {0.6, 1}, 
       AutoQuoteCharacters -> {}, PasteAutoQuoteCharacters -> {}, 
       StyleMenuListing -> None, FontFamily -> "Source Sans Pro", 
       PrivateFontOptions -> {"OperatorSubstitution" -> True}], 
      Cell[
       StyleData["InputForm"], PageWidth -> DirectedInfinity[1], 
       InputAutoReplacements -> {}, AllowInlineCells -> False, Hyphenation -> 
       False, AutoQuoteCharacters -> {}, PasteAutoQuoteCharacters -> {}, 
       AutoSpacing -> False, NumberMarks -> True, AutoNumberFormatting -> 
       False, StyleMenuListing -> None, FontFamily -> "Source Sans Pro", 
       PrivateFontOptions -> {"OperatorSubstitution" -> True}], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["DetailsLink"], FontFamily -> "Source Sans Pro", FontSize :> 
          If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.9]], FontColor -> GrayLevel[0], 
          ButtonBoxOptions -> {
           ButtonFunction :> (
             Function[$CellContext`t, 
              NotebookFind[$CellContext`t, "Notes", All, CellStyle]; 
              NotebookFind[$CellContext`t, "NotesSection", All, CellStyle, 
                AutoScroll -> Top]][
              Documentation`HelpLookup[
               StringJoin["ref/", #]]]& ), ButtonSource -> ButtonContents, 
            Evaluator -> Automatic}], 
         Cell[
          StyleData["DetailsLink", "Printout"], FontFamily -> 
          "Source Sans Pro", FontSize :> If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.88]], FontColor -> GrayLevel[0]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["LinkAlt"], FontFamily -> "Source Sans Pro", FontSize :> 
          If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.9]], FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["LinkAlt", "Printout"], FontFamily -> "Source Sans Pro", 
          FontSize :> If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.88]], FontColor -> GrayLevel[0]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Hyperlink"], MenuSortingValue -> None, FontColor -> 
          RGBColor[0.3, 0.35, 0.5]], 
         Cell[
          StyleData["Hyperlink", "Printout"]]}, Closed]], 
      Cell[
       StyleData[
       "IndexNavigationLink", StyleDefinitions -> StyleData["Hyperlink"]], 
       MenuSortingValue -> None, FontColor -> 
       RGBColor[
        0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
      Cell[
       StyleData["Crosslink"], 
       ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
            
            NotebookLocate[#2, "OpenInNewWindow" -> 
             CurrentValue["HyperlinkModifierKey"]]}]& ), Evaluator -> None, 
         Method -> "Queued"}], 
      Cell[
       StyleData["VocabularyLink"], FontColor -> GrayLevel[0], 
       ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
            
            NotebookLocate[#2, "OpenInNewWindow" -> 
             CurrentValue["HyperlinkModifierKey"]]}]& ), Evaluator -> None, 
         Method -> "Queued"}], 
      Cell[
       StyleData["InlineCode"], SpanMaxSize -> 1, FontColor -> GrayLevel[0]], 
      
      Cell[
       StyleData["InlineCodeText"], SpanMaxSize -> 1, FontFamily -> 
       "Source Sans Pro", FontSize -> 0.95 Inherited], 
      Cell[
       StyleData["NoLabel"], ShowCellLabel -> 
       False, $CellContext`GeneratedCellStyles -> {
        "Output" -> "ExerciseOutput"}], 
      Cell[
       StyleData["MenuName"], FontFamily -> "Verdana", FontWeight -> "Bold", 
       FontColor -> GrayLevel[0.286275]], 
      Cell[
       StyleData["KeyEvent"], CellFrame -> {{0.5, 0.5}, {0.5, 0.5}}, 
       CellFrameMargins -> {{2, 2}, {2, 2}}, CellFrameColor -> GrayLevel[0.7],
        FontFamily -> "Verdana", FontColor -> GrayLevel[0.4]], 
      Cell[
       StyleData["KeyEventDelimiter"], FontColor -> GrayLevel[0.5]], 
      Cell[
       CellGroupData[{
         Cell["Key Styles", "Subsubsection"], 
         Cell[
          StyleData["Key0"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {"Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-2, -2}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}], 
         Cell[
          StyleData["Key1"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #2, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {
                 "ColumnsIndexed" -> {2 -> GrayLevel[0.8352941176470589]}, 
                  "Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-2, -2}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}], 
         Cell[
          StyleData["Key2"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #2, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #3, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {
                 "ColumnsIndexed" -> {
                   2 -> GrayLevel[0.8352941176470589], 3 -> 
                    GrayLevel[0.8352941176470589]}, "Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-2, -2}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}], 
         Cell[
          StyleData["Key3"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #2, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   TemplateBox[{"\[ThickSpace]", #3, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #4, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {
                 "ColumnsIndexed" -> {
                   2 -> GrayLevel[0.8352941176470589], 3 -> 
                    GrayLevel[0.8352941176470589], 4 -> 
                    GrayLevel[0.8352941176470589]}, "Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-2, -2}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Entity styles", "Subsubsection"], 
         Cell[
          StyleData["Entity"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               PaneSelectorBox[{True -> GridBox[{{
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontFamily -> "Source Sans Pro", 
                    FontWeight -> "Plain", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}},
                    BaselinePosition -> {1, 1}], False -> 
                 PaneBox[#, 
                   BaseStyle -> {
                    FontColor -> RGBColor[0.395437, 0.20595, 0.061158]}, 
                   BaselinePosition -> Baseline]}, 
                Dynamic[
                 CurrentValue[Evaluatable]], ImageSize -> Automatic, 
                BaselinePosition -> Baseline, 
                BaseStyle -> {FontFamily -> "Helvetica"}], FrameStyle -> 
               RGBColor[1., 0.504768, 0.], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityFrameless"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              PaneSelectorBox[{True -> GridBox[{{
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontFamily -> "Source Sans Pro", 
                    FontWeight -> "Plain", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                  BaselinePosition -> {1, 1}], False -> 
                PaneBox[#, 
                  BaseStyle -> {
                   FontColor -> RGBColor[0.395437, 0.20595, 0.061158]}, 
                  BaselinePosition -> Baseline]}, 
               Dynamic[
                CurrentValue[Evaluatable]], ImageSize -> Automatic, 
               BaselinePosition -> Baseline, 
               BaseStyle -> {FontFamily -> "Helvetica"}], #3, 
              BaseStyle -> {
               ShowStringCharacters -> False, LineIndent -> 0, 
                PrivateFontOptions -> {
                 FontWeight -> "Plain", "OperatorSubstitution" -> False}}]& ),
             Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityFramelessHot"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {
           DisplayFunction -> (PaneSelectorBox[{True -> GridBox[{{
                   
                   StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0]], 
                   StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0], Selectable -> 
                    False]}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 1}], False -> 
               PaneBox[#, BaseStyle -> {FontColor -> GrayLevel[0]}, 
                 BaselinePosition -> Baseline]}, 
              Dynamic[
               CurrentValue[Evaluatable]], ImageSize -> Automatic, 
              BaselinePosition -> Baseline, 
              BaseStyle -> {
               FontWeight -> "Plain", FontFamily -> "Helvetica", 
                ShowStringCharacters -> False, LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityClass"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               PaneSelectorBox[{True -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}},
                    BaselinePosition -> {1, 2}], False -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]]}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}},
                    BaselinePosition -> {1, 2}]}, 
                Dynamic[
                 CurrentValue[Evaluatable]], ImageSize -> Automatic, 
                BaselinePosition -> Baseline, 
                BaseStyle -> {FontFamily -> "Helvetica"}], FrameStyle -> 
               RGBColor[1., 0.504768, 0.], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityClassFrameless"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              PaneSelectorBox[{True -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                  BaselinePosition -> {1, 2}], False -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]]}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                  BaselinePosition -> {1, 2}]}, 
               Dynamic[
                CurrentValue[Evaluatable]], ImageSize -> Automatic, 
               BaselinePosition -> Baseline, 
               BaseStyle -> {FontFamily -> "Helvetica"}], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityClassFramelessHot"], ShowStringCharacters -> False,
           TemplateBoxOptions -> {
           DisplayFunction -> (PaneSelectorBox[{True -> GridBox[{{
                   PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                   
                   StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0]], 
                   StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0], Selectable -> 
                    False]}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 2}], False -> GridBox[{{
                   PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                   StyleBox[#, FontColor -> GrayLevel[0]]}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 2}]}, 
              Dynamic[
               CurrentValue[Evaluatable]], ImageSize -> Automatic, 
              BaselinePosition -> Baseline, 
              BaseStyle -> {
               FontWeight -> "Plain", FontFamily -> "Helvetica", 
                ShowStringCharacters -> False, LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityProperty"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               
               PaneBox[#, 
                BaseStyle -> {
                 FontSlant -> Italic, FontWeight -> Plain, FontFamily -> 
                  "Source Sans Pro", FontColor -> 
                  RGBColor[0.395437, 0.20595, 0.061158]}, BaselinePosition -> 
                Baseline], FrameStyle -> 
               RGBColor[0.94227, 0.703639, 0.033387], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityPropertyClass"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               PaneBox[
                GridBox[{{
                   PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], #}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 2}], 
                BaseStyle -> {
                 FontSlant -> Italic, FontWeight -> Plain, FontFamily -> 
                  "Source Sans Pro", FontColor -> 
                  RGBColor[0.395437, 0.20595, 0.061158]}, BaselinePosition -> 
                Baseline], FrameStyle -> 
               RGBColor[0.94227, 0.703639, 0.033387], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityValue"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              
              GridBox[{{#, #2}}, GridBoxAlignment -> {"Rows" -> {{Baseline}}},
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
               GridBoxSpacings -> {"Columns" -> {{0}}}, 
               BaselinePosition -> {1, 1}], Background -> 
              RGBColor[{0.9921568627450981, 0.9529411764705882, 
                0.8509803921568627}], BaselinePosition -> Baseline, 
              FrameMargins -> {{1, 1}, {1, 1}}, ImageMargins -> 2, FrameStyle -> 
              RGBColor[{0.9333333333333333, 0.8470588235294118, 
                0.5529411764705883}], RoundingRadius -> 5]& )}]}, Closed]]}, 
     Closed]]}, Visible -> False, FrontEndVersion -> 
  "11.1 for Mac OS X x86 (32-bit, 64-bit Kernel) (March 16, 2017)", 
  StyleDefinitions -> "StylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "p:291"->{
  Cell[655, 23, 422, 10, 
  70, "SectionDoubleDigit", "ExpressionUUID" -> "071a46e0-
   faad-409c-890a-0e6295b00e15",
   CounterAssignments->{{"Section", 46}, {"Subsection", 0}, {
     "Subsubsection", 0}, {"Exercise", 0}},
   CellTags->"p:291"]},
 "i:1"->{
  Cell[1080, 35, 412, 9, 
  70, "Text", "ExpressionUUID" -> "1a455f21-94cd-4c5a-be62-2dd01ecaed44",
   CellTags->"i:1"]},
 "i:2"->{
  Cell[1495, 46, 525, 10, 
  70, "Text", "ExpressionUUID" -> "652d8c2f-8976-41c5-abe4-d30059dd3274",
   CellTags->"i:2"]},
 "i:3"->{
  Cell[2349, 68, 218, 5, 
  70, "CodeCaption", "ExpressionUUID" -> "e1cac363-6a06-42d6-971a-01a0ad6b2d28
   ",
   CellTags->"i:3"]},
 "i:4"->{
  Cell[3136, 93, 422, 9, 
  70, "Text", "ExpressionUUID" -> "20e25a54-c006-46cb-90d2-e85e78421d67",
   CellTags->"i:4"]},
 "i:5"->{
  Cell[3561, 104, 475, 16, 
  70, "CodeCaption", "ExpressionUUID" -> "0a554842-3837-4c53-b8d8-689232273f3a
   ",
   CellTags->"i:5"]},
 "i:6"->{
  Cell[5077, 155, 433, 9, 
  70, "Text", "ExpressionUUID" -> "62c6b4e7-9e6a-4c98-8c01-e445b5c06825",
   CellTags->"i:6"]},
 "i:7"->{
  Cell[6554, 202, 294, 7, 
  70, "CodeCaption", "ExpressionUUID" -> "62afbb58-67a2-471d-8912-18e6dc58c561
   ",
   CellTags->"i:7"]},
 "i:8"->{
  Cell[7555, 235, 575, 16, 
  70, "Text", "ExpressionUUID" -> "e6798835-d02a-4ccd-b026-fb061dbee5ee",
   CellTags->{"i:8", "LastCellOfAPage"}]},
 "LastCellOfAPage"->{
  Cell[7555, 235, 575, 16, 
  70, "Text", "ExpressionUUID" -> "e6798835-d02a-4ccd-b026-fb061dbee5ee",
   CellTags->{"i:8", "LastCellOfAPage"}],
  Cell[21359, 657, 257, 7, 
  70, "Output", "ExpressionUUID" -> "bbefdc4b-a6b9-4fe5-a2f7-069a1ebcf56d",
   Evaluatable->False,
   CellTags->"LastCellOfAPage"],
  Cell[73600, 1835, 1784, 61, 
  70, "Exercise", "ExpressionUUID" -> "6d8eb33c-f9b9-47ed-9e9f-165db8be5321",
   CellTags->"LastCellOfAPage"],
  Cell[82531, 2125, 350, 8, 
  70, "MoreExplore", "ExpressionUUID" -> "c1c8284d-9d9f-4615-b5ea-21e12544f9bb
   ",
   CellTags->"LastCellOfAPage"]},
 "i:9"->{
  Cell[8133, 253, 467, 17, 
  70, "CodeCaption", "ExpressionUUID" -> "e5809107-7ed7-40fa-8497-5141b9a3b4b1
   ",
   CellTags->{"i:9", "p:292"}]},
 "p:292"->{
  Cell[8133, 253, 467, 17, 
  70, "CodeCaption", "ExpressionUUID" -> "e5809107-7ed7-40fa-8497-5141b9a3b4b1
   ",
   CellTags->{"i:9", "p:292"}]},
 "i:10"->{
  Cell[9530, 303, 535, 11, 
  70, "Text", "ExpressionUUID" -> "205b4a36-21f1-441b-8b45-1c2e5bb8cfb7",
   CellTags->"i:10"]},
 "i:11"->{
  Cell[20491, 626, 270, 8, 
  70, "CodeCaption", "ExpressionUUID" -> "042fa617-36e0-4c46-9f2e-613019fd2dad
   ",
   CellTags->"i:11"]},
 "i:12"->{
  Cell[21631, 667, 324, 11, 
  70, "Text", "ExpressionUUID" -> "d3d9b7a4-890f-4c23-ba02-0e6062556474",
   CellTags->{"i:12", "p:293"}]},
 "p:293"->{
  Cell[21631, 667, 324, 11, 
  70, "Text", "ExpressionUUID" -> "d3d9b7a4-890f-4c23-ba02-0e6062556474",
   CellTags->{"i:12", "p:293"}]},
 "i:13"->{
  Cell[21958, 680, 333, 9, 
  70, "CodeCaption", "ExpressionUUID" -> "0beb9f3c-c126-4d2e-809f-9042d78753e7
   ",
   CellTags->"i:13"]},
 "i:14"->{
  Cell[28098, 808, 458, 18, 
  70, "Text", "ExpressionUUID" -> "2e7e45a4-2217-45ce-8b7a-37a877293d43",
   CellTags->"i:14"]},
 "p:294"->{
  Cell[76975, 1946, 161, 4, 
  70, "QASection", "ExpressionUUID" -> "51f3cfb6-5e19-4f45-b067-6d1d5224b0e9",
   
   CellTags->"p:294"]},
 "i:15"->{
  Cell[77344, 1959, 620, 16, 
  70, "Answer", "ExpressionUUID" -> "074c6db3-427a-4c7c-a7d0-b1c6d7c96fe2",
   CellTags->"i:15"]},
 "i:16"->{
  Cell[78172, 1984, 662, 15, 
  70, "Answer", "ExpressionUUID" -> "1216c195-6743-4d7d-8ad5-e55d49f972f6",
   CellTags->"i:16"]},
 "i:17"->{
  Cell[79101, 2010, 495, 10, 
  70, "Answer", "ExpressionUUID" -> "b1f12715-1608-495c-a325-4c17c8ca5c80",
   CellTags->"i:17"]},
 "i:18"->{
  Cell[79832, 2031, 407, 9, 
  70, "Answer", "ExpressionUUID" -> "83839ea8-a8b0-4904-a73b-2a9e3d330cd4",
   CellTags->"i:18"]},
 "i:19"->{
  Cell[80522, 2051, 382, 10, 
  70, "Answer", "ExpressionUUID" -> "5f60a9dd-f74b-48fa-97ea-59a1acf89bab",
   CellTags->"i:19"]},
 "i:20"->{
  Cell[80907, 2063, 218, 5, 
  70, "Question", "ExpressionUUID" -> "471cf27b-e311-4edd-9699-8192a0172aad",
   CellTags->"i:20"]},
 "i:21"->{
  Cell[81654, 2092, 436, 13, 
  70, "TechNote", "ExpressionUUID" -> "28a081a6-c745-43c1-b2a7-11f2cdc6cd57",
   CellTags->"i:21"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"p:291", 172660, 3953},
 {"i:1", 172918, 3960},
 {"i:2", 173050, 3964},
 {"i:3", 173183, 3968},
 {"i:4", 173326, 3973},
 {"i:5", 173458, 3977},
 {"i:6", 173603, 3982},
 {"i:7", 173736, 3986},
 {"i:8", 173880, 3991},
 {"LastCellOfAPage", 174047, 3995},
 {"i:9", 174651, 4010},
 {"p:292", 174809, 4015},
 {"i:10", 174966, 4020},
 {"i:11", 175102, 4024},
 {"i:12", 175249, 4029},
 {"p:293", 175398, 4033},
 {"i:13", 175546, 4037},
 {"i:14", 175693, 4042},
 {"p:294", 175831, 4046},
 {"i:15", 175978, 4051},
 {"i:16", 176118, 4055},
 {"i:17", 176258, 4059},
 {"i:18", 176398, 4063},
 {"i:19", 176537, 4067},
 {"i:20", 176677, 4071},
 {"i:21", 176818, 4075}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[655, 23, 422, 10, 70, "SectionDoubleDigit", "ExpressionUUID" -> \
"071a46e0-faad-409c-890a-0e6295b00e15",
 CounterAssignments->{{"Section", 46}, {"Subsection", 0}, {
   "Subsubsection", 0}, {"Exercise", 0}},
 CellTags->"p:291"],
Cell[1080, 35, 412, 9, 70, "Text", "ExpressionUUID" -> \
"1a455f21-94cd-4c5a-be62-2dd01ecaed44",
 CellTags->"i:1"],
Cell[1495, 46, 525, 10, 70, "Text", "ExpressionUUID" -> \
"652d8c2f-8976-41c5-abe4-d30059dd3274",
 CellTags->"i:2"],
Cell[2023, 58, 323, 8, 70, "Text", "ExpressionUUID" -> \
"ef388a17-43c4-426e-8ff7-c213db3ca3a0"],
Cell[2349, 68, 218, 5, 70, "CodeCaption", "ExpressionUUID" -> \
"e1cac363-6a06-42d6-971a-01a0ad6b2d28",
 CellTags->"i:3"],
Cell[2570, 75, 563, 16, 70, "Input", "ExpressionUUID" -> \
"18d94e65-c769-4866-95d1-06d1ff557c26"],
Cell[3136, 93, 422, 9, 70, "Text", "ExpressionUUID" -> \
"20e25a54-c006-46cb-90d2-e85e78421d67",
 CellTags->"i:4"],
Cell[3561, 104, 475, 16, 70, "CodeCaption", "ExpressionUUID" -> \
"0a554842-3837-4c53-b8d8-689232273f3a",
 CellTags->"i:5"],
Cell[CellGroupData[{
Cell[4061, 124, 287, 8, 70, "Input", "ExpressionUUID" -> \
"58f83671-e93b-455d-b7d3-fd30081b5d93"],
Cell[4351, 134, 487, 10, 70, "Message", "ExpressionUUID" -> \
"fc7b19fe-cded-4edd-ac6e-357a9d20ee66"],
Cell[4841, 146, 221, 6, 70, "Output", "ExpressionUUID" -> \
"c2ab5e02-4faa-40ac-94cb-e394eba2a1c7",
 Evaluatable->False]
}, Open  ]],
Cell[5077, 155, 433, 9, 70, "Text", "ExpressionUUID" -> \
"62c6b4e7-9e6a-4c98-8c01-e445b5c06825",
 CellTags->"i:6"],
Cell[5513, 166, 526, 15, 70, "CodeCaption", "ExpressionUUID" -> \
"e4ee2f1a-754f-4141-a2af-5d778c2a01c7"],
Cell[CellGroupData[{
Cell[6064, 185, 212, 5, 70, "Input", "ExpressionUUID" -> \
"9e636a0b-e857-42ea-bd02-ea522a9480ed"],
Cell[6279, 192, 260, 7, 70, "Output", "ExpressionUUID" -> \
"75667a5c-59ff-46e8-830e-ab88c52fe5e6",
 Evaluatable->False]
}, Open  ]],
Cell[6554, 202, 294, 7, 70, "CodeCaption", "ExpressionUUID" -> \
"62afbb58-67a2-471d-8912-18e6dc58c561",
 CellTags->"i:7"],
Cell[CellGroupData[{
Cell[6873, 213, 379, 11, 70, "Input", "ExpressionUUID" -> \
"cf01afb9-684d-42c5-b477-d6f5d6de8a4f"],
Cell[7255, 226, 285, 6, 70, "Output", "ExpressionUUID" -> \
"3f31e4d7-cd0d-46e3-9c35-34d839c261c4",
 Evaluatable->False]
}, Open  ]],
Cell[7555, 235, 575, 16, 70, "Text", "ExpressionUUID" -> \
"e6798835-d02a-4ccd-b026-fb061dbee5ee",
 CellTags->{"i:8", "LastCellOfAPage"}],
Cell[8133, 253, 467, 17, 70, "CodeCaption", "ExpressionUUID" -> \
"e5809107-7ed7-40fa-8497-5141b9a3b4b1",
 CellTags->{"i:9", "p:292"}],
Cell[CellGroupData[{
Cell[8625, 274, 513, 15, 70, "Input", "ExpressionUUID" -> \
"ee41a2c9-8a1c-48e3-b5f0-8cb71010e946"],
Cell[9141, 291, 374, 9, 70, "Output", "ExpressionUUID" -> \
"ba16175f-0b7e-4861-bd61-95701d475da1",
 Evaluatable->False]
}, Open  ]],
Cell[9530, 303, 535, 11, 70, "Text", "ExpressionUUID" -> \
"205b4a36-21f1-441b-8b45-1c2e5bb8cfb7",
 CellTags->"i:10"],
Cell[10068, 316, 184, 4, 70, "CodeCaption", "ExpressionUUID" -> \
"8a138d6a-acd0-431c-926b-e5c4ed4ef175"],
Cell[CellGroupData[{
Cell[10277, 324, 561, 16, 70, "Input", "ExpressionUUID" -> \
"05536735-e73c-444f-8d41-36924ea20583"],
Cell[10841, 342, 6316, 171, 70, "Output", "ExpressionUUID" -> \
"59294a32-3b6d-4e45-9a13-938a8f3b2426",
 Evaluatable->False]
}, Open  ]],
Cell[17172, 516, 486, 15, 70, "CodeCaption", "ExpressionUUID" -> \
"423b3785-f0c0-414e-8be6-f2cb77c8485f"],
Cell[CellGroupData[{
Cell[17683, 535, 556, 16, 70, "Input", "ExpressionUUID" -> \
"30c39af9-91b3-48c5-aac6-bef22a2a2403"],
Cell[18242, 553, 374, 9, 70, "Output", "ExpressionUUID" -> \
"3f424f35-fae2-4a82-900c-1a8143fb0f20",
 Evaluatable->False]
}, Open  ]],
Cell[18631, 565, 313, 10, 70, "CodeCaption", "ExpressionUUID" -> \
"11910ffb-d9dd-4eea-b7c3-b163e6f549f0"],
Cell[CellGroupData[{
Cell[18969, 579, 712, 21, 70, "Input", "ExpressionUUID" -> \
"df9b2a30-d3f9-48e3-b468-47ca482a7574"],
Cell[19684, 602, 334, 8, 70, "Output", "ExpressionUUID" -> \
"0a398fc4-caf9-4a32-86ce-2162ac4e175a",
 Evaluatable->False]
}, Open  ]],
Cell[20033, 613, 455, 11, 70, "Text", "ExpressionUUID" -> \
"9505a3b7-28a5-48e8-a958-091a50d612b7"],
Cell[20491, 626, 270, 8, 70, "CodeCaption", "ExpressionUUID" -> \
"042fa617-36e0-4c46-9f2e-613019fd2dad",
 CellTags->"i:11"],
Cell[CellGroupData[{
Cell[20786, 638, 284, 8, 70, "Input", "ExpressionUUID" -> \
"e260fd49-5a7f-4282-bdce-bc94016edb51"],
Cell[CellGroupData[{
Cell[21095, 650, 81, 0, 70, "Echo", "ExpressionUUID" -> \
"20a57b77-bbbe-48f6-ae82-3563e4cdf660"],
Cell[21179, 652, 81, 0, 70, "Echo", "ExpressionUUID" -> \
"0f143ab6-4264-4b1c-96e3-c28c277eab91"],
Cell[21263, 654, 81, 0, 70, "Echo", "ExpressionUUID" -> \
"6b3c3cbe-2ac4-43ad-952f-3a261c2c83ac"]
}, Open  ]],
Cell[21359, 657, 257, 7, 70, "Output", "ExpressionUUID" -> \
"bbefdc4b-a6b9-4fe5-a2f7-069a1ebcf56d",
 Evaluatable->False,
 CellTags->"LastCellOfAPage"]
}, Open  ]],
Cell[21631, 667, 324, 11, 70, "Text", "ExpressionUUID" -> \
"d3d9b7a4-890f-4c23-ba02-0e6062556474",
 CellTags->{"i:12", "p:293"}],
Cell[21958, 680, 333, 9, 70, "CodeCaption", "ExpressionUUID" -> \
"0beb9f3c-c126-4d2e-809f-9042d78753e7",
 CellTags->"i:13"],
Cell[CellGroupData[{
Cell[22316, 693, 446, 13, 70, "Input", "ExpressionUUID" -> \
"565766ff-e52f-408a-b7d3-1971ad865389"],
Cell[22765, 708, 4901, 86, 70, "PrintTemporary", "ExpressionUUID" -> \
"1d03f704-e161-4870-9f2c-6d847b571184"],
Cell[27669, 796, 414, 9, 70, "Output", "ExpressionUUID" -> \
"997572e6-7710-47db-9699-473ec9462c45",
 Evaluatable->False]
}, Open  ]],
Cell[28098, 808, 458, 18, 70, "Text", "ExpressionUUID" -> \
"2e7e45a4-2217-45ce-8b7a-37a877293d43",
 CellTags->"i:14"],
Cell[28559, 828, 323, 12, 70, "CodeCaption", "ExpressionUUID" -> \
"0791537a-e057-464e-b71c-f96cf1597331"],
Cell[CellGroupData[{
Cell[28907, 844, 331, 9, 70, "Input", "ExpressionUUID" -> \
"11359746-4a75-4d16-bdae-f3c68f5bb477"],
Cell[29241, 855, 327, 10, 70, "Output", "ExpressionUUID" -> \
"000c3c1d-a950-4f64-9466-fc6e0714cad0",
 Evaluatable->False]
}, Open  ]],
Cell[29583, 868, 448, 15, 70, "CodeCaption", "ExpressionUUID" -> \
"32068377-7b68-4f33-982f-f5fb3d0bb509"],
Cell[CellGroupData[{
Cell[30056, 887, 512, 14, 70, "Input", "ExpressionUUID" -> \
"6d50571f-fadf-4b18-8df4-deee2ca28f5f"],
Cell[30571, 903, 340, 9, 70, "Output", "ExpressionUUID" -> \
"71d287d6-04e7-4531-8bd5-08bbdf211b63",
 Evaluatable->False]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[30960, 918, 159, 4, 70, "VocabularySection", "ExpressionUUID" -> \
"5bab5e00-f131-4048-82aa-70c94292f39e"],
Cell[31122, 924, 2825, 80, 70, "VocabularyTable", "ExpressionUUID" -> \
"ad10a41e-ee2c-4e52-9bdd-4ea969c58a21"]
}, Open  ]],
Cell[CellGroupData[{
Cell[33984, 1009, 1780, 46, 70, "ExerciseSection", "ExpressionUUID" -> \
"49fd136b-f4e2-499b-9da2-39a787d45349"],
Cell[CellGroupData[{
Cell[35789, 1059, 1250, 38, 70, "ExerciseSummaryCell", "ExpressionUUID" -> \
"542791b8-1bc4-45b2-8842-e174dac42999"],
Cell[CellGroupData[{
Cell[37064, 1101, 1284, 41, 70, "Exercise", "ExpressionUUID" -> \
"49e77757-27b5-487d-b3f9-2bc6ba340975"],
Cell[38351, 1144, 32450, 592, 70, "ExerciseOutput", "ExpressionUUID" -> \
"6c53e156-1084-4e51-bb63-be0e09af6ff7"]
}, Closed]],
Cell[CellGroupData[{
Cell[70838, 1741, 1476, 51, 70, "Exercise", "ExpressionUUID" -> \
"dcfec621-46b5-4fc7-8e1a-f44b72599384"],
Cell[72317, 1794, 1246, 36, 70, "ExerciseOutput", "ExpressionUUID" -> \
"780de206-587b-41ff-8068-ed82d1033b7b"]
}, Closed]],
Cell[CellGroupData[{
Cell[73600, 1835, 1784, 61, 70, "Exercise", "ExpressionUUID" -> \
"6d8eb33c-f9b9-47ed-9e9f-165db8be5321",
 CellTags->"LastCellOfAPage"],
Cell[75387, 1898, 1527, 41, 70, "ExerciseOutput", "ExpressionUUID" -> \
"68e50600-227f-4077-934d-ff38dda89e44"]
}, Closed]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[76975, 1946, 161, 4, 70, "QASection", "ExpressionUUID" -> \
"51f3cfb6-5e19-4f45-b067-6d1d5224b0e9",
 CellTags->"p:294"],
Cell[77139, 1952, 202, 5, 70, "Question", "ExpressionUUID" -> \
"a6003fcd-6121-431e-b6f9-217633d8cdcb"],
Cell[77344, 1959, 620, 16, 70, "Answer", "ExpressionUUID" -> \
"074c6db3-427a-4c7c-a7d0-b1c6d7c96fe2",
 CellTags->"i:15"],
Cell[77967, 1977, 202, 5, 70, "Question", "ExpressionUUID" -> \
"eabd5647-24ae-4820-b0d7-5b3f58f8eff2"],
Cell[78172, 1984, 662, 15, 70, "Answer", "ExpressionUUID" -> \
"1216c195-6743-4d7d-8ad5-e55d49f972f6",
 CellTags->"i:16"],
Cell[78837, 2001, 261, 7, 70, "Question", "ExpressionUUID" -> \
"790e05b4-83eb-49be-bd11-7ebd4da741e4"],
Cell[79101, 2010, 495, 10, 70, "Answer", "ExpressionUUID" -> \
"b1f12715-1608-495c-a325-4c17c8ca5c80",
 CellTags->"i:17"],
Cell[79599, 2022, 230, 7, 70, "Question", "ExpressionUUID" -> \
"9a955e17-5ee1-4c87-9a76-d5dc6d6e50f4"],
Cell[79832, 2031, 407, 9, 70, "Answer", "ExpressionUUID" -> \
"83839ea8-a8b0-4904-a73b-2a9e3d330cd4",
 CellTags->"i:18"],
Cell[80242, 2042, 277, 7, 70, "Question", "ExpressionUUID" -> \
"a2df5a96-5bdc-4dec-93fe-b6a8d7a8291b"],
Cell[80522, 2051, 382, 10, 70, "Answer", "ExpressionUUID" -> \
"5f60a9dd-f74b-48fa-97ea-59a1acf89bab",
 CellTags->"i:19"],
Cell[80907, 2063, 218, 5, 70, "Question", "ExpressionUUID" -> \
"471cf27b-e311-4edd-9699-8192a0172aad",
 CellTags->"i:20"],
Cell[81128, 2070, 329, 11, 70, "Answer", "ExpressionUUID" -> \
"bdf9090e-eff2-48c3-8c18-3e9a5aca6a05"]
}, Open  ]],
Cell[CellGroupData[{
Cell[81494, 2086, 157, 4, 70, "TechNoteSection", "ExpressionUUID" -> \
"8685e968-e529-4c3f-b8d0-15f9b98a16ac"],
Cell[81654, 2092, 436, 13, 70, "TechNote", "ExpressionUUID" -> \
"28a081a6-c745-43c1-b2a7-11f2cdc6cd57",
 CellTags->"i:21"],
Cell[82093, 2107, 233, 7, 70, "TechNote", "ExpressionUUID" -> \
"f21e71c9-f172-4109-947b-e3225c734647"]
}, Open  ]],
Cell[CellGroupData[{
Cell[82363, 2119, 165, 4, 70, "MoreExploreSection", "ExpressionUUID" -> \
"e6e6ec09-225e-4dd3-b67c-551754826e72"],
Cell[82531, 2125, 350, 8, 70, "MoreExplore", "ExpressionUUID" -> \
"c1c8284d-9d9f-4615-b5ea-21e12544f9bb",
 CellTags->"LastCellOfAPage"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
(* NotebookSignature OSWrXiFOGT7hSje@dyaXh5BO *)
